-- Copyright (C) 2007 - Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-------------------------------------------------------------------------------
--                                                                           --
-- Containing VHDL Model for the Atoms:                                      --
--                                                                           --
--                                 stratixiv_hssi_refclk_divider                   --
--                                                                           --
-------------------------------------------------------------------------------




LIBRARY IEEE;
USE IEEE.std_logic_1164.ALL;


ENTITY stratixiv_hssi_aux_clock_div IS
    GENERIC (
        clk_divide_by : INTEGER := 1;
        extra_latency : INTEGER := 0
    );
    PORT (
        clk                     : IN STD_LOGIC;   
        reset                   : IN STD_LOGIC := '0';  
        powerdown               : IN STD_LOGIC := '0'; 
        enable_d                : IN STD_LOGIC := '0';
        d                       : IN STD_LOGIC_VECTOR(7 DOWNTO 0) := "00000001";
        clkout                  : OUT STD_LOGIC
    );   
END stratixiv_hssi_aux_clock_div;

ARCHITECTURE clock_div_arch OF stratixiv_hssi_aux_clock_div IS  
    SIGNAL clk_edges                :  INTEGER := -1;     
    SIGNAL div_n_register           :  STD_LOGIC_VECTOR(2 * extra_latency DOWNTO 0)
                                                    := (OTHERS => '0');     
    SIGNAL d_factor : INTEGER := 1;
    FUNCTION to_int(arg : IN STD_LOGIC_VECTOR) RETURN INTEGER IS
    VARIABLE result : INTEGER;
    BEGIN
    result := 0;
    FOR i IN arg'RANGE LOOP
        IF arg(i) = '1' THEN
            result := result + 2**i;
        END IF;
    END LOOP;
    RETURN result;
    END to_int;

BEGIN

    d_factor <= to_int(d) WHEN (enable_d = '1') ELSE clk_divide_by;

    PROCESS(clk,reset,d_factor,powerdown)
    VARIABLE div_n : STD_LOGIC_VECTOR(2 * extra_latency DOWNTO 0) := (OTHERS => '0');
    VARIABLE m : INTEGER := 0;
    VARIABLE running_clk_edge : INTEGER := -1;
    BEGIN
        running_clk_edge := clk_edges;
        IF (powerdown = '1') THEN
            clk_edges <= -1;
            m := 0;    
            div_n := (OTHERS => '0'); 
        ELSIF (d_factor'EVENT) THEN
            clk_edges <= -1;
            m := 0;    
            div_n := (OTHERS => '0'); 
        ELSIF (reset = '1') THEN
            clk_edges <= -1;
            m := 0;    
            div_n := (OTHERS => '0');  
        ELSIF (clk'EVENT AND (clk = '1' OR clk = '0')) THEN
            IF (running_clk_edge = -1) THEN
                m := 0;
                div_n(0) := clk;
                IF (clk = '1') THEN running_clk_edge := 0; END IF;
            ELSIF (running_clk_edge mod d_factor = 0) THEN
                div_n(0) := NOT div_n(0);
            END IF;
            IF (running_clk_edge >= 0 OR clk = '1') THEN 
                clk_edges <= (running_clk_edge + 1) mod (2 * d_factor);
            END IF;
        END IF;
        
        m := 0;
        div_n_register(m) <= div_n(m); 
        WHILE (m < 2 * extra_latency) LOOP
            div_n_register(m+1) <=  div_n_register(m);  
            m := m + 1;
        END LOOP;
        
    END PROCESS;
    clkout <= div_n_register(2 * extra_latency);

END clock_div_arch;

LIBRARY IEEE;
USE IEEE.std_logic_1164.ALL;

USE WORK.stratixiv_hssi_components.ALL;

ENTITY stratixiv_hssi_aux_clock_mult IS
    GENERIC (
        clk_multiply_by : INTEGER := 1;
        pfd_fb_select : string := "internal"
    );
    PORT (
        clk                     : IN STD_LOGIC;   
        fbclk                   : IN STD_LOGIC;   
        adjust                  : IN STD_LOGIC := '0';   
        adjust_without_lol      : IN STD_LOGIC := '0';   
        reset                   : IN STD_LOGIC := '0';   
        enable_m                : IN STD_LOGIC := '0';
        m                       : IN STD_LOGIC_VECTOR(7 DOWNTO 0) := "00000001";
        clkout                  : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);   
        busy                    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0));   
END stratixiv_hssi_aux_clock_mult;

ARCHITECTURE clock_mult_arch OF stratixiv_hssi_aux_clock_mult IS

    SIGNAL busy_m,busy_n : STD_LOGIC_VECTOR(1 DOWNTO 0) := "01";
    SIGNAL mult_n                   :  STD_LOGIC := '0'; 
    SIGNAL m_factor : INTEGER := 1;  
    SIGNAL m_change : BOOLEAN := FALSE;
    SIGNAL sig_clk_fast_period : TIME := 0 ps;
    SIGNAL phase_adjust : TIME := 0 ps;
    SIGNAL init_ext_fb : STD_LOGIC := '0';
    SIGNAL last_fb_rising_edge  :  TIME := 0 ps;     
    SIGNAL sig_last_rising_edge  :  TIME := 0 ps;     
 
    FUNCTION to_int(arg : IN STD_LOGIC_VECTOR) RETURN INTEGER IS
    VARIABLE result : INTEGER;
    BEGIN
    result := 0;
    FOR i IN arg'RANGE LOOP
        IF arg(i) = '1' THEN
            result := result + 2**i;
        END IF;
    END LOOP;
    RETURN result;
    END to_int;
BEGIN

    m_factor <= to_int(m) WHEN (enable_m = '1') ELSE clk_multiply_by;

    PROCESS 
    BEGIN
        IF (alpha_tolower(pfd_fb_select) = ("iqtxrxclk")) THEN
            init_ext_fb <= '1';
        ELSE
            init_ext_fb <= '0';
        END IF;
        WAIT;
    END PROCESS;

    PROCESS (adjust, busy_m, m_factor)
    BEGIN
        IF (m_factor'EVENT) THEN
            busy_n <= "01";
            m_change <= TRUE, FALSE AFTER 1 ps;
        END IF;
        IF (adjust'EVENT AND adjust = '1') THEN
            busy_n <= "01";
        END IF;
        IF (busy_m'EVENT) THEN
            busy_n <= busy_m;
        END IF;
    END PROCESS;
    
    PROCESS (fbclk)
    BEGIN
       IF (fbclk'EVENT AND fbclk = '1') THEN
          last_fb_rising_edge <= NOW;
       END IF;
    END PROCESS;
    
    PROCESS
    VARIABLE clk_period :  TIME;   
    VARIABLE clk_fast_period :  TIME := 0 ps; 
    VARIABLE last_rising_edge  :  TIME := 0 ps;     
    VARIABLE n :  INTEGER := 0;
    VARIABLE clk_adjust_settled : BOOLEAN := FALSE;   
    VARIABLE clk_sync_period :  TIME; 
    VARIABLE clk_adjust : TIME := 0 ps;
    VARIABLE clk_adjust_running : TIME := 0 ps;
    VARIABLE clk_adjust_interval : INTEGER := 0;
    VARIABLE current_mult_val : STD_LOGIC;
    VARIABLE sched_time : time := 0 ps;
    BEGIN
        WAIT UNTIL (clk'EVENT OR reset'EVENT OR adjust'EVENT OR m_change'EVENT);
        IF (m_change'EVENT AND m_change = FALSE) THEN
            mult_n <= '0';
        END IF;
        IF (adjust'EVENT AND adjust = '1') THEN
            busy_m <= "01";
        END IF;
        IF (reset = '1') THEN
            mult_n <= '0';   
            busy_m <= "01"; 
        ELSIF (clk'EVENT AND clk = '1') THEN
            IF (init_ext_fb = '1') THEN
                IF (busy_n = "01" and adjust_without_lol = '0') THEN -- first rising edge            
                        mult_n <= '0';    
                        last_rising_edge := NOW;    
                        sig_last_rising_edge <= last_rising_edge;    
                        busy_m <= "11";    
                ELSE
                    last_rising_edge := NOW;    
                    sig_last_rising_edge <= last_rising_edge;    
                    IF (busy_n = "01" and adjust_without_lol = '1') THEN -- first rising edge            
                        mult_n <= '0';    
                        busy_m <= "11";
                    END IF;
                    IF (busy_n = "11") THEN -- second rising edge                
                        clk_period := NOW - sig_last_rising_edge;    

                        IF ((NOW - last_fb_rising_edge) >= clk_period) THEN
                            phase_adjust <= 0 ps;
                        ELSE
                            phase_adjust <= NOW - last_fb_rising_edge;    
                        END IF;
    
                        clk_fast_period := clk_period / m_factor;    
                        sig_clk_fast_period <= clk_fast_period;    
                        clk_adjust := clk_period - (clk_fast_period * m_factor);    
                        IF ((phase_adjust = 0 ps) AND (sig_last_rising_edge = last_fb_rising_edge)) THEN
                                busy_m <= "00";    
                        END IF;
                    END IF;
                    current_mult_val := mult_n;
                    --mult_n <= transport NOT mult_n after phase_adjust;    
                    mult_n <= NOT mult_n;    
                    IF (clk_adjust > 0 ps) THEN
                        clk_adjust_running := clk_adjust + 1 ps;    
                    END IF;
                    clk_adjust_settled := (clk_adjust = 0 ps);    --  if no adjustment necessary
                    n := m_factor;
                    sched_time := 0 ps;
                    WHILE (n >= 1) LOOP
                        IF (clk_adjust_settled = FALSE) THEN
                            clk_adjust_running := clk_adjust_running - 1 ps;    
                            clk_adjust_interval := (n * 1 ps)/ clk_adjust_running;    
                            IF ((n * 1 ps) - (clk_adjust_interval * clk_adjust_running) = 0 ps) THEN
                                clk_adjust_settled := TRUE;    
                            END IF;
                            clk_sync_period := clk_fast_period + 1 ps;    
                        ELSE
                            IF (clk_adjust = 0 ps) THEN
                                clk_sync_period := clk_fast_period;    
                            ELSE
                                IF (n mod clk_adjust_interval = 0) THEN
                                    clk_sync_period := clk_fast_period + 1 ps;    
                                ELSE
                                    clk_sync_period := clk_fast_period;    
                                END IF;
                            END IF;
                        END IF;
                        IF (reset = '1') THEN
                            mult_n <= '0';    
                        ELSE
                              -- begin new code
                              sched_time := sched_time + clk_sync_period/2;
                              mult_n <= transport current_mult_val after sched_time;
                              if (n > 1) then
                                  sched_time := sched_time + (clk_sync_period - clk_sync_period/2);
                                  mult_n <= transport NOT current_mult_val after sched_time;
                              end if;
                        END IF;
                        n := n - 1;
                    END LOOP;
                END IF;
            ELSE --end of external feedback
                IF (busy_n = "01" and adjust_without_lol = '0') THEN -- first rising edge            
                    mult_n <= '0';    
                    last_rising_edge := NOW;    
                    busy_m <= "11";    
                ELSE
                    IF (busy_n = "01" and adjust_without_lol = '1') THEN -- first rising edge            
                       mult_n <= '0';    
                       last_rising_edge := NOW;    
                       busy_m <= "11";
                    END IF;
                    IF (busy_n = "11") THEN -- second rising edge                
                        clk_period := NOW - last_rising_edge;    
                        clk_fast_period := clk_period / m_factor;    
                        sig_clk_fast_period <= clk_fast_period;    
                        clk_adjust := clk_period - (clk_fast_period * m_factor);    
                        busy_m <= "00";    
                    END IF;
                    current_mult_val := mult_n;
                    mult_n <= NOT mult_n;    
                    IF (clk_adjust > 0 ps) THEN
                        clk_adjust_running := clk_adjust + 1 ps;    
                    END IF;
                    clk_adjust_settled := (clk_adjust = 0 ps);    --  if no adjustment necessary
                    n := m_factor;
                    sched_time := 0 ps;
                    WHILE (n >= 1) LOOP
                        IF (clk_adjust_settled = FALSE) THEN
                            clk_adjust_running := clk_adjust_running - 1 ps;    
                            clk_adjust_interval := (n * 1 ps)/ clk_adjust_running;    
                            IF ((n * 1 ps) - (clk_adjust_interval * clk_adjust_running) = 0 ps) THEN
                                clk_adjust_settled := TRUE;    
                            END IF;
                            clk_sync_period := clk_fast_period + 1 ps;    
                        ELSE
                            IF (clk_adjust = 0 ps) THEN
                                clk_sync_period := clk_fast_period;    
                            ELSE
                                IF (n mod clk_adjust_interval = 0) THEN
                                    clk_sync_period := clk_fast_period + 1 ps;    
                                ELSE
                                    clk_sync_period := clk_fast_period;    
                                END IF;
                            END IF;
                        END IF;
                        IF (reset = '1') THEN
                            mult_n <= '0';    
                        ELSE
    --                        WAIT FOR (clk_sync_period/2);
    --                        mult_n <= NOT mult_n;  
    --                        IF (n > 1) THEN
    --                            WAIT FOR (clk_sync_period - clk_sync_period/2);
    --                            mult_n <= NOT mult_n;    
    --                        END IF;
                              -- begin new code
                              sched_time := sched_time + clk_sync_period/2;
                              mult_n <= transport current_mult_val after sched_time;
                              if (n > 1) then
                                  sched_time := sched_time + (clk_sync_period - clk_sync_period/2);
                                  mult_n <= transport NOT current_mult_val after sched_time;
                              end if;
                        END IF;
                        n := n - 1;
                    END LOOP;
                END IF;
            END IF; --end of internal feedback
        END IF;
    END PROCESS;
    clkout(0) <= transport mult_n after phase_adjust;
    clkout(1) <= transport mult_n after (sig_clk_fast_period/4 + phase_adjust);
    clkout(2) <= transport NOT mult_n after phase_adjust; 
    clkout(3) <= transport mult_n after ((sig_clk_fast_period * 3)/4 + phase_adjust);
    busy <= busy_n;

END clock_mult_arch;
Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_divby2q IS
   PORT (
      
      clk       : IN STD_LOGIC;
      
      clk0      : OUT STD_LOGIC;
      clk90     : OUT STD_LOGIC;
      clk180    : OUT STD_LOGIC;
      clk270    : OUT STD_LOGIC;
      clkb      : IN STD_LOGIC;
      rst_n     : IN STD_LOGIC;
      vcce_la   : IN STD_LOGIC;
      vssexqyx  : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_divby2q;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_divby2q IS
   
   SIGNAL clk0_init   : STD_LOGIC := '0' ;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL clk0_xhdl0  : STD_LOGIC := '1' ;
   SIGNAL clk90_xhdl1 : STD_LOGIC := '1' ;
   SIGNAL clk180_xhdl0 : STD_LOGIC := '0' ;
BEGIN
   -- Drive referenced outputs
   clk0 <= clk0_xhdl0;
   clk90 <= clk90_xhdl1;
   clk180 <= clk180_xhdl0;
   
   PROCESS (clk, rst_n)
   BEGIN
      IF (rst_n = '0') THEN
         clk0_init <= '0';
         clk0_xhdl0 <= '1';
         clk180_xhdl0 <= '1';
      ELSIF (clk'EVENT AND clk = '1') THEN
         clk0_init <= '1';
         clk0_xhdl0 <= NOT(clk0_xhdl0);
         clk180_xhdl0 <= clk0_xhdl0;
      END IF;
   END PROCESS;
   
   PROCESS (clkb, rst_n)
   BEGIN
      IF (rst_n = '0') THEN
         clk90_xhdl1 <= '1';
         clk270 <= '1';
      ELSIF (clkb'EVENT AND clkb = '1') THEN
         IF (clk0_init = '1') THEN
            clk90_xhdl1 <= NOT(clk90_xhdl1);
            clk270 <= clk90_xhdl1;
         END IF;
      END IF;
   END PROCESS;
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_pcie_sw IS
   GENERIC (
      
      PARAM_DELAY  : INTEGER := 0
   );
   PORT (
      cpulse       : IN STD_LOGIC;
      
      cpulse_out   : OUT STD_LOGIC;
      cpulseb      : IN STD_LOGIC;
      cpulsei      : IN STD_LOGIC;
      dynamic_sw   : IN STD_LOGIC;
      gen2ngen1    : OUT STD_LOGIC;
      hclk         : OUT STD_LOGIC;
      hfclkn       : IN STD_LOGIC;
      hfclkn_out   : OUT STD_LOGIC;
      hfclkp       : IN STD_LOGIC;
      hfclkp_out   : OUT STD_LOGIC;
      lfclkn       : IN STD_LOGIC;
      lfclkn_out   : OUT STD_LOGIC;
      lfclkp       : IN STD_LOGIC;
      lfclkp_out   : OUT STD_LOGIC;
      pcie_sw      : IN STD_LOGIC;
      pcie_sw_cdr  : OUT STD_LOGIC;
      pclk         : OUT STD_LOGIC;
      pdb          : IN STD_LOGIC;
      rst_n        : IN STD_LOGIC;
      vccelxqyx    : IN STD_LOGIC;
      vssexqyx     : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_pcie_sw;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_pcie_sw IS
   COMPONENT stratixiv_hssi_pma_c_divby2q
      PORT (
         clk          : IN STD_LOGIC;
         clk0         : OUT STD_LOGIC;
         clk90        : OUT STD_LOGIC;
         clk180       : OUT STD_LOGIC;
         clk270       : OUT STD_LOGIC;
         clkb         : IN STD_LOGIC;
         rst_n        : IN STD_LOGIC;
         vcce_la      : IN STD_LOGIC;
         vssexqyx     : IN STD_LOGIC
      );
   END COMPONENT;
   
   SIGNAL nclri             : STD_LOGIC;
   SIGNAL clk_selectb       : STD_LOGIC;
   SIGNAL div2_enlf         : STD_LOGIC;
   SIGNAL lfclk0_div2       : STD_LOGIC;
   SIGNAL lfclk90_div2      : STD_LOGIC;
   SIGNAL lfclk180_div2     : STD_LOGIC;
   SIGNAL lfclk270_div2     : STD_LOGIC;
   SIGNAL lfclk0_div2_int   : STD_LOGIC;
   SIGNAL lfclk90_div2_int  : STD_LOGIC;
   SIGNAL lfclk180_div2_int : STD_LOGIC;
   SIGNAL lfclk270_div2_int : STD_LOGIC;
   SIGNAL hfclk0_div2       : STD_LOGIC;
   SIGNAL hfclk90_div2      : STD_LOGIC;
   SIGNAL hfclk180_div2     : STD_LOGIC;
   SIGNAL hfclk270_div2     : STD_LOGIC;
   SIGNAL cpulse_div2       : STD_LOGIC;
   SIGNAL div2_enhf         : STD_LOGIC;
   SIGNAL div2_enhf_reg     : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL lfclkp_out_xhdl0  : STD_LOGIC;
   SIGNAL pcie_sw_cdr_xhdl1 : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   lfclkp_out <= lfclkp_out_xhdl0;
   pcie_sw_cdr <= pcie_sw_cdr_xhdl1;
   
   PROCESS (hfclkp)
   BEGIN
      IF (hfclkp'EVENT AND hfclkp = '0') THEN
         div2_enhf_reg <= div2_enhf;
      END IF;
   END PROCESS;
   
   xhf : stratixiv_hssi_pma_c_divby2q
      PORT MAP (
         clk       => hfclkp,
         clk0      => hfclk0_div2,
         clk90     => hfclk90_div2,
         clk180    => hfclk180_div2,
         vcce_la   => '1',
         vssexqyx  => '0',
         clk270    => hfclk270_div2,
         clkb      => hfclkn,
         rst_n     => div2_enhf_reg
      );
   
   xlf : stratixiv_hssi_pma_c_divby2q
      PORT MAP (
         clk       => lfclkp,
         clk0      => lfclk0_div2_int,
         clk90     => lfclk90_div2_int,
         clk180    => lfclk180_div2_int,
         vcce_la   => '1',
         vssexqyx  => '0',
         clk270    => lfclk270_div2_int,
         clkb      => lfclkn,
         rst_n     => '1'
      );
   
--   hclk <= NOT((NOT(lfclkp) AND nclri));
   hclk <= NOT((NOT(lfclkp) AND rst_n));
   pclk <= lfclkp_out_xhdl0;
   
   clk_selectb <= div2_enhf_reg;
   div2_enlf <= div2_enhf_reg;
   gen2ngen1 <= NOT((div2_enhf_reg AND nclri));
   nclri <= dynamic_sw AND rst_n;
   pcie_sw_cdr_xhdl1 <= NOT(pcie_sw) AND dynamic_sw AND rst_n;
--   (lfclk0_div2, lfclk90_div2, lfclk180_div2, lfclk270_div2) <= (lfclk0_div2_int & lfclk90_div2_int & lfclk180_div2_int & lfclk270_div2_int) WHEN (div2_enhf_reg = '1') ELSE
--                                                                "0000";
   lfclk0_div2 <= lfclk0_div2_int WHEN (div2_enhf_reg = '1') ELSE '0';
   lfclk90_div2 <= lfclk90_div2_int WHEN (div2_enhf_reg = '1') ELSE '0';
   lfclk180_div2 <= lfclk180_div2_int WHEN (div2_enhf_reg = '1') ELSE '0';
   lfclk270_div2 <= lfclk270_div2_int WHEN (div2_enhf_reg = '1') ELSE '0';

   hfclkp_out <= hfclkp WHEN ((NOT(clk_selectb)) = '1') ELSE
                 hfclk0_div2;
   hfclkn_out <= hfclkn WHEN ((NOT(clk_selectb)) = '1') ELSE
                 hfclk180_div2;
   cpulse_out <= cpulse WHEN ((NOT(clk_selectb)) = '1') ELSE
                 cpulse_div2 AND lfclk0_div2;
   lfclkp_out_xhdl0 <= lfclkp WHEN ((NOT(clk_selectb)) = '1') ELSE
                       lfclk0_div2;
   lfclkn_out <= lfclkn WHEN ((NOT(clk_selectb)) = '1') ELSE
                 lfclk180_div2;
   
   -- cpulse div by 2
   PROCESS (hfclk0_div2, div2_enhf_reg)
   BEGIN
      IF (div2_enhf_reg = '0') THEN
         cpulse_div2 <= '0';
      ELSIF (hfclk0_div2'EVENT AND hfclk0_div2 = '1') THEN
         -- - stratixiv_hssi_pma_c_deglitch -
         -- Synchronization with lclk270 _div2
         cpulse_div2 <= cpulse;
      END IF;
   END PROCESS;
   
   PROCESS (lfclk270_div2_int, rst_n)
   BEGIN
      IF (rst_n = '0') THEN
         div2_enhf <= '0';
      ELSIF (lfclk270_div2_int'EVENT AND lfclk270_div2_int = '1') THEN
         div2_enhf <= pcie_sw_cdr_xhdl1;
      END IF;
   END PROCESS;
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;

   
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_controller_4t16 IS
   PORT (
      
      atben    : OUT STD_LOGIC;
      ct0      : IN STD_LOGIC;
      ct1      : IN STD_LOGIC;
      ct2      : IN STD_LOGIC;
      ct3      : IN STD_LOGIC;
      tmsb1    : OUT STD_LOGIC;
      tmsb2    : OUT STD_LOGIC;
      tmsb3    : OUT STD_LOGIC;
      tmsb4    : OUT STD_LOGIC;
      tmsb5    : OUT STD_LOGIC;
      tmsb6    : OUT STD_LOGIC;
      tmsb7    : OUT STD_LOGIC;
      tmsb8    : OUT STD_LOGIC;
      tmsb9    : OUT STD_LOGIC;
      tmsb10   : OUT STD_LOGIC;
      tmsb11   : OUT STD_LOGIC;
      tmsb12   : OUT STD_LOGIC;
      tmsb13   : OUT STD_LOGIC;
      tmsb14   : OUT STD_LOGIC;
      tmsb15   : OUT STD_LOGIC;
      vcce_la  : IN STD_LOGIC;
      vssex    : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_controller_4t16;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_controller_4t16 IS
   
   SIGNAL tmsb0    : STD_LOGIC;
   SIGNAL tmsb_bus : STD_LOGIC_VECTOR(15 DOWNTO 0);
   -- X-HDL generated signals

   SIGNAL xhdl0 : STD_LOGIC_VECTOR(3 DOWNTO 0);
BEGIN
   
   tmsb0 <= tmsb_bus(0);
   tmsb1 <= tmsb_bus(1);
   tmsb2 <= tmsb_bus(2);
   tmsb3 <= tmsb_bus(3);
   tmsb4 <= tmsb_bus(4);
   tmsb5 <= tmsb_bus(5);
   tmsb6 <= tmsb_bus(6);
   tmsb7 <= tmsb_bus(7);
   tmsb8 <= tmsb_bus(8);
   tmsb9 <= tmsb_bus(9);
   tmsb10 <= tmsb_bus(10);
   tmsb11 <= tmsb_bus(11);
   tmsb12 <= tmsb_bus(12);
   tmsb13 <= tmsb_bus(13);
   tmsb14 <= tmsb_bus(14);
   tmsb15 <= tmsb_bus(15);
   
   atben <= reduction_or((ct3 & ct2 & ct1 & ct0));
   xhdl0 <= ct3 & ct2 & ct1 & ct0;
   PROCESS (ct3, ct2, ct1, ct0)
   BEGIN
      CASE xhdl0 IS
         WHEN "0000" =>
            tmsb_bus <= "0000000000000001";
         WHEN "0001" =>
            tmsb_bus <= "0000000000000010";
         WHEN "0010" =>
            tmsb_bus <= "0000000000000100";
         WHEN "0011" =>
            tmsb_bus <= "0000000000001000";
         WHEN "0100" =>
            tmsb_bus <= "0000000000010000";
         WHEN "0101" =>
            tmsb_bus <= "0000000000100000";
         WHEN "0110" =>
            tmsb_bus <= "0000000001000000";
         WHEN "0111" =>
            tmsb_bus <= "0000000010000000";
         WHEN "1000" =>
            tmsb_bus <= "0000000100000000";
         WHEN "1001" =>
            tmsb_bus <= "0000001000000000";
         WHEN "1010" =>
            tmsb_bus <= "0000010000000000";
         WHEN "1011" =>
            tmsb_bus <= "0000100000000000";
         WHEN "1100" =>
            tmsb_bus <= "0001000000000000";
         WHEN "1101" =>
            tmsb_bus <= "0010000000000000";
         WHEN "1110" =>
            tmsb_bus <= "0100000000000000";
         WHEN "1111" =>
            tmsb_bus <= "1000000000000000";
         WHEN OTHERS =>
            tmsb_bus <= "0000000000000000";
      END CASE;
   END PROCESS;
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;
   USE ieee.std_logic_unsigned.all;

ENTITY stratixiv_hssi_pma_c_clkgendrv IS
   PORT (
      
      clk0       : IN STD_LOGIC;
      clk90      : IN STD_LOGIC;
      clk180     : IN STD_LOGIC;
      clk270     : IN STD_LOGIC;
      
      cpulse     : OUT STD_LOGIC;
      cpulseb    : OUT STD_LOGIC;
      cpulseo    : OUT STD_LOGIC;
      div5       : IN STD_LOGIC;
      hfclk_n    : OUT STD_LOGIC;
      hfclk_p    : OUT STD_LOGIC;
      lfclk_n    : OUT STD_LOGIC;
      lfclk_p    : OUT STD_LOGIC;
      rst_n      : IN STD_LOGIC;
      vccelxqyx  : IN STD_LOGIC;
      vssexqyx   : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_clkgendrv;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_clkgendrv IS
   
   SIGNAL lfclkp_counter : INTEGER := 0 ;
   SIGNAL lfclkp_div5    : STD_LOGIC := '0' ;
   SIGNAL lfclkp_div4    : STD_LOGIC := '0' ;
   SIGNAL lfclkn_div5    : STD_LOGIC := '1' ;
   SIGNAL lfclkn_div4    : STD_LOGIC := '1' ;
   SIGNAL cpulse_div4    : STD_LOGIC := '0' ;
   SIGNAL cpulse_div5    : STD_LOGIC := '0' ;
   SIGNAL init_done      : STD_LOGIC := '0' ;
--   SIGNAL hfclk_p_prev   : STD_LOGIC := '0' ;
   SIGNAL hfclk_p_prev   : STD_LOGIC;
   SIGNAL hfclk_p_wire   : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL cpulse_xhdl0   : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   cpulse <= cpulse_xhdl0;
   
   hfclk_p <= hfclk_p_wire;
   hfclk_p_wire <= '0' WHEN (rst_n = '0') ELSE
                   NOT(clk180);
   hfclk_n <= '1' WHEN (rst_n = '0') ELSE
                   NOT(clk0);
   lfclk_p <= lfclkp_div5 WHEN (div5 = '1') ELSE
              lfclkp_div4;
   lfclk_n <= lfclkn_div5 WHEN (div5 = '1') ELSE
              lfclkn_div4;
   cpulse_xhdl0 <= cpulse_div5 WHEN (div5 = '1') ELSE
                   cpulse_div4;
   cpulseo <= cpulse_xhdl0;
   cpulseb <= NOT(cpulse_xhdl0);
   
   
   -- Edge counter used for lfclkp/n_div4/div5 and cpulse_div4/5 generation
   PROCESS (hfclk_p_wire, rst_n)
   BEGIN
      IF (rst_n = '0') THEN
         lfclkp_counter <= 0;
         init_done <= '0';
      ELSIF (hfclk_p_wire'event) THEN
         IF (hfclk_p_wire /= hfclk_p_prev) THEN
            -- after one cycle of hfclkp, if set, reset cpulse_div4/5
            IF (hfclk_p_wire = '1' AND cpulse_div5 = '1') THEN
               cpulse_div5 <= '0';
            END IF;
            IF (hfclk_p_wire = '1' AND cpulse_div4 = '1') THEN
               -- generation of lfclkp/n_div5 & pulse_div5 ** posedge of lfclkp_div5 occurs at posedge of hfclkp **
               cpulse_div4 <= '0';
            END IF;
            IF ((lfclkp_counter MOD 5 = 1) AND (hfclk_p_wire = '1')) THEN
               lfclkp_div5 <= '1';
               lfclkn_div5 <= '0';
               IF (lfclkp_div5 = '0') THEN
                  cpulse_div5 <= '1';
               END IF;
            ELSIF ((lfclkp_counter MOD 5 = 1) AND (hfclk_p_wire = '0')) THEN
               lfclkp_div5 <= '0';
               lfclkn_div5 <= '1';
            END IF;
            -- generation of lfclkp/n_div4 & pulse_div4 ** posedge of lfclkp_div5 occurs at posedge of hfclkp **
            IF ((hfclk_p_wire = '1') AND ((lfclkp_counter MOD 4 = 0) OR (lfclkp_counter MOD 4 = 1))) THEN
               IF (init_done = '0') THEN
                  lfclkp_div4 <= '1';
                  lfclkn_div4 <= '0';
                  init_done <= '1';
               ELSE
                  lfclkp_div4 <= NOT(lfclkp_div4);
                  lfclkn_div4 <= NOT(lfclkn_div4);
               END IF;
               IF (lfclkp_div4 = '0') THEN
                  cpulse_div4 <= '1';
               END IF;
            END IF;
            lfclkp_counter <= lfclkp_counter + 1;
         END IF;
      END IF;
      hfclk_p_prev <= hfclk_p_wire;
   END PROCESS;
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_clkgenbuf IS
   GENERIC (
      
      PARAM_DELAY  : INTEGER := 0
   );
   PORT (
      cgb_x_en     : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      clk0_0       : IN STD_LOGIC;
      clk0_1       : IN STD_LOGIC;
      
      clk0_out     : OUT STD_LOGIC;
      clk90_0      : IN STD_LOGIC;
      clk90_1      : IN STD_LOGIC;
      clk90_out    : OUT STD_LOGIC;
      clk180_0     : IN STD_LOGIC;
      clk180_1     : IN STD_LOGIC;
      clk180_out   : OUT STD_LOGIC;
      clk270_0     : IN STD_LOGIC;
      clk270_1     : IN STD_LOGIC;
      clk270_out   : OUT STD_LOGIC;
      cmu_sel      : IN STD_LOGIC;
      cpulse       : OUT STD_LOGIC;
      div5         : IN STD_LOGIC;
      dynamic_sw   : IN STD_LOGIC;
      gen2ngen1    : OUT STD_LOGIC;
      hclk         : OUT STD_LOGIC;
      hfclk_n      : OUT STD_LOGIC;
      hfclk_p      : OUT STD_LOGIC;
      lfclk_n      : OUT STD_LOGIC;
      lfclk_p      : OUT STD_LOGIC;
      m_sel        : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pcie_sw      : IN STD_LOGIC;
      pcie_sw_cdr  : OUT STD_LOGIC;
      pclk         : OUT STD_LOGIC;
      pdb          : IN STD_LOGIC;
      rst_n        : IN STD_LOGIC;
      rst_n1       : OUT STD_LOGIC;
      vccelxqyx    : IN STD_LOGIC;
      vssexqyx     : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_clkgenbuf;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_clkgenbuf IS
   COMPONENT stratixiv_hssi_pma_c_divby2q
      PORT (
         clk          : IN STD_LOGIC;
         clk0         : OUT STD_LOGIC;
         clk90        : OUT STD_LOGIC;
         clk180       : OUT STD_LOGIC;
         clk270       : OUT STD_LOGIC;
         clkb         : IN STD_LOGIC;
         rst_n        : IN STD_LOGIC;
         vcce_la      : IN STD_LOGIC;
         vssexqyx     : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_c_clkgendrv
      PORT (
         clk0         : IN STD_LOGIC;
         clk90        : IN STD_LOGIC;
         clk180       : IN STD_LOGIC;
         clk270       : IN STD_LOGIC;
         cpulse       : OUT STD_LOGIC;
         cpulseb      : OUT STD_LOGIC;
         cpulseo      : OUT STD_LOGIC;
         div5         : IN STD_LOGIC;
         hfclk_n      : OUT STD_LOGIC;
         hfclk_p      : OUT STD_LOGIC;
         lfclk_n      : OUT STD_LOGIC;
         lfclk_p      : OUT STD_LOGIC;
         rst_n        : IN STD_LOGIC;
         vccelxqyx    : IN STD_LOGIC;
         vssexqyx     : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_c_pcie_sw
   GENERIC (
      
      PARAM_DELAY  : INTEGER := 0
   );
    PORT (
      cpulse       : IN STD_LOGIC;
      cpulse_out   : OUT STD_LOGIC;
      cpulseb      : IN STD_LOGIC;
      cpulsei      : IN STD_LOGIC;
      dynamic_sw   : IN STD_LOGIC;
      gen2ngen1    : OUT STD_LOGIC;
      hclk         : OUT STD_LOGIC;
      hfclkn       : IN STD_LOGIC;
      hfclkn_out   : OUT STD_LOGIC;
      hfclkp       : IN STD_LOGIC;
      hfclkp_out   : OUT STD_LOGIC;
      lfclkn       : IN STD_LOGIC;
      lfclkn_out   : OUT STD_LOGIC;
      lfclkp       : IN STD_LOGIC;
      lfclkp_out   : OUT STD_LOGIC;
      pcie_sw      : IN STD_LOGIC;
      pcie_sw_cdr  : OUT STD_LOGIC;
      pclk         : OUT STD_LOGIC;
      pdb          : IN STD_LOGIC;
      rst_n        : IN STD_LOGIC;
      vccelxqyx    : IN STD_LOGIC;
      vssexqyx     : IN STD_LOGIC
   );
END COMPONENT;

   SIGNAL pdb_buf              : STD_LOGIC;
   SIGNAL clk_in               : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL clk_div2             : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL clk_div4             : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL clk_out              : STD_LOGIC_VECTOR(3 DOWNTO 0);
   
   SIGNAL rst_n1_clkgenbuf_div : STD_LOGIC;
   SIGNAL rst_n2_clkgenbuf_div : STD_LOGIC;
   SIGNAL cpulse_i             : STD_LOGIC;
   SIGNAL cpulseb_i            : STD_LOGIC;
   SIGNAL cpulseo              : STD_LOGIC;
   SIGNAL hfclkn_i             : STD_LOGIC;
   SIGNAL hfclkp_i             : STD_LOGIC;
   SIGNAL lfclkn_i             : STD_LOGIC;
   SIGNAL lfclkp_i             : STD_LOGIC;
   -- X-HDL generated signals

   SIGNAL xhdl14 : STD_LOGIC;
   SIGNAL xhdl15 : STD_LOGIC;
   SIGNAL xhdl16 : STD_LOGIC;
   SIGNAL xhdl17 : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL clk0_out_xhdl0       : STD_LOGIC;
   SIGNAL clk90_out_xhdl3      : STD_LOGIC;
   SIGNAL clk180_out_xhdl1     : STD_LOGIC;
   SIGNAL clk270_out_xhdl2     : STD_LOGIC;
   SIGNAL cpulse_xhdl4         : STD_LOGIC;
   SIGNAL gen2ngen1_xhdl5      : STD_LOGIC;
   SIGNAL hclk_xhdl6           : STD_LOGIC;
   SIGNAL hfclk_n_xhdl7        : STD_LOGIC;
   SIGNAL hfclk_p_xhdl8        : STD_LOGIC;
   SIGNAL lfclk_n_xhdl9        : STD_LOGIC;
   SIGNAL lfclk_p_xhdl10       : STD_LOGIC;
   SIGNAL pcie_sw_cdr_xhdl11   : STD_LOGIC;
   SIGNAL pclk_xhdl12          : STD_LOGIC;
   SIGNAL rst_n1_xhdl13        : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   clk0_out <= clk0_out_xhdl0;
   clk90_out <= clk90_out_xhdl3;
   clk180_out <= clk180_out_xhdl1;
   clk270_out <= clk270_out_xhdl2;
   cpulse <= cpulse_xhdl4;
   gen2ngen1 <= gen2ngen1_xhdl5;
   hclk <= hclk_xhdl6;
   hfclk_n <= hfclk_n_xhdl7;
   hfclk_p <= hfclk_p_xhdl8;
   lfclk_n <= lfclk_n_xhdl9;
   lfclk_p <= lfclk_p_xhdl10;
   pcie_sw_cdr <= pcie_sw_cdr_xhdl11;
   pclk <= pclk_xhdl12;
   rst_n1 <= rst_n1_xhdl13;
   
   pdb_buf <= pdb AND NOT((reduction_or(cgb_x_en)));
   rst_n1_xhdl13 <= rst_n AND pdb_buf;
   
   -- * * b_mux4_2t1 - xcmux instance * *
   clk_in <= "0000" WHEN ((NOT(pdb)) = '1') ELSE
             (clk270_1 & clk180_1 & clk90_1 & clk0_1) WHEN (cmu_sel = '1') ELSE
             (clk270_0 & clk180_0 & clk90_0 & clk0_0);
   
   -- * * stratixiv_hssi_pma_c_clkgenbuf_div - xdiv instance * *
   rst_n1_clkgenbuf_div <= rst_n1_xhdl13 AND (m_sel(1) OR m_sel(0));
   rst_n2_clkgenbuf_div <= rst_n1_xhdl13 AND m_sel(1);
   --   assign {clk270_out,clk180_out,clk90_out,clk0_out} = clk_out;
   clk270_out_xhdl2 <= clk_out(3);
   clk180_out_xhdl1 <= clk_out(2);
   clk90_out_xhdl3 <= clk_out(1);
   clk0_out_xhdl0 <= clk_out(0);
   
   
   xhdl14 <= NOT(clk_in(2));
   xhdl15 <= NOT(clk_in(0));
   xdiv2_2 : stratixiv_hssi_pma_c_divby2q
      PORT MAP (
         clk       => xhdl14,
         clk0      => clk_div2(0),
         clk90     => clk_div2(1),
         clk180    => clk_div2(2),
         clk270    => clk_div2(3),
         vcce_la   => '1',
         vssexqyx  => '0',
         clkb      => xhdl15,
         rst_n     => rst_n1_clkgenbuf_div
      );
   
   xhdl16 <= NOT(clk_div2(2));
   xhdl17 <= NOT(clk_div2(0));
   xdiv2_4 : stratixiv_hssi_pma_c_divby2q
      PORT MAP (
         clk       => xhdl16,
         clk0      => clk_div4(0),
         clk90     => clk_div4(1),
         clk180    => clk_div4(2),
         clk270    => clk_div4(3),
         vcce_la   => '1',
         vssexqyx  => '0',
         clkb      => xhdl17,
         rst_n     => rst_n2_clkgenbuf_div
      );
   
   PROCESS (m_sel, clk_in, clk_div2, clk_div4)
   BEGIN
      CASE m_sel IS
         WHEN "00" =>
            clk_out <= clk_in;
         WHEN "01" =>
            clk_out <= clk_div2;
         --       2'b11   : clk_out = 4'b0000;
         WHEN "10" =>
            clk_out <= clk_div4;
         WHEN "11" =>
            clk_out <= "0000";
         WHEN OTHERS =>
            clk_out <= "XXXX";
      END CASE;
   END PROCESS;
   
   -- * * stratixiv_hssi_pma_c_clkgendrv - xdrv instance - div by 4 or 5 * *
   xdrv : stratixiv_hssi_pma_c_clkgendrv
      PORT MAP (
         clk0       => clk0_out_xhdl0,
         clk90      => clk90_out_xhdl3,
         clk180     => clk180_out_xhdl1,
         clk270     => clk270_out_xhdl2,
         cpulse     => cpulse_i,
         cpulseb    => cpulseb_i,
         cpulseo    => cpulseo,
         div5       => div5,
         hfclk_n    => hfclkn_i,
         hfclk_p    => hfclkp_i,
         lfclk_n    => lfclkn_i,
         lfclk_p    => lfclkp_i,
         rst_n      => rst_n1_xhdl13,
         vccelxqyx  => vccelxqyx,
         vssexqyx   => vssexqyx
      );
   
   -- * * c_pcie_sw - xpcie_sw instance * *
   xpcie_sw : stratixiv_hssi_pma_c_pcie_sw
      GENERIC MAP (
         param_delay  => PARAM_DELAY
      )
      PORT MAP (
         cpulse       => cpulse_i,
         cpulse_out   => cpulse_xhdl4,
         cpulseb      => cpulseb_i,
         cpulsei      => cpulse_i,
         dynamic_sw   => dynamic_sw,
         gen2ngen1    => gen2ngen1_xhdl5,
         hclk         => hclk_xhdl6,
         hfclkn       => hfclkn_i,
         hfclkn_out   => hfclk_n_xhdl7,
         hfclkp       => hfclkp_i,
         hfclkp_out   => hfclk_p_xhdl8,
         lfclkn       => lfclkn_i,
         lfclkn_out   => lfclk_n_xhdl9,
         lfclkp       => lfclkp_i,
         lfclkp_out   => lfclk_p_xhdl10,
         pcie_sw      => pcie_sw,
         pcie_sw_cdr  => pcie_sw_cdr_xhdl11,
         pclk         => pclk_xhdl12,
         pdb          => pdb_buf,
         rst_n        => rst_n1_xhdl13,
         vccelxqyx    => vccelxqyx,
         vssexqyx     => vssexqyx
      );
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_clkgenbuf_cmu IS
   PORT (
      cgb_vccelxqyx  : OUT STD_LOGIC;
      cgb_vssexqyx   : OUT STD_LOGIC;
      cgb_x_en       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      clk0_0         : IN STD_LOGIC;
      clk0_1         : IN STD_LOGIC;
      clk90_0        : IN STD_LOGIC;
      clk90_1        : IN STD_LOGIC;
      clk180_0       : IN STD_LOGIC;
      clk180_1       : IN STD_LOGIC;
      clk270_0       : IN STD_LOGIC;
      clk270_1       : IN STD_LOGIC;
      pdb            : IN STD_LOGIC;
      cmu_sel        : IN STD_LOGIC;
      cpulse_ht      : OUT STD_LOGIC;
      cpulse_x1      : OUT STD_LOGIC;
      div5           : IN STD_LOGIC;
      dynamic_sw     : IN STD_LOGIC;
      hfclkn_ht      : OUT STD_LOGIC;
      hfclkn_x1      : OUT STD_LOGIC;
      hfclkp_ht      : OUT STD_LOGIC;
      hfclkp_x1      : OUT STD_LOGIC;
      hclk           : OUT STD_LOGIC;
      ht_sel         : IN STD_LOGIC;
      lfclkn_ht      : OUT STD_LOGIC;
      lfclkn_x1      : OUT STD_LOGIC;
      lfclkp_ht      : OUT STD_LOGIC;
      lfclkp_x1      : OUT STD_LOGIC;
      m_sel          : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pcie_sw        : IN STD_LOGIC;
      pcie_sw_cdr    : OUT STD_LOGIC;
      pclk           : OUT STD_LOGIC;
      gen2ngen1      : OUT STD_LOGIC;
      rst_n          : IN STD_LOGIC;
      vccelxqyx      : IN STD_LOGIC;
      vssexqyx       : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_clkgenbuf_cmu;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_clkgenbuf_cmu IS
   COMPONENT stratixiv_hssi_pma_c_divby2q
      PORT (
         clk            : IN STD_LOGIC;
         clk0           : OUT STD_LOGIC;
         clk90          : OUT STD_LOGIC;
         clk180         : OUT STD_LOGIC;
         clk270         : OUT STD_LOGIC;
         clkb           : IN STD_LOGIC;
         rst_n          : IN STD_LOGIC;
         vcce_la        : IN STD_LOGIC;
         vssexqyx       : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_c_clkgenbuf
      GENERIC (
         PARAM_DELAY    : INTEGER := 0
      );
      PORT (
         cgb_x_en       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         clk0_0         : IN STD_LOGIC;
         clk0_1         : IN STD_LOGIC;
         clk0_out       : OUT STD_LOGIC;
         clk90_0        : IN STD_LOGIC;
         clk90_1        : IN STD_LOGIC;
         clk90_out      : OUT STD_LOGIC;
         clk180_0       : IN STD_LOGIC;
         clk180_1       : IN STD_LOGIC;
         clk180_out     : OUT STD_LOGIC;
         clk270_0       : IN STD_LOGIC;
         clk270_1       : IN STD_LOGIC;
         clk270_out     : OUT STD_LOGIC;
         cmu_sel        : IN STD_LOGIC;
         cpulse         : OUT STD_LOGIC;
         div5           : IN STD_LOGIC;
         dynamic_sw     : IN STD_LOGIC;
         gen2ngen1      : OUT STD_LOGIC;
         hclk           : OUT STD_LOGIC;
         hfclk_n        : OUT STD_LOGIC;
         hfclk_p        : OUT STD_LOGIC;
         lfclk_n        : OUT STD_LOGIC;
         lfclk_p        : OUT STD_LOGIC;
         m_sel          : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         pcie_sw        : IN STD_LOGIC;
         pcie_sw_cdr    : OUT STD_LOGIC;
         pclk           : OUT STD_LOGIC;
         pdb            : IN STD_LOGIC;
         rst_n          : IN STD_LOGIC;
         rst_n1         : OUT STD_LOGIC;
         vccelxqyx      : IN STD_LOGIC;
         vssexqyx       : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_c_clkgendrv
      PORT (
         clk0           : IN STD_LOGIC;
         clk90          : IN STD_LOGIC;
         clk180         : IN STD_LOGIC;
         clk270         : IN STD_LOGIC;
         cpulse         : OUT STD_LOGIC;
         cpulseb        : OUT STD_LOGIC;
         cpulseo        : OUT STD_LOGIC;
         div5           : IN STD_LOGIC;
         hfclk_n        : OUT STD_LOGIC;
         hfclk_p        : OUT STD_LOGIC;
         lfclk_n        : OUT STD_LOGIC;
         lfclk_p        : OUT STD_LOGIC;
         rst_n          : IN STD_LOGIC;
         vccelxqyx      : IN STD_LOGIC;
         vssexqyx       : IN STD_LOGIC
      );
   END COMPONENT;
   
   SIGNAL rst_n1             : STD_LOGIC;
   SIGNAL rst_n1b            : STD_LOGIC;
   SIGNAL ht_en              : STD_LOGIC;
   SIGNAL clk0_out           : STD_LOGIC;
   SIGNAL clk90_out          : STD_LOGIC;
   SIGNAL clk180_out         : STD_LOGIC;
   SIGNAL clk270_out         : STD_LOGIC;
   SIGNAL cpulseo            : STD_LOGIC;
   SIGNAL cpulseb_ht         : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL cpulse_ht_xhdl0    : STD_LOGIC;
   SIGNAL cpulse_x1_xhdl1    : STD_LOGIC;
   SIGNAL hfclkn_ht_xhdl4    : STD_LOGIC;
   SIGNAL hfclkn_x1_xhdl5    : STD_LOGIC;
   SIGNAL hfclkp_ht_xhdl6    : STD_LOGIC;
   SIGNAL hfclkp_x1_xhdl7    : STD_LOGIC;
   SIGNAL hclk_xhdl3         : STD_LOGIC;
   SIGNAL lfclkn_ht_xhdl8    : STD_LOGIC;
   SIGNAL lfclkn_x1_xhdl9    : STD_LOGIC;
   SIGNAL lfclkp_ht_xhdl10   : STD_LOGIC;
   SIGNAL lfclkp_x1_xhdl11   : STD_LOGIC;
   SIGNAL pcie_sw_cdr_xhdl12 : STD_LOGIC;
   SIGNAL gen2ngen1_xhdl2    : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   cpulse_ht <= cpulse_ht_xhdl0;
   cpulse_x1 <= cpulse_x1_xhdl1;
   hfclkn_ht <= hfclkn_ht_xhdl4;
   hfclkn_x1 <= hfclkn_x1_xhdl5;
   hfclkp_ht <= hfclkp_ht_xhdl6;
   hfclkp_x1 <= hfclkp_x1_xhdl7;
   hclk <= hclk_xhdl3;
   lfclkn_ht <= lfclkn_ht_xhdl8;
   lfclkn_x1 <= lfclkn_x1_xhdl9;
   lfclkp_ht <= lfclkp_ht_xhdl10;
   lfclkp_x1 <= lfclkp_x1_xhdl11;
   pcie_sw_cdr <= pcie_sw_cdr_xhdl12;
   gen2ngen1 <= gen2ngen1_xhdl2;
   
   rst_n1b <= NOT((rst_n1 AND ht_sel));
   ht_en <= NOT(rst_n1b);
   
   xclkgen : stratixiv_hssi_pma_c_clkgenbuf
      PORT MAP (
         cgb_x_en     => cgb_x_en,
         clk0_0       => clk0_0,
         clk0_1       => clk0_1,
         clk0_out     => clk0_out,
         clk90_0      => clk90_0,
         clk90_1      => clk90_1,
         clk90_out    => clk90_out,
         clk180_0     => clk180_0,
         clk180_1     => clk180_1,
         clk180_out   => clk180_out,
         clk270_0     => clk270_0,
         clk270_1     => clk270_1,
         clk270_out   => clk270_out,
         cmu_sel      => cmu_sel,
         cpulse       => cpulse_x1_xhdl1,
         div5         => div5,
         dynamic_sw   => dynamic_sw,
         gen2ngen1    => gen2ngen1_xhdl2,
         hclk         => hclk_xhdl3,
         hfclk_n      => hfclkn_x1_xhdl5,
         hfclk_p      => hfclkp_x1_xhdl7,
         lfclk_n      => lfclkn_x1_xhdl9,
         lfclk_p      => lfclkp_x1_xhdl11,
         m_sel        => m_sel,
         pcie_sw      => pcie_sw,
         pcie_sw_cdr  => pcie_sw_cdr_xhdl12,
         pclk         => pclk,
         pdb          => pdb,
         rst_n        => rst_n,
         rst_n1       => rst_n1,
         vccelxqyx    => vccelxqyx,
         vssexqyx     => vssexqyx
      );
   
   xdrv : stratixiv_hssi_pma_c_clkgendrv
      PORT MAP (
         clk0       => clk270_out,
         clk90      => clk0_out,
         clk180     => clk90_out,
         clk270     => clk180_out,
         cpulse     => cpulse_ht_xhdl0,
         cpulseb    => cpulseb_ht,
         cpulseo    => cpulseo,
         div5       => div5,
         hfclk_n    => hfclkn_ht_xhdl4,
         hfclk_p    => hfclkp_ht_xhdl6,
         lfclk_n    => lfclkn_ht_xhdl8,
         lfclk_p    => lfclkp_ht_xhdl10,
         rst_n      => ht_en,
         vccelxqyx  => vccelxqyx,
         vssexqyx   => vssexqyx
      );
   
   cgb_vccelxqyx <= vccelxqyx WHEN (vssexqyx = '0') ELSE
                    'Z';
   cgb_vssexqyx <= vssexqyx WHEN (vccelxqyx = '1') ELSE
                   'Z';
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_d2a_mbpass IS
   PORT (
      
      bypass       : IN STD_LOGIC_VECTOR(7 DOWNTO 5);
      d2a_in       : IN STD_LOGIC;
      d2a_out      : OUT STD_LOGIC;
      radce_adapt  : IN STD_LOGIC;
      radce_pdb    : IN STD_LOGIC;
      vccehx       : IN STD_LOGIC;
      vssex        : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_d2a_mbpass;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_d2a_mbpass IS
   
   SIGNAL level   : STD_LOGIC_VECTOR(7 DOWNTO 1);
   SIGNAL nbypass : STD_LOGIC_VECTOR(7 DOWNTO 5);
   SIGNAL sel     : STD_LOGIC_VECTOR(7 DOWNTO 0);
BEGIN
   
   d2a_out <= d2a_in WHEN ((radce_adapt OR (NOT(radce_adapt) AND NOT(radce_pdb))) = '1') ELSE
              'Z';
   d2a_out <= vccehx WHEN (((NOT(radce_adapt) AND radce_pdb) AND (bypass(7) OR bypass(6) OR bypass(5))) = '1') ELSE
              'Z';
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_tx_clkmux_cmu IS
   GENERIC (
      DELAY        : INTEGER := 1
   );
   PORT (
      cpulse       : OUT STD_LOGIC;
      cpulse_ht    : IN STD_LOGIC;
      cpulse_x1    : IN STD_LOGIC;
      cpulse_x4    : IN STD_LOGIC;
      cpulse_xn_b  : IN STD_LOGIC;
      cpulse_xn_t  : IN STD_LOGIC;
      delay_sel    : IN STD_LOGIC;
      hfclk_n      : OUT STD_LOGIC;
      hfclk_p      : OUT STD_LOGIC;
      hfclkn_ht    : IN STD_LOGIC;
      hfclkn_x1    : IN STD_LOGIC;
      hfclkn_x4    : IN STD_LOGIC;
      hfclkn_xn_b  : IN STD_LOGIC;
      hfclkn_xn_t  : IN STD_LOGIC;
      hfclkp_ht    : IN STD_LOGIC;
      hfclkp_x1    : IN STD_LOGIC;
      hfclkp_x4    : IN STD_LOGIC;
      hfclkp_xn_b  : IN STD_LOGIC;
      hfclkp_xn_t  : IN STD_LOGIC;
      ht_sel       : IN STD_LOGIC;
      lfclk_n      : OUT STD_LOGIC;
      lfclk_p      : OUT STD_LOGIC;
      lfclkn_ht    : IN STD_LOGIC;
      lfclkn_x1    : IN STD_LOGIC;
      lfclkn_x4    : IN STD_LOGIC;
      lfclkn_xn_b  : IN STD_LOGIC;
      lfclkn_xn_t  : IN STD_LOGIC;
      lfclkp_ht    : IN STD_LOGIC;
      lfclkp_x1    : IN STD_LOGIC;
      lfclkp_x4    : IN STD_LOGIC;
      lfclkp_xn_b  : IN STD_LOGIC;
      lfclkp_xn_t  : IN STD_LOGIC;
      pdb          : IN STD_LOGIC;
      sel          : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      vccelxqyx    : IN STD_LOGIC;
      vssexqyx     : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_tx_clkmux_cmu;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_tx_clkmux_cmu IS
   
   SIGNAL n10_sel_0   : STD_LOGIC;
   SIGNAL n11_sel_1   : STD_LOGIC;
   SIGNAL nx1_sel_xn  : STD_LOGIC;
   SIGNAL n01_sel_x4  : STD_LOGIC;
   SIGNAL n00_sel_x1  : STD_LOGIC;
   SIGNAL hfclkp_x1_0 : STD_LOGIC;
   SIGNAL hfclkn_x1_0 : STD_LOGIC;
   SIGNAL cpulse_x1_0 : STD_LOGIC;
   SIGNAL lfclkp_x1_0 : STD_LOGIC;
   SIGNAL lfclkn_x1_0 : STD_LOGIC;
   SIGNAL sel_x4_d    : STD_LOGIC;
   SIGNAL hfclkp_x4_0 : STD_LOGIC;
   SIGNAL hfclkn_x4_0 : STD_LOGIC;
   SIGNAL cpulse_x4_0 : STD_LOGIC;
   SIGNAL lfclkp_x4_0 : STD_LOGIC;
   SIGNAL lfclkn_x4_0 : STD_LOGIC;
   SIGNAL hfclkp_xn   : STD_LOGIC;
   SIGNAL hfclkn_xn   : STD_LOGIC;
   SIGNAL cpulse_xn   : STD_LOGIC;
   SIGNAL lfclkp_xn   : STD_LOGIC;
   SIGNAL lfclkn_xn   : STD_LOGIC;
   SIGNAL hfclkp_ht_d : STD_LOGIC;
   SIGNAL hfclkn_ht_d : STD_LOGIC;
   SIGNAL cpulse_ht_d : STD_LOGIC;
   SIGNAL lfclkp_ht_d : STD_LOGIC;
   SIGNAL lfclkn_ht_d : STD_LOGIC;
   SIGNAL hfclkp_x4_d : STD_LOGIC;
   SIGNAL hfclkn_x4_d : STD_LOGIC;
   SIGNAL cpulse_x4_d : STD_LOGIC;
   SIGNAL lfclkp_x4_d : STD_LOGIC;
   SIGNAL lfclkn_x4_d : STD_LOGIC;
   -- X-HDL generated signals

   SIGNAL xhdl0 : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL xhdl1 : STD_LOGIC_VECTOR(2 DOWNTO 0);
BEGIN
   
   -- * * c_tx_clkmux_2t1 x0 * *
   
   -- xhtdelay
   PROCESS (hfclkp_ht, hfclkn_ht, cpulse_ht, lfclkp_ht, lfclkn_ht)
   BEGIN
      hfclkp_ht_d <=  TRANSPORT hfclkp_ht AFTER (DELAY)*1 ps;
      hfclkn_ht_d <=  TRANSPORT hfclkn_ht AFTER (DELAY)*1 ps;
      cpulse_ht_d <=  TRANSPORT cpulse_ht AFTER (DELAY)*1 ps;
      lfclkp_ht_d <=  TRANSPORT lfclkp_ht AFTER (DELAY)*1 ps;
      lfclkn_ht_d <=  TRANSPORT lfclkn_ht AFTER (DELAY)*1 ps;
   END PROCESS;
   
   -- assign {hfclkp_x1_0,hfclkn_x1_0,cpulse_x1_0,lfclkp_x1_0,lfclkn_x1_0} = ( pdb == 1'b0  ) ? 1'b0 :( (ht_sel == 1'b1) & (sel == 2'b00) ) ? {hfclkp_ht_d,hfclkn_ht_d,cpulse_ht_d,lfclkp_ht_d,lfclkn_ht_d} : {hfclkp_x1,hfclkn_x1,cpulse_x1,lfclkp_x1,lfclkn_x1};
   hfclkp_x1_0 <= '0' WHEN (pdb = '0') ELSE
                  hfclkp_ht_d WHEN ((ht_sel = '1') AND (sel = "00")) ELSE
                  hfclkp_x1;
   hfclkn_x1_0 <= '0' WHEN (pdb = '0') ELSE
                  hfclkn_ht_d WHEN ((ht_sel = '1') AND (sel = "00")) ELSE
                  hfclkn_x1;
   cpulse_x1_0 <= '0' WHEN (pdb = '0') ELSE
                  cpulse_ht_d WHEN ((ht_sel = '1') AND (sel = "00")) ELSE
                  cpulse_x1;
   lfclkp_x1_0 <= '0' WHEN (pdb = '0') ELSE
                  lfclkp_ht_d WHEN ((ht_sel = '1') AND (sel = "00")) ELSE
                  lfclkp_x1;
   lfclkn_x1_0 <= '0' WHEN (pdb = '0') ELSE
                  lfclkn_ht_d WHEN ((ht_sel = '1') AND (sel = "00")) ELSE
                  lfclkn_x1;
   
   -- * * c_tx_clkmux_2t1 x2 * *
   
   -- xdelay
   PROCESS (hfclkp_x4, hfclkn_x4, cpulse_x4, lfclkp_x4, lfclkn_x4)
   BEGIN
      hfclkp_x4_d <=  TRANSPORT hfclkp_x4 AFTER (DELAY)*1 ps;
      hfclkn_x4_d <=  TRANSPORT hfclkn_x4 AFTER (DELAY)*1 ps;
      cpulse_x4_d <=  TRANSPORT cpulse_x4 AFTER (DELAY)*1 ps;
      lfclkp_x4_d <=  TRANSPORT lfclkp_x4 AFTER (DELAY)*1 ps;
      lfclkn_x4_d <=  TRANSPORT lfclkn_x4 AFTER (DELAY)*1 ps;
   END PROCESS;
   
   sel_x4_d <= delay_sel AND NOT(sel(1)) AND sel(0);
   
   PROCESS (sel_x4_d, hfclkp_x4_d, hfclkn_x4_d, cpulse_x4_d, lfclkp_x4_d, lfclkn_x4_d, hfclkp_x4, hfclkn_x4, cpulse_x4, lfclkp_x4, lfclkn_x4, pdb)
   BEGIN
      IF (pdb = '1') THEN
         CASE sel_x4_d IS
            WHEN '0' =>
               hfclkp_x4_0 <= hfclkp_x4;
               hfclkn_x4_0 <= hfclkn_x4;
               cpulse_x4_0 <= cpulse_x4;
               lfclkp_x4_0 <= lfclkp_x4;
               lfclkn_x4_0 <= lfclkn_x4;
            WHEN '1' =>
               hfclkp_x4_0 <= hfclkp_x4_d;
               hfclkn_x4_0 <= hfclkn_x4_d;
               cpulse_x4_0 <= cpulse_x4_d;
               lfclkp_x4_0 <= lfclkp_x4_d;
               lfclkn_x4_0 <= lfclkn_x4_d;
            WHEN OTHERS =>
               hfclkp_x4_0 <= 'X';
               hfclkn_x4_0 <= 'X';
               cpulse_x4_0 <= 'X';
               lfclkp_x4_0 <= 'X';
               lfclkn_x4_0 <= 'X';
         END CASE;
      ELSE
         --     {hfclkp_x4_0,hfclkn_x4_0,cpulse_x4_0,lfclkp_x4_0,lfclkn_x4_0} = 5'b01001; : revert to 5'b00000 for now : all 6g regtests failing : need to find vhdl_out why
         hfclkp_x4_0 <= '0';
         hfclkn_x4_0 <= '0';
         cpulse_x4_0 <= '0';
         lfclkp_x4_0 <= '0';
         lfclkn_x4_0 <= '0';
      END IF;
   END PROCESS;
   
   -- * * c_tx_clkmux_2t1 x0 * *
   n10_sel_0 <= sel(1) AND NOT(sel(0)) AND pdb;
   n11_sel_1 <= sel(1) AND sel(0) AND pdb;
   
   xhdl0 <= n11_sel_1 & n10_sel_0;
   PROCESS (n11_sel_1, n10_sel_0, hfclkp_xn_t, hfclkn_xn_t, cpulse_xn_t, lfclkp_xn_t, lfclkn_xn_t, hfclkp_xn_b, hfclkn_xn_b, cpulse_xn_b, lfclkp_xn_b, lfclkn_xn_b, pdb)
   BEGIN
      IF (pdb = '1') THEN
         CASE xhdl0 IS
            WHEN "00" =>
               hfclkp_xn <= 'Z';
               hfclkn_xn <= 'Z';
               cpulse_xn <= 'Z';
               lfclkp_xn <= 'Z';
               lfclkn_xn <= 'Z';
            WHEN "01" =>
               hfclkp_xn <= hfclkp_xn_t;
               hfclkn_xn <= hfclkn_xn_t;
               cpulse_xn <= cpulse_xn_t;
               lfclkp_xn <= lfclkp_xn_t;
               lfclkn_xn <= lfclkn_xn_t;
            WHEN "10" =>
               hfclkp_xn <= hfclkp_xn_b;
               hfclkn_xn <= hfclkn_xn_b;
               cpulse_xn <= cpulse_xn_b;
               lfclkp_xn <= lfclkp_xn_b;
               lfclkn_xn <= lfclkn_xn_b;
            WHEN OTHERS =>
               hfclkp_xn <= 'X';
               hfclkn_xn <= 'X';
               cpulse_xn <= 'X';
               lfclkp_xn <= 'X';
               lfclkn_xn <= 'X';
         END CASE;
      ELSE
         --     {hfclkp_xn,hfclkn_xn,cpulse_xn,lfclkp_xn,lfclkn_xn} = 5'b01001; : revert to 5'b00000 for now : all 6g regtests failing : need to find vhdl_out why
         hfclkp_xn <= '0';
         hfclkn_xn <= '0';
         cpulse_xn <= '0';
         lfclkp_xn <= '0';
         lfclkn_xn <= '0';
      END IF;
   END PROCESS;
   
   -- * * c_tx_clkmux x1 * *
   nx1_sel_xn <= sel(1);
   n01_sel_x4 <= NOT(sel(1)) AND sel(0) AND pdb;
   n00_sel_x1 <= NOT(sel(1)) AND NOT(sel(0)) AND pdb;
   
   xhdl1 <= nx1_sel_xn & n01_sel_x4 & n00_sel_x1;
   PROCESS (nx1_sel_xn, n01_sel_x4, n00_sel_x1, hfclkp_x1_0, hfclkn_x1_0, cpulse_x1_0, lfclkp_x1_0, lfclkn_x1_0, hfclkp_x4_0, hfclkn_x4_0, cpulse_x4_0, lfclkp_x4_0, lfclkn_x4_0, hfclkp_xn, hfclkn_xn, cpulse_xn, lfclkp_xn, lfclkn_xn, pdb)
   BEGIN
      IF (pdb = '1') THEN
         CASE xhdl1 IS
            WHEN "000" =>
               hfclk_p <= 'Z';
               hfclk_n <= 'Z';
               cpulse <= 'Z';
               lfclk_p <= 'Z';
               lfclk_n <= 'Z';
            WHEN "001" =>
               hfclk_p <= hfclkp_x1_0;
               hfclk_n <= hfclkn_x1_0;
               cpulse <= cpulse_x1_0;
               lfclk_p <= lfclkp_x1_0;
               lfclk_n <= lfclkn_x1_0;
            WHEN "010" =>
               hfclk_p <= hfclkp_x4_0;
               hfclk_n <= hfclkn_x4_0;
               cpulse <= cpulse_x4_0;
               lfclk_p <= lfclkp_x4_0;
               lfclk_n <= lfclkn_x4_0;
            WHEN "100" =>
               hfclk_p <= hfclkp_xn;
               hfclk_n <= hfclkn_xn;
               cpulse <= cpulse_xn;
               lfclk_p <= lfclkp_xn;
               lfclk_n <= lfclkn_xn;
            WHEN OTHERS =>
               hfclk_p <= 'X';
               hfclk_n <= 'X';
               cpulse <= 'X';
               lfclk_p <= 'X';
               lfclk_n <= 'X';
         END CASE;
      ELSE
         --     {hfclk_p,hfclk_n,cpulse,lfclk_p,lfclk_n} = 5'b01001; : revert to 5'b00000 for now : all 6g regtests failing : need to find vhdl_out why
         hfclk_p <= '0';
         hfclk_n <= '0';
         cpulse <= '0';
         lfclk_p <= '0';
         lfclk_n <= '0';
      END IF;
   END PROCESS;
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
   
LIBRARY ieee;
   USE ieee.std_logic_1164.all;
   USE ieee.std_logic_unsigned.all;

ENTITY stratixiv_hssi_pma_c_deser IS
   GENERIC (
      PARAM_DELAY         : INTEGER := 0;
      RST_SD_PULSE_WIDTH  : INTEGER := 1
   );
   PORT (
      clk90b              : IN STD_LOGIC;
      clk_divrx           : OUT STD_LOGIC;
      deser_div2          : IN STD_LOGIC;
      deser_div5          : IN STD_LOGIC;
      deser_pdb           : IN STD_LOGIC;
      deven               : IN STD_LOGIC;
      devenb              : IN STD_LOGIC;
      dodd                : IN STD_LOGIC;
      doddb               : IN STD_LOGIC;
      dout                : OUT STD_LOGIC_VECTOR(19 DOWNTO 0);
      fsd                 : OUT STD_LOGIC;
      pcie_sw             : IN STD_LOGIC;
      pcieo               : OUT STD_LOGIC;
      rdynamic_sw         : IN STD_LOGIC;
      rfast_sd            : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      rst_n               : IN STD_LOGIC;
      rtest_fastsd        : IN STD_LOGIC;
      rxinn               : IN STD_LOGIC;
      rxinp               : IN STD_LOGIC;
      vcce_la             : IN STD_LOGIC;
      vssexqyx            : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_deser;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_deser IS
   COMPONENT stratixiv_hssi_pma_c_divby2q
      PORT (
         clk                 : IN STD_LOGIC;
         clk0                : OUT STD_LOGIC;
         clk90               : OUT STD_LOGIC;
         clk180              : OUT STD_LOGIC;
         clk270              : OUT STD_LOGIC;
         clkb                : IN STD_LOGIC;
         rst_n               : IN STD_LOGIC;
         vcce_la             : IN STD_LOGIC;
         vssexqyx            : IN STD_LOGIC
      );
   END COMPONENT;
   
   SIGNAL dp                           : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL dsync                        : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL drp                          : STD_LOGIC_VECTOR(3 DOWNTO 0) := "0000" ;
   SIGNAL dfp                          : STD_LOGIC_VECTOR(3 DOWNTO 0) := "0000" ;
   SIGNAL outp                         : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL outn                         : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL ph                           : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL d10a                         : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL douta                        : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL doutb                        : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL deven_ok                     : STD_LOGIC;
   SIGNAL devenb_ok                    : STD_LOGIC;
   SIGNAL data_even                    : STD_LOGIC;
   SIGNAL dodd_ok                      : STD_LOGIC;
   SIGNAL doddb_ok                     : STD_LOGIC;
   SIGNAL data_odd                     : STD_LOGIC;
   SIGNAL ck_div                       : STD_LOGIC;
   SIGNAL clk90_div5                   : STD_LOGIC := '0' ;
   SIGNAL clk90_div4                   : STD_LOGIC := '0' ;
   SIGNAL clk270_div5                  : STD_LOGIC := '0' ;
   SIGNAL clk270_div4                  : STD_LOGIC := '0' ;
   SIGNAL clk90_div_init_done          : STD_LOGIC := '0' ;
   SIGNAL clk270_div_init_done         : STD_LOGIC := '0' ;
   SIGNAL rst_sd                       : STD_LOGIC := '1' ;
   SIGNAL even_all0q                   : STD_LOGIC := '0' ;
   SIGNAL even_all1q                   : STD_LOGIC := '0' ;
   SIGNAL odd_all0q                    : STD_LOGIC := '0' ;
   SIGNAL odd_all1q                    : STD_LOGIC := '0' ;
   SIGNAL shiftout                     : STD_LOGIC := '0' ;
   SIGNAL shiftout_1                   : STD_LOGIC := '0' ;
   SIGNAL shiftoutq                    : STD_LOGIC := '0' ;
   SIGNAL n1                           : STD_LOGIC := '0' ;
   SIGNAL n0                           : STD_LOGIC := '0' ;
   SIGNAL pcie2                        : STD_LOGIC := '0' ;
   SIGNAL n4                           : STD_LOGIC := '0' ;
   SIGNAL n3                           : STD_LOGIC := '0' ;
   SIGNAL n2                           : STD_LOGIC := '0' ;
   SIGNAL n6                           : STD_LOGIC := '0' ;
--   SIGNAL got_first_clk270_rising_edge : STD_LOGIC := '0' ;
   
   SIGNAL clk90                        : STD_LOGIC;
   SIGNAL clk270                       : STD_LOGIC;
   SIGNAL b1                           : STD_LOGIC;
   SIGNAL cout                         : STD_LOGIC;
   SIGNAL muxout_ff_chain              : STD_LOGIC;
   SIGNAL rst_ni                       : STD_LOGIC;
   SIGNAL rst_n_div2                   : STD_LOGIC;
   SIGNAL ck_div2                      : STD_LOGIC;
   SIGNAL ck_2div                      : STD_LOGIC;
   SIGNAL even_all0                    : STD_LOGIC;
   SIGNAL even_all1                    : STD_LOGIC;
   SIGNAL odd_all0                     : STD_LOGIC;
   SIGNAL odd_all1                     : STD_LOGIC;
   SIGNAL ckb_2div                     : STD_LOGIC;
   SIGNAL rxp_clk                      : STD_LOGIC;
   SIGNAL rxn_clk                      : STD_LOGIC;
   SIGNAL noswitch                     : STD_LOGIC;
   SIGNAL nc0                          : STD_LOGIC;
   SIGNAL nc1                          : STD_LOGIC;
   SIGNAL nc2                          : STD_LOGIC;
   SIGNAL ck_div_en                    : STD_LOGIC;
   SIGNAL pcie_clk_div                 : STD_LOGIC;
   SIGNAL activity                     : STD_LOGIC;
   SIGNAL exor                         : STD_LOGIC;
   
   SIGNAL clk90_counter                : INTEGER := 0 ;
   SIGNAL clk270_counter               : INTEGER := 0 ;
   -- X-HDL generated signals

   SIGNAL xhdl1 : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL clk_divrx_xhdl0              : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   clk_divrx <= clk_divrx_xhdl0;
   
   rst_ni <= deser_pdb AND rst_n;
   rst_n_div2 <= rst_ni AND deser_div2;
   dout <= (doutb & douta);
   clk_divrx_xhdl0 <= ck_div_en AND (NOT(ck_2div));
   clk90 <= NOT(clk90b);
   clk270 <= clk90b;
   
   -- * * c_deser_ph_clk * * 
   -- b1   synch w/ clk90  ; 60-40 duty-cycle vhdl_in div5 mode ; 50-50 vhdl_in div4 mode
   -- cout synch w/ clk270 ; 50-50 duty-cycle vhdl_in div5 and div4 modes
   b1 <= clk90_div5 WHEN (deser_div5 = '1') ELSE
         clk90_div4;
   cout <= clk270_div5 WHEN (deser_div5 = '1') ELSE
           clk270_div4;
   PROCESS (clk90, rst_ni)
   BEGIN
      IF (rst_ni = '0') THEN
         clk90_counter <= 0;
         clk90_div_init_done <= '0';
         clk90_div5 <= '0';
         clk90_div4 <= '0';
      ELSIF (clk90'EVENT AND clk90 = '1') THEN
         -- generation of clk90_div5 
         IF (clk90_div_init_done = '0') THEN
            clk90_div5 <= '1';
            clk90_div4 <= '1';
            clk90_div_init_done <= '1';
         ELSE
            IF (clk90_counter MOD 5 = 0) THEN
               clk90_div5 <= '1';
            ELSIF (clk90_counter MOD 5 = 3) THEN
               -- generation of clk90_div4 
               clk90_div5 <= '0';
            END IF;
            IF (clk90_counter MOD 2 = 0) THEN
               clk90_div4 <= NOT(clk90_div4);
            END IF;
         END IF;
         clk90_counter <= clk90_counter + 1;
      END IF;
   END PROCESS;
   
   -- clk270_div4/5 should not start toggling before clk90_div4/5 
   PROCESS (clk270, rst_ni)
   VARIABLE got_first_clk270_rising_edge : STD_LOGIC := '0' ;
   BEGIN
      IF (rst_ni = '0') THEN
         clk270_counter <= 0;
         clk270_div_init_done <= '0';
         clk270_div5 <= '0';
         clk270_div4 <= '0';
         got_first_clk270_rising_edge := '0';
      ELSE
         IF (clk90_div_init_done = '1') THEN
            -- generation of clk270_div5
            IF ((clk270_counter MOD 5 = 0) AND (clk270 = '1')) THEN
               got_first_clk270_rising_edge := '1';
               clk270_div5 <= '1';
            ELSIF ((clk270_counter MOD 5 = 0) AND (clk270 = '0')) THEN
               -- generation of clk270_div4
               clk270_div5 <= '0';
            END IF;
            IF ((clk270 = '1') AND (clk270_counter MOD 4 = 0)) THEN
               IF (clk270_div_init_done = '0') THEN
                  clk270_div4 <= '1';
                  clk270_div_init_done <= '1';
               ELSE
                  clk270_div4 <= NOT(clk270_div4);
               END IF;
            END IF;
            IF (got_first_clk270_rising_edge = '1') THEN
               clk270_counter <= clk270_counter + 1;
            END IF;
         END IF;
      END IF;
   END PROCESS;
   
   -- like b1, ph duty-cycle is 60-40 vhdl_in dvi5 mode, and 50-50 vhdl_in div4 mode
   PROCESS (rst_ni, clk270)
   BEGIN
      IF ((NOT(rst_ni)) = '1') THEN
         ph(3 DOWNTO 0) <=  TRANSPORT "0000" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (clk270'EVENT AND clk270 = '1') THEN
         ph(3 DOWNTO 0) <=  TRANSPORT (ph(2 DOWNTO 0) & b1) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (deser_div5, clk270)
   BEGIN
      IF ((NOT(deser_div5)) = '1') THEN
         ph(4) <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSIF (clk270'EVENT AND clk270 = '1') THEN
         -- Shift register
         ph(4) <=  TRANSPORT ph(3) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (rst_ni, ph(0))
   BEGIN
      IF ((NOT(rst_ni)) = '1') THEN
         dp(1 DOWNTO 0) <=  TRANSPORT "00" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (ph(0)'EVENT AND ph(0) = '1') THEN
         dp(1 DOWNTO 0) <=  TRANSPORT (dodd & deven) AFTER (PARAM_DELAY)*1 ps;		-- used to be {data_odd,data_even}
      END IF;
   END PROCESS;
   
   PROCESS (rst_ni, ph(1))
   BEGIN
      IF ((NOT(rst_ni)) = '1') THEN
         dp(3 DOWNTO 2) <=  TRANSPORT "00" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (ph(1)'EVENT AND ph(1) = '1') THEN
         dp(3 DOWNTO 2) <=  TRANSPORT (dodd & deven) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (rst_ni, ph(2))
   BEGIN
      IF ((NOT(rst_ni)) = '1') THEN
         dp(5 DOWNTO 4) <=  TRANSPORT "00" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (ph(2)'EVENT AND ph(2) = '1') THEN
         dp(5 DOWNTO 4) <=  TRANSPORT (dodd & deven) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (rst_ni, ph(3))
   BEGIN
      IF ((NOT(rst_ni)) = '1') THEN
         dp(7 DOWNTO 6) <=  TRANSPORT "00" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (ph(3)'EVENT AND ph(3) = '1') THEN
         dp(7 DOWNTO 6) <=  TRANSPORT (dodd & deven) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (rst_ni, ph(4))
   BEGIN
      IF ((NOT(rst_ni)) = '1') THEN
         dp(9 DOWNTO 8) <=  TRANSPORT "00" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (ph(4)'EVENT AND ph(4) = '1') THEN
         -- dp[0,1,2,3] synchronization
         dp(9 DOWNTO 8) <=  TRANSPORT (dodd & deven) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (rst_ni, ph(3))
   BEGIN
      IF ((NOT(rst_ni)) = '1') THEN
         dsync(3 DOWNTO 0) <=  TRANSPORT "0000" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (ph(3)'EVENT AND ph(3) = '1') THEN
         dsync(3 DOWNTO 0) <=  TRANSPORT dp(3 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (rst_ni, ph(0))
   BEGIN
      IF ((NOT(rst_ni)) = '1') THEN
         outp(9 DOWNTO 0) <=  TRANSPORT "0000000000" AFTER (PARAM_DELAY)*1 ps;
         outn(9 DOWNTO 0) <=  TRANSPORT "0000000000" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (ph(0)'EVENT AND ph(0) = '1') THEN
         outp(9 DOWNTO 0) <=  TRANSPORT (dp(9 DOWNTO 4) & dsync(3 DOWNTO 0)) AFTER (PARAM_DELAY)*1 ps;
         outn(9 DOWNTO 0) <=  TRANSPORT NOT((dp(9 DOWNTO 4) & dsync(3 DOWNTO 0))) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   -- * * c_deser_10to20 * *
   
   xhdl1 <= NOT(cout);
   xdiv2_2 : stratixiv_hssi_pma_c_divby2q
      PORT MAP (
         clk       => xhdl1,
         clkb      => cout,
         clk0      => nc0,
         clk90     => nc1,
         vcce_la   => '1',
         vssexqyx  => '0',
         clk180    => ck_div2,
         clk270    => nc2,
         rst_n     => rst_ni
      );
   
   ck_2div <= NOT(ck_div2) WHEN (deser_div2 = '1') ELSE
              NOT(cout);
   ckb_2div <= ck_div2 WHEN (deser_div2 = '1') ELSE
               cout;
   
   PROCESS (rst_ni, ck_2div)
   BEGIN
      IF ((NOT(rst_ni)) = '1') THEN
         d10a(9 DOWNTO 0) <=  TRANSPORT "0000000000" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (ck_2div'EVENT AND ck_2div = '1') THEN
         d10a(9 DOWNTO 0) <=  TRANSPORT outp(9 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (rst_ni, ckb_2div)
   BEGIN
      IF ((NOT(rst_ni)) = '1') THEN
         douta(9 DOWNTO 0) <=  TRANSPORT "0000000000" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (ckb_2div'EVENT AND ckb_2div = '1') THEN
         douta(9 DOWNTO 0) <=  TRANSPORT d10a(9 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (rst_n_div2, ckb_2div)
   BEGIN
      IF ((NOT(rst_n_div2)) = '1') THEN
         doutb(9 DOWNTO 0) <=  TRANSPORT "0000000000" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (ckb_2div'EVENT AND ckb_2div = '1') THEN
         -- ** c_deser_data_comp blocks * *
         doutb(9 DOWNTO 0) <=  TRANSPORT outp(9 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   even_all1 <= reduction_and((outp(6) & outp(4) & outp(2) & outp(0))) AND (NOT(deser_div5) OR outp(8));
   even_all0 <= reduction_and((outn(6) & outn(4) & outn(2) & outn(0))) AND (NOT(deser_div5) OR outn(8));
   odd_all1 <= reduction_and((outp(7) & outp(5) & outp(3) & outp(1))) AND (NOT(deser_div5) OR outp(9));
   odd_all0 <= reduction_and((outn(7) & outn(5) & outn(3) & outn(1))) AND (NOT(deser_div5) OR outn(9));
   
   -- rst_sd pulse generator
   PROCESS (ph(3))
   BEGIN
      IF (ph(3)'EVENT AND ph(3) = '1') THEN
         rst_sd <= '0';
         rst_sd <=  TRANSPORT '1' AFTER (RST_SD_PULSE_WIDTH)*1 ps;
      END IF;
   END PROCESS;
   
   -- c_deser_ff_chain
   rxp_clk <= rxinp AND rfast_sd(2);
   rxn_clk <= rxinn AND rfast_sd(2);
   muxout_ff_chain <= reduction_or((drp(0) & dfp(0))) WHEN (rfast_sd(1) = '0' AND rfast_sd(0) = '0') ELSE
                      reduction_or((drp(1) & dfp(1))) WHEN (rfast_sd(1) = '0' AND rfast_sd(0) = '1') ELSE
                      reduction_or((drp(2) & dfp(2))) WHEN (rfast_sd(1) = '1' AND rfast_sd(0) = '0') ELSE
                      reduction_or((drp(3) & dfp(3))) WHEN (rfast_sd(1) = '1' AND rfast_sd(0) = '1') ELSE
                      'X';
   
   PROCESS (rxp_clk, rst_sd)
   BEGIN
      IF (rst_sd = '0') THEN
         drp(3 DOWNTO 0) <=  TRANSPORT "0000" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (rxp_clk'EVENT AND rxp_clk = '1') THEN
         drp(3 DOWNTO 0) <=  TRANSPORT (drp(2 DOWNTO 0) & vcce_la) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (rxn_clk, rst_sd)
   BEGIN
      IF (rst_sd = '0') THEN
         dfp(3 DOWNTO 0) <=  TRANSPORT "0000" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (rxn_clk'EVENT AND rxn_clk = '1') THEN
         dfp(3 DOWNTO 0) <=  TRANSPORT (dfp(2 DOWNTO 0) & vcce_la) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (ph(3))
   BEGIN
      IF (ph(3)'EVENT AND ph(3) = '1') THEN
         shiftout_1 <=  TRANSPORT muxout_ff_chain AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (ph(3))
   BEGIN
      IF (ph(3)'EVENT AND ph(3) = '0') THEN
         -- c_deser_pcie
         shiftout <=  TRANSPORT shiftout_1 AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   pcie_clk_div <= ck_2div AND rdynamic_sw;
   exor <= (NOT(n1) AND n0) OR (n1 AND NOT(n0));
   ck_div_en <= NOT((n2 OR n3 OR n4));
   pcieo <= NOT(rdynamic_sw) OR n6;
   
   PROCESS (pcie_clk_div, rst_ni)
   BEGIN
      IF (rst_ni = '0') THEN
         n1 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         n0 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         pcie2 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         n4 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         n3 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         n2 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         n6 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSIF (pcie_clk_div'EVENT AND pcie_clk_div = '1') THEN
         n1 <=  TRANSPORT n0 AFTER (PARAM_DELAY)*1 ps;
         n0 <=  TRANSPORT pcie2 AFTER (PARAM_DELAY)*1 ps;
         pcie2 <=  TRANSPORT pcie_sw AFTER (PARAM_DELAY)*1 ps;
         n4 <=  TRANSPORT n3 AFTER (PARAM_DELAY)*1 ps;
         n3 <=  TRANSPORT n2 AFTER (PARAM_DELAY)*1 ps;
         n2 <=  TRANSPORT exor AFTER (PARAM_DELAY)*1 ps;
         n6 <=  TRANSPORT n1 AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   -- c_deser_data_comp
   noswitch <= (((shiftout OR NOT(rfast_sd(3))) AND shiftoutq) OR (NOT(rfast_sd(2)) AND rtest_fastsd)) AND (NOT(activity) OR (NOT(rfast_sd(2)) AND NOT(rtest_fastsd)));
   
   activity <= NOT(((((even_all0 OR NOT(rfast_sd(3))) AND even_all0q) OR ((even_all1 OR NOT(rfast_sd(3))) AND even_all1q)) AND (((odd_all0 OR NOT(rfast_sd(3))) AND odd_all0q) OR ((odd_all0 OR NOT(rfast_sd(3))) AND odd_all0q))));
   
   PROCESS (rst_ni, clk_divrx_xhdl0)
   BEGIN
      IF (rst_ni = '0') THEN
         even_all1q <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         even_all0q <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         odd_all1q <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         odd_all0q <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         shiftoutq <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSIF (clk_divrx_xhdl0'EVENT AND clk_divrx_xhdl0 = '0') THEN
         even_all1q <=  TRANSPORT even_all1 AFTER (PARAM_DELAY)*1 ps;
         even_all0q <=  TRANSPORT even_all0 AFTER (PARAM_DELAY)*1 ps;
         odd_all1q <=  TRANSPORT odd_all1 AFTER (PARAM_DELAY)*1 ps;
         odd_all0q <=  TRANSPORT odd_all0 AFTER (PARAM_DELAY)*1 ps;
         shiftoutq <=  TRANSPORT shiftout AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (rst_ni, clk_divrx_xhdl0)
   BEGIN
      IF (rst_ni = '0') THEN
         fsd <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSIF (clk_divrx_xhdl0'EVENT AND clk_divrx_xhdl0 = '1') THEN
         fsd <=  TRANSPORT NOT(noswitch) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_div4or5_mcnt IS
   PORT (
      clk     : IN STD_LOGIC;
      clkb    : IN STD_LOGIC;
      d5      : IN STD_LOGIC;
      fout    : OUT STD_LOGIC;
      foutn   : OUT STD_LOGIC;
      rst_n   : IN STD_LOGIC;
      vccerx  : IN STD_LOGIC;
      vssex   : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_div4or5_mcnt;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_div4or5_mcnt IS
   
   SIGNAL clk_by2    : STD_LOGIC;
   SIGNAL clk_by4    : STD_LOGIC;
   SIGNAL a          : STD_LOGIC;
   SIGNAL b          : STD_LOGIC;
   SIGNAL c          : STD_LOGIC;
   SIGNAL clk_by5    : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL fout_xhdl0 : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   fout <= fout_xhdl0;
   
   foutn <= NOT(fout_xhdl0);
   fout_xhdl0 <= clk_by5 WHEN (d5 = '1') ELSE
                 clk_by4;
   
   -- Divide-by-4 clock
   PROCESS (rst_n, clk)
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         clk_by2 <= '0';
      ELSIF (clk'EVENT AND clk = '1') THEN
         
         clk_by2 <= NOT(clk_by2);
      END IF;
   END PROCESS;
   
   PROCESS (rst_n, clk_by2)
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         clk_by4 <= '0';
      ELSIF (clk_by2'EVENT AND clk_by2 = '1') THEN
         
         -- Divide-by-5 clock
         clk_by4 <= NOT(clk_by4);
      END IF;
   END PROCESS;
   
   clk_by5 <= (clk OR NOT(b)) AND (a OR clk_by5);
   PROCESS (rst_n, clk)
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         a <= '0';
         b <= '0';
         c <= '0';
      ELSIF (clk'EVENT AND clk = '1') THEN
         a <= (NOT(a) AND NOT(b) AND c);
         b <= (NOT(a) AND NOT(c));
         c <= (b);
      END IF;
   END PROCESS;
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;
   USE ieee.std_logic_unsigned.all;

ENTITY stratixiv_hssi_pma_c_lockdet_tx18 IS
   PORT (
      
      disableb  : IN STD_LOGIC;
      dn        : IN STD_LOGIC;
      dnb       : IN STD_LOGIC;
      ib50      : INOUT STD_LOGIC;
      lock      : OUT STD_LOGIC;
      lockb     : OUT STD_LOGIC;
      pd        : IN STD_LOGIC;
      up        : IN STD_LOGIC;
      upb       : IN STD_LOGIC;
      vccerx    : IN STD_LOGIC;
      vssex     : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_lockdet_tx18;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_lockdet_tx18 IS
   
   SIGNAL cnt        : STD_LOGIC_VECTOR(4 DOWNTO 0);
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL lock_xhdl0 : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   lock <= lock_xhdl0;
   
   lock_xhdl0 <= int2bit((cnt = "00011"));
   lockb <= NOT(lock_xhdl0);
   
   PROCESS (pd, up)
   BEGIN
      IF (pd = '1') THEN
         cnt <= "00000";
      ELSIF (up'EVENT AND up = '1') THEN
         IF (cnt /= "00011") THEN
            cnt <= cnt + "00001";
         END IF;
      END IF;
   END PROCESS;
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_pfd IS
   PORT (
      dn      : OUT STD_LOGIC;
      dnb     : OUT STD_LOGIC;
      fbclk   : IN STD_LOGIC;
      refclk  : IN STD_LOGIC;
      up      : OUT STD_LOGIC;
      upb     : OUT STD_LOGIC;
      vccerx  : IN STD_LOGIC;
      vssex   : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_pfd;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_pfd IS
BEGIN
   
   up <= refclk;
   upb <= NOT(refclk);
   dn <= fbclk;
   dnb <= NOT(fbclk);
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_rlpbk_ctrl IS
   PORT (
      cru_rlbk      : IN STD_LOGIC;
      rrevlb_sw     : IN STD_LOGIC;
      rrx_s_rdlpbk  : IN STD_LOGIC;
      tx_rlpbk      : OUT STD_LOGIC;
      vccerx        : IN STD_LOGIC;
      vssex         : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_rlpbk_ctrl;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_rlpbk_ctrl IS
BEGIN
   
   tx_rlpbk <= cru_rlbk WHEN (rrevlb_sw = '1') ELSE
               rrx_s_rdlpbk;
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_rlpbk_mux IS
   PORT (
      
      doddn    : IN STD_LOGIC;
      doddp    : IN STD_LOGIC;
      dodn     : IN STD_LOGIC;
      dodp     : IN STD_LOGIC;
      don      : IN STD_LOGIC;
      don_pre  : IN STD_LOGIC;
      dop      : IN STD_LOGIC;
      dop_pre  : IN STD_LOGIC;
      drxn     : IN STD_LOGIC;
      drxp     : IN STD_LOGIC;
      sel      : IN STD_LOGIC;
      vcce_la  : IN STD_LOGIC;
      
      voddn    : OUT STD_LOGIC;
      voddp    : OUT STD_LOGIC;
      vodn     : OUT STD_LOGIC;
      vodp     : OUT STD_LOGIC;
      von      : OUT STD_LOGIC;
      von_pre  : OUT STD_LOGIC;
      vop      : OUT STD_LOGIC;
      vop_pre  : OUT STD_LOGIC;
      vssex    : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_rlpbk_mux;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_rlpbk_mux IS
BEGIN
   
   von <= don WHEN (sel = '1') ELSE
          drxn;
   vop <= dop WHEN (sel = '1') ELSE
          drxp;
   voddn <= doddn;
   voddp <= doddp;
   vodn <= dodn;
   vodp <= dodp;
   von_pre <= don_pre;
   vop_pre <= dop_pre;
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;

   
LIBRARY ieee;
   USE ieee.std_logic_1164.all;
   USE ieee.std_logic_unsigned.all;

ENTITY stratixiv_hssi_pma_c_rx IS
   GENERIC (
      PARAM_DELAY        : INTEGER := 0;
      INVALID_SD_ON_OFF  : INTEGER := 500
   );
   PORT (
      analog_sd          : OUT STD_LOGIC;
      atb_0              : INOUT STD_LOGIC;
      atb_1              : INOUT STD_LOGIC;
      atbsel             : IN STD_LOGIC_VECTOR(5 DOWNTO 0);
      ck0_sigdet         : IN STD_LOGIC;
      eqa_ctrl           : IN STD_LOGIC;
      eqb_ctrl           : IN STD_LOGIC;
      eqc_ctrl           : IN STD_LOGIC;
      eqd_ctrl           : IN STD_LOGIC;
      eqv_ctrl           : IN STD_LOGIC;
      ibc50u             : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      ibp50u             : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      ibp150u            : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      inn                : IN STD_LOGIC;
      inn3               : OUT STD_LOGIC;
      inp                : IN STD_LOGIC;
      inp3               : OUT STD_LOGIC;
      lpbkn              : IN STD_LOGIC;
      lpbkp              : IN STD_LOGIC;
      oc_calpd           : IN STD_LOGIC;
      oc_en              : IN STD_LOGIC;
      pdb                : IN STD_LOGIC;
      rbit_dc            : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      rdlpbkn            : OUT STD_LOGIC;
      rdlpbkp            : OUT STD_LOGIC;
      refclk             : IN STD_LOGIC;
      rx_b50             : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      rx_oc              : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
      rx_test            : IN STD_LOGIC;
      rx_testclk         : IN STD_LOGIC;
      rxbuf_ibias        : OUT STD_LOGIC;
      rxn                : OUT STD_LOGIC;
      rxp                : OUT STD_LOGIC;
      s_lpbk             : IN STD_LOGIC;
      s_rdlpbk           : IN STD_LOGIC;
      sd_cdr             : OUT STD_LOGIC;
      sd_cpon            : OUT STD_LOGIC;
      sd_cpop            : OUT STD_LOGIC;
      sd_force           : IN STD_LOGIC;
      sd_off             : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
      sd_on              : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      sdlv               : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      term               : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      vcce_la            : IN STD_LOGIC;
      vcce_oa            : IN STD_LOGIC;
      vccehtxqyx         : IN STD_LOGIC;
      vssexqyx           : IN STD_LOGIC;
      vtt                : IN STD_LOGIC_VECTOR(2 DOWNTO 0)
   );
END stratixiv_hssi_pma_c_rx;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_rx IS
   
   SIGNAL ib50uc2               : STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   SIGNAL vccbn1g               : STD_LOGIC;
   SIGNAL d_vm                  : STD_LOGIC;
   SIGNAL vbn_lb                : STD_LOGIC;
   SIGNAL vbn_dlb               : STD_LOGIC;
   SIGNAL vbn2_dlb              : STD_LOGIC;
   SIGNAL rxbuf_vcc             : STD_LOGIC;
   SIGNAL rxbuf_vsg             : STD_LOGIC;
   SIGNAL dlbpd                 : STD_LOGIC;
   SIGNAL lbpd                  : STD_LOGIC;
   SIGNAL linepd                : STD_LOGIC;
   
   SIGNAL rst_sdn               : STD_LOGIC := '0' ;
   SIGNAL rst_sdp               : STD_LOGIC := '0' ;
   SIGNAL sdp                   : STD_LOGIC := '0' ;
   SIGNAL sdn                   : STD_LOGIC := '0' ;
   SIGNAL sd_on_chg             : STD_LOGIC;
   SIGNAL sd_off_chg            : STD_LOGIC;
   SIGNAL sd_1_compout_pulse    : INTEGER;
   SIGNAL sd_0_ck0_pulse        : INTEGER;
   SIGNAL sdp_count             : INTEGER := 0 ;
   SIGNAL sdn_count             : INTEGER := 0 ;
   SIGNAL ck0_sigdet_count_cpop : INTEGER := 0 ;
   SIGNAL ck0_sigdet_count_cpon : INTEGER := 0 ;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL analog_sd_xhdl0       : STD_LOGIC;
   SIGNAL inn3_xhdl1            : STD_LOGIC;
   SIGNAL inp3_xhdl2            : STD_LOGIC;
   SIGNAL rxbuf_ibias_xhdl3     : STD_LOGIC;
   SIGNAL rxn_xhdl4             : STD_LOGIC;
   SIGNAL rxp_xhdl5             : STD_LOGIC;
   SIGNAL sd_cpon_xhdl6         : STD_LOGIC;
   SIGNAL sd_cpop_xhdl7         : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   analog_sd <= analog_sd_xhdl0;
   inn3 <= inn3_xhdl1;
   inp3 <= inp3_xhdl2;
   rxbuf_ibias <= rxbuf_ibias_xhdl3;
   rxn <= rxn_xhdl4;
   rxp <= rxp_xhdl5;
   sd_cpon <= sd_cpon_xhdl6;
   sd_cpop <= sd_cpop_xhdl7;
   
   atb_0 <= vccbn1g WHEN ((atbsel(0)) = '1') ELSE
            'Z';
   atb_1 <= d_vm WHEN ((atbsel(0)) = '1') ELSE
            'Z';
   atb_0 <= rxbuf_ibias_xhdl3 WHEN ((atbsel(1)) = '1') ELSE
            'Z';
   atb_1 <= vbn_lb WHEN ((atbsel(1)) = '1') ELSE
            'Z';
   atb_0 <= vbn_dlb WHEN ((atbsel(2)) = '1') ELSE
            'Z';
   atb_1 <= vbn2_dlb WHEN ((atbsel(2)) = '1') ELSE
            'Z';
   atb_0 <= rxbuf_vcc WHEN ((atbsel(3)) = '1') ELSE
            'Z';
   atb_1 <= rxbuf_vsg WHEN ((atbsel(3)) = '1') ELSE
            'Z';
   atb_0 <= vssexqyx WHEN ((atbsel(4)) = '1') ELSE
            'Z';
   atb_1 <= vssexqyx WHEN ((atbsel(4)) = '1') ELSE
            'Z';
   
   -- c_rx_dlb - buffer w/ power-down (loopback to TX)
   dlbpd <= NOT((s_rdlpbk AND pdb));
   rdlpbkp <= '1' WHEN (dlbpd = '1') ELSE
              rxp_xhdl5;
   rdlpbkn <= '0' WHEN (dlbpd = '1') ELSE
              rxn_xhdl4;
   
   -- c_rx_lb - buffer w/ power-down (loopback from serializer)
   lbpd <= NOT((s_lpbk AND pdb));
   inp3_xhdl2 <= inp WHEN (lbpd = '1') ELSE
                 lpbkp WHEN (pdb = '1') ELSE
                 '1';
   inn3_xhdl1 <= inn WHEN (lbpd = '1') ELSE
                 lpbkn WHEN (pdb = '1') ELSE
                 '1';
   
   -- c_rx_term_vtt black-box
   
   -- c_rx_buffer instance
   linepd <= rx_test OR s_lpbk;
   rxp_xhdl5 <= inp WHEN (linepd = '0') ELSE		-- Logic to be changed
                inp3_xhdl2 WHEN ((rx_test = '0') AND (rx_testclk = '0')) ELSE
                refclk WHEN ((rx_test = '0') AND (rx_testclk = '1')) ELSE
                lpbkp WHEN ((rx_test = '1') AND (rx_testclk = '0')) ELSE
                '1' WHEN (pdb = '1') ELSE
                '1';
   rxn_xhdl4 <= inn WHEN (linepd = '0') ELSE		-- Logic to be changed
                inn3_xhdl1 WHEN ((rx_test = '0') AND (rx_testclk = '0')) ELSE
                NOT(refclk) WHEN ((rx_test = '0') AND (rx_testclk = '1')) ELSE
                lpbkn WHEN ((rx_test = '1') AND (rx_testclk = '0')) ELSE
                '1' WHEN (pdb = '1') ELSE
                '1';
   
   -- c_sd - vhdl_signal detect 
   analog_sd_xhdl0 <= sdp OR sdn;
   sd_cdr <= sd_force OR s_lpbk OR analog_sd_xhdl0;
   sd_cpop_xhdl7 <= (inp AND pdb);		-- for digital simulation, assuming inp and inn are comparator's outputs
   sd_cpon_xhdl6 <= (inn AND pdb);
   
   
   PROCESS (sd_on)
   BEGIN
      IF ((sd_on = "0000") OR (sd_on = "1111")) THEN
         --       $display ("Instance %m, Time %t: ERROR [Illegal usage]: The SD_ON value is illegal - sd_on=%b", $time, sd_on);
         sd_1_compout_pulse <= INVALID_SD_ON_OFF;
      ELSE
         CASE sd_on IS
            WHEN "0001" =>
               sd_1_compout_pulse <= 4;
            WHEN "0010" =>
               sd_1_compout_pulse <= 6;
            WHEN "0011" =>
               sd_1_compout_pulse <= 8;
            WHEN "0100" =>
               sd_1_compout_pulse <= 10;
            WHEN "0101" =>
               sd_1_compout_pulse <= 12;
            WHEN "0110" =>
               sd_1_compout_pulse <= 14;
            WHEN "0111" =>
               sd_1_compout_pulse <= 16;
            WHEN "1000" =>
               sd_1_compout_pulse <= 18;
            WHEN "1001" =>
               sd_1_compout_pulse <= 20;
            WHEN "1010" =>
               sd_1_compout_pulse <= 22;
            WHEN "1011" =>
               sd_1_compout_pulse <= 24;
            WHEN "1100" =>
               sd_1_compout_pulse <= 26;
            WHEN "1101" =>
               sd_1_compout_pulse <= 28;
            WHEN "1110" =>
               sd_1_compout_pulse <= 30;
            WHEN "1111" =>
               sd_1_compout_pulse <= INVALID_SD_ON_OFF;
            WHEN OTHERS =>
               sd_1_compout_pulse <= 4;
         END CASE;
      END IF;
      sd_1_compout_pulse <= bin2int(sd_on);
      sd_on_chg <= '1';
      sd_on_chg <=  TRANSPORT '0' AFTER 1 ps;
   END PROCESS;
   
   
   PROCESS (sd_off)
   BEGIN
      IF (sd_off = "01111") THEN
         --       $display ("Instance %m, Time %t: ERROR [Illegal usage]: The SD_OFF value is illegal - sd_off=%b", $time, sd_off);
         sd_0_ck0_pulse <= INVALID_SD_ON_OFF;
      ELSE
         CASE sd_off(3 DOWNTO 0) IS
            WHEN "0001" =>
               sd_0_ck0_pulse <= 4;
            WHEN "0010" =>
               sd_0_ck0_pulse <= 6;
            WHEN "0011" =>
               sd_0_ck0_pulse <= 8;
            WHEN "0100" =>
               sd_0_ck0_pulse <= 10;
            WHEN "0101" =>
               sd_0_ck0_pulse <= 12;
            WHEN "0110" =>
               sd_0_ck0_pulse <= 14;
            WHEN "0111" =>
               sd_0_ck0_pulse <= 16;
            WHEN "1000" =>
               sd_0_ck0_pulse <= 18;
            WHEN "1001" =>
               sd_0_ck0_pulse <= 20;
            WHEN "1010" =>
               sd_0_ck0_pulse <= 22;
            WHEN "1011" =>
               sd_0_ck0_pulse <= 24;
            WHEN "1100" =>
               sd_0_ck0_pulse <= 26;
            WHEN "1101" =>
               sd_0_ck0_pulse <= 28;
            WHEN "1110" =>
               sd_0_ck0_pulse <= 30;
            WHEN "1111" =>
               sd_0_ck0_pulse <= INVALID_SD_ON_OFF;
            WHEN OTHERS =>
               sd_0_ck0_pulse <= 4;
         END CASE;
      END IF;
      sd_off_chg <= '1';
      sd_off_chg <=  TRANSPORT '0' AFTER 1 ps;
   END PROCESS;
   
   
   -- Set sdp
   PROCESS (sd_cpop_xhdl7, rst_sdp, sd_on_chg)
   BEGIN
      IF (sd_cpop_xhdl7'EVENT AND sd_cpop_xhdl7 = '0') THEN
         IF ((rst_sdp = '1') OR (sd_on_chg = '1')) THEN
            sdp <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
             
            sdp_count <= 0;
         ELSE
            sdp_count <= sdp_count + 1;
            IF (sdp_count >= sd_1_compout_pulse) THEN
               sdp <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
                
            END IF;
         END IF;
      END IF;
   END PROCESS;
   
   
   -- Set sdn
   PROCESS (sd_cpon_xhdl6, rst_sdn, sd_on_chg)
   BEGIN
      IF (sd_cpon_xhdl6'EVENT AND sd_cpon_xhdl6 = '0') THEN
         IF ((rst_sdn = '1') OR (sd_on_chg = '1')) THEN
            sdn <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
             
            sdn_count <= 0;
         ELSE
            sdn_count <= sdn_count + 1;
            IF (sdn_count >= sd_1_compout_pulse) THEN
               sdn <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
                
            END IF;
         END IF;
      END IF;
   END PROCESS;
   
   
   -- Clear sdp -- generate rst_sdp
   PROCESS (ck0_sigdet, sd_cpop_xhdl7)
   BEGIN
      IF ((ck0_sigdet = '0') AND (sd_cpop_xhdl7 = '0')) THEN
         ck0_sigdet_count_cpop <= ck0_sigdet_count_cpop + 1;
         IF (ck0_sigdet_count_cpop = sd_0_ck0_pulse) THEN
            rst_sdp <= '1';
         END IF;
      ELSIF (sd_cpop_xhdl7'EVENT AND sd_cpop_xhdl7 = '1') THEN
         IF (ck0_sigdet = '1') THEN
            rst_sdp <= '0';
         END IF;
      END IF;
      IF (sd_cpop_xhdl7 = '1') THEN
         ck0_sigdet_count_cpop <= 0;
      END IF;
   END PROCESS;
   
   
   -- Clear sdn -- generate rst_sdn
   PROCESS (ck0_sigdet, sd_cpon_xhdl6)
   BEGIN
      IF ((ck0_sigdet = '0') AND (sd_cpon_xhdl6 = '0')) THEN
         ck0_sigdet_count_cpon <= ck0_sigdet_count_cpon + 1;
         IF (ck0_sigdet_count_cpon = sd_0_ck0_pulse) THEN
            rst_sdn <= '1';
         END IF;
      ELSIF (sd_cpon_xhdl6'EVENT AND sd_cpon_xhdl6 = '1') THEN
         IF (ck0_sigdet = '1') THEN
            rst_sdn <= '0';
         END IF;
      END IF;
      IF (sd_cpon_xhdl6 = '1') THEN
         ck0_sigdet_count_cpon <= 0;
      END IF;
   END PROCESS;
   
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;

   
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_ser IS
   GENERIC (
      
      PARAM_DELAY    : INTEGER := 0
   );
   PORT (
      
      clk_divtx      : OUT STD_LOGIC;
      cpulse         : IN STD_LOGIC;
      data           : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
      div2           : IN STD_LOGIC;
      div5           : IN STD_LOGIC;
      hfclkn         : IN STD_LOGIC;
      hfclkp         : IN STD_LOGIC;
      lbvon          : OUT STD_LOGIC;
      lbvop          : OUT STD_LOGIC;
      lfclkn         : IN STD_LOGIC;
      lfclkp         : IN STD_LOGIC;
      pclk_in        : IN STD_LOGIC;
      pclksel        : IN STD_LOGIC;
      pdb            : IN STD_LOGIC;
      pre_em         : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
      pre_em_2t      : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      pre_em_pretap  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      pre_en_out     : OUT STD_LOGIC;
      rst_n          : IN STD_LOGIC;
      s_lpbk         : IN STD_LOGIC;
      vccelxqyx      : IN STD_LOGIC;
      vccetxqyx      : IN STD_LOGIC;
      von            : OUT STD_LOGIC;
      von_op1        : OUT STD_LOGIC;
      von_op2        : OUT STD_LOGIC;
      von_pre        : OUT STD_LOGIC;
      vop            : OUT STD_LOGIC;
      vop_op1        : OUT STD_LOGIC;
      vop_op2        : OUT STD_LOGIC;
      vop_pre        : OUT STD_LOGIC;
      vssexqyx       : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_ser;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_ser IS
   COMPONENT stratixiv_hssi_pma_c_divby2q
      PORT (
         clk            : IN STD_LOGIC;
         clk0           : OUT STD_LOGIC;
         clk90          : OUT STD_LOGIC;
         clk180         : OUT STD_LOGIC;
         clk270         : OUT STD_LOGIC;
         clkb           : IN STD_LOGIC;
         rst_n          : IN STD_LOGIC;
         vcce_la        : IN STD_LOGIC;
         vssexqyx       : IN STD_LOGIC
      );
   END COMPONENT;
   
   
   SIGNAL pre_en            : STD_LOGIC;
   SIGNAL pre_en_pretap     : STD_LOGIC;
   SIGNAL pre_en_2t         : STD_LOGIC;
   SIGNAL s_lpbkbuf         : STD_LOGIC;
   SIGNAL div5buf           : STD_LOGIC;
   SIGNAL rst_nbuf          : STD_LOGIC;
   SIGNAL rst_pdb           : STD_LOGIC;
   SIGNAL sel               : STD_LOGIC;
   SIGNAL pe_pre            : STD_LOGIC;
   SIGNAL pe                : STD_LOGIC;
   SIGNAL pe_2t             : STD_LOGIC;
   SIGNAL lben              : STD_LOGIC;
   SIGNAL a                 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL b                 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL d10m              : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL lfclk_div2        : STD_LOGIC;
   SIGNAL nc0               : STD_LOGIC;
   SIGNAL nc1               : STD_LOGIC;
   SIGNAL nc3               : STD_LOGIC;
   SIGNAL nc2               : STD_LOGIC;
   
   SIGNAL d10a              : STD_LOGIC_VECTOR(9 DOWNTO 0) := "0000000000" ;
   SIGNAL d10b              : STD_LOGIC_VECTOR(9 DOWNTO 0) := "0000000000" ;
   SIGNAL d10               : STD_LOGIC_VECTOR(9 DOWNTO 0) := "0000000000" ;
   SIGNAL data_mux5t1_sync1 : STD_LOGIC_VECTOR(9 DOWNTO 0) := "0000000000" ;
   SIGNAL do_mux5t1_sync2   : STD_LOGIC_VECTOR(4 DOWNTO 0) := "00000" ;
   SIGNAL de_mux5t1_sync2   : STD_LOGIC_VECTOR(4 DOWNTO 0) := "00000" ;
   SIGNAL cp_even           : STD_LOGIC := '0' ;
   SIGNAL c0_even           : STD_LOGIC := '0' ;
   SIGNAL c1_even           : STD_LOGIC := '0' ;
   SIGNAL c2_even           : STD_LOGIC := '0' ;
   SIGNAL c3_even           : STD_LOGIC := '0' ;
   SIGNAL c4_even           : STD_LOGIC := '0' ;
   SIGNAL cp_odd            : STD_LOGIC := '0' ;
   SIGNAL c0_odd            : STD_LOGIC := '0' ;
   SIGNAL c1_odd            : STD_LOGIC := '0' ;
   SIGNAL c2_odd            : STD_LOGIC := '0' ;
   SIGNAL c3_odd            : STD_LOGIC := '0' ;
   SIGNAL c4_odd            : STD_LOGIC := '0' ;
   SIGNAL out_o             : STD_LOGIC := '0' ;
   SIGNAL out_e             : STD_LOGIC := '0' ;
   SIGNAL vop_pre_reg       : STD_LOGIC := '0' ;
   SIGNAL von_pre_reg       : STD_LOGIC := '1' ;
   SIGNAL vop_reg           : STD_LOGIC := '0' ;
   SIGNAL von_reg           : STD_LOGIC := '1' ;
   SIGNAL vop_op1_reg       : STD_LOGIC := '0' ;
   SIGNAL von_op1_reg       : STD_LOGIC := '1' ;
   SIGNAL oo1               : STD_LOGIC := '0' ;
   SIGNAL oo2               : STD_LOGIC := '0' ;
   SIGNAL oo3               : STD_LOGIC := '0' ;
   SIGNAL oe1               : STD_LOGIC := '0' ;
   SIGNAL oe2               : STD_LOGIC := '0' ;
   SIGNAL oe3               : STD_LOGIC := '0' ;
   SIGNAL vop_op2_reg       : STD_LOGIC := '0' ;
   SIGNAL von_op2_reg       : STD_LOGIC := '1' ;
   SIGNAL out_lb_reg        : STD_LOGIC := '0' ;
   SIGNAL outb_lb_reg       : STD_LOGIC := '1' ;
   SIGNAL clk_divtx_wire    : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL pre_en_out_xhdl0  : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   pre_en_out <= pre_en_out_xhdl0;
   
   pre_en_out_xhdl0 <= reduction_nor(pre_em);
   pre_en_pretap <= reduction_or(pre_em_pretap);
   pre_en_2t <= reduction_or(pre_em_2t);
   s_lpbkbuf <= pdb AND s_lpbk;
   div5buf <= pdb AND div5;
   rst_nbuf <= pdb AND rst_n;
   clk_divtx <= clk_divtx_wire;
   -- * * c_ser_20to10 -- x20to10 instance * *
   a <= data(9 DOWNTO 0);
   b <= data(19 DOWNTO 10);
   sel <= NOT(clk_divtx_wire) AND div2;
   rst_pdb <= rst_n AND div2;
   
   -- xdivby2
   
   xdiv2_2 : stratixiv_hssi_pma_c_divby2q
      PORT MAP (
         clk       => lfclkp,
         clkb      => lfclkn,
         clk0      => nc0,
         clk90     => nc1,
         vcce_la   => '1',
         vssexqyx  => '0',
         clk180    => lfclk_div2,
         clk270    => nc2,
         rst_n     => rst_nbuf
      );
   
   -- c_mux2to1_4xd - xi37 // clk_divtx is same as halfclk_p
   clk_divtx_wire <= lfclkp WHEN ((pclksel = '0') AND (div2 = '0')) ELSE
                     lfclk_div2 WHEN ((pclksel = '0') AND (div2 = '1')) ELSE
                     pclk_in WHEN ((pclksel = '1') AND (div2 = '0' OR div2 = '1')) ELSE
                     'X';
   
   -- Pipe #1
   PROCESS (clk_divtx_wire, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         d10a <=  TRANSPORT "0000000000" AFTER (PARAM_DELAY)*1 ps;
         d10b <=  TRANSPORT "0000000000" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (clk_divtx_wire'EVENT AND clk_divtx_wire = '1') THEN
         d10a <=  TRANSPORT a AFTER (PARAM_DELAY)*1 ps;
         d10b <=  TRANSPORT b AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   
   d10m <= d10b WHEN (sel = '1') ELSE
           d10a;
   
   -- Pipe #2
   -- Pipe #1 - synchronize data to lfclkp negedge
   PROCESS (lfclkp, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         d10 <=  TRANSPORT "0000000000" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (lfclkp'EVENT AND lfclkp = '1') THEN
         d10 <=  TRANSPORT d10m AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   -- Pipe #2 - Synchronize 0,2,4 and 1,3 to CLK and CLKB ; 6,8 and 5,7,9 to CLK and CLKB
   PROCESS (lfclkn, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         data_mux5t1_sync1 <=  TRANSPORT "0000000000" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (lfclkn'EVENT AND lfclkn = '1') THEN
         data_mux5t1_sync1 <=  TRANSPORT d10 AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (lfclkp, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         de_mux5t1_sync2(2 DOWNTO 0) <=  TRANSPORT "000" AFTER (PARAM_DELAY)*1 ps;
         do_mux5t1_sync2(1 DOWNTO 0) <=  TRANSPORT "00" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (lfclkp'EVENT AND lfclkp = '1') THEN
         de_mux5t1_sync2(2 DOWNTO 0) <=  TRANSPORT (data_mux5t1_sync1(4) & data_mux5t1_sync1(2) & data_mux5t1_sync1(0)) AFTER (PARAM_DELAY)*1 ps;
         do_mux5t1_sync2(1 DOWNTO 0) <=  TRANSPORT (data_mux5t1_sync1(3) & data_mux5t1_sync1(1)) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (lfclkn, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         de_mux5t1_sync2(4 DOWNTO 3) <=  TRANSPORT "00" AFTER (PARAM_DELAY)*1 ps;
         do_mux5t1_sync2(4 DOWNTO 2) <=  TRANSPORT "000" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (lfclkn'EVENT AND lfclkn = '1') THEN
         de_mux5t1_sync2(4 DOWNTO 3) <=  TRANSPORT (data_mux5t1_sync1(8) & data_mux5t1_sync1(6)) AFTER (PARAM_DELAY)*1 ps;
         do_mux5t1_sync2(4 DOWNTO 2) <=  TRANSPORT (data_mux5t1_sync1(9) & data_mux5t1_sync1(7) & data_mux5t1_sync1(5)) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   
   -- Pulse generation for odd and even - CPULSE, CP, C0, ..., C4
   --   always @ ( posedge hfclkp or negedge rst_nbuf ) // Mux Even 
   --     if ( hfclkp == 1'b1 ) 
   --       cp_even <= #(PARAM_DELAY) cpulse;
   --     else 
   --       cp_even <= #(PARAM_DELAY) 1'b0;
   
   PROCESS (hfclkn, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         c4_even <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         c3_even <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         c2_even <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         c1_even <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         c0_even <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSIF (hfclkn'EVENT AND hfclkn = '1') THEN
         c0_even <=  TRANSPORT cpulse AFTER (PARAM_DELAY)*1 ps;
         c1_even <=  TRANSPORT c0_even AFTER (PARAM_DELAY)*1 ps;
         c2_even <=  TRANSPORT c1_even AFTER (PARAM_DELAY)*1 ps;
         c3_even <=  TRANSPORT c2_even AFTER (PARAM_DELAY)*1 ps;
         IF (div5buf = '1') THEN
            c4_even <=  TRANSPORT c3_even AFTER (PARAM_DELAY)*1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   PROCESS (hfclkn, rst_nbuf)		-- Mux Odd
   BEGIN
      IF (rst_nbuf = '0') THEN
         cp_odd <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSIF (hfclkn'EVENT AND hfclkn = '1') THEN
         cp_odd <=  TRANSPORT cpulse AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (hfclkp, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         c4_odd <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         c3_odd <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         c2_odd <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         c1_odd <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         c0_odd <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSIF (hfclkp'EVENT AND hfclkp = '1') THEN
         c0_odd <=  TRANSPORT cp_odd AFTER (PARAM_DELAY)*1 ps;
         c1_odd <=  TRANSPORT c0_odd AFTER (PARAM_DELAY)*1 ps;
         c2_odd <=  TRANSPORT c1_odd AFTER (PARAM_DELAY)*1 ps;
         c3_odd <=  TRANSPORT c2_odd AFTER (PARAM_DELAY)*1 ps;
         IF (div5buf = '1') THEN
            c4_odd <=  TRANSPORT c3_odd AFTER (PARAM_DELAY)*1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   
   -- Mux2to1 Even outputs
   PROCESS (c0_even,c1_even,c2_even,c3_even,c4_even)
   BEGIN
      IF (c0_even = '1' AND c0_even'EVENT) THEN
         out_e <=  TRANSPORT de_mux5t1_sync2(0) AFTER (PARAM_DELAY)*1 ps;
      END IF;
      IF (c1_even = '1'AND c1_even'EVENT) THEN
         out_e <=  TRANSPORT de_mux5t1_sync2(1) AFTER (PARAM_DELAY)*1 ps;
      END IF;
      IF (c2_even = '1'AND c2_even'EVENT) THEN
         out_e <=  TRANSPORT de_mux5t1_sync2(2) AFTER (PARAM_DELAY)*1 ps;
      END IF;
      IF (c3_even = '1'AND c3_even'EVENT) THEN
         out_e <=  TRANSPORT de_mux5t1_sync2(3) AFTER (PARAM_DELAY)*1 ps;
      END IF;
      IF (c4_even = '1'AND c4_even'EVENT) THEN
         out_e <=  TRANSPORT de_mux5t1_sync2(4) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   
   -- Mux2to1 Odd outputs
   PROCESS (c0_odd,c1_odd,c2_odd,c3_odd,c4_odd)
   BEGIN
      IF (c0_odd = '1'AND c0_odd'EVENT) THEN
         out_o <=  TRANSPORT do_mux5t1_sync2(0) AFTER (PARAM_DELAY)*1 ps;
      END IF;
      IF (c1_odd = '1'AND c1_odd'EVENT) THEN
         out_o <=  TRANSPORT do_mux5t1_sync2(1) AFTER (PARAM_DELAY)*1 ps;
      END IF;
      IF (c2_odd = '1'AND c2_odd'EVENT) THEN
         out_o <=  TRANSPORT do_mux5t1_sync2(2) AFTER (PARAM_DELAY)*1 ps;
      END IF;
      IF (c3_odd = '1'AND c3_odd'EVENT) THEN
         out_o <=  TRANSPORT do_mux5t1_sync2(3) AFTER (PARAM_DELAY)*1 ps;
      END IF;
      IF (c4_odd = '1'AND c4_odd'EVENT) THEN
         out_o <=  TRANSPORT do_mux5t1_sync2(4) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   
   -- * * c_ser_mux2to1 -- xmux2to1 instance * *
   pe_pre <= pre_en_pretap AND rst_nbuf AND pdb;
   pe <= pre_en_out_xhdl0 AND rst_nbuf AND pdb;
   pe_2t <= pre_en_2t AND rst_nbuf AND pdb;
   
   vop_pre <= vop_pre_reg WHEN (pe_pre = '1') ELSE
              '1';
   von_pre <= von_pre_reg WHEN (pe_pre = '1') ELSE
              '1';
   vop <= vop_reg WHEN (pdb = '1') ELSE
          '1';
   von <= von_reg WHEN (pdb = '1') ELSE
          '1';
   vop_op1 <= vop_op1_reg WHEN (pe = '1') ELSE
              '1';
   von_op1 <= von_op1_reg WHEN (pe = '1') ELSE
              '1';
   vop_op2 <= vop_op2_reg WHEN (pe_2t = '1') ELSE
              '1';
   von_op2 <= von_op2_reg WHEN (pe_2t = '1') ELSE
              '1';
   
   -- FFs for OO & OE 1, 2 and 3 Generation
   PROCESS (hfclkn, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         oe3 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         oo2 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         oe1 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSIF (hfclkn'EVENT AND hfclkn = '1') THEN
         oe1 <=  TRANSPORT out_e AFTER (PARAM_DELAY)*1 ps;
         oo2 <=  TRANSPORT oo1 AFTER (PARAM_DELAY)*1 ps;
         oe3 <=  TRANSPORT oe2 AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (hfclkp, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         oo3 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         oe2 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         oo1 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSIF (hfclkp'EVENT AND hfclkp = '1') THEN
         oo1 <=  TRANSPORT out_o AFTER (PARAM_DELAY)*1 ps;
         oe2 <=  TRANSPORT oe1 AFTER (PARAM_DELAY)*1 ps;
         oo3 <=  TRANSPORT oo2 AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   
   -- FFs for VOP/N_PRE, VOP/N, VOP/N_OP1 and VOP/N_OP2 Outputs Generation 
   PROCESS (hfclkp,hfclkn)
   BEGIN
      IF ((hfclkp = '1' AND hfclkp'EVENT)AND pe_pre = '1') THEN
         vop_pre_reg <=  TRANSPORT out_o AFTER (PARAM_DELAY)*1 ps;
         von_pre_reg <=  TRANSPORT NOT(out_o) AFTER (PARAM_DELAY)*1 ps;
      END IF;
      IF ((hfclkn = '1' AND hfclkn'EVENT)AND pe_pre = '1') THEN
         vop_pre_reg <=  TRANSPORT out_e AFTER (PARAM_DELAY)*1 ps;
         von_pre_reg <=  TRANSPORT NOT(out_e) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (hfclkp,hfclkn)
   BEGIN
      IF ((hfclkp = '1' AND hfclkp'EVENT) AND pdb = '1') THEN
         vop_reg <=  TRANSPORT oe1 AFTER (PARAM_DELAY)*1 ps;
         von_reg <=  TRANSPORT NOT(oe1) AFTER (PARAM_DELAY)*1 ps;
      END IF;
      IF ((hfclkn = '1' AND hfclkn'EVENT) AND pdb = '1') THEN
         vop_reg <=  TRANSPORT oo1 AFTER (PARAM_DELAY)*1 ps;
         von_reg <=  TRANSPORT NOT(oo1) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   
   PROCESS (hfclkp,hfclkn)
   BEGIN
      IF ((hfclkp = '1' AND hfclkp'EVENT) AND pe = '1') THEN
         vop_op1_reg <=  TRANSPORT oo2 AFTER (PARAM_DELAY)*1 ps;
         von_op1_reg <=  TRANSPORT NOT(oo2) AFTER (PARAM_DELAY)*1 ps;
      END IF;
      IF ((hfclkn = '1' AND hfclkn'EVENT) AND pe = '1') THEN
         vop_op1_reg <=  TRANSPORT oe2 AFTER (PARAM_DELAY)*1 ps;
         von_op1_reg <=  TRANSPORT NOT(oe2) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (hfclkp,hfclkn)
   BEGIN
      IF ((hfclkp = '1' AND hfclkp'EVENT) AND pe_2t = '1') THEN
         vop_op2_reg <=  TRANSPORT oe3 AFTER (PARAM_DELAY)*1 ps;
         von_op2_reg <=  TRANSPORT NOT(oe3) AFTER (PARAM_DELAY)*1 ps;
      END IF;
      IF ((hfclkn = '1' AND hfclkn'EVENT) AND pe_2t = '1') THEN
         vop_op2_reg <=  TRANSPORT oo3 AFTER (PARAM_DELAY)*1 ps;
         von_op2_reg <=  TRANSPORT NOT(oo3) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   -- * * c_ser_mux2to1_lb -- xmux2to1_lb instance * *
   lben <= pdb AND s_lpbkbuf;
   lbvop <= out_lb_reg WHEN (lben = '1') ELSE
            '1';
   lbvon <= outb_lb_reg WHEN (lben = '1') ELSE
            '1';
   
   PROCESS (hfclkn,hfclkp)
   BEGIN
      IF ((hfclkn = '1' AND hfclkn'EVENT) AND lben = '1') THEN
         out_lb_reg <=  TRANSPORT out_e AFTER (PARAM_DELAY)*1 ps;
         outb_lb_reg <=  TRANSPORT NOT(out_e) AFTER (PARAM_DELAY)*1 ps;
      END IF;
      IF ((hfclkp = '1' AND hfclkp'EVENT) AND lben = '1') THEN
         out_lb_reg <=  TRANSPORT out_o AFTER (PARAM_DELAY)*1 ps;
         outb_lb_reg <=  TRANSPORT NOT(out_o) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_sdl_en_2x IS
   PORT (
      
      clk       : IN STD_LOGIC;
      d         : IN STD_LOGIC;
      db        : IN STD_LOGIC;
      en        : IN STD_LOGIC;
      
      vhdl_out  : OUT STD_LOGIC;
      outb      : OUT STD_LOGIC;
      vcce_la   : IN STD_LOGIC;
      vssex     : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_sdl_en_2x;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_sdl_en_2x IS
BEGIN
   
   PROCESS (en, clk)
   BEGIN
      IF ((NOT(en)) = '1') THEN
         vhdl_out <= '0';
         outb <= '1';
      ELSIF (clk'EVENT AND clk = '1') THEN
         vhdl_out <= d;
         outb <= db;
      END IF;
   END PROCESS;
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_rcv_detect_div_by_2 IS		-- synthesis syn_black_box
   PORT (
      CLK      : IN STD_LOGIC;
      RESET_N  : IN STD_LOGIC;
      CLKOUT   : OUT STD_LOGIC
   );
END stratixiv_hssi_pma_c_rcv_detect_div_by_2;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_rcv_detect_div_by_2 IS
   SIGNAL NEXT_VAL     : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL CLKOUT_xhdl0 : STD_LOGIC := '0';
BEGIN
   -- Drive referenced outputs
   CLKOUT <= CLKOUT_xhdl0;
   
   -- state definition
   PROCESS (CLK, RESET_N)
   BEGIN
      IF ((NOT(RESET_N)) = '1') THEN
         CLKOUT_xhdl0 <= '0';
      ELSIF (CLK'EVENT AND CLK = '1') THEN
         CLKOUT_xhdl0 <= NEXT_VAL;
      END IF;
   END PROCESS;
   
   NEXT_VAL <= NOT(CLKOUT_xhdl0);
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_rcv_detect_clk_gen IS
   PORT (
      CLK      : IN STD_LOGIC;
      RESET_N  : IN STD_LOGIC;
      CLKOUT   : OUT STD_LOGIC
   );
END stratixiv_hssi_pma_c_rcv_detect_clk_gen;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_rcv_detect_clk_gen IS
   COMPONENT stratixiv_hssi_pma_c_rcv_detect_div_by_2
      PORT (
         CLK      : IN STD_LOGIC;
         RESET_N  : IN STD_LOGIC;
         CLKOUT   : OUT STD_LOGIC
      );
   END COMPONENT;
   
   SIGNAL CLK8M        : STD_LOGIC;
   SIGNAL CLK4M        : STD_LOGIC;
   SIGNAL CLK2M        : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL CLKOUT_xhdl0 : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   CLKOUT <= CLKOUT_xhdl0;
   
   DIV_1 : stratixiv_hssi_pma_c_rcv_detect_div_by_2
      PORT MAP (
         CLK      => CLK,
         RESET_N  => RESET_N,
         CLKOUT   => CLK8M
      );
   
   DIV_2 : stratixiv_hssi_pma_c_rcv_detect_div_by_2
      PORT MAP (
         CLK      => CLK8M,
         RESET_N  => RESET_N,
         CLKOUT   => CLK4M
      );
   
   DIV_3 : stratixiv_hssi_pma_c_rcv_detect_div_by_2
      PORT MAP (
         CLK      => CLK4M,
         RESET_N  => RESET_N,
         CLKOUT   => CLK2M
      );
   
   DIV_4 : stratixiv_hssi_pma_c_rcv_detect_div_by_2
      PORT MAP (
         CLK      => CLK2M,
         RESET_N  => RESET_N,
         CLKOUT   => CLKOUT_xhdl0
      );
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_rcv_detect_sync IS		-- synthesis syn_black_box
   PORT (
      
      CLK          : IN STD_LOGIC;
      RESET_N      : IN STD_LOGIC;
      RCV_DET      : IN STD_LOGIC;
      RCV_DET_OUT  : OUT STD_LOGIC
   );
END stratixiv_hssi_pma_c_rcv_detect_sync;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_rcv_detect_sync IS
   SIGNAL RCV_DET_MID : STD_LOGIC;
BEGIN
   
   PROCESS (CLK, RESET_N)
   BEGIN
      IF ((NOT(RESET_N)) = '1') THEN
         RCV_DET_OUT <= '0';
         RCV_DET_MID <= '0';
      ELSIF (CLK'EVENT AND CLK = '1') THEN
         RCV_DET_OUT <= RCV_DET_MID;
         RCV_DET_MID <= RCV_DET;
      END IF;
   END PROCESS;
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_rcv_detect_fsm IS		-- synthesis syn_black_box
   GENERIC (
      
      RESET         : INTEGER := 0;
      WAKE          : INTEGER := 1;
      STATE_1       : INTEGER := 3;
      STATE_2       : INTEGER := 5;
      HOLD          : INTEGER := 4
   );
   PORT (
      CLK           : IN STD_LOGIC;
      RESET_N       : IN STD_LOGIC;
      COM_PASS      : IN STD_LOGIC;
      PROBE_PASS    : IN STD_LOGIC;
      
      DET_ON        : OUT STD_LOGIC;
      DETECT_VALID  : OUT STD_LOGIC;
      RCV_FOUND     : OUT STD_LOGIC;
      TX_DET_RX     : IN STD_LOGIC;
      RX_P          : IN STD_LOGIC;
      RX_N          : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_rcv_detect_fsm;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_rcv_detect_fsm IS
   SIGNAL STATE            : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL NEXTSTATE        : STD_LOGIC_VECTOR(2 DOWNTO 0) := int2bin(WAKE, 3);
   SIGNAL NEXT_RCV_FOUND   : STD_LOGIC := '0';
   
   SIGNAL FAKE_RCV_PRESENT : STD_LOGIC := '1' ;
   
   SIGNAL RXPN_NOT_Z       : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL RCV_FOUND_xhdl0  : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   RCV_FOUND <= RCV_FOUND_xhdl0;
   
   -- state definition
   
   -- manju : FAKE_RCV_PRESENT will always be '1' as no Denali models.
   --   assign    RXPN_NOT_Z = ( (RX_P == 1'b1) && (RX_N == 1'b1) || (RX_P == 1'b0) && (RX_N == 1'b0) ) ? 1'b1 : 1'b0; 
   
   
   --   always @ ( TX_DET_RX or RXPN_NOT_Z ) 
   --     if ( TX_DET_RX == 1'b1 && RXPN_NOT_Z == 1'b1 )
   --       FAKE_RCV_PRESENT <= 1'b1;
   --     else if ( TX_DET_RX == 1'b0 )
   --       FAKE_RCV_PRESENT <= 1'b0;
   
   -- State logic and FSM
   PROCESS (CLK, RESET_N)
   BEGIN
      IF ((NOT(RESET_N)) = '1') THEN
         STATE <= int2bin(RESET, 3);
      ELSIF (CLK'EVENT AND CLK = '1') THEN
         STATE <= NEXTSTATE;
      END IF;
   END PROCESS;
   
   PROCESS (STATE, COM_PASS)
   BEGIN
      CASE STATE IS
         WHEN "000" =>
            NEXTSTATE <= int2bin(WAKE, 3);
           WHEN "001" =>
            IF (COM_PASS = '1') THEN
               NEXTSTATE <= int2bin(STATE_1, 3);
            ELSE
               NEXTSTATE <= int2bin(WAKE, 3);
            END IF;
          WHEN "011" =>
            NEXTSTATE <= int2bin(STATE_2, 3);
          WHEN "101"=>
            NEXTSTATE <= int2bin(HOLD, 3);
           WHEN "100" =>
            NEXTSTATE <= int2bin(HOLD, 3);
         WHEN OTHERS =>		-- case(state)
            NEXTSTATE <= int2bin(RESET, 3);
      END CASE;
   END PROCESS;
   
   -- Output logic
   PROCESS (CLK, RESET_N)
   BEGIN
      IF ((NOT(RESET_N)) = '1') THEN
         RCV_FOUND_xhdl0 <= '0';
      ELSIF (CLK'EVENT AND CLK = '1') THEN
         RCV_FOUND_xhdl0 <= NEXT_RCV_FOUND;
      END IF;
   END PROCESS;
   
   PROCESS (NEXTSTATE, PROBE_PASS, FAKE_RCV_PRESENT)
   BEGIN
      IF ((NEXTSTATE = int2bin(STATE_2, 3)) AND ((NOT(PROBE_PASS))) = '1' AND FAKE_RCV_PRESENT = '1') THEN		-- probe pass goes up slow -> there is rx 
         NEXT_RCV_FOUND <= '1';
      ELSIF ((NEXTSTATE = int2bin(HOLD, 3)) AND FAKE_RCV_PRESENT = '1') THEN
         NEXT_RCV_FOUND <= RCV_FOUND_xhdl0;		-- probe pass goes up fast -> no rx
      ELSE
         NEXT_RCV_FOUND <= '0';
      END IF;
   END PROCESS;
   
   -- there is no rcv_det_syn
   PROCESS (STATE)
   BEGIN
      IF (STATE = int2bin(RESET, 3)) THEN
         DET_ON <= '0';
      ELSE
         DET_ON <= '1';
      END IF;
   END PROCESS;
   
   PROCESS (STATE)
   BEGIN
      IF (STATE = int2bin(HOLD, 3)) THEN
         DETECT_VALID <= '1';
      ELSE
         DETECT_VALID <= '0';
      END IF;
   END PROCESS;
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_rcv_detect_control IS
   PORT (
      CLK           : IN STD_LOGIC;
      RCV_DET_EN    : IN STD_LOGIC;
      RCV_DET_PDB   : IN STD_LOGIC;
      COM_PASS      : IN STD_LOGIC;
      PROBE_PASS    : IN STD_LOGIC;
      DET_ON        : OUT STD_LOGIC;
      DETECT_VALID  : OUT STD_LOGIC;
      RCV_FOUND     : OUT STD_LOGIC;
      RX_P          : IN STD_LOGIC;
      RX_N          : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_rcv_detect_control;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_rcv_detect_control IS
   COMPONENT stratixiv_hssi_pma_c_rcv_detect_fsm
      GENERIC (
         RESET         : INTEGER := 0;
         WAKE          : INTEGER := 1;
         STATE_1       : INTEGER := 3;
         STATE_2       : INTEGER := 5;
         HOLD          : INTEGER := 4
      );
      PORT (
         CLK           : IN STD_LOGIC;
         RESET_N       : IN STD_LOGIC;
         COM_PASS      : IN STD_LOGIC;
         PROBE_PASS    : IN STD_LOGIC;
         DET_ON        : OUT STD_LOGIC;
         DETECT_VALID  : OUT STD_LOGIC;
         RCV_FOUND     : OUT STD_LOGIC;
         TX_DET_RX     : IN STD_LOGIC;
         RX_P          : IN STD_LOGIC;
         RX_N          : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_c_rcv_detect_sync
      PORT (
         CLK           : IN STD_LOGIC;
         RESET_N       : IN STD_LOGIC;
         RCV_DET       : IN STD_LOGIC;
         RCV_DET_OUT   : OUT STD_LOGIC
      );
   END COMPONENT;
   
   SIGNAL RCV_DET_SYN        : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL DET_ON_xhdl1       : STD_LOGIC;
   SIGNAL DETECT_VALID_xhdl0 : STD_LOGIC;
   SIGNAL RCV_FOUND_xhdl2    : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   DET_ON <= DET_ON_xhdl1;
   DETECT_VALID <= DETECT_VALID_xhdl0;
   RCV_FOUND <= RCV_FOUND_xhdl2;
   
   
   XRCV_DET_SYNC : stratixiv_hssi_pma_c_rcv_detect_sync
      PORT MAP (
         CLK          => CLK,
         RESET_N      => RCV_DET_PDB,
         RCV_DET      => RCV_DET_EN,
         RCV_DET_OUT  => RCV_DET_SYN
      );
   
   XRCV_DET_FSM : stratixiv_hssi_pma_c_rcv_detect_fsm
      PORT MAP (
         CLK           => CLK,
         RESET_N       => RCV_DET_SYN,
         COM_PASS      => COM_PASS,
         PROBE_PASS    => PROBE_PASS,
         DET_ON        => DET_ON_xhdl1,
         DETECT_VALID  => DETECT_VALID_xhdl0,
         RCV_FOUND     => RCV_FOUND_xhdl2,
         TX_DET_RX     => RCV_DET_EN,
         RX_P          => RX_P,
         RX_N          => RX_N
      );
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_rcv_det_digital IS
   PORT (
      
      OSCCLK        : IN STD_LOGIC;
      RCV_DET_PDB   : IN STD_LOGIC;
      RCV_DET_EN    : IN STD_LOGIC;
      COM_PASS      : IN STD_LOGIC;
      PROBE_PASS    : IN STD_LOGIC;
      DET_ON        : OUT STD_LOGIC;
      DETECT_VALID  : OUT STD_LOGIC;
      RCV_FOUND     : OUT STD_LOGIC;
      RX_P          : IN STD_LOGIC;
      RX_N          : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_rcv_det_digital;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_rcv_det_digital IS
   COMPONENT stratixiv_hssi_pma_c_rcv_detect_control
      PORT (
         CLK           : IN STD_LOGIC;
         RCV_DET_EN    : IN STD_LOGIC;
         RCV_DET_PDB   : IN STD_LOGIC;
         COM_PASS      : IN STD_LOGIC;
         PROBE_PASS    : IN STD_LOGIC;
         DET_ON        : OUT STD_LOGIC;
         DETECT_VALID  : OUT STD_LOGIC;
         RCV_FOUND     : OUT STD_LOGIC;
         RX_P          : IN STD_LOGIC;
         RX_N          : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_c_rcv_detect_clk_gen
      PORT (
         CLK           : IN STD_LOGIC;
         RESET_N       : IN STD_LOGIC;
         CLKOUT        : OUT STD_LOGIC
      );
   END COMPONENT;
   
   SIGNAL CLK                : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL DET_ON_xhdl1       : STD_LOGIC;
   SIGNAL DETECT_VALID_xhdl0 : STD_LOGIC;
   SIGNAL RCV_FOUND_xhdl2    : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   DET_ON <= DET_ON_xhdl1;
   DETECT_VALID <= DETECT_VALID_xhdl0;
   RCV_FOUND <= RCV_FOUND_xhdl2;
   
   XCLK_GEN : stratixiv_hssi_pma_c_rcv_detect_clk_gen
      PORT MAP (
         CLK      => OSCCLK,
         RESET_N  => RCV_DET_PDB,
         CLKOUT   => CLK
      );
   
   XRCV_DET_CTRL : stratixiv_hssi_pma_c_rcv_detect_control
      PORT MAP (
         CLK           => CLK,
         RCV_DET_EN    => RCV_DET_EN,
         RCV_DET_PDB   => RCV_DET_PDB,
         COM_PASS      => COM_PASS,
         PROBE_PASS    => PROBE_PASS,
         DET_ON        => DET_ON_xhdl1,
         DETECT_VALID  => DETECT_VALID_xhdl0,
         RCV_FOUND     => RCV_FOUND_xhdl2,
         RX_P          => RX_P,
         RX_N          => RX_N
      );
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_rcv_detect IS
   GENERIC (
      RX_EXIST       : INTEGER := 1
   );
   PORT (
      com_pass       : OUT STD_LOGIC;
      detect_on      : OUT STD_LOGIC;
      fixed_clk_out  : OUT STD_LOGIC;
      probe_pass     : OUT STD_LOGIC;
      rcv_det_pdb    : IN STD_LOGIC;
      rdet           : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rx_det_clk     : IN STD_LOGIC;
      rx_det_valid   : OUT STD_LOGIC;
      rx_found       : OUT STD_LOGIC;
      sel_150r       : OUT STD_LOGIC;
      tx_det_rx      : IN STD_LOGIC;
      rx_n           : IN STD_LOGIC;
      rx_p           : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_rcv_detect;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_rcv_detect IS
   COMPONENT stratixiv_hssi_pma_c_rcv_det_digital
      PORT (
         OSCCLK         : IN STD_LOGIC;
         RCV_DET_PDB    : IN STD_LOGIC;
         RCV_DET_EN     : IN STD_LOGIC;
         COM_PASS       : IN STD_LOGIC;
         PROBE_PASS     : IN STD_LOGIC;
         DET_ON         : OUT STD_LOGIC;
         DETECT_VALID   : OUT STD_LOGIC;
         RCV_FOUND      : OUT STD_LOGIC;
         RX_P           : IN STD_LOGIC;
         RX_N           : IN STD_LOGIC
      );
   END COMPONENT;
   
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL com_pass_xhdl0     : STD_LOGIC;
   SIGNAL detect_on_xhdl1    : STD_LOGIC;
   SIGNAL probe_pass_xhdl2   : STD_LOGIC;
   SIGNAL rx_det_valid_xhdl3 : STD_LOGIC;
   SIGNAL rx_found_xhdl4     : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   com_pass <= com_pass_xhdl0;
   detect_on <= detect_on_xhdl1;
   probe_pass <= probe_pass_xhdl2;
   rx_det_valid <= rx_det_valid_xhdl3;
   rx_found <= rx_found_xhdl4;
   
   fixed_clk_out <= rx_det_clk;
   sel_150r <= '0';
   
   com_pass_xhdl0 <= transport detect_on_xhdl1 after 100 ns;
   probe_pass_xhdl2 <= NOT(int2bit(RX_EXIST));
   
   -- * * Analog portion not modeled * *
   
   XRCV_DET_DIGITAL : stratixiv_hssi_pma_c_rcv_det_digital
      PORT MAP (
         OSCCLK        => rx_det_clk,
         RCV_DET_PDB   => rcv_det_pdb,
         RCV_DET_EN    => tx_det_rx,
         COM_PASS      => com_pass_xhdl0,
         PROBE_PASS    => probe_pass_xhdl2,
         DET_ON        => detect_on_xhdl1,
         DETECT_VALID  => rx_det_valid_xhdl3,
         RCV_FOUND     => rx_found_xhdl4,
         RX_N          => rx_n,
         RX_P          => rx_p
      );
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;

   
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_tx IS
   PORT (
      
      atb0             : INOUT STD_LOGIC;
      atb1             : INOUT STD_LOGIC;
      bsmode           : IN STD_LOGIC;
      bstxn_in         : IN STD_LOGIC;
      bstxp_in         : IN STD_LOGIC;
      cgb_vccelxqyx    : IN STD_LOGIC;
      cgb_vssexqyx     : IN STD_LOGIC;
      
      com_pass         : OUT STD_LOGIC;
      detect_on        : OUT STD_LOGIC;
      fixed_clk_out    : OUT STD_LOGIC;
      ib50uc_rcvdt     : INOUT STD_LOGIC;
      ib50uc_vcm       : INOUT STD_LOGIC;
      ib50ut_vcm       : INOUT STD_LOGIC;
      ib100uc          : INOUT STD_LOGIC;
      lst              : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      pdb              : IN STD_LOGIC;
      probe_pass       : OUT STD_LOGIC;
      r_dft_sel        : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      r_dis_idlegate   : IN STD_LOGIC;
      r_highv          : IN STD_LOGIC;
      r_lowv           : IN STD_LOGIC;
      r_rx_det         : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      r_slew           : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rlpbkn           : IN STD_LOGIC;
      rlpbkn_em        : IN STD_LOGIC;
      rlpbkp           : IN STD_LOGIC;
      rlpbkp_em        : IN STD_LOGIC;
      rpre_em_1t       : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
      rpre_em_2t       : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      rpre_em_pt       : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      rsig_inv_2t      : IN STD_LOGIC;
      rsig_inv_ptap    : IN STD_LOGIC;
      rterm_sel        : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      rtx_rlpbk        : IN STD_LOGIC;
      rtx_vtt          : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rvod_sel         : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      rx_det_clk       : IN STD_LOGIC;
      rx_det_pdb       : IN STD_LOGIC;
      rx_detect_valid  : OUT STD_LOGIC;
      rx_found         : OUT STD_LOGIC;
      sel_150r         : OUT STD_LOGIC;
      tx50             : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      tx_det_rx        : IN STD_LOGIC;
      tx_dftout        : OUT STD_LOGIC_VECTOR(6 DOWNTO 1);
      tx_elec_idl      : IN STD_LOGIC;
      vccehtxqyx       : IN STD_LOGIC;
      vccehxqyx        : IN STD_LOGIC;
      vccesdh_la       : IN STD_LOGIC;
      vccesdp_la       : IN STD_LOGIC;
      vccetxqyx        : IN STD_LOGIC;
      vin              : IN STD_LOGIC;
      vin_po1          : IN STD_LOGIC;
      vin_po2          : IN STD_LOGIC;
      vin_pre          : IN STD_LOGIC;
      vip              : IN STD_LOGIC;
      vip_po1          : IN STD_LOGIC;
      vip_po2          : IN STD_LOGIC;
      vip_pre          : IN STD_LOGIC;
      von              : INOUT STD_LOGIC;
      vop              : INOUT STD_LOGIC;
      vssexqyx         : IN STD_LOGIC;
      rx_p             : IN STD_LOGIC;
      rx_n             : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_tx;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_tx IS
   COMPONENT stratixiv_hssi_pma_c_controller_4t16
      PORT (
         atben            : OUT STD_LOGIC;
         ct0              : IN STD_LOGIC;
         ct1              : IN STD_LOGIC;
         ct2              : IN STD_LOGIC;
         ct3              : IN STD_LOGIC;
         tmsb1            : OUT STD_LOGIC;
         tmsb2            : OUT STD_LOGIC;
         tmsb3            : OUT STD_LOGIC;
         tmsb4            : OUT STD_LOGIC;
         tmsb5            : OUT STD_LOGIC;
         tmsb6            : OUT STD_LOGIC;
         tmsb7            : OUT STD_LOGIC;
         tmsb8            : OUT STD_LOGIC;
         tmsb9            : OUT STD_LOGIC;
         tmsb10           : OUT STD_LOGIC;
         tmsb11           : OUT STD_LOGIC;
         tmsb12           : OUT STD_LOGIC;
         tmsb13           : OUT STD_LOGIC;
         tmsb14           : OUT STD_LOGIC;
         tmsb15           : OUT STD_LOGIC;
         vcce_la          : IN STD_LOGIC;
         vssex            : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_c_rcv_detect
      GENERIC (
         RX_EXIST         : INTEGER := 1
      );
      PORT (
         com_pass         : OUT STD_LOGIC;
         detect_on        : OUT STD_LOGIC;
         fixed_clk_out    : OUT STD_LOGIC;
         probe_pass       : OUT STD_LOGIC;
         rcv_det_pdb      : IN STD_LOGIC;
         rdet             : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rx_det_clk       : IN STD_LOGIC;
         rx_det_valid     : OUT STD_LOGIC;
         rx_found         : OUT STD_LOGIC;
         sel_150r         : OUT STD_LOGIC;
         tx_det_rx        : IN STD_LOGIC;
         rx_n             : IN STD_LOGIC;
         rx_p             : IN STD_LOGIC
      );
   END COMPONENT;
   
   
   SIGNAL atbsel                : STD_LOGIC_VECTOR(14 DOWNTO 0);
   SIGNAL atbi_0                : STD_LOGIC;
   SIGNAL atbi_1                : STD_LOGIC;
   SIGNAL vtp_1po               : STD_LOGIC;		-- not driven for now
   SIGNAL vtn_1po               : STD_LOGIC;
   SIGNAL vbiasp_cs             : STD_LOGIC;
   SIGNAL vbiasn_cs             : STD_LOGIC;
   SIGNAL vbiasp                : STD_LOGIC;
   SIGNAL vbiasn                : STD_LOGIC;
   SIGNAL vtp                   : STD_LOGIC;
   SIGNAL vtn                   : STD_LOGIC;
   SIGNAL vodselb               : STD_LOGIC_VECTOR(6 DOWNTO 1);
   SIGNAL vodsel_pdrv           : STD_LOGIC_VECTOR(6 DOWNTO 1);
   SIGNAL atben                 : STD_LOGIC;
   SIGNAL pre_em_2po            : STD_LOGIC_VECTOR(5 DOWNTO 1);
   SIGNAL pre_em_pre            : STD_LOGIC_VECTOR(5 DOWNTO 1);
   SIGNAL pre_em_1po            : STD_LOGIC_VECTOR(6 DOWNTO 1);
   SIGNAL po1_en_pdrvb          : STD_LOGIC;
   SIGNAL pre_en_pos            : STD_LOGIC;
   SIGNAL pre_en_neg            : STD_LOGIC;
   SIGNAL po2_en_pos            : STD_LOGIC;
   SIGNAL po2_en_neg            : STD_LOGIC;
   SIGNAL outpos_p              : STD_LOGIC;
   SIGNAL outpos_n              : STD_LOGIC;
   SIGNAL outneg_p              : STD_LOGIC;
   SIGNAL outneg_n              : STD_LOGIC;
   SIGNAL vopos_pd              : STD_LOGIC_VECTOR(5 DOWNTO 0);
   SIGNAL vopos_nd              : STD_LOGIC_VECTOR(5 DOWNTO 0);
   SIGNAL voneg_pd              : STD_LOGIC_VECTOR(5 DOWNTO 0);
   SIGNAL voneg_nd              : STD_LOGIC_VECTOR(5 DOWNTO 0);
   SIGNAL txden                 : STD_LOGIC;
   SIGNAL rlpbk_en              : STD_LOGIC;
   SIGNAL po1_rlpbk_en          : STD_LOGIC;
   SIGNAL po1_en                : STD_LOGIC;
   SIGNAL po2_en                : STD_LOGIC;
   SIGNAL pre_en                : STD_LOGIC;
   SIGNAL prepb_em_pre          : STD_LOGIC;
   SIGNAL pd_idl                : STD_LOGIC;
   SIGNAL tx_p                  : STD_LOGIC;
   SIGNAL tx_n                  : STD_LOGIC;
   SIGNAL vccbn1g               : STD_LOGIC;
   SIGNAL threshold             : STD_LOGIC;
   
   SIGNAL prep                  : STD_LOGIC;
   SIGNAL pren                  : STD_LOGIC;
   SIGNAL po1p                  : STD_LOGIC;
   SIGNAL po1n                  : STD_LOGIC;
   SIGNAL po2p                  : STD_LOGIC;
   SIGNAL po2n                  : STD_LOGIC;
   SIGNAL mainp                 : STD_LOGIC;
   SIGNAL mainn                 : STD_LOGIC;
   SIGNAL dec2t4_en             : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL vodsel                : STD_LOGIC_VECTOR(6 DOWNTO 1);
   -- X-HDL generated signals

   SIGNAL xhdl7 : STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL com_pass_xhdl0        : STD_LOGIC;
   SIGNAL detect_on_xhdl1       : STD_LOGIC;
   SIGNAL fixed_clk_out_xhdl2   : STD_LOGIC;
   SIGNAL probe_pass_xhdl3      : STD_LOGIC;
   SIGNAL rx_detect_valid_xhdl4 : STD_LOGIC;
   SIGNAL rx_found_xhdl5        : STD_LOGIC;
   SIGNAL sel_150r_xhdl6        : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   com_pass <= com_pass_xhdl0;
   detect_on <= detect_on_xhdl1;
   fixed_clk_out <= fixed_clk_out_xhdl2;
   probe_pass <= probe_pass_xhdl3;
   rx_detect_valid <= rx_detect_valid_xhdl4;
   rx_found <= rx_found_xhdl5;
   sel_150r <= sel_150r_xhdl6;
   
   -- ibias_ref & c_tx_vcm not modeled
   
   -- txgate_por
   atb0 <= atbi_0 WHEN (atben = '1') ELSE
           'Z';
   atb1 <= atbi_1 WHEN (atben = '1') ELSE
           'Z';
   
   xatb : stratixiv_hssi_pma_c_controller_4t16
      PORT MAP (
         atben    => atben,
         ct0      => lst(0),
         ct1      => lst(1),
         ct2      => lst(2),
         ct3      => lst(3),
         tmsb1    => atbsel(0),
         tmsb2    => atbsel(1),
         tmsb3    => atbsel(2),
         tmsb4    => atbsel(3),
         tmsb5    => atbsel(4),
         tmsb6    => atbsel(5),
         tmsb7    => atbsel(6),
         tmsb8    => atbsel(7),
         tmsb9    => atbsel(8),
         tmsb10   => atbsel(9),
         tmsb11   => atbsel(10),
         tmsb12   => atbsel(11),
         tmsb13   => atbsel(12),
         tmsb14   => atbsel(13),
         tmsb15   => atbsel(14),
         vcce_la  => '1',
         vssex    => '0'
      );
   
   -- * * C_TX_DRIVER * *
   
   -- txgate_por 
   atbi_0 <= vtp_1po WHEN ((atbsel(1)) = '1') ELSE
             'Z';
   atbi_0 <= vbiasp WHEN ((atbsel(0)) = '1') ELSE
             'Z';
   atbi_0 <= vbiasp_cs WHEN ((atbsel(2)) = '1') ELSE
             'Z';
   atbi_0 <= vtp WHEN ((atbsel(3)) = '1') ELSE
             'Z';
   atbi_1 <= vtn_1po WHEN ((atbsel(1)) = '1') ELSE
             'Z';
   atbi_1 <= vbiasn WHEN ((atbsel(0)) = '1') ELSE
             'Z';
   atbi_1 <= vbiasn_cs WHEN ((atbsel(2)) = '1') ELSE
             'Z';
   atbi_1 <= vtn WHEN ((atbsel(3)) = '1') ELSE
             'Z';
   
   -- -- c_tx_dec xtxdec --
   txden <= pdb AND NOT(tx_elec_idl) AND NOT(rtx_rlpbk);
   rlpbk_en <= pdb AND NOT(tx_elec_idl) AND rtx_rlpbk;
   po1_rlpbk_en <= reduction_or(rpre_em_1t) WHEN (rlpbk_en = '1') ELSE
                   '0';
   
   -- c_dec3t7 - xmp_decode
   vodselb <= NOT(vodsel);
   PROCESS (rvod_sel, pdb)
   BEGIN
      IF (pdb = '1') THEN
         CASE rvod_sel IS
            WHEN "000" =>
               vodsel <= "000000";
            WHEN "001" =>
               vodsel <= "000001";
            WHEN "010" =>
               vodsel <= "000011";
            WHEN "011" =>
               vodsel <= "000111";
            WHEN "100" =>
               vodsel <= "001111";
            WHEN "101" =>
               vodsel <= "011111";
            WHEN "110" =>
               vodsel <= "100011";
            WHEN "111" =>
               vodsel <= "100111";
            WHEN OTHERS =>
               vodsel <= "000000";
         END CASE;
      ELSE
         vodsel <= "000000";
      END IF;
   END PROCESS;
   
   
   -- c_dec5t5 - x1t_decode
   PROCESS (rpre_em_1t, pdb)
   BEGIN
      IF (pdb = '1') THEN
         CASE rpre_em_1t IS
            WHEN "00000" =>
               pre_em_1po <= "000000";
            WHEN "00001" =>
               pre_em_1po <= "000100";
            WHEN "00010" =>
               pre_em_1po <= "000101";
            WHEN "00011" =>
               pre_em_1po <= "000110";
            WHEN "00100" =>
               pre_em_1po <= "000111";
            WHEN "00101" =>
               pre_em_1po <= "001000";
            WHEN "00110" =>
               pre_em_1po <= "001001";
            
            WHEN "00111" =>
               pre_em_1po <= "001010";
            WHEN "01000" =>
               pre_em_1po <= "001011";
            WHEN "01001" =>
               pre_em_1po <= "001100";
            WHEN "01010" =>
               pre_em_1po <= "001101";
            WHEN "01011" =>
               pre_em_1po <= "001110";
            WHEN "01100" =>
               pre_em_1po <= "001111";
            WHEN "01101" =>
               pre_em_1po <= "010000";
            WHEN "01110" =>
               pre_em_1po <= "010001";
            
            WHEN "01111" =>
               pre_em_1po <= "010010";
            WHEN "10000" =>
               pre_em_1po <= "010011";
            WHEN "10001" =>
               pre_em_1po <= "010100";
            WHEN "10010" =>
               pre_em_1po <= "010101";
            WHEN "10011" =>
               pre_em_1po <= "010110";
            WHEN "10100" =>
               pre_em_1po <= "010111";
            WHEN "10101" =>
               pre_em_1po <= "011000";
            WHEN "10110" =>
               pre_em_1po <= "011010";
            
            WHEN "10111" =>
               pre_em_1po <= "011100";
            WHEN "11000" =>
               pre_em_1po <= "011110";
            WHEN "11001" =>
               pre_em_1po <= "110000";
            WHEN "11010" =>
               pre_em_1po <= "110010";
            WHEN "11011" =>
               pre_em_1po <= "110100";
            WHEN "11100" =>
               pre_em_1po <= "110110";
            WHEN "11101" =>
               pre_em_1po <= "111000";
            WHEN "11110" =>
               pre_em_1po <= "111100";
            
            WHEN "11111" =>
               pre_em_1po <= "111111";
            WHEN OTHERS =>
               pre_em_1po <= "000000";
         END CASE;
      ELSE
         pre_em_1po <= "000000";
      END IF;
   END PROCESS;
   
   
   -- x2t_decode 
   PROCESS (rpre_em_2t, pdb)
   BEGIN
      IF (pdb = '1') THEN
         IF (rpre_em_2t = "0000") THEN
            pre_em_2po(5 DOWNTO 1) <= "00000";
         ELSE
            pre_em_2po(5 DOWNTO 1) <= ('1' & rpre_em_2t);
         END IF;
      ELSE
         pre_em_2po <= "00000";
      END IF;
   END PROCESS;
   
   
   -- xpr_decode
   PROCESS (rpre_em_pt, pdb)
   BEGIN
      IF (pdb = '1') THEN
         IF (rpre_em_pt = "0000") THEN
            pre_em_pre(5 DOWNTO 1) <= "00000";
         ELSE
            pre_em_pre(5 DOWNTO 1) <= ('1' & rpre_em_pt);
         END IF;
      ELSE
         pre_em_pre <= "00000";
      END IF;
   END PROCESS;
   
   
   -- -- c_tx_testmux_dec --
   PROCESS (r_dft_sel)
   BEGIN
      CASE r_dft_sel IS
         WHEN "0--" =>
            dec2t4_en <= "0000";
         WHEN "100" =>
            dec2t4_en <= "0001";
         WHEN "101" =>
            dec2t4_en <= "0010";
         WHEN "110" =>
            dec2t4_en <= "0100";
         WHEN "111" =>
            dec2t4_en <= "1000";
         WHEN OTHERS =>
            dec2t4_en <= "0000";
      END CASE;
   END PROCESS;
   
   
   tx_dftout(6 DOWNTO 1) <= ('0' & pre_em_pre(5 DOWNTO 1)) WHEN (dec2t4_en(3) = '1') ELSE		-- used to be 6'bxxxxxx -- too pessimistic
                            ('0' & pre_em_2po(5 DOWNTO 1)) WHEN (dec2t4_en(2) = '1') ELSE
                            pre_em_1po(6 DOWNTO 1) WHEN (dec2t4_en(1) = '1') ELSE
                            vodsel(6 DOWNTO 1) WHEN (dec2t4_en(0) = '1') ELSE
                            "000000";
   
   -- -- c_tx_drv_buf xdrvbuf --
   vodsel_pdrv <= vodsel AND NOT(tx_elec_idl) & NOT(tx_elec_idl) & NOT(tx_elec_idl) & NOT(tx_elec_idl) & NOT(tx_elec_idl) & NOT(tx_elec_idl);
   
   -- -- c_tx_predrv xpredrv --
   pd_idl <= NOT(pdb) OR tx_elec_idl;
   
   -- xmain_tap_mux
   xhdl7 <= rlpbk_en & txden;
   PROCESS (txden, rlpbk_en, vip, vin, rlpbkp, rlpbkn)
   BEGIN
      CASE xhdl7 IS
         WHEN "00" =>
            mainp <= '0';
            mainn <= '1';
         WHEN "01" =>
            mainp <= vip;
            mainn <= vin;
         WHEN "10" =>
            mainp <= rlpbkp;
            mainn <= rlpbkn;
         WHEN "11" =>
            mainp <= 'X';
            mainn <= 'X';
         WHEN OTHERS =>
            mainp <= 'X';
            mainn <= 'X';
      END CASE;
   END PROCESS;
   
   
   -- xdrv0
   vopos_pd(0) <= mainp WHEN ((NOT(pd_idl)) = '1') ELSE		-- slew fct is not implemented
                  '1';
   vopos_nd(0) <= mainp WHEN ((NOT(pd_idl)) = '1') ELSE
                  '0';
   voneg_pd(0) <= mainn WHEN ((NOT(pd_idl)) = '1') ELSE
                  '1';
   voneg_nd(0) <= mainn WHEN ((NOT(pd_idl)) = '1') ELSE
                  '0';
   
   -- xdv_x6 - for driving strength
   vopos_pd(1) <= mainp WHEN ((vodsel_pdrv(1)) = '1') ELSE		-- slew fct is not implemelted
                  '1';
   vopos_nd(1) <= mainp WHEN ((vodsel_pdrv(1)) = '1') ELSE
                  '0';
   voneg_pd(1) <= mainn WHEN ((vodsel_pdrv(1)) = '1') ELSE
                  '1';
   voneg_nd(1) <= mainn WHEN ((vodsel_pdrv(1)) = '1') ELSE
                  '0';
   
   vopos_pd(2) <= mainp WHEN ((vodsel_pdrv(2)) = '1') ELSE
                  '1';
   vopos_nd(2) <= mainp WHEN ((vodsel_pdrv(2)) = '1') ELSE
                  '0';
   voneg_pd(2) <= mainn WHEN ((vodsel_pdrv(2)) = '1') ELSE
                  '1';
   voneg_nd(2) <= mainn WHEN ((vodsel_pdrv(2)) = '1') ELSE
                  '0';
   
   vopos_pd(3) <= mainp WHEN ((vodsel_pdrv(3)) = '1') ELSE
                  '1';
   vopos_nd(3) <= mainp WHEN ((vodsel_pdrv(3)) = '1') ELSE
                  '0';
   voneg_pd(3) <= mainn WHEN ((vodsel_pdrv(3)) = '1') ELSE
                  '1';
   voneg_nd(3) <= mainn WHEN ((vodsel_pdrv(3)) = '1') ELSE
                  '0';
   
   vopos_pd(4) <= mainp WHEN ((vodsel_pdrv(4)) = '1') ELSE
                  '1';
   vopos_nd(4) <= mainp WHEN ((vodsel_pdrv(4)) = '1') ELSE
                  '0';
   voneg_pd(4) <= mainn WHEN ((vodsel_pdrv(4)) = '1') ELSE
                  '1';
   voneg_nd(4) <= mainn WHEN ((vodsel_pdrv(4)) = '1') ELSE
                  '0';
   
   vopos_pd(5) <= mainp WHEN ((vodsel_pdrv(5)) = '1') ELSE
                  '1';
   vopos_nd(5) <= mainp WHEN ((vodsel_pdrv(5)) = '1') ELSE
                  '0';
   voneg_pd(5) <= mainn WHEN ((vodsel_pdrv(5)) = '1') ELSE
                  '1';
   voneg_nd(5) <= mainn WHEN ((vodsel_pdrv(5)) = '1') ELSE
                  '0';
   
   -- * * x1post_drv, x2post_drv and xpre_drv not implemented * *
   
   -- -- c_tx_drv xctxdrv --
   vop <= '1' WHEN ((NOT((reduction_and(voneg_pd))) AND NOT((reduction_and(voneg_nd)))) = '1') ELSE		-- 7 bits for driving strength - fct not implemented
          '0' WHEN (((reduction_or(voneg_pd)) AND (reduction_or(voneg_nd))) = '1') ELSE
          'Z' WHEN (((reduction_or(voneg_pd)) AND NOT((reduction_and(voneg_nd)))) = '1') ELSE
          '0' WHEN (tx_det_rx = '1') ELSE
          'X';
   von <= '1' WHEN ((NOT((reduction_and(vopos_pd))) AND NOT((reduction_and(vopos_nd)))) = '1') ELSE
          '0' WHEN (((reduction_or(vopos_pd)) AND (reduction_or(vopos_nd))) = '1') ELSE
          'Z' WHEN (((reduction_or(vopos_pd)) AND NOT((reduction_and(vopos_nd)))) = '1') ELSE
          '0' WHEN (tx_det_rx = '1') ELSE
          'X';
   
   -- * * C_RCV_DETECT * *
   tx_p <= vop;
   tx_n <= von;
   
   
   xi_rcv_det : stratixiv_hssi_pma_c_rcv_detect
      PORT MAP (
         com_pass       => com_pass_xhdl0,
         detect_on      => detect_on_xhdl1,
         fixed_clk_out  => fixed_clk_out_xhdl2,
         probe_pass     => probe_pass_xhdl3,
         rcv_det_pdb    => rx_det_pdb,
         rdet           => r_rx_det,
         rx_det_clk     => rx_det_clk,
         rx_det_valid   => rx_detect_valid_xhdl4,
         rx_found       => rx_found_xhdl5,
         sel_150r       => sel_150r_xhdl6,
         tx_det_rx      => tx_det_rx,
         rx_n           => rx_n,
         rx_p           => rx_p
      );
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;

   
LIBRARY ieee;
   USE ieee.std_logic_1164.all;
   USE ieee.std_logic_unsigned.all;

ENTITY stratixiv_hssi_pma_ppmdetect IS		-- MZ
   PORT (
      scan_mode      : IN STD_LOGIC;		-- MZ
      ppmsel         : IN STD_LOGIC_VECTOR(5 DOWNTO 0);		-- ppmsel setting      ppmsel=6'b100000 <=> +/- 1000 PPM
      --                     ppmsel=6'b010000 <=> +/- 500 PPM
      --                     ppmsel=6'b001000 <=> +/- 300 PPM
      --                     ppmsel=6'b000100 <=> +/- 200 PPM
      --                     ppmsel=6'b000010 <=> +/- 125 PPM
      --                     ppmsel=6'b000001 <=> +/- 100 PPM
      
      fref           : IN STD_LOGIC;		-- Reference clock
      fvcobyn        : IN STD_LOGIC;		-- VCO divided clock
      pd             : IN STD_LOGIC;		-- Power down
      -- CRAM: force freq_lock high
      -- CRAM: force freq_lock low
      hard_reset     : IN STD_LOGIC;		-- initialize all registers to one
      rforcehigh     : IN STD_LOGIC;
      rforcelow      : IN STD_LOGIC;
      -- reset ppm_cnt_latch register
      
      freq_lock      : OUT STD_LOGIC;		-- fref and fvcobyn are vhdl_in range, set by ppmsel
      ppm_cnt_latch  : OUT STD_LOGIC_VECTOR(6 DOWNTO 0);		-- PPM difference, can be sent off-chip via testmux
      ppm_cnt_reset  : IN STD_LOGIC
   );
END stratixiv_hssi_pma_ppmdetect;

ARCHITECTURE trans OF stratixiv_hssi_pma_ppmdetect IS
   
   SIGNAL ref_cnt                   : STD_LOGIC_VECTOR(15 DOWNTO 0);		-- 16-vhdl_bit counter using fref clock
   SIGNAL vco_cnt                   : STD_LOGIC_VECTOR(15 DOWNTO 0);		-- 16-vhdl_bit counter using fvcobyn clock
   SIGNAL eight_cnt                 : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- counter used to delay the 16-vhdl_bit counters reset by 8-cycles
   SIGNAL ppm_cnt                   : STD_LOGIC_VECTOR(6 DOWNTO 0);		-- 6-vhdl_bit counter used to count number of fref vhdl_in open windows
   SIGNAL stable2                   : STD_LOGIC;
   SIGNAL stable1                   : STD_LOGIC;
   SIGNAL stable0                   : STD_LOGIC;
   SIGNAL overflow_vco              : STD_LOGIC;
   SIGNAL overflow_vco1             : STD_LOGIC;
   SIGNAL overflow_vco2             : STD_LOGIC;
   SIGNAL freq_lock_pre             : STD_LOGIC;
   SIGNAL v65536v                   : STD_LOGIC;
   SIGNAL v65536r                   : STD_LOGIC;
   SIGNAL window0                   : STD_LOGIC;
   SIGNAL window1                   : STD_LOGIC;
   SIGNAL rst_div2                  : STD_LOGIC;
   SIGNAL rst_div1                  : STD_LOGIC;
   SIGNAL rst_div0                  : STD_LOGIC;
   SIGNAL stay                      : STD_LOGIC;
   SIGNAL rst_div_fref              : STD_LOGIC;		--exists to delay the release of ref_cnt by one cycle. This will reduce the 
   -- the time difference between the start of ref_cnt and vco_cnt after the
   -- release of rst_div. The time difference is due to rst_div being synchronized
   -- to fvcobyn from fref domain. ref_cnt start up immediately and vco_cnt starts
   -- 2 fvcobyn clock edges later. rst_div_fref will help reduce that 2 edge gap to
   -- 1 edge.
   
   SIGNAL eight_cnt_0               : STD_LOGIC;
   SIGNAL eight_cnt_4               : STD_LOGIC;
   SIGNAL eight_cnt_8               : STD_LOGIC;
   SIGNAL window                    : STD_LOGIC;
   SIGNAL pd_sync_fref              : STD_LOGIC;
   SIGNAL pd_sync_fvcobyn           : STD_LOGIC;
   SIGNAL hard_reset_inv            : STD_LOGIC;
   
   -- Inverting hard_reset because rxpma_rstb is active low
   
   SIGNAL pd_sync_fref_pre          : STD_LOGIC;		-- MZ
   SIGNAL pd_sync_fref_b4scanmux    : STD_LOGIC;
   SIGNAL pd_sync_fvcobyn_pre       : STD_LOGIC;
   SIGNAL pd_sync_fvcobyn_b4scanmux : STD_LOGIC;
   --Synchronize pd to fref
   -- MZ
   --Synchronize pd to fvcobyn
   -- MZ
   
   -- This piece of code creates flags that reset the 16-vhdl_bit counters, when they BOTH go 
   -- beyond 32768 (plus about 20 cycles) cycles. Before that they have to synchronized to
   -- relevant clock domains. This resetting has to happen because when the PPM difference
   -- is so low that the window vhdl_signal is less than a fref clock period, it will be missed
   -- and the counters will continue counting until it reaches all ONES. This is not desirable.
   SIGNAL overflow_ref              : STD_LOGIC;
   -- X-HDL generated signals

   SIGNAL xhdl0 : STD_LOGIC;
   SIGNAL xhdl1 : STD_LOGIC;
   SIGNAL xhdl2 : STD_LOGIC;
BEGIN
   eight_cnt_0 <= reduction_nor(eight_cnt);
   eight_cnt_4 <= NOT(eight_cnt(3)) AND eight_cnt(2) AND NOT(eight_cnt(1)) AND NOT(eight_cnt(0));
   eight_cnt_8 <= eight_cnt(3) AND NOT(eight_cnt(2)) AND NOT(eight_cnt(1)) AND NOT(eight_cnt(0));
   window <= v65536r XOR v65536v;
   hard_reset_inv <= NOT(hard_reset);
   PROCESS (hard_reset_inv, fref)
   BEGIN
      IF (hard_reset_inv = '1') THEN
         pd_sync_fref_pre <= '1';
         pd_sync_fref_b4scanmux <= '1';
      ELSIF (fref'EVENT AND fref = '1') THEN
         pd_sync_fref_pre <= pd;
         pd_sync_fref_b4scanmux <= pd_sync_fref_pre;
      END IF;
   END PROCESS;
   
   pd_sync_fref <= '0' WHEN (scan_mode = '1') ELSE
                   pd_sync_fref_b4scanmux;
   PROCESS (hard_reset_inv, fvcobyn)
   BEGIN
      IF (hard_reset_inv = '1') THEN
         pd_sync_fvcobyn_pre <= '1';
         pd_sync_fvcobyn_b4scanmux <= '1';
      ELSIF (fvcobyn'EVENT AND fvcobyn = '1') THEN
         pd_sync_fvcobyn_pre <= pd;
         pd_sync_fvcobyn_b4scanmux <= pd_sync_fvcobyn_pre;
      END IF;
   END PROCESS;
   
   pd_sync_fvcobyn <= '0' WHEN (scan_mode = '1') ELSE
                      pd_sync_fvcobyn_b4scanmux;
   xhdl0 <= '1' WHEN (ref_cnt > "1000000000010000") ELSE
                      '0';
   PROCESS (pd_sync_fref, fref)
   BEGIN
      IF (pd_sync_fref = '1') THEN
         overflow_ref <= '0';
      ELSIF (fref'EVENT AND fref = '1') THEN
         overflow_ref <= xhdl0;
      END IF;
   END PROCESS;
   
   xhdl1 <= '1' WHEN (vco_cnt > "1000000000010000") ELSE
                   '0';
   PROCESS (pd_sync_fvcobyn, fvcobyn)
   BEGIN
      IF (pd_sync_fvcobyn = '1') THEN
         overflow_vco <= '0';
      ELSIF (fvcobyn'EVENT AND fvcobyn = '1') THEN
         
         -- After power down is released, the counters start counting. One counter may start several
         -- thousand cycles after the other. So, after 128 cycles of fvcobyn, a vhdl_signal called "stable"
         -- is released. This will guarantee that fvcobyn was stable, before module operation started.
         overflow_vco <= xhdl1;
      END IF;
   END PROCESS;
   
   PROCESS (pd_sync_fvcobyn, fvcobyn)
   BEGIN
      IF (pd_sync_fvcobyn = '1') THEN
         stable0 <= '0';
      ELSIF (fvcobyn'EVENT AND fvcobyn = '1') THEN
         IF (vco_cnt(15 DOWNTO 0) = "0000000011111111") THEN
            
            --synchronize stable and overflow_vco to fref domain. "overflow_vco" will be used as one of the
            --cases when rst_div = 1
            stable0 <= '1';
         END IF;
      END IF;
   END PROCESS;
   
   PROCESS (pd_sync_fref, fref)
   BEGIN
      IF (pd_sync_fref = '1') THEN
         stable1 <= '0';
         stable2 <= '0';
         overflow_vco1 <= '0';
         overflow_vco2 <= '0';
      ELSIF (fref'EVENT AND fref = '1') THEN
         stable1 <= stable0;
         stable2 <= stable1;
         overflow_vco1 <= overflow_vco;
         overflow_vco2 <= overflow_vco1;
      END IF;
   END PROCESS;
   
   
   --synchronize rst_div to fvcobyn domain
   PROCESS (pd_sync_fvcobyn, fvcobyn)
   BEGIN
      IF (pd_sync_fvcobyn = '1') THEN
         rst_div1 <= '0';
         rst_div2 <= '0';
      ELSIF (fvcobyn'EVENT AND fvcobyn = '1') THEN
         rst_div1 <= rst_div0;
         rst_div2 <= rst_div1;
      END IF;
   END PROCESS;
   
   
   --window1 is set to HIGH if clocks  are stable ("stable2" = 1) and 
   --window1 can be HIGH only when the 8 counter is not counting down.
   PROCESS (pd_sync_fref, fref)
   BEGIN
      IF (pd_sync_fref = '1') THEN
         window0 <= '0';
         window1 <= '0';
      ELSIF (fref'EVENT AND fref = '1') THEN
         IF ((NOT(stable2)) = '1') THEN
            window0 <= '0';
            window1 <= '0';
         ELSE
            window1 <= window0;
            IF (eight_cnt_8 = '1') THEN
               window0 <= window;
            ELSE
               window0 <= '0';
            END IF;
         END IF;
      END IF;
   END PROCESS;
   
   
   -- fref and fvcobyn counter reset
   PROCESS (pd_sync_fref, fref)
   BEGIN
      IF (pd_sync_fref = '1') THEN
         rst_div0 <= '0';
         rst_div_fref <= '0';
      ELSIF (fref'EVENT AND fref = '1') THEN
         IF (((eight_cnt > "0000") AND (eight_cnt < "1000")) OR ((overflow_ref AND overflow_vco2)) = '1') THEN
            rst_div0 <= '1';
            rst_div_fref <= rst_div0;
         ELSE
            rst_div0 <= '0';
            rst_div_fref <= rst_div0;
         END IF;
      END IF;
   END PROCESS;
   
   
   --reset counters during PD_SYNC and during the clocking down of the 8 counter
   -- fref counter
   PROCESS (pd_sync_fref, fref)
   BEGIN
      IF (pd_sync_fref = '1') THEN
         ref_cnt <= "0000000000000000";
         v65536r <= '1';
      ELSIF (fref'EVENT AND fref = '1') THEN
         IF (rst_div_fref = '1') THEN
            ref_cnt <= "0000000000000000";
            v65536r <= '1';
         ELSE
            ref_cnt <= ref_cnt + "0000000000000001";		--ref_cnt[15] = 1 means 32,768 cycles have passed
            v65536r <= NOT((ref_cnt(15)));
         END IF;
      END IF;
   END PROCESS;
   
   
   -- fvcobyn counter
   PROCESS (pd_sync_fvcobyn, fvcobyn)
   BEGIN
      IF (pd_sync_fvcobyn = '1') THEN
         vco_cnt <= "0000000000000000";
         v65536v <= '1';
      ELSIF (fvcobyn'EVENT AND fvcobyn = '1') THEN
         IF (rst_div2 = '1') THEN
            vco_cnt <= "0000000000000000";
            v65536v <= '1';
         ELSE
            vco_cnt <= vco_cnt + "0000000000000001";		--vco_cnt[15] = 1 means 32,768 cycles have passed
            v65536v <= NOT((vco_cnt(15)));
         END IF;
      END IF;
   END PROCESS;
   
   
   -- count only after window ends. Then stop at 0 and reset to 8.
   -- "stay" there until window goes high and low again. STAY is HIGH from 
   -- when WINDOW1 is HIGH to when EIGHT_CNT is 0. 
   PROCESS (pd_sync_fref, fref)
   BEGIN
      IF (pd_sync_fref = '1') THEN
         eight_cnt <= "1000";
         stay <= '0';
      ELSIF (fref'EVENT AND fref = '1') THEN
         IF (eight_cnt_0 = '1') THEN
            eight_cnt <= "1000";
            stay <= '0';
         ELSIF ((window1 = '1') OR ((overflow_ref AND overflow_vco2)) = '1') THEN
            stay <= '1';
         ELSIF ((window1 = '0') AND (stay = '1')) THEN
            eight_cnt <= eight_cnt - "0001";
         END IF;
      END IF;
   END PROCESS;
   
   
   -- PPM counter
   -- using 6-vhdl_bit counter to acount for setting of more than 1000PPM
   -- starts counting when window starts, which is "upd_synctctr"
   -- stops counting when window ends, which is when 
   PROCESS (pd_sync_fref, fref)
   BEGIN
      IF (pd_sync_fref = '1') THEN
         ppm_cnt <= "0000000";		-- Avoiding the comparison after pd_sync
      ELSIF (fref'EVENT AND fref = '1') THEN
         IF (eight_cnt_0 = '1') THEN
            ppm_cnt <= "0000000";		-- If 
         ELSIF (ppm_cnt = "1111111") THEN
            ppm_cnt <= "1111111";		--Hold all Ones until eight_count_0
         ELSIF (window1 = '1') THEN		--If window has been opened by FREF or FVCOBYN
            ppm_cnt <= ppm_cnt + "0000001";
         END IF;
      END IF;
   END PROCESS;
   
   
   -- freq_lock_pre detection
   -- Perfom the comparison 4 clock cycles before reseting the 16-vhdl_bit counters
   -- ppmsel setting      ppmsel=6'b100000 <=> +/- 1000 PPM
   --                     ppmsel=6'b010000 <=> +/- 500 PPM
   --                     ppmsel=6'b001000 <=> +/- 300 PPM
   --                     ppmsel=6'b001001 <=> +/- 250 PPM
   --                     ppmsel=6'b000100 <=> +/- 200 PPM
   --                     ppmsel=6'b000010 <=> +/- 125 PPM
   --                     ppmsel=6'b000001 <=> +/- 100 PPM
   --                     ppmsel=6'b000011 <=> +/- 62.5 PPM
   --  +/- 1000 PPM
   --  +/- 500 PPM
   --  +/- 300 PPM
   --  +/- 250 PPM
   --  +/- 200 PPM
   --  +/- 125 PPM
   --  +/- 100 PPM
   xhdl2 <= '1' WHEN (((eight_cnt_4 = '1') AND (ppmsel = "100000") AND (ppm_cnt <= "1000011")) OR ((eight_cnt_4 = '1') AND (ppmsel = "010000") AND (ppm_cnt <= "0100010")) OR ((eight_cnt_4 = '1') AND (ppmsel = "001000") AND (ppm_cnt <= "0010101")) OR ((eight_cnt_4 = '1') AND (ppmsel = "001001") AND (ppm_cnt <= "0010010")) OR ((eight_cnt_4 = '1') AND (ppmsel = "000100") AND (ppm_cnt <= "0001111")) OR ((eight_cnt_4 = '1') AND (ppmsel = "000010") AND (ppm_cnt <= "0001010")) OR ((eight_cnt_4 = '1') AND (ppmsel = "000001") AND (ppm_cnt <= "0001000")) OR ((eight_cnt_4 = '1') AND (ppmsel = "000011") AND (ppm_cnt <= "0000110")) OR ((eight_cnt_4 = '1') AND (ppmsel = "111111"))) ELSE		--  +/- 62.5 PPM
              '0';
   PROCESS (pd_sync_fref, fref)
   BEGIN
      IF (pd_sync_fref = '1') THEN
         freq_lock_pre <= '0';
      ELSIF (fref'EVENT AND fref = '1') THEN
         IF (eight_cnt_4 = '1') THEN
            freq_lock_pre <= xhdl2;
         END IF;
      END IF;
   END PROCESS;
   
   
   PROCESS (pd_sync_fref, fref)
   BEGIN
      IF (pd_sync_fref = '1') THEN
         ppm_cnt_latch <= "0000000";
      ELSIF (fref'EVENT AND fref = '1') THEN
         IF (ppm_cnt_reset = '1') THEN
            ppm_cnt_latch <= "0000000";
         ELSIF (eight_cnt_4 = '1') THEN
            ppm_cnt_latch <= ppm_cnt;
         END IF;
      END IF;
   END PROCESS;
   
   
   --CRAM bits force HIGH or LOW on to freq_lock. This serves as module bypass.
   freq_lock <= '1' WHEN (rforcehigh = '1') ELSE
                '0' WHEN (rforcelow = '1') ELSE
                freq_lock_pre;
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;

   
LIBRARY ieee;
   USE ieee.std_logic_1164.all;
   USE ieee.std_logic_unsigned.all;

ENTITY stratixiv_hssi_pma_c_ser_10g IS
   GENERIC (
      
      PARAM_DELAY  : INTEGER := 0
   );
   PORT (
      
      clk_divtx    : OUT STD_LOGIC;
      clk_skew     : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      cpulse       : IN STD_LOGIC;
      cpulseb      : IN STD_LOGIC;
      data_in      : IN STD_LOGIC_VECTOR(63 DOWNTO 0);
      hfclkn       : IN STD_LOGIC;
      hfclkp       : IN STD_LOGIC;
      lbvon        : OUT STD_LOGIC;
      lbvop        : OUT STD_LOGIC;
      lfclkn       : IN STD_LOGIC;
      lfclkp       : IN STD_LOGIC;
      pdb          : IN STD_LOGIC;
      pre_em       : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
      rst_n        : IN STD_LOGIC;
      s_lpbk       : IN STD_LOGIC;
      vccelxqyx    : IN STD_LOGIC;
      vccetxqyx    : IN STD_LOGIC;
      von          : OUT STD_LOGIC;
      von_op1      : OUT STD_LOGIC;
      vop          : OUT STD_LOGIC;
      vop_op1      : OUT STD_LOGIC;
      vssexqyx     : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_ser_10g;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_ser_10g IS
   
   SIGNAL do8                  : STD_LOGIC_VECTOR(7 DOWNTO 0) := "00000000" ;
   SIGNAL core_clk             : STD_LOGIC;
   SIGNAL lfclkp_div_init_done : STD_LOGIC := '0' ;
   SIGNAL out_lb_reg           : STD_LOGIC := '0' ;
   SIGNAL outb_lb_reg          : STD_LOGIC := '1' ;
   SIGNAL out_e                : STD_LOGIC := '0' ;
   SIGNAL out_o                : STD_LOGIC := '0' ;
   SIGNAL data_mux4t1_sync1    : STD_LOGIC_VECTOR(7 DOWNTO 0) := "00000000" ;
   SIGNAL cpulse_x8_bus        : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL do_mux4t1_sync2      : STD_LOGIC_VECTOR(3 DOWNTO 0) := "0000" ;
   SIGNAL de_mux4t1_sync2      : STD_LOGIC_VECTOR(3 DOWNTO 0) := "0000" ;
   SIGNAL c0_even              : STD_LOGIC := '0' ;
   SIGNAL c1_even              : STD_LOGIC := '0' ;
   SIGNAL c2_even              : STD_LOGIC := '0' ;
   SIGNAL c3_even              : STD_LOGIC := '0' ;
   SIGNAL cp                   : STD_LOGIC := '0' ; -- initialization : manju
   SIGNAL cp_odd               : STD_LOGIC;
   SIGNAL c0_odd               : STD_LOGIC := '0' ;
   SIGNAL c1_odd               : STD_LOGIC := '0' ;
   SIGNAL c2_odd               : STD_LOGIC := '0' ;
   SIGNAL c3_odd               : STD_LOGIC := '0' ;
   SIGNAL cpulse_x8            : STD_LOGIC := '0' ; -- initialization : manju
   SIGNAL oo1                  : STD_LOGIC := '0' ;
   SIGNAL oe1                  : STD_LOGIC := '0' ;
   SIGNAL vop_reg              : STD_LOGIC := '0' ;
   SIGNAL von_reg              : STD_LOGIC := '1' ;
   SIGNAL vop_op1_reg          : STD_LOGIC := '0' ;
   SIGNAL von_op1_reg          : STD_LOGIC := '1' ;
   SIGNAL data_sync            : STD_LOGIC_VECTOR(63 DOWNTO 0) := "0000000000000000000000000000000000000000000000000000000000000000" ;
   SIGNAL do64                 : STD_LOGIC_VECTOR(63 DOWNTO 0) := "0000000000000000000000000000000000000000000000000000000000000000" ;
   
   SIGNAL lben                 : STD_LOGIC;
   SIGNAL pre_en               : STD_LOGIC;
   SIGNAL s_lpbkbuf            : STD_LOGIC;
   SIGNAL rst_nbuf             : STD_LOGIC;
   SIGNAL pe                   : STD_LOGIC;
   
   SIGNAL lfclkp_counter       : INTEGER := 0 ;
   -- X-HDL generated signals

   SIGNAL xhdl0 : STD_LOGIC_VECTOR(8 DOWNTO 0);
   SIGNAL xhdl1 : STD_LOGIC_VECTOR(8 DOWNTO 0);
BEGIN
   
   pre_en <= reduction_nor(pre_em);
   s_lpbkbuf <= pdb AND s_lpbk;
   rst_nbuf <= pdb AND rst_n;
   clk_divtx <= core_clk;
   
   xhdl0 <= "000000000";
   
   -- * * c_div8_10g * *
   PROCESS (lfclkp, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         lfclkp_counter <= 0;
         lfclkp_div_init_done <= '0';
         core_clk <= '0';
      ELSIF (lfclkp'EVENT AND lfclkp = '1') THEN
         -- after one cycle of lfclkp, if set, reset cpulse_x8
         IF (lfclkp = '1' AND cpulse_x8 = '1') THEN
            cpulse_x8 <= '0';
         END IF;
         IF (lfclkp_div_init_done = '0') THEN
            core_clk <= '1';
            lfclkp_div_init_done <= '1';
         ELSE
            -- generation of core_clk
            IF (lfclkp_counter MOD 4 = 0) THEN
               core_clk <= NOT(core_clk);
               IF (core_clk = '0') THEN
                  cpulse_x8 <= '1';
               END IF;
            END IF;
         END IF;
         lfclkp_counter <= lfclkp_counter + 1;
      END IF;
   END PROCESS;
   
   -- * * c_mux64to8_10g * *
   -- - cpulse_8x8_gen -
   xhdl1 <= "000000000";
   PROCESS (lfclkp, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
--         (cpulse_x8_bus(7 DOWNTO 0), cp) <=  TRANSPORT xhdl1 AFTER (PARAM_DELAY)*1 ps;
         cpulse_x8_bus(7 DOWNTO 0) <=  TRANSPORT xhdl1(8 downto 1) AFTER (PARAM_DELAY)*1 ps;
         cp <=  TRANSPORT xhdl1(0) AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (lfclkp'EVENT AND lfclkp = '1') THEN
--         (cpulse_x8_bus(7 DOWNTO 0), cp) <=  TRANSPORT (cpulse_x8_bus(6 DOWNTO 0) & cp & cpulse_x8) AFTER (PARAM_DELAY)*1 ps;
         cpulse_x8_bus(7 DOWNTO 0) <=  TRANSPORT (cpulse_x8_bus(6 DOWNTO 0) & cp) AFTER (PARAM_DELAY)*1 ps;
         cp <=  TRANSPORT (cpulse_x8) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   
   -- - c_64bit_reg_10g -
   PROCESS (core_clk)
   BEGIN
      IF (core_clk'EVENT AND core_clk = '1') THEN
         -- - c_32bit_reg_10g bits[63:32] -
         data_sync <=  TRANSPORT data_in AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (core_clk)
   BEGIN
      IF (core_clk'EVENT AND core_clk = '1') THEN
         -- - c_32bit_reg_10g bits[31:0] -
         do64(63 DOWNTO 32) <=  TRANSPORT data_sync(63 DOWNTO 32) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (core_clk)
   BEGIN
      IF (core_clk'EVENT AND core_clk = '0') THEN
         -- - a_8bit_tri_reg - 
         do64(31 DOWNTO 0) <=  TRANSPORT data_sync(31 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (cpulse_x8_bus, rst_nbuf)
   BEGIN
      IF ((NOT(rst_nbuf)) = '1') THEN
         do8 <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
      ELSE
         IF (cpulse_x8_bus(4)'EVENT AND cpulse_x8_bus(4) = '1') THEN
             do8 <=  TRANSPORT do64(7 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
         END IF;

         IF (cpulse_x8_bus(5)'EVENT AND cpulse_x8_bus(5) = '1') THEN
             do8 <=  TRANSPORT do64(15 DOWNTO 8) AFTER (PARAM_DELAY)*1 ps;
         END IF;

         IF (cpulse_x8_bus(6)'EVENT AND cpulse_x8_bus(6) = '1') THEN
             do8 <=  TRANSPORT do64(23 DOWNTO 16) AFTER (PARAM_DELAY)*1 ps;
         END IF;

         IF (cpulse_x8_bus(7)'EVENT AND cpulse_x8_bus(7) = '1') THEN
             do8 <=  TRANSPORT do64(31 DOWNTO 24) AFTER (PARAM_DELAY)*1 ps;
         END IF;
         
         IF (cpulse_x8_bus(0)'EVENT AND cpulse_x8_bus(0) = '1') THEN
             do8 <=  TRANSPORT do64(39 DOWNTO 32) AFTER (PARAM_DELAY)*1 ps;
         END IF;
          
         IF (cpulse_x8_bus(1)'EVENT AND cpulse_x8_bus(1) = '1') THEN
             do8 <=  TRANSPORT do64(47 DOWNTO 40) AFTER (PARAM_DELAY)*1 ps;
         END IF;
          
         IF (cpulse_x8_bus(2)'EVENT AND cpulse_x8_bus(2) = '1') THEN
             do8 <=  TRANSPORT do64(55 DOWNTO 48) AFTER (PARAM_DELAY)*1 ps;
         END IF;
         
         IF (cpulse_x8_bus(3)'EVENT AND cpulse_x8_bus(3) = '1') THEN
             do8 <=  TRANSPORT do64(63 DOWNTO 56) AFTER (PARAM_DELAY)*1 ps;
         END IF;
      END IF;
   END PROCESS;

   -- * * stratixiv_hssi_pma_c_ser_mux4to1 -- xmux4to1_even & odd instances * *
   -- Pipe #1 - synchronize data to lfclkp negedge
   PROCESS (lfclkn, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         data_mux4t1_sync1 <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (lfclkn'EVENT AND lfclkn = '1') THEN
         data_mux4t1_sync1 <=  TRANSPORT do8 AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   -- Pipe #2 - Synchronize 0,2 and 1,3 to CLK and CLKB ; 6,8 and 5,7 to CLK and CLKB
   PROCESS (lfclkp, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         de_mux4t1_sync2(1 DOWNTO 0) <=  TRANSPORT "00" AFTER (PARAM_DELAY)*1 ps;
         do_mux4t1_sync2(1 DOWNTO 0) <=  TRANSPORT "00" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (lfclkp'EVENT AND lfclkp = '1') THEN
         de_mux4t1_sync2(1 DOWNTO 0) <=  TRANSPORT (data_mux4t1_sync1(2) & data_mux4t1_sync1(0)) AFTER (PARAM_DELAY)*1 ps;
         do_mux4t1_sync2(1 DOWNTO 0) <=  TRANSPORT (data_mux4t1_sync1(3) & data_mux4t1_sync1(1)) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (lfclkn, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         de_mux4t1_sync2(3 DOWNTO 2) <=  TRANSPORT "00" AFTER (PARAM_DELAY)*1 ps;
         do_mux4t1_sync2(3 DOWNTO 2) <=  TRANSPORT "00" AFTER (PARAM_DELAY)*1 ps;
      ELSIF (lfclkn'EVENT AND lfclkn = '1') THEN
         de_mux4t1_sync2(3 DOWNTO 2) <=  TRANSPORT (data_mux4t1_sync1(6) & data_mux4t1_sync1(4)) AFTER (PARAM_DELAY)*1 ps;
         do_mux4t1_sync2(3 DOWNTO 2) <=  TRANSPORT (data_mux4t1_sync1(7) & data_mux4t1_sync1(5)) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   -- Pulse generation for odd and even - CPULSE, CP, C0, ..., C3
   PROCESS (hfclkn, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         c3_even <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         c2_even <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         c1_even <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         c0_even <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSIF (hfclkn'EVENT AND hfclkn = '1') THEN
         c0_even <=  TRANSPORT cpulse AFTER (PARAM_DELAY)*1 ps;
         c1_even <=  TRANSPORT c0_even AFTER (PARAM_DELAY)*1 ps;
         c2_even <=  TRANSPORT c1_even AFTER (PARAM_DELAY)*1 ps;
         c3_even <=  TRANSPORT c2_even AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   
   PROCESS (hfclkn, rst_nbuf)		-- Mux Odd
   BEGIN
      IF (rst_nbuf = '0') THEN
         cp_odd <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSIF (hfclkn'EVENT AND hfclkn = '1') THEN
         cp_odd <=  TRANSPORT cpulse AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (hfclkp, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         c3_odd <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         c2_odd <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         c1_odd <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         c0_odd <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSIF (hfclkp'EVENT AND hfclkp = '1') THEN
         c0_odd <=  TRANSPORT cp_odd AFTER (PARAM_DELAY)*1 ps;
         c1_odd <=  TRANSPORT c0_odd AFTER (PARAM_DELAY)*1 ps;
         c2_odd <=  TRANSPORT c1_odd AFTER (PARAM_DELAY)*1 ps;
         c3_odd <=  TRANSPORT c2_odd AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   
   -- Mux2to1 Even outputs
   PROCESS (c0_even, c1_even, c2_even, c3_even)
   BEGIN
      IF (c0_even'EVENT AND c0_even = '1') THEN
         out_e <=  TRANSPORT de_mux4t1_sync2(0) AFTER (PARAM_DELAY)*1 ps;
      END IF;

      IF (c1_even'EVENT AND c1_even = '1') THEN
         out_e <=  TRANSPORT de_mux4t1_sync2(1) AFTER (PARAM_DELAY)*1 ps;
      END IF;

      IF (c2_even'EVENT AND c2_even = '1') THEN
         out_e <=  TRANSPORT de_mux4t1_sync2(2) AFTER (PARAM_DELAY)*1 ps;
      END IF;

      IF (c3_even'EVENT AND c3_even = '1') THEN
         out_e <=  TRANSPORT de_mux4t1_sync2(3) AFTER (PARAM_DELAY)*1 ps;
      END IF;

   END PROCESS;
   
   -- Mux2to1 Odd outputs
   PROCESS (c0_odd, c1_odd, c2_odd, c3_odd)
   BEGIN
      IF (c0_odd'EVENT AND c0_odd = '1') THEN
         out_o <=  TRANSPORT do_mux4t1_sync2(0) AFTER (PARAM_DELAY)*1 ps;
      END IF;

      IF (c1_odd'EVENT AND c1_odd = '1') THEN
         out_o <=  TRANSPORT do_mux4t1_sync2(1) AFTER (PARAM_DELAY)*1 ps;
      END IF;

      IF (c2_odd'EVENT AND c2_odd = '1') THEN
         out_o <=  TRANSPORT do_mux4t1_sync2(2) AFTER (PARAM_DELAY)*1 ps;
      END IF;

      IF (c3_odd'EVENT AND c3_odd = '1') THEN
         out_o <=  TRANSPORT do_mux4t1_sync2(3) AFTER (PARAM_DELAY)*1 ps;
      END IF;

   END PROCESS;
   
   -- * * stratixiv_hssi_pma_c_ser_mux2to1 -- xmux2to1 instance * *
   pe <= pre_en AND rst_nbuf AND pdb;
   vop <= vop_reg WHEN (pdb = '1') ELSE
          '1';
   von <= von_reg WHEN (pdb = '1') ELSE
          '1';
   vop_op1 <= vop_op1_reg WHEN (pe = '1') ELSE
              '1';
   von_op1 <= von_op1_reg WHEN (pe = '1') ELSE
              '1';
   
   PROCESS (hfclkn, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         oe1 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSIF (hfclkn'EVENT AND hfclkn = '1') THEN
         oe1 <=  TRANSPORT out_e AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (hfclkp, rst_nbuf)
   BEGIN
      IF (rst_nbuf = '0') THEN
         oo1 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSIF (hfclkp'EVENT AND hfclkp = '1') THEN
         oo1 <=  TRANSPORT out_o AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (hfclkp, hfclkn)
   BEGIN
      IF (hfclkp'EVENT AND hfclkp = '1' AND pdb = '1') THEN
         vop_reg <=  TRANSPORT out_o AFTER (PARAM_DELAY)*1 ps;
         von_reg <=  TRANSPORT NOT(out_o) AFTER (PARAM_DELAY)*1 ps;
      END IF;
          
      IF (hfclkn'EVENT AND hfclkn = '1' AND pdb = '1') THEN
         vop_reg <=  TRANSPORT out_e AFTER (PARAM_DELAY)*1 ps;
         von_reg <=  TRANSPORT NOT(out_e) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (hfclkp, hfclkn)
   BEGIN
      IF (hfclkp'EVENT AND hfclkp = '1' AND pe = '1') THEN
         vop_op1_reg <=  TRANSPORT oe1 AFTER (PARAM_DELAY)*1 ps;
         von_op1_reg <=  TRANSPORT NOT(oe1) AFTER (PARAM_DELAY)*1 ps;
      END IF;
          
      IF (hfclkn'EVENT AND hfclkn = '1' AND pe = '1') THEN
         vop_op1_reg <=  TRANSPORT oo1 AFTER (PARAM_DELAY)*1 ps;
         von_op1_reg <=  TRANSPORT NOT(oo1) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   -- * * stratixiv_hssi_pma_c_ser_mux2to1_lb -- xmux2to1_lb instance * *
   lben <= pdb AND s_lpbkbuf;
   lbvop <= out_lb_reg WHEN (lben = '1') ELSE
            '1';
   lbvon <= outb_lb_reg WHEN (lben = '1') ELSE
            '1';
   
   PROCESS (hfclkn, hfclkp)
   BEGIN
      IF (hfclkn'EVENT AND hfclkn = '1' AND lben = '1') THEN
         out_lb_reg <=  TRANSPORT out_e AFTER (PARAM_DELAY)*1 ps;
         outb_lb_reg <=  TRANSPORT NOT(out_e) AFTER (PARAM_DELAY)*1 ps;
      END IF;
          
      IF (hfclkp'EVENT AND hfclkp = '1' AND lben = '1') THEN
         out_lb_reg <=  TRANSPORT out_o AFTER (PARAM_DELAY)*1 ps;
         outb_lb_reg <=  TRANSPORT NOT(out_o) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;
   USE ieee.std_logic_unsigned.all;

ENTITY stratixiv_hssi_pma_c_deser_10g IS
   GENERIC (
      
      PARAM_DELAY  : INTEGER := 0
   );
   PORT (
      clk90b       : IN STD_LOGIC;
      
      clk_divrx    : OUT STD_LOGIC;
      deser_pdb    : IN STD_LOGIC;
      deven        : IN STD_LOGIC;
      devenb       : IN STD_LOGIC;
      dodd         : IN STD_LOGIC;
      doddb        : IN STD_LOGIC;
      dout         : OUT STD_LOGIC_VECTOR(63 DOWNTO 0);
      rst_n        : IN STD_LOGIC;
      vcce_la      : IN STD_LOGIC;
      vssexqyx     : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_deser_10g;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_deser_10g IS
   
   SIGNAL clk90_counter        : INTEGER := 0 ;
   SIGNAL clk270_counter       : INTEGER := 0 ;
   SIGNAL ph2_counter          : INTEGER := 0 ;
   SIGNAL clk90_div_init_done  : STD_LOGIC := '0' ;
   SIGNAL clk90_div4           : STD_LOGIC := '0' ;
   SIGNAL clk270_div_init_done : STD_LOGIC := '0' ;
   SIGNAL clk270_div4          : STD_LOGIC := '0' ;
   SIGNAL ph2_div_init_done    : STD_LOGIC := '0' ;
   SIGNAL ph2_div8             : STD_LOGIC := '0' ;
   SIGNAL ph                   : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dsync                : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dp                   : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL doutp                : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL doutn                : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL ph8                  : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL dout_int             : STD_LOGIC_VECTOR(63 DOWNTO 0);
   SIGNAL dsync8               : STD_LOGIC_VECTOR(63 DOWNTO 0);
   
   SIGNAL clk90                : STD_LOGIC;
   SIGNAL clk270               : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL clk_divrx_xhdl0      : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   clk_divrx <= clk_divrx_xhdl0;
   
   clk90 <= NOT(clk90b);
   clk270 <= clk90b;
   
   -- * * c_deser_2to8_10g * * 
   
   -- - c_deser_divby4_10g -
   PROCESS (clk90, rst_n)
   BEGIN
      IF (rst_n = '0') THEN
         clk90_counter <= 0;
         clk90_div_init_done <= '0';
         clk90_div4 <= '0';
      ELSIF (clk90'EVENT AND clk90 = '1') THEN
         IF (clk90_div_init_done = '0') THEN
            clk90_div4 <= '1';
            clk90_div_init_done <= '1';
         ELSE
            -- generation of clk90_div4
            IF (clk90_counter MOD 2 = 0) THEN
               clk90_div4 <= NOT(clk90_div4);
            END IF;
         END IF;
         clk90_counter <= clk90_counter + 1;
      END IF;
   END PROCESS;
   
   
   -- clk270_div4 should not start toggling before clk90_div4
   PROCESS (clk270, rst_n)
   BEGIN
      IF (rst_n = '0') THEN
         clk270_counter <= 0;
         clk270_div_init_done <= '0';
         clk270_div4 <= '0';
      ELSE
         IF (clk90_div_init_done = '1') THEN
            -- generation of clk270_div4
            IF ((clk270 = '1') AND (clk270_counter MOD 4 = 0)) THEN
               IF (clk270_div_init_done = '0') THEN
                  clk270_div4 <= '1';
                  clk270_div_init_done <= '1';
               ELSE
                  clk270_div4 <= NOT(clk270_div4);
               END IF;
            END IF;
            clk270_counter <= clk270_counter + 1;
         END IF;
      END IF;
   END PROCESS;
   
   
   PROCESS (rst_n, clk270)
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         ph(3 DOWNTO 0) <=  TRANSPORT "0000" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (clk270'EVENT AND clk270 = '1') THEN
         
         -- - 1 to 4 demux -
         -- Shift register
         ph(3 DOWNTO 0) <=  TRANSPORT (ph(2 DOWNTO 0) & clk270_div4) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (rst_n, ph(0))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         dp(1 DOWNTO 0) <=  TRANSPORT "00" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph(0)'EVENT AND ph(0) = '1') THEN
         
         dp(1 DOWNTO 0) <=  TRANSPORT (dodd & deven) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (rst_n, ph(1))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         dp(3 DOWNTO 2) <=  TRANSPORT "00" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph(1)'EVENT AND ph(1) = '1') THEN
         
         dp(3 DOWNTO 2) <=  TRANSPORT (dodd & deven) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (rst_n, ph(2))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         dp(5 DOWNTO 4) <=  TRANSPORT "00" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph(2)'EVENT AND ph(2) = '1') THEN
         
         dp(5 DOWNTO 4) <=  TRANSPORT (dodd & deven) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (rst_n, ph(3))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         dp(7 DOWNTO 6) <=  TRANSPORT "00" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph(3)'EVENT AND ph(3) = '1') THEN
         
         -- dp[0,1,2,3] synchronization
         dp(7 DOWNTO 6) <=  TRANSPORT (dodd & deven) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (rst_n, ph(0))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         dsync(3 DOWNTO 0) <=  TRANSPORT "0000" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph(0)'EVENT AND ph(0) = '0') THEN
         
         dsync(3 DOWNTO 0) <=  TRANSPORT dp(3 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (rst_n, ph(0))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         doutp(7 DOWNTO 0) <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
          
         doutn(7 DOWNTO 0) <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph(0)'EVENT AND ph(0) = '1') THEN
         doutp(7 DOWNTO 0) <=  TRANSPORT (dp(7 DOWNTO 4) & dsync(3 DOWNTO 0)) AFTER (PARAM_DELAY)*1 ps;
          
         doutn(7 DOWNTO 0) <=  TRANSPORT NOT((dp(7 DOWNTO 4) & dsync(3 DOWNTO 0))) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   
   -- * * c_deser_8to64_10g * *
   
   -- - c_deser_divby8_10g - 
   PROCESS (ph(2), rst_n)
   BEGIN
      IF (rst_n = '0') THEN
         ph2_counter <= 0;
         ph2_div_init_done <= '0';
         ph2_div8 <= '0';
      ELSIF (ph(2)'EVENT AND ph(2) = '1') THEN
         IF (ph2_div_init_done = '0') THEN
            ph2_div8 <= '1';
            ph2_div_init_done <= '1';
         ELSE
            -- generation of ph2_div8
            IF (ph2_counter MOD 4 = 0) THEN
               ph2_div8 <= NOT(ph2_div8);
            END IF;
         END IF;
         ph2_counter <= ph2_counter + 1;
      END IF;
   END PROCESS;
   
   
   PROCESS (rst_n, ph(2))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         ph8(7 DOWNTO 0) <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph(2)'EVENT AND ph(2) = '1') THEN
         
         -- - c_deser_by8_8_10g -
         ph8(7 DOWNTO 0) <=  TRANSPORT (ph8(6 DOWNTO 0) & ph2_div8) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   clk_divrx_xhdl0 <= ph8(0);
   
   PROCESS (rst_n, ph8(0))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         dout_int(7 DOWNTO 0) <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph8(0)'EVENT AND ph8(0) = '1') THEN
         
         dout_int(7 DOWNTO 0) <=  TRANSPORT doutp(7 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (rst_n, ph8(1))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         dout_int(15 DOWNTO 8) <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph8(1)'EVENT AND ph8(1) = '1') THEN
         
         dout_int(15 DOWNTO 8) <=  TRANSPORT doutp(7 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (rst_n, ph8(2))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         dout_int(23 DOWNTO 16) <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph8(2)'EVENT AND ph8(2) = '1') THEN
         
         dout_int(23 DOWNTO 16) <=  TRANSPORT doutp(7 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (rst_n, ph8(3))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         dout_int(31 DOWNTO 24) <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph8(3)'EVENT AND ph8(3) = '1') THEN
         
         dout_int(31 DOWNTO 24) <=  TRANSPORT doutp(7 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (rst_n, ph8(4))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         dout_int(39 DOWNTO 32) <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph8(4)'EVENT AND ph8(4) = '1') THEN
         
         dout_int(39 DOWNTO 32) <=  TRANSPORT doutp(7 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (rst_n, ph8(5))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         dout_int(47 DOWNTO 40) <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph8(5)'EVENT AND ph8(5) = '1') THEN
         
         dout_int(47 DOWNTO 40) <=  TRANSPORT doutp(7 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (rst_n, ph8(6))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         dout_int(55 DOWNTO 48) <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph8(6)'EVENT AND ph8(6) = '1') THEN
         
         dout_int(55 DOWNTO 48) <=  TRANSPORT doutp(7 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (rst_n, ph8(7))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         dout_int(63 DOWNTO 56) <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph8(7)'EVENT AND ph8(7) = '1') THEN
         
         dout_int(63 DOWNTO 56) <=  TRANSPORT doutp(7 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (rst_n, ph8(7))
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         dsync8(7 DOWNTO 0) <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
          
         dsync8(15 DOWNTO 8) <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
          
         dsync8(23 DOWNTO 16) <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
          
         dsync8(31 DOWNTO 24) <=  TRANSPORT "00000000" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (ph8(7)'EVENT AND ph8(7) = '1') THEN
         dsync8(7 DOWNTO 0) <=  TRANSPORT dout_int(7 DOWNTO 0) AFTER (PARAM_DELAY)*1 ps;
          
         dsync8(15 DOWNTO 8) <=  TRANSPORT dout_int(15 DOWNTO 8) AFTER (PARAM_DELAY)*1 ps;
          
         dsync8(23 DOWNTO 16) <=  TRANSPORT dout_int(23 DOWNTO 16) AFTER (PARAM_DELAY)*1 ps;
          
         dsync8(31 DOWNTO 24) <=  TRANSPORT dout_int(31 DOWNTO 24) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   
   PROCESS (rst_n, clk_divrx_xhdl0)
   BEGIN
      IF ((NOT(rst_n)) = '1') THEN
         dout(63 DOWNTO 0) <=  TRANSPORT "0000000000000000000000000000000000000000000000000000000000000000" AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (clk_divrx_xhdl0'EVENT AND clk_divrx_xhdl0 = '1') THEN
         
         dout(63 DOWNTO 0) <=  TRANSPORT (dout_int(63 DOWNTO 32) & dsync8(31 DOWNTO 0)) AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   
END trans;



Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;
   USE ieee.std_logic_unsigned.all;

ENTITY stratixiv_hssi_pma_c_clkgendrv_tx10g IS
   PORT (
      
      clk0       : IN STD_LOGIC;
      clk180     : IN STD_LOGIC;
      cpulse     : OUT STD_LOGIC;
      cpulseb    : OUT STD_LOGIC;
      hfclk_n    : OUT STD_LOGIC;
      hfclk_p    : OUT STD_LOGIC;
      lfclk_n    : OUT STD_LOGIC;
      lfclk_p    : OUT STD_LOGIC;
      rst_n      : IN STD_LOGIC;
      vccelxqyx  : IN STD_LOGIC;
      vssexqyx   : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_clkgendrv_tx10g;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_clkgendrv_tx10g IS
   
   COMPONENT stratixiv_hssi_pma_c_clkgendrv
   PORT (
      clk0       : IN STD_LOGIC;
      clk90      : IN STD_LOGIC;
      clk180     : IN STD_LOGIC;
      clk270     : IN STD_LOGIC;
      
      cpulse     : OUT STD_LOGIC;
      cpulseb    : OUT STD_LOGIC;
      cpulseo    : OUT STD_LOGIC;
      div5       : IN STD_LOGIC;
      hfclk_n    : OUT STD_LOGIC;
      hfclk_p    : OUT STD_LOGIC;
      lfclk_n    : OUT STD_LOGIC;
      lfclk_p    : OUT STD_LOGIC;
      rst_n      : IN STD_LOGIC;
      vccelxqyx  : IN STD_LOGIC;
      vssexqyx   : IN STD_LOGIC
   );
   END COMPONENT;

   SIGNAL nc2           : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL cpulse_xhdl0  : STD_LOGIC;
   SIGNAL cpulseb_xhdl1 : STD_LOGIC;
   SIGNAL hfclk_n_xhdl2 : STD_LOGIC;
   SIGNAL hfclk_p_xhdl3 : STD_LOGIC;
   SIGNAL lfclk_n_xhdl4 : STD_LOGIC;
   SIGNAL lfclk_p_xhdl5 : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   cpulse <= cpulse_xhdl0;
   cpulseb <= cpulseb_xhdl1;
   hfclk_n <= hfclk_n_xhdl2;
   hfclk_p <= hfclk_p_xhdl3;
   lfclk_n <= lfclk_n_xhdl4;
   lfclk_p <= lfclk_p_xhdl5;
   
   
   
   xdrv : stratixiv_hssi_pma_c_clkgendrv
      PORT MAP (
         clk0       => clk0,
         clk90      => '0',
         clk180     => clk180,
         clk270     => '1',
         cpulse     => cpulse_xhdl0,
         cpulseb    => cpulseb_xhdl1,
         cpulseo    => nc2,
         div5       => '0',
         hfclk_n    => hfclk_n_xhdl2,
         hfclk_p    => hfclk_p_xhdl3,
         lfclk_n    => lfclk_n_xhdl4,
         lfclk_p    => lfclk_p_xhdl5,
         rst_n      => rst_n,
         vccelxqyx  => vccelxqyx,
         vssexqyx   => vssexqyx
      );
   
END trans;


Library work;
USE work.stratixiv_hssi_components.all;
LIBRARY ieee;
   USE ieee.std_logic_1164.all;

ENTITY stratixiv_hssi_pma_c_clkgenbuf_tx10g IS
   PORT (
      clk0_in      : IN STD_LOGIC;
      clk180_in    : IN STD_LOGIC;
      cpulse       : OUT STD_LOGIC;
      cpulseb      : OUT STD_LOGIC;
      hfclk_n      : OUT STD_LOGIC;
      hfclk_p      : OUT STD_LOGIC;
      lfclk_n      : OUT STD_LOGIC;
      lfclk_p      : OUT STD_LOGIC;
      rst_n        : IN STD_LOGIC;
      vccelxqyx    : IN STD_LOGIC;
      vssexqyx     : IN STD_LOGIC
   );
END stratixiv_hssi_pma_c_clkgenbuf_tx10g;

ARCHITECTURE trans OF stratixiv_hssi_pma_c_clkgenbuf_tx10g IS
   COMPONENT stratixiv_hssi_pma_c_clkgendrv_tx10g
      PORT (
         clk0         : IN STD_LOGIC;
         clk180       : IN STD_LOGIC;
         cpulse       : OUT STD_LOGIC;
         cpulseb      : OUT STD_LOGIC;
         hfclk_n      : OUT STD_LOGIC;
         hfclk_p      : OUT STD_LOGIC;
         lfclk_n      : OUT STD_LOGIC;
         lfclk_p      : OUT STD_LOGIC;
         rst_n        : IN STD_LOGIC;
         vccelxqyx    : IN STD_LOGIC;
         vssexqyx     : IN STD_LOGIC
      );
   END COMPONENT;
   
   SIGNAL clk0_out      : STD_LOGIC;
   SIGNAL clk180_out    : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL cpulse_xhdl0  : STD_LOGIC;
   SIGNAL cpulseb_xhdl1 : STD_LOGIC;
   SIGNAL hfclk_n_xhdl2 : STD_LOGIC;
   SIGNAL hfclk_p_xhdl3 : STD_LOGIC;
   SIGNAL lfclk_n_xhdl4 : STD_LOGIC;
   SIGNAL lfclk_p_xhdl5 : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   cpulse <= cpulse_xhdl0;
   cpulseb <= cpulseb_xhdl1;
   hfclk_n <= hfclk_n_xhdl2;
   hfclk_p <= hfclk_p_xhdl3;
   lfclk_n <= lfclk_n_xhdl4;
   lfclk_p <= lfclk_p_xhdl5;
   
   clk0_out <= clk0_in;
   clk180_out <= clk180_in;
   
   
   
   xdrv : stratixiv_hssi_pma_c_clkgendrv_tx10g
      PORT MAP (
         clk0       => clk0_out,
         clk180     => clk180_out,
         cpulse     => cpulse_xhdl0,
         cpulseb    => cpulseb_xhdl1,
         hfclk_n    => hfclk_n_xhdl2,
         hfclk_p    => hfclk_p_xhdl3,
         lfclk_n    => lfclk_n_xhdl4,
         lfclk_p    => lfclk_p_xhdl5,
         rst_n      => rst_n,
         vccelxqyx  => vccelxqyx,
         vssexqyx   => vssexqyx
      );
   
END trans;

--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = io_buf_tri 264 lut 176 mux21 86 tri_bus 62 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_pma_c_adce IS 
	 PORT 
	 ( 
		 adapt_capture	:	IN  STD_LOGIC;
		 adapt_done	:	OUT  STD_LOGIC;
		 atb0	:	INOUT  STD_LOGIC;
		 atb1	:	INOUT  STD_LOGIC;
		 atb_0	:	INOUT  STD_LOGIC;
		 atb_1	:	INOUT  STD_LOGIC;
		 atben	:	IN  STD_LOGIC;
		 atbsel	:	IN  STD_LOGIC_VECTOR (23 DOWNTO 0);
		 e_clk	:	OUT  STD_LOGIC;
		 eqa_ctrl	:	OUT  STD_LOGIC;
		 eqa_set	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 eqb_ctrl	:	OUT  STD_LOGIC;
		 eqb_set	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 eqc_ctrl	:	OUT  STD_LOGIC;
		 eqc_set	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 eqctrlout	:	OUT  STD_LOGIC_VECTOR (5 DOWNTO 0);
		 eqd_ctrl	:	OUT  STD_LOGIC;
		 eqd_set	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 eqin_n	:	IN  STD_LOGIC;
		 eqin_p	:	IN  STD_LOGIC;
		 eqv_ctrl	:	OUT  STD_LOGIC;
		 eqv_set	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 fine_d2aout	:	OUT  STD_LOGIC;
		 fixed_clk	:	IN  STD_LOGIC;
		 hf_adapt_done	:	OUT  STD_LOGIC;
		 hfclk_macro	:	OUT  STD_LOGIC;
		 hfmac_cnt0_nclr	:	OUT  STD_LOGIC;
		 hfmac_cnt2_nclr	:	OUT  STD_LOGIC;
		 ib50u_c	:	INOUT  STD_LOGIC;
		 ib50u_t	:	INOUT  STD_LOGIC;
		 ibrgen1	:	OUT  STD_LOGIC;
		 ibrgen2	:	OUT  STD_LOGIC;
		 lf_adapt_done	:	OUT  STD_LOGIC;
		 lfclk_macro	:	OUT  STD_LOGIC;
		 lfmac_cnt0_nclr	:	OUT  STD_LOGIC;
		 lfmac_cnt2_nclr	:	OUT  STD_LOGIC;
		 lock_lf_ovd	:	IN  STD_LOGIC;
		 lst	:	IN  STD_LOGIC_VECTOR (4 DOWNTO 0);
		 outeqn	:	INOUT  STD_LOGIC;
		 outeqp	:	INOUT  STD_LOGIC;
		 r_clk	:	OUT  STD_LOGIC;
		 radce_adapt	:	IN  STD_LOGIC;
		 radce_digital	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 radce_hflck	:	IN  STD_LOGIC_VECTOR (14 DOWNTO 0);
		 radce_lflck	:	IN  STD_LOGIC_VECTOR (14 DOWNTO 0);
		 radce_pdb	:	IN  STD_LOGIC;
		 radce_rstb	:	IN  STD_LOGIC;
		 radce_vod_int	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 radce_vod_lsb	:	IN  STD_LOGIC;
		 rbit_dc	:	IN  STD_LOGIC;
		 rclkdiv	:	IN  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 rd2a_res	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rdc_freq	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rdfe_en	:	IN  STD_LOGIC;
		 rf_hpf	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rf_lpf	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rgenctrlout	:	OUT  STD_LOGIC_VECTOR (5 DOWNTO 0);
		 rhf_os	:	IN  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 rhyst_hf	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 rhyst_lf	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 rlf_os	:	IN  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 rrect_adj	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rrgen_bw	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rrgen_set	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 rrgen_vod	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 rseq_sel	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 standby	:	IN  STD_LOGIC;
		 tmxselan	:	OUT  STD_LOGIC;
		 tmxselbn	:	OUT  STD_LOGIC;
		 tmxselcn	:	OUT  STD_LOGIC;
		 tmxseldn	:	OUT  STD_LOGIC;
		 tmxselvn	:	OUT  STD_LOGIC;
		 updnn_hf	:	OUT  STD_LOGIC;
		 updnn_lf	:	OUT  STD_LOGIC;
		 vbn	:	IN  STD_LOGIC;
		 vccehxqyx	:	INOUT  STD_LOGIC;
		 vccerxqyx	:	INOUT  STD_LOGIC;
		 vctl_quiet	:	INOUT  STD_LOGIC;
		 vssexqyx	:	INOUT  STD_LOGIC
	 ); 
 END stratixiv_hssi_pma_c_adce;

 ARCHITECTURE RTL OF stratixiv_hssi_pma_c_adce IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 n0i0il69	:	STD_LOGIC := '0';
	 SIGNAL	 n0i0il70	:	STD_LOGIC := '0';
	 SIGNAL	 n0i0iO67	:	STD_LOGIC := '0';
	 SIGNAL	 n0i0iO68	:	STD_LOGIC := '0';
	 SIGNAL	 n0i0ll65	:	STD_LOGIC := '0';
	 SIGNAL	 n0i0ll66	:	STD_LOGIC := '0';
	 SIGNAL	 n0i0lO63	:	STD_LOGIC := '0';
	 SIGNAL	 n0i0lO64	:	STD_LOGIC := '0';
	 SIGNAL	 n0i10O79	:	STD_LOGIC := '0';
	 SIGNAL	 n0i10O80	:	STD_LOGIC := '0';
	 SIGNAL	 n0i1ii77	:	STD_LOGIC := '0';
	 SIGNAL	 n0i1ii78	:	STD_LOGIC := '0';
	 SIGNAL	 n0i1il75	:	STD_LOGIC := '0';
	 SIGNAL	 n0i1il76	:	STD_LOGIC := '0';
	 SIGNAL	 n0i1iO73	:	STD_LOGIC := '0';
	 SIGNAL	 n0i1iO74	:	STD_LOGIC := '0';
	 SIGNAL	 n0i1li71	:	STD_LOGIC := '0';
	 SIGNAL	 n0i1li72	:	STD_LOGIC := '0';
	 SIGNAL	 n0ii0l59	:	STD_LOGIC := '0';
	 SIGNAL	 n0ii0l60	:	STD_LOGIC := '0';
	 SIGNAL	 n0ii1i61	:	STD_LOGIC := '0';
	 SIGNAL	 n0ii1i62	:	STD_LOGIC := '0';
	 SIGNAL	 n0iiiO57	:	STD_LOGIC := '0';
	 SIGNAL	 n0iiiO58	:	STD_LOGIC := '0';
	 SIGNAL	 n0iiOi55	:	STD_LOGIC := '0';
	 SIGNAL	 n0iiOi56	:	STD_LOGIC := '0';
	 SIGNAL	 n0il0i51	:	STD_LOGIC := '0';
	 SIGNAL	 n0il0i52	:	STD_LOGIC := '0';
	 SIGNAL	 n0il0l49	:	STD_LOGIC := '0';
	 SIGNAL	 n0il0l50	:	STD_LOGIC := '0';
	 SIGNAL	 n0il1O53	:	STD_LOGIC := '0';
	 SIGNAL	 n0il1O54	:	STD_LOGIC := '0';
	 SIGNAL	 n0iliO47	:	STD_LOGIC := '0';
	 SIGNAL	 n0iliO48	:	STD_LOGIC := '0';
	 SIGNAL	 n0illi45	:	STD_LOGIC := '0';
	 SIGNAL	 n0illi46	:	STD_LOGIC := '0';
	 SIGNAL	 n0illO43	:	STD_LOGIC := '0';
	 SIGNAL	 n0illO44	:	STD_LOGIC := '0';
	 SIGNAL	 n0ilOi41	:	STD_LOGIC := '0';
	 SIGNAL	 n0ilOi42	:	STD_LOGIC := '0';
	 SIGNAL	 n0iO0O37	:	STD_LOGIC := '0';
	 SIGNAL	 n0iO0O38	:	STD_LOGIC := '0';
	 SIGNAL	 n0iO1l39	:	STD_LOGIC := '0';
	 SIGNAL	 n0iO1l40	:	STD_LOGIC := '0';
	 SIGNAL	 n0iOii35	:	STD_LOGIC := '0';
	 SIGNAL	 n0iOii36	:	STD_LOGIC := '0';
	 SIGNAL	 n0iOiO33	:	STD_LOGIC := '0';
	 SIGNAL	 n0iOiO34	:	STD_LOGIC := '0';
	 SIGNAL	 n0iOll31	:	STD_LOGIC := '0';
	 SIGNAL	 n0iOll32	:	STD_LOGIC := '0';
	 SIGNAL	 n0iOlO29	:	STD_LOGIC := '0';
	 SIGNAL	 n0iOlO30	:	STD_LOGIC := '0';
	 SIGNAL	 n0l00i1	:	STD_LOGIC := '0';
	 SIGNAL	 n0l00i2	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0l00i2_w_lg_w_lg_q36w37w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l00i2_w_lg_q36w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0l01i7	:	STD_LOGIC := '0';
	 SIGNAL	 n0l01i8	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0l01i8_w_lg_w_lg_q56w57w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l01i8_w_lg_q56w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0l01l5	:	STD_LOGIC := '0';
	 SIGNAL	 n0l01l6	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0l01l6_w_lg_w_lg_q52w53w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l01l6_w_lg_q52w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0l01O3	:	STD_LOGIC := '0';
	 SIGNAL	 n0l01O4	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0l01O4_w_lg_w_lg_q48w49w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l01O4_w_lg_q48w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0l10i23	:	STD_LOGIC := '0';
	 SIGNAL	 n0l10i24	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0l10i24_w_lg_w_lg_q104w105w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l10i24_w_lg_q104w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0l10l21	:	STD_LOGIC := '0';
	 SIGNAL	 n0l10l22	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0l10l22_w_lg_w_lg_q100w101w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l10l22_w_lg_q100w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0l10O19	:	STD_LOGIC := '0';
	 SIGNAL	 n0l10O20	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0l10O20_w_lg_w_lg_q94w95w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l10O20_w_lg_q94w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0l11l27	:	STD_LOGIC := '0';
	 SIGNAL	 n0l11l28	:	STD_LOGIC := '0';
	 SIGNAL	 n0l11O25	:	STD_LOGIC := '0';
	 SIGNAL	 n0l11O26	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0l11O26_w_lg_w_lg_q107w108w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l11O26_w_lg_q107w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0l1ii17	:	STD_LOGIC := '0';
	 SIGNAL	 n0l1ii18	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0l1ii18_w_lg_w_lg_q91w92w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l1ii18_w_lg_q91w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0l1iO15	:	STD_LOGIC := '0';
	 SIGNAL	 n0l1iO16	:	STD_LOGIC := '0';
	 SIGNAL	 n0l1ll13	:	STD_LOGIC := '0';
	 SIGNAL	 n0l1ll14	:	STD_LOGIC := '0';
	 SIGNAL	 n0l1Ol11	:	STD_LOGIC := '0';
	 SIGNAL	 n0l1Ol12	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0l1Ol12_w_lg_w_lg_q72w73w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l1Ol12_w_lg_q72w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0l1OO10	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0l1OO10_w_lg_w_lg_q62w63w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l1OO10_w_lg_q62w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0l1OO9	:	STD_LOGIC := '0';
	 SIGNAL	n011O	:	STD_LOGIC := '0';
	 SIGNAL	n01il	:	STD_LOGIC := '0';
	 SIGNAL	n1O0O	:	STD_LOGIC := '0';
	 SIGNAL	n1O1l	:	STD_LOGIC := '0';
	 SIGNAL	n1Oli	:	STD_LOGIC := '0';
	 SIGNAL	n1OOl	:	STD_LOGIC := '0';
	 SIGNAL	wire_n01ii_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_n01ii_PRN	:	STD_LOGIC;
	 SIGNAL  wire_n01ii_w_lg_n1O1l250w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n010i	:	STD_LOGIC := '0';
	 SIGNAL	n01li	:	STD_LOGIC := '0';
	 SIGNAL	n1O1O	:	STD_LOGIC := '0';
	 SIGNAL	n1Oii	:	STD_LOGIC := '0';
	 SIGNAL	n1Oll	:	STD_LOGIC := '0';
	 SIGNAL	n1OOO	:	STD_LOGIC := '0';
	 SIGNAL	wire_n01iO_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_n01iO_PRN	:	STD_LOGIC;
	 SIGNAL	n0lili	:	STD_LOGIC := '0';
	 SIGNAL	n0liOO	:	STD_LOGIC := '0';
	 SIGNAL	n0ll0l	:	STD_LOGIC := '0';
	 SIGNAL	n0llll	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0llli_w_lg_n0lili1478w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0llli_w_lg_n0liOO1487w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0llli_w_lg_n0ll0l1498w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0llli_w_lg_n0llll1507w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n0lill	:	STD_LOGIC := '0';
	 SIGNAL	n0ll0O	:	STD_LOGIC := '0';
	 SIGNAL	n0ll1i	:	STD_LOGIC := '0';
	 SIGNAL	n0llOi	:	STD_LOGIC := '0';
	 SIGNAL	n0O00O	:	STD_LOGIC := '0';
	 SIGNAL	n0O10l	:	STD_LOGIC := '0';
	 SIGNAL	n0O1li	:	STD_LOGIC := '0';
	 SIGNAL	n0O1OO	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O00l_w_lg_n0O00O1446w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O00l_w_lg_n0O10l1417w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O00l_w_lg_n0O1li1426w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O00l_w_lg_n0O1OO1437w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n0O01i	:	STD_LOGIC := '0';
	 SIGNAL	n0O0il	:	STD_LOGIC := '0';
	 SIGNAL	n0O10O	:	STD_LOGIC := '0';
	 SIGNAL	n0O1ll	:	STD_LOGIC := '0';
	 SIGNAL	n0Oill	:	STD_LOGIC := '0';
	 SIGNAL	wire_n0Oili_CLK	:	STD_LOGIC;
	 SIGNAL  wire_n0Oili_w_lg_n0Oill1405w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n0OiOi	:	STD_LOGIC := '0';
	 SIGNAL	wire_n0OilO_CLK	:	STD_LOGIC;
	 SIGNAL	n0Ol0i	:	STD_LOGIC := '0';
	 SIGNAL	n0OliO	:	STD_LOGIC := '0';
	 SIGNAL	n0OlOl	:	STD_LOGIC := '0';
	 SIGNAL	n0OO0l	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0OO0i_w_lg_n0Ol0i1357w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0OO0i_w_lg_n0OliO1366w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0OO0i_w_lg_n0OlOl1377w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0OO0i_w_lg_n0OO0l1386w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n0Ol0l	:	STD_LOGIC := '0';
	 SIGNAL	n0Olli	:	STD_LOGIC := '0';
	 SIGNAL	n0OlOO	:	STD_LOGIC := '0';
	 SIGNAL	n0OOii	:	STD_LOGIC := '0';
	 SIGNAL	n100i	:	STD_LOGIC := '0';
	 SIGNAL	n10li	:	STD_LOGIC := '0';
	 SIGNAL	n1i1l	:	STD_LOGIC := '0';
	 SIGNAL	wire_n1i1i_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_n1i1i_w_lg_n100i276w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i1i_w_lg_n10li285w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i1i_w_lg_n1i1l295w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n100l	:	STD_LOGIC := '0';
	 SIGNAL	n10ll	:	STD_LOGIC := '0';
	 SIGNAL	n1i0i	:	STD_LOGIC := '0';
	 SIGNAL	n1l0l	:	STD_LOGIC := '0';
	 SIGNAL	wire_n1l0i_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_n1l0i_w_lg_n1l0l263w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n1l1O	:	STD_LOGIC := '0';
	 SIGNAL	wire_n1l1l_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_n1l1l_PRN	:	STD_LOGIC;
	 SIGNAL  wire_n1l1l_w_lg_n1l1O370w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n1llO	:	STD_LOGIC := '0';
	 SIGNAL	n1lOl	:	STD_LOGIC := '0';
	 SIGNAL	ni00iO	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni00il_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_ni00il_w_lg_ni00iO1068w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	ni00ll	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni00li_PRN	:	STD_LOGIC;
	 SIGNAL	ni010l	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni010i_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_ni010i_w_lg_ni010l1086w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	ni01ii	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni010O_PRN	:	STD_LOGIC;
	 SIGNAL	ni0iOi	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni0ilO_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_ni0ilO_w_lg_ni0iOi1039w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	ni0iOO	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni0iOl_PRN	:	STD_LOGIC;
	 SIGNAL	ni0O1l	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni0O1i_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_ni0O1i_w_lg_ni0O1l1049w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	ni0O0i	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni0O1O_PRN	:	STD_LOGIC;
	 SIGNAL	ni100i	:	STD_LOGIC := '0';
	 SIGNAL	ni10iO	:	STD_LOGIC := '0';
	 SIGNAL	ni10OO	:	STD_LOGIC := '0';
	 SIGNAL	ni11Ol	:	STD_LOGIC := '0';
	 SIGNAL  wire_ni10Ol_w_lg_ni100i1305w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni10Ol_w_lg_ni10iO1316w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni10Ol_w_lg_ni10OO1325w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni10Ol_w_lg_ni11Ol1296w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	ni100l	:	STD_LOGIC := '0';
	 SIGNAL	ni10li	:	STD_LOGIC := '0';
	 SIGNAL	ni11OO	:	STD_LOGIC := '0';
	 SIGNAL	ni1i1l	:	STD_LOGIC := '0';
	 SIGNAL	ni1l0l	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni1l0i_CLK	:	STD_LOGIC;
	 SIGNAL  wire_ni1l0i_w_lg_ni1l0l1284w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	ni1lii	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni1l0O_CLK	:	STD_LOGIC;
	 SIGNAL	ni1O1i	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni1lOO_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_ni1lOO_w_lg_ni1O1i1078w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	ni1O1O	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni1O1l_PRN	:	STD_LOGIC;
	 SIGNAL	nii0li	:	STD_LOGIC := '0';
	 SIGNAL	wire_nii0iO_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nii0iO_w_lg_nii0li939w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nii0lO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nii0ll_PRN	:	STD_LOGIC;
	 SIGNAL	nii10O	:	STD_LOGIC := '0';
	 SIGNAL	wire_nii10l_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nii10l_w_lg_nii10O1057w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nii1il	:	STD_LOGIC := '0';
	 SIGNAL	wire_nii1ii_PRN	:	STD_LOGIC;
	 SIGNAL	niiiOl	:	STD_LOGIC := '0';
	 SIGNAL	wire_niiiOi_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_niiiOi_w_lg_niiiOl940w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	niil1i	:	STD_LOGIC := '0';
	 SIGNAL	wire_niiiOO_PRN	:	STD_LOGIC;
	 SIGNAL	niiO0l	:	STD_LOGIC := '0';
	 SIGNAL	wire_niiO0i_PRN	:	STD_LOGIC;
	 SIGNAL	niiO1O	:	STD_LOGIC := '0';
	 SIGNAL	wire_niiO1l_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_niiO1l_w_lg_niiO1O937w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nl10OO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl10Ol_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nl10Ol_PRN	:	STD_LOGIC;
	 SIGNAL  wire_nl10Ol_w_lg_nl10OO889w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nl111i	:	STD_LOGIC := '0';
	 SIGNAL	nl11ii	:	STD_LOGIC := '0';
	 SIGNAL	nl11Ol	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl11Oi_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nl11Oi_PRN	:	STD_LOGIC;
	 SIGNAL  wire_nl11Oi_w_lg_nl111i830w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl11Oi_w_lg_nl11ii839w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl11Oi_w_lg_nl11Ol849w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nl101i	:	STD_LOGIC := '0';
	 SIGNAL	nl111l	:	STD_LOGIC := '0';
	 SIGNAL	nl11il	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl11OO_CLRN	:	STD_LOGIC;
	 SIGNAL	nl1i1l	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl1i1i_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nl1i1i_w_lg_nl1i1l820w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nll01O	:	STD_LOGIC := '0';
	 SIGNAL	wire_nll01l_PRN	:	STD_LOGIC;
	 SIGNAL	nll01i	:	STD_LOGIC := '0';
	 SIGNAL	wire_nll1OO_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nll1OO_w_lg_nll01i353w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nlli0l	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlli0i_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nlli0i_PRN	:	STD_LOGIC;
	 SIGNAL  wire_nlli0i_w_lg_nlli0l361w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nlliii	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlli0O_PRN	:	STD_LOGIC;
	 SIGNAL	nllliO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlllil_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nlllil_PRN	:	STD_LOGIC;
	 SIGNAL  wire_nlllil_w_lg_w_lg_w_lg_nllliO341w342w346w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlllil_w_lg_w_lg_nllliO343w344w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlllil_w_lg_nllliO341w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlllil_w_lg_w_lg_w_lg_w_lg_nllliO341w342w346w347w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlllil_w_lg_w_lg_w_lg_nllliO343w344w345w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlllil_w_lg_w_lg_nllliO341w342w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlllil_w_lg_nllliO343w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nlllll	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlllli_PRN	:	STD_LOGIC;
	 SIGNAL	nllOOi	:	STD_LOGIC := '0';
	 SIGNAL	wire_nllOlO_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nllOlO_w_lg_w_lg_w_lg_nllOOi312w313w317w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllOlO_w_lg_w_lg_nllOOi314w315w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllOlO_w_lg_nllOOi312w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllOlO_w_lg_w_lg_w_lg_w_lg_nllOOi312w313w317w318w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllOlO_w_lg_w_lg_w_lg_nllOOi314w315w316w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllOlO_w_lg_w_lg_nllOOi312w313w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllOlO_w_lg_nllOOi314w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nllOOO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nllOOl_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nllOOl_PRN	:	STD_LOGIC;
	 SIGNAL	nlO01l	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlO01i_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nlO01i_w_lg_nlO01l324w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nlO00i	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlO01O_PRN	:	STD_LOGIC;
	 SIGNAL	nlOi0O	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlOi0l_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nlOi0l_w_lg_nlOi0O332w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nlOiil	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlOiii_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nlOiii_PRN	:	STD_LOGIC;
	 SIGNAL  wire_n00il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n00il_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_radce_hflck_range213w225w230w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00iO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n00iO_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_radce_hflck_range213w214w223w229w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00li_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n00li_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_radce_hflck_range213w221w228w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00ll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n00ll_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_radce_hflck_range213w214w217w227w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n00lO_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_radce_hflck_range213w225w226w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00Oi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n00Oi_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_radce_hflck_range213w214w223w224w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00Ol_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n00Ol_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_radce_hflck_range213w221w222w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00OO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n00OO_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_radce_hflck_range213w214w217w220w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n010l_w_lg_dataout234w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n010l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_vcc	:	STD_LOGIC;
	 SIGNAL  wire_n011i_w_lg_dataout243w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n011i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0ili_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0ili_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_radce_lflck_range186w198w203w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0ill_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0ill_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_radce_lflck_range186w187w196w202w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0ilO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0ilO_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_radce_lflck_range186w194w201w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0iOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0iOi_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_radce_lflck_range186w187w190w200w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0iOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0iOl_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_radce_lflck_range186w198w199w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0iOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0iOO_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_radce_lflck_range186w187w196w197w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0l1i_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_radce_lflck_range186w194w195w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0l1l_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_radce_lflck_range186w187w190w193w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0liil_w_lg_dataout1524w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0liil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0liOi_w_lg_dataout1521w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0liOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0ll1O_w_lg_dataout1518w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0ll1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0llil_w_lg_dataout1515w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0llil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0O01O_w_lg_dataout1454w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O01O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0O11O_w_lg_dataout1463w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O11O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0O1il_w_lg_dataout1460w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O1il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0O1Oi_w_lg_dataout1457w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O1Oi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0Ol1l_w_lg_dataout1403w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0Ol1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0Olii_w_lg_dataout1400w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0Olii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0OllO_w_lg_dataout1397w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0OllO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0OO1l_w_lg_dataout1394w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0OO1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n100O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n101l_w_lg_dataout310w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n101l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n10il_w_lg_dataout309w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n10lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n10Ol_w_lg_dataout303w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10Ol_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n11OO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1l0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1lil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1lOO_w_lg_dataout251w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1O0i_w_lg_dataout249w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1Oil_w_lg_dataout247w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1Oil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1OlO_w_lg_dataout245w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1OlO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni00lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni00Ol_w_lg_dataout1235w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni00Ol_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni01i_datain	:	STD_LOGIC;
	 SIGNAL  wire_n0l11l28_w_lg_w_lg_q110w111w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni01i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni01i_oe	:	STD_LOGIC;
	 SIGNAL  wire_nl1llO_w123w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni01il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni01li_w_lg_dataout1254w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni01li_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni01lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni01Oi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni01Oi_oe	:	STD_LOGIC;
	 SIGNAL  wire_nl1lOi_w_lg_w_dataout_range33w252w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni01Ol_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni01OO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni01OO_oe	:	STD_LOGIC;
	 SIGNAL  wire_ni0i0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0i0i_oe	:	STD_LOGIC;
	 SIGNAL  wire_ni0i1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0i1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0i1l_oe	:	STD_LOGIC;
	 SIGNAL  wire_ni0i1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0l0l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0l0l_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOiil_w_lg_w_dataout_range1099w1100w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0l0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0l1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0l1O_w_lg_dataout1216w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0l1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0lii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0lii_oe	:	STD_LOGIC;
	 SIGNAL  wire_ni0lil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0O0l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0Oii_w_lg_dataout1197w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0Oii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0OiO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0OiO_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOl0O_w_lg_w_dataout_range1097w1098w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0Oli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0Oll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0Oll_oe	:	STD_LOGIC;
	 SIGNAL  wire_ni0OlO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni101l_w_lg_dataout1339w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni101l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni10ii_w_lg_dataout1336w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni10ii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni10lO_w_lg_dataout1333w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni10lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni11lO_w_lg_dataout1342w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni11lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1ii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1ii_oe	:	STD_LOGIC;
	 SIGNAL  wire_ni1il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1il_oe	:	STD_LOGIC;
	 SIGNAL  wire_nl1llO_w_lg_w_lg_w_dataout_range35w137w148w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1iO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1iO_oe	:	STD_LOGIC;
	 SIGNAL  wire_nl1llO_w_lg_w_lg_w_lg_w_dataout_range35w112w146w147w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1li_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1li_oe	:	STD_LOGIC;
	 SIGNAL  wire_ni1ll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1ll_oe	:	STD_LOGIC;
	 SIGNAL  wire_n0iO1l40_w_lg_w_lg_q142w143w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1lO_datain	:	STD_LOGIC;
	 SIGNAL  wire_n0iO0O38_w_lg_w_lg_q134w135w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1lO_oe	:	STD_LOGIC;
	 SIGNAL  wire_ni1O0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1O0O_w_lg_dataout1273w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1O0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1Oi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1Oi_oe	:	STD_LOGIC;
	 SIGNAL  wire_n0iOii36_w_lg_w_lg_q132w133w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1Oil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1OiO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1OiO_oe	:	STD_LOGIC;
	 SIGNAL  wire_ni1Ol_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1Ol_oe	:	STD_LOGIC;
	 SIGNAL  wire_n0iOiO34_w_lg_w_lg_q127w128w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1Oli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1Oll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1Oll_oe	:	STD_LOGIC;
	 SIGNAL  wire_ni1OO_datain	:	STD_LOGIC;
	 SIGNAL  wire_n0iOll32_w_lg_w_lg_q124w125w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1OO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1OO_oe	:	STD_LOGIC;
	 SIGNAL  wire_nii01i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nii0Oi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nii0OO_w_lg_dataout1153w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii0OO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nii1iO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nii1ll_w_lg_dataout1175w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii1ll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nii1Oi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nii1Oi_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOO0i_w_lg_w_dataout_range1095w1096w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii1Ol_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nii1OO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nii1OO_oe	:	STD_LOGIC;
	 SIGNAL  wire_niii0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niii0l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niii0l_oe	:	STD_LOGIC;
	 SIGNAL  wire_nl1llO_w_lg_w_dataout_range35w112w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niii1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niii1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niii1O_oe	:	STD_LOGIC;
	 SIGNAL  wire_niil0i_w_lg_dataout1134w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niil0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niil0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niil1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niilii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niilii_oe	:	STD_LOGIC;
	 SIGNAL  wire_niilil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiliO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiliO_oe	:	STD_LOGIC;
	 SIGNAL  wire_niiO0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiOil_w_lg_dataout1115w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiOil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiOli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiOll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiOll_oe	:	STD_LOGIC;
	 SIGNAL  wire_niiOlO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiOOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiOOi_oe	:	STD_LOGIC;
	 SIGNAL  wire_nil01l_w_lg_dataout1075w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nil01l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nil10l_w_lg_dataout1083w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nil10l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nil1ii_w_lg_dataout1065w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nil1ii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nil1iO_w_lg_dataout1036w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nil1iO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nil1ll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nil1Oi_w_lg_dataout1046w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nil1Oi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nil1OO_w_lg_dataout1054w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nil1OO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niO0ll_datain	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_eqa_set_range800w801w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO0ll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niO0ll_oe	:	STD_LOGIC;
	 SIGNAL  wire_niO0lO_datain	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_eqb_set_range756w757w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO0lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niO0lO_oe	:	STD_LOGIC;
	 SIGNAL  wire_niO0Oi_datain	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_eqc_set_range702w703w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO0Oi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niO0Oi_oe	:	STD_LOGIC;
	 SIGNAL  wire_niO0Ol_datain	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_eqd_set_range647w648w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO0Ol_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niO0Ol_oe	:	STD_LOGIC;
	 SIGNAL  wire_niO0OO_datain	:	STD_LOGIC;
	 SIGNAL  wire_niO0OO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niO0OO_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOi0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOi0i_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOi0l_datain	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_eqv_set_range596w601w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOi0l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOi0l_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOi0O_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOi0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOi1i_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOi1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOi1i_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOi1l_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOi1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOi1O_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOi1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOiiO_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOiiO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOiiO_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOili_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOili_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOili_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOill_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOill_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOill_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOilO_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOilO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOilO_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOiOi_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOiOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOiOi_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOiOl_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOiOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOiOl_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOiOO_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOiOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOl0i_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOl0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOl1i_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOl1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOl1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOl1l_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOl1O_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOl1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOl1O_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOlii_datain	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_eqa_set_range805w806w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOlii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOlii_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOlil_datain	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_eqb_set_range761w762w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOlil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOlil_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOliO_datain	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_eqc_set_range707w708w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOliO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOliO_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOlli_datain	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_eqd_set_range652w653w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOlli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOlli_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOlll_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOlll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOlll_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOllO_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOllO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOllO_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOlOi_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOlOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOlOl_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOlOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOlOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOlOO_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOO0l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOO1i_datain	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_eqv_set_range599w609w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOO1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOO1i_oe	:	STD_LOGIC;
	 SIGNAL  wire_niOO1l_datain	:	STD_LOGIC;
	 SIGNAL  wire_niOO1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOOlO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOOOl_w_lg_dataout866w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_gnd	:	STD_LOGIC;
	 SIGNAL  wire_nl000i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl000i_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqb_set_range756w757w760w770w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl000l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl000l_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqb_set_range756w768w769w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl000O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl000O_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqb_set_range756w757w766w767w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl001i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl001i_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqb_set_range756w768w773w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl001l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl001l_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqb_set_range756w757w766w772w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl001O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl001O_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqb_set_range756w764w771w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl00ii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl00ii_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqb_set_range756w764w765w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl00il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl00il_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqb_set_range756w757w760w763w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl00li_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl00li_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_radce_adapt746w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl00ll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl00ll_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_radce_adapt537w538w745w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl00lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl00lO_oe	:	STD_LOGIC;
	 SIGNAL  wire_nl00Oi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl00Oi_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_n0i01O734w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl00Ol_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl0lll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl0lll_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqc_set_range702w714w719w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0llO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl0llO_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqc_set_range702w703w712w718w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0lOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl0lOi_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqc_set_range702w710w717w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0lOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl0lOl_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqc_set_range702w703w706w716w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0lOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl0lOO_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqc_set_range702w714w715w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0O0l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl0O0l_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_radce_adapt692w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0O0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl0O0O_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_radce_adapt537w538w691w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0O1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl0O1i_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqc_set_range702w703w712w713w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0O1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl0O1l_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqc_set_range702w710w711w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0O1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl0O1O_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqc_set_range702w703w706w709w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Oii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl0Oii_oe	:	STD_LOGIC;
	 SIGNAL  wire_nl0Oil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl0Oil_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_n0i00i680w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OiO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl110l_w_lg_dataout865w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl110l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl111O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl11iO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl11ll_w_lg_dataout857w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl11ll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1i0l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1i1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1l0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1l0i_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqa_set_range800w801w810w816w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1l0l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1l0l_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqa_set_range800w808w815w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1l0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1l0O_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqa_set_range800w801w804w814w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1l1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1l1O_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqa_set_range800w812w817w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1lii_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqa_set_range800w812w813w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1lil_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqa_set_range800w801w810w811w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1liO_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqa_set_range800w808w809w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1lli_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqa_set_range800w801w804w807w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1lOl_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_radce_adapt786w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1lOO_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_radce_adapt537w538w785w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1O1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1O1i_oe	:	STD_LOGIC;
	 SIGNAL  wire_nl1O1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1O1l_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_n0i01i781w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1O1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli00i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli00i_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqd_set_range647w655w662w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli00l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli00l_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqd_set_range647w648w651w661w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli00O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli00O_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqd_set_range647w659w660w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli01l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli01l_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqd_set_range647w659w664w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli01O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli01O_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqd_set_range647w648w657w663w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli0ii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli0ii_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqd_set_range647w648w657w658w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli0il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli0il_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqd_set_range647w655w656w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli0iO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli0iO_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqd_set_range647w648w651w654w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli0ll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli0ll_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_radce_adapt637w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli0lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli0lO_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_radce_adapt537w538w636w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli0Oi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli0Oi_oe	:	STD_LOGIC;
	 SIGNAL  wire_nli0Ol_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli0Ol_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_n0i00O631w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli0OO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliOil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliOil_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqv_set_range596w601w607w613w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOiO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliOiO_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqv_set_range596w605w612w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliOli_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqv_set_range596w601w602w611w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliOll_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqv_set_range596w598w610w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOlO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliOlO_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqv_set_range596w601w607w608w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliOOi_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqv_set_range596w605w606w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliOOl_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_eqv_set_range596w601w602w603w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliOOO_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_eqv_set_range596w598w600w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll00i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nll00O_w_lg_dataout503w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll00O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nll0il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nll0iO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nll0iO_oe	:	STD_LOGIC;
	 SIGNAL  wire_nll0li_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nll0ll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nll0ll_oe	:	STD_LOGIC;
	 SIGNAL  wire_nll10i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nll10i_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_radce_adapt537w538w564w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll11l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nll11l_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_radce_adapt586w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll11O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nll11O_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_radce_adapt565w566w585w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlliil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllili_w_lg_dataout480w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllili_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllilO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlliOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlliOi_oe	:	STD_LOGIC;
	 SIGNAL  wire_nlliOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlliOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlliOO_oe	:	STD_LOGIC;
	 SIGNAL  wire_nllllO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlllOl_w_lg_dataout459w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlllOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllO0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllO0i_oe	:	STD_LOGIC;
	 SIGNAL  wire_nllO1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllO1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllO1l_oe	:	STD_LOGIC;
	 SIGNAL  wire_nllO1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO00l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO0ii_w_lg_dataout415w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0ii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO0iO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO0li_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO0li_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_radce_vod_int_range408w409w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0ll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO0lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO0lO_oe	:	STD_LOGIC;
	 SIGNAL  wire_nlO10l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO10O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO10O_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_radce_vod_int_range431w432w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO11i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO11O_w_lg_dataout438w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO11O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO1ii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO1il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO1il_oe	:	STD_LOGIC;
	 SIGNAL  wire_nlOiiO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOill_w_lg_dataout392w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOill_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOiOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOiOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOiOl_oe	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_radce_vod_int_range382w383w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOiOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOl1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOl1i_oe	:	STD_LOGIC;
	 SIGNAL  wire_nlOlil_w_lg_dataout358w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOlil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOlli_w_lg_dataout340w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOlli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOllO_w_lg_dataout311w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOllO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOlOl_w_lg_dataout321w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOlOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOO1i_w_lg_dataout329w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOO1O_w_lg_dataout350w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0liiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0liOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Ol1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Olil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni101O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl110i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0i1i_datain	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n0i1i_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l1O_datain	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n0l1O_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni001i_w_lg_w_dataout_range1257w1258w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni001i_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni001i_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni001i_w_dataout_range1257w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni001l_w_lg_w_dataout_range1256w1259w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni001l_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni001l_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni001l_w_dataout_range1256w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni01l_datain	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_ni01l_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni01l_w_dataout_range82w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni01O_datain	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_ni01O_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni01O_w_dataout_range77w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0i0l_w_lg_w_dataout_range1238w1239w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0i0l_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni0i0l_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0i0l_w_dataout_range1238w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0i0O_w_lg_w_dataout_range1237w1240w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0i0O_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni0i0O_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0i0O_w_dataout_range1237w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0liO_w_lg_w_dataout_range1219w1220w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0liO_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni0liO_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0liO_w_dataout_range1219w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0ll_datain	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_ni0ll_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0lli_w_lg_w_dataout_range1218w1221w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0lli_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni0lli_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0lli_w_dataout_range1218w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0lO_datain	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0lO_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0Oi_datain	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0Oi_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0Ol_datain	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0Ol_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_datain	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OOi_w_lg_w_dataout_range1200w1201w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OOi_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni0OOi_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OOi_w_dataout_range1200w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OOl_w_lg_w_dataout_range1199w1202w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OOl_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni0OOl_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OOl_w_dataout_range1199w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1OlO_w_lg_w_dataout_range1276w1277w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1OlO_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni1OlO_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1OlO_w_dataout_range1276w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1OOi_w_lg_w_dataout_range1275w1278w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1OOi_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni1OOi_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1OOi_w_dataout_range1275w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii01l_w_lg_w_dataout_range1178w1179w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii01l_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nii01l_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii01l_w_dataout_range1178w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii01O_w_lg_w_dataout_range1177w1180w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii01O_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nii01O_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii01O_w_dataout_range1177w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii0i_datain	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii0i_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii0l_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nii0l_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii0O_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nii0O_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii1i_datain	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii1i_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii1l_datain	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii1l_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii1O_datain	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii1O_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niii0O_w_lg_w_dataout_range1156w1157w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niii0O_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niii0O_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niii0O_w_dataout_range1156w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiiii_w_lg_w_dataout_range1155w1158w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiiii_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niiiii_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiiii_w_dataout_range1155w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niilli_w_lg_w_dataout_range1137w1138w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niilli_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niilli_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niilli_w_dataout_range1137w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niilll_w_lg_w_dataout_range1136w1139w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niilll_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niilll_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niilll_w_dataout_range1136w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiOOl_w_lg_w_dataout_range1118w1119w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiOOl_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niiOOl_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiOOl_w_dataout_range1118w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiOOO_w_lg_w_dataout_range1117w1120w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiOOO_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niiOOO_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiOOO_w_dataout_range1117w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiii_datain	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_niOiii_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiil_datain	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niOiil_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_datain	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_niOl0l_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0O_datain	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niOl0O_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOO0i_datain	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niOO0i_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOO1O_datain	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_niOO1O_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl00iO_datain	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl00iO_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0i1i_datain	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl0i1i_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0O0i_datain	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0O0i_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Oll_datain	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl0Oll_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lll_datain	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl1lll_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llO_w_lg_w_dataout_range35w348w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llO_w_lg_w_dataout_range35w319w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llO_w_lg_w_dataout_range35w144w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llO_w_lg_w_dataout_range35w137w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llO_w_lg_w_dataout_range35w130w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llO_datain	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llO_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llO_w_dataout_range35w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lOi_datain	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lOi_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1O0l_datain	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O0l_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli0li_datain	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nli0li_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlii1l_datain	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlii1l_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0lO_w_lg_w_dataout_range510w511w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0lO_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nll0lO_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0lO_w_dataout_range510w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0Oi_w_lg_w_dataout_range505w512w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0Oi_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nll0Oi_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0Oi_w_dataout_range505w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll11i_datain	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nll11i_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlll1i_w_lg_w_dataout_range487w488w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlll1i_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlll1i_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlll1i_w_dataout_range487w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlll1l_w_lg_w_dataout_range482w489w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlll1l_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlll1l_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlll1l_w_dataout_range482w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO0l_w_lg_w_dataout_range464w465w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO0l_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllO0l_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO0l_w_dataout_range464w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO0O_w_lg_w_dataout_range461w466w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO0O_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllO0O_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO0O_w_dataout_range461w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0Oi_w_lg_w_dataout_range420w421w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0Oi_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlO0Oi_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0Oi_w_dataout_range420w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0Ol_w_lg_w_dataout_range417w422w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0Ol_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlO0Ol_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0Ol_w_dataout_range417w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1iO_w_lg_w_dataout_range443w444w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1iO_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlO1iO_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1iO_w_dataout_range443w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1li_w_lg_w_dataout_range442w445w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1li_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlO1li_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1li_w_dataout_range442w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl1l_w_lg_w_dataout_range397w398w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl1l_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlOl1l_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl1l_w_dataout_range397w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl1O_w_lg_w_dataout_range396w399w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl1O_datain	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlOl1O_dataout	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl1O_w_dataout_range396w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n00OOi1030w1031w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i10i1022w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i11O1015w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i1OO968w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0ii1019w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0ii1012w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l1Oi83w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l1Oi78w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0liii258w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_radce_adapt539w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_eqa_set_range800w808w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_eqb_set_range756w764w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_eqc_set_range702w710w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_eqd_set_range647w655w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_eqv_set_range596w605w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_hflck_range213w221w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_hflck_range1413w1418w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_hflck_range1422w1427w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_hflck_range1433w1438w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_hflck_range1442w1447w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_hflck_range1474w1479w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_hflck_range1483w1488w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_hflck_range1494w1499w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_hflck_range1503w1508w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_lflck_range186w194w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_lflck_range1292w1297w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_lflck_range1301w1306w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_lflck_range1312w1317w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_lflck_range1321w1326w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_lflck_range1353w1358w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_lflck_range1362w1367w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_lflck_range1373w1378w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_lflck_range1382w1387w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rclkdiv_range154w164w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rclkdiv_range149w152w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rhyst_hf_range826w831w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rhyst_hf_range835w840w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rhyst_hf_range845w850w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rhyst_lf_range272w277w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rhyst_lf_range281w286w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rhyst_lf_range291w296w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rseq_sel_range541w556w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rseq_sel_range543w997w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rseq_sel_range543w675w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rseq_sel_range543w684w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_radce_adapt255w256w257w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_fixed_clk253w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_lock_lf_ovd1279w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n000il1522w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n000iO1519w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n000ll1461w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n000lO1458w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n000OO1409w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00i0i1340w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00i0l1337w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00i1i1401w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00i1l1398w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00iil1288w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00iiO1274w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00ili1255w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00ill1269w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00ilO1268w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00iOi1236w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00iOl1250w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00iOO1249w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00l0i1198w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00l0l1212w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00l0O1211w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00l1i1217w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00l1l1231w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00l1O1230w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00lii1176w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00lil1193w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00liO1192w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00lli1154w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00lll1135w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00llO1149w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00lOi1148w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00lOl1116w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00lOO1130w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00O0i969w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00O0l967w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00O0O959w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00O1i1129w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00O1l1113w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00Oii956w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00Oil951w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00OiO948w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00Oli909w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00Oll908w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00OlO1032w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00OOi1030w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00OOl907w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00OOO906w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i00i681w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i00l623w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i00O632w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i01i782w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i01l728w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i01O735w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i0ii551w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i0li504w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i0Oi481w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i0Ol499w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i0OO498w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i10i872w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i10l868w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i11i991w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i11l880w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i11O875w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i1ll862w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i1lO819w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ii0i475w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ii0O440w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ii1l460w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ii1O476w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iiii455w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iiil454w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iili416w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iill434w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iilO433w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iiOl394w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iiOO411w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0il0O306w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0il1i410w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0il1l390w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ilii262w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ilOl248w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ilOO244w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iO0i138w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iO0l136w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iO1i246w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iO1O140w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iOil129w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iOli126w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iOOl116w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iOOO114w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l00l31w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0ii30w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0il540w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0iO549w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0li547w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0ll570w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0lO264w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0OO1290w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l11i113w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0li0i821w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0li1O1411w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_radce_adapt255w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_radce_pdb536w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_radce_rstb267w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_eqa_set_range802w803w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_eqb_set_range758w759w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_eqc_set_range704w705w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_eqd_set_range649w650w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_eqv_set_range597w604w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_hflck_range215w216w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_radce_lflck_range188w189w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rclkdiv_range155w163w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rclkdiv_range150w151w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rseq_sel_range543w555w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n0l0ll570w571w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n0l0ll570w671w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_radce_adapt255w256w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0ii683w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rseq_sel_range541w965w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  n000il :	STD_LOGIC;
	 SIGNAL  n000iO :	STD_LOGIC;
	 SIGNAL  n000li :	STD_LOGIC;
	 SIGNAL  n000ll :	STD_LOGIC;
	 SIGNAL  n000lO :	STD_LOGIC;
	 SIGNAL  n000Oi :	STD_LOGIC;
	 SIGNAL  n000Ol :	STD_LOGIC;
	 SIGNAL  n000OO :	STD_LOGIC;
	 SIGNAL  n00i0i :	STD_LOGIC;
	 SIGNAL  n00i0l :	STD_LOGIC;
	 SIGNAL  n00i0O :	STD_LOGIC;
	 SIGNAL  n00i1i :	STD_LOGIC;
	 SIGNAL  n00i1l :	STD_LOGIC;
	 SIGNAL  n00i1O :	STD_LOGIC;
	 SIGNAL  n00iii :	STD_LOGIC;
	 SIGNAL  n00iil :	STD_LOGIC;
	 SIGNAL  n00iiO :	STD_LOGIC;
	 SIGNAL  n00ili :	STD_LOGIC;
	 SIGNAL  n00ill :	STD_LOGIC;
	 SIGNAL  n00ilO :	STD_LOGIC;
	 SIGNAL  n00iOi :	STD_LOGIC;
	 SIGNAL  n00iOl :	STD_LOGIC;
	 SIGNAL  n00iOO :	STD_LOGIC;
	 SIGNAL  n00l0i :	STD_LOGIC;
	 SIGNAL  n00l0l :	STD_LOGIC;
	 SIGNAL  n00l0O :	STD_LOGIC;
	 SIGNAL  n00l1i :	STD_LOGIC;
	 SIGNAL  n00l1l :	STD_LOGIC;
	 SIGNAL  n00l1O :	STD_LOGIC;
	 SIGNAL  n00lii :	STD_LOGIC;
	 SIGNAL  n00lil :	STD_LOGIC;
	 SIGNAL  n00liO :	STD_LOGIC;
	 SIGNAL  n00lli :	STD_LOGIC;
	 SIGNAL  n00lll :	STD_LOGIC;
	 SIGNAL  n00llO :	STD_LOGIC;
	 SIGNAL  n00lOi :	STD_LOGIC;
	 SIGNAL  n00lOl :	STD_LOGIC;
	 SIGNAL  n00lOO :	STD_LOGIC;
	 SIGNAL  n00O0i :	STD_LOGIC;
	 SIGNAL  n00O0l :	STD_LOGIC;
	 SIGNAL  n00O0O :	STD_LOGIC;
	 SIGNAL  n00O1i :	STD_LOGIC;
	 SIGNAL  n00O1l :	STD_LOGIC;
	 SIGNAL  n00O1O :	STD_LOGIC;
	 SIGNAL  n00Oii :	STD_LOGIC;
	 SIGNAL  n00Oil :	STD_LOGIC;
	 SIGNAL  n00OiO :	STD_LOGIC;
	 SIGNAL  n00Oli :	STD_LOGIC;
	 SIGNAL  n00Oll :	STD_LOGIC;
	 SIGNAL  n00OlO :	STD_LOGIC;
	 SIGNAL  n00OOi :	STD_LOGIC;
	 SIGNAL  n00OOl :	STD_LOGIC;
	 SIGNAL  n00OOO :	STD_LOGIC;
	 SIGNAL  n0i00i :	STD_LOGIC;
	 SIGNAL  n0i00l :	STD_LOGIC;
	 SIGNAL  n0i00O :	STD_LOGIC;
	 SIGNAL  n0i01i :	STD_LOGIC;
	 SIGNAL  n0i01l :	STD_LOGIC;
	 SIGNAL  n0i01O :	STD_LOGIC;
	 SIGNAL  n0i0ii :	STD_LOGIC;
	 SIGNAL  n0i0li :	STD_LOGIC;
	 SIGNAL  n0i0Oi :	STD_LOGIC;
	 SIGNAL  n0i0Ol :	STD_LOGIC;
	 SIGNAL  n0i0OO :	STD_LOGIC;
	 SIGNAL  n0i10i :	STD_LOGIC;
	 SIGNAL  n0i10l :	STD_LOGIC;
	 SIGNAL  n0i11i :	STD_LOGIC;
	 SIGNAL  n0i11l :	STD_LOGIC;
	 SIGNAL  n0i11O :	STD_LOGIC;
	 SIGNAL  n0i1ll :	STD_LOGIC;
	 SIGNAL  n0i1lO :	STD_LOGIC;
	 SIGNAL  n0i1Oi :	STD_LOGIC;
	 SIGNAL  n0i1Ol :	STD_LOGIC;
	 SIGNAL  n0i1OO :	STD_LOGIC;
	 SIGNAL  n0ii0i :	STD_LOGIC;
	 SIGNAL  n0ii0O :	STD_LOGIC;
	 SIGNAL  n0ii1l :	STD_LOGIC;
	 SIGNAL  n0ii1O :	STD_LOGIC;
	 SIGNAL  n0iiii :	STD_LOGIC;
	 SIGNAL  n0iiil :	STD_LOGIC;
	 SIGNAL  n0iili :	STD_LOGIC;
	 SIGNAL  n0iill :	STD_LOGIC;
	 SIGNAL  n0iilO :	STD_LOGIC;
	 SIGNAL  n0iiOl :	STD_LOGIC;
	 SIGNAL  n0iiOO :	STD_LOGIC;
	 SIGNAL  n0il0O :	STD_LOGIC;
	 SIGNAL  n0il1i :	STD_LOGIC;
	 SIGNAL  n0il1l :	STD_LOGIC;
	 SIGNAL  n0ilii :	STD_LOGIC;
	 SIGNAL  n0ilil :	STD_LOGIC;
	 SIGNAL  n0illl :	STD_LOGIC;
	 SIGNAL  n0ilOl :	STD_LOGIC;
	 SIGNAL  n0ilOO :	STD_LOGIC;
	 SIGNAL  n0iO0i :	STD_LOGIC;
	 SIGNAL  n0iO0l :	STD_LOGIC;
	 SIGNAL  n0iO1i :	STD_LOGIC;
	 SIGNAL  n0iO1O :	STD_LOGIC;
	 SIGNAL  n0iOil :	STD_LOGIC;
	 SIGNAL  n0iOli :	STD_LOGIC;
	 SIGNAL  n0iOOl :	STD_LOGIC;
	 SIGNAL  n0iOOO :	STD_LOGIC;
	 SIGNAL  n0l00l :	STD_LOGIC;
	 SIGNAL  n0l00O :	STD_LOGIC;
	 SIGNAL  n0l0ii :	STD_LOGIC;
	 SIGNAL  n0l0il :	STD_LOGIC;
	 SIGNAL  n0l0iO :	STD_LOGIC;
	 SIGNAL  n0l0li :	STD_LOGIC;
	 SIGNAL  n0l0ll :	STD_LOGIC;
	 SIGNAL  n0l0lO :	STD_LOGIC;
	 SIGNAL  n0l0Oi :	STD_LOGIC;
	 SIGNAL  n0l0Ol :	STD_LOGIC;
	 SIGNAL  n0l0OO :	STD_LOGIC;
	 SIGNAL  n0l11i :	STD_LOGIC;
	 SIGNAL  n0l1il :	STD_LOGIC;
	 SIGNAL  n0l1Oi :	STD_LOGIC;
	 SIGNAL  n0li0i :	STD_LOGIC;
	 SIGNAL  n0li1i :	STD_LOGIC;
	 SIGNAL  n0li1l :	STD_LOGIC;
	 SIGNAL  n0li1O :	STD_LOGIC;
	 SIGNAL  n0liii :	STD_LOGIC;
	 SIGNAL  wire_w_eqa_set_range800w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_eqa_set_range802w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_eqb_set_range756w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_eqb_set_range758w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_eqc_set_range702w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_eqc_set_range704w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_eqd_set_range647w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_eqd_set_range649w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_eqv_set_range596w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_eqv_set_range597w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_hflck_range213w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_hflck_range1413w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_hflck_range1422w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_hflck_range1433w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_hflck_range1442w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_hflck_range215w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_hflck_range1474w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_hflck_range1483w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_hflck_range1494w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_hflck_range1503w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_lflck_range186w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_lflck_range1292w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_lflck_range1301w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_lflck_range1312w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_lflck_range1321w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_lflck_range188w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_lflck_range1353w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_lflck_range1362w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_lflck_range1373w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_radce_lflck_range1382w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rclkdiv_range154w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rclkdiv_range155w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rclkdiv_range149w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rclkdiv_range150w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rhyst_hf_range826w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rhyst_hf_range835w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rhyst_hf_range845w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rhyst_lf_range272w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rhyst_lf_range281w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rhyst_lf_range291w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rseq_sel_range541w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rseq_sel_range543w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_gnd <= '0';
	wire_vcc <= '1';
	wire_w_lg_w_lg_n00OOi1030w1031w(0) <= wire_w_lg_n00OOi1030w(0) AND n00OOO;
	wire_w_lg_n0i10i1022w(0) <= n0i10i AND wire_w_lg_n0l0li547w(0);
	wire_w_lg_n0i11O1015w(0) <= n0i11O AND wire_w_lg_n0l0iO549w(0);
	wire_w_lg_n0i1OO968w(0) <= n0i1OO AND wire_w_lg_n00O0l967w(0);
	wire_w_lg_n0l0ii1019w(0) <= n0l0ii AND wire_w_lg_n0i10i872w(0);
	wire_w_lg_n0l0ii1012w(0) <= n0l0ii AND wire_w_lg_n0i11O875w(0);
	wire_w_lg_n0l1Oi83w(0) <= n0l1Oi AND wire_ni01l_w_dataout_range82w(0);
	wire_w_lg_n0l1Oi78w(0) <= n0l1Oi AND wire_ni01O_w_dataout_range77w(0);
	wire_w_lg_n0liii258w(0) <= n0liii AND wire_w_lg_w_lg_w_lg_radce_adapt255w256w257w(0);
	wire_w_lg_radce_adapt539w(0) <= radce_adapt AND wire_w_lg_n0l0ii30w(0);
	wire_w_lg_w_eqa_set_range800w808w(0) <= wire_w_eqa_set_range800w(0) AND wire_w_lg_w_eqa_set_range802w803w(0);
	wire_w_lg_w_eqb_set_range756w764w(0) <= wire_w_eqb_set_range756w(0) AND wire_w_lg_w_eqb_set_range758w759w(0);
	wire_w_lg_w_eqc_set_range702w710w(0) <= wire_w_eqc_set_range702w(0) AND wire_w_lg_w_eqc_set_range704w705w(0);
	wire_w_lg_w_eqd_set_range647w655w(0) <= wire_w_eqd_set_range647w(0) AND wire_w_lg_w_eqd_set_range649w650w(0);
	wire_w_lg_w_eqv_set_range596w605w(0) <= wire_w_eqv_set_range596w(0) AND wire_w_lg_w_eqv_set_range597w604w(0);
	wire_w_lg_w_radce_hflck_range213w221w(0) <= wire_w_radce_hflck_range213w(0) AND wire_w_lg_w_radce_hflck_range215w216w(0);
	wire_w_lg_w_radce_hflck_range1413w1418w(0) <= wire_w_radce_hflck_range1413w(0) AND wire_n0O00l_w_lg_n0O10l1417w(0);
	wire_w_lg_w_radce_hflck_range1422w1427w(0) <= wire_w_radce_hflck_range1422w(0) AND wire_n0O00l_w_lg_n0O1li1426w(0);
	wire_w_lg_w_radce_hflck_range1433w1438w(0) <= wire_w_radce_hflck_range1433w(0) AND wire_n0O00l_w_lg_n0O1OO1437w(0);
	wire_w_lg_w_radce_hflck_range1442w1447w(0) <= wire_w_radce_hflck_range1442w(0) AND wire_n0O00l_w_lg_n0O00O1446w(0);
	wire_w_lg_w_radce_hflck_range1474w1479w(0) <= wire_w_radce_hflck_range1474w(0) AND wire_n0llli_w_lg_n0lili1478w(0);
	wire_w_lg_w_radce_hflck_range1483w1488w(0) <= wire_w_radce_hflck_range1483w(0) AND wire_n0llli_w_lg_n0liOO1487w(0);
	wire_w_lg_w_radce_hflck_range1494w1499w(0) <= wire_w_radce_hflck_range1494w(0) AND wire_n0llli_w_lg_n0ll0l1498w(0);
	wire_w_lg_w_radce_hflck_range1503w1508w(0) <= wire_w_radce_hflck_range1503w(0) AND wire_n0llli_w_lg_n0llll1507w(0);
	wire_w_lg_w_radce_lflck_range186w194w(0) <= wire_w_radce_lflck_range186w(0) AND wire_w_lg_w_radce_lflck_range188w189w(0);
	wire_w_lg_w_radce_lflck_range1292w1297w(0) <= wire_w_radce_lflck_range1292w(0) AND wire_ni10Ol_w_lg_ni11Ol1296w(0);
	wire_w_lg_w_radce_lflck_range1301w1306w(0) <= wire_w_radce_lflck_range1301w(0) AND wire_ni10Ol_w_lg_ni100i1305w(0);
	wire_w_lg_w_radce_lflck_range1312w1317w(0) <= wire_w_radce_lflck_range1312w(0) AND wire_ni10Ol_w_lg_ni10iO1316w(0);
	wire_w_lg_w_radce_lflck_range1321w1326w(0) <= wire_w_radce_lflck_range1321w(0) AND wire_ni10Ol_w_lg_ni10OO1325w(0);
	wire_w_lg_w_radce_lflck_range1353w1358w(0) <= wire_w_radce_lflck_range1353w(0) AND wire_n0OO0i_w_lg_n0Ol0i1357w(0);
	wire_w_lg_w_radce_lflck_range1362w1367w(0) <= wire_w_radce_lflck_range1362w(0) AND wire_n0OO0i_w_lg_n0OliO1366w(0);
	wire_w_lg_w_radce_lflck_range1373w1378w(0) <= wire_w_radce_lflck_range1373w(0) AND wire_n0OO0i_w_lg_n0OlOl1377w(0);
	wire_w_lg_w_radce_lflck_range1382w1387w(0) <= wire_w_radce_lflck_range1382w(0) AND wire_n0OO0i_w_lg_n0OO0l1386w(0);
	wire_w_lg_w_rclkdiv_range154w164w(0) <= wire_w_rclkdiv_range154w(0) AND wire_w_lg_w_rclkdiv_range155w163w(0);
	wire_w_lg_w_rclkdiv_range149w152w(0) <= wire_w_rclkdiv_range149w(0) AND wire_w_lg_w_rclkdiv_range150w151w(0);
	wire_w_lg_w_rhyst_hf_range826w831w(0) <= wire_w_rhyst_hf_range826w(0) AND wire_nl11Oi_w_lg_nl111i830w(0);
	wire_w_lg_w_rhyst_hf_range835w840w(0) <= wire_w_rhyst_hf_range835w(0) AND wire_nl11Oi_w_lg_nl11ii839w(0);
	wire_w_lg_w_rhyst_hf_range845w850w(0) <= wire_w_rhyst_hf_range845w(0) AND wire_nl11Oi_w_lg_nl11Ol849w(0);
	wire_w_lg_w_rhyst_lf_range272w277w(0) <= wire_w_rhyst_lf_range272w(0) AND wire_n1i1i_w_lg_n100i276w(0);
	wire_w_lg_w_rhyst_lf_range281w286w(0) <= wire_w_rhyst_lf_range281w(0) AND wire_n1i1i_w_lg_n10li285w(0);
	wire_w_lg_w_rhyst_lf_range291w296w(0) <= wire_w_rhyst_lf_range291w(0) AND wire_n1i1i_w_lg_n1i1l295w(0);
	wire_w_lg_w_rseq_sel_range541w556w(0) <= wire_w_rseq_sel_range541w(0) AND wire_w_lg_w_rseq_sel_range543w555w(0);
	wire_w_lg_w_rseq_sel_range543w997w(0) <= wire_w_rseq_sel_range543w(0) AND wire_w_lg_n00Oii956w(0);
	wire_w_lg_w_rseq_sel_range543w675w(0) <= wire_w_rseq_sel_range543w(0) AND wire_w_lg_w_lg_n0l0ll570w571w(0);
	wire_w_lg_w_rseq_sel_range543w684w(0) <= wire_w_rseq_sel_range543w(0) AND wire_w_lg_n0l0ii683w(0);
	wire_w_lg_w_lg_w_lg_radce_adapt255w256w257w(0) <= NOT wire_w_lg_w_lg_radce_adapt255w256w(0);
	wire_w_lg_fixed_clk253w(0) <= NOT fixed_clk;
	wire_w_lg_lock_lf_ovd1279w(0) <= NOT lock_lf_ovd;
	wire_w_lg_n000il1522w(0) <= NOT n000il;
	wire_w_lg_n000iO1519w(0) <= NOT n000iO;
	wire_w_lg_n000ll1461w(0) <= NOT n000ll;
	wire_w_lg_n000lO1458w(0) <= NOT n000lO;
	wire_w_lg_n000OO1409w(0) <= NOT n000OO;
	wire_w_lg_n00i0i1340w(0) <= NOT n00i0i;
	wire_w_lg_n00i0l1337w(0) <= NOT n00i0l;
	wire_w_lg_n00i1i1401w(0) <= NOT n00i1i;
	wire_w_lg_n00i1l1398w(0) <= NOT n00i1l;
	wire_w_lg_n00iil1288w(0) <= NOT n00iil;
	wire_w_lg_n00iiO1274w(0) <= NOT n00iiO;
	wire_w_lg_n00ili1255w(0) <= NOT n00ili;
	wire_w_lg_n00ill1269w(0) <= NOT n00ill;
	wire_w_lg_n00ilO1268w(0) <= NOT n00ilO;
	wire_w_lg_n00iOi1236w(0) <= NOT n00iOi;
	wire_w_lg_n00iOl1250w(0) <= NOT n00iOl;
	wire_w_lg_n00iOO1249w(0) <= NOT n00iOO;
	wire_w_lg_n00l0i1198w(0) <= NOT n00l0i;
	wire_w_lg_n00l0l1212w(0) <= NOT n00l0l;
	wire_w_lg_n00l0O1211w(0) <= NOT n00l0O;
	wire_w_lg_n00l1i1217w(0) <= NOT n00l1i;
	wire_w_lg_n00l1l1231w(0) <= NOT n00l1l;
	wire_w_lg_n00l1O1230w(0) <= NOT n00l1O;
	wire_w_lg_n00lii1176w(0) <= NOT n00lii;
	wire_w_lg_n00lil1193w(0) <= NOT n00lil;
	wire_w_lg_n00liO1192w(0) <= NOT n00liO;
	wire_w_lg_n00lli1154w(0) <= NOT n00lli;
	wire_w_lg_n00lll1135w(0) <= NOT n00lll;
	wire_w_lg_n00llO1149w(0) <= NOT n00llO;
	wire_w_lg_n00lOi1148w(0) <= NOT n00lOi;
	wire_w_lg_n00lOl1116w(0) <= NOT n00lOl;
	wire_w_lg_n00lOO1130w(0) <= NOT n00lOO;
	wire_w_lg_n00O0i969w(0) <= NOT n00O0i;
	wire_w_lg_n00O0l967w(0) <= NOT n00O0l;
	wire_w_lg_n00O0O959w(0) <= NOT n00O0O;
	wire_w_lg_n00O1i1129w(0) <= NOT n00O1i;
	wire_w_lg_n00O1l1113w(0) <= NOT n00O1l;
	wire_w_lg_n00Oii956w(0) <= NOT n00Oii;
	wire_w_lg_n00Oil951w(0) <= NOT n00Oil;
	wire_w_lg_n00OiO948w(0) <= NOT n00OiO;
	wire_w_lg_n00Oli909w(0) <= NOT n00Oli;
	wire_w_lg_n00Oll908w(0) <= NOT n00Oll;
	wire_w_lg_n00OlO1032w(0) <= NOT n00OlO;
	wire_w_lg_n00OOi1030w(0) <= NOT n00OOi;
	wire_w_lg_n00OOl907w(0) <= NOT n00OOl;
	wire_w_lg_n00OOO906w(0) <= NOT n00OOO;
	wire_w_lg_n0i00i681w(0) <= NOT n0i00i;
	wire_w_lg_n0i00l623w(0) <= NOT n0i00l;
	wire_w_lg_n0i00O632w(0) <= NOT n0i00O;
	wire_w_lg_n0i01i782w(0) <= NOT n0i01i;
	wire_w_lg_n0i01l728w(0) <= NOT n0i01l;
	wire_w_lg_n0i01O735w(0) <= NOT n0i01O;
	wire_w_lg_n0i0ii551w(0) <= NOT n0i0ii;
	wire_w_lg_n0i0li504w(0) <= NOT n0i0li;
	wire_w_lg_n0i0Oi481w(0) <= NOT n0i0Oi;
	wire_w_lg_n0i0Ol499w(0) <= NOT n0i0Ol;
	wire_w_lg_n0i0OO498w(0) <= NOT n0i0OO;
	wire_w_lg_n0i10i872w(0) <= NOT n0i10i;
	wire_w_lg_n0i10l868w(0) <= NOT n0i10l;
	wire_w_lg_n0i11i991w(0) <= NOT n0i11i;
	wire_w_lg_n0i11l880w(0) <= NOT n0i11l;
	wire_w_lg_n0i11O875w(0) <= NOT n0i11O;
	wire_w_lg_n0i1ll862w(0) <= NOT n0i1ll;
	wire_w_lg_n0i1lO819w(0) <= NOT n0i1lO;
	wire_w_lg_n0ii0i475w(0) <= NOT n0ii0i;
	wire_w_lg_n0ii0O440w(0) <= NOT n0ii0O;
	wire_w_lg_n0ii1l460w(0) <= NOT n0ii1l;
	wire_w_lg_n0ii1O476w(0) <= NOT n0ii1O;
	wire_w_lg_n0iiii455w(0) <= NOT n0iiii;
	wire_w_lg_n0iiil454w(0) <= NOT n0iiil;
	wire_w_lg_n0iili416w(0) <= NOT n0iili;
	wire_w_lg_n0iill434w(0) <= NOT n0iill;
	wire_w_lg_n0iilO433w(0) <= NOT n0iilO;
	wire_w_lg_n0iiOl394w(0) <= NOT n0iiOl;
	wire_w_lg_n0iiOO411w(0) <= NOT n0iiOO;
	wire_w_lg_n0il0O306w(0) <= NOT n0il0O;
	wire_w_lg_n0il1i410w(0) <= NOT n0il1i;
	wire_w_lg_n0il1l390w(0) <= NOT n0il1l;
	wire_w_lg_n0ilii262w(0) <= NOT n0ilii;
	wire_w_lg_n0ilOl248w(0) <= NOT n0ilOl;
	wire_w_lg_n0ilOO244w(0) <= NOT n0ilOO;
	wire_w_lg_n0iO0i138w(0) <= NOT n0iO0i;
	wire_w_lg_n0iO0l136w(0) <= NOT n0iO0l;
	wire_w_lg_n0iO1i246w(0) <= NOT n0iO1i;
	wire_w_lg_n0iO1O140w(0) <= NOT n0iO1O;
	wire_w_lg_n0iOil129w(0) <= NOT n0iOil;
	wire_w_lg_n0iOli126w(0) <= NOT n0iOli;
	wire_w_lg_n0iOOl116w(0) <= NOT n0iOOl;
	wire_w_lg_n0iOOO114w(0) <= NOT n0iOOO;
	wire_w_lg_n0l00l31w(0) <= NOT n0l00l;
	wire_w_lg_n0l0ii30w(0) <= NOT n0l0ii;
	wire_w_lg_n0l0il540w(0) <= NOT n0l0il;
	wire_w_lg_n0l0iO549w(0) <= NOT n0l0iO;
	wire_w_lg_n0l0li547w(0) <= NOT n0l0li;
	wire_w_lg_n0l0ll570w(0) <= NOT n0l0ll;
	wire_w_lg_n0l0lO264w(0) <= NOT n0l0lO;
	wire_w_lg_n0l0OO1290w(0) <= NOT n0l0OO;
	wire_w_lg_n0l11i113w(0) <= NOT n0l11i;
	wire_w_lg_n0li0i821w(0) <= NOT n0li0i;
	wire_w_lg_n0li1O1411w(0) <= NOT n0li1O;
	wire_w_lg_radce_adapt255w(0) <= NOT radce_adapt;
	wire_w_lg_radce_pdb536w(0) <= NOT radce_pdb;
	wire_w_lg_radce_rstb267w(0) <= NOT radce_rstb;
	wire_w_lg_w_eqa_set_range802w803w(0) <= NOT wire_w_eqa_set_range802w(0);
	wire_w_lg_w_eqb_set_range758w759w(0) <= NOT wire_w_eqb_set_range758w(0);
	wire_w_lg_w_eqc_set_range704w705w(0) <= NOT wire_w_eqc_set_range704w(0);
	wire_w_lg_w_eqd_set_range649w650w(0) <= NOT wire_w_eqd_set_range649w(0);
	wire_w_lg_w_eqv_set_range597w604w(0) <= NOT wire_w_eqv_set_range597w(0);
	wire_w_lg_w_radce_hflck_range215w216w(0) <= NOT wire_w_radce_hflck_range215w(0);
	wire_w_lg_w_radce_lflck_range188w189w(0) <= NOT wire_w_radce_lflck_range188w(0);
	wire_w_lg_w_rclkdiv_range155w163w(0) <= NOT wire_w_rclkdiv_range155w(0);
	wire_w_lg_w_rclkdiv_range150w151w(0) <= NOT wire_w_rclkdiv_range150w(0);
	wire_w_lg_w_rseq_sel_range543w555w(0) <= NOT wire_w_rseq_sel_range543w(0);
	wire_w_lg_w_lg_n0l0ll570w571w(0) <= wire_w_lg_n0l0ll570w(0) OR wire_w_lg_n0l0li547w(0);
	wire_w_lg_w_lg_n0l0ll570w671w(0) <= wire_w_lg_n0l0ll570w(0) OR n0l0ii;
	wire_w_lg_w_lg_radce_adapt255w256w(0) <= wire_w_lg_radce_adapt255w(0) OR radce_pdb;
	wire_w_lg_n0l0ii683w(0) <= n0l0ii OR wire_w_lg_n0l0il540w(0);
	wire_w_lg_w_rseq_sel_range541w965w(0) <= wire_w_rseq_sel_range541w(0) OR wire_w_lg_w_rseq_sel_range543w555w(0);
	adapt_done <= n0liii;
	atb0 <= wire_nii0O_dataout(0);
	atb1 <= wire_nii0l_dataout(0);
	atb_0 <= wire_nii0i_dataout(0);
	atb_1 <= wire_nii1O_dataout(0);
	e_clk <= n0li0i;
	eqa_ctrl <= wire_nl1O0l_dataout(0);
	eqb_ctrl <= wire_nl0i1i_dataout(0);
	eqc_ctrl <= wire_nl0Oll_dataout(0);
	eqctrlout <= ( nii10O & ni0O1l & ni0iOi & ni00iO & ni010l & ni1O1i);
	eqd_ctrl <= wire_nlii1l_dataout(0);
	eqv_ctrl <= wire_ni0ll_dataout(0);
	fine_d2aout <= '0';
	hf_adapt_done <= n0li1O;
	hfclk_macro <= wire_n0i1i_dataout(0);
	hfmac_cnt0_nclr <= n0li1l;
	hfmac_cnt2_nclr <= n0li1i;
	ib50u_c <= wire_nii1l_dataout(0);
	ib50u_t <= wire_nii1i_dataout(0);
	ibrgen1 <= '0';
	ibrgen2 <= '0';
	lf_adapt_done <= n0l0OO;
	lfclk_macro <= wire_n0l1O_dataout(0);
	lfmac_cnt0_nclr <= n0l0Ol;
	lfmac_cnt2_nclr <= n0l0Oi;
	n000il <= (n0lili AND wire_nl1lOi_dataout(0));
	n000iO <= (n000il AND n0liOO);
	n000li <= ((NOT wire_nl1llO_dataout(0)) AND wire_n0i1i_dataout(0));
	n000ll <= (n0O10l AND wire_nl1lOi_dataout(0));
	n000lO <= (n000ll AND n0O1li);
	n000Oi <= (n000Ol AND wire_w_lg_n0li1O1411w(0));
	n000Ol <= ((NOT (radce_hflck(7) OR radce_hflck(8))) AND (NOT (radce_hflck(9) OR radce_hflck(10))));
	n000OO <= ((NOT ((NOT ((NOT ((NOT radce_hflck(3)) AND n0lili)) AND (NOT wire_w_lg_w_radce_hflck_range1474w1479w(0)))) OR (NOT ((NOT ((NOT radce_hflck(4)) AND n0liOO)) AND (NOT wire_w_lg_w_radce_hflck_range1483w1488w(0)))))) AND (NOT ((NOT ((NOT ((NOT radce_hflck(5)) AND n0ll0l)) AND (NOT wire_w_lg_w_radce_hflck_range1494w1499w(0)))) OR (NOT ((NOT ((NOT radce_hflck(6)) AND n0llll)) AND (NOT wire_w_lg_w_radce_hflck_range1503w1508w(0)))))));
	n00i0i <= (ni11Ol AND wire_nl1lOi_dataout(0));
	n00i0l <= (n00i0i AND ni100i);
	n00i0O <= (n00iii AND wire_w_lg_n0l0OO1290w(0));
	n00i1i <= (n0Ol0i AND wire_nl1lOi_dataout(0));
	n00i1l <= (n00i1i AND n0OliO);
	n00i1O <= ((NOT wire_nl1llO_dataout(0)) AND wire_n0l1O_dataout(0));
	n00iii <= ((NOT (radce_lflck(7) OR radce_lflck(8))) AND (NOT (radce_lflck(9) OR radce_lflck(10))));
	n00iil <= ((NOT ((NOT ((NOT ((NOT radce_lflck(3)) AND n0Ol0i)) AND (NOT wire_w_lg_w_radce_lflck_range1353w1358w(0)))) OR (NOT ((NOT ((NOT radce_lflck(4)) AND n0OliO)) AND (NOT wire_w_lg_w_radce_lflck_range1362w1367w(0)))))) AND (NOT ((NOT ((NOT ((NOT radce_lflck(5)) AND n0OlOl)) AND (NOT wire_w_lg_w_radce_lflck_range1373w1378w(0)))) OR (NOT ((NOT ((NOT radce_lflck(6)) AND n0OO0l)) AND (NOT wire_w_lg_w_radce_lflck_range1382w1387w(0)))))));
	n00iiO <= wire_ni1OOi_w_lg_w_dataout_range1275w1278w(0);
	n00ili <= wire_ni001l_w_lg_w_dataout_range1256w1259w(0);
	n00ill <= (radce_adapt AND nl10OO);
	n00ilO <= (radce_adapt AND wire_nl10Ol_w_lg_nl10OO889w(0));
	n00iOi <= wire_ni0i0O_w_lg_w_dataout_range1237w1240w(0);
	n00iOl <= (n00ill AND ni1O1i);
	n00iOO <= (n00ilO AND ni1O1O);
	n00l0i <= wire_ni0OOl_w_lg_w_dataout_range1199w1202w(0);
	n00l0l <= (n00l1l AND ni00iO);
	n00l0O <= (n00l1O AND ni00ll);
	n00l1i <= wire_ni0lli_w_lg_w_dataout_range1218w1221w(0);
	n00l1l <= (n00iOl AND ni010l);
	n00l1O <= (n00iOO AND ni01ii);
	n00lii <= wire_nii01O_w_lg_w_dataout_range1177w1180w(0);
	n00lil <= (n00l0l AND ni0iOi);
	n00liO <= (n00l0O AND ni0iOO);
	n00lli <= wire_niiiii_w_lg_w_dataout_range1155w1158w(0);
	n00lll <= wire_niilll_w_lg_w_dataout_range1136w1139w(0);
	n00llO <= (n0i1Ol AND nl10OO);
	n00lOi <= (n0i1Ol AND wire_nl10Ol_w_lg_nl10OO889w(0));
	n00lOl <= wire_niiOOO_w_lg_w_dataout_range1117w1120w(0);
	n00lOO <= (n00llO AND nii0li);
	n00O0i <= (wire_w_lg_n0l0ll570w(0) AND wire_nl10Ol_w_lg_nl10OO889w(0));
	n00O0l <= (wire_w_lg_n00OiO948w(0) AND nl10OO);
	n00O0O <= ((wire_nii0iO_w_lg_nii0li939w(0) OR niiiOl) OR niiO1O);
	n00O1i <= (n00lOi AND nii0lO);
	n00O1l <= (n0i1OO AND (NOT (wire_w_lg_n00O0l967w(0) AND wire_w_lg_n00O0i969w(0))));
	n00O1O <= (wire_w_lg_n0i1OO968w(0) AND wire_w_lg_n00O0i969w(0));
	n00Oii <= ((nii0li OR wire_niiiOi_w_lg_niiiOl940w(0)) OR niiO1O);
	n00Oil <= ((wire_nii0iO_w_lg_nii0li939w(0) OR wire_niiiOi_w_lg_niiiOl940w(0)) OR niiO1O);
	n00OiO <= ((nii0li OR niiiOl) OR wire_niiO1l_w_lg_niiO1O937w(0));
	n00Oli <= (((NOT (wire_w_lg_n0l0ii1019w(0) AND wire_nl10Ol_w_lg_nl10OO889w(0))) AND (NOT (wire_w_lg_n0i10i1022w(0) AND wire_nl10Ol_w_lg_nl10OO889w(0)))) AND (NOT (wire_w_lg_n0l0ll570w(0) AND wire_nl10Ol_w_lg_nl10OO889w(0))));
	n00Oll <= ((NOT (wire_w_lg_n0l0ii1012w(0) AND wire_nl10Ol_w_lg_nl10OO889w(0))) AND (NOT (wire_w_lg_n0i11O1015w(0) AND wire_nl10Ol_w_lg_nl10OO889w(0))));
	n00OlO <= ((NOT ((NOT (((NOT rseq_sel(0)) AND rseq_sel(1)) AND n0l0ii)) AND (NOT (n0i11l AND wire_w_lg_n0l0il540w(0))))) AND wire_nl10Ol_w_lg_nl10OO889w(0));
	n00OOi <= ((n0l0ii AND n0i11i) AND wire_nl10Ol_w_lg_nl10OO889w(0));
	n00OOl <= ((NOT (n00Oll AND n00Oli)) OR (NOT (wire_w_lg_w_lg_n00OOi1030w1031w(0) AND wire_w_lg_n00OlO1032w(0))));
	n00OOO <= (((NOT ((wire_w_lg_n0i11l880w(0) AND wire_w_lg_n0l0il540w(0)) AND wire_nl10Ol_w_lg_nl10OO889w(0))) AND (NOT ((wire_w_lg_n0i11O875w(0) AND wire_w_lg_n0l0iO549w(0)) AND wire_nl10Ol_w_lg_nl10OO889w(0)))) AND (NOT ((wire_w_lg_n0i10i872w(0) AND wire_w_lg_n0l0li547w(0)) AND wire_nl10Ol_w_lg_nl10OO889w(0))));
	n0i00i <= (radce_adapt OR radce_pdb);
	n0i00l <= (rseq_sel(0) AND rseq_sel(1));
	n0i00O <= (radce_adapt OR radce_pdb);
	n0i01i <= (radce_adapt OR radce_pdb);
	n0i01l <= (rseq_sel(0) OR rseq_sel(1));
	n0i01O <= (radce_adapt OR radce_pdb);
	n0i0ii <= (rseq_sel(0) OR rseq_sel(1));
	n0i0li <= wire_nll0Oi_w_lg_w_dataout_range505w512w(0);
	n0i0Oi <= wire_nlll1l_w_lg_w_dataout_range482w489w(0);
	n0i0Ol <= (radce_adapt AND n1l1O);
	n0i0OO <= (radce_adapt AND wire_n1l1l_w_lg_n1l1O370w(0));
	n0i10i <= (rseq_sel(0) OR rseq_sel(1));
	n0i10l <= (radce_rstb AND nl10OO);
	n0i11i <= (rseq_sel(0) AND rseq_sel(1));
	n0i11l <= wire_w_lg_w_rseq_sel_range541w965w(0);
	n0i11O <= ((NOT rseq_sel(0)) OR rseq_sel(1));
	n0i1ll <= (((NOT ((NOT ((NOT rhyst_hf(0)) AND nl111i)) AND (NOT wire_w_lg_w_rhyst_hf_range826w831w(0)))) OR (NOT ((NOT ((NOT rhyst_hf(1)) AND nl11ii)) AND (NOT wire_w_lg_w_rhyst_hf_range835w840w(0))))) OR (NOT ((NOT ((NOT rhyst_hf(2)) AND nl11Ol)) AND (NOT wire_w_lg_w_rhyst_hf_range845w850w(0)))));
	n0i1lO <= ((rhyst_hf(0) OR rhyst_hf(1)) OR rhyst_hf(2));
	n0i1Oi <= (radce_adapt AND radce_rstb);
	n0i1Ol <= (radce_adapt AND n0i1OO);
	n0i1OO <= (((NOT ((NOT ((NOT (ni0iOi AND wire_nil1iO_w_lg_dataout1036w(0))) AND (NOT (wire_ni0ilO_w_lg_ni0iOi1039w(0) AND wire_nil1iO_dataout)))) OR wire_nl1llO_dataout(0))) AND (NOT ((NOT ((NOT (ni0O1l AND wire_nil1Oi_w_lg_dataout1046w(0))) AND (NOT (wire_ni0O1i_w_lg_ni0O1l1049w(0) AND wire_nil1Oi_dataout)))) OR (NOT ((NOT (nii10O AND wire_nil1OO_w_lg_dataout1054w(0))) AND (NOT (wire_nii10l_w_lg_nii10O1057w(0) AND wire_nil1OO_dataout))))))) AND ((NOT ((NOT ((NOT (ni00iO AND wire_nil1ii_w_lg_dataout1065w(0))) AND (NOT (wire_ni00il_w_lg_ni00iO1068w(0) AND wire_nil1ii_dataout)))) OR wire_nl1llO_dataout(0))) AND (NOT ((NOT ((NOT (ni1O1i AND wire_nil01l_w_lg_dataout1075w(0))) AND (NOT (wire_ni1lOO_w_lg_ni1O1i1078w(0) AND wire_nil01l_dataout)))) OR (NOT ((NOT (ni010l AND wire_nil10l_w_lg_dataout1083w(0))) AND (NOT (wire_ni010i_w_lg_ni010l1086w(0) AND wire_nil10l_dataout))))))));
	n0ii0i <= (n0i0OO AND nll01O);
	n0ii0O <= wire_nlO1li_w_lg_w_dataout_range442w445w(0);
	n0ii1l <= wire_nllO0O_w_lg_w_dataout_range461w466w(0);
	n0ii1O <= (n0i0Ol AND nll01i);
	n0iiii <= (n0ii1O AND nlli0l);
	n0iiil <= (n0ii0i AND nlliii);
	n0iili <= wire_nlO0Ol_w_lg_w_dataout_range417w422w(0);
	n0iill <= (n0iiii AND nllliO);
	n0iilO <= (n0iiil AND nlllll);
	n0iiOl <= wire_nlOl1O_w_lg_w_dataout_range396w399w(0);
	n0iiOO <= (n0iill AND nllOOi);
	n0il0O <= (((NOT ((NOT ((NOT rhyst_lf(0)) AND n100i)) AND (NOT wire_w_lg_w_rhyst_lf_range272w277w(0)))) OR (NOT ((NOT ((NOT rhyst_lf(1)) AND n10li)) AND (NOT wire_w_lg_w_rhyst_lf_range281w286w(0))))) OR (NOT ((NOT ((NOT rhyst_lf(2)) AND n1i1l)) AND (NOT wire_w_lg_w_rhyst_lf_range291w296w(0)))));
	n0il1i <= (n0iilO AND nllOOO);
	n0il1l <= (((NOT wire_nl1llO_w_lg_w_dataout_range35w319w(0)) AND (NOT ((NOT ((NOT (nlO01l AND wire_nlOlOl_w_lg_dataout321w(0))) AND (NOT (wire_nlO01i_w_lg_nlO01l324w(0) AND wire_nlOlOl_dataout)))) OR (NOT ((NOT (nlOi0O AND wire_nlOO1i_w_lg_dataout329w(0))) AND (NOT (wire_nlOi0l_w_lg_nlOi0O332w(0) AND wire_nlOO1i_dataout))))))) AND ((NOT wire_nl1llO_w_lg_w_dataout_range35w348w(0)) AND (NOT ((NOT ((NOT (nll01i AND wire_nlOO1O_w_lg_dataout350w(0))) AND (NOT (wire_nll1OO_w_lg_nll01i353w(0) AND wire_nlOO1O_dataout)))) OR (NOT ((NOT (nlli0l AND wire_nlOlil_w_lg_dataout358w(0))) AND (NOT (wire_nlli0i_w_lg_nlli0l361w(0) AND wire_nlOlil_dataout))))))));
	n0ilii <= ((rhyst_lf(0) OR rhyst_lf(1)) OR rhyst_lf(2));
	n0ilil <= (radce_adapt AND radce_rstb);
	n0illl <= '1';
	n0ilOl <= (n1O1l AND n1O0O);
	n0ilOO <= (n0iO1i AND n1OOl);
	n0iO0i <= ((NOT wire_w_lg_w_rclkdiv_range154w164w(0)) OR (NOT wire_w_lg_w_rclkdiv_range149w152w(0)));
	n0iO0l <= ((NOT (rclkdiv(0) AND rclkdiv(1))) OR (NOT ((NOT rclkdiv(2)) AND wire_w_lg_w_rclkdiv_range150w151w(0))));
	n0iO1i <= (n0ilOl AND n1Oli);
	n0iO1O <= ((NOT ((NOT rclkdiv(2)) AND wire_w_lg_w_rclkdiv_range150w151w(0))) OR (NOT wire_w_lg_w_rclkdiv_range154w164w(0)));
	n0iOil <= ((NOT wire_w_lg_w_rclkdiv_range149w152w(0)) OR (NOT ((NOT rclkdiv(0)) AND wire_w_lg_w_rclkdiv_range155w163w(0))));
	n0iOli <= ((NOT ((NOT rclkdiv(0)) AND wire_w_lg_w_rclkdiv_range155w163w(0))) OR (NOT ((NOT rclkdiv(2)) AND wire_w_lg_w_rclkdiv_range150w151w(0))));
	n0iOOl <= ((NOT ((NOT rclkdiv(2)) AND wire_w_lg_w_rclkdiv_range150w151w(0))) OR (NOT ((NOT rclkdiv(0)) AND rclkdiv(1))));
	n0iOOO <= ((NOT wire_w_lg_w_rclkdiv_range149w152w(0)) OR (NOT ((NOT rclkdiv(0)) AND rclkdiv(1))));
	n0l00l <= (((((radce_digital(2) AND radce_digital(3)) AND rhf_os(0)) AND rhf_os(1)) AND rhf_os(2)) AND rhf_os(3));
	n0l00O <= (((((radce_digital(4) AND radce_digital(5)) AND rlf_os(0)) AND rlf_os(1)) AND rlf_os(2)) AND rlf_os(3));
	n0l0ii <= ((NOT ((NOT ((rseq_sel(0) AND rseq_sel(1)) AND wire_w_lg_n00OiO948w(0))) AND (NOT (wire_w_lg_n00Oil951w(0) AND wire_w_lg_n0i11l880w(0))))) OR (NOT ((NOT (wire_w_lg_n00Oii956w(0) AND wire_w_lg_n0i11O875w(0))) AND (NOT (wire_w_lg_n00O0O959w(0) AND wire_w_lg_n0i10i872w(0))))));
	n0l0il <= ((NOT (wire_w_lg_n00Oil951w(0) AND n0i11i)) AND (NOT (wire_w_lg_n00OiO948w(0) AND wire_w_lg_n0i11i991w(0))));
	n0l0iO <= ((NOT (wire_w_lg_w_rseq_sel_range543w555w(0) AND wire_w_lg_n00Oil951w(0))) AND (NOT wire_w_lg_w_rseq_sel_range543w997w(0)));
	n0l0li <= ((NOT (wire_w_lg_n00O0O959w(0) AND n0i10i)) AND (NOT (wire_w_lg_n00Oii956w(0) AND wire_w_lg_n0i10i872w(0))));
	n0l0ll <= ((nii0li OR niiiOl) OR niiO1O);
	n0l0lO <= (wire_w_lg_n0l1Oi83w(0) AND (n0l1iO16 XOR n0l1iO15));
	n0l0Oi <= (radce_rstb AND (NOT (n00iil AND wire_ni1l0i_w_lg_ni1l0l1284w(0))));
	n0l0Ol <= (radce_rstb AND ni1lii);
	n0l0OO <= ((NOT ((NOT ((NOT ((NOT radce_lflck(11)) AND ni11Ol)) AND (NOT wire_w_lg_w_radce_lflck_range1292w1297w(0)))) OR (NOT ((NOT ((NOT radce_lflck(12)) AND ni100i)) AND (NOT wire_w_lg_w_radce_lflck_range1301w1306w(0)))))) AND (NOT ((NOT ((NOT ((NOT radce_lflck(13)) AND ni10iO)) AND (NOT wire_w_lg_w_radce_lflck_range1312w1317w(0)))) OR (NOT ((NOT ((NOT radce_lflck(14)) AND ni10OO)) AND (NOT wire_w_lg_w_radce_lflck_range1321w1326w(0)))))));
	n0l11i <= ((NOT wire_w_lg_w_rclkdiv_range149w152w(0)) OR (NOT (rclkdiv(0) AND rclkdiv(1))));
	n0l1il <= (fixed_clk AND n1lOl);
	n0l1Oi <= (radce_adapt AND wire_nl1lOi_dataout(0));
	n0li0i <= (wire_w_lg_n0l1Oi78w(0) AND (n0l1ll14 XOR n0l1ll13));
	n0li1i <= (radce_rstb AND (NOT (n000OO AND wire_n0Oili_w_lg_n0Oill1405w(0))));
	n0li1l <= (radce_rstb AND n0OiOi);
	n0li1O <= ((NOT ((NOT ((NOT ((NOT radce_hflck(11)) AND n0O10l)) AND (NOT wire_w_lg_w_radce_hflck_range1413w1418w(0)))) OR (NOT ((NOT ((NOT radce_hflck(12)) AND n0O1li)) AND (NOT wire_w_lg_w_radce_hflck_range1422w1427w(0)))))) AND (NOT ((NOT ((NOT ((NOT radce_hflck(13)) AND n0O1OO)) AND (NOT wire_w_lg_w_radce_hflck_range1433w1438w(0)))) OR (NOT ((NOT ((NOT radce_hflck(14)) AND n0O00O)) AND (NOT wire_w_lg_w_radce_hflck_range1442w1447w(0)))))));
	n0liii <= ((lock_lf_ovd OR (wire_w_lg_lock_lf_ovd1279w(0) AND n0l0OO)) AND n0li1O);
	outeqn <= wire_ni0OO_dataout(0);
	outeqp <= wire_ni0Ol_dataout(0);
	r_clk <= n0l0lO;
	rgenctrlout <= ( nlOi0O & nlO01l & nllOOi & nllliO & nlli0l & nll01i);
	tmxselan <= n0l0ll;
	tmxselbn <= n0l0li;
	tmxselcn <= n0l0iO;
	tmxseldn <= n0l0il;
	tmxselvn <= wire_w_lg_n0l0ii30w(0);
	updnn_hf <= n0l00O;
	updnn_lf <= wire_w_lg_n0l00l31w(0);
	vccehxqyx <= wire_ni0Oi_dataout(0);
	vccerxqyx <= wire_nl1lOi_dataout(0);
	vctl_quiet <= wire_ni0lO_dataout(0);
	vssexqyx <= wire_nl1llO_dataout(0);
	wire_w_eqa_set_range800w(0) <= eqa_set(0);
	wire_w_eqa_set_range802w(0) <= eqa_set(1);
	wire_w_eqb_set_range756w(0) <= eqb_set(0);
	wire_w_eqb_set_range758w(0) <= eqb_set(1);
	wire_w_eqc_set_range702w(0) <= eqc_set(0);
	wire_w_eqc_set_range704w(0) <= eqc_set(1);
	wire_w_eqd_set_range647w(0) <= eqd_set(0);
	wire_w_eqd_set_range649w(0) <= eqd_set(1);
	wire_w_eqv_set_range596w(0) <= eqv_set(0);
	wire_w_eqv_set_range597w(0) <= eqv_set(1);
	wire_w_radce_hflck_range213w(0) <= radce_hflck(0);
	wire_w_radce_hflck_range1413w(0) <= radce_hflck(11);
	wire_w_radce_hflck_range1422w(0) <= radce_hflck(12);
	wire_w_radce_hflck_range1433w(0) <= radce_hflck(13);
	wire_w_radce_hflck_range1442w(0) <= radce_hflck(14);
	wire_w_radce_hflck_range215w(0) <= radce_hflck(1);
	wire_w_radce_hflck_range1474w(0) <= radce_hflck(3);
	wire_w_radce_hflck_range1483w(0) <= radce_hflck(4);
	wire_w_radce_hflck_range1494w(0) <= radce_hflck(5);
	wire_w_radce_hflck_range1503w(0) <= radce_hflck(6);
	wire_w_radce_lflck_range186w(0) <= radce_lflck(0);
	wire_w_radce_lflck_range1292w(0) <= radce_lflck(11);
	wire_w_radce_lflck_range1301w(0) <= radce_lflck(12);
	wire_w_radce_lflck_range1312w(0) <= radce_lflck(13);
	wire_w_radce_lflck_range1321w(0) <= radce_lflck(14);
	wire_w_radce_lflck_range188w(0) <= radce_lflck(1);
	wire_w_radce_lflck_range1353w(0) <= radce_lflck(3);
	wire_w_radce_lflck_range1362w(0) <= radce_lflck(4);
	wire_w_radce_lflck_range1373w(0) <= radce_lflck(5);
	wire_w_radce_lflck_range1382w(0) <= radce_lflck(6);
	wire_w_rclkdiv_range154w(0) <= rclkdiv(0);
	wire_w_rclkdiv_range155w(0) <= rclkdiv(1);
	wire_w_rclkdiv_range149w(0) <= rclkdiv(2);
	wire_w_rclkdiv_range150w(0) <= rclkdiv(3);
	wire_w_rhyst_hf_range826w(0) <= rhyst_hf(0);
	wire_w_rhyst_hf_range835w(0) <= rhyst_hf(1);
	wire_w_rhyst_hf_range845w(0) <= rhyst_hf(2);
	wire_w_rhyst_lf_range272w(0) <= rhyst_lf(0);
	wire_w_rhyst_lf_range281w(0) <= rhyst_lf(1);
	wire_w_rhyst_lf_range291w(0) <= rhyst_lf(2);
	wire_w_rseq_sel_range541w(0) <= rseq_sel(0);
	wire_w_rseq_sel_range543w(0) <= rseq_sel(1);
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i0il69 <= n0i0il70;
		END IF;
		if (now = 0 ns) then
			n0i0il69 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i0il70 <= n0i0il69;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i0iO67 <= n0i0iO68;
		END IF;
		if (now = 0 ns) then
			n0i0iO67 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i0iO68 <= n0i0iO67;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i0ll65 <= n0i0ll66;
		END IF;
		if (now = 0 ns) then
			n0i0ll65 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i0ll66 <= n0i0ll65;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i0lO63 <= n0i0lO64;
		END IF;
		if (now = 0 ns) then
			n0i0lO63 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i0lO64 <= n0i0lO63;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i10O79 <= n0i10O80;
		END IF;
		if (now = 0 ns) then
			n0i10O79 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i10O80 <= n0i10O79;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i1ii77 <= n0i1ii78;
		END IF;
		if (now = 0 ns) then
			n0i1ii77 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i1ii78 <= n0i1ii77;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i1il75 <= n0i1il76;
		END IF;
		if (now = 0 ns) then
			n0i1il75 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i1il76 <= n0i1il75;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i1iO73 <= n0i1iO74;
		END IF;
		if (now = 0 ns) then
			n0i1iO73 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i1iO74 <= n0i1iO73;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i1li71 <= n0i1li72;
		END IF;
		if (now = 0 ns) then
			n0i1li71 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0i1li72 <= n0i1li71;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0ii0l59 <= n0ii0l60;
		END IF;
		if (now = 0 ns) then
			n0ii0l59 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0ii0l60 <= n0ii0l59;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0ii1i61 <= n0ii1i62;
		END IF;
		if (now = 0 ns) then
			n0ii1i61 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0ii1i62 <= n0ii1i61;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iiiO57 <= n0iiiO58;
		END IF;
		if (now = 0 ns) then
			n0iiiO57 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iiiO58 <= n0iiiO57;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iiOi55 <= n0iiOi56;
		END IF;
		if (now = 0 ns) then
			n0iiOi55 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iiOi56 <= n0iiOi55;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0il0i51 <= n0il0i52;
		END IF;
		if (now = 0 ns) then
			n0il0i51 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0il0i52 <= n0il0i51;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0il0l49 <= n0il0l50;
		END IF;
		if (now = 0 ns) then
			n0il0l49 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0il0l50 <= n0il0l49;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0il1O53 <= n0il1O54;
		END IF;
		if (now = 0 ns) then
			n0il1O53 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0il1O54 <= n0il1O53;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iliO47 <= n0iliO48;
		END IF;
		if (now = 0 ns) then
			n0iliO47 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iliO48 <= n0iliO47;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0illi45 <= n0illi46;
		END IF;
		if (now = 0 ns) then
			n0illi45 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0illi46 <= n0illi45;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0illO43 <= n0illO44;
		END IF;
		if (now = 0 ns) then
			n0illO43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0illO44 <= n0illO43;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0ilOi41 <= n0ilOi42;
		END IF;
		if (now = 0 ns) then
			n0ilOi41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0ilOi42 <= n0ilOi41;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iO0O37 <= n0iO0O38;
		END IF;
		if (now = 0 ns) then
			n0iO0O37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iO0O38 <= n0iO0O37;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iO1l39 <= n0iO1l40;
		END IF;
		if (now = 0 ns) then
			n0iO1l39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iO1l40 <= n0iO1l39;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iOii35 <= n0iOii36;
		END IF;
		if (now = 0 ns) then
			n0iOii35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iOii36 <= n0iOii35;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iOiO33 <= n0iOiO34;
		END IF;
		if (now = 0 ns) then
			n0iOiO33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iOiO34 <= n0iOiO33;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iOll31 <= n0iOll32;
		END IF;
		if (now = 0 ns) then
			n0iOll31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iOll32 <= n0iOll31;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iOlO29 <= n0iOlO30;
		END IF;
		if (now = 0 ns) then
			n0iOlO29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0iOlO30 <= n0iOlO29;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l00i1 <= n0l00i2;
		END IF;
		if (now = 0 ns) then
			n0l00i1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l00i2 <= n0l00i1;
		END IF;
	END PROCESS;
	wire_n0l00i2_w_lg_w_lg_q36w37w(0) <= wire_n0l00i2_w_lg_q36w(0) AND atb0;
	wire_n0l00i2_w_lg_q36w(0) <= n0l00i2 XOR n0l00i1;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l01i7 <= n0l01i8;
		END IF;
		if (now = 0 ns) then
			n0l01i7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l01i8 <= n0l01i7;
		END IF;
	END PROCESS;
	wire_n0l01i8_w_lg_w_lg_q56w57w(0) <= wire_n0l01i8_w_lg_q56w(0) AND ib50u_t;
	wire_n0l01i8_w_lg_q56w(0) <= n0l01i8 XOR n0l01i7;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l01l5 <= n0l01l6;
		END IF;
		if (now = 0 ns) then
			n0l01l5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l01l6 <= n0l01l5;
		END IF;
	END PROCESS;
	wire_n0l01l6_w_lg_w_lg_q52w53w(0) <= wire_n0l01l6_w_lg_q52w(0) AND ib50u_c;
	wire_n0l01l6_w_lg_q52w(0) <= n0l01l6 XOR n0l01l5;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l01O3 <= n0l01O4;
		END IF;
		if (now = 0 ns) then
			n0l01O3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l01O4 <= n0l01O3;
		END IF;
	END PROCESS;
	wire_n0l01O4_w_lg_w_lg_q48w49w(0) <= wire_n0l01O4_w_lg_q48w(0) AND atb_1;
	wire_n0l01O4_w_lg_q48w(0) <= n0l01O4 XOR n0l01O3;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l10i23 <= n0l10i24;
		END IF;
		if (now = 0 ns) then
			n0l10i23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l10i24 <= n0l10i23;
		END IF;
	END PROCESS;
	wire_n0l10i24_w_lg_w_lg_q104w105w(0) <= wire_n0l10i24_w_lg_q104w(0) AND wire_ni1Oi_dataout;
	wire_n0l10i24_w_lg_q104w(0) <= n0l10i24 XOR n0l10i23;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l10l21 <= n0l10l22;
		END IF;
		if (now = 0 ns) then
			n0l10l21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l10l22 <= n0l10l21;
		END IF;
	END PROCESS;
	wire_n0l10l22_w_lg_w_lg_q100w101w(0) <= wire_n0l10l22_w_lg_q100w(0) AND wire_ni1ll_dataout;
	wire_n0l10l22_w_lg_q100w(0) <= n0l10l22 XOR n0l10l21;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l10O19 <= n0l10O20;
		END IF;
		if (now = 0 ns) then
			n0l10O19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l10O20 <= n0l10O19;
		END IF;
	END PROCESS;
	wire_n0l10O20_w_lg_w_lg_q94w95w(0) <= wire_n0l10O20_w_lg_q94w(0) AND wire_ni1OO_dataout;
	wire_n0l10O20_w_lg_q94w(0) <= n0l10O20 XOR n0l10O19;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l11l27 <= n0l11l28;
		END IF;
		if (now = 0 ns) then
			n0l11l27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l11l28 <= n0l11l27;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l11O25 <= n0l11O26;
		END IF;
		if (now = 0 ns) then
			n0l11O25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l11O26 <= n0l11O25;
		END IF;
	END PROCESS;
	wire_n0l11O26_w_lg_w_lg_q107w108w(0) <= wire_n0l11O26_w_lg_q107w(0) AND wire_ni1Ol_dataout;
	wire_n0l11O26_w_lg_q107w(0) <= n0l11O26 XOR n0l11O25;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l1ii17 <= n0l1ii18;
		END IF;
		if (now = 0 ns) then
			n0l1ii17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l1ii18 <= n0l1ii17;
		END IF;
	END PROCESS;
	wire_n0l1ii18_w_lg_w_lg_q91w92w(0) <= wire_n0l1ii18_w_lg_q91w(0) AND wire_ni1iO_dataout;
	wire_n0l1ii18_w_lg_q91w(0) <= n0l1ii18 XOR n0l1ii17;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l1iO15 <= n0l1iO16;
		END IF;
		if (now = 0 ns) then
			n0l1iO15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l1iO16 <= n0l1iO15;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l1ll13 <= n0l1ll14;
		END IF;
		if (now = 0 ns) then
			n0l1ll13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l1ll14 <= n0l1ll13;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l1Ol11 <= n0l1Ol12;
		END IF;
		if (now = 0 ns) then
			n0l1Ol11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l1Ol12 <= n0l1Ol11;
		END IF;
	END PROCESS;
	wire_n0l1Ol12_w_lg_w_lg_q72w73w(0) <= wire_n0l1Ol12_w_lg_q72w(0) AND wire_nll11O_dataout;
	wire_n0l1Ol12_w_lg_q72w(0) <= n0l1Ol12 XOR n0l1Ol11;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l1OO10 <= n0l1OO9;
		END IF;
	END PROCESS;
	wire_n0l1OO10_w_lg_w_lg_q62w63w(0) <= wire_n0l1OO10_w_lg_q62w(0) AND outeqp;
	wire_n0l1OO10_w_lg_q62w(0) <= n0l1OO10 XOR n0l1OO9;
	PROCESS (wire_nl1i0l_dataout)
	BEGIN
		IF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN n0l1OO9 <= n0l1OO10;
		END IF;
		if (now = 0 ns) then
			n0l1OO9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (n0l1il, wire_n01ii_PRN, wire_n01ii_CLRN)
	BEGIN
		IF (wire_n01ii_PRN = '0') THEN
				n011O <= '1';
				n01il <= '1';
				n1O0O <= '1';
				n1O1l <= '1';
				n1Oli <= '1';
				n1OOl <= '1';
		ELSIF (wire_n01ii_CLRN = '0') THEN
				n011O <= '0';
				n01il <= '0';
				n1O0O <= '0';
				n1O1l <= '0';
				n1Oli <= '0';
				n1OOl <= '0';
		ELSIF (n0l1il = '1' AND n0l1il'event) THEN
				n011O <= wire_n011i_dataout;
				n01il <= wire_n010l_dataout;
				n1O0O <= wire_n1O0i_dataout;
				n1O1l <= wire_n1lOO_dataout;
				n1Oli <= wire_n1Oil_dataout;
				n1OOl <= wire_n1OlO_dataout;
		END IF;
	END PROCESS;
	wire_n01ii_CLRN <= ((n0illi46 XOR n0illi45) AND radce_rstb);
	wire_n01ii_PRN <= (n0iliO48 XOR n0iliO47);
	wire_n01ii_w_lg_n1O1l250w(0) <= NOT n1O1l;
	PROCESS (n0l1il, wire_n01iO_PRN, wire_n01iO_CLRN)
	BEGIN
		IF (wire_n01iO_PRN = '0') THEN
				n010i <= '1';
				n01li <= '1';
				n1O1O <= '1';
				n1Oii <= '1';
				n1Oll <= '1';
				n1OOO <= '1';
		ELSIF (wire_n01iO_CLRN = '0') THEN
				n010i <= '0';
				n01li <= '0';
				n1O1O <= '0';
				n1Oii <= '0';
				n1Oll <= '0';
				n1OOO <= '0';
		ELSIF (n0l1il = '1' AND n0l1il'event) THEN
				n010i <= wire_n011i_w_lg_dataout243w(0);
				n01li <= wire_n010l_w_lg_dataout234w(0);
				n1O1O <= wire_n1lOO_w_lg_dataout251w(0);
				n1Oii <= wire_n1O0i_w_lg_dataout249w(0);
				n1Oll <= wire_n1Oil_w_lg_dataout247w(0);
				n1OOO <= wire_n1OlO_w_lg_dataout245w(0);
		END IF;
		if (now = 0 ns) then
			n010i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n01li <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n1O1O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n1Oii <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n1Oll <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n1OOO <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_n01iO_CLRN <= (n0ilOi42 XOR n0ilOi41);
	wire_n01iO_PRN <= ((n0illO44 XOR n0illO43) AND radce_rstb);
	PROCESS (n000li, n0li1l)
	BEGIN
		IF (n0li1l = '0') THEN
				n0lili <= '0';
				n0liOO <= '0';
				n0ll0l <= '0';
				n0llll <= '0';
		ELSIF (n000li = '1' AND n000li'event) THEN
				n0lili <= wire_n0liil_dataout;
				n0liOO <= wire_n0liOi_dataout;
				n0ll0l <= wire_n0ll1O_dataout;
				n0llll <= wire_n0llil_dataout;
		END IF;
	END PROCESS;
	wire_n0llli_w_lg_n0lili1478w(0) <= NOT n0lili;
	wire_n0llli_w_lg_n0liOO1487w(0) <= NOT n0liOO;
	wire_n0llli_w_lg_n0ll0l1498w(0) <= NOT n0ll0l;
	wire_n0llli_w_lg_n0llll1507w(0) <= NOT n0llll;
	PROCESS (n000li, n0li1l)
	BEGIN
		IF (n0li1l = '0') THEN
				n0lill <= '1';
				n0ll0O <= '1';
				n0ll1i <= '1';
				n0llOi <= '1';
		ELSIF (n000li = '1' AND n000li'event) THEN
				n0lill <= wire_n0liil_w_lg_dataout1524w(0);
				n0ll0O <= wire_n0ll1O_w_lg_dataout1518w(0);
				n0ll1i <= wire_n0liOi_w_lg_dataout1521w(0);
				n0llOi <= wire_n0llil_w_lg_dataout1515w(0);
		END IF;
		if (now = 0 ns) then
			n0lill <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0ll0O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0ll1i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0llOi <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (n000Oi, n0li1i)
	BEGIN
		IF (n0li1i = '0') THEN
				n0O00O <= '0';
				n0O10l <= '0';
				n0O1li <= '0';
				n0O1OO <= '0';
		ELSIF (n000Oi = '1' AND n000Oi'event) THEN
				n0O00O <= wire_n0O01O_dataout;
				n0O10l <= wire_n0O11O_dataout;
				n0O1li <= wire_n0O1il_dataout;
				n0O1OO <= wire_n0O1Oi_dataout;
		END IF;
	END PROCESS;
	wire_n0O00l_w_lg_n0O00O1446w(0) <= NOT n0O00O;
	wire_n0O00l_w_lg_n0O10l1417w(0) <= NOT n0O10l;
	wire_n0O00l_w_lg_n0O1li1426w(0) <= NOT n0O1li;
	wire_n0O00l_w_lg_n0O1OO1437w(0) <= NOT n0O1OO;
	PROCESS (n000Oi, n0li1i)
	BEGIN
		IF (n0li1i = '0') THEN
				n0O01i <= '1';
				n0O0il <= '1';
				n0O10O <= '1';
				n0O1ll <= '1';
		ELSIF (n000Oi = '1' AND n000Oi'event) THEN
				n0O01i <= wire_n0O1Oi_w_lg_dataout1457w(0);
				n0O0il <= wire_n0O01O_w_lg_dataout1454w(0);
				n0O10O <= wire_n0O11O_w_lg_dataout1463w(0);
				n0O1ll <= wire_n0O1il_w_lg_dataout1460w(0);
		END IF;
		if (now = 0 ns) then
			n0O01i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0O0il <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0O10O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0O1ll <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_n0Oili_CLK, radce_rstb)
	BEGIN
		IF (radce_rstb = '0') THEN
				n0Oill <= '0';
		ELSIF (wire_n0Oili_CLK = '1' AND wire_n0Oili_CLK'event) THEN
				n0Oill <= n000Ol;
		END IF;
	END PROCESS;
	wire_n0Oili_CLK <= (NOT wire_n0i1i_dataout(0));
	wire_n0Oili_w_lg_n0Oill1405w(0) <= NOT n0Oill;
	PROCESS (wire_n0i1i_dataout(0), radce_rstb)
	BEGIN
		IF (radce_rstb = '0') THEN
				n0OiOi <= '0';
		ELSIF (wire_n0i1i_dataout(0) = '1' AND wire_n0i1i_dataout(0)'event) THEN
				n0OiOi <= wire_w_lg_n000OO1409w(0);
		END IF;
	END PROCESS;
	wire_n0OilO_CLK <= wire_n0i1i_dataout(0);
	PROCESS (n00i1O, n0l0Ol)
	BEGIN
		IF (n0l0Ol = '0') THEN
				n0Ol0i <= '0';
				n0OliO <= '0';
				n0OlOl <= '0';
				n0OO0l <= '0';
		ELSIF (n00i1O = '1' AND n00i1O'event) THEN
				n0Ol0i <= wire_n0Ol1l_dataout;
				n0OliO <= wire_n0Olii_dataout;
				n0OlOl <= wire_n0OllO_dataout;
				n0OO0l <= wire_n0OO1l_dataout;
		END IF;
	END PROCESS;
	wire_n0OO0i_w_lg_n0Ol0i1357w(0) <= NOT n0Ol0i;
	wire_n0OO0i_w_lg_n0OliO1366w(0) <= NOT n0OliO;
	wire_n0OO0i_w_lg_n0OlOl1377w(0) <= NOT n0OlOl;
	wire_n0OO0i_w_lg_n0OO0l1386w(0) <= NOT n0OO0l;
	PROCESS (n00i1O, n0l0Ol)
	BEGIN
		IF (n0l0Ol = '0') THEN
				n0Ol0l <= '1';
				n0Olli <= '1';
				n0OlOO <= '1';
				n0OOii <= '1';
		ELSIF (n00i1O = '1' AND n00i1O'event) THEN
				n0Ol0l <= wire_n0Ol1l_w_lg_dataout1403w(0);
				n0Olli <= wire_n0Olii_w_lg_dataout1400w(0);
				n0OlOO <= wire_n0OllO_w_lg_dataout1397w(0);
				n0OOii <= wire_n0OO1l_w_lg_dataout1394w(0);
		END IF;
		if (now = 0 ns) then
			n0Ol0l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0Olli <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0OlOO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0OOii <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (n0l0lO, wire_n1i1i_CLRN)
	BEGIN
		IF (wire_n1i1i_CLRN = '0') THEN
				n100i <= '0';
				n10li <= '0';
				n1i1l <= '0';
		ELSIF (n0l0lO = '1' AND n0l0lO'event) THEN
				n100i <= wire_n101l_dataout;
				n10li <= wire_n10il_dataout;
				n1i1l <= wire_n10Ol_dataout;
		END IF;
	END PROCESS;
	wire_n1i1i_CLRN <= ((n0il1O54 XOR n0il1O53) AND n0ilil);
	wire_n1i1i_w_lg_n100i276w(0) <= NOT n100i;
	wire_n1i1i_w_lg_n10li285w(0) <= NOT n10li;
	wire_n1i1i_w_lg_n1i1l295w(0) <= NOT n1i1l;
	PROCESS (n0l0lO, n0ilil)
	BEGIN
		IF (n0ilil = '0') THEN
				n100l <= '1';
				n10ll <= '1';
				n1i0i <= '1';
		ELSIF (n0l0lO = '1' AND n0l0lO'event) THEN
				n100l <= wire_n101l_w_lg_dataout310w(0);
				n10ll <= wire_n10il_w_lg_dataout309w(0);
				n1i0i <= wire_n10Ol_w_lg_dataout303w(0);
		END IF;
		if (now = 0 ns) then
			n100l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n10ll <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n1i0i <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (n0l0lO, wire_n1l0i_CLRN)
	BEGIN
		IF (wire_n1l0i_CLRN = '0') THEN
				n1l0l <= '0';
		ELSIF (n0l0lO = '0' AND n0l0lO'event) THEN
				n1l0l <= n0il0O;
		END IF;
	END PROCESS;
	wire_n1l0i_CLRN <= ((n0il0l50 XOR n0il0l49) AND radce_rstb);
	wire_n1l0i_w_lg_n1l0l263w(0) <= NOT n1l0l;
	PROCESS (wire_n1l0O_dataout, wire_n1l1l_PRN, wire_nl1lOi_dataout(0))
	BEGIN
		IF (wire_n1l1l_PRN = '0') THEN
				n1l1O <= '1';
		ELSIF (wire_nl1lOi_dataout(0) = '0') THEN
				n1l1O <= '0';
		ELSIF (wire_n1l0O_dataout = '1' AND wire_n1l0O_dataout'event) THEN
				n1l1O <= wire_w_lg_n0l00l31w(0);
		END IF;
	END PROCESS;
	wire_n1l1l_CLRN <= wire_nl1lOi_dataout(0);
	wire_n1l1l_PRN <= ((n0il0i52 XOR n0il0i51) AND (NOT (wire_w_lg_radce_rstb267w(0) AND wire_nl1lOi_dataout(0))));
	wire_n1l1l_w_lg_n1l1O370w(0) <= NOT n1l1O;
	PROCESS (fixed_clk, radce_rstb)
	BEGIN
		IF (radce_rstb = '0') THEN
				n1llO <= '0';
				n1lOl <= '0';
		ELSIF (fixed_clk = '0' AND fixed_clk'event) THEN
				n1llO <= (NOT ((adapt_capture OR standby) OR wire_w_lg_n0liii258w(0)));
				n1lOl <= n1llO;
		END IF;
	END PROCESS;
	PROCESS (wire_nl1i0l_dataout, n00iOi, wire_ni0i0O_w_dataout_range1237w(0))
	BEGIN
		IF (n00iOi = '1') THEN
				ni00iO <= '1';
		ELSIF (wire_ni0i0O_w_dataout_range1237w(0) = '0') THEN
				ni00iO <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				ni00iO <= wire_ni00Ol_dataout;
		END IF;
	END PROCESS;
	wire_ni00il_CLRN <= wire_ni0i0O_dataout(0);
	wire_ni00il_w_lg_ni00iO1068w(0) <= NOT ni00iO;
	PROCESS (wire_nl1i0l_dataout, wire_ni0i0O_w_dataout_range1237w(0), n00iOi)
	BEGIN
		IF (wire_ni0i0O_w_dataout_range1237w(0) = '0') THEN
				ni00ll <= '1';
		ELSIF (n00iOi = '1') THEN
				ni00ll <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				ni00ll <= wire_ni00Ol_w_lg_dataout1235w(0);
		END IF;
	END PROCESS;
	wire_ni00li_PRN <= wire_ni0i0O_dataout(0);
	PROCESS (wire_nl1i0l_dataout, n00ili, wire_ni001l_w_dataout_range1256w(0))
	BEGIN
		IF (n00ili = '1') THEN
				ni010l <= '1';
		ELSIF (wire_ni001l_w_dataout_range1256w(0) = '0') THEN
				ni010l <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				ni010l <= wire_ni01li_dataout;
		END IF;
	END PROCESS;
	wire_ni010i_CLRN <= wire_ni001l_dataout(0);
	wire_ni010i_w_lg_ni010l1086w(0) <= NOT ni010l;
	PROCESS (wire_nl1i0l_dataout, wire_ni001l_w_dataout_range1256w(0), n00ili)
	BEGIN
		IF (wire_ni001l_w_dataout_range1256w(0) = '0') THEN
				ni01ii <= '1';
		ELSIF (n00ili = '1') THEN
				ni01ii <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				ni01ii <= wire_ni01li_w_lg_dataout1254w(0);
		END IF;
	END PROCESS;
	wire_ni010O_PRN <= wire_ni001l_dataout(0);
	PROCESS (wire_nl1i0l_dataout, n00l1i, wire_ni0lli_w_dataout_range1218w(0))
	BEGIN
		IF (n00l1i = '1') THEN
				ni0iOi <= '1';
		ELSIF (wire_ni0lli_w_dataout_range1218w(0) = '0') THEN
				ni0iOi <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				ni0iOi <= wire_ni0l1O_dataout;
		END IF;
	END PROCESS;
	wire_ni0ilO_CLRN <= wire_ni0lli_dataout(0);
	wire_ni0ilO_w_lg_ni0iOi1039w(0) <= NOT ni0iOi;
	PROCESS (wire_nl1i0l_dataout, wire_ni0lli_w_dataout_range1218w(0), n00l1i)
	BEGIN
		IF (wire_ni0lli_w_dataout_range1218w(0) = '0') THEN
				ni0iOO <= '1';
		ELSIF (n00l1i = '1') THEN
				ni0iOO <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				ni0iOO <= wire_ni0l1O_w_lg_dataout1216w(0);
		END IF;
	END PROCESS;
	wire_ni0iOl_PRN <= wire_ni0lli_dataout(0);
	PROCESS (wire_nl1i0l_dataout, n00l0i, wire_ni0OOl_w_dataout_range1199w(0))
	BEGIN
		IF (n00l0i = '1') THEN
				ni0O1l <= '1';
		ELSIF (wire_ni0OOl_w_dataout_range1199w(0) = '0') THEN
				ni0O1l <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				ni0O1l <= wire_ni0Oii_dataout;
		END IF;
	END PROCESS;
	wire_ni0O1i_CLRN <= wire_ni0OOl_dataout(0);
	wire_ni0O1i_w_lg_ni0O1l1049w(0) <= NOT ni0O1l;
	PROCESS (wire_nl1i0l_dataout, wire_ni0OOl_w_dataout_range1199w(0), n00l0i)
	BEGIN
		IF (wire_ni0OOl_w_dataout_range1199w(0) = '0') THEN
				ni0O0i <= '1';
		ELSIF (n00l0i = '1') THEN
				ni0O0i <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				ni0O0i <= wire_ni0Oii_w_lg_dataout1197w(0);
		END IF;
	END PROCESS;
	wire_ni0O1O_PRN <= wire_ni0OOl_dataout(0);
	PROCESS (n00i0O, n0l0Oi)
	BEGIN
		IF (n0l0Oi = '0') THEN
				ni100i <= '0';
				ni10iO <= '0';
				ni10OO <= '0';
				ni11Ol <= '0';
		ELSIF (n00i0O = '1' AND n00i0O'event) THEN
				ni100i <= wire_ni101l_dataout;
				ni10iO <= wire_ni10ii_dataout;
				ni10OO <= wire_ni10lO_dataout;
				ni11Ol <= wire_ni11lO_dataout;
		END IF;
	END PROCESS;
	wire_ni10Ol_w_lg_ni100i1305w(0) <= NOT ni100i;
	wire_ni10Ol_w_lg_ni10iO1316w(0) <= NOT ni10iO;
	wire_ni10Ol_w_lg_ni10OO1325w(0) <= NOT ni10OO;
	wire_ni10Ol_w_lg_ni11Ol1296w(0) <= NOT ni11Ol;
	PROCESS (n00i0O, n0l0Oi)
	BEGIN
		IF (n0l0Oi = '0') THEN
				ni100l <= '1';
				ni10li <= '1';
				ni11OO <= '1';
				ni1i1l <= '1';
		ELSIF (n00i0O = '1' AND n00i0O'event) THEN
				ni100l <= wire_ni101l_w_lg_dataout1339w(0);
				ni10li <= wire_ni10ii_w_lg_dataout1336w(0);
				ni11OO <= wire_ni11lO_w_lg_dataout1342w(0);
				ni1i1l <= wire_ni10lO_w_lg_dataout1333w(0);
		END IF;
		if (now = 0 ns) then
			ni100l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni10li <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni11OO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni1i1l <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (wire_ni1l0i_CLK, radce_rstb)
	BEGIN
		IF (radce_rstb = '0') THEN
				ni1l0l <= '0';
		ELSIF (wire_ni1l0i_CLK = '1' AND wire_ni1l0i_CLK'event) THEN
				ni1l0l <= n00iii;
		END IF;
	END PROCESS;
	wire_ni1l0i_CLK <= (NOT wire_n0l1O_dataout(0));
	wire_ni1l0i_w_lg_ni1l0l1284w(0) <= NOT ni1l0l;
	PROCESS (wire_n0l1O_dataout(0), radce_rstb)
	BEGIN
		IF (radce_rstb = '0') THEN
				ni1lii <= '0';
		ELSIF (wire_n0l1O_dataout(0) = '1' AND wire_n0l1O_dataout(0)'event) THEN
				ni1lii <= wire_w_lg_n00iil1288w(0);
		END IF;
	END PROCESS;
	wire_ni1l0O_CLK <= wire_n0l1O_dataout(0);
	PROCESS (wire_nl1i0l_dataout, n00iiO, wire_ni1OOi_w_dataout_range1275w(0))
	BEGIN
		IF (n00iiO = '1') THEN
				ni1O1i <= '1';
		ELSIF (wire_ni1OOi_w_dataout_range1275w(0) = '0') THEN
				ni1O1i <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				ni1O1i <= wire_ni1O0O_dataout;
		END IF;
	END PROCESS;
	wire_ni1lOO_CLRN <= wire_ni1OOi_dataout(0);
	wire_ni1lOO_w_lg_ni1O1i1078w(0) <= NOT ni1O1i;
	PROCESS (wire_nl1i0l_dataout, wire_ni1OOi_w_dataout_range1275w(0), n00iiO)
	BEGIN
		IF (wire_ni1OOi_w_dataout_range1275w(0) = '0') THEN
				ni1O1O <= '1';
		ELSIF (n00iiO = '1') THEN
				ni1O1O <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				ni1O1O <= wire_ni1O0O_w_lg_dataout1273w(0);
		END IF;
	END PROCESS;
	wire_ni1O1l_PRN <= wire_ni1OOi_dataout(0);
	PROCESS (wire_nl1i0l_dataout, n00lli, wire_niiiii_w_dataout_range1155w(0))
	BEGIN
		IF (n00lli = '1') THEN
				nii0li <= '1';
		ELSIF (wire_niiiii_w_dataout_range1155w(0) = '0') THEN
				nii0li <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				nii0li <= wire_nii0OO_dataout;
		END IF;
	END PROCESS;
	wire_nii0iO_CLRN <= wire_niiiii_dataout(0);
	wire_nii0iO_w_lg_nii0li939w(0) <= NOT nii0li;
	PROCESS (wire_nl1i0l_dataout, wire_niiiii_w_dataout_range1155w(0), n00lli)
	BEGIN
		IF (wire_niiiii_w_dataout_range1155w(0) = '0') THEN
				nii0lO <= '1';
		ELSIF (n00lli = '1') THEN
				nii0lO <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				nii0lO <= wire_nii0OO_w_lg_dataout1153w(0);
		END IF;
	END PROCESS;
	wire_nii0ll_PRN <= wire_niiiii_dataout(0);
	PROCESS (wire_nl1i0l_dataout, n00lii, wire_nii01O_w_dataout_range1177w(0))
	BEGIN
		IF (n00lii = '1') THEN
				nii10O <= '1';
		ELSIF (wire_nii01O_w_dataout_range1177w(0) = '0') THEN
				nii10O <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				nii10O <= wire_nii1ll_dataout;
		END IF;
	END PROCESS;
	wire_nii10l_CLRN <= wire_nii01O_dataout(0);
	wire_nii10l_w_lg_nii10O1057w(0) <= NOT nii10O;
	PROCESS (wire_nl1i0l_dataout, wire_nii01O_w_dataout_range1177w(0), n00lii)
	BEGIN
		IF (wire_nii01O_w_dataout_range1177w(0) = '0') THEN
				nii1il <= '1';
		ELSIF (n00lii = '1') THEN
				nii1il <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				nii1il <= wire_nii1ll_w_lg_dataout1175w(0);
		END IF;
	END PROCESS;
	wire_nii1ii_PRN <= wire_nii01O_dataout(0);
	PROCESS (wire_nl1i0l_dataout, n00lll, wire_niilll_w_dataout_range1136w(0))
	BEGIN
		IF (n00lll = '1') THEN
				niiiOl <= '1';
		ELSIF (wire_niilll_w_dataout_range1136w(0) = '0') THEN
				niiiOl <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				niiiOl <= wire_niil0i_dataout;
		END IF;
	END PROCESS;
	wire_niiiOi_CLRN <= wire_niilll_dataout(0);
	wire_niiiOi_w_lg_niiiOl940w(0) <= NOT niiiOl;
	PROCESS (wire_nl1i0l_dataout, wire_niilll_w_dataout_range1136w(0), n00lll)
	BEGIN
		IF (wire_niilll_w_dataout_range1136w(0) = '0') THEN
				niil1i <= '1';
		ELSIF (n00lll = '1') THEN
				niil1i <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				niil1i <= wire_niil0i_w_lg_dataout1134w(0);
		END IF;
	END PROCESS;
	wire_niiiOO_PRN <= wire_niilll_dataout(0);
	PROCESS (wire_nl1i0l_dataout, wire_niiOOO_w_dataout_range1117w(0), n00lOl)
	BEGIN
		IF (wire_niiOOO_w_dataout_range1117w(0) = '0') THEN
				niiO0l <= '1';
		ELSIF (n00lOl = '1') THEN
				niiO0l <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				niiO0l <= wire_niiOil_w_lg_dataout1115w(0);
		END IF;
	END PROCESS;
	wire_niiO0i_PRN <= wire_niiOOO_dataout(0);
	PROCESS (wire_nl1i0l_dataout, n00lOl, wire_niiOOO_w_dataout_range1117w(0))
	BEGIN
		IF (n00lOl = '1') THEN
				niiO1O <= '1';
		ELSIF (wire_niiOOO_w_dataout_range1117w(0) = '0') THEN
				niiO1O <= '0';
		ELSIF (wire_nl1i0l_dataout = '1' AND wire_nl1i0l_dataout'event) THEN
				niiO1O <= wire_niiOil_dataout;
		END IF;
	END PROCESS;
	wire_niiO1l_CLRN <= wire_niiOOO_dataout(0);
	wire_niiO1l_w_lg_niiO1O937w(0) <= NOT niiO1O;
	PROCESS (wire_nl1i1O_dataout, wire_nl10Ol_PRN, wire_nl1lOi_dataout(0))
	BEGIN
		IF (wire_nl10Ol_PRN = '0') THEN
				nl10OO <= '1';
		ELSIF (wire_nl1lOi_dataout(0) = '0') THEN
				nl10OO <= '0';
		ELSIF (wire_nl1i1O_dataout = '1' AND wire_nl1i1O_dataout'event) THEN
				nl10OO <= n0l00O;
		END IF;
	END PROCESS;
	wire_nl10Ol_CLRN <= wire_nl1lOi_dataout(0);
	wire_nl10Ol_PRN <= ((n0i1iO74 XOR n0i1iO73) AND (NOT (wire_w_lg_radce_rstb267w(0) AND wire_nl1lOi_dataout(0))));
	wire_nl10Ol_w_lg_nl10OO889w(0) <= NOT nl10OO;
	PROCESS (n0li0i, wire_nl11Oi_PRN, wire_nl11Oi_CLRN)
	BEGIN
		IF (wire_nl11Oi_PRN = '0') THEN
				nl111i <= '1';
				nl11ii <= '1';
				nl11Ol <= '1';
		ELSIF (wire_nl11Oi_CLRN = '0') THEN
				nl111i <= '0';
				nl11ii <= '0';
				nl11Ol <= '0';
		ELSIF (n0li0i = '1' AND n0li0i'event) THEN
				nl111i <= wire_niOOOl_dataout;
				nl11ii <= wire_nl110l_dataout;
				nl11Ol <= wire_nl11ll_dataout;
		END IF;
	END PROCESS;
	wire_nl11Oi_CLRN <= ((n0i1ii78 XOR n0i1ii77) AND n0i1Oi);
	wire_nl11Oi_PRN <= (n0i10O80 XOR n0i10O79);
	wire_nl11Oi_w_lg_nl111i830w(0) <= NOT nl111i;
	wire_nl11Oi_w_lg_nl11ii839w(0) <= NOT nl11ii;
	wire_nl11Oi_w_lg_nl11Ol849w(0) <= NOT nl11Ol;
	PROCESS (n0li0i, n0i1Oi, wire_nl11OO_CLRN)
	BEGIN
		IF (n0i1Oi = '0') THEN
				nl101i <= '1';
				nl111l <= '1';
				nl11il <= '1';
		ELSIF (wire_nl11OO_CLRN = '0') THEN
				nl101i <= '0';
				nl111l <= '0';
				nl11il <= '0';
		ELSIF (n0li0i = '1' AND n0li0i'event) THEN
				nl101i <= wire_nl11ll_w_lg_dataout857w(0);
				nl111l <= wire_niOOOl_w_lg_dataout866w(0);
				nl11il <= wire_nl110l_w_lg_dataout865w(0);
		END IF;
		if (now = 0 ns) then
			nl101i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl111l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl11il <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nl11OO_CLRN <= (n0i1il76 XOR n0i1il75);
	PROCESS (n0li0i, wire_nl1i1i_CLRN)
	BEGIN
		IF (wire_nl1i1i_CLRN = '0') THEN
				nl1i1l <= '0';
		ELSIF (n0li0i = '0' AND n0li0i'event) THEN
				nl1i1l <= n0i1ll;
		END IF;
	END PROCESS;
	wire_nl1i1i_CLRN <= ((n0i1li72 XOR n0i1li71) AND radce_rstb);
	wire_nl1i1i_w_lg_nl1i1l820w(0) <= NOT nl1i1l;
	PROCESS (wire_n1lil_dataout, wire_nll01l_PRN, n0i0li)
	BEGIN
		IF (wire_nll01l_PRN = '0') THEN
				nll01O <= '1';
		ELSIF (n0i0li = '1') THEN
				nll01O <= '0';
		ELSIF (wire_n1lil_dataout = '1' AND wire_n1lil_dataout'event) THEN
				nll01O <= wire_nll00O_w_lg_dataout503w(0);
		END IF;
	END PROCESS;
	wire_nll01l_PRN <= ((n0i0iO68 XOR n0i0iO67) AND wire_nll0Oi_dataout(0));
	PROCESS (wire_n1lil_dataout, n0i0li, wire_nll1OO_CLRN)
	BEGIN
		IF (n0i0li = '1') THEN
				nll01i <= '1';
		ELSIF (wire_nll1OO_CLRN = '0') THEN
				nll01i <= '0';
		ELSIF (wire_n1lil_dataout = '1' AND wire_n1lil_dataout'event) THEN
				nll01i <= wire_nll00O_dataout;
		END IF;
	END PROCESS;
	wire_nll1OO_CLRN <= ((n0i0il70 XOR n0i0il69) AND wire_nll0Oi_dataout(0));
	wire_nll1OO_w_lg_nll01i353w(0) <= NOT nll01i;
	PROCESS (wire_n1lil_dataout, wire_nlli0i_PRN, wire_nlll1l_w_dataout_range482w(0))
	BEGIN
		IF (wire_nlli0i_PRN = '0') THEN
				nlli0l <= '1';
		ELSIF (wire_nlll1l_w_dataout_range482w(0) = '0') THEN
				nlli0l <= '0';
		ELSIF (wire_n1lil_dataout = '1' AND wire_n1lil_dataout'event) THEN
				nlli0l <= wire_nllili_dataout;
		END IF;
	END PROCESS;
	wire_nlli0i_CLRN <= wire_nlll1l_dataout(0);
	wire_nlli0i_PRN <= ((n0i0ll66 XOR n0i0ll65) AND wire_w_lg_n0i0Oi481w(0));
	wire_nlli0i_w_lg_nlli0l361w(0) <= NOT nlli0l;
	PROCESS (wire_n1lil_dataout, wire_nlli0O_PRN, n0i0Oi)
	BEGIN
		IF (wire_nlli0O_PRN = '0') THEN
				nlliii <= '1';
		ELSIF (n0i0Oi = '1') THEN
				nlliii <= '0';
		ELSIF (wire_n1lil_dataout = '1' AND wire_n1lil_dataout'event) THEN
				nlliii <= wire_nllili_w_lg_dataout480w(0);
		END IF;
	END PROCESS;
	wire_nlli0O_PRN <= ((n0i0lO64 XOR n0i0lO63) AND wire_nlll1l_dataout(0));
	PROCESS (wire_n1lil_dataout, wire_nlllil_PRN, wire_nllO0O_w_dataout_range461w(0))
	BEGIN
		IF (wire_nlllil_PRN = '0') THEN
				nllliO <= '1';
		ELSIF (wire_nllO0O_w_dataout_range461w(0) = '0') THEN
				nllliO <= '0';
		ELSIF (wire_n1lil_dataout = '1' AND wire_n1lil_dataout'event) THEN
				nllliO <= wire_nlllOl_dataout;
		END IF;
	END PROCESS;
	wire_nlllil_CLRN <= wire_nllO0O_dataout(0);
	wire_nlllil_PRN <= ((n0ii1i62 XOR n0ii1i61) AND wire_w_lg_n0ii1l460w(0));
	wire_nlllil_w_lg_w_lg_w_lg_nllliO341w342w346w(0) <= wire_nlllil_w_lg_w_lg_nllliO341w342w(0) AND wire_nlllil_w_lg_w_lg_w_lg_nllliO343w344w345w(0);
	wire_nlllil_w_lg_w_lg_nllliO343w344w(0) <= wire_nlllil_w_lg_nllliO343w(0) AND wire_nlOlli_dataout;
	wire_nlllil_w_lg_nllliO341w(0) <= nllliO AND wire_nlOlli_w_lg_dataout340w(0);
	wire_nlllil_w_lg_w_lg_w_lg_w_lg_nllliO341w342w346w347w(0) <= NOT wire_nlllil_w_lg_w_lg_w_lg_nllliO341w342w346w(0);
	wire_nlllil_w_lg_w_lg_w_lg_nllliO343w344w345w(0) <= NOT wire_nlllil_w_lg_w_lg_nllliO343w344w(0);
	wire_nlllil_w_lg_w_lg_nllliO341w342w(0) <= NOT wire_nlllil_w_lg_nllliO341w(0);
	wire_nlllil_w_lg_nllliO343w(0) <= NOT nllliO;
	PROCESS (wire_n1lil_dataout, wire_nllO0O_w_dataout_range461w(0), n0ii1l)
	BEGIN
		IF (wire_nllO0O_w_dataout_range461w(0) = '0') THEN
				nlllll <= '1';
		ELSIF (n0ii1l = '1') THEN
				nlllll <= '0';
		ELSIF (wire_n1lil_dataout = '1' AND wire_n1lil_dataout'event) THEN
				nlllll <= wire_nlllOl_w_lg_dataout459w(0);
		END IF;
	END PROCESS;
	wire_nlllli_PRN <= wire_nllO0O_dataout(0);
	PROCESS (wire_n1lil_dataout, n0ii0O, wire_nlO1li_w_dataout_range442w(0))
	BEGIN
		IF (n0ii0O = '1') THEN
				nllOOi <= '1';
		ELSIF (wire_nlO1li_w_dataout_range442w(0) = '0') THEN
				nllOOi <= '0';
		ELSIF (wire_n1lil_dataout = '1' AND wire_n1lil_dataout'event) THEN
				nllOOi <= wire_nlO11O_dataout;
		END IF;
	END PROCESS;
	wire_nllOlO_CLRN <= wire_nlO1li_dataout(0);
	wire_nllOlO_w_lg_w_lg_w_lg_nllOOi312w313w317w(0) <= wire_nllOlO_w_lg_w_lg_nllOOi312w313w(0) AND wire_nllOlO_w_lg_w_lg_w_lg_nllOOi314w315w316w(0);
	wire_nllOlO_w_lg_w_lg_nllOOi314w315w(0) <= wire_nllOlO_w_lg_nllOOi314w(0) AND wire_nlOllO_dataout;
	wire_nllOlO_w_lg_nllOOi312w(0) <= nllOOi AND wire_nlOllO_w_lg_dataout311w(0);
	wire_nllOlO_w_lg_w_lg_w_lg_w_lg_nllOOi312w313w317w318w(0) <= NOT wire_nllOlO_w_lg_w_lg_w_lg_nllOOi312w313w317w(0);
	wire_nllOlO_w_lg_w_lg_w_lg_nllOOi314w315w316w(0) <= NOT wire_nllOlO_w_lg_w_lg_nllOOi314w315w(0);
	wire_nllOlO_w_lg_w_lg_nllOOi312w313w(0) <= NOT wire_nllOlO_w_lg_nllOOi312w(0);
	wire_nllOlO_w_lg_nllOOi314w(0) <= NOT nllOOi;
	PROCESS (wire_n1lil_dataout, wire_nlO1li_w_dataout_range442w(0), wire_nllOOl_CLRN)
	BEGIN
		IF (wire_nlO1li_w_dataout_range442w(0) = '0') THEN
				nllOOO <= '1';
		ELSIF (wire_nllOOl_CLRN = '0') THEN
				nllOOO <= '0';
		ELSIF (wire_n1lil_dataout = '1' AND wire_n1lil_dataout'event) THEN
				nllOOO <= wire_nlO11O_w_lg_dataout438w(0);
		END IF;
	END PROCESS;
	wire_nllOOl_CLRN <= ((n0ii0l60 XOR n0ii0l59) AND wire_w_lg_n0ii0O440w(0));
	wire_nllOOl_PRN <= wire_nlO1li_dataout(0);
	PROCESS (wire_n1lil_dataout, n0iili, wire_nlO0Ol_w_dataout_range417w(0))
	BEGIN
		IF (n0iili = '1') THEN
				nlO01l <= '1';
		ELSIF (wire_nlO0Ol_w_dataout_range417w(0) = '0') THEN
				nlO01l <= '0';
		ELSIF (wire_n1lil_dataout = '1' AND wire_n1lil_dataout'event) THEN
				nlO01l <= wire_nlO0ii_dataout;
		END IF;
	END PROCESS;
	wire_nlO01i_CLRN <= wire_nlO0Ol_dataout(0);
	wire_nlO01i_w_lg_nlO01l324w(0) <= NOT nlO01l;
	PROCESS (wire_n1lil_dataout, wire_nlO01O_PRN, n0iili)
	BEGIN
		IF (wire_nlO01O_PRN = '0') THEN
				nlO00i <= '1';
		ELSIF (n0iili = '1') THEN
				nlO00i <= '0';
		ELSIF (wire_n1lil_dataout = '1' AND wire_n1lil_dataout'event) THEN
				nlO00i <= wire_nlO0ii_w_lg_dataout415w(0);
		END IF;
	END PROCESS;
	wire_nlO01O_PRN <= ((n0iiiO58 XOR n0iiiO57) AND wire_nlO0Ol_dataout(0));
	PROCESS (wire_n1lil_dataout, n0iiOl, wire_nlOl1O_w_dataout_range396w(0))
	BEGIN
		IF (n0iiOl = '1') THEN
				nlOi0O <= '1';
		ELSIF (wire_nlOl1O_w_dataout_range396w(0) = '0') THEN
				nlOi0O <= '0';
		ELSIF (wire_n1lil_dataout = '1' AND wire_n1lil_dataout'event) THEN
				nlOi0O <= wire_nlOill_dataout;
		END IF;
	END PROCESS;
	wire_nlOi0l_CLRN <= wire_nlOl1O_dataout(0);
	wire_nlOi0l_w_lg_nlOi0O332w(0) <= NOT nlOi0O;
	PROCESS (wire_n1lil_dataout, wire_nlOl1O_w_dataout_range396w(0), wire_nlOiii_CLRN)
	BEGIN
		IF (wire_nlOl1O_w_dataout_range396w(0) = '0') THEN
				nlOiil <= '1';
		ELSIF (wire_nlOiii_CLRN = '0') THEN
				nlOiil <= '0';
		ELSIF (wire_n1lil_dataout = '1' AND wire_n1lil_dataout'event) THEN
				nlOiil <= wire_nlOill_w_lg_dataout392w(0);
		END IF;
	END PROCESS;
	wire_nlOiii_CLRN <= ((n0iiOi56 XOR n0iiOi55) AND wire_w_lg_n0iiOl394w(0));
	wire_nlOiii_PRN <= wire_nlOl1O_dataout(0);
	wire_n00il_oe <= wire_w_lg_w_lg_w_radce_hflck_range213w225w230w(0);
	wire_w_lg_w_lg_w_radce_hflck_range213w225w230w(0) <= (radce_hflck(0) AND radce_hflck(1)) AND radce_hflck(2);
	n00il :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1llO_dataout(0),
		dataout => wire_n00il_dataout,
		oe => wire_n00il_oe
	  );
	wire_n00iO_oe <= wire_w_lg_w_lg_w_lg_w_radce_hflck_range213w214w223w229w(0);
	wire_w_lg_w_lg_w_lg_w_radce_hflck_range213w214w223w229w(0) <= ((NOT radce_hflck(0)) AND radce_hflck(1)) AND radce_hflck(2);
	n00iO :  io_buf_tri
	  PORT MAP ( 
		datain => n01il,
		dataout => wire_n00iO_dataout,
		oe => wire_n00iO_oe
	  );
	wire_n00li_oe <= wire_w_lg_w_lg_w_radce_hflck_range213w221w228w(0);
	wire_w_lg_w_lg_w_radce_hflck_range213w221w228w(0) <= wire_w_lg_w_radce_hflck_range213w221w(0) AND radce_hflck(2);
	n00li :  io_buf_tri
	  PORT MAP ( 
		datain => n011O,
		dataout => wire_n00li_dataout,
		oe => wire_n00li_oe
	  );
	wire_n00ll_oe <= wire_w_lg_w_lg_w_lg_w_radce_hflck_range213w214w217w227w(0);
	wire_w_lg_w_lg_w_lg_w_radce_hflck_range213w214w217w227w(0) <= ((NOT radce_hflck(0)) AND wire_w_lg_w_radce_hflck_range215w216w(0)) AND radce_hflck(2);
	n00ll :  io_buf_tri
	  PORT MAP ( 
		datain => n1OOl,
		dataout => wire_n00ll_dataout,
		oe => wire_n00ll_oe
	  );
	wire_n00lO_oe <= wire_w_lg_w_lg_w_radce_hflck_range213w225w226w(0);
	wire_w_lg_w_lg_w_radce_hflck_range213w225w226w(0) <= (radce_hflck(0) AND radce_hflck(1)) AND (NOT radce_hflck(2));
	n00lO :  io_buf_tri
	  PORT MAP ( 
		datain => n1Oli,
		dataout => wire_n00lO_dataout,
		oe => wire_n00lO_oe
	  );
	wire_n00Oi_oe <= wire_w_lg_w_lg_w_lg_w_radce_hflck_range213w214w223w224w(0);
	wire_w_lg_w_lg_w_lg_w_radce_hflck_range213w214w223w224w(0) <= ((NOT radce_hflck(0)) AND radce_hflck(1)) AND (NOT radce_hflck(2));
	n00Oi :  io_buf_tri
	  PORT MAP ( 
		datain => n1O0O,
		dataout => wire_n00Oi_dataout,
		oe => wire_n00Oi_oe
	  );
	wire_n00Ol_oe <= wire_w_lg_w_lg_w_radce_hflck_range213w221w222w(0);
	wire_w_lg_w_lg_w_radce_hflck_range213w221w222w(0) <= wire_w_lg_w_radce_hflck_range213w221w(0) AND (NOT radce_hflck(2));
	n00Ol :  io_buf_tri
	  PORT MAP ( 
		datain => n1O1l,
		dataout => wire_n00Ol_dataout,
		oe => wire_n00Ol_oe
	  );
	wire_n00OO_oe <= wire_w_lg_w_lg_w_lg_w_radce_hflck_range213w214w217w220w(0);
	wire_w_lg_w_lg_w_lg_w_radce_hflck_range213w214w217w220w(0) <= ((NOT radce_hflck(0)) AND wire_w_lg_w_radce_hflck_range215w216w(0)) AND (NOT radce_hflck(2));
	n00OO :  io_buf_tri
	  PORT MAP ( 
		datain => n0l1il,
		dataout => wire_n00OO_dataout,
		oe => wire_n00OO_oe
	  );
	wire_n010l_w_lg_dataout234w(0) <= NOT wire_n010l_dataout;
	n010l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n010O_dataout,
		dataout => wire_n010l_dataout,
		oe => wire_vcc
	  );
	wire_n011i_w_lg_dataout243w(0) <= NOT wire_n011i_dataout;
	n011i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n011l_dataout,
		dataout => wire_n011i_dataout,
		oe => wire_vcc
	  );
	wire_n0ili_oe <= wire_w_lg_w_lg_w_radce_lflck_range186w198w203w(0);
	wire_w_lg_w_lg_w_radce_lflck_range186w198w203w(0) <= (radce_lflck(0) AND radce_lflck(1)) AND radce_lflck(2);
	n0ili :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1llO_dataout(0),
		dataout => wire_n0ili_dataout,
		oe => wire_n0ili_oe
	  );
	wire_n0ill_oe <= wire_w_lg_w_lg_w_lg_w_radce_lflck_range186w187w196w202w(0);
	wire_w_lg_w_lg_w_lg_w_radce_lflck_range186w187w196w202w(0) <= ((NOT radce_lflck(0)) AND radce_lflck(1)) AND radce_lflck(2);
	n0ill :  io_buf_tri
	  PORT MAP ( 
		datain => n01il,
		dataout => wire_n0ill_dataout,
		oe => wire_n0ill_oe
	  );
	wire_n0ilO_oe <= wire_w_lg_w_lg_w_radce_lflck_range186w194w201w(0);
	wire_w_lg_w_lg_w_radce_lflck_range186w194w201w(0) <= wire_w_lg_w_radce_lflck_range186w194w(0) AND radce_lflck(2);
	n0ilO :  io_buf_tri
	  PORT MAP ( 
		datain => n011O,
		dataout => wire_n0ilO_dataout,
		oe => wire_n0ilO_oe
	  );
	wire_n0iOi_oe <= wire_w_lg_w_lg_w_lg_w_radce_lflck_range186w187w190w200w(0);
	wire_w_lg_w_lg_w_lg_w_radce_lflck_range186w187w190w200w(0) <= ((NOT radce_lflck(0)) AND wire_w_lg_w_radce_lflck_range188w189w(0)) AND radce_lflck(2);
	n0iOi :  io_buf_tri
	  PORT MAP ( 
		datain => n1OOl,
		dataout => wire_n0iOi_dataout,
		oe => wire_n0iOi_oe
	  );
	wire_n0iOl_oe <= wire_w_lg_w_lg_w_radce_lflck_range186w198w199w(0);
	wire_w_lg_w_lg_w_radce_lflck_range186w198w199w(0) <= (radce_lflck(0) AND radce_lflck(1)) AND (NOT radce_lflck(2));
	n0iOl :  io_buf_tri
	  PORT MAP ( 
		datain => n1Oli,
		dataout => wire_n0iOl_dataout,
		oe => wire_n0iOl_oe
	  );
	wire_n0iOO_oe <= wire_w_lg_w_lg_w_lg_w_radce_lflck_range186w187w196w197w(0);
	wire_w_lg_w_lg_w_lg_w_radce_lflck_range186w187w196w197w(0) <= ((NOT radce_lflck(0)) AND radce_lflck(1)) AND (NOT radce_lflck(2));
	n0iOO :  io_buf_tri
	  PORT MAP ( 
		datain => n1O0O,
		dataout => wire_n0iOO_dataout,
		oe => wire_n0iOO_oe
	  );
	wire_n0l1i_oe <= wire_w_lg_w_lg_w_radce_lflck_range186w194w195w(0);
	wire_w_lg_w_lg_w_radce_lflck_range186w194w195w(0) <= wire_w_lg_w_radce_lflck_range186w194w(0) AND (NOT radce_lflck(2));
	n0l1i :  io_buf_tri
	  PORT MAP ( 
		datain => n1O1l,
		dataout => wire_n0l1i_dataout,
		oe => wire_n0l1i_oe
	  );
	wire_n0l1l_oe <= wire_w_lg_w_lg_w_lg_w_radce_lflck_range186w187w190w193w(0);
	wire_w_lg_w_lg_w_lg_w_radce_lflck_range186w187w190w193w(0) <= ((NOT radce_lflck(0)) AND wire_w_lg_w_radce_lflck_range188w189w(0)) AND (NOT radce_lflck(2));
	n0l1l :  io_buf_tri
	  PORT MAP ( 
		datain => n0l1il,
		dataout => wire_n0l1l_dataout,
		oe => wire_n0l1l_oe
	  );
	wire_n0liil_w_lg_dataout1524w(0) <= NOT wire_n0liil_dataout;
	n0liil :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n0liiO_dataout,
		dataout => wire_n0liil_dataout,
		oe => wire_vcc
	  );
	wire_n0liOi_w_lg_dataout1521w(0) <= NOT wire_n0liOi_dataout;
	n0liOi :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n0liOl_dataout,
		dataout => wire_n0liOi_dataout,
		oe => wire_vcc
	  );
	wire_n0ll1O_w_lg_dataout1518w(0) <= NOT wire_n0ll1O_dataout;
	n0ll1O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n0ll0i_dataout,
		dataout => wire_n0ll1O_dataout,
		oe => wire_vcc
	  );
	wire_n0llil_w_lg_dataout1515w(0) <= NOT wire_n0llil_dataout;
	n0llil :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n0lliO_dataout,
		dataout => wire_n0llil_dataout,
		oe => wire_vcc
	  );
	wire_n0O01O_w_lg_dataout1454w(0) <= NOT wire_n0O01O_dataout;
	n0O01O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n0O00i_dataout,
		dataout => wire_n0O01O_dataout,
		oe => wire_vcc
	  );
	wire_n0O11O_w_lg_dataout1463w(0) <= NOT wire_n0O11O_dataout;
	n0O11O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n0O10i_dataout,
		dataout => wire_n0O11O_dataout,
		oe => wire_vcc
	  );
	wire_n0O1il_w_lg_dataout1460w(0) <= NOT wire_n0O1il_dataout;
	n0O1il :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n0O1iO_dataout,
		dataout => wire_n0O1il_dataout,
		oe => wire_vcc
	  );
	wire_n0O1Oi_w_lg_dataout1457w(0) <= NOT wire_n0O1Oi_dataout;
	n0O1Oi :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n0O1Ol_dataout,
		dataout => wire_n0O1Oi_dataout,
		oe => wire_vcc
	  );
	wire_n0Ol1l_w_lg_dataout1403w(0) <= NOT wire_n0Ol1l_dataout;
	n0Ol1l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n0Ol1O_dataout,
		dataout => wire_n0Ol1l_dataout,
		oe => wire_vcc
	  );
	wire_n0Olii_w_lg_dataout1400w(0) <= NOT wire_n0Olii_dataout;
	n0Olii :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n0Olil_dataout,
		dataout => wire_n0Olii_dataout,
		oe => wire_vcc
	  );
	wire_n0OllO_w_lg_dataout1397w(0) <= NOT wire_n0OllO_dataout;
	n0OllO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n0OlOi_dataout,
		dataout => wire_n0OllO_dataout,
		oe => wire_vcc
	  );
	wire_n0OO1l_w_lg_dataout1394w(0) <= NOT wire_n0OO1l_dataout;
	n0OO1l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n0OO1O_dataout,
		dataout => wire_n0OO1l_dataout,
		oe => wire_vcc
	  );
	n100O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n10ii_dataout,
		dataout => wire_n100O_dataout,
		oe => wire_vcc
	  );
	wire_n101l_w_lg_dataout310w(0) <= NOT wire_n101l_dataout;
	n101l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n101O_dataout,
		dataout => wire_n101l_dataout,
		oe => wire_vcc
	  );
	wire_n10il_w_lg_dataout309w(0) <= NOT wire_n10il_dataout;
	n10il :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n10iO_dataout,
		dataout => wire_n10il_dataout,
		oe => wire_vcc
	  );
	n10lO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n10Oi_dataout,
		dataout => wire_n10lO_dataout,
		oe => wire_vcc
	  );
	wire_n10Ol_w_lg_dataout303w(0) <= NOT wire_n10Ol_dataout;
	n10Ol :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n10OO_dataout,
		dataout => wire_n10Ol_dataout,
		oe => wire_vcc
	  );
	n11OO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n101i_dataout,
		dataout => wire_n11OO_dataout,
		oe => wire_vcc
	  );
	n1l0O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n1lii_dataout,
		dataout => wire_n1l0O_dataout,
		oe => wire_vcc
	  );
	n1lil :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n1liO_dataout,
		dataout => wire_n1lil_dataout,
		oe => wire_vcc
	  );
	wire_n1lOO_w_lg_dataout251w(0) <= NOT wire_n1lOO_dataout;
	n1lOO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n1O1i_dataout,
		dataout => wire_n1lOO_dataout,
		oe => wire_vcc
	  );
	wire_n1O0i_w_lg_dataout249w(0) <= NOT wire_n1O0i_dataout;
	n1O0i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n1O0l_dataout,
		dataout => wire_n1O0i_dataout,
		oe => wire_vcc
	  );
	wire_n1Oil_w_lg_dataout247w(0) <= NOT wire_n1Oil_dataout;
	n1Oil :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n1OiO_dataout,
		dataout => wire_n1Oil_dataout,
		oe => wire_vcc
	  );
	wire_n1OlO_w_lg_dataout245w(0) <= NOT wire_n1OlO_dataout;
	n1OlO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_n1OOi_dataout,
		dataout => wire_n1OlO_dataout,
		oe => wire_vcc
	  );
	ni00lO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni00Oi_dataout,
		dataout => wire_ni00lO_dataout,
		oe => wire_vcc
	  );
	wire_ni00Ol_w_lg_dataout1235w(0) <= NOT wire_ni00Ol_dataout;
	ni00Ol :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni00OO_dataout,
		dataout => wire_ni00Ol_dataout,
		oe => wire_vcc
	  );
	wire_ni01i_datain <= wire_n0l11l28_w_lg_w_lg_q110w111w(0);
	wire_n0l11l28_w_lg_w_lg_q110w111w(0) <= (n0l11l28 XOR n0l11l27) AND n1O0O;
	wire_ni01i_oe <= wire_nl1llO_w123w(0);
	wire_nl1llO_w123w(0) <= NOT (((NOT wire_nl1llO_dataout(0)) AND (NOT ((wire_w_lg_n0l11i113w(0) OR wire_w_lg_n0iOOO114w(0)) OR wire_w_lg_n0iOOl116w(0)))) AND (n0iOlO30 XOR n0iOlO29));
	ni01i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni01i_datain,
		dataout => wire_ni01i_dataout,
		oe => wire_ni01i_oe
	  );
	ni01il :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni01iO_dataout,
		dataout => wire_ni01il_dataout,
		oe => wire_vcc
	  );
	wire_ni01li_w_lg_dataout1254w(0) <= NOT wire_ni01li_dataout;
	ni01li :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni01ll_dataout,
		dataout => wire_ni01li_dataout,
		oe => wire_vcc
	  );
	ni01lO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_ni01lO_dataout,
		oe => wire_nl1lOi_dataout(0)
	  );
	wire_ni01Oi_oe <= wire_nl1lOi_w_lg_w_dataout_range33w252w(0);
	wire_nl1lOi_w_lg_w_dataout_range33w252w(0) <= NOT wire_nl1lOi_dataout(0);
	ni01Oi :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_ni01Oi_dataout,
		oe => wire_ni01Oi_oe
	  );
	ni01Ol :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_ni01Ol_dataout,
		oe => wire_nl1lOi_dataout(0)
	  );
	wire_ni01OO_oe <= wire_nl1lOi_w_lg_w_dataout_range33w252w(0);
	ni01OO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_ni01OO_dataout,
		oe => wire_ni01OO_oe
	  );
	wire_ni0i0i_oe <= wire_nl1lOi_w_lg_w_dataout_range33w252w(0);
	ni0i0i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_ni0i0i_dataout,
		oe => wire_ni0i0i_oe
	  );
	ni0i1i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_ni0i1i_dataout,
		oe => wire_nl1lOi_dataout(0)
	  );
	wire_ni0i1l_oe <= wire_nl1lOi_w_lg_w_dataout_range33w252w(0);
	ni0i1l :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_ni0i1l_dataout,
		oe => wire_ni0i1l_oe
	  );
	ni0i1O :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_ni0i1O_dataout,
		oe => wire_nl1lOi_dataout(0)
	  );
	wire_ni0l0l_oe <= wire_niOiil_w_lg_w_dataout_range1099w1100w(0);
	wire_niOiil_w_lg_w_dataout_range1099w1100w(0) <= NOT wire_niOiil_dataout(0);
	ni0l0l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_ni0l0l_dataout,
		oe => wire_ni0l0l_oe
	  );
	ni0l0O :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_ni0l0O_dataout,
		oe => wire_niOiil_dataout(0)
	  );
	ni0l1i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni0l1l_dataout,
		dataout => wire_ni0l1i_dataout,
		oe => wire_vcc
	  );
	wire_ni0l1O_w_lg_dataout1216w(0) <= NOT wire_ni0l1O_dataout;
	ni0l1O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni0l0i_dataout,
		dataout => wire_ni0l1O_dataout,
		oe => wire_vcc
	  );
	wire_ni0lii_oe <= wire_niOiil_w_lg_w_dataout_range1099w1100w(0);
	ni0lii :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_ni0lii_dataout,
		oe => wire_ni0lii_oe
	  );
	ni0lil :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_ni0lil_dataout,
		oe => wire_niOiil_dataout(0)
	  );
	ni0O0l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni0O0O_dataout,
		dataout => wire_ni0O0l_dataout,
		oe => wire_vcc
	  );
	wire_ni0Oii_w_lg_dataout1197w(0) <= NOT wire_ni0Oii_dataout;
	ni0Oii :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni0Oil_dataout,
		dataout => wire_ni0Oii_dataout,
		oe => wire_vcc
	  );
	wire_ni0OiO_oe <= wire_niOl0O_w_lg_w_dataout_range1097w1098w(0);
	wire_niOl0O_w_lg_w_dataout_range1097w1098w(0) <= NOT wire_niOl0O_dataout(0);
	ni0OiO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_ni0OiO_dataout,
		oe => wire_ni0OiO_oe
	  );
	ni0Oli :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_ni0Oli_dataout,
		oe => wire_niOl0O_dataout(0)
	  );
	wire_ni0Oll_oe <= wire_niOl0O_w_lg_w_dataout_range1097w1098w(0);
	ni0Oll :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_ni0Oll_dataout,
		oe => wire_ni0Oll_oe
	  );
	ni0OlO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_ni0OlO_dataout,
		oe => wire_niOl0O_dataout(0)
	  );
	wire_ni101l_w_lg_dataout1339w(0) <= NOT wire_ni101l_dataout;
	ni101l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni101O_dataout,
		dataout => wire_ni101l_dataout,
		oe => wire_vcc
	  );
	wire_ni10ii_w_lg_dataout1336w(0) <= NOT wire_ni10ii_dataout;
	ni10ii :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni10il_dataout,
		dataout => wire_ni10ii_dataout,
		oe => wire_vcc
	  );
	wire_ni10lO_w_lg_dataout1333w(0) <= NOT wire_ni10lO_dataout;
	ni10lO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni10Oi_dataout,
		dataout => wire_ni10lO_dataout,
		oe => wire_vcc
	  );
	wire_ni11lO_w_lg_dataout1342w(0) <= NOT wire_ni11lO_dataout;
	ni11lO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni11Oi_dataout,
		dataout => wire_ni11lO_dataout,
		oe => wire_vcc
	  );
	wire_ni1ii_oe <= wire_nl1llO_w_lg_w_dataout_range35w130w(0);
	ni1ii :  io_buf_tri
	  PORT MAP ( 
		datain => n1Oli,
		dataout => wire_ni1ii_dataout,
		oe => wire_ni1ii_oe
	  );
	wire_ni1il_oe <= wire_nl1llO_w_lg_w_lg_w_dataout_range35w137w148w(0);
	wire_nl1llO_w_lg_w_lg_w_dataout_range35w137w148w(0) <= wire_nl1llO_w_lg_w_dataout_range35w137w(0) OR wire_w_lg_n0iO1O140w(0);
	ni1il :  io_buf_tri
	  PORT MAP ( 
		datain => n011O,
		dataout => wire_ni1il_dataout,
		oe => wire_ni1il_oe
	  );
	wire_ni1iO_oe <= wire_nl1llO_w_lg_w_lg_w_lg_w_dataout_range35w112w146w147w(0);
	wire_nl1llO_w_lg_w_lg_w_lg_w_dataout_range35w112w146w147w(0) <= NOT ((NOT wire_nl1llO_dataout(0)) AND (NOT wire_nl1llO_w_lg_w_dataout_range35w144w(0)));
	ni1iO :  io_buf_tri
	  PORT MAP ( 
		datain => n01il,
		dataout => wire_ni1iO_dataout,
		oe => wire_ni1iO_oe
	  );
	wire_ni1li_oe <= wire_w_lg_n0iOli126w(0);
	ni1li :  io_buf_tri
	  PORT MAP ( 
		datain => n0l1il,
		dataout => wire_ni1li_dataout,
		oe => wire_ni1li_oe
	  );
	wire_ni1ll_oe <= wire_n0iO1l40_w_lg_w_lg_q142w143w(0);
	wire_n0iO1l40_w_lg_w_lg_q142w143w(0) <= (n0iO1l40 XOR n0iO1l39) AND ((wire_w_lg_n0l11i113w(0) OR wire_w_lg_n0iO0i138w(0)) OR wire_w_lg_n0iO1O140w(0));
	ni1ll :  io_buf_tri
	  PORT MAP ( 
		datain => n1O0O,
		dataout => wire_ni1ll_dataout,
		oe => wire_ni1ll_oe
	  );
	wire_ni1lO_datain <= wire_n0iO0O38_w_lg_w_lg_q134w135w(0);
	wire_n0iO0O38_w_lg_w_lg_q134w135w(0) <= (n0iO0O38 XOR n0iO0O37) AND n1Oli;
	wire_ni1lO_oe <= wire_nl1llO_w_lg_w_dataout_range35w137w(0);
	ni1lO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni1lO_datain,
		dataout => wire_ni1lO_dataout,
		oe => wire_ni1lO_oe
	  );
	ni1O0i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni1O0l_dataout,
		dataout => wire_ni1O0i_dataout,
		oe => wire_vcc
	  );
	wire_ni1O0O_w_lg_dataout1273w(0) <= NOT wire_ni1O0O_dataout;
	ni1O0O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni1Oii_dataout,
		dataout => wire_ni1O0O_dataout,
		oe => wire_vcc
	  );
	wire_ni1Oi_oe <= wire_n0iOii36_w_lg_w_lg_q132w133w(0);
	wire_n0iOii36_w_lg_w_lg_q132w133w(0) <= (n0iOii36 XOR n0iOii35) AND (wire_nl1llO_w_lg_w_dataout_range35w130w(0) OR wire_w_lg_n0iOOl116w(0));
	ni1Oi :  io_buf_tri
	  PORT MAP ( 
		datain => n011O,
		dataout => wire_ni1Oi_dataout,
		oe => wire_ni1Oi_oe
	  );
	ni1Oil :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_ni1Oil_dataout,
		oe => wire_nl1lOi_dataout(0)
	  );
	wire_ni1OiO_oe <= wire_nl1lOi_w_lg_w_dataout_range33w252w(0);
	ni1OiO :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_ni1OiO_dataout,
		oe => wire_ni1OiO_oe
	  );
	wire_ni1Ol_oe <= wire_n0iOiO34_w_lg_w_lg_q127w128w(0);
	wire_n0iOiO34_w_lg_w_lg_q127w128w(0) <= (n0iOiO34 XOR n0iOiO33) AND wire_w_lg_n0iOOO114w(0);
	ni1Ol :  io_buf_tri
	  PORT MAP ( 
		datain => n01il,
		dataout => wire_ni1Ol_dataout,
		oe => wire_ni1Ol_oe
	  );
	ni1Oli :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_ni1Oli_dataout,
		oe => wire_nl1lOi_dataout(0)
	  );
	wire_ni1Oll_oe <= wire_nl1lOi_w_lg_w_dataout_range33w252w(0);
	ni1Oll :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_ni1Oll_dataout,
		oe => wire_ni1Oll_oe
	  );
	wire_ni1OO_datain <= wire_n0iOll32_w_lg_w_lg_q124w125w(0);
	wire_n0iOll32_w_lg_w_lg_q124w125w(0) <= (n0iOll32 XOR n0iOll31) AND n0l1il;
	wire_ni1OO_oe <= wire_w_lg_n0iOli126w(0);
	ni1OO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_ni1OO_datain,
		dataout => wire_ni1OO_dataout,
		oe => wire_ni1OO_oe
	  );
	nii01i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nii01i_dataout,
		oe => wire_niOO0i_dataout(0)
	  );
	nii0Oi :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nii0Ol_dataout,
		dataout => wire_nii0Oi_dataout,
		oe => wire_vcc
	  );
	wire_nii0OO_w_lg_dataout1153w(0) <= NOT wire_nii0OO_dataout;
	nii0OO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niii1i_dataout,
		dataout => wire_nii0OO_dataout,
		oe => wire_vcc
	  );
	nii1iO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nii1li_dataout,
		dataout => wire_nii1iO_dataout,
		oe => wire_vcc
	  );
	wire_nii1ll_w_lg_dataout1175w(0) <= NOT wire_nii1ll_dataout;
	nii1ll :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nii1lO_dataout,
		dataout => wire_nii1ll_dataout,
		oe => wire_vcc
	  );
	wire_nii1Oi_oe <= wire_niOO0i_w_lg_w_dataout_range1095w1096w(0);
	wire_niOO0i_w_lg_w_dataout_range1095w1096w(0) <= NOT wire_niOO0i_dataout(0);
	nii1Oi :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nii1Oi_dataout,
		oe => wire_nii1Oi_oe
	  );
	nii1Ol :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_nii1Ol_dataout,
		oe => wire_niOO0i_dataout(0)
	  );
	wire_nii1OO_oe <= wire_niOO0i_w_lg_w_dataout_range1095w1096w(0);
	nii1OO :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_nii1OO_dataout,
		oe => wire_nii1OO_oe
	  );
	niii0i :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_niii0i_dataout,
		oe => wire_nl1llO_dataout(0)
	  );
	wire_niii0l_oe <= wire_nl1llO_w_lg_w_dataout_range35w112w(0);
	wire_nl1llO_w_lg_w_dataout_range35w112w(0) <= NOT wire_nl1llO_w_dataout_range35w(0);
	niii0l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_niii0l_dataout,
		oe => wire_niii0l_oe
	  );
	niii1l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_niii1l_dataout,
		oe => wire_nl1llO_dataout(0)
	  );
	wire_niii1O_oe <= wire_nl1llO_w_lg_w_dataout_range35w112w(0);
	niii1O :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_niii1O_dataout,
		oe => wire_niii1O_oe
	  );
	wire_niil0i_w_lg_dataout1134w(0) <= NOT wire_niil0i_dataout;
	niil0i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niil0l_dataout,
		dataout => wire_niil0i_dataout,
		oe => wire_vcc
	  );
	niil0O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_niil0O_dataout,
		oe => wire_nl1llO_dataout(0)
	  );
	niil1l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niil1O_dataout,
		dataout => wire_niil1l_dataout,
		oe => wire_vcc
	  );
	wire_niilii_oe <= wire_nl1llO_w_lg_w_dataout_range35w112w(0);
	niilii :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_niilii_dataout,
		oe => wire_niilii_oe
	  );
	niilil :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_niilil_dataout,
		oe => wire_nl1llO_dataout(0)
	  );
	wire_niiliO_oe <= wire_nl1llO_w_lg_w_dataout_range35w112w(0);
	niiliO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_niiliO_dataout,
		oe => wire_niiliO_oe
	  );
	niiO0O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niiOii_dataout,
		dataout => wire_niiO0O_dataout,
		oe => wire_vcc
	  );
	wire_niiOil_w_lg_dataout1115w(0) <= NOT wire_niiOil_dataout;
	niiOil :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niiOiO_dataout,
		dataout => wire_niiOil_dataout,
		oe => wire_vcc
	  );
	niiOli :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_niiOli_dataout,
		oe => wire_nl1lOi_dataout(0)
	  );
	wire_niiOll_oe <= wire_nl1lOi_w_lg_w_dataout_range33w252w(0);
	niiOll :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_niiOll_dataout,
		oe => wire_niiOll_oe
	  );
	niiOlO :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_niiOlO_dataout,
		oe => wire_nl1lOi_dataout(0)
	  );
	wire_niiOOi_oe <= wire_nl1lOi_w_lg_w_dataout_range33w252w(0);
	niiOOi :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_niiOOi_dataout,
		oe => wire_niiOOi_oe
	  );
	wire_nil01l_w_lg_dataout1075w(0) <= NOT wire_nil01l_dataout;
	nil01l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nil01O_dataout,
		dataout => wire_nil01l_dataout,
		oe => wire_vcc
	  );
	wire_nil10l_w_lg_dataout1083w(0) <= NOT wire_nil10l_dataout;
	nil10l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nil10O_dataout,
		dataout => wire_nil10l_dataout,
		oe => wire_vcc
	  );
	wire_nil1ii_w_lg_dataout1065w(0) <= NOT wire_nil1ii_dataout;
	nil1ii :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nil1il_dataout,
		dataout => wire_nil1ii_dataout,
		oe => wire_vcc
	  );
	wire_nil1iO_w_lg_dataout1036w(0) <= NOT wire_nil1iO_dataout;
	nil1iO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nil1li_dataout,
		dataout => wire_nil1iO_dataout,
		oe => wire_vcc
	  );
	nil1ll :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nil1lO_dataout,
		dataout => wire_nil1ll_dataout,
		oe => wire_vcc
	  );
	wire_nil1Oi_w_lg_dataout1046w(0) <= NOT wire_nil1Oi_dataout;
	nil1Oi :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nil1Ol_dataout,
		dataout => wire_nil1Oi_dataout,
		oe => wire_vcc
	  );
	wire_nil1OO_w_lg_dataout1054w(0) <= NOT wire_nil1OO_dataout;
	nil1OO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nil01i_dataout,
		dataout => wire_nil1OO_dataout,
		oe => wire_vcc
	  );
	wire_niO0ll_datain <= wire_w_lg_w_eqa_set_range800w801w(0);
	wire_w_lg_w_eqa_set_range800w801w(0) <= NOT wire_w_eqa_set_range800w(0);
	wire_niO0ll_oe <= wire_w_lg_n0l0ll570w(0);
	niO0ll :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niO0ll_datain,
		dataout => wire_niO0ll_dataout,
		oe => wire_niO0ll_oe
	  );
	wire_niO0lO_datain <= wire_w_lg_w_eqb_set_range756w757w(0);
	wire_w_lg_w_eqb_set_range756w757w(0) <= NOT wire_w_eqb_set_range756w(0);
	wire_niO0lO_oe <= wire_w_lg_n0l0li547w(0);
	niO0lO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niO0lO_datain,
		dataout => wire_niO0lO_dataout,
		oe => wire_niO0lO_oe
	  );
	wire_niO0Oi_datain <= wire_w_lg_w_eqc_set_range702w703w(0);
	wire_w_lg_w_eqc_set_range702w703w(0) <= NOT wire_w_eqc_set_range702w(0);
	wire_niO0Oi_oe <= wire_w_lg_n0l0iO549w(0);
	niO0Oi :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niO0Oi_datain,
		dataout => wire_niO0Oi_dataout,
		oe => wire_niO0Oi_oe
	  );
	wire_niO0Ol_datain <= wire_w_lg_w_eqd_set_range647w648w(0);
	wire_w_lg_w_eqd_set_range647w648w(0) <= NOT wire_w_eqd_set_range647w(0);
	wire_niO0Ol_oe <= wire_w_lg_n0l0il540w(0);
	niO0Ol :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niO0Ol_datain,
		dataout => wire_niO0Ol_dataout,
		oe => wire_niO0Ol_oe
	  );
	wire_niO0OO_datain <= wire_w_lg_w_eqa_set_range800w801w(0);
	wire_niO0OO_oe <= wire_w_lg_n00Oli909w(0);
	niO0OO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niO0OO_datain,
		dataout => wire_niO0OO_dataout,
		oe => wire_niO0OO_oe
	  );
	wire_niOi0i_oe <= wire_w_lg_n00OOl907w(0);
	niOi0i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1llO_dataout(0),
		dataout => wire_niOi0i_dataout,
		oe => wire_niOi0i_oe
	  );
	wire_niOi0l_datain <= wire_w_lg_w_eqv_set_range596w601w(0);
	wire_w_lg_w_eqv_set_range596w601w(0) <= NOT wire_w_eqv_set_range596w(0);
	wire_niOi0l_oe <= wire_w_lg_n00OOO906w(0);
	niOi0l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOi0l_datain,
		dataout => wire_niOi0l_dataout,
		oe => wire_niOi0l_oe
	  );
	wire_niOi0O_datain <= wire_w_lg_w_eqv_set_range596w601w(0);
	niOi0O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOi0O_datain,
		dataout => wire_niOi0O_dataout,
		oe => n0l0ii
	  );
	wire_niOi1i_datain <= wire_w_lg_w_eqb_set_range756w757w(0);
	wire_niOi1i_oe <= wire_w_lg_n00Oll908w(0);
	niOi1i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOi1i_datain,
		dataout => wire_niOi1i_dataout,
		oe => wire_niOi1i_oe
	  );
	wire_niOi1l_datain <= wire_w_lg_w_eqc_set_range702w703w(0);
	niOi1l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOi1l_datain,
		dataout => wire_niOi1l_dataout,
		oe => n00OlO
	  );
	wire_niOi1O_datain <= wire_w_lg_w_eqd_set_range647w648w(0);
	niOi1O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOi1O_datain,
		dataout => wire_niOi1O_dataout,
		oe => n00OOi
	  );
	wire_niOiiO_datain <= wire_w_lg_w_eqa_set_range802w803w(0);
	wire_niOiiO_oe <= wire_w_lg_n0l0ll570w(0);
	niOiiO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOiiO_datain,
		dataout => wire_niOiiO_dataout,
		oe => wire_niOiiO_oe
	  );
	wire_niOili_datain <= wire_w_lg_w_eqb_set_range758w759w(0);
	wire_niOili_oe <= wire_w_lg_n0l0li547w(0);
	niOili :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOili_datain,
		dataout => wire_niOili_dataout,
		oe => wire_niOili_oe
	  );
	wire_niOill_datain <= wire_w_lg_w_eqc_set_range704w705w(0);
	wire_niOill_oe <= wire_w_lg_n0l0iO549w(0);
	niOill :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOill_datain,
		dataout => wire_niOill_dataout,
		oe => wire_niOill_oe
	  );
	wire_niOilO_datain <= wire_w_lg_w_eqd_set_range649w650w(0);
	wire_niOilO_oe <= wire_w_lg_n0l0il540w(0);
	niOilO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOilO_datain,
		dataout => wire_niOilO_dataout,
		oe => wire_niOilO_oe
	  );
	wire_niOiOi_datain <= wire_w_lg_w_eqa_set_range802w803w(0);
	wire_niOiOi_oe <= wire_w_lg_n00Oli909w(0);
	niOiOi :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOiOi_datain,
		dataout => wire_niOiOi_dataout,
		oe => wire_niOiOi_oe
	  );
	wire_niOiOl_datain <= wire_w_lg_w_eqb_set_range758w759w(0);
	wire_niOiOl_oe <= wire_w_lg_n00Oll908w(0);
	niOiOl :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOiOl_datain,
		dataout => wire_niOiOl_dataout,
		oe => wire_niOiOl_oe
	  );
	wire_niOiOO_datain <= wire_w_lg_w_eqc_set_range704w705w(0);
	niOiOO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOiOO_datain,
		dataout => wire_niOiOO_dataout,
		oe => n00OlO
	  );
	wire_niOl0i_datain <= wire_w_lg_w_eqv_set_range597w604w(0);
	niOl0i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOl0i_datain,
		dataout => wire_niOl0i_dataout,
		oe => n0l0ii
	  );
	wire_niOl1i_datain <= wire_w_lg_w_eqd_set_range649w650w(0);
	niOl1i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOl1i_datain,
		dataout => wire_niOl1i_dataout,
		oe => n00OOi
	  );
	wire_niOl1l_oe <= wire_w_lg_n00OOl907w(0);
	niOl1l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1llO_dataout(0),
		dataout => wire_niOl1l_dataout,
		oe => wire_niOl1l_oe
	  );
	wire_niOl1O_datain <= wire_w_lg_w_eqv_set_range597w604w(0);
	wire_niOl1O_oe <= wire_w_lg_n00OOO906w(0);
	niOl1O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOl1O_datain,
		dataout => wire_niOl1O_dataout,
		oe => wire_niOl1O_oe
	  );
	wire_niOlii_datain <= wire_w_lg_w_eqa_set_range805w806w(0);
	wire_w_lg_w_eqa_set_range805w806w(0) <= NOT eqa_set(2);
	wire_niOlii_oe <= wire_w_lg_n0l0ll570w(0);
	niOlii :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOlii_datain,
		dataout => wire_niOlii_dataout,
		oe => wire_niOlii_oe
	  );
	wire_niOlil_datain <= wire_w_lg_w_eqb_set_range761w762w(0);
	wire_w_lg_w_eqb_set_range761w762w(0) <= NOT eqb_set(2);
	wire_niOlil_oe <= wire_w_lg_n0l0li547w(0);
	niOlil :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOlil_datain,
		dataout => wire_niOlil_dataout,
		oe => wire_niOlil_oe
	  );
	wire_niOliO_datain <= wire_w_lg_w_eqc_set_range707w708w(0);
	wire_w_lg_w_eqc_set_range707w708w(0) <= NOT eqc_set(2);
	wire_niOliO_oe <= wire_w_lg_n0l0iO549w(0);
	niOliO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOliO_datain,
		dataout => wire_niOliO_dataout,
		oe => wire_niOliO_oe
	  );
	wire_niOlli_datain <= wire_w_lg_w_eqd_set_range652w653w(0);
	wire_w_lg_w_eqd_set_range652w653w(0) <= NOT eqd_set(2);
	wire_niOlli_oe <= wire_w_lg_n0l0il540w(0);
	niOlli :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOlli_datain,
		dataout => wire_niOlli_dataout,
		oe => wire_niOlli_oe
	  );
	wire_niOlll_datain <= wire_w_lg_w_eqa_set_range805w806w(0);
	wire_niOlll_oe <= wire_w_lg_n00Oli909w(0);
	niOlll :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOlll_datain,
		dataout => wire_niOlll_dataout,
		oe => wire_niOlll_oe
	  );
	wire_niOllO_datain <= wire_w_lg_w_eqb_set_range761w762w(0);
	wire_niOllO_oe <= wire_w_lg_n00Oll908w(0);
	niOllO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOllO_datain,
		dataout => wire_niOllO_dataout,
		oe => wire_niOllO_oe
	  );
	wire_niOlOi_datain <= wire_w_lg_w_eqc_set_range707w708w(0);
	niOlOi :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOlOi_datain,
		dataout => wire_niOlOi_dataout,
		oe => n00OlO
	  );
	wire_niOlOl_datain <= wire_w_lg_w_eqd_set_range652w653w(0);
	niOlOl :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOlOl_datain,
		dataout => wire_niOlOl_dataout,
		oe => n00OOi
	  );
	wire_niOlOO_oe <= wire_w_lg_n00OOl907w(0);
	niOlOO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1llO_dataout(0),
		dataout => wire_niOlOO_dataout,
		oe => wire_niOlOO_oe
	  );
	niOO0l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOO0O_dataout,
		dataout => wire_niOO0l_dataout,
		oe => wire_vcc
	  );
	wire_niOO1i_datain <= wire_w_lg_w_eqv_set_range599w609w(0);
	wire_w_lg_w_eqv_set_range599w609w(0) <= NOT eqv_set(2);
	wire_niOO1i_oe <= wire_w_lg_n00OOO906w(0);
	niOO1i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOO1i_datain,
		dataout => wire_niOO1i_dataout,
		oe => wire_niOO1i_oe
	  );
	wire_niOO1l_datain <= wire_w_lg_w_eqv_set_range599w609w(0);
	niOO1l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOO1l_datain,
		dataout => wire_niOO1l_dataout,
		oe => n0l0ii
	  );
	niOOlO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOOOi_dataout,
		dataout => wire_niOOlO_dataout,
		oe => wire_vcc
	  );
	wire_niOOOl_w_lg_dataout866w(0) <= NOT wire_niOOOl_dataout;
	niOOOl :  io_buf_tri
	  PORT MAP ( 
		datain => wire_niOOOO_dataout,
		dataout => wire_niOOOl_dataout,
		oe => wire_vcc
	  );
	wire_nl000i_oe <= wire_w_lg_w_lg_w_lg_w_eqb_set_range756w757w760w770w(0);
	wire_w_lg_w_lg_w_lg_w_eqb_set_range756w757w760w770w(0) <= ((NOT eqb_set(0)) AND wire_w_lg_w_eqb_set_range758w759w(0)) AND eqb_set(2);
	nl000i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl000i_dataout,
		oe => wire_nl000i_oe
	  );
	wire_nl000l_oe <= wire_w_lg_w_lg_w_eqb_set_range756w768w769w(0);
	wire_w_lg_w_lg_w_eqb_set_range756w768w769w(0) <= (eqb_set(0) AND eqb_set(1)) AND (NOT eqb_set(2));
	nl000l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl000l_dataout,
		oe => wire_nl000l_oe
	  );
	wire_nl000O_oe <= wire_w_lg_w_lg_w_lg_w_eqb_set_range756w757w766w767w(0);
	wire_w_lg_w_lg_w_lg_w_eqb_set_range756w757w766w767w(0) <= ((NOT eqb_set(0)) AND eqb_set(1)) AND (NOT eqb_set(2));
	nl000O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl000O_dataout,
		oe => wire_nl000O_oe
	  );
	wire_nl001i_oe <= wire_w_lg_w_lg_w_eqb_set_range756w768w773w(0);
	wire_w_lg_w_lg_w_eqb_set_range756w768w773w(0) <= (eqb_set(0) AND eqb_set(1)) AND eqb_set(2);
	nl001i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nl001i_dataout,
		oe => wire_nl001i_oe
	  );
	wire_nl001l_oe <= wire_w_lg_w_lg_w_lg_w_eqb_set_range756w757w766w772w(0);
	wire_w_lg_w_lg_w_lg_w_eqb_set_range756w757w766w772w(0) <= ((NOT eqb_set(0)) AND eqb_set(1)) AND eqb_set(2);
	nl001l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl001l_dataout,
		oe => wire_nl001l_oe
	  );
	wire_nl001O_oe <= wire_w_lg_w_lg_w_eqb_set_range756w764w771w(0);
	wire_w_lg_w_lg_w_eqb_set_range756w764w771w(0) <= wire_w_lg_w_eqb_set_range756w764w(0) AND eqb_set(2);
	nl001O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl001O_dataout,
		oe => wire_nl001O_oe
	  );
	wire_nl00ii_oe <= wire_w_lg_w_lg_w_eqb_set_range756w764w765w(0);
	wire_w_lg_w_lg_w_eqb_set_range756w764w765w(0) <= wire_w_lg_w_eqb_set_range756w764w(0) AND (NOT eqb_set(2));
	nl00ii :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl00ii_dataout,
		oe => wire_nl00ii_oe
	  );
	wire_nl00il_oe <= wire_w_lg_w_lg_w_lg_w_eqb_set_range756w757w760w763w(0);
	wire_w_lg_w_lg_w_lg_w_eqb_set_range756w757w760w763w(0) <= ((NOT eqb_set(0)) AND wire_w_lg_w_eqb_set_range758w759w(0)) AND (NOT eqb_set(2));
	nl00il :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1llO_dataout(0),
		dataout => wire_nl00il_dataout,
		oe => wire_nl00il_oe
	  );
	wire_nl00li_oe <= wire_w_lg_radce_adapt746w(0);
	wire_w_lg_radce_adapt746w(0) <= radce_adapt AND wire_w_lg_n0l0li547w(0);
	nl00li :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl00li_dataout,
		oe => wire_nl00li_oe
	  );
	wire_nl00ll_oe <= wire_w_lg_w_lg_w_lg_radce_adapt537w538w745w(0);
	wire_w_lg_w_lg_w_lg_radce_adapt537w538w745w(0) <= (NOT (radce_adapt OR wire_w_lg_radce_pdb536w(0))) OR ((radce_adapt AND n0l0li) AND (NOT ((NOT ((wire_w_lg_n0l0il540w(0) OR wire_w_lg_n0l0iO549w(0)) AND wire_w_lg_n0i01l728w(0))) AND (NOT ((wire_w_lg_n0l0ii683w(0) OR wire_w_lg_n0l0iO549w(0)) AND n0i01l)))));
	nl00ll :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl00iO_dataout(0),
		dataout => wire_nl00ll_dataout,
		oe => wire_nl00ll_oe
	  );
	wire_nl00lO_oe <= wire_w_lg_n0i01O735w(0);
	nl00lO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1llO_dataout(0),
		dataout => wire_nl00lO_dataout,
		oe => wire_nl00lO_oe
	  );
	wire_nl00Oi_oe <= wire_w_lg_n0i01O734w(0);
	wire_w_lg_n0i01O734w(0) <= n0i01O AND ((radce_adapt AND n0l0li) AND (NOT ((NOT (wire_w_lg_n0l0ll570w(0) AND n0i01l)) AND (NOT (wire_w_lg_n0i01l728w(0) AND wire_w_lg_w_lg_n0l0ll570w671w(0))))));
	nl00Oi :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl00Ol_dataout,
		dataout => wire_nl00Oi_dataout,
		oe => wire_nl00Oi_oe
	  );
	nl00Ol :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl00OO_dataout,
		dataout => wire_nl00Ol_dataout,
		oe => wire_vcc
	  );
	wire_nl0lll_oe <= wire_w_lg_w_lg_w_eqc_set_range702w714w719w(0);
	wire_w_lg_w_lg_w_eqc_set_range702w714w719w(0) <= (eqc_set(0) AND eqc_set(1)) AND eqc_set(2);
	nl0lll :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nl0lll_dataout,
		oe => wire_nl0lll_oe
	  );
	wire_nl0llO_oe <= wire_w_lg_w_lg_w_lg_w_eqc_set_range702w703w712w718w(0);
	wire_w_lg_w_lg_w_lg_w_eqc_set_range702w703w712w718w(0) <= ((NOT eqc_set(0)) AND eqc_set(1)) AND eqc_set(2);
	nl0llO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl0llO_dataout,
		oe => wire_nl0llO_oe
	  );
	wire_nl0lOi_oe <= wire_w_lg_w_lg_w_eqc_set_range702w710w717w(0);
	wire_w_lg_w_lg_w_eqc_set_range702w710w717w(0) <= wire_w_lg_w_eqc_set_range702w710w(0) AND eqc_set(2);
	nl0lOi :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl0lOi_dataout,
		oe => wire_nl0lOi_oe
	  );
	wire_nl0lOl_oe <= wire_w_lg_w_lg_w_lg_w_eqc_set_range702w703w706w716w(0);
	wire_w_lg_w_lg_w_lg_w_eqc_set_range702w703w706w716w(0) <= ((NOT eqc_set(0)) AND wire_w_lg_w_eqc_set_range704w705w(0)) AND eqc_set(2);
	nl0lOl :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl0lOl_dataout,
		oe => wire_nl0lOl_oe
	  );
	wire_nl0lOO_oe <= wire_w_lg_w_lg_w_eqc_set_range702w714w715w(0);
	wire_w_lg_w_lg_w_eqc_set_range702w714w715w(0) <= (eqc_set(0) AND eqc_set(1)) AND (NOT eqc_set(2));
	nl0lOO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl0lOO_dataout,
		oe => wire_nl0lOO_oe
	  );
	wire_nl0O0l_oe <= wire_w_lg_radce_adapt692w(0);
	wire_w_lg_radce_adapt692w(0) <= radce_adapt AND wire_w_lg_n0l0iO549w(0);
	nl0O0l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl0O0l_dataout,
		oe => wire_nl0O0l_oe
	  );
	wire_nl0O0O_oe <= wire_w_lg_w_lg_w_lg_radce_adapt537w538w691w(0);
	wire_w_lg_w_lg_w_lg_radce_adapt537w538w691w(0) <= (NOT (radce_adapt OR wire_w_lg_radce_pdb536w(0))) OR ((radce_adapt AND n0l0iO) AND (NOT ((NOT wire_w_lg_w_rseq_sel_range543w684w(0)) AND (NOT (wire_w_lg_w_rseq_sel_range543w555w(0) AND wire_w_lg_n0l0il540w(0))))));
	nl0O0O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl0O0i_dataout(0),
		dataout => wire_nl0O0O_dataout,
		oe => wire_nl0O0O_oe
	  );
	wire_nl0O1i_oe <= wire_w_lg_w_lg_w_lg_w_eqc_set_range702w703w712w713w(0);
	wire_w_lg_w_lg_w_lg_w_eqc_set_range702w703w712w713w(0) <= ((NOT eqc_set(0)) AND eqc_set(1)) AND (NOT eqc_set(2));
	nl0O1i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl0O1i_dataout,
		oe => wire_nl0O1i_oe
	  );
	wire_nl0O1l_oe <= wire_w_lg_w_lg_w_eqc_set_range702w710w711w(0);
	wire_w_lg_w_lg_w_eqc_set_range702w710w711w(0) <= wire_w_lg_w_eqc_set_range702w710w(0) AND (NOT eqc_set(2));
	nl0O1l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl0O1l_dataout,
		oe => wire_nl0O1l_oe
	  );
	wire_nl0O1O_oe <= wire_w_lg_w_lg_w_lg_w_eqc_set_range702w703w706w709w(0);
	wire_w_lg_w_lg_w_lg_w_eqc_set_range702w703w706w709w(0) <= ((NOT eqc_set(0)) AND wire_w_lg_w_eqc_set_range704w705w(0)) AND (NOT eqc_set(2));
	nl0O1O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1llO_dataout(0),
		dataout => wire_nl0O1O_dataout,
		oe => wire_nl0O1O_oe
	  );
	wire_nl0Oii_oe <= wire_w_lg_n0i00i681w(0);
	nl0Oii :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1llO_dataout(0),
		dataout => wire_nl0Oii_dataout,
		oe => wire_nl0Oii_oe
	  );
	wire_nl0Oil_oe <= wire_w_lg_n0i00i680w(0);
	wire_w_lg_n0i00i680w(0) <= n0i00i AND ((radce_adapt AND n0l0iO) AND (NOT ((NOT (wire_w_lg_w_rseq_sel_range543w555w(0) AND (wire_w_lg_w_lg_n0l0ll570w671w(0) OR wire_w_lg_n0l0li547w(0)))) AND (NOT wire_w_lg_w_rseq_sel_range543w675w(0)))));
	nl0Oil :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl0OiO_dataout,
		dataout => wire_nl0Oil_dataout,
		oe => wire_nl0Oil_oe
	  );
	nl0OiO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl0Oli_dataout,
		dataout => wire_nl0OiO_dataout,
		oe => wire_vcc
	  );
	wire_nl110l_w_lg_dataout865w(0) <= NOT wire_nl110l_dataout;
	nl110l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl110O_dataout,
		dataout => wire_nl110l_dataout,
		oe => wire_vcc
	  );
	nl111O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl110i_dataout,
		dataout => wire_nl111O_dataout,
		oe => wire_vcc
	  );
	nl11iO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl11li_dataout,
		dataout => wire_nl11iO_dataout,
		oe => wire_vcc
	  );
	wire_nl11ll_w_lg_dataout857w(0) <= NOT wire_nl11ll_dataout;
	nl11ll :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl11lO_dataout,
		dataout => wire_nl11ll_dataout,
		oe => wire_vcc
	  );
	nl1i0l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1i0O_dataout,
		dataout => wire_nl1i0l_dataout,
		oe => wire_vcc
	  );
	nl1i1O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1i0i_dataout,
		dataout => wire_nl1i1O_dataout,
		oe => wire_vcc
	  );
	wire_nl1l0i_oe <= wire_w_lg_w_lg_w_lg_w_eqa_set_range800w801w810w816w(0);
	wire_w_lg_w_lg_w_lg_w_eqa_set_range800w801w810w816w(0) <= ((NOT eqa_set(0)) AND eqa_set(1)) AND eqa_set(2);
	nl1l0i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl1l0i_dataout,
		oe => wire_nl1l0i_oe
	  );
	wire_nl1l0l_oe <= wire_w_lg_w_lg_w_eqa_set_range800w808w815w(0);
	wire_w_lg_w_lg_w_eqa_set_range800w808w815w(0) <= wire_w_lg_w_eqa_set_range800w808w(0) AND eqa_set(2);
	nl1l0l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl1l0l_dataout,
		oe => wire_nl1l0l_oe
	  );
	wire_nl1l0O_oe <= wire_w_lg_w_lg_w_lg_w_eqa_set_range800w801w804w814w(0);
	wire_w_lg_w_lg_w_lg_w_eqa_set_range800w801w804w814w(0) <= ((NOT eqa_set(0)) AND wire_w_lg_w_eqa_set_range802w803w(0)) AND eqa_set(2);
	nl1l0O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl1l0O_dataout,
		oe => wire_nl1l0O_oe
	  );
	wire_nl1l1O_oe <= wire_w_lg_w_lg_w_eqa_set_range800w812w817w(0);
	wire_w_lg_w_lg_w_eqa_set_range800w812w817w(0) <= (eqa_set(0) AND eqa_set(1)) AND eqa_set(2);
	nl1l1O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nl1l1O_dataout,
		oe => wire_nl1l1O_oe
	  );
	wire_nl1lii_oe <= wire_w_lg_w_lg_w_eqa_set_range800w812w813w(0);
	wire_w_lg_w_lg_w_eqa_set_range800w812w813w(0) <= (eqa_set(0) AND eqa_set(1)) AND (NOT eqa_set(2));
	nl1lii :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl1lii_dataout,
		oe => wire_nl1lii_oe
	  );
	wire_nl1lil_oe <= wire_w_lg_w_lg_w_lg_w_eqa_set_range800w801w810w811w(0);
	wire_w_lg_w_lg_w_lg_w_eqa_set_range800w801w810w811w(0) <= ((NOT eqa_set(0)) AND eqa_set(1)) AND (NOT eqa_set(2));
	nl1lil :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl1lil_dataout,
		oe => wire_nl1lil_oe
	  );
	wire_nl1liO_oe <= wire_w_lg_w_lg_w_eqa_set_range800w808w809w(0);
	wire_w_lg_w_lg_w_eqa_set_range800w808w809w(0) <= wire_w_lg_w_eqa_set_range800w808w(0) AND (NOT eqa_set(2));
	nl1liO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl1liO_dataout,
		oe => wire_nl1liO_oe
	  );
	wire_nl1lli_oe <= wire_w_lg_w_lg_w_lg_w_eqa_set_range800w801w804w807w(0);
	wire_w_lg_w_lg_w_lg_w_eqa_set_range800w801w804w807w(0) <= ((NOT eqa_set(0)) AND wire_w_lg_w_eqa_set_range802w803w(0)) AND (NOT eqa_set(2));
	nl1lli :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1llO_dataout(0),
		dataout => wire_nl1lli_dataout,
		oe => wire_nl1lli_oe
	  );
	wire_nl1lOl_oe <= wire_w_lg_radce_adapt786w(0);
	wire_w_lg_radce_adapt786w(0) <= radce_adapt AND wire_w_lg_n0l0ll570w(0);
	nl1lOl :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nl1lOl_dataout,
		oe => wire_nl1lOl_oe
	  );
	wire_nl1lOO_oe <= wire_w_lg_w_lg_w_lg_radce_adapt537w538w785w(0);
	wire_w_lg_w_lg_w_lg_radce_adapt537w538w785w(0) <= (NOT (radce_adapt OR wire_w_lg_radce_pdb536w(0))) OR ((radce_adapt AND n0l0ll) AND wire_nl1lOi_dataout(0));
	nl1lOO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lll_dataout(0),
		dataout => wire_nl1lOO_dataout,
		oe => wire_nl1lOO_oe
	  );
	wire_nl1O1i_oe <= wire_w_lg_n0i01i782w(0);
	nl1O1i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1llO_dataout(0),
		dataout => wire_nl1O1i_dataout,
		oe => wire_nl1O1i_oe
	  );
	wire_nl1O1l_oe <= wire_w_lg_n0i01i781w(0);
	wire_w_lg_n0i01i781w(0) <= n0i01i AND ((radce_adapt AND n0l0ll) AND wire_nl1llO_dataout(0));
	nl1O1l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1O1O_dataout,
		dataout => wire_nl1O1l_dataout,
		oe => wire_nl1O1l_oe
	  );
	nl1O1O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1O0i_dataout,
		dataout => wire_nl1O1O_dataout,
		oe => wire_vcc
	  );
	wire_nli00i_oe <= wire_w_lg_w_lg_w_eqd_set_range647w655w662w(0);
	wire_w_lg_w_lg_w_eqd_set_range647w655w662w(0) <= wire_w_lg_w_eqd_set_range647w655w(0) AND eqd_set(2);
	nli00i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nli00i_dataout,
		oe => wire_nli00i_oe
	  );
	wire_nli00l_oe <= wire_w_lg_w_lg_w_lg_w_eqd_set_range647w648w651w661w(0);
	wire_w_lg_w_lg_w_lg_w_eqd_set_range647w648w651w661w(0) <= ((NOT eqd_set(0)) AND wire_w_lg_w_eqd_set_range649w650w(0)) AND eqd_set(2);
	nli00l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nli00l_dataout,
		oe => wire_nli00l_oe
	  );
	wire_nli00O_oe <= wire_w_lg_w_lg_w_eqd_set_range647w659w660w(0);
	wire_w_lg_w_lg_w_eqd_set_range647w659w660w(0) <= (eqd_set(0) AND eqd_set(1)) AND (NOT eqd_set(2));
	nli00O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nli00O_dataout,
		oe => wire_nli00O_oe
	  );
	wire_nli01l_oe <= wire_w_lg_w_lg_w_eqd_set_range647w659w664w(0);
	wire_w_lg_w_lg_w_eqd_set_range647w659w664w(0) <= (eqd_set(0) AND eqd_set(1)) AND eqd_set(2);
	nli01l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nli01l_dataout,
		oe => wire_nli01l_oe
	  );
	wire_nli01O_oe <= wire_w_lg_w_lg_w_lg_w_eqd_set_range647w648w657w663w(0);
	wire_w_lg_w_lg_w_lg_w_eqd_set_range647w648w657w663w(0) <= ((NOT eqd_set(0)) AND eqd_set(1)) AND eqd_set(2);
	nli01O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nli01O_dataout,
		oe => wire_nli01O_oe
	  );
	wire_nli0ii_oe <= wire_w_lg_w_lg_w_lg_w_eqd_set_range647w648w657w658w(0);
	wire_w_lg_w_lg_w_lg_w_eqd_set_range647w648w657w658w(0) <= ((NOT eqd_set(0)) AND eqd_set(1)) AND (NOT eqd_set(2));
	nli0ii :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nli0ii_dataout,
		oe => wire_nli0ii_oe
	  );
	wire_nli0il_oe <= wire_w_lg_w_lg_w_eqd_set_range647w655w656w(0);
	wire_w_lg_w_lg_w_eqd_set_range647w655w656w(0) <= wire_w_lg_w_eqd_set_range647w655w(0) AND (NOT eqd_set(2));
	nli0il :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nli0il_dataout,
		oe => wire_nli0il_oe
	  );
	wire_nli0iO_oe <= wire_w_lg_w_lg_w_lg_w_eqd_set_range647w648w651w654w(0);
	wire_w_lg_w_lg_w_lg_w_eqd_set_range647w648w651w654w(0) <= ((NOT eqd_set(0)) AND wire_w_lg_w_eqd_set_range649w650w(0)) AND (NOT eqd_set(2));
	nli0iO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1llO_dataout(0),
		dataout => wire_nli0iO_dataout,
		oe => wire_nli0iO_oe
	  );
	wire_nli0ll_oe <= wire_w_lg_radce_adapt637w(0);
	wire_w_lg_radce_adapt637w(0) <= radce_adapt AND wire_w_lg_n0l0il540w(0);
	nli0ll :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nli0ll_dataout,
		oe => wire_nli0ll_oe
	  );
	wire_nli0lO_oe <= wire_w_lg_w_lg_w_lg_radce_adapt537w538w636w(0);
	wire_w_lg_w_lg_w_lg_radce_adapt537w538w636w(0) <= (NOT (radce_adapt OR wire_w_lg_radce_pdb536w(0))) OR ((radce_adapt AND n0l0il) AND (n0l0ii AND n0i00l));
	nli0lO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nli0li_dataout(0),
		dataout => wire_nli0lO_dataout,
		oe => wire_nli0lO_oe
	  );
	wire_nli0Oi_oe <= wire_w_lg_n0i00O632w(0);
	nli0Oi :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1llO_dataout(0),
		dataout => wire_nli0Oi_dataout,
		oe => wire_nli0Oi_oe
	  );
	wire_nli0Ol_oe <= wire_w_lg_n0i00O631w(0);
	wire_w_lg_n0i00O631w(0) <= n0i00O AND ((radce_adapt AND n0l0il) AND (NOT ((NOT (wire_w_lg_n0l0ll570w(0) OR wire_w_lg_n0i00l623w(0))) AND (NOT (wire_w_lg_n0l0li547w(0) OR wire_w_lg_n0l0iO549w(0))))));
	nli0Ol :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nli0OO_dataout,
		dataout => wire_nli0Ol_dataout,
		oe => wire_nli0Ol_oe
	  );
	nli0OO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlii1i_dataout,
		dataout => wire_nli0OO_dataout,
		oe => wire_vcc
	  );
	wire_nliOil_oe <= wire_w_lg_w_lg_w_lg_w_eqv_set_range596w601w607w613w(0);
	wire_w_lg_w_lg_w_lg_w_eqv_set_range596w601w607w613w(0) <= ((NOT eqv_set(0)) AND wire_w_lg_w_eqv_set_range597w604w(0)) AND (NOT eqv_set(2));
	nliOil :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nliOil_dataout,
		oe => wire_nliOil_oe
	  );
	wire_nliOiO_oe <= wire_w_lg_w_lg_w_eqv_set_range596w605w612w(0);
	wire_w_lg_w_lg_w_eqv_set_range596w605w612w(0) <= wire_w_lg_w_eqv_set_range596w605w(0) AND (NOT eqv_set(2));
	nliOiO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nliOiO_dataout,
		oe => wire_nliOiO_oe
	  );
	wire_nliOli_oe <= wire_w_lg_w_lg_w_lg_w_eqv_set_range596w601w602w611w(0);
	wire_w_lg_w_lg_w_lg_w_eqv_set_range596w601w602w611w(0) <= ((NOT eqv_set(0)) AND eqv_set(1)) AND (NOT eqv_set(2));
	nliOli :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nliOli_dataout,
		oe => wire_nliOli_oe
	  );
	wire_nliOll_oe <= wire_w_lg_w_lg_w_eqv_set_range596w598w610w(0);
	wire_w_lg_w_lg_w_eqv_set_range596w598w610w(0) <= (eqv_set(0) AND eqv_set(1)) AND (NOT eqv_set(2));
	nliOll :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nliOll_dataout,
		oe => wire_nliOll_oe
	  );
	wire_nliOlO_oe <= wire_w_lg_w_lg_w_lg_w_eqv_set_range596w601w607w608w(0);
	wire_w_lg_w_lg_w_lg_w_eqv_set_range596w601w607w608w(0) <= ((NOT eqv_set(0)) AND wire_w_lg_w_eqv_set_range597w604w(0)) AND eqv_set(2);
	nliOlO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nliOlO_dataout,
		oe => wire_nliOlO_oe
	  );
	wire_nliOOi_oe <= wire_w_lg_w_lg_w_eqv_set_range596w605w606w(0);
	wire_w_lg_w_lg_w_eqv_set_range596w605w606w(0) <= wire_w_lg_w_eqv_set_range596w605w(0) AND eqv_set(2);
	nliOOi :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nliOOi_dataout,
		oe => wire_nliOOi_oe
	  );
	wire_nliOOl_oe <= wire_w_lg_w_lg_w_lg_w_eqv_set_range596w601w602w603w(0);
	wire_w_lg_w_lg_w_lg_w_eqv_set_range596w601w602w603w(0) <= ((NOT eqv_set(0)) AND eqv_set(1)) AND eqv_set(2);
	nliOOl :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nliOOl_dataout,
		oe => wire_nliOOl_oe
	  );
	wire_nliOOO_oe <= wire_w_lg_w_lg_w_eqv_set_range596w598w600w(0);
	wire_w_lg_w_lg_w_eqv_set_range596w598w600w(0) <= (eqv_set(0) AND eqv_set(1)) AND eqv_set(2);
	nliOOO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1llO_dataout(0),
		dataout => wire_nliOOO_dataout,
		oe => wire_nliOOO_oe
	  );
	nll00i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nll00l_dataout,
		dataout => wire_nll00i_dataout,
		oe => wire_vcc
	  );
	wire_nll00O_w_lg_dataout503w(0) <= NOT wire_nll00O_dataout;
	nll00O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nll0ii_dataout,
		dataout => wire_nll00O_dataout,
		oe => wire_vcc
	  );
	nll0il :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nll0il_dataout,
		oe => wire_nl1lOi_dataout(0)
	  );
	wire_nll0iO_oe <= wire_nl1lOi_w_lg_w_dataout_range33w252w(0);
	nll0iO :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_nll0iO_dataout,
		oe => wire_nll0iO_oe
	  );
	nll0li :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_nll0li_dataout,
		oe => wire_nl1lOi_dataout(0)
	  );
	wire_nll0ll_oe <= wire_nl1lOi_w_lg_w_dataout_range33w252w(0);
	nll0ll :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nll0ll_dataout,
		oe => wire_nll0ll_oe
	  );
	wire_nll10i_oe <= wire_w_lg_w_lg_w_lg_radce_adapt537w538w564w(0);
	wire_w_lg_w_lg_w_lg_radce_adapt537w538w564w(0) <= (NOT (radce_adapt OR wire_w_lg_radce_pdb536w(0))) OR (wire_w_lg_radce_adapt539w(0) AND (NOT (((NOT (wire_w_lg_n0l0il540w(0) AND ((NOT rseq_sel(0)) AND rseq_sel(1)))) AND (NOT (((wire_w_lg_n0l0li547w(0) OR wire_w_lg_n0l0il540w(0)) OR wire_w_lg_n0l0iO549w(0)) AND wire_w_lg_n0i0ii551w(0)))) AND ((NOT wire_w_lg_w_rseq_sel_range541w556w(0)) OR (NOT (wire_w_lg_n0l0il540w(0) OR wire_w_lg_n0l0iO549w(0)))))));
	nll10i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nll11i_dataout(0),
		dataout => wire_nll10i_dataout,
		oe => wire_nll10i_oe
	  );
	wire_nll11l_oe <= wire_w_lg_radce_adapt586w(0);
	wire_w_lg_radce_adapt586w(0) <= radce_adapt AND n0l0ii;
	nll11l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_gnd,
		dataout => wire_nll11l_dataout,
		oe => wire_nll11l_oe
	  );
	wire_nll11O_oe <= wire_w_lg_w_lg_w_lg_radce_adapt565w566w585w(0);
	wire_w_lg_w_lg_w_lg_radce_adapt565w566w585w(0) <= (NOT (radce_adapt OR radce_pdb)) OR (wire_w_lg_radce_adapt539w(0) AND ((NOT ((NOT (rseq_sel(0) AND rseq_sel(1))) AND ((NOT ((NOT rseq_sel(0)) AND rseq_sel(1))) OR (NOT (wire_w_lg_w_lg_n0l0ll570w571w(0) OR wire_w_lg_n0l0iO549w(0)))))) OR (NOT (((NOT wire_w_lg_w_rseq_sel_range541w556w(0)) OR (NOT wire_w_lg_w_lg_n0l0ll570w571w(0))) AND (NOT (wire_w_lg_n0l0ll570w(0) AND wire_w_lg_n0i0ii551w(0)))))));
	nll11O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nll11O_dataout,
		oe => wire_nll11O_oe
	  );
	nlliil :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlliiO_dataout,
		dataout => wire_nlliil_dataout,
		oe => wire_vcc
	  );
	wire_nllili_w_lg_dataout480w(0) <= NOT wire_nllili_dataout;
	nllili :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nllill_dataout,
		dataout => wire_nllili_dataout,
		oe => wire_vcc
	  );
	nllilO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nllilO_dataout,
		oe => wire_nl1lOi_dataout(0)
	  );
	wire_nlliOi_oe <= wire_nl1lOi_w_lg_w_dataout_range33w252w(0);
	nlliOi :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_nlliOi_dataout,
		oe => wire_nlliOi_oe
	  );
	nlliOl :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_nlliOl_dataout,
		oe => wire_nl1lOi_dataout(0)
	  );
	wire_nlliOO_oe <= wire_nl1lOi_w_lg_w_dataout_range33w252w(0);
	nlliOO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nlliOO_dataout,
		oe => wire_nlliOO_oe
	  );
	nllllO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlllOi_dataout,
		dataout => wire_nllllO_dataout,
		oe => wire_vcc
	  );
	wire_nlllOl_w_lg_dataout459w(0) <= NOT wire_nlllOl_dataout;
	nlllOl :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlllOO_dataout,
		dataout => wire_nlllOl_dataout,
		oe => wire_vcc
	  );
	wire_nllO0i_oe <= wire_nl1lOi_w_lg_w_dataout_range33w252w(0);
	nllO0i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nllO0i_dataout,
		oe => wire_nllO0i_oe
	  );
	nllO1i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nllO1i_dataout,
		oe => wire_nl1lOi_dataout(0)
	  );
	wire_nllO1l_oe <= wire_nl1lOi_w_lg_w_dataout_range33w252w(0);
	nllO1l :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_nllO1l_dataout,
		oe => wire_nllO1l_oe
	  );
	nllO1O :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_nllO1O_dataout,
		oe => wire_nl1lOi_dataout(0)
	  );
	nlO00l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlO00O_dataout,
		dataout => wire_nlO00l_dataout,
		oe => wire_vcc
	  );
	wire_nlO0ii_w_lg_dataout415w(0) <= NOT wire_nlO0ii_dataout;
	nlO0ii :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlO0il_dataout,
		dataout => wire_nlO0ii_dataout,
		oe => wire_vcc
	  );
	nlO0iO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nlO0iO_dataout,
		oe => radce_vod_int(1)
	  );
	wire_nlO0li_oe <= wire_w_lg_w_radce_vod_int_range408w409w(0);
	wire_w_lg_w_radce_vod_int_range408w409w(0) <= NOT radce_vod_int(1);
	nlO0li :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_nlO0li_dataout,
		oe => wire_nlO0li_oe
	  );
	nlO0ll :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_nlO0ll_dataout,
		oe => radce_vod_int(1)
	  );
	wire_nlO0lO_oe <= wire_w_lg_w_radce_vod_int_range408w409w(0);
	nlO0lO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nlO0lO_dataout,
		oe => wire_nlO0lO_oe
	  );
	nlO10l :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nlO10l_dataout,
		oe => radce_vod_int(0)
	  );
	wire_nlO10O_oe <= wire_w_lg_w_radce_vod_int_range431w432w(0);
	wire_w_lg_w_radce_vod_int_range431w432w(0) <= NOT radce_vod_int(0);
	nlO10O :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_nlO10O_dataout,
		oe => wire_nlO10O_oe
	  );
	nlO11i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlO11l_dataout,
		dataout => wire_nlO11i_dataout,
		oe => wire_vcc
	  );
	wire_nlO11O_w_lg_dataout438w(0) <= NOT wire_nlO11O_dataout;
	nlO11O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlO10i_dataout,
		dataout => wire_nlO11O_dataout,
		oe => wire_vcc
	  );
	nlO1ii :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_nlO1ii_dataout,
		oe => radce_vod_int(0)
	  );
	wire_nlO1il_oe <= wire_w_lg_w_radce_vod_int_range431w432w(0);
	nlO1il :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nlO1il_dataout,
		oe => wire_nlO1il_oe
	  );
	nlOiiO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlOili_dataout,
		dataout => wire_nlOiiO_dataout,
		oe => wire_vcc
	  );
	wire_nlOill_w_lg_dataout392w(0) <= NOT wire_nlOill_dataout;
	nlOill :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlOilO_dataout,
		dataout => wire_nlOill_dataout,
		oe => wire_vcc
	  );
	nlOiOi :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nlOiOi_dataout,
		oe => radce_vod_int(2)
	  );
	wire_nlOiOl_oe <= wire_w_lg_w_radce_vod_int_range382w383w(0);
	wire_w_lg_w_radce_vod_int_range382w383w(0) <= NOT radce_vod_int(2);
	nlOiOl :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_nlOiOl_dataout,
		oe => wire_nlOiOl_oe
	  );
	nlOiOO :  io_buf_tri
	  PORT MAP ( 
		datain => radce_rstb,
		dataout => wire_nlOiOO_dataout,
		oe => radce_vod_int(2)
	  );
	wire_nlOl1i_oe <= wire_w_lg_w_radce_vod_int_range382w383w(0);
	nlOl1i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nl1lOi_dataout(0),
		dataout => wire_nlOl1i_dataout,
		oe => wire_nlOl1i_oe
	  );
	wire_nlOlil_w_lg_dataout358w(0) <= NOT wire_nlOlil_dataout;
	nlOlil :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlOliO_dataout,
		dataout => wire_nlOlil_dataout,
		oe => wire_vcc
	  );
	wire_nlOlli_w_lg_dataout340w(0) <= NOT wire_nlOlli_dataout;
	nlOlli :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlOlll_dataout,
		dataout => wire_nlOlli_dataout,
		oe => wire_vcc
	  );
	wire_nlOllO_w_lg_dataout311w(0) <= NOT wire_nlOllO_dataout;
	nlOllO :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlOlOi_dataout,
		dataout => wire_nlOllO_dataout,
		oe => wire_vcc
	  );
	wire_nlOlOl_w_lg_dataout321w(0) <= NOT wire_nlOlOl_dataout;
	nlOlOl :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlOlOO_dataout,
		dataout => wire_nlOlOl_dataout,
		oe => wire_vcc
	  );
	wire_nlOO1i_w_lg_dataout329w(0) <= NOT wire_nlOO1i_dataout;
	nlOO1i :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlOO1l_dataout,
		dataout => wire_nlOO1i_dataout,
		oe => wire_vcc
	  );
	wire_nlOO1O_w_lg_dataout350w(0) <= NOT wire_nlOO1O_dataout;
	nlOO1O :  io_buf_tri
	  PORT MAP ( 
		datain => wire_nlOO0i_dataout,
		dataout => wire_nlOO1O_dataout,
		oe => wire_vcc
	  );
	wire_n010O_dataout <= n01il WHEN (NOT (n0ilOO AND n011O)) = '1'  ELSE n01li;
	wire_n011l_dataout <= n011O WHEN wire_w_lg_n0ilOO244w(0) = '1'  ELSE n010i;
	wire_n0liiO_dataout <= n0lili WHEN (NOT wire_nl1lOi_dataout(0)) = '1'  ELSE n0lill;
	wire_n0liOl_dataout <= n0liOO WHEN wire_w_lg_n000il1522w(0) = '1'  ELSE n0ll1i;
	wire_n0ll0i_dataout <= n0ll0l WHEN wire_w_lg_n000iO1519w(0) = '1'  ELSE n0ll0O;
	wire_n0lliO_dataout <= n0llll WHEN (NOT (n000iO AND n0ll0l)) = '1'  ELSE n0llOi;
	wire_n0O00i_dataout <= n0O00O WHEN (NOT (n000lO AND n0O1OO)) = '1'  ELSE n0O0il;
	wire_n0O10i_dataout <= n0O10l WHEN (NOT wire_nl1lOi_dataout(0)) = '1'  ELSE n0O10O;
	wire_n0O1iO_dataout <= n0O1li WHEN wire_w_lg_n000ll1461w(0) = '1'  ELSE n0O1ll;
	wire_n0O1Ol_dataout <= n0O1OO WHEN wire_w_lg_n000lO1458w(0) = '1'  ELSE n0O01i;
	wire_n0Ol1O_dataout <= n0Ol0i WHEN (NOT wire_nl1lOi_dataout(0)) = '1'  ELSE n0Ol0l;
	wire_n0Olil_dataout <= n0OliO WHEN wire_w_lg_n00i1i1401w(0) = '1'  ELSE n0Olli;
	wire_n0OlOi_dataout <= n0OlOl WHEN wire_w_lg_n00i1l1398w(0) = '1'  ELSE n0OlOO;
	wire_n0OO1O_dataout <= n0OO0l WHEN (NOT (n00i1l AND n0OlOl)) = '1'  ELSE n0OOii;
	wire_n101i_dataout <= n100i WHEN (NOT wire_nl1lOi_dataout(0)) = '1'  ELSE n100l;
	wire_n101O_dataout <= wire_nl1llO_dataout(0) WHEN wire_w_lg_n0il0O306w(0) = '1'  ELSE wire_n11OO_dataout;
	wire_n10ii_dataout <= n10li WHEN wire_n1i1i_w_lg_n100i276w(0) = '1'  ELSE n10ll;
	wire_n10iO_dataout <= wire_nl1llO_dataout(0) WHEN wire_w_lg_n0il0O306w(0) = '1'  ELSE wire_n100O_dataout;
	wire_n10Oi_dataout <= n1i1l WHEN (NOT (n100i AND n10li)) = '1'  ELSE n1i0i;
	wire_n10OO_dataout <= wire_nl1llO_dataout(0) WHEN wire_w_lg_n0il0O306w(0) = '1'  ELSE wire_n10lO_dataout;
	wire_n1lii_dataout <= wire_w_lg_n0l0lO264w(0) WHEN wire_w_lg_n0ilii262w(0) = '1'  ELSE wire_n1l0i_w_lg_n1l0l263w(0);
	wire_n1liO_dataout <= n0l0lO WHEN wire_w_lg_n0ilii262w(0) = '1'  ELSE n1l0l;
	wire_n1O0l_dataout <= n1O0O WHEN wire_n01ii_w_lg_n1O1l250w(0) = '1'  ELSE n1Oii;
	wire_n1O1i_dataout <= n1O1l WHEN (NOT wire_nl1lOi_dataout(0)) = '1'  ELSE n1O1O;
	wire_n1OiO_dataout <= n1Oli WHEN wire_w_lg_n0ilOl248w(0) = '1'  ELSE n1Oll;
	wire_n1OOi_dataout <= n1OOl WHEN wire_w_lg_n0iO1i246w(0) = '1'  ELSE n1OOO;
	wire_ni00Oi_dataout <= ni00ll WHEN ((NOT (wire_w_lg_n00l1O1230w(0) AND wire_w_lg_n00l1l1231w(0))) AND wire_w_lg_n00O1l1113w(0)) = '1'  ELSE ni00iO;
	wire_ni00OO_dataout <= wire_nil01l_w_lg_dataout1075w(0) WHEN n00O1O = '1'  ELSE wire_ni00lO_dataout;
	wire_ni01iO_dataout <= ni01ii WHEN ((NOT (wire_w_lg_n00iOO1249w(0) AND wire_w_lg_n00iOl1250w(0))) AND wire_w_lg_n00O1l1113w(0)) = '1'  ELSE ni010l;
	wire_ni01ll_dataout <= wire_nil01l_w_lg_dataout1075w(0) WHEN n00O1O = '1'  ELSE wire_ni01il_dataout;
	wire_ni0l0i_dataout <= wire_niOO0l_dataout WHEN n00O1O = '1'  ELSE wire_ni0l1i_dataout;
	wire_ni0l1l_dataout <= ni0iOO WHEN ((NOT (wire_w_lg_n00l0O1211w(0) AND wire_w_lg_n00l0l1212w(0))) AND wire_w_lg_n00O1l1113w(0)) = '1'  ELSE ni0iOi;
	wire_ni0O0O_dataout <= ni0O0i WHEN ((NOT (wire_w_lg_n00liO1192w(0) AND wire_w_lg_n00lil1193w(0))) AND wire_w_lg_n00O1l1113w(0)) = '1'  ELSE ni0O1l;
	wire_ni0Oil_dataout <= (wire_w_lg_n0i10l868w(0) AND (NOT wire_niOl0l_dataout(0))) WHEN n00O1O = '1'  ELSE wire_ni0O0l_dataout;
	wire_ni101O_dataout <= ni100i WHEN wire_w_lg_n00i0i1340w(0) = '1'  ELSE ni100l;
	wire_ni10il_dataout <= ni10iO WHEN wire_w_lg_n00i0l1337w(0) = '1'  ELSE ni10li;
	wire_ni10Oi_dataout <= ni10OO WHEN (NOT (n00i0l AND ni10iO)) = '1'  ELSE ni1i1l;
	wire_ni11Oi_dataout <= ni11Ol WHEN (NOT wire_nl1lOi_dataout(0)) = '1'  ELSE ni11OO;
	wire_ni1O0l_dataout <= ni1O1O WHEN ((NOT (wire_w_lg_n00ilO1268w(0) AND wire_w_lg_n00ill1269w(0))) AND wire_w_lg_n00O1l1113w(0)) = '1'  ELSE ni1O1i;
	wire_ni1Oii_dataout <= wire_nil01l_w_lg_dataout1075w(0) WHEN n00O1O = '1'  ELSE wire_ni1O0i_dataout;
	wire_nii0Ol_dataout <= nii0lO WHEN ((NOT (wire_w_lg_n00lOi1148w(0) AND wire_w_lg_n00llO1149w(0))) AND wire_w_lg_n00O1l1113w(0)) = '1'  ELSE nii0li;
	wire_nii1li_dataout <= nii1il WHEN ((NOT ((NOT (n00liO AND ni0O0i)) AND (NOT (n00lil AND ni0O1l)))) AND wire_w_lg_n00O1l1113w(0)) = '1'  ELSE nii10O;
	wire_nii1lO_dataout <= (wire_w_lg_n0i10l868w(0) AND (NOT wire_niOO1O_dataout(0))) WHEN n00O1O = '1'  ELSE wire_nii1iO_dataout;
	wire_niii1i_dataout <= wire_nii0Oi_dataout AND NOT((NOT wire_nl1lOi_dataout(0)));
	wire_niil0l_dataout <= wire_niil1l_dataout AND NOT((NOT wire_nl1lOi_dataout(0)));
	wire_niil1O_dataout <= niil1i WHEN ((NOT (wire_w_lg_n00O1i1129w(0) AND wire_w_lg_n00lOO1130w(0))) AND wire_w_lg_n00O1l1113w(0)) = '1'  ELSE niiiOl;
	wire_niiOii_dataout <= niiO0l WHEN ((NOT ((NOT (n00O1i AND niil1i)) AND (NOT (n00lOO AND niiiOl)))) AND wire_w_lg_n00O1l1113w(0)) = '1'  ELSE niiO1O;
	wire_niiOiO_dataout <= wire_niiO0O_dataout AND NOT((NOT wire_nl1lOi_dataout(0)));
	wire_nil01i_dataout <= wire_nl1llO_dataout(0) WHEN wire_nl10Ol_w_lg_nl10OO889w(0) = '1'  ELSE (NOT wire_niOO0i_dataout(0));
	wire_nil01O_dataout <= wire_nl1llO_dataout(0) WHEN wire_nl10Ol_w_lg_nl10OO889w(0) = '1'  ELSE wire_nl1lOi_dataout(0);
	wire_nil10O_dataout <= wire_nl1llO_dataout(0) WHEN wire_nl10Ol_w_lg_nl10OO889w(0) = '1'  ELSE wire_nl1lOi_dataout(0);
	wire_nil1il_dataout <= wire_nl1llO_dataout(0) WHEN wire_nl10Ol_w_lg_nl10OO889w(0) = '1'  ELSE wire_nl1lOi_dataout(0);
	wire_nil1li_dataout <= wire_nil1ll_dataout WHEN wire_nl10Ol_w_lg_nl10OO889w(0) = '1'  ELSE (NOT wire_niOiil_dataout(0));
	wire_nil1lO_dataout <= wire_nl1llO_dataout(0) WHEN n0l0ii = '1'  ELSE radce_digital(7);
	wire_nil1Ol_dataout <= wire_nl1llO_dataout(0) WHEN wire_nl10Ol_w_lg_nl10OO889w(0) = '1'  ELSE (NOT wire_niOl0O_dataout(0));
	wire_niOO0O_dataout <= (wire_w_lg_n0i10l868w(0) AND (NOT wire_niOiii_dataout(0))) WHEN (wire_w_lg_n0i10l868w(0) OR (NOT ((NOT ((NOT ((NOT (wire_w_lg_n0l0ll570w(0) AND wire_w_lg_n0i10i872w(0))) AND (NOT (wire_w_lg_n0i11O875w(0) AND wire_w_lg_n0l0li547w(0))))) OR (NOT ((NOT (wire_w_lg_n0i11l880w(0) AND wire_w_lg_n0l0iO549w(0))) AND (NOT (wire_w_lg_n0l0il540w(0) AND n0i11i)))))) OR wire_nl10Ol_w_lg_nl10OO889w(0)))) = '1'  ELSE radce_digital(7);
	wire_niOOOi_dataout <= nl111i WHEN (NOT wire_nl1lOi_dataout(0)) = '1'  ELSE nl111l;
	wire_niOOOO_dataout <= wire_nl1llO_dataout(0) WHEN wire_w_lg_n0i1ll862w(0) = '1'  ELSE wire_niOOlO_dataout;
	wire_nl00OO_dataout <= wire_nl1llO_dataout(0) AND (NOT radce_digital(7));
	wire_nl0Oli_dataout <= wire_nl1llO_dataout(0) AND (NOT radce_digital(7));
	wire_nl110i_dataout <= nl11ii WHEN wire_nl11Oi_w_lg_nl111i830w(0) = '1'  ELSE nl11il;
	wire_nl110O_dataout <= wire_nl1llO_dataout(0) WHEN wire_w_lg_n0i1ll862w(0) = '1'  ELSE wire_nl111O_dataout;
	wire_nl11li_dataout <= nl11Ol WHEN (NOT (nl111i AND nl11ii)) = '1'  ELSE nl101i;
	wire_nl11lO_dataout <= wire_nl1llO_dataout(0) WHEN wire_w_lg_n0i1ll862w(0) = '1'  ELSE wire_nl11iO_dataout;
	wire_nl1i0i_dataout <= wire_w_lg_n0li0i821w(0) WHEN wire_w_lg_n0i1lO819w(0) = '1'  ELSE wire_nl1i1i_w_lg_nl1i1l820w(0);
	wire_nl1i0O_dataout <= n0li0i WHEN wire_w_lg_n0i1lO819w(0) = '1'  ELSE nl1i1l;
	wire_nl1O0i_dataout <= wire_nl1llO_dataout(0) AND (NOT radce_digital(7));
	wire_nlii1i_dataout <= wire_nl1llO_dataout(0) AND (NOT radce_digital(7));
	wire_nll00l_dataout <= nll01O WHEN ((NOT (wire_w_lg_n0i0OO498w(0) AND wire_w_lg_n0i0Ol499w(0))) AND wire_w_lg_n0il1l390w(0)) = '1'  ELSE nll01i;
	wire_nll0ii_dataout <= wire_nll00i_dataout AND NOT((NOT wire_nl1lOi_dataout(0)));
	wire_nlliiO_dataout <= nlliii WHEN ((NOT (wire_w_lg_n0ii0i475w(0) AND wire_w_lg_n0ii1O476w(0))) AND wire_w_lg_n0il1l390w(0)) = '1'  ELSE nlli0l;
	wire_nllill_dataout <= wire_nlliil_dataout AND NOT((NOT wire_nl1lOi_dataout(0)));
	wire_nlllOi_dataout <= nlllll WHEN ((NOT (wire_w_lg_n0iiil454w(0) AND wire_w_lg_n0iiii455w(0))) AND wire_w_lg_n0il1l390w(0)) = '1'  ELSE nllliO;
	wire_nlllOO_dataout <= wire_nllllO_dataout AND NOT((NOT wire_nl1lOi_dataout(0)));
	wire_nlO00O_dataout <= nlO00i WHEN ((NOT (wire_w_lg_n0il1i410w(0) AND wire_w_lg_n0iiOO411w(0))) AND wire_w_lg_n0il1l390w(0)) = '1'  ELSE nlO01l;
	wire_nlO0il_dataout <= wire_nlO00l_dataout AND NOT((NOT wire_nl1lOi_dataout(0)));
	wire_nlO10i_dataout <= wire_nlO11i_dataout AND NOT((NOT wire_nl1lOi_dataout(0)));
	wire_nlO11l_dataout <= nllOOO WHEN ((NOT (wire_w_lg_n0iilO433w(0) AND wire_w_lg_n0iill434w(0))) AND wire_w_lg_n0il1l390w(0)) = '1'  ELSE nllOOi;
	wire_nlOili_dataout <= nlOiil WHEN ((NOT ((NOT (n0il1i AND nlO00i)) AND (NOT (n0iiOO AND nlO01l)))) AND wire_w_lg_n0il1l390w(0)) = '1'  ELSE nlOi0O;
	wire_nlOilO_dataout <= wire_nlOiiO_dataout AND NOT((NOT wire_nl1lOi_dataout(0)));
	wire_nlOliO_dataout <= wire_nl1llO_dataout(0) WHEN wire_n1l1l_w_lg_n1l1O370w(0) = '1'  ELSE wire_nl1lOi_dataout(0);
	wire_nlOlll_dataout <= wire_nl1llO_dataout(0) WHEN wire_n1l1l_w_lg_n1l1O370w(0) = '1'  ELSE wire_nl1lOi_dataout(0);
	wire_nlOlOi_dataout <= radce_vod_lsb WHEN wire_n1l1l_w_lg_n1l1O370w(0) = '1'  ELSE rrgen_set(0);
	wire_nlOlOO_dataout <= radce_digital(8) WHEN wire_n1l1l_w_lg_n1l1O370w(0) = '1'  ELSE rrgen_set(1);
	wire_nlOO0i_dataout <= wire_nl1llO_dataout(0) WHEN wire_n1l1l_w_lg_n1l1O370w(0) = '1'  ELSE wire_nl1lOi_dataout(0);
	wire_nlOO1l_dataout <= radce_digital(9) WHEN wire_n1l1l_w_lg_n1l1O370w(0) = '1'  ELSE rrgen_set(2);
	wire_n0i1i_datain <= ( wire_n00OO_dataout & wire_n00Ol_dataout & wire_n00Oi_dataout & wire_n00lO_dataout & wire_n00ll_dataout & wire_n00li_dataout & wire_n00iO_dataout & wire_n00il_dataout);
	n0i1i :  tri_bus
	  GENERIC MAP (
		width_datain => 8,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_n0i1i_datain,
		dataout => wire_n0i1i_dataout
	  );
	wire_n0l1O_datain <= ( wire_n0l1l_dataout & wire_n0l1i_dataout & wire_n0iOO_dataout & wire_n0iOl_dataout & wire_n0iOi_dataout & wire_n0ilO_dataout & wire_n0ill_dataout & wire_n0ili_dataout);
	n0l1O :  tri_bus
	  GENERIC MAP (
		width_datain => 8,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_n0l1O_datain,
		dataout => wire_n0l1O_dataout
	  );
	wire_ni001i_w_lg_w_dataout_range1257w1258w(0) <= NOT wire_ni001i_w_dataout_range1257w(0);
	wire_ni001i_datain <= ( wire_ni01Oi_dataout & wire_ni01lO_dataout);
	wire_ni001i_w_dataout_range1257w(0) <= wire_ni001i_dataout(0);
	ni001i :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni001i_datain,
		dataout => wire_ni001i_dataout
	  );
	wire_ni001l_w_lg_w_dataout_range1256w1259w(0) <= wire_ni001l_w_dataout_range1256w(0) AND wire_ni001i_w_lg_w_dataout_range1257w1258w(0);
	wire_ni001l_datain <= ( wire_ni01OO_dataout & wire_ni01Ol_dataout);
	wire_ni001l_w_dataout_range1256w(0) <= wire_ni001l_dataout(0);
	ni001l :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni001l_datain,
		dataout => wire_ni001l_dataout
	  );
	wire_ni01l_datain <= ( wire_n0l11O26_w_lg_w_lg_q107w108w & wire_n0l10i24_w_lg_w_lg_q104w105w & wire_ni1lO_dataout & wire_n0l10l22_w_lg_w_lg_q100w101w & wire_ni1li_dataout);
	wire_ni01l_w_dataout_range82w(0) <= wire_ni01l_dataout(0);
	ni01l :  tri_bus
	  GENERIC MAP (
		width_datain => 5,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni01l_datain,
		dataout => wire_ni01l_dataout
	  );
	wire_ni01O_datain <= ( wire_ni01i_dataout & wire_n0l10O20_w_lg_w_lg_q94w95w & wire_n0l1ii18_w_lg_w_lg_q91w92w & wire_ni1il_dataout & wire_ni1ii_dataout);
	wire_ni01O_w_dataout_range77w(0) <= wire_ni01O_dataout(0);
	ni01O :  tri_bus
	  GENERIC MAP (
		width_datain => 5,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni01O_datain,
		dataout => wire_ni01O_dataout
	  );
	wire_ni0i0l_w_lg_w_dataout_range1238w1239w(0) <= NOT wire_ni0i0l_w_dataout_range1238w(0);
	wire_ni0i0l_datain <= ( wire_ni0i1l_dataout & wire_ni0i1i_dataout);
	wire_ni0i0l_w_dataout_range1238w(0) <= wire_ni0i0l_dataout(0);
	ni0i0l :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni0i0l_datain,
		dataout => wire_ni0i0l_dataout
	  );
	wire_ni0i0O_w_lg_w_dataout_range1237w1240w(0) <= wire_ni0i0O_w_dataout_range1237w(0) AND wire_ni0i0l_w_lg_w_dataout_range1238w1239w(0);
	wire_ni0i0O_datain <= ( wire_ni0i0i_dataout & wire_ni0i1O_dataout);
	wire_ni0i0O_w_dataout_range1237w(0) <= wire_ni0i0O_dataout(0);
	ni0i0O :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni0i0O_datain,
		dataout => wire_ni0i0O_dataout
	  );
	wire_ni0liO_w_lg_w_dataout_range1219w1220w(0) <= NOT wire_ni0liO_w_dataout_range1219w(0);
	wire_ni0liO_datain <= ( wire_ni0l0O_dataout & wire_ni0l0l_dataout);
	wire_ni0liO_w_dataout_range1219w(0) <= wire_ni0liO_dataout(0);
	ni0liO :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni0liO_datain,
		dataout => wire_ni0liO_dataout
	  );
	wire_ni0ll_datain <= ( wire_nll10i_dataout & wire_n0l1Ol12_w_lg_w_lg_q72w73w & wire_nll11l_dataout);
	ni0ll :  tri_bus
	  GENERIC MAP (
		width_datain => 3,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni0ll_datain,
		dataout => wire_ni0ll_dataout
	  );
	wire_ni0lli_w_lg_w_dataout_range1218w1221w(0) <= wire_ni0lli_w_dataout_range1218w(0) AND wire_ni0liO_w_lg_w_dataout_range1219w1220w(0);
	wire_ni0lli_datain <= ( wire_ni0lil_dataout & wire_ni0lii_dataout);
	wire_ni0lli_w_dataout_range1218w(0) <= wire_ni0lli_dataout(0);
	ni0lli :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni0lli_datain,
		dataout => wire_ni0lli_dataout
	  );
	wire_ni0lO_datain(0) <= ( vctl_quiet);
	ni0lO :  tri_bus
	  GENERIC MAP (
		width_datain => 1,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni0lO_datain,
		dataout => wire_ni0lO_dataout
	  );
	wire_ni0Oi_datain(0) <= ( vccehxqyx);
	ni0Oi :  tri_bus
	  GENERIC MAP (
		width_datain => 1,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni0Oi_datain,
		dataout => wire_ni0Oi_dataout
	  );
	wire_ni0Ol_datain <= ( wire_n0l1OO10_w_lg_w_lg_q62w63w);
	ni0Ol :  tri_bus
	  GENERIC MAP (
		width_datain => 1,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni0Ol_datain,
		dataout => wire_ni0Ol_dataout
	  );
	wire_ni0OO_datain(0) <= ( outeqn);
	ni0OO :  tri_bus
	  GENERIC MAP (
		width_datain => 1,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni0OO_datain,
		dataout => wire_ni0OO_dataout
	  );
	wire_ni0OOi_w_lg_w_dataout_range1200w1201w(0) <= NOT wire_ni0OOi_w_dataout_range1200w(0);
	wire_ni0OOi_datain <= ( wire_ni0Oli_dataout & wire_ni0OiO_dataout);
	wire_ni0OOi_w_dataout_range1200w(0) <= wire_ni0OOi_dataout(0);
	ni0OOi :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni0OOi_datain,
		dataout => wire_ni0OOi_dataout
	  );
	wire_ni0OOl_w_lg_w_dataout_range1199w1202w(0) <= wire_ni0OOl_w_dataout_range1199w(0) AND wire_ni0OOi_w_lg_w_dataout_range1200w1201w(0);
	wire_ni0OOl_datain <= ( wire_ni0OlO_dataout & wire_ni0Oll_dataout);
	wire_ni0OOl_w_dataout_range1199w(0) <= wire_ni0OOl_dataout(0);
	ni0OOl :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni0OOl_datain,
		dataout => wire_ni0OOl_dataout
	  );
	wire_ni1OlO_w_lg_w_dataout_range1276w1277w(0) <= NOT wire_ni1OlO_w_dataout_range1276w(0);
	wire_ni1OlO_datain <= ( wire_ni1OiO_dataout & wire_ni1Oil_dataout);
	wire_ni1OlO_w_dataout_range1276w(0) <= wire_ni1OlO_dataout(0);
	ni1OlO :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni1OlO_datain,
		dataout => wire_ni1OlO_dataout
	  );
	wire_ni1OOi_w_lg_w_dataout_range1275w1278w(0) <= wire_ni1OOi_w_dataout_range1275w(0) AND wire_ni1OlO_w_lg_w_dataout_range1276w1277w(0);
	wire_ni1OOi_datain <= ( wire_ni1Oll_dataout & wire_ni1Oli_dataout);
	wire_ni1OOi_w_dataout_range1275w(0) <= wire_ni1OOi_dataout(0);
	ni1OOi :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_ni1OOi_datain,
		dataout => wire_ni1OOi_dataout
	  );
	wire_nii01l_w_lg_w_dataout_range1178w1179w(0) <= NOT wire_nii01l_w_dataout_range1178w(0);
	wire_nii01l_datain <= ( wire_nii1Ol_dataout & wire_nii1Oi_dataout);
	wire_nii01l_w_dataout_range1178w(0) <= wire_nii01l_dataout(0);
	nii01l :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nii01l_datain,
		dataout => wire_nii01l_dataout
	  );
	wire_nii01O_w_lg_w_dataout_range1177w1180w(0) <= wire_nii01O_w_dataout_range1177w(0) AND wire_nii01l_w_lg_w_dataout_range1178w1179w(0);
	wire_nii01O_datain <= ( wire_nii01i_dataout & wire_nii1OO_dataout);
	wire_nii01O_w_dataout_range1177w(0) <= wire_nii01O_dataout(0);
	nii01O :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nii01O_datain,
		dataout => wire_nii01O_dataout
	  );
	wire_nii0i_datain(0) <= ( atb_0);
	nii0i :  tri_bus
	  GENERIC MAP (
		width_datain => 1,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nii0i_datain,
		dataout => wire_nii0i_dataout
	  );
	wire_nii0l_datain <= ( "0" & atb1);
	nii0l :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nii0l_datain,
		dataout => wire_nii0l_dataout
	  );
	wire_nii0O_datain <= ( "0" & wire_n0l00i2_w_lg_w_lg_q36w37w);
	nii0O :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nii0O_datain,
		dataout => wire_nii0O_dataout
	  );
	wire_nii1i_datain <= ( wire_n0l01i8_w_lg_w_lg_q56w57w);
	nii1i :  tri_bus
	  GENERIC MAP (
		width_datain => 1,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nii1i_datain,
		dataout => wire_nii1i_dataout
	  );
	wire_nii1l_datain <= ( wire_n0l01l6_w_lg_w_lg_q52w53w);
	nii1l :  tri_bus
	  GENERIC MAP (
		width_datain => 1,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nii1l_datain,
		dataout => wire_nii1l_dataout
	  );
	wire_nii1O_datain <= ( wire_n0l01O4_w_lg_w_lg_q48w49w);
	nii1O :  tri_bus
	  GENERIC MAP (
		width_datain => 1,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nii1O_datain,
		dataout => wire_nii1O_dataout
	  );
	wire_niii0O_w_lg_w_dataout_range1156w1157w(0) <= NOT wire_niii0O_w_dataout_range1156w(0);
	wire_niii0O_datain <= ( wire_niii1O_dataout & wire_niii1l_dataout);
	wire_niii0O_w_dataout_range1156w(0) <= wire_niii0O_dataout(0);
	niii0O :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_niii0O_datain,
		dataout => wire_niii0O_dataout
	  );
	wire_niiiii_w_lg_w_dataout_range1155w1158w(0) <= wire_niiiii_w_dataout_range1155w(0) AND wire_niii0O_w_lg_w_dataout_range1156w1157w(0);
	wire_niiiii_datain <= ( wire_niii0l_dataout & wire_niii0i_dataout);
	wire_niiiii_w_dataout_range1155w(0) <= wire_niiiii_dataout(0);
	niiiii :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_niiiii_datain,
		dataout => wire_niiiii_dataout
	  );
	wire_niilli_w_lg_w_dataout_range1137w1138w(0) <= NOT wire_niilli_w_dataout_range1137w(0);
	wire_niilli_datain <= ( wire_niilii_dataout & wire_niil0O_dataout);
	wire_niilli_w_dataout_range1137w(0) <= wire_niilli_dataout(0);
	niilli :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_niilli_datain,
		dataout => wire_niilli_dataout
	  );
	wire_niilll_w_lg_w_dataout_range1136w1139w(0) <= wire_niilll_w_dataout_range1136w(0) AND wire_niilli_w_lg_w_dataout_range1137w1138w(0);
	wire_niilll_datain <= ( wire_niiliO_dataout & wire_niilil_dataout);
	wire_niilll_w_dataout_range1136w(0) <= wire_niilll_dataout(0);
	niilll :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_niilll_datain,
		dataout => wire_niilll_dataout
	  );
	wire_niiOOl_w_lg_w_dataout_range1118w1119w(0) <= NOT wire_niiOOl_w_dataout_range1118w(0);
	wire_niiOOl_datain <= ( wire_niiOll_dataout & wire_niiOli_dataout);
	wire_niiOOl_w_dataout_range1118w(0) <= wire_niiOOl_dataout(0);
	niiOOl :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_niiOOl_datain,
		dataout => wire_niiOOl_dataout
	  );
	wire_niiOOO_w_lg_w_dataout_range1117w1120w(0) <= wire_niiOOO_w_dataout_range1117w(0) AND wire_niiOOl_w_lg_w_dataout_range1118w1119w(0);
	wire_niiOOO_datain <= ( wire_niiOOi_dataout & wire_niiOlO_dataout);
	wire_niiOOO_w_dataout_range1117w(0) <= wire_niiOOO_dataout(0);
	niiOOO :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_niiOOO_datain,
		dataout => wire_niiOOO_dataout
	  );
	wire_niOiii_datain <= ( wire_niOi0l_dataout & wire_niOi0i_dataout & wire_niOi1O_dataout & wire_niOi1l_dataout & wire_niOi1i_dataout & wire_niO0OO_dataout);
	niOiii :  tri_bus
	  GENERIC MAP (
		width_datain => 6,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_niOiii_datain,
		dataout => wire_niOiii_dataout
	  );
	wire_niOiil_datain <= ( wire_niOi0O_dataout & wire_niO0Ol_dataout & wire_niO0Oi_dataout & wire_niO0lO_dataout & wire_niO0ll_dataout);
	niOiil :  tri_bus
	  GENERIC MAP (
		width_datain => 5,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_niOiil_datain,
		dataout => wire_niOiil_dataout
	  );
	wire_niOl0l_datain <= ( wire_niOl1O_dataout & wire_niOl1l_dataout & wire_niOl1i_dataout & wire_niOiOO_dataout & wire_niOiOl_dataout & wire_niOiOi_dataout);
	niOl0l :  tri_bus
	  GENERIC MAP (
		width_datain => 6,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_niOl0l_datain,
		dataout => wire_niOl0l_dataout
	  );
	wire_niOl0O_datain <= ( wire_niOl0i_dataout & wire_niOilO_dataout & wire_niOill_dataout & wire_niOili_dataout & wire_niOiiO_dataout);
	niOl0O :  tri_bus
	  GENERIC MAP (
		width_datain => 5,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_niOl0O_datain,
		dataout => wire_niOl0O_dataout
	  );
	wire_niOO0i_datain <= ( wire_niOO1l_dataout & wire_niOlli_dataout & wire_niOliO_dataout & wire_niOlil_dataout & wire_niOlii_dataout);
	niOO0i :  tri_bus
	  GENERIC MAP (
		width_datain => 5,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_niOO0i_datain,
		dataout => wire_niOO0i_dataout
	  );
	wire_niOO1O_datain <= ( wire_niOO1i_dataout & wire_niOlOO_dataout & wire_niOlOl_dataout & wire_niOlOi_dataout & wire_niOllO_dataout & wire_niOlll_dataout);
	niOO1O :  tri_bus
	  GENERIC MAP (
		width_datain => 6,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_niOO1O_datain,
		dataout => wire_niOO1O_dataout
	  );
	wire_nl00iO_datain <= ( wire_nl00il_dataout & wire_nl00ii_dataout & wire_nl000O_dataout & wire_nl000l_dataout & wire_nl000i_dataout & wire_nl001O_dataout & wire_nl001l_dataout & wire_nl001i_dataout);
	nl00iO :  tri_bus
	  GENERIC MAP (
		width_datain => 8,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nl00iO_datain,
		dataout => wire_nl00iO_dataout
	  );
	wire_nl0i1i_datain <= ( wire_nl00Oi_dataout & wire_nl00lO_dataout & wire_nl00ll_dataout & wire_nl00li_dataout);
	nl0i1i :  tri_bus
	  GENERIC MAP (
		width_datain => 4,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nl0i1i_datain,
		dataout => wire_nl0i1i_dataout
	  );
	wire_nl0O0i_datain <= ( wire_nl0O1O_dataout & wire_nl0O1l_dataout & wire_nl0O1i_dataout & wire_nl0lOO_dataout & wire_nl0lOl_dataout & wire_nl0lOi_dataout & wire_nl0llO_dataout & wire_nl0lll_dataout);
	nl0O0i :  tri_bus
	  GENERIC MAP (
		width_datain => 8,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nl0O0i_datain,
		dataout => wire_nl0O0i_dataout
	  );
	wire_nl0Oll_datain <= ( wire_nl0Oil_dataout & wire_nl0Oii_dataout & wire_nl0O0O_dataout & wire_nl0O0l_dataout);
	nl0Oll :  tri_bus
	  GENERIC MAP (
		width_datain => 4,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nl0Oll_datain,
		dataout => wire_nl0Oll_dataout
	  );
	wire_nl1lll_datain <= ( wire_nl1lli_dataout & wire_nl1liO_dataout & wire_nl1lil_dataout & wire_nl1lii_dataout & wire_nl1l0O_dataout & wire_nl1l0l_dataout & wire_nl1l0i_dataout & wire_nl1l1O_dataout);
	nl1lll :  tri_bus
	  GENERIC MAP (
		width_datain => 8,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nl1lll_datain,
		dataout => wire_nl1lll_dataout
	  );
	wire_nl1llO_w_lg_w_dataout_range35w348w(0) <= wire_nl1llO_w_dataout_range35w(0) OR wire_nlllil_w_lg_w_lg_w_lg_w_lg_nllliO341w342w346w347w(0);
	wire_nl1llO_w_lg_w_dataout_range35w319w(0) <= wire_nl1llO_w_dataout_range35w(0) OR wire_nllOlO_w_lg_w_lg_w_lg_w_lg_nllOOi312w313w317w318w(0);
	wire_nl1llO_w_lg_w_dataout_range35w144w(0) <= wire_nl1llO_w_dataout_range35w(0) OR wire_w_lg_n0iO0i138w(0);
	wire_nl1llO_w_lg_w_dataout_range35w137w(0) <= wire_nl1llO_w_dataout_range35w(0) OR wire_w_lg_n0iO0l136w(0);
	wire_nl1llO_w_lg_w_dataout_range35w130w(0) <= wire_nl1llO_w_dataout_range35w(0) OR wire_w_lg_n0iOil129w(0);
	wire_nl1llO_datain(0) <= ( vssexqyx);
	wire_nl1llO_w_dataout_range35w(0) <= wire_nl1llO_dataout(0);
	nl1llO :  tri_bus
	  GENERIC MAP (
		width_datain => 1,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nl1llO_datain,
		dataout => wire_nl1llO_dataout
	  );
	wire_nl1lOi_datain(0) <= ( vccerxqyx);
	nl1lOi :  tri_bus
	  GENERIC MAP (
		width_datain => 1,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nl1lOi_datain,
		dataout => wire_nl1lOi_dataout
	  );
	wire_nl1O0l_datain <= ( wire_nl1O1l_dataout & wire_nl1O1i_dataout & wire_nl1lOO_dataout & wire_nl1lOl_dataout);
	nl1O0l :  tri_bus
	  GENERIC MAP (
		width_datain => 4,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nl1O0l_datain,
		dataout => wire_nl1O0l_dataout
	  );
	wire_nli0li_datain <= ( wire_nli0iO_dataout & wire_nli0il_dataout & wire_nli0ii_dataout & wire_nli00O_dataout & wire_nli00l_dataout & wire_nli00i_dataout & wire_nli01O_dataout & wire_nli01l_dataout);
	nli0li :  tri_bus
	  GENERIC MAP (
		width_datain => 8,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nli0li_datain,
		dataout => wire_nli0li_dataout
	  );
	wire_nlii1l_datain <= ( wire_nli0Ol_dataout & wire_nli0Oi_dataout & wire_nli0lO_dataout & wire_nli0ll_dataout);
	nlii1l :  tri_bus
	  GENERIC MAP (
		width_datain => 4,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nlii1l_datain,
		dataout => wire_nlii1l_dataout
	  );
	wire_nll0lO_w_lg_w_dataout_range510w511w(0) <= NOT wire_nll0lO_w_dataout_range510w(0);
	wire_nll0lO_datain <= ( wire_nll0iO_dataout & wire_nll0il_dataout);
	wire_nll0lO_w_dataout_range510w(0) <= wire_nll0lO_dataout(0);
	nll0lO :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nll0lO_datain,
		dataout => wire_nll0lO_dataout
	  );
	wire_nll0Oi_w_lg_w_dataout_range505w512w(0) <= wire_nll0Oi_w_dataout_range505w(0) AND wire_nll0lO_w_lg_w_dataout_range510w511w(0);
	wire_nll0Oi_datain <= ( wire_nll0ll_dataout & wire_nll0li_dataout);
	wire_nll0Oi_w_dataout_range505w(0) <= wire_nll0Oi_dataout(0);
	nll0Oi :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nll0Oi_datain,
		dataout => wire_nll0Oi_dataout
	  );
	wire_nll11i_datain <= ( wire_nliOOO_dataout & wire_nliOOl_dataout & wire_nliOOi_dataout & wire_nliOlO_dataout & wire_nliOll_dataout & wire_nliOli_dataout & wire_nliOiO_dataout & wire_nliOil_dataout);
	nll11i :  tri_bus
	  GENERIC MAP (
		width_datain => 8,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nll11i_datain,
		dataout => wire_nll11i_dataout
	  );
	wire_nlll1i_w_lg_w_dataout_range487w488w(0) <= NOT wire_nlll1i_w_dataout_range487w(0);
	wire_nlll1i_datain <= ( wire_nlliOi_dataout & wire_nllilO_dataout);
	wire_nlll1i_w_dataout_range487w(0) <= wire_nlll1i_dataout(0);
	nlll1i :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nlll1i_datain,
		dataout => wire_nlll1i_dataout
	  );
	wire_nlll1l_w_lg_w_dataout_range482w489w(0) <= wire_nlll1l_w_dataout_range482w(0) AND wire_nlll1i_w_lg_w_dataout_range487w488w(0);
	wire_nlll1l_datain <= ( wire_nlliOO_dataout & wire_nlliOl_dataout);
	wire_nlll1l_w_dataout_range482w(0) <= wire_nlll1l_dataout(0);
	nlll1l :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nlll1l_datain,
		dataout => wire_nlll1l_dataout
	  );
	wire_nllO0l_w_lg_w_dataout_range464w465w(0) <= NOT wire_nllO0l_w_dataout_range464w(0);
	wire_nllO0l_datain <= ( wire_nllO1l_dataout & wire_nllO1i_dataout);
	wire_nllO0l_w_dataout_range464w(0) <= wire_nllO0l_dataout(0);
	nllO0l :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nllO0l_datain,
		dataout => wire_nllO0l_dataout
	  );
	wire_nllO0O_w_lg_w_dataout_range461w466w(0) <= wire_nllO0O_w_dataout_range461w(0) AND wire_nllO0l_w_lg_w_dataout_range464w465w(0);
	wire_nllO0O_datain <= ( wire_nllO0i_dataout & wire_nllO1O_dataout);
	wire_nllO0O_w_dataout_range461w(0) <= wire_nllO0O_dataout(0);
	nllO0O :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nllO0O_datain,
		dataout => wire_nllO0O_dataout
	  );
	wire_nlO0Oi_w_lg_w_dataout_range420w421w(0) <= NOT wire_nlO0Oi_w_dataout_range420w(0);
	wire_nlO0Oi_datain <= ( wire_nlO0li_dataout & wire_nlO0iO_dataout);
	wire_nlO0Oi_w_dataout_range420w(0) <= wire_nlO0Oi_dataout(0);
	nlO0Oi :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nlO0Oi_datain,
		dataout => wire_nlO0Oi_dataout
	  );
	wire_nlO0Ol_w_lg_w_dataout_range417w422w(0) <= wire_nlO0Ol_w_dataout_range417w(0) AND wire_nlO0Oi_w_lg_w_dataout_range420w421w(0);
	wire_nlO0Ol_datain <= ( wire_nlO0lO_dataout & wire_nlO0ll_dataout);
	wire_nlO0Ol_w_dataout_range417w(0) <= wire_nlO0Ol_dataout(0);
	nlO0Ol :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nlO0Ol_datain,
		dataout => wire_nlO0Ol_dataout
	  );
	wire_nlO1iO_w_lg_w_dataout_range443w444w(0) <= NOT wire_nlO1iO_w_dataout_range443w(0);
	wire_nlO1iO_datain <= ( wire_nlO10O_dataout & wire_nlO10l_dataout);
	wire_nlO1iO_w_dataout_range443w(0) <= wire_nlO1iO_dataout(0);
	nlO1iO :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nlO1iO_datain,
		dataout => wire_nlO1iO_dataout
	  );
	wire_nlO1li_w_lg_w_dataout_range442w445w(0) <= wire_nlO1li_w_dataout_range442w(0) AND wire_nlO1iO_w_lg_w_dataout_range443w444w(0);
	wire_nlO1li_datain <= ( wire_nlO1il_dataout & wire_nlO1ii_dataout);
	wire_nlO1li_w_dataout_range442w(0) <= wire_nlO1li_dataout(0);
	nlO1li :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nlO1li_datain,
		dataout => wire_nlO1li_dataout
	  );
	wire_nlOl1l_w_lg_w_dataout_range397w398w(0) <= NOT wire_nlOl1l_w_dataout_range397w(0);
	wire_nlOl1l_datain <= ( wire_nlOiOl_dataout & wire_nlOiOi_dataout);
	wire_nlOl1l_w_dataout_range397w(0) <= wire_nlOl1l_dataout(0);
	nlOl1l :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nlOl1l_datain,
		dataout => wire_nlOl1l_dataout
	  );
	wire_nlOl1O_w_lg_w_dataout_range396w399w(0) <= wire_nlOl1O_w_dataout_range396w(0) AND wire_nlOl1l_w_lg_w_dataout_range397w398w(0);
	wire_nlOl1O_datain <= ( wire_nlOl1i_dataout & wire_nlOiOO_dataout);
	wire_nlOl1O_w_dataout_range396w(0) <= wire_nlOl1O_dataout(0);
	nlOl1O :  tri_bus
	  GENERIC MAP (
		width_datain => 2,
		width_dataout => 1
	  )
	  PORT MAP ( 
		datain => wire_nlOl1O_datain,
		dataout => wire_nlOl1O_dataout
	  );

 END RTL; --stratixiv_hssi_pma_c_adce
--synopsys translate_on
--VALID FILE
-- ***********************************************************
-- This WYSIWYG atom header was automatically generated by the
-- Atmgen build tool. To change it, alter data stored in the 
-- corresponding WYS file(s) in the tools/atmgen subdirectory.
-- ***********************************************************

-- *** Section 1 -- Header ***

-- -----------------------------------------------------------
--
-- Module Name : stratixiv_hssi_clock_divider
--
-- Description : DEV_FAMILY_STRATIXIV stratixiv_hssi_clock_divider Verilog simulation model
--
-- -----------------------------------------------------------

-- *** End of Section 1 ***


-- *** Section 3 -- Module declaration ***


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

USE IEEE.VITAL_Timing.all;
USE IEEE.VITAL_Primitives.all;
ENTITY stratixiv_hssi_clock_divider IS
   GENERIC (

          --  generic control parameters  --
       MsgOn                   : Boolean := DefGlitchMsgOn;
       XOn                     : Boolean := DefGlitchXOn;
       MsgOnChecks             : Boolean := DefMsgOnChecks;
       XOnChecks               : Boolean := DefXOnChecks;
       InstancePath            : String := "*";
       TimingChecksOn          : Boolean := True;
          --  tipd  :interconnect path delays --
      tipd_refclkin               :VitalDelayArrayType01(2 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rateswitchdonein               :VitalDelayArrayType01(2 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_dpriodisable                : VitalDelayType01 := DefpropDelay01;
      tipd_quadreset                : VitalDelayType01 := DefpropDelay01;
      tipd_clk0in               :VitalDelayArrayType01(4 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_vcobypassin                : VitalDelayType01 := DefpropDelay01;
      tipd_clk1in               :VitalDelayArrayType01(4 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rateswitchbaseclkin               :VitalDelayArrayType01(2 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_refclkdig                : VitalDelayType01 := DefpropDelay01;
      tipd_dprioin               :VitalDelayArrayType01(100 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_powerdn                : VitalDelayType01 := DefpropDelay01;
      tipd_rateswitch                : VitalDelayType01 := DefpropDelay01;
          --  tpd: Edge-Sensitive Paths --
          --  tpd: parallel and Full Connection Paths --
          --  tsetup and thold values : setup and hold times  --
          --  Pulse Width parameters  --
      
      -- *** End of Section 3 ***
      
      -- *** Section 4 -- Port size declarations ***
      
      -- Note: Variable port sizes dictated by parameters are not currently defined in
      -- the WYS file data. Busses are marked with the VARIABLE notation as a reminder.
            
      -- *** End of Section 4 ***
      
      -- *** Section 5 -- Port declarations ***
      
      lpm_type                             : STRING := "stratixiv_hssi_clock_divider";
      channel_num                          : INTEGER := 0;
      coreclk_out_gated_by_quad_reset      : STRING := "false";
      data_rate                            : INTEGER := 0;
      divide_by                            : INTEGER := 4;
      divider_type                         : STRING := "CHANNEL_REGULAR";
      dprio_config_mode                    : STD_LOGIC_VECTOR(5 DOWNTO 0) := "000000";
      effective_data_rate                  : STRING := "unused";
      enable_dynamic_divider               : STRING := "false";
      enable_refclk_out                    : STRING := "false";
      inclk_select                         : INTEGER := 0;
      logical_channel_address              : INTEGER := 0;
      pre_divide_by                        : INTEGER := 1;
      rate_switch_base_clk_in_select       : INTEGER := 0;
      rate_switch_done_in_select           : INTEGER := 0;
      refclk_divide_by                     : INTEGER := 0;
      refclk_multiply_by                   : INTEGER := 0;
      refclkin_select                      : INTEGER := 0;
      select_local_rate_switch_base_clock  : STRING := "false";
      select_local_rate_switch_done        : STRING := "true";		-- shawn
      select_local_refclk                  : STRING := "false";
      select_refclk_dig                    : STRING := "false";
      sim_analogfastrefclkout_phase_shift  : INTEGER := 0;
      sim_analogrefclkout_phase_shift      : INTEGER := 0;
      sim_coreclkout_phase_shift           : INTEGER := 0;
      sim_refclkout_phase_shift            : INTEGER := 0;
      use_coreclk_out_post_divider         : STRING := "false";
      use_refclk_post_divider              : STRING := "false";
      use_vco_bypass                       : STRING := "false"
   );
   PORT (
      clk0in                               : IN STD_LOGIC_VECTOR(4 - 1 DOWNTO 0) := (others => '0');
      clk1in                               : IN STD_LOGIC_VECTOR(4 - 1 DOWNTO 0) := (others => '0');
      dpriodisable                         : IN STD_LOGIC := '1';
      dprioin                              : IN STD_LOGIC_VECTOR(100 - 1 DOWNTO 0) := (others => '0');
      powerdn                              : IN STD_LOGIC := '0';
      quadreset                            : IN STD_LOGIC := '0';
      rateswitch                           : IN STD_LOGIC := '0';
      rateswitchbaseclkin                  : IN STD_LOGIC_VECTOR(2 - 1 DOWNTO 0) := (others => '0');
      rateswitchdonein                     : IN STD_LOGIC_VECTOR(2 - 1 DOWNTO 0) := (others => '0');
      refclkdig                            : IN STD_LOGIC := '0';
      refclkin                             : IN STD_LOGIC_VECTOR(2 - 1 DOWNTO 0) := (others => '0');
      vcobypassin                          : IN STD_LOGIC := '0';
      analogfastrefclkout                  : OUT STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
      analogfastrefclkoutshifted           : OUT STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
      analogrefclkout                      : OUT STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
      analogrefclkoutshifted               : OUT STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
      analogrefclkpulse                    : OUT STD_LOGIC;
      analogrefclkpulseshifted             : OUT STD_LOGIC;
      coreclkout                           : OUT STD_LOGIC;
      dprioout                             : OUT STD_LOGIC_VECTOR(100 - 1 DOWNTO 0);
      rateswitchbaseclock                  : OUT STD_LOGIC;
      rateswitchdone                       : OUT STD_LOGIC;
      rateswitchout                        : OUT STD_LOGIC;
      refclkout                            : OUT STD_LOGIC
   );
END stratixiv_hssi_clock_divider;

ARCHITECTURE trans OF stratixiv_hssi_clock_divider IS

  signal refclkin_ipd  :STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
  signal rateswitchdonein_ipd  :STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
  signal dpriodisable_ipd  :STD_LOGIC;
  signal quadreset_ipd  :STD_LOGIC;
  signal clk0in_ipd  :STD_LOGIC_VECTOR(4 - 1 DOWNTO 0);
  signal vcobypassin_ipd  :STD_LOGIC;
  signal clk1in_ipd  :STD_LOGIC_VECTOR(4 - 1 DOWNTO 0);
  signal rateswitchbaseclkin_ipd  :STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
  signal refclkdig_ipd  :STD_LOGIC;
  signal dprioin_ipd  :STD_LOGIC_VECTOR(100 - 1 DOWNTO 0);
  signal powerdn_ipd  :STD_LOGIC;
  signal rateswitch_ipd  :STD_LOGIC;
   COMPONENT stratixiv_hssi_pma_c_clkgenbuf_tx10g
      PORT (
         clk0_in                              : IN STD_LOGIC;
         clk180_in                            : IN STD_LOGIC;
         cpulse                               : OUT STD_LOGIC;
         cpulseb                              : OUT STD_LOGIC;
         hfclk_n                              : OUT STD_LOGIC;
         hfclk_p                              : OUT STD_LOGIC;
         lfclk_n                              : OUT STD_LOGIC;
         lfclk_p                              : OUT STD_LOGIC;
         rst_n                                : IN STD_LOGIC;
         vccelxqyx                            : IN STD_LOGIC;
         vssexqyx                             : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_c_clkgenbuf_cmu
      PORT (
         cgb_vccelxqyx                        : OUT STD_LOGIC;
         cgb_vssexqyx                         : OUT STD_LOGIC;
         cgb_x_en                             : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         clk0_0                               : IN STD_LOGIC;
         clk0_1                               : IN STD_LOGIC;
         clk90_0                              : IN STD_LOGIC;
         clk90_1                              : IN STD_LOGIC;
         clk180_0                             : IN STD_LOGIC;
         clk180_1                             : IN STD_LOGIC;
         clk270_0                             : IN STD_LOGIC;
         clk270_1                             : IN STD_LOGIC;
         pdb                                  : IN STD_LOGIC;
         cmu_sel                              : IN STD_LOGIC;
         cpulse_ht                            : OUT STD_LOGIC;
         cpulse_x1                            : OUT STD_LOGIC;
         div5                                 : IN STD_LOGIC;
         dynamic_sw                           : IN STD_LOGIC;
         hfclkn_ht                            : OUT STD_LOGIC;
         hfclkn_x1                            : OUT STD_LOGIC;
         hfclkp_ht                            : OUT STD_LOGIC;
         hfclkp_x1                            : OUT STD_LOGIC;
         hclk                                 : OUT STD_LOGIC;
         ht_sel                               : IN STD_LOGIC;
         lfclkn_ht                            : OUT STD_LOGIC;
         lfclkn_x1                            : OUT STD_LOGIC;
         lfclkp_ht                            : OUT STD_LOGIC;
         lfclkp_x1                            : OUT STD_LOGIC;
         m_sel                                : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         pcie_sw                              : IN STD_LOGIC;
         pcie_sw_cdr                          : OUT STD_LOGIC;
         pclk                                 : OUT STD_LOGIC;
         gen2ngen1                            : OUT STD_LOGIC;
         rst_n                                : IN STD_LOGIC;
         vccelxqyx                            : IN STD_LOGIC;
         vssexqyx                             : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_aux_clock_div
      GENERIC (
         clk_divide_by                        : INTEGER := 1;
         extra_latency                        : INTEGER := 0
      );
      PORT (
         clk                                  : IN STD_LOGIC;
         reset                                : IN STD_LOGIC;
         powerdown                            : IN STD_LOGIC := '0';
         enable_d                             : IN STD_LOGIC;
         d                                    : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         clkout                               : OUT STD_LOGIC
      );
   END COMPONENT;
   
   
   -- *** End of Section 5 ***
   
   -- *** Section 6 -- Parameter declarations and default values ***
   
   -- *** End of Section 6 ***
   
   -- *** Section 7 -- Port declarations with defaults, if any ***
   
   -- This section will always be empty for WYSIWYG atoms
   -- tri1 devclrn;		//sample
   
   -- *** End of Section 7 ***
   
    -- ---------------------------------------------------------------------------
	--  New DPRIO Begin                                                          
	-- ---------------------------------------------------------------------------
	constant inclk_select_CLOCK_DIV_IDX          : integer := 0;    -- logic
	constant ht_sel_CLOCK_DIV_IDX		         : integer := 1;	-- existing 
	constant rdynamic_sw_CLOCK_DIV_IDX_0 		 : integer := 86;
	constant rpmadwidth_tx_CLOCK_DIV_IDX_0 		 : integer := 89;	-- rcgb_div5
	constant rpma_doublewidth_tx_CLOCK_DIV_IDX_0 : integer := 90;	-- rcgb_div2
	constant rcgb_m_sel_CLOCK_DIV_IDX_0 		 : integer := 91;
	constant rcgb_m_sel_CLOCK_DIV_IDX_1 		 : integer := 92;
	constant rcgb_cmu_sel_CLOCK_DIV_IDX_0 		 : integer := 93;
	
	-- central clock divider section
	constant rfreerun_centrl_CLOCK_DIV_IDX   	: integer := 10;
	constant rcentrl_clk_sel_CLOCK_DIV_IDX     	: integer := 11;
	constant rrefclk_out_div2_CLOCK_DIV_IDX    	: integer := 12;
	
	-- ---------------------------------------------------------------------------
	-- DPRIO input CRAM  
	-- ---------------------------------------------------------------------------
	-- CRAM value from DPRIO
	SIGNAL dprioin_ht_sel: STD_LOGIC;
	SIGNAL dprioin_rcgb_cmu_sel: STD_LOGIC;
	SIGNAL dprioin_rcgb_m_sel: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL dprioin_rpmadwidth_tx: STD_LOGIC;				-- rcgb_div5
	SIGNAL dprioin_rcgb_rpma_doublewidth_tx: STD_LOGIC;		-- rcgb_div2
	SIGNAL dprioin_rcgb_dynamic_sw: STD_LOGIC;
	
	-- central clock divider section
	SIGNAL dprioin_rfreerun_centrl: STD_LOGIC;
	SIGNAL dprioin_rcentrl_clk_sel: STD_LOGIC;
	SIGNAL dprioin_rrefclk_out_div2: STD_LOGIC;
	
	-- ---------------------------------------------------------------------------
	-- Initial CRAM  
	-- ---------------------------------------------------------------------------
	SIGNAL init_ht_sel: STD_LOGIC;
	SIGNAL init_rcgb_cmu_sel: STD_LOGIC;
	SIGNAL init_rcgb_m_sel: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL init_rpmadwidth_tx: STD_LOGIC;				-- rcgb_div5
	SIGNAL init_rcgb_rpma_doublewidth_tx: STD_LOGIC;	-- rcgb_div2
	SIGNAL init_rcgb_dynamic_sw: STD_LOGIC;
	
	-- central clock divider section
	SIGNAL init_rfreerun_centrl: STD_LOGIC;
	SIGNAL init_rcentrl_clk_sel: STD_LOGIC;
	SIGNAL init_rrefclk_out_div2: STD_LOGIC;
	
	-- ---------------------------------------------------------------------------
	-- CRAM  
	-- ---------------------------------------------------------------------------
	SIGNAL cram_ht_sel: STD_LOGIC;
	SIGNAL cram_rcgb_cmu_sel: STD_LOGIC;
	SIGNAL cram_rcgb_m_sel: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL cram_rpmadwidth_tx: STD_LOGIC;				-- rcgb_div5
	SIGNAL cram_rcgb_rpma_doublewidth_tx: STD_LOGIC;	-- rcgb_div2
	SIGNAL cram_rcgb_dynamic_sw: STD_LOGIC;
   
	-- central clock divider section
	SIGNAL cram_rfreerun_centrl: STD_LOGIC;
	SIGNAL cram_rcentrl_clk_sel: STD_LOGIC;
	SIGNAL cram_rrefclk_out_div2: STD_LOGIC;
	
  	SIGNAL dpriodisable_in           : STD_LOGIC;   

  	-- logic index
	SIGNAL dprioin_inclk_select  : STD_LOGIC;
	SIGNAL init_inclk_select     : STD_LOGIC;
	SIGNAL cram_inclk_select     : STD_LOGIC;
   
   -- wires for other inputs and outputs
   -- inputs
   SIGNAL clkgen_cgb_x_en         : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL clkgen_clk0_0           : STD_LOGIC;
   SIGNAL clkgen_clk90_0          : STD_LOGIC;
   SIGNAL clkgen_clk180_0         : STD_LOGIC;
   SIGNAL clkgen_clk270_0         : STD_LOGIC;
   SIGNAL clkgen_clk0_1           : STD_LOGIC;
   SIGNAL clkgen_clk90_1          : STD_LOGIC;
   SIGNAL clkgen_clk180_1         : STD_LOGIC;
   SIGNAL clkgen_clk270_1         : STD_LOGIC;
   SIGNAL clkgen_cmu_sel          : STD_LOGIC;
   SIGNAL clkgen_div5             : STD_LOGIC;
   SIGNAL clkgen_div2             : STD_LOGIC;
   SIGNAL clkgen_dynamic_sw       : STD_LOGIC;
   SIGNAL clkgen_ht_sel           : STD_LOGIC;
   SIGNAL clkgen_m_sel            : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL clkgen_pcie_sw          : STD_LOGIC;
   SIGNAL clkgen_pdb              : STD_LOGIC;
   SIGNAL clkgen_rst_n            : STD_LOGIC;
   
   -- 10g inputs
   SIGNAL clkgen_10g_clk0_in      : STD_LOGIC;
   SIGNAL clkgen_10g_clk180_in    : STD_LOGIC;
   SIGNAL clkgen_10g_rst_n        : STD_LOGIC;
   
   -- outputs
   SIGNAL clkgen_cgb_vccelxqyx    : STD_LOGIC;
   SIGNAL clkgen_cgb_vssexqyx     : STD_LOGIC;
   SIGNAL clkgen_cpulse_ht        : STD_LOGIC;
   SIGNAL clkgen_cpulse_x1        : STD_LOGIC;
   SIGNAL clkgen_hclk             : STD_LOGIC;
   SIGNAL clkgen_hfclkn_ht        : STD_LOGIC;
   SIGNAL clkgen_hfclkn_x1        : STD_LOGIC;
   SIGNAL clkgen_hfclkp_ht        : STD_LOGIC;
   SIGNAL clkgen_hfclkp_x1        : STD_LOGIC;
   SIGNAL clkgen_lfclkn_x1        : STD_LOGIC;
   SIGNAL clkgen_lfclkp_x1        : STD_LOGIC;
   SIGNAL clkgen_pclk             : STD_LOGIC;
   SIGNAL clkgen_pcie_sw_cdr      : STD_LOGIC;
   SIGNAL clkgen_gen2ngen1        : STD_LOGIC;
   SIGNAL vccelx                  : STD_LOGIC;
   SIGNAL vssex                   : STD_LOGIC;
   SIGNAL wire_reset              : STD_LOGIC;
   
   -- 10g outputs
   SIGNAL clkgen_10g_cpulse       : STD_LOGIC;
   SIGNAL clkgen_10g_cpulseb      : STD_LOGIC;
   SIGNAL clkgen_10g_hfclk_n      : STD_LOGIC;
   SIGNAL clkgen_10g_hfclk_p      : STD_LOGIC;
   SIGNAL clkgen_10g_lfclk_n      : STD_LOGIC;
   SIGNAL clkgen_10g_lfclk_p      : STD_LOGIC;
   
   -- intermediate wires
   SIGNAL coreclkout_mux          : STD_LOGIC;
   SIGNAL refclk_divide_out       : STD_LOGIC;
   SIGNAL vcobypassmux_out        : STD_LOGIC;
   SIGNAL refclkdividemux_out     : STD_LOGIC;
   
   -- upper case to lower case parameter values
   SIGNAL l_divider_type          : string(1 to 20);
    
   -- ICD's clkgenbuf_cmu instantiation 
   
   SIGNAL clkgen_lfclkn_ht        : STD_LOGIC;
   SIGNAL clkgen_lfclkp_ht        : STD_LOGIC;
   
   SIGNAL vccelxqyx               : STD_LOGIC;
   SIGNAL vssexqyx                : STD_LOGIC;
   
   SIGNAL coreclk_divide_out      : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL refclkout_xhdl0         : STD_LOGIC;
BEGIN
          
      ------------------------
      --  Wire Delay Block --
      ------------------------
      WireDelay : BLOCK
      BEGIN
       bits_refclkin : FOR i in refclkin'RANGE GENERATE
           VitalWireDelay (refclkin_ipd(i),refclkin(i), tipd_refclkin(i));
       END GENERATE;
       bits_rateswitchdonein : FOR i in rateswitchdonein'RANGE GENERATE
           VitalWireDelay (rateswitchdonein_ipd(i),rateswitchdonein(i), tipd_rateswitchdonein(i));
       END GENERATE;
           VitalWireDelay (dpriodisable_ipd,dpriodisable, tipd_dpriodisable);
           VitalWireDelay (quadreset_ipd,quadreset, tipd_quadreset);
       bits_clk0in : FOR i in clk0in'RANGE GENERATE
           VitalWireDelay (clk0in_ipd(i),clk0in(i), tipd_clk0in(i));
       END GENERATE;
           VitalWireDelay (vcobypassin_ipd,vcobypassin, tipd_vcobypassin);
       bits_clk1in : FOR i in clk1in'RANGE GENERATE
           VitalWireDelay (clk1in_ipd(i),clk1in(i), tipd_clk1in(i));
       END GENERATE;
       bits_rateswitchbaseclkin : FOR i in rateswitchbaseclkin'RANGE GENERATE
           VitalWireDelay (rateswitchbaseclkin_ipd(i),rateswitchbaseclkin(i), tipd_rateswitchbaseclkin(i));
       END GENERATE;
       bits_dprioin : FOR i in dprioin'RANGE GENERATE
           VitalWireDelay (dprioin_ipd(i),dprioin(i), tipd_dprioin(i));
       END GENERATE;
           VitalWireDelay (refclkdig_ipd,refclkdig, tipd_refclkdig);
           VitalWireDelay (rateswitch_ipd,rateswitch, tipd_rateswitch);
           VitalWireDelay (powerdn_ipd,powerdn, tipd_powerdn);
      END BLOCK;
          
      ------------------------
      --  Functionality Section --
      ------------------------
   -- Drive referenced outputs
   refclkout <= refclkout_xhdl0;
   PROCESS 
      
   BEGIN
      init_ht_sel <= mux_select((alpha_tolower(divider_type) = ("central_enhanced") OR alpha_tolower(divider_type) = ("central_regular")), '1', '0');
      init_rcgb_cmu_sel <= mux_select((inclk_select = 0), '0', '1');
      IF (pre_divide_by = 2) THEN
          init_rcgb_m_sel <= "01";
      ELSIF (pre_divide_by = 4) THEN
          init_rcgb_m_sel <= "10";
      ELSE
          init_rcgb_m_sel <= "00";
      END IF;
      init_rpmadwidth_tx <= mux_select((divide_by = 4), '0', '1');
      init_rcgb_rpma_doublewidth_tx <= mux_select((use_refclk_post_divider = ("true")), '1', '0');
      init_rcgb_dynamic_sw <= mux_select((enable_dynamic_divider = ("true")), '1', '0');
      
      init_inclk_select <= mux_select((inclk_select = 0), '0', '1');
      
    -- central clock divider section
	init_rfreerun_centrl	<= '1';  -- missing parameter
	init_rcentrl_clk_sel    <= mux_select((select_refclk_dig = ("true")), '1', '0');
	init_rrefclk_out_div2   <= mux_select((use_coreclk_out_post_divider = ("true")), '1', '0');
      WAIT;
   END PROCESS;
   
   	-- ---------------------------------------------------------------------------
	-- Set DPRIO CRAM input from dprioin  
	-- ---------------------------------------------------------------------------
	dprioin_ht_sel 					<= dprioin(ht_sel_CLOCK_DIV_IDX);
	dprioin_rcgb_cmu_sel 			<= dprioin(rcgb_cmu_sel_CLOCK_DIV_IDX_0);
	dprioin_rcgb_m_sel 				<= dprioin(rcgb_m_sel_CLOCK_DIV_IDX_1 DOWNTO rcgb_m_sel_CLOCK_DIV_IDX_0);
	dprioin_rpmadwidth_tx 			<= dprioin(rpmadwidth_tx_CLOCK_DIV_IDX_0);
	dprioin_rcgb_rpma_doublewidth_tx <= dprioin(rpma_doublewidth_tx_CLOCK_DIV_IDX_0);
	dprioin_rcgb_dynamic_sw 			<= dprioin(rdynamic_sw_CLOCK_DIV_IDX_0);
	
	-- central clock divider section
	dprioin_rfreerun_centrl  <= dprioin(rfreerun_centrl_CLOCK_DIV_IDX);
	dprioin_rcentrl_clk_sel  <= dprioin(rcentrl_clk_sel_CLOCK_DIV_IDX);
	dprioin_rrefclk_out_div2 <= dprioin(rrefclk_out_div2_CLOCK_DIV_IDX);
	
	-- ---------------------------------------------------------------------------
	-- Set DPRIO output from initial CRAM
	-- ---------------------------------------------------------------------------
	dprioout(ht_sel_CLOCK_DIV_IDX) 										<= init_ht_sel;
	dprioout(rcgb_cmu_sel_CLOCK_DIV_IDX_0) 								<= init_rcgb_cmu_sel;
	dprioout(rcgb_m_sel_CLOCK_DIV_IDX_1 DOWNTO rcgb_m_sel_CLOCK_DIV_IDX_0) 	<= init_rcgb_m_sel;
	dprioout(rpmadwidth_tx_CLOCK_DIV_IDX_0) 							<= init_rpmadwidth_tx;
	dprioout(rpma_doublewidth_tx_CLOCK_DIV_IDX_0) 						<= init_rcgb_rpma_doublewidth_tx;
	dprioout(rdynamic_sw_CLOCK_DIV_IDX_0) 								<= init_rcgb_dynamic_sw;
	
	-- central clock divider section
	dprioout(rfreerun_centrl_CLOCK_DIV_IDX)  <= init_rfreerun_centrl;
	dprioout(rcentrl_clk_sel_CLOCK_DIV_IDX)  <= init_rcentrl_clk_sel;
	dprioout(rrefclk_out_div2_CLOCK_DIV_IDX) <= init_rrefclk_out_div2;
	
	-- ---------------------------------------------------------------------------
	-- Set DPRIO CRAM
	-- ---------------------------------------------------------------------------
	dpriodisable_in <= '0' WHEN (dpriodisable = '0') ELSE '1';
	
	--cram_ht_sel 					<= init_ht_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_ht_sel;
	cram_ht_sel 					<= init_ht_sel;
	cram_rcgb_cmu_sel 				<= init_rcgb_cmu_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rcgb_cmu_sel;
	cram_rcgb_m_sel 				<= init_rcgb_m_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rcgb_m_sel;
	cram_rpmadwidth_tx 				<= init_rpmadwidth_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rpmadwidth_tx;
	cram_rcgb_rpma_doublewidth_tx 	<= init_rcgb_rpma_doublewidth_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rcgb_rpma_doublewidth_tx;
	cram_rcgb_dynamic_sw 			<= init_rcgb_dynamic_sw WHEN (dpriodisable_in /= '0') ELSE dprioin_rcgb_dynamic_sw;
    
	-- central clock divider section
	cram_rfreerun_centrl    <= init_rfreerun_centrl WHEN (dpriodisable_in /= '0') ELSE dprioin_rfreerun_centrl;
	cram_rcentrl_clk_sel    <= init_rcentrl_clk_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rcentrl_clk_sel;
	cram_rrefclk_out_div2   <= init_rrefclk_out_div2 WHEN (dpriodisable_in /= '0') ELSE dprioin_rrefclk_out_div2;
	
	-- ---------------------------------------------------------------------------
	-- logic index
	-- ---------------------------------------------------------------------------
   	dprioin_inclk_select <= dprioin(INCLK_SELECT_CLOCK_DIV_IDX);
    cram_inclk_select    <= init_inclk_select WHEN (dpriodisable /= '0') ELSE dprioin_inclk_select;
    dprioout(INCLK_SELECT_CLOCK_DIV_IDX) <= init_inclk_select;
	
   clkgen_cgb_x_en <= "00";
   clkgen_clk0_0 <= '0' WHEN (alpha_tolower(divider_type) = ("high_speed_regular")) ELSE
                    clk0in_ipd(0);
   clkgen_clk0_1 <= '0' WHEN (alpha_tolower(divider_type) = ("high_speed_regular")) ELSE
                    clk1in_ipd(0);
   clkgen_clk90_0 <= '0' WHEN (alpha_tolower(divider_type) = ("high_speed_regular")) ELSE
                     clk0in_ipd(1);
   clkgen_clk90_1 <= '0' WHEN (alpha_tolower(divider_type) = ("high_speed_regular")) ELSE
                     clk1in_ipd(1);
   clkgen_clk180_0 <= '0' WHEN (alpha_tolower(divider_type) = ("high_speed_regular")) ELSE
                      clk0in_ipd(2);
   clkgen_clk180_1 <= '0' WHEN (alpha_tolower(divider_type) = ("high_speed_regular")) ELSE
                      clk1in_ipd(2);
   clkgen_clk270_0 <= '0' WHEN (alpha_tolower(divider_type) = ("high_speed_regular")) ELSE
                      clk0in_ipd(3);
   clkgen_clk270_1 <= '0' WHEN (alpha_tolower(divider_type) = ("high_speed_regular")) ELSE
                      clk1in_ipd(3);
   clkgen_pdb <= '0' WHEN (powerdn_ipd = '1') ELSE
                 '1';
   clkgen_ht_sel <= cram_ht_sel;
   clkgen_pcie_sw <= '1' WHEN (rateswitch_ipd = '1') ELSE '0';
   clkgen_cmu_sel <= cram_inclk_select;   -- shawn cram_rcgb_cmu_sel;
   clkgen_m_sel <= cram_rcgb_m_sel;
   clkgen_div2 <= cram_rcgb_rpma_doublewidth_tx;
   clkgen_div5 <= cram_rpmadwidth_tx;
   clkgen_dynamic_sw <= cram_rcgb_dynamic_sw;
   clkgen_rst_n <= '0' WHEN (quadreset_ipd = '1') ELSE
                   '1';
   clkgen_10g_clk0_in <= clk0in_ipd(0) WHEN (alpha_tolower(divider_type) = ("high_speed_regular")) ELSE
                         '0';
   clkgen_10g_clk180_in <= clk0in_ipd(2) WHEN (alpha_tolower(divider_type) = ("high_speed_regular")) ELSE
                           '0';
   clkgen_10g_rst_n <= '0' WHEN (quadreset_ipd = '1') ELSE
                       '1';
   
   
   clkgen : stratixiv_hssi_pma_c_clkgenbuf_cmu
      PORT MAP (
         cgb_x_en       => clkgen_cgb_x_en,
         clk0_0         => clkgen_clk0_0,
         clk0_1         => clkgen_clk0_1,
         clk90_0        => clkgen_clk90_0,
         clk90_1        => clkgen_clk90_1,
         clk180_0       => clkgen_clk180_0,
         clk180_1       => clkgen_clk180_1,
         clk270_0       => clkgen_clk270_0,
         clk270_1       => clkgen_clk270_1,
         cmu_sel        => clkgen_cmu_sel,
         div5           => clkgen_div5,
         dynamic_sw     => clkgen_dynamic_sw,
         ht_sel         => clkgen_ht_sel,
         m_sel          => clkgen_m_sel,
         pcie_sw        => clkgen_pcie_sw,
         pdb            => clkgen_pdb,
         rst_n          => clkgen_rst_n,
         vccelxqyx      => vccelx,
         vssexqyx       => vssex,
         cgb_vccelxqyx  => clkgen_cgb_vccelxqyx,
         cgb_vssexqyx   => clkgen_cgb_vssexqyx,
         cpulse_ht      => clkgen_cpulse_ht,
         cpulse_x1      => clkgen_cpulse_x1,
         gen2ngen1      => clkgen_gen2ngen1,
         hclk           => clkgen_hclk,
         hfclkn_ht      => clkgen_hfclkn_ht,
         hfclkn_x1      => clkgen_hfclkn_x1,
         hfclkp_ht      => clkgen_hfclkp_ht,
         hfclkp_x1      => clkgen_hfclkp_x1,
         lfclkn_ht      => clkgen_lfclkn_ht,
         lfclkn_x1      => clkgen_lfclkn_x1,
         lfclkp_ht      => clkgen_lfclkp_ht,
         lfclkp_x1      => clkgen_lfclkp_x1,
         pcie_sw_cdr    => clkgen_pcie_sw_cdr,
         pclk           => clkgen_pclk
      );
   
   
   clkgen_10g : stratixiv_hssi_pma_c_clkgenbuf_tx10g
      PORT MAP (
         clk0_in    => clkgen_10g_clk0_in,
         clk180_in  => clkgen_10g_clk180_in,
         rst_n      => clkgen_10g_rst_n,
         vccelxqyx  => vccelxqyx,
         vssexqyx   => vssexqyx,
         cpulse     => clkgen_10g_cpulse,
         cpulseb    => clkgen_10g_cpulseb,
         hfclk_n    => clkgen_10g_hfclk_n,
         hfclk_p    => clkgen_10g_hfclk_p,
         lfclk_n    => clkgen_10g_lfclk_n,
         lfclk_p    => clkgen_10g_lfclk_p
      );
   analogrefclkout <= ((clkgen_10g_lfclk_n & clkgen_10g_lfclk_p)) WHEN (alpha_tolower(divider_type) = ("high_speed_regular")) ELSE
                      ((clkgen_lfclkn_x1 & clkgen_lfclkp_x1));
   analogfastrefclkout <= ((clkgen_10g_hfclk_n & clkgen_10g_hfclk_p)) WHEN (alpha_tolower(divider_type) = ("high_speed_regular")) ELSE
                          ((clkgen_hfclkn_x1 & clkgen_hfclkp_x1));
   analogrefclkpulse <= clkgen_10g_cpulse WHEN (alpha_tolower(divider_type) = ("high_speed_regular")) ELSE
                        clkgen_cpulse_x1;
   rateswitchdone <= clkgen_gen2ngen1 WHEN (select_local_rate_switch_done = ("true")) ELSE
                     rateswitchdonein_ipd(rate_switch_done_in_select);
   rateswitchbaseclock <= clkgen_hclk WHEN (select_local_rate_switch_base_clock = ("true")) ELSE
                          rateswitchbaseclkin_ipd(rate_switch_base_clk_in_select);
   rateswitchout <= rateswitch_ipd;


   analogrefclkoutshifted <= ((clkgen_lfclkn_ht & clkgen_lfclkp_ht));
   analogfastrefclkoutshifted <= ((clkgen_hfclkn_ht & clkgen_hfclkp_ht));
   analogrefclkpulseshifted <= clkgen_cpulse_ht;


   vcobypassmux_out <= NOT(vcobypassin_ipd) WHEN (use_vco_bypass = ("true")) ELSE
                       clkgen_pclk;

   refclk_divider : stratixiv_hssi_aux_clock_div
      GENERIC MAP (
         clk_divide_by  => 2,
         extra_latency  => 0
      )
      PORT MAP (
         clk       => vcobypassmux_out,
         enable_d  => '0',
         d         => "00000000",
         reset     => wire_reset,
         clkout    => refclk_divide_out
      );
  
   refclkdividemux_out <= refclk_divide_out WHEN (cram_rcgb_rpma_doublewidth_tx = '1') ELSE
                          vcobypassmux_out; 

   refclkout_xhdl0 <= refclkdig_ipd WHEN (cram_rcentrl_clk_sel = '1') ELSE
                      refclkdividemux_out WHEN (select_local_refclk = ("true")) ELSE
                      refclkin_ipd(refclkin_select) WHEN (enable_refclk_out = ("true")) ELSE
                      'Z';
   
   
   coreclk_divider : stratixiv_hssi_aux_clock_div
      GENERIC MAP (
         clk_divide_by  => 2,
         extra_latency  => 0
      )
      PORT MAP (
         clk       => refclkout_xhdl0,
         enable_d  => '0',
         d         => "00000000",
         reset     => wire_reset,
         clkout    => coreclk_divide_out
      );
   
   coreclkout_mux <= coreclk_divide_out WHEN (cram_rrefclk_out_div2 = '1') ELSE
                     refclkout_xhdl0;
   
   coreclkout <= coreclkout_mux;
   
END trans;


-- ***********************************************************
-- This WYSIWYG atom header was automatically generated by the
-- Atmgen build tool. To change it, alter data stored in the 
-- corresponding WYS file(s) in the tools/atmgen subdirectory.
-- ***********************************************************

-- *** Section 1 -- Header ***

-- -----------------------------------------------------------
--
-- Module Name : stratixiv_hssi_pll
--
-- Description : DEV_FAMILY_STRATIXIV stratixiv_hssi_pll Verilog simulation model
--
-- -----------------------------------------------------------

-- *** End of Section 1 ***


-- *** Section 3 -- Module declaration ***


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

USE IEEE.VITAL_Timing.all;
USE IEEE.VITAL_Primitives.all;
ENTITY stratixiv_hssi_pll IS
   GENERIC (

          --  generic control parameters  --
       MsgOn                   : Boolean := DefGlitchMsgOn;
       XOn                     : Boolean := DefGlitchXOn;
       MsgOnChecks             : Boolean := DefMsgOnChecks;
       XOnChecks               : Boolean := DefXOnChecks;
       InstancePath            : String := "*";
       TimingChecksOn          : Boolean := True;
          --  tipd  :interconnect path delays --
      tipd_dpriodisable                : VitalDelayType01 := DefpropDelay01;
      tipd_datain                : VitalDelayType01 := DefpropDelay01;
      tipd_areset                : VitalDelayType01 := DefpropDelay01;
      tipd_earlyeios             : VitalDelayType01 := DefpropDelay01;
      tipd_locktorefclk                : VitalDelayType01 := DefpropDelay01;
      tipd_pfdfbclk                : VitalDelayType01 := DefpropDelay01;
      tipd_powerdown                : VitalDelayType01 := DefpropDelay01;
      tipd_inclk               :VitalDelayArrayType01(10 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_dprioin               :VitalDelayArrayType01(300 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rateswitch                : VitalDelayType01 := DefpropDelay01;
          --  tpd: Edge-Sensitive Paths --
          --  tpd: parallel and Full Connection Paths --
      tpd_inclk_clk : VitalDelayType01 := DefPropDelay01;
          --  tsetup and thold values : setup and hold times  --
          --  Pulse Width parameters  --
      
      -- *** End of Section 3 ***
      
      -- *** Section 4 -- Port size declarations ***
      
      -- Note: Variable port sizes dictated by parameters are not currently defined in
      -- the WYS file data. Busses are marked with the VARIABLE notation as a reminder.
      
      -- * VARIABLE
      
      -- * VARIABLE
      
      -- * VARIABLE
      
      -- * VARIABLE
      
      -- * VARIABLE
      
      -- *** End of Section 4 ***
      
      -- *** Section 5 -- Port declarations ***
      
      lpm_type                       : STRING := "stratixiv_hssi_pll";
      auto_settings                  : STRING := "true";
      bandwidth_type                 : STRING := "Auto";
      base_data_rate                 : STRING := "unused";
      channel_num                    : INTEGER := 0;
      charge_pump_current_bits       : INTEGER := 0;
      charge_pump_mode_bits          : INTEGER := 0;
      charge_pump_test_enable        : STRING := "false";
      dprio_config_mode              : STD_LOGIC_VECTOR(5 DOWNTO 0) := "000000";
      effective_data_rate            : STRING := "unused";
      enable_dynamic_divider         : STRING := "false";
      fast_lock_control              : STRING := "false";
      inclk0_input_period            : INTEGER := 0;
      inclk1_input_period            : INTEGER := 0;
      inclk2_input_period            : INTEGER := 0;
      inclk3_input_period            : INTEGER := 0;
      inclk4_input_period            : INTEGER := 0;
      inclk5_input_period            : INTEGER := 0;
      inclk6_input_period            : INTEGER := 0;
      inclk7_input_period            : INTEGER := 0;
      inclk8_input_period            : INTEGER := 0;
      inclk9_input_period            : INTEGER := 0;
      input_clock_frequency          : STRING := "unused";
      logical_channel_address        : INTEGER := 0;
      logical_tx_pll_number          : INTEGER := 0;
      loop_filter_c_bits             : INTEGER := 0;
      loop_filter_r_bits             : INTEGER := 0;
      m                              : INTEGER := 0;
      n                              : INTEGER := 0;
      pd_charge_pump_current_bits    : INTEGER := 0;
      pd_loop_filter_r_bits          : INTEGER := 0;
      pfd_clk_select                 : INTEGER := 0;
      pfd_fb_select                  : STRING := "internal";
      pll_type                       : STRING := "Auto";
      protocol_hint                  : STRING := "basic";
      refclk_divide_by               : INTEGER := 0;
      refclk_multiply_by             : INTEGER := 0;
      sim_is_negative_ppm_drift      : STRING := "false";
      sim_net_ppm_variation          : INTEGER := 0;
      test_charge_pump_current_down  : STRING := "false";
      test_charge_pump_current_up    : STRING := "false";
      use_refclk_pin                 : STRING := "false";
      vco_data_rate                  : INTEGER := 0;
      vco_divide_by                  : INTEGER := 0;
      vco_range                      : STRING := "low";
      vco_multiply_by                : INTEGER := 0;
      vco_post_scale                 : INTEGER := 0;
      vco_tuning_bits                : INTEGER := 0;
      volt_reg_control_bits          : INTEGER := 0;
      volt_reg_output_bits           : INTEGER := 0;
      sim_clkout_phase_shift         : INTEGER := 0;
      sim_clkout_latency             : INTEGER := 0;
      PARAM_DELAY                    : INTEGER := 0
   );
   PORT (
      areset                         : IN STD_LOGIC := '0';
      datain                         : IN STD_LOGIC := '0';
      dpriodisable                   : IN STD_LOGIC := '1';
      dprioin                        : IN STD_LOGIC_VECTOR(300 - 1 DOWNTO 0) := (others => '0');
      earlyeios                      : IN STD_LOGIC := '0';
      extra10gin                     : IN STD_LOGIC_VECTOR(6 - 1 DOWNTO 0) := (others => '0');
      inclk                          : IN STD_LOGIC_VECTOR(10 - 1 DOWNTO 0) := (others => '0');
      locktorefclk                   : IN STD_LOGIC := '1';
      pfdfbclk                       : IN STD_LOGIC := '0';
      powerdown                      : IN STD_LOGIC := '0';
      rateswitch                     : IN STD_LOGIC := '0';
      clk                            : OUT STD_LOGIC_VECTOR(4 - 1 DOWNTO 0);
      dataout                        : OUT STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
      dprioout                       : OUT STD_LOGIC_VECTOR(300 - 1 DOWNTO 0);
      freqlocked                     : OUT STD_LOGIC;
      locked                         : OUT STD_LOGIC;
      pfdfbclkout                    : OUT STD_LOGIC;
      pfdrefclkout                   : OUT STD_LOGIC;
      vcobypassout                   : OUT STD_LOGIC
   );
END stratixiv_hssi_pll;

ARCHITECTURE trans OF stratixiv_hssi_pll IS

  signal dpriodisable_ipd  :STD_LOGIC;
  signal datain_ipd  :STD_LOGIC;
  signal areset_ipd  :STD_LOGIC;
  signal earlyeios_ipd  :STD_LOGIC;
  signal locktorefclk_ipd  :STD_LOGIC;
  signal pfdfbclk_ipd  :STD_LOGIC;
  signal powerdown_ipd  :STD_LOGIC;
  signal inclk_ipd  :STD_LOGIC_VECTOR(10 - 1 DOWNTO 0);
  signal dprioin_ipd  :STD_LOGIC_VECTOR(300 - 1 DOWNTO 0);
  signal rateswitch_ipd  :STD_LOGIC;
   COMPONENT stratixiv_hssi_aux_clock_div
      GENERIC (
         clk_divide_by                  : INTEGER := 1;
         extra_latency                  : INTEGER := 0
      );
      PORT (
         clk                            : IN STD_LOGIC;
         reset                          : IN STD_LOGIC;
         powerdown                      : IN STD_LOGIC := '0';
         enable_d                       : IN STD_LOGIC;
         d                              : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         clkout                         : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_aux_clock_mult
      GENERIC (
         clk_multiply_by                : INTEGER := 1;
         pfd_fb_select                  : string := "internal"
      );
      PORT (
         clk                            : IN STD_LOGIC;
         fbclk                          : IN STD_LOGIC;
         adjust                         : IN STD_LOGIC := '0';
         adjust_without_lol             : IN STD_LOGIC := '0';
         reset                          : IN STD_LOGIC := '0';
         enable_m                       : IN STD_LOGIC;
         m                              : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         clkout                         : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
         busy                           : OUT STD_LOGIC_VECTOR(1 DOWNTO 0)
      );
   END COMPONENT;
   
   
   -- *** End of Section 5 ***
   
   -- *** Section 6 -- Parameter declarations and default values ***
   
   -- *** End of Section 6 ***
   
   -- Simulation only parameters
   
   -- *** Section 7 -- Port declarations with defaults, if any ***
   
   -- This section will always be empty for WYSIWYG atoms
   -- tri1 devclrn;		//sample
   
   -- *** End of Section 7 ***
   
   -- ---------------------------------------------------------------------------
   --  Model Implementation Begin                                               -
   -- ---------------------------------------------------------------------------    
   SIGNAL mdpriodisable               : STD_LOGIC;
    
   -- ******************* DPRIO support for SDI *********************************
   
   -- ---------------------------------------------------------------------------
   --  Model / Submodule Instantiations                                         -
   -- ---------------------------------------------------------------------------
   
   --signalareset_ipd                  : STD_LOGIC;
   SIGNAL ck0_pd                      : STD_LOGIC;
   SIGNAL ck90_pd                     : STD_LOGIC;
   SIGNAL ck180_pd                    : STD_LOGIC;
   SIGNAL ck270_pd                    : STD_LOGIC;
      
   -- DPRIO
   SIGNAL dprioenable                 : STD_LOGIC;
   SIGNAL dprioen_reg                 : STD_LOGIC;
   SIGNAL cru_l_chn                   : STD_LOGIC_VECTOR(7 DOWNTO 0);
     
   -- intermediate wires
   SIGNAL busy                        : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- VCO state
   SIGNAL charge_pump_delayed         : STD_LOGIC;
   SIGNAL check_phase                 : STD_LOGIC;
   SIGNAL clk_div                     : STD_LOGIC;
   SIGNAL clk_div_delayed             : STD_LOGIC;
   SIGNAL clk_post_scale              : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL clk_vco                     : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL divide_by_M_clkout          : STD_LOGIC;
   SIGNAL fbclk                       : STD_LOGIC;
   SIGNAL pcie_clk                    : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL pcie_div2_clk0              : STD_LOGIC;
   SIGNAL pcie_div2_clk1              : STD_LOGIC;
   SIGNAL pfd_refclk                  : STD_LOGIC;
   SIGNAL pll_clkin                   : STD_LOGIC;
   SIGNAL pll_clkin_pre_latency       : STD_LOGIC;
   SIGNAL reset                       : STD_LOGIC;
   
   SIGNAL deven                       : STD_LOGIC;
   SIGNAL devenb                      : STD_LOGIC;
   SIGNAL dodd                        : STD_LOGIC;
   SIGNAL doddb                       : STD_LOGIC;
   SIGNAL deven_int1                  : STD_LOGIC := '0';
   SIGNAL deven_int2                  : STD_LOGIC := '0';
   SIGNAL dodd_int1                   : STD_LOGIC := '0';
   SIGNAL dodd_int2                   : STD_LOGIC := '0';
   SIGNAL d90_int1                    : STD_LOGIC;
   SIGNAL d90_int2                    : STD_LOGIC;
   SIGNAL d270_int1                   : STD_LOGIC;
   SIGNAL d270_int2                   : STD_LOGIC;
   SIGNAL pcie_div2_clk2              : STD_LOGIC;
   SIGNAL pcie_div2_clk3              : STD_LOGIC;
   
   SIGNAL pdb                         : STD_LOGIC;
   
   SIGNAL charge_pump                 : STD_LOGIC := '1';	-- re-adjust VCO frequency
   SIGNAL adjust_without_lol          : STD_LOGIC := '0';
   
   SIGNAL last_fb_clk_edge            : time ;
   SIGNAL expected_clk_period         : time ;
   SIGNAL clk_tolerance               : time ;
   SIGNAL real_clk_period             : time ;
   SIGNAL last_pfd_refclk_edge        : time ;
   SIGNAL last_pll_clkin_edge         : time ;
   SIGNAL last_real_clk_period        : time ;
   
   SIGNAL first_pll_clkin_edge_detect : STD_LOGIC := '0';
   SIGNAL display_msgs                : STD_LOGIC := '1';
   SIGNAL freq_viol_msg_sem           : STD_LOGIC;
   SIGNAL locked_real                 : STD_LOGIC := '0';
   
   SIGNAL dprio_reset                 : STD_LOGIC;		-- reset through DPRIO CRAM in 7.1
   SIGNAL d_wire                      : STD_LOGIC_VECTOR(7 DOWNTO 0);

    SIGNAL change_in_clk_freq : BOOLEAN := FALSE;
    SIGNAL minor_clk_freq_change : BOOLEAN := FALSE;
   
   SIGNAL datain_dly                  : STD_LOGIC := '0';
   -- X-HDL generated signals

   SIGNAL xhdl1 : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL locked_xhdl0                : STD_LOGIC;
   
   -- Table39: PMA Per Channel RX Control Register 4 for Channel 0	(RXPLL)
   constant rcru_pdbwctrl_PLL_IDX_0	: integer := 0;
   constant rcru_pdbwctrl_PLL_IDX_1	: integer := 1;
   constant rcru_pfdbwctrl_PLL_IDX_0	: integer := 2;
   constant rcru_pfdbwctrl_PLL_IDX_1	: integer := 3;
   constant rcru_crplctrl_PLL_IDX_0	: integer := 4;
   constant rcru_crplctrl_PLL_IDX_1	: integer := 5;
   constant rcru_ctl0_PLL_IDX_0	: integer := 6;
   constant rcru_l_PLL_IDX_0	: integer := 7;
   constant rcru_l_PLL_IDX_1	: integer := 8;
   constant rcru_m_PLL_IDX_0	: integer := 9;
   constant rcru_m_PLL_IDX_1	: integer := 10;
   constant rcru_m_PLL_IDX_2	: integer := 11;
   constant rcru_m_PLL_IDX_3	: integer := 12;
   constant rcru_m_sel_PLL_IDX_0	: integer := 13;
   constant rcru_m_sel_PLL_IDX_1	: integer := 14;
   constant rcru_div2_PLL_IDX_0	: integer := 15;
   
   -- Table40: PMA Per Channel RX Control Register 5 for Channel 0	(RXPLL)
   constant reserved_0_TB40_PLL_IDX_0	: integer := 16;
   constant reserved_0_TB40_PLL_IDX_1	: integer := 17;
   constant rcru_iselpd_PLL_IDX_0	: integer := 18;
   constant rcru_iselpd_PLL_IDX_1	: integer := 19;
   constant rcru_iselpd_PLL_IDX_2	: integer := 20;
   constant rcru_isel_PLL_IDX_0	: integer := 21;
   constant rcru_isel_PLL_IDX_1	: integer := 22;
   constant rcru_isel_PLL_IDX_2	: integer := 23;
   constant rcru_testdnen_PLL_IDX_0	: integer := 24;
   constant rcru_testupen_PLL_IDX_0	: integer := 25;
   constant rcru_testen_PLL_IDX_0	: integer := 26;
   constant rcru_lst_PLL_IDX_0	: integer := 27;
   constant rcru_lst_PLL_IDX_1	: integer := 28;
   constant rcru_lst_PLL_IDX_2	: integer := 29;
   constant rcru_lst_PLL_IDX_3	: integer := 30;
   constant rcru_rlbk_PLL_IDX_0	: integer := 31;
   
   -- Table41: PMA Per Channel RX Control Register 6 for Channel 0	(RXPLL)
   constant rcru_rgla_isel_PLL_IDX_0	: integer := 32;
   constant rcru_rgla_isel_PLL_IDX_1	: integer := 33;
   constant rcru_rgla_isel_PLL_IDX_2	: integer := 34;
   constant rcru_pdof_test_PLL_IDX_0	: integer := 35;
   constant rcru_pdof_test_PLL_IDX_1	: integer := 36;
   constant rcru_pdof_test_PLL_IDX_2	: integer := 37;
   constant rcru_pdfl_PLL_IDX_0	: integer := 38;
   constant rcru_sd_sel_PLL_IDX_0	: integer := 39;
   constant reserved_0_TB41_PLL_IDX_0	: integer := 40;
   constant rcru_ignore_phslck_PLL_IDX_0	: integer := 41;
   constant rcru_cmu_mode_PLL_IDX_0	: integer := 42;
   constant rrx_cru_rst_PLL_IDX_0	: integer := 43;
   constant rrx_cru_pdb_PLL_IDX_0	: integer := 44;
   constant rltr_PLL_IDX_0	: integer := 45;
   constant rltd_PLL_IDX_0	: integer := 46;
   constant rcp_mode_PLL_IDX_0	: integer := 47;
   
   -- Table42: PMA Per Channel RX Control Register 7 for Channel 0	(RXPLL)
   constant rcru_pdof_270i_PLL_IDX_0	: integer := 48;
   constant rcru_pdof_270i_PLL_IDX_1	: integer := 49;
   constant rcru_pdof_270i_PLL_IDX_2	: integer := 50;
   constant rcru_pdof_270i_PLL_IDX_3	: integer := 51;
   constant rcru_pdof_180i_PLL_IDX_0	: integer := 52;
   constant rcru_pdof_180i_PLL_IDX_1	: integer := 53;
   constant rcru_pdof_180i_PLL_IDX_2	: integer := 54;
   constant rcru_pdof_180i_PLL_IDX_3	: integer := 55;
   constant rcru_pdof_90i_PLL_IDX_0	: integer := 56;
   constant rcru_pdof_90i_PLL_IDX_1	: integer := 57;
   constant rcru_pdof_90i_PLL_IDX_2	: integer := 58;
   constant rcru_pdof_90i_PLL_IDX_3	: integer := 59;
   constant rcru_pdof_0i_PLL_IDX_0	: integer := 60;
   constant rcru_pdof_0i_PLL_IDX_1	: integer := 61;
   constant rcru_pdof_0i_PLL_IDX_2	: integer := 62;
   constant rcru_pdof_0i_PLL_IDX_3	: integer := 63;

   -- Manual: PLL (only rx_cdr_pll uses it: table 33 & 59) --------------
   constant rdynamic_sw_PLL_IDX_0 	: integer := 70;
   
   -- SW logical index ---------------------------------------------------------- 
   constant PFD_CLK_SEL_PLL_IDX_0	: integer := 100;
   constant PFD_CLK_SEL_PLL_IDX_1	: integer := 101;
   constant PFD_CLK_SEL_PLL_IDX_2	: integer := 102;
   constant PFD_CLK_SEL_PLL_IDX_3	: integer := 103;
       
   -- ---------------------------------------------------------------------------
   -- DPRIO input CRAM  
   -- ---------------------------------------------------------------------------
   
   -- PMA Per Channel RX Control Register 4 for Channel 0
   SIGNAL dprioin_rcru_pdbwctrl	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_rcru_pfdbwctrl	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_rcru_crplctrl	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_rcru_ctl0	: STD_LOGIC;
   SIGNAL dprioin_rcru_l	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_rcru_m	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dprioin_rcru_m_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_rcru_div2	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 5 for Channel 0
   SIGNAL dprioin_reserved_0_TB40	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_rcru_iselpd	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_rcru_isel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_rcru_testdnen	: STD_LOGIC;
   SIGNAL dprioin_rcru_testupen	: STD_LOGIC;
   SIGNAL dprioin_rcru_testen	: STD_LOGIC;
   SIGNAL dprioin_rcru_lst	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dprioin_rcru_rlbk	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 6 for Channel 0
   SIGNAL dprioin_rcru_rgla_isel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_rcru_pdof_test	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_rcru_pdfl	: STD_LOGIC;
   SIGNAL dprioin_rcru_sd_sel	: STD_LOGIC;
   SIGNAL dprioin_reserved_0_TB41	: STD_LOGIC;
   SIGNAL dprioin_rcru_ignore_phslck	: STD_LOGIC;
   SIGNAL dprioin_rcru_cmu_mode	: STD_LOGIC;
   SIGNAL dprioin_rrx_cru_rst	: STD_LOGIC;
   SIGNAL dprioin_rrx_cru_pdb	: STD_LOGIC;
   SIGNAL dprioin_rltr	: STD_LOGIC;
   SIGNAL dprioin_rltd	: STD_LOGIC;
   SIGNAL dprioin_rcp_mode	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 7 for Channel 0
   SIGNAL dprioin_rcru_pdof_270i	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dprioin_rcru_pdof_180i	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dprioin_rcru_pdof_90i	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dprioin_rcru_pdof_0i	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   
   SIGNAL m_dprioin_modulus           : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL n_dprioin_modulus           : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL dprioin_vco_post_scale : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00";
   SIGNAL dprioin_pfd_fb_select : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00";
   SIGNAL dprioin_pfd_clk_sel	: STD_LOGIC_VECTOR(3 DOWNTO 0) := "0000";  
   
   -- ---------------------------------------------------------------------------
   -- Initial CRAM  
   -- ---------------------------------------------------------------------------
   
   -- PMA Per Channel RX Control Register 4 for Channel 0
   SIGNAL init_rcru_pdbwctrl	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rcru_pfdbwctrl	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rcru_crplctrl	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rcru_ctl0	: STD_LOGIC;
   SIGNAL init_rcru_l	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rcru_m	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rcru_m_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rcru_div2	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 5 for Channel 0
   SIGNAL init_reserved_0_TB40	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rcru_iselpd	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_rcru_isel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_rcru_testdnen	: STD_LOGIC;
   SIGNAL init_rcru_testupen	: STD_LOGIC;
   SIGNAL init_rcru_testen	: STD_LOGIC;
   SIGNAL init_rcru_lst	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rcru_rlbk	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 6 for Channel 0
   SIGNAL init_rcru_rgla_isel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_rcru_pdof_test	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_rcru_pdfl	: STD_LOGIC;
   SIGNAL init_rcru_sd_sel	: STD_LOGIC;
   SIGNAL init_reserved_0_TB41	: STD_LOGIC;
   SIGNAL init_rcru_ignore_phslck	: STD_LOGIC;
   SIGNAL init_rcru_cmu_mode	: STD_LOGIC;
   SIGNAL init_rrx_cru_rst	: STD_LOGIC;
   SIGNAL init_rrx_cru_pdb	: STD_LOGIC;
   SIGNAL init_rltr	: STD_LOGIC;
   SIGNAL init_rltd	: STD_LOGIC;
   SIGNAL init_rcp_mode	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 7 for Channel 0
   SIGNAL init_rcru_pdof_270i	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rcru_pdof_180i	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rcru_pdof_90i	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rcru_pdof_0i	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   
   -- Manual section
   SIGNAL init_vco_post_scale : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00";
   SIGNAL init_pfd_fb_select : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00";
   SIGNAL init_pfd_clk_sel	    : STD_LOGIC_VECTOR(3 DOWNTO 0) := "0000";
   
   SIGNAL ext_fb_select : STD_LOGIC := '0';
   SIGNAL dprioin_rdynamic_sw : STD_LOGIC := '0';
   
   -- ---------------------------------------------------------------------------
   -- CRAM  
   -- ---------------------------------------------------------------------------
   
   -- PMA Per Channel RX Control Register 4 for Channel 0
   SIGNAL cram_rcru_pdbwctrl	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rcru_pfdbwctrl	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rcru_crplctrl	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rcru_ctl0	: STD_LOGIC;
   SIGNAL cram_rcru_l	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rcru_m	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rcru_m_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rcru_div2	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 5 for Channel 0
   SIGNAL cram_reserved_0_TB40	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rcru_iselpd	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_rcru_isel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_rcru_testdnen	: STD_LOGIC;
   SIGNAL cram_rcru_testupen	: STD_LOGIC;
   SIGNAL cram_rcru_testen	: STD_LOGIC;
   SIGNAL cram_rcru_lst	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rcru_rlbk	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 6 for Channel 0
   SIGNAL cram_rcru_rgla_isel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_rcru_pdof_test	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_rcru_pdfl	: STD_LOGIC;
   SIGNAL cram_rcru_sd_sel	: STD_LOGIC;
   SIGNAL cram_reserved_0_TB41	: STD_LOGIC;
   SIGNAL cram_rcru_ignore_phslck	: STD_LOGIC;
   SIGNAL cram_rcru_cmu_mode	: STD_LOGIC;
   SIGNAL cram_rrx_cru_rst	: STD_LOGIC;
   SIGNAL cram_rrx_cru_pdb	: STD_LOGIC;
   SIGNAL cram_rltr	: STD_LOGIC;
   SIGNAL cram_rltd	: STD_LOGIC;
   SIGNAL cram_rcp_mode	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 7 for Channel 0
   SIGNAL cram_rcru_pdof_270i	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rcru_pdof_180i	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rcru_pdof_90i	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rcru_pdof_0i	: STD_LOGIC_VECTOR(3 DOWNTO 0);
 
   -- SW logical index ------------------------------------------
   SIGNAL cram_vco_post_scale : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00";
   SIGNAL cram_pfd_fb_select : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00";
   SIGNAL cram_pfd_clk_sel	    : STD_LOGIC_VECTOR(3 DOWNTO 0) := "0000";
   
   SIGNAL cram_rdynamic_sw : STD_LOGIC := '0';
   
BEGIN
          
      ------------------------
      --  Wire Delay Block --
      ------------------------
      WireDelay : BLOCK
      BEGIN
           VitalWireDelay (areset_ipd,areset, tipd_areset);
           VitalWireDelay (datain_ipd,datain, tipd_datain);
           VitalWireDelay (dpriodisable_ipd,dpriodisable, tipd_dpriodisable);
           VitalWireDelay (earlyeios_ipd,earlyeios, tipd_earlyeios);
           VitalWireDelay (locktorefclk_ipd,locktorefclk, tipd_locktorefclk);
           VitalWireDelay (pfdfbclk_ipd,pfdfbclk, tipd_pfdfbclk);
           VitalWireDelay (powerdown_ipd,powerdown, tipd_powerdown);
       bits_dprioin : FOR i in dprioin'RANGE GENERATE
           VitalWireDelay (dprioin_ipd(i),dprioin(i), tipd_dprioin(i));
       END GENERATE;
       bits_inclk : FOR i in inclk'RANGE GENERATE
           VitalWireDelay (inclk_ipd(i),inclk(i), tipd_inclk(i));
       END GENERATE;
           VitalWireDelay (rateswitch_ipd,rateswitch, tipd_rateswitch);
      END BLOCK;
          
        -- new DPRIO model begin --
        -- ---------------------------------------------------------------------------
        -- Set DPRIO CRAM input from dprioin  
        -- ---------------------------------------------------------------------------
        
        -- PMA Per Channel RX Control Register 4 for Channel 0
        dprioin_rcru_pdbwctrl	<= dprioin(rcru_pdbwctrl_PLL_IDX_1 DOWNTO rcru_pdbwctrl_PLL_IDX_0);
        dprioin_rcru_pfdbwctrl	<= dprioin(rcru_pfdbwctrl_PLL_IDX_1 DOWNTO rcru_pfdbwctrl_PLL_IDX_0);
        dprioin_rcru_crplctrl	<= dprioin(rcru_crplctrl_PLL_IDX_1 DOWNTO rcru_crplctrl_PLL_IDX_0);
        dprioin_rcru_ctl0	<= dprioin(rcru_ctl0_PLL_IDX_0);
        dprioin_rcru_l	<= dprioin(rcru_l_PLL_IDX_1 DOWNTO rcru_l_PLL_IDX_0);
        dprioin_rcru_m	<= dprioin(rcru_m_PLL_IDX_3 DOWNTO rcru_m_PLL_IDX_0);
        dprioin_rcru_m_sel	<= dprioin(rcru_m_sel_PLL_IDX_1 DOWNTO rcru_m_sel_PLL_IDX_0);
        dprioin_rcru_div2	<= dprioin(rcru_div2_PLL_IDX_0);
        
        -- PMA Per Channel RX Control Register 5 for Channel 0
        dprioin_reserved_0_TB40	<= dprioin(reserved_0_TB40_PLL_IDX_1 DOWNTO reserved_0_TB40_PLL_IDX_0);
        dprioin_rcru_iselpd	<= dprioin(rcru_iselpd_PLL_IDX_2 DOWNTO rcru_iselpd_PLL_IDX_0);
        dprioin_rcru_isel	<= dprioin(rcru_isel_PLL_IDX_2 DOWNTO rcru_isel_PLL_IDX_0);
        dprioin_rcru_testdnen	<= dprioin(rcru_testdnen_PLL_IDX_0);
        dprioin_rcru_testupen	<= dprioin(rcru_testupen_PLL_IDX_0);
        dprioin_rcru_testen	<= dprioin(rcru_testen_PLL_IDX_0);
        dprioin_rcru_lst	<= dprioin(rcru_lst_PLL_IDX_3 DOWNTO rcru_lst_PLL_IDX_0);
        dprioin_rcru_rlbk	<= dprioin(rcru_rlbk_PLL_IDX_0);
        
        -- PMA Per Channel RX Control Register 6 for Channel 0
        dprioin_rcru_rgla_isel	<= dprioin(rcru_rgla_isel_PLL_IDX_2 DOWNTO rcru_rgla_isel_PLL_IDX_0);
        dprioin_rcru_pdof_test	<= dprioin(rcru_pdof_test_PLL_IDX_2 DOWNTO rcru_pdof_test_PLL_IDX_0);
        dprioin_rcru_pdfl	<= dprioin(rcru_pdfl_PLL_IDX_0);
        dprioin_rcru_sd_sel	<= dprioin(rcru_sd_sel_PLL_IDX_0);
        dprioin_reserved_0_TB41	<= dprioin(reserved_0_TB41_PLL_IDX_0);
        dprioin_rcru_ignore_phslck	<= dprioin(rcru_ignore_phslck_PLL_IDX_0);
        dprioin_rcru_cmu_mode	<= dprioin(rcru_cmu_mode_PLL_IDX_0);
        dprioin_rrx_cru_rst	<= dprioin(rrx_cru_rst_PLL_IDX_0);
        dprioin_rrx_cru_pdb	<= dprioin(rrx_cru_pdb_PLL_IDX_0);
        dprioin_rltr	<= dprioin(rltr_PLL_IDX_0);
        dprioin_rltd	<= dprioin(rltd_PLL_IDX_0);
        dprioin_rcp_mode	<= dprioin(rcp_mode_PLL_IDX_0);
        
        -- PMA Per Channel RX Control Register 7 for Channel 0
        dprioin_rcru_pdof_270i	<= dprioin(rcru_pdof_270i_PLL_IDX_3 DOWNTO rcru_pdof_270i_PLL_IDX_0);
        dprioin_rcru_pdof_180i	<= dprioin(rcru_pdof_180i_PLL_IDX_3 DOWNTO rcru_pdof_180i_PLL_IDX_0);
        dprioin_rcru_pdof_90i	<= dprioin(rcru_pdof_90i_PLL_IDX_3 DOWNTO rcru_pdof_90i_PLL_IDX_0);
        dprioin_rcru_pdof_0i	<= dprioin(rcru_pdof_0i_PLL_IDX_3 DOWNTO rcru_pdof_0i_PLL_IDX_0);
        
        -- manual section --
   	    dprioin_pfd_clk_sel <= dprioin(PFD_CLK_SEL_PLL_IDX_3 DOWNTO PFD_CLK_SEL_PLL_IDX_0);
   	    dprioin_rdynamic_sw <= dprioin(rdynamic_sw_PLL_IDX_0);
   	    
        -- ---------------------------------------------------------------------------
        -- Set DPRIO output from initial CRAM
        -- ---------------------------------------------------------------------------
        
        -- PMA Per Channel RX Control Register 4 for Channel 0
        dprioout(rcru_pdbwctrl_PLL_IDX_1 DOWNTO rcru_pdbwctrl_PLL_IDX_0) <= init_rcru_pdbwctrl;
        dprioout(rcru_pfdbwctrl_PLL_IDX_1 DOWNTO rcru_pfdbwctrl_PLL_IDX_0) <= init_rcru_pfdbwctrl;
        dprioout(rcru_crplctrl_PLL_IDX_1 DOWNTO rcru_crplctrl_PLL_IDX_0) <= init_rcru_crplctrl;
        dprioout(rcru_ctl0_PLL_IDX_0) <= init_rcru_ctl0;
        dprioout(rcru_l_PLL_IDX_1 DOWNTO rcru_l_PLL_IDX_0) <= init_rcru_l;
        dprioout(rcru_m_PLL_IDX_3 DOWNTO rcru_m_PLL_IDX_0) <= init_rcru_m;
        dprioout(rcru_m_sel_PLL_IDX_1 DOWNTO rcru_m_sel_PLL_IDX_0) <= init_rcru_m_sel;
        dprioout(rcru_div2_PLL_IDX_0) <= init_rcru_div2;
        
        -- PMA Per Channel RX Control Register 5 for Channel 0
        dprioout(reserved_0_TB40_PLL_IDX_1 DOWNTO reserved_0_TB40_PLL_IDX_0) <= init_reserved_0_TB40;
        dprioout(rcru_iselpd_PLL_IDX_2 DOWNTO rcru_iselpd_PLL_IDX_0) <= init_rcru_iselpd;
        dprioout(rcru_isel_PLL_IDX_2 DOWNTO rcru_isel_PLL_IDX_0) <= init_rcru_isel;
        dprioout(rcru_testdnen_PLL_IDX_0) <= init_rcru_testdnen;
        dprioout(rcru_testupen_PLL_IDX_0) <= init_rcru_testupen;
        dprioout(rcru_testen_PLL_IDX_0) <= init_rcru_testen;
        dprioout(rcru_lst_PLL_IDX_3 DOWNTO rcru_lst_PLL_IDX_0) <= init_rcru_lst;
        dprioout(rcru_rlbk_PLL_IDX_0) <= init_rcru_rlbk;
        
        -- PMA Per Channel RX Control Register 6 for Channel 0
        dprioout(rcru_rgla_isel_PLL_IDX_2 DOWNTO rcru_rgla_isel_PLL_IDX_0) <= init_rcru_rgla_isel;
        dprioout(rcru_pdof_test_PLL_IDX_2 DOWNTO rcru_pdof_test_PLL_IDX_0) <= init_rcru_pdof_test;
        dprioout(rcru_pdfl_PLL_IDX_0) <= init_rcru_pdfl;
        dprioout(rcru_sd_sel_PLL_IDX_0) <= init_rcru_sd_sel;
        dprioout(reserved_0_TB41_PLL_IDX_0) <= init_reserved_0_TB41;
        dprioout(rcru_ignore_phslck_PLL_IDX_0) <= init_rcru_ignore_phslck;
        dprioout(rcru_cmu_mode_PLL_IDX_0) <= init_rcru_cmu_mode;
        dprioout(rrx_cru_rst_PLL_IDX_0) <= init_rrx_cru_rst;
        dprioout(rrx_cru_pdb_PLL_IDX_0) <= init_rrx_cru_pdb;
        dprioout(rltr_PLL_IDX_0) <= init_rltr;
        dprioout(rltd_PLL_IDX_0) <= init_rltd;
        dprioout(rcp_mode_PLL_IDX_0) <= init_rcp_mode;
        
        -- PMA Per Channel RX Control Register 7 for Channel 0
        dprioout(rcru_pdof_270i_PLL_IDX_3 DOWNTO rcru_pdof_270i_PLL_IDX_0) <= init_rcru_pdof_270i;
        dprioout(rcru_pdof_180i_PLL_IDX_3 DOWNTO rcru_pdof_180i_PLL_IDX_0) <= init_rcru_pdof_180i;
        dprioout(rcru_pdof_90i_PLL_IDX_3 DOWNTO rcru_pdof_90i_PLL_IDX_0) <= init_rcru_pdof_90i;
        dprioout(rcru_pdof_0i_PLL_IDX_3 DOWNTO rcru_pdof_0i_PLL_IDX_0) <= init_rcru_pdof_0i;
        
        -- manual section --
        dprioout(PFD_CLK_SEL_PLL_IDX_3 DOWNTO PFD_CLK_SEL_PLL_IDX_0) <= init_pfd_clk_sel;
        
        -- ---------------------------------------------------------------------------
        -- Set DPRIO CRAM
        -- ---------------------------------------------------------------------------
        
        -- PMA Per Channel RX Control Register 4 for Channel 0
        cram_rcru_pdbwctrl <= init_rcru_pdbwctrl WHEN (dpriodisable /= '0') ELSE dprioin_rcru_pdbwctrl;
        cram_rcru_pfdbwctrl <= init_rcru_pfdbwctrl WHEN (dpriodisable /= '0') ELSE dprioin_rcru_pfdbwctrl;
        cram_rcru_crplctrl <= init_rcru_crplctrl WHEN (dpriodisable /= '0') ELSE dprioin_rcru_crplctrl;
        cram_rcru_ctl0 <= init_rcru_ctl0 WHEN (dpriodisable /= '0') ELSE dprioin_rcru_ctl0;
        cram_rcru_l <= init_rcru_l WHEN (dpriodisable /= '0') ELSE dprioin_rcru_l;
        cram_rcru_m <= dprioin_rcru_m WHEN (dpriodisable = '0' AND (alpha_tolower(pll_type) = "rx cdr" OR alpha_tolower(pll_type) = "high speed rx cdr" OR alpha_tolower(pll_type) = "cmu" OR alpha_tolower(pll_type) = "high speed cmu")) ELSE init_rcru_m;
        cram_rcru_m_sel <= dprioin_rcru_m_sel WHEN (dpriodisable = '0' AND (alpha_tolower(pll_type) = "rx cdr" OR alpha_tolower(pll_type) = "high speed rx cdr" OR alpha_tolower(pll_type) = "cmu" OR alpha_tolower(pll_type) = "high speed cmu")) ELSE init_rcru_m_sel;
        cram_rcru_div2 <= init_rcru_div2 WHEN (dpriodisable /= '0') ELSE dprioin_rcru_div2;
        
        -- PMA Per Channel RX Control Register 5 for Channel 0
        cram_reserved_0_TB40 <= init_reserved_0_TB40 WHEN (dpriodisable /= '0') ELSE dprioin_reserved_0_TB40;
        cram_rcru_iselpd <= init_rcru_iselpd WHEN (dpriodisable /= '0') ELSE dprioin_rcru_iselpd;
        cram_rcru_isel <= init_rcru_isel WHEN (dpriodisable /= '0') ELSE dprioin_rcru_isel;
        cram_rcru_testdnen <= init_rcru_testdnen WHEN (dpriodisable /= '0') ELSE dprioin_rcru_testdnen;
        cram_rcru_testupen <= init_rcru_testupen WHEN (dpriodisable /= '0') ELSE dprioin_rcru_testupen;
        cram_rcru_testen <= init_rcru_testen WHEN (dpriodisable /= '0') ELSE dprioin_rcru_testen;
        cram_rcru_lst <= init_rcru_lst WHEN (dpriodisable /= '0') ELSE dprioin_rcru_lst;
        cram_rcru_rlbk <= init_rcru_rlbk WHEN (dpriodisable /= '0') ELSE dprioin_rcru_rlbk;
        
        -- PMA Per Channel RX Control Register 6 for Channel 0
        cram_rcru_rgla_isel <= init_rcru_rgla_isel WHEN (dpriodisable /= '0') ELSE dprioin_rcru_rgla_isel;
        cram_rcru_pdof_test <= init_rcru_pdof_test WHEN (dpriodisable /= '0') ELSE dprioin_rcru_pdof_test;
        cram_rcru_pdfl <= init_rcru_pdfl WHEN (dpriodisable /= '0') ELSE dprioin_rcru_pdfl;
        cram_rcru_sd_sel <= init_rcru_sd_sel WHEN (dpriodisable /= '0') ELSE dprioin_rcru_sd_sel;
        cram_reserved_0_TB41 <= init_reserved_0_TB41 WHEN (dpriodisable /= '0') ELSE dprioin_reserved_0_TB41;
        cram_rcru_ignore_phslck <= init_rcru_ignore_phslck WHEN (dpriodisable /= '0') ELSE dprioin_rcru_ignore_phslck;
        cram_rcru_cmu_mode <= init_rcru_cmu_mode WHEN (dpriodisable /= '0') ELSE dprioin_rcru_cmu_mode;
        cram_rrx_cru_rst <= init_rrx_cru_rst WHEN (dpriodisable /= '0') ELSE dprioin_rrx_cru_rst;
        cram_rrx_cru_pdb <= init_rrx_cru_pdb WHEN (dpriodisable /= '0') ELSE dprioin_rrx_cru_pdb;
        cram_rltr <= init_rltr WHEN (dpriodisable /= '0') ELSE dprioin_rltr;
        cram_rltd <= init_rltd WHEN (dpriodisable /= '0') ELSE dprioin_rltd;
        cram_rcp_mode <= init_rcp_mode WHEN (dpriodisable /= '0') ELSE dprioin_rcp_mode;
        
        -- PMA Per Channel RX Control Register 7 for Channel 0
        cram_rcru_pdof_270i <= init_rcru_pdof_270i WHEN (dpriodisable /= '0') ELSE dprioin_rcru_pdof_270i;
        cram_rcru_pdof_180i <= init_rcru_pdof_180i WHEN (dpriodisable /= '0') ELSE dprioin_rcru_pdof_180i;
        cram_rcru_pdof_90i <= init_rcru_pdof_90i WHEN (dpriodisable /= '0') ELSE dprioin_rcru_pdof_90i;
        cram_rcru_pdof_0i <= init_rcru_pdof_0i WHEN (dpriodisable /= '0') ELSE dprioin_rcru_pdof_0i;
  
   	    -- manual section --
        cram_pfd_clk_sel <= dprioin_pfd_clk_sel WHEN (dpriodisable = '0' AND (alpha_tolower(pll_type) = "rx cdr" OR alpha_tolower(pll_type) = "high speed rx cdr" OR alpha_tolower(pll_type) = "cmu" OR alpha_tolower(pll_type) = "high speed cmu")) ELSE init_pfd_clk_sel;
   		cram_vco_post_scale <= init_vco_post_scale;
   		--cram_rdynamic_sw <= ((alpha_tolower(pll_type) = "rx cdr") AND (alpha_tolower(protocol_hint) = "pcie2" OR enable_dynamic_divider = "true")) WHEN (dpriodisable /= '0') ELSE ((alpha_tolower(pll_type) = "rx cdr") AND dprioin_rdynamic_sw);
   	    
   		cram_rdynamic_sw <= '1' WHEN (dpriodisable /= '0' AND ((alpha_tolower(pll_type) = "rx cdr") AND (alpha_tolower(protocol_hint) = "pcie2" OR enable_dynamic_divider = "true"))) 
   								ELSE dprioin_rdynamic_sw when (alpha_tolower(pll_type) = "rx cdr") ELSE '0';
   		
  	PROCESS 
   	BEGIN
  		init_rcru_pdof_270i	<= "0000";
  		init_rcru_pdof_180i	<= "0000";
  		init_rcru_pdof_90i	<= "0000";
  		init_rcru_pdof_0i	<= "0000";
  		
  		init_rcru_m <= (mux_select((m = 1), "0000", mux_select((m = 2), "0001", mux_select((m = 4), "0010", mux_select((m = 5), "0011", mux_select((m = 8), "0100", mux_select((m = 10), "0101", mux_select((m = 16), "0110", mux_select((m = 20), "0111", mux_select((m = 25), "1000", mux_select((m = 32), "1001", mux_select((m = 40), "1010", mux_select((m = 50), "1011", "000X")))))))))))));
        init_rcru_m_sel <= (mux_select((n = 1), "00", mux_select((n = 2), "01", mux_select((n = 4), "10", mux_select((n = 8), "11", "00")))));
        init_pfd_clk_sel <= mux_select(((pfd_clk_select >= 0) AND (pfd_clk_select <= 9)), int2bin(pfd_clk_select, 4), "0000");
        init_vco_post_scale <= (mux_select((vco_post_scale = 0), "01", int2bin(vco_post_scale, 2)));
        init_pfd_fb_select <= (mux_select((alpha_tolower(pfd_fb_select) = ("pldclk")), "10", mux_select((alpha_tolower(pfd_fb_select) = ("iqtxrxclk")), "11", "00")));
     	WAIT;
   	END PROCESS;	
       -- new DPRIO model end --
  
   ext_fb_select <= '1' WHEN (init_pfd_fb_select = "11") ELSE '0';

   m_dprioin_modulus <= "00000001" WHEN (cram_rcru_m = "0000") ELSE
                        "00000010" WHEN (cram_rcru_m = "0001") ELSE
                        "00000100" WHEN (cram_rcru_m = "0010") ELSE
                        "00000101" WHEN (cram_rcru_m = "0011") ELSE
                        "00001000" WHEN (cram_rcru_m = "0100") ELSE
                        "00001010" WHEN (cram_rcru_m = "0101") ELSE
                        "00010000" WHEN (cram_rcru_m = "0110") ELSE
                        "00010100" WHEN (cram_rcru_m = "0111") ELSE
                        "00011001" WHEN (cram_rcru_m = "1000") ELSE
                        "00100000" WHEN (cram_rcru_m = "1001") ELSE
                        "00101000" WHEN (cram_rcru_m = "1010") ELSE
                        "00110010" WHEN (cram_rcru_m = "1011") ELSE
                        "00000001";
   
   n_dprioin_modulus <= "00000001" WHEN (cram_rcru_m_sel = "00") ELSE
                        "00000010" WHEN (cram_rcru_m_sel = "01") ELSE
                        "00000100" WHEN (cram_rcru_m_sel = "10") ELSE
                        "00000001";
   
   PROCESS 
       FUNCTION select_clock_period (                                 
           clk_select              : IN integer) RETURN time IS       
           VARIABLE period_int             :  INTEGER;                
       BEGIN                                                          
           CASE clk_select IS                                         
               WHEN 0 =>                                              
                           period_int := inclk0_input_period;               
               WHEN 1 =>                                              
                           period_int := inclk1_input_period;               
               WHEN 2 =>                                              
                           period_int := inclk2_input_period;               
               WHEN 3 =>                                              
                           period_int := inclk3_input_period;               
               WHEN 4 =>                                              
                           period_int := inclk4_input_period;               
               WHEN 5 =>                                              
                           period_int := inclk5_input_period;               
               WHEN 6 =>                                              
                           period_int := inclk6_input_period;               
               WHEN 7 =>                                              
                           period_int := inclk7_input_period;          
               WHEN 8 =>                                              
                           period_int := inclk8_input_period;          
               WHEN 9 =>                                              
                           period_int := inclk9_input_period;          
               WHEN OTHERS  =>                                        
                           period_int := inclk0_input_period;         
                                                                      
           END CASE;                                                  
           RETURN((period_int)* 1 ps);                             
       END select_clock_period;                                        
      
   BEGIN
      expected_clk_period <= (select_clock_period((pfd_clk_select)));
      clk_tolerance <= 0.1 * expected_clk_period;
      freq_viol_msg_sem <= '1';
--      locked_real <= '0';
      WAIT;
   END PROCESS;
   
   pll_clkin_pre_latency <= inclk_ipd(bin2int(cram_pfd_clk_sel)) WHEN (bin2int(cram_pfd_clk_sel) >= 0 AND bin2int(cram_pfd_clk_sel) <= 9) ELSE inclk_ipd(0);
   reset <= areset_ipd OR powerdown_ipd OR dprio_reset;
   pdb <= NOT(powerdown_ipd);
   dprioenable <= NOT(dpriodisable_ipd);
   cru_l_chn <= dprioin_ipd(15 DOWNTO 8);
   dprio_reset <= '1' WHEN ((dprioenable = '1') AND (dprioin_ipd(16) = '1' OR dprioin_ipd(17) = '1')) ELSE
                  '0';
   
   
   clock_latency : stratixiv_hssi_aux_clock_div
      GENERIC MAP (
         clk_divide_by  => 1,
         extra_latency  => sim_clkout_latency
      )
      PORT MAP (
         clk       => pll_clkin_pre_latency,
         enable_d  => '0',
         d         => "00000000",
         reset     => reset,
         clkout    => pll_clkin
      );
   PROCESS (pll_clkin)
   VARIABLE  txt : LINE;
   BEGIN
      IF (pll_clkin'EVENT AND pll_clkin = '1') THEN
         dprioen_reg <= dprioenable;
      END IF;
   END PROCESS;
   
   n_cntr : stratixiv_hssi_aux_clock_div
      GENERIC MAP (
         clk_divide_by  => n,
         extra_latency  => 0
      )
      PORT MAP (
         clk       => pll_clkin,
         enable_d  => dprioenable,
         d         => n_dprioin_modulus,
         reset     => reset,
         clkout    => pfd_refclk
      );

   PROCESS (pfd_refclk, reset, busy, change_in_clk_freq)
   BEGIN
      IF (reset'EVENT AND reset /= '1') THEN
         charge_pump <= '1';
         adjust_without_lol <= '0';
      ELSIF (busy'EVENT and busy = "00") THEN
         charge_pump <= '0';
         adjust_without_lol <= '0';
      ELSIF (change_in_clk_freq = TRUE) THEN
         charge_pump <= '1';
         IF (minor_clk_freq_change = TRUE) THEN
             adjust_without_lol <= '1';
         END IF;
      ELSIF (pfd_refclk'EVENT AND pfd_refclk = '0' AND (NOW > 0* 1 ps) AND (busy /= "11") AND (busy /= "01") ) THEN
--            charge_pump <= int2bit((last_pfd_refclk_edge /= last_fb_clk_edge));
           IF (last_fb_clk_edge /= last_pfd_refclk_edge) THEN
               charge_pump <= '1';
               IF (locked_real = '1') THEN
                   adjust_without_lol <= '1';
               END IF;
           END IF;
      END IF;
   END PROCESS;


   PROCESS (pll_clkin, reset)
   VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         first_pll_clkin_edge_detect <= '0';
      ELSIF (pll_clkin'EVENT AND pll_clkin = '1') THEN
         IF (first_pll_clkin_edge_detect = '0') THEN
            first_pll_clkin_edge_detect <= '1';
         ELSE
            real_clk_period <= NOW - last_pll_clkin_edge;
            IF ((real_clk_period < expected_clk_period - clk_tolerance) OR (real_clk_period > expected_clk_period + clk_tolerance)) THEN
               IF (freq_viol_msg_sem = '1') THEN
ASSERT FALSE REPORT  " CMU PLL input frequency mismatch between parameter-specified period and real clock period" SEVERITY WARNING; 
                  freq_viol_msg_sem <= '0';
               END IF;
            END IF;
            IF ((real_clk_period /= last_real_clk_period) AND (last_real_clk_period > 0 ps)) THEN
               change_in_clk_freq <= TRUE;
               IF ( (abs(real_clk_period - last_real_clk_period)) <= 2 ps) THEN
                   minor_clk_freq_change <= TRUE;
               END IF;
            ELSE
               change_in_clk_freq <= FALSE;
               minor_clk_freq_change <= FALSE;
            END IF;
            last_real_clk_period <= real_clk_period;
         END IF;
         last_pll_clkin_edge <= NOW;
      END IF;
   END PROCESS;
   
   PROCESS (pfd_refclk)
   VARIABLE  txt : LINE;
   BEGIN
      IF (pfd_refclk'EVENT AND pfd_refclk = '1') THEN
         last_pfd_refclk_edge <= NOW;
      END IF;
   END PROCESS;
   
   PROCESS (fbclk)
   VARIABLE  txt : LINE;
   BEGIN
      IF (fbclk'EVENT AND fbclk = '1') THEN
         last_fb_clk_edge <= NOW;
      END IF;
   END PROCESS;
   
   PROCESS (reset)
   VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         ASSERT FALSE REPORT  " CMU PLL is reset" SEVERITY NOTE; 
      END IF;
   END PROCESS;
   
   PROCESS (charge_pump, reset)
   VARIABLE  txt : LINE;
   BEGIN
      IF (reset'EVENT AND reset = '1') THEN
         display_msgs <= '0';
      ELSIF (charge_pump'EVENT) THEN
         IF (charge_pump = '1' and adjust_without_lol = '0') THEN
            IF (display_msgs = '0') THEN
               ASSERT FALSE REPORT  " CMU PLL lost lock due to reset or change in frequency of input clock" SEVERITY NOTE; 
               display_msgs <= '1';
            END IF;
         ELSE
            IF (display_msgs = '1') THEN
               ASSERT FALSE REPORT  " CMU PLL locked to incoming clock" SEVERITY NOTE; 
               display_msgs <= '0';
            END IF;
         END IF;
      END IF;
   END PROCESS;
   
   vco : stratixiv_hssi_aux_clock_mult
      GENERIC MAP (
         clk_multiply_by  => m,
         pfd_fb_select => pfd_fb_select
      )
      PORT MAP (
         clk       => pfd_refclk,
         fbclk     => fbclk,
         adjust    => charge_pump,
         adjust_without_lol => adjust_without_lol,
         reset     => reset,
         enable_m  => dprioenable,
         m         => m_dprioin_modulus,
         clkout    => clk_vco,
         busy      => busy
      );
   post_scale : FOR j IN 0 TO 3 GENERATE
      
      l_cntr : stratixiv_hssi_aux_clock_div
         GENERIC MAP (
            clk_divide_by  => 1,
            extra_latency  => 0
         )
         PORT MAP (
            clk       => clk_vco(j),
            enable_d  => '0',
            d         => "00000000",
            reset     => reset,
            clkout    => clk_post_scale(j)
         );
   END GENERATE;
   
   divide_by_M : stratixiv_hssi_aux_clock_div
      GENERIC MAP (
         clk_divide_by  => m,
         extra_latency  => 0
      )
      PORT MAP (
         clk       => clk_post_scale(0),
         reset     => reset,
         enable_d  => dprioen_reg,
         d         => m_dprioin_modulus,
         clkout    => divide_by_M_clkout
      );
   fbclk <= divide_by_M_clkout WHEN (alpha_tolower(pfd_fb_select) = ("internal")) ELSE
            pfdfbclk_ipd;
   
   pcie_sw_0 : stratixiv_hssi_aux_clock_div
      GENERIC MAP (
         clk_divide_by  => 2,
         extra_latency  => 0
      )
      PORT MAP (
         clk       => clk_post_scale(0),
         enable_d  => '0',
         d         => d_wire,
         reset     => reset,
         clkout    => pcie_div2_clk0
      );
   PROCESS (reset, pcie_div2_clk0)
   VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         pcie_div2_clk2 <= '0';
      ELSE
         pcie_div2_clk2 <= NOT(pcie_div2_clk0);
      END IF;
   END PROCESS;
      
   xhdl1 <= NOT(clk_post_scale(0));
      pcie_sw_1 : stratixiv_hssi_aux_clock_div
         GENERIC MAP (
            clk_divide_by  => 2,
            extra_latency  => 0
         )
         PORT MAP (
            clk       => xhdl1,
            enable_d  => '0',
            d         => d_wire,
            reset     => reset,
            clkout    => pcie_div2_clk1
         );
   PROCESS (reset, pcie_div2_clk1)
   VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         pcie_div2_clk3 <= '0';
      ELSE
         pcie_div2_clk3 <= NOT(pcie_div2_clk1);
      END IF;
   END PROCESS;
   
   PROCESS (busy, reset, adjust_without_lol)
   VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         locked_real <= '0';
      ELSIF (busy = "00" or adjust_without_lol = '1') THEN
         locked_real <= '1';
      ELSE
         locked_real <= '0';
      END IF;
   END PROCESS;
   
   pcie_clk(0) <= pcie_div2_clk0 WHEN (rateswitch_ipd = '0') ELSE
             clk_post_scale(0);
   pcie_clk(1) <= pcie_div2_clk1 WHEN (rateswitch_ipd = '0') ELSE
              clk_post_scale(1);
   pcie_clk(2) <= pcie_div2_clk2 WHEN (rateswitch_ipd = '0') ELSE
               clk_post_scale(2);
   pcie_clk(3)<= pcie_div2_clk3 WHEN (rateswitch_ipd = '0') ELSE
               clk_post_scale(3);

   ck0_pd	<= pcie_clk(0) WHEN (cram_rdynamic_sw = '1') ELSE clk_post_scale(0);
   ck90_pd  <= pcie_clk(1) WHEN (cram_rdynamic_sw = '1') ELSE clk_post_scale(1);
   ck180_pd <= pcie_clk(2) WHEN (cram_rdynamic_sw = '1') ELSE clk_post_scale(2);
   ck270_pd <= pcie_clk(3) WHEN (cram_rdynamic_sw = '1') ELSE clk_post_scale(3);

   datain_dly <= transport datain_ipd after 5 ps;
   
   PROCESS (ck0_pd, pdb)
   VARIABLE  txt : LINE;
   BEGIN
      IF (pdb = '0') THEN
         deven_int1 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSE
         IF (ck0_pd'event and ck0_pd = '1') THEN
            deven_int1 <=  TRANSPORT datain_dly AFTER (PARAM_DELAY)*1 ps;
         ELSIF (ck0_pd'event and ck0_pd = '0') THEN
            deven_int2 <=  TRANSPORT deven_int1 AFTER (PARAM_DELAY)*1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   PROCESS (ck180_pd, pdb)
   VARIABLE  txt : LINE;
   BEGIN
      IF (pdb = '0') THEN
         dodd_int1 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSE
         IF (ck180_pd'event and ck180_pd = '1') THEN
            dodd_int1 <=  TRANSPORT datain_dly AFTER (PARAM_DELAY)*1 ps;
         ELSIF (ck180_pd'event and ck180_pd = '0') THEN
            dodd_int2 <=  TRANSPORT dodd_int1 AFTER (PARAM_DELAY)*1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   PROCESS (ck90_pd, pdb)
   VARIABLE  txt : LINE;
   BEGIN
      IF (pdb = '0') THEN
         d90_int1 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSE
         IF (ck90_pd'event and ck90_pd = '1') THEN
            d90_int1 <=  TRANSPORT datain_dly AFTER (PARAM_DELAY)*1 ps;
         ELSIF (ck90_pd'event and ck90_pd = '0') THEN
            d90_int2 <=  TRANSPORT d90_int1 AFTER (PARAM_DELAY)*1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   PROCESS (ck270_pd, pdb)
   VARIABLE  txt : LINE;
   BEGIN
      IF (pdb = '0') THEN
         d270_int1 <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
      ELSE
         IF (ck270_pd'event and ck270_pd = '1') THEN
            d270_int1 <=  TRANSPORT datain_dly AFTER (PARAM_DELAY)*1 ps;
         ELSIF (ck270_pd'event and ck270_pd = '0') THEN
            d270_int2 <=  TRANSPORT d270_int1 AFTER (PARAM_DELAY)*1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   PROCESS (ck90_pd, pdb)
   VARIABLE  txt : LINE;
   BEGIN
      IF (pdb = '0') THEN
         deven <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         dodd <=  TRANSPORT '0' AFTER (PARAM_DELAY)*1 ps;
         devenb <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
         doddb <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
      ELSIF (ck90_pd'EVENT AND ck90_pd = '1') THEN
         deven <=  TRANSPORT deven_int2 AFTER (PARAM_DELAY)*1 ps;
         dodd <=  TRANSPORT dodd_int2 AFTER (PARAM_DELAY)*1 ps;
         devenb <=  TRANSPORT NOT(deven_int2) AFTER (PARAM_DELAY)*1 ps;
         doddb <=  TRANSPORT NOT(dodd_int2) AFTER (PARAM_DELAY)*1 ps;
      END IF;
   END PROCESS;
   
   clk(0) <= ck0_pd AND (locked_xhdl0 OR ext_fb_select);
   clk(1) <= ck90_pd AND (locked_xhdl0 OR ext_fb_select);
   clk(2) <= ck180_pd AND (locked_xhdl0 OR ext_fb_select);
   clk(3) <= ck270_pd AND (locked_xhdl0 OR ext_fb_select);
   
   dataout(0) <= deven;
   dataout(1) <= dodd;
   
   locked_xhdl0 <= locked_real;

   -- Drive referenced outputs
   locked <= locked_xhdl0;
   pfdfbclkout <= fbclk;
   pfdrefclkout <= pfd_refclk;
   vcobypassout <= pll_clkin;
   freqlocked <= NOT(locktorefclk_ipd);
   
END trans;


-- ***********************************************************
-- This WYSIWYG atom header was automatically generated by the
-- Atmgen build tool. To change it, alter data stored in the 
-- corresponding WYS file(s) in the tools/atmgen subdirectory.
-- ***********************************************************

-- *** Section 1 -- Header ***

-- -----------------------------------------------------------
--
-- Module Name : stratixiv_hssi_tx_pma
--
-- Description : DEV_FAMILY_STRATIXIV stratixiv_hssi_tx_pma Verilog simulation model
--
-- -----------------------------------------------------------

-- *** End of Section 1 ***

-- *** Section 3 -- Module declaration ***


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

USE IEEE.VITAL_Timing.all;
USE IEEE.VITAL_Primitives.all;
ENTITY stratixiv_hssi_tx_pma IS
   GENERIC (

          --  generic control parameters  --
       MsgOn                   : Boolean := DefGlitchMsgOn;
       XOn                     : Boolean := DefGlitchXOn;
       MsgOnChecks             : Boolean := DefMsgOnChecks;
       XOnChecks               : Boolean := DefXOnChecks;
       InstancePath            : String := "*";
       TimingChecksOn          : Boolean := True;
          --  tipd  :interconnect path delays --
      tipd_datain               :VitalDelayArrayType01(64 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_datainfull           :VitalDelayArrayType01(20 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_refclk0inpulse                : VitalDelayType01 := DefpropDelay01;
      tipd_forceelecidle                : VitalDelayType01 := DefpropDelay01;
      tipd_pclk                : VitalDelayArrayType01(5 - 1 DOWNTO 0) := (OTHERS => DefpropDelay01);
      tipd_fastrefclk4in                : VitalDelayArrayType01(2 - 1 DOWNTO 0) := (OTHERS => DefpropDelay01);
      tipd_refclk1in               :VitalDelayArrayType01(2 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_refclk0in               :VitalDelayArrayType01(2 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_refclk4inpulse                : VitalDelayType01 := DefpropDelay01;
      tipd_refclk4in                : VitalDelayArrayType01(2 - 1 DOWNTO 0) := (OTHERS => DefpropDelay01);
      tipd_dpriodisable                : VitalDelayType01 := DefpropDelay01;
      tipd_rxdetecten                : VitalDelayType01 := DefpropDelay01;
      tipd_refclk1inpulse                : VitalDelayType01 := DefpropDelay01;
      tipd_fastrefclk3in               :VitalDelayArrayType01(2 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_txpmareset                : VitalDelayType01 := DefpropDelay01;
      tipd_fastrefclk0in               :VitalDelayArrayType01(2 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_revserialfdbk                : VitalDelayType01 := DefpropDelay01;
      tipd_refclk3in               :VitalDelayArrayType01(2 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_powerdn                : VitalDelayType01 := DefpropDelay01;
      tipd_fastrefclk2in               :VitalDelayArrayType01(2 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_detectrxpowerdown                : VitalDelayType01 := DefpropDelay01;
      tipd_refclk3inpulse                : VitalDelayType01 := DefpropDelay01;
      tipd_refclk2inpulse                : VitalDelayType01 := DefpropDelay01;
      tipd_refclk2in               :VitalDelayArrayType01(2 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rxdetectclk                : VitalDelayType01 := DefpropDelay01;
      tipd_fastrefclk1in               :VitalDelayArrayType01(2 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_dprioin               :VitalDelayArrayType01(300 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
          --  tpd: Edge-Sensitive Paths --
          --  tpd: parallel and Full Connection Paths --
          --  tsetup and thold values : setup and hold times  --
          --  Pulse Width parameters  --
      
      -- *** End of Section 3 ***
      
      -- *** Section 4 -- Port size declarations ***
      
      -- Note: Variable port sizes dictated by parameters are not currently defined in
      -- the WYS file data. Busses are marked with the VARIABLE notation as a reminder.
      -- *** End of Section 4 ***
      
      -- *** Section 5 -- Port declarations ***
      
      lpm_type                        : STRING := "stratixiv_hssi_tx_pma";
      analog_power                    : STRING := "1.5V";
      channel_number                  : INTEGER := 9999;
      channel_type                    : STRING := "auto";
      clkin_select                    : INTEGER := 0; -- 9999; out of bound in loading
      clkmux_delay                    : STRING := "false";
      common_mode                     : STRING := "0.6V";
      dprio_config_mode               : STD_LOGIC_VECTOR(5 DOWNTO 0) := "000000";
      enable_reverse_serial_loopback  : STRING := "false";
      logical_channel_address         : INTEGER := 0;
      logical_protocol_hint_0         : STRING := "basic";
      logical_protocol_hint_1         : STRING := "basic";
      logical_protocol_hint_2         : STRING := "basic";
      logical_protocol_hint_3         : STRING := "basic";
      low_speed_test_select           : INTEGER := 9999;
      physical_clkin0_mapping         : STRING := "x1";
      physical_clkin1_mapping         : STRING := "x4";
      physical_clkin2_mapping         : STRING := "xn_top";
      physical_clkin3_mapping         : STRING := "xn_bottom";
      physical_clkin4_mapping         : STRING := "hypertransport";
      preemp_pretap                   : INTEGER := 0;
      preemp_pretap_inv               : STRING := "false";
      preemp_tap_1                    : INTEGER := 0;
      preemp_tap_1_a                  : INTEGER := 0;
      preemp_tap_1_b                  : INTEGER := 0;
      preemp_tap_1_c                  : INTEGER := 0;
      preemp_tap_2                    : INTEGER := 0;
      preemp_tap_2_inv                : STRING := "false";
      protocol_hint                   : STRING := "basic";
      rx_detect                       : INTEGER := 9999;
      serialization_factor            : INTEGER := 8;
      slew_rate                       : STRING := "low";
      termination                     : STRING := "OCT 100 Ohms";
      use_external_termination        : STRING := "false";
      use_pclk                        : STRING := "false";
      use_pma_direct                  : STRING := "false";
      use_rx_detect                   : STRING := "false";
      use_ser_double_data_mode        : STRING := "false";
      vod_selection                   : INTEGER := 0;
      vod_selection_a                 : INTEGER := 0;
      vod_selection_b                 : INTEGER := 0;
      vod_selection_c                 : INTEGER := 0;
      vod_selection_d                 : INTEGER := 0
   );
   PORT (
      datain                          : IN STD_LOGIC_VECTOR(64 - 1 DOWNTO 0) := (others => '0');
      datainfull                      : IN STD_LOGIC_VECTOR(20 - 1 DOWNTO 0) := (others => '0');
      detectrxpowerdown               : IN STD_LOGIC := '0';
      dpriodisable                    : IN STD_LOGIC := '1';
      dprioin                         : IN STD_LOGIC_VECTOR(300 - 1 DOWNTO 0) := (others => '0');
      extra10gin                      : IN STD_LOGIC_VECTOR(11 - 1 DOWNTO 0) := (others => '0');
      fastrefclk0in                   : IN STD_LOGIC_VECTOR(2 - 1 DOWNTO 0) := (others => '0');
      fastrefclk1in                   : IN STD_LOGIC_VECTOR(2 - 1 DOWNTO 0) := (others => '0');
      fastrefclk2in                   : IN STD_LOGIC_VECTOR(2 - 1 DOWNTO 0) := (others => '0');
      fastrefclk3in                   : IN STD_LOGIC_VECTOR(2 - 1 DOWNTO 0) := (others => '0');
      fastrefclk4in                   : IN STD_LOGIC_VECTOR(2 - 1 DOWNTO 0) := (OTHERS => '0');
      forceelecidle                   : IN STD_LOGIC := '0';
      pclk                            : IN STD_LOGIC_VECTOR(5 - 1 DOWNTO 0) := (OTHERS => '0');
      powerdn                         : IN STD_LOGIC := '0';
      refclk0in                       : IN STD_LOGIC_VECTOR(2 - 1 DOWNTO 0) := (others => '0');
      refclk0inpulse                  : IN STD_LOGIC := '0';
      refclk1in                       : IN STD_LOGIC_VECTOR(2 - 1 DOWNTO 0) := (others => '0');
      refclk1inpulse                  : IN STD_LOGIC := '0';
      refclk2in                       : IN STD_LOGIC_VECTOR(2 - 1 DOWNTO 0) := (others => '0');
      refclk2inpulse                  : IN STD_LOGIC := '0';
      refclk3in                       : IN STD_LOGIC_VECTOR(2 - 1 DOWNTO 0) := (others => '0');
      refclk3inpulse                  : IN STD_LOGIC := '0';
      refclk4in                       : IN STD_LOGIC_VECTOR(2 - 1 DOWNTO 0) := (OTHERS => '0');
      refclk4inpulse                  : IN STD_LOGIC := '0';
      revserialfdbk                   : IN STD_LOGIC := '0';
      rxdetectclk                     : IN STD_LOGIC := '0';
      rxdetecten                      : IN STD_LOGIC := '0';
      txpmareset                      : IN STD_LOGIC := '0';
      clockout                        : OUT STD_LOGIC;
      dataout                         : OUT STD_LOGIC;
      dftout                          : OUT STD_LOGIC_VECTOR(6 - 1 DOWNTO 0);
      dprioout                        : OUT STD_LOGIC_VECTOR(300 - 1 DOWNTO 0);
      rxdetectvalidout                : OUT STD_LOGIC;
      rxfoundout                      : OUT STD_LOGIC;
      seriallpbkout                   : OUT STD_LOGIC
   );
END stratixiv_hssi_tx_pma;

ARCHITECTURE trans OF stratixiv_hssi_tx_pma IS

  signal datain_ipd  :STD_LOGIC_VECTOR(64 - 1 DOWNTO 0);
  signal datainfull_ipd  :STD_LOGIC_VECTOR(20 - 1 DOWNTO 0);
  signal refclk0inpulse_ipd  :STD_LOGIC;
  signal forceelecidle_ipd  :STD_LOGIC;
  signal pclk_ipd  :STD_LOGIC_VECTOR(5 - 1 DOWNTO 0);
  signal fastrefclk4in_ipd  :STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
  signal refclk1in_ipd  :STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
  signal refclk0in_ipd  :STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
  signal refclk4inpulse_ipd  :STD_LOGIC;
  signal refclk4in_ipd  :STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
  signal dpriodisable_ipd  :STD_LOGIC;
  signal rxdetecten_ipd  :STD_LOGIC;
  signal refclk1inpulse_ipd  :STD_LOGIC;
  signal fastrefclk3in_ipd  :STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
  signal txpmareset_ipd  :STD_LOGIC;
  signal fastrefclk0in_ipd  :STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
  signal revserialfdbk_ipd  :STD_LOGIC;
  signal refclk3in_ipd  :STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
  signal powerdn_ipd  :STD_LOGIC;
  signal fastrefclk2in_ipd  :STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
  signal detectrxpowerdown_ipd  :STD_LOGIC;
  signal refclk3inpulse_ipd  :STD_LOGIC;
  signal refclk2inpulse_ipd  :STD_LOGIC;
  signal refclk2in_ipd  :STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
  signal rxdetectclk_ipd  :STD_LOGIC;
  signal fastrefclk1in_ipd  :STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
  signal dprioin_ipd  :STD_LOGIC_VECTOR(300 - 1 DOWNTO 0);
   COMPONENT stratixiv_hssi_pma_c_ser_10g
      GENERIC (
         PARAM_DELAY                     : INTEGER := 0
      );
      PORT (
         clk_divtx                       : OUT STD_LOGIC;
         clk_skew                        : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         cpulse                          : IN STD_LOGIC;
         cpulseb                         : IN STD_LOGIC;
         data_in                         : IN STD_LOGIC_VECTOR(63 DOWNTO 0);
         hfclkn                          : IN STD_LOGIC;
         hfclkp                          : IN STD_LOGIC;
         lbvon                           : OUT STD_LOGIC;
         lbvop                           : OUT STD_LOGIC;
         lfclkn                          : IN STD_LOGIC;
         lfclkp                          : IN STD_LOGIC;
         pdb                             : IN STD_LOGIC;
         pre_em                          : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         rst_n                           : IN STD_LOGIC;
         s_lpbk                          : IN STD_LOGIC;
         vccelxqyx                       : IN STD_LOGIC;
         vccetxqyx                       : IN STD_LOGIC;
         von                             : OUT STD_LOGIC;
         von_op1                         : OUT STD_LOGIC;
         vop                             : OUT STD_LOGIC;
         vop_op1                         : OUT STD_LOGIC;
         vssexqyx                        : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_c_ser
      GENERIC (
         PARAM_DELAY                     : INTEGER := 0
      );
      PORT (
         clk_divtx                       : OUT STD_LOGIC;
         cpulse                          : IN STD_LOGIC;
         data                            : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
         div2                            : IN STD_LOGIC;
         div5                            : IN STD_LOGIC;
         hfclkn                          : IN STD_LOGIC;
         hfclkp                          : IN STD_LOGIC;
         lbvon                           : OUT STD_LOGIC;
         lbvop                           : OUT STD_LOGIC;
         lfclkn                          : IN STD_LOGIC;
         lfclkp                          : IN STD_LOGIC;
         pclk_in                         : IN STD_LOGIC;
         pclksel                         : IN STD_LOGIC;
         pdb                             : IN STD_LOGIC;
         pre_em                          : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         pre_em_2t                       : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         pre_em_pretap                   : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         pre_en_out                      : OUT STD_LOGIC;
         rst_n                           : IN STD_LOGIC;
         s_lpbk                          : IN STD_LOGIC;
         vccelxqyx                       : IN STD_LOGIC;
         vccetxqyx                       : IN STD_LOGIC;
         von                             : OUT STD_LOGIC;
         von_op1                         : OUT STD_LOGIC;
         von_op2                         : OUT STD_LOGIC;
         von_pre                         : OUT STD_LOGIC;
         vop                             : OUT STD_LOGIC;
         vop_op1                         : OUT STD_LOGIC;
         vop_op2                         : OUT STD_LOGIC;
         vop_pre                         : OUT STD_LOGIC;
         vssexqyx                        : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_c_tx
      PORT (
         atb0                            : INOUT STD_LOGIC;
         atb1                            : INOUT STD_LOGIC;
         bsmode                          : IN STD_LOGIC;
         bstxn_in                        : IN STD_LOGIC;
         bstxp_in                        : IN STD_LOGIC;
         cgb_vccelxqyx                   : IN STD_LOGIC;
         cgb_vssexqyx                    : IN STD_LOGIC;
         com_pass                        : OUT STD_LOGIC;
         detect_on                       : OUT STD_LOGIC;
         fixed_clk_out                   : OUT STD_LOGIC;
         ib50uc_rcvdt                    : INOUT STD_LOGIC;
         ib50uc_vcm                      : INOUT STD_LOGIC;
         ib50ut_vcm                      : INOUT STD_LOGIC;
         ib100uc                         : INOUT STD_LOGIC;
         lst                             : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         pdb                             : IN STD_LOGIC;
         probe_pass                      : OUT STD_LOGIC;
         r_dft_sel                       : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         r_dis_idlegate                  : IN STD_LOGIC;
         r_highv                         : IN STD_LOGIC;
         r_lowv                          : IN STD_LOGIC;
         r_rx_det                        : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         r_slew                          : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rlpbkn                          : IN STD_LOGIC;
         rlpbkn_em                       : IN STD_LOGIC;
         rlpbkp                          : IN STD_LOGIC;
         rlpbkp_em                       : IN STD_LOGIC;
         rpre_em_1t                      : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         rpre_em_2t                      : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         rpre_em_pt                      : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         rsig_inv_2t                     : IN STD_LOGIC;
         rsig_inv_ptap                   : IN STD_LOGIC;
         rterm_sel                       : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rtx_rlpbk                       : IN STD_LOGIC;
         rtx_vtt                         : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rvod_sel                        : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rx_det_clk                      : IN STD_LOGIC;
         rx_det_pdb                      : IN STD_LOGIC;
         rx_detect_valid                 : OUT STD_LOGIC;
         rx_found                        : OUT STD_LOGIC;
         sel_150r                        : OUT STD_LOGIC;
         tx50                            : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         tx_det_rx                       : IN STD_LOGIC;
         tx_dftout                       : OUT STD_LOGIC_VECTOR(6 DOWNTO 1);
         tx_elec_idl                     : IN STD_LOGIC;
         vccehtxqyx                      : IN STD_LOGIC;
         vccehxqyx                       : IN STD_LOGIC;
         vccesdh_la                      : IN STD_LOGIC;
         vccesdp_la                      : IN STD_LOGIC;
         vccetxqyx                       : IN STD_LOGIC;
         vin                             : IN STD_LOGIC;
         vin_po1                         : IN STD_LOGIC;
         vin_po2                         : IN STD_LOGIC;
         vin_pre                         : IN STD_LOGIC;
         vip                             : IN STD_LOGIC;
         vip_po1                         : IN STD_LOGIC;
         vip_po2                         : IN STD_LOGIC;
         vip_pre                         : IN STD_LOGIC;
         von                             : INOUT STD_LOGIC;
         vop                             : INOUT STD_LOGIC;
         vssexqyx                        : IN STD_LOGIC;
         rx_p                            : IN STD_LOGIC;
         rx_n                            : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_c_tx_clkmux_cmu
      GENERIC (
         DELAY                           : INTEGER := 1
      );
      PORT (
         cpulse                          : OUT STD_LOGIC;
         cpulse_ht                       : IN STD_LOGIC;
         cpulse_x1                       : IN STD_LOGIC;
         cpulse_x4                       : IN STD_LOGIC;
         cpulse_xn_b                     : IN STD_LOGIC;
         cpulse_xn_t                     : IN STD_LOGIC;
         delay_sel                       : IN STD_LOGIC;
         hfclk_n                         : OUT STD_LOGIC;
         hfclk_p                         : OUT STD_LOGIC;
         hfclkn_ht                       : IN STD_LOGIC;
         hfclkn_x1                       : IN STD_LOGIC;
         hfclkn_x4                       : IN STD_LOGIC;
         hfclkn_xn_b                     : IN STD_LOGIC;
         hfclkn_xn_t                     : IN STD_LOGIC;
         hfclkp_ht                       : IN STD_LOGIC;
         hfclkp_x1                       : IN STD_LOGIC;
         hfclkp_x4                       : IN STD_LOGIC;
         hfclkp_xn_b                     : IN STD_LOGIC;
         hfclkp_xn_t                     : IN STD_LOGIC;
         ht_sel                          : IN STD_LOGIC;
         lfclk_n                         : OUT STD_LOGIC;
         lfclk_p                         : OUT STD_LOGIC;
         lfclkn_ht                       : IN STD_LOGIC;
         lfclkn_x1                       : IN STD_LOGIC;
         lfclkn_x4                       : IN STD_LOGIC;
         lfclkn_xn_b                     : IN STD_LOGIC;
         lfclkn_xn_t                     : IN STD_LOGIC;
         lfclkp_ht                       : IN STD_LOGIC;
         lfclkp_x1                       : IN STD_LOGIC;
         lfclkp_x4                       : IN STD_LOGIC;
         lfclkp_xn_b                     : IN STD_LOGIC;
         lfclkp_xn_t                     : IN STD_LOGIC;
         pdb                             : IN STD_LOGIC;
         sel                             : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         vccelxqyx                       : IN STD_LOGIC;
         vssexqyx                        : IN STD_LOGIC
      );
   END COMPONENT;
   
   
   -- *** End of Section 5 ***
   
   -- *** Section 6 -- Parameter declarations and default values ***
   
   -- *** End of Section 6 ***
   
   -- *** Section 7 -- Port declarations with defaults, if any ***
   
   -- This section will always be empty for WYSIWYG atoms
   -- tri1 devclrn;		//sample
   
   -- *** End of Section 7 ***
   
   -- ---------------------------------------------------------------------------
   --  Model Implementation Begin                                               -
   -- ---------------------------------------------------------------------------
   
   -- DPRIO Index  --------------------------------------------------------------
   -- --- Name in Alphabetical order
   
   -- Initial CRAM converted from parameter -------------------------------------
   -- --- Name in Alphabetical order
   
   SIGNAL ht_sel_init            : STD_LOGIC;
   SIGNAL rcgb_delay_sel_init    : STD_LOGIC;
   SIGNAL rcgb_pdb_init          : STD_LOGIC;
   SIGNAL rcgb_x_en_init         : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rpclksel_init          : STD_LOGIC;
   SIGNAL rpmphs_1tap_init       : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL rpmphs_2tap_init       : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rpmphs_ptap_init       : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL r_rx_det_init          : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rser_div2_init         : STD_LOGIC;
   SIGNAL rser_div5_init         : STD_LOGIC;
   SIGNAL rsig_inv_2t_init       : STD_LOGIC;
   SIGNAL rsig_inv_ptap_init     : STD_LOGIC;
   SIGNAL rslew_init             : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rtx_lst_init           : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rtx_rlpbk_init         : STD_LOGIC;
   SIGNAL rtx_term_sel_init      : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rtx_vtt_init           : STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   -- CRAM value from DPRIO -----------------------------------------------------
   -- --- Name in Alphabetical order
   
   SIGNAL ht_sel_dprioin         : STD_LOGIC;
   SIGNAL rcgb_delay_sel_dprioin : STD_LOGIC;
   SIGNAL rcgb_pdb_dprioin       : STD_LOGIC;
   SIGNAL rcgb_x_en_dprioin      : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rpclksel_dprioin       : STD_LOGIC;
   SIGNAL rpmphs_1tap_dprioin    : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL rpmphs_2tap_dprioin    : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rpmphs_ptap_dprioin    : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL r_rx_det_dprioin       : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rser_div2_dprioin      : STD_LOGIC;
   SIGNAL rser_div5_dprioin      : STD_LOGIC;
   SIGNAL rsig_inv_2t_dprioin    : STD_LOGIC;
   SIGNAL rsig_inv_ptap_dprioin  : STD_LOGIC;
   SIGNAL rslew_dprioin          : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rtx_lst_dprioin        : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rtx_rlpbk_dprioin      : STD_LOGIC;
   SIGNAL rtx_term_sel_dprioin   : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rtx_vtt_dprioin        : STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   -- CRAM to pass to Model -----------------------------------------------------
   -- --- Name in Alphabetical order
   
   SIGNAL ht_sel_cram            : STD_LOGIC;
   SIGNAL rcgb_delay_sel_cram    : STD_LOGIC;
   SIGNAL rcgb_pdb_cram          : STD_LOGIC;
   SIGNAL rcgb_x_en_cram         : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rpclksel_cram          : STD_LOGIC;
   SIGNAL rpmphs_1tap_cram       : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL rpmphs_2tap_cram       : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rpmphs_ptap_cram       : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL r_rx_det_cram          : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rser_div2_cram         : STD_LOGIC;
   SIGNAL rser_div5_cram         : STD_LOGIC;
   SIGNAL rsig_inv_2t_cram       : STD_LOGIC;
   SIGNAL rsig_inv_ptap_cram     : STD_LOGIC;
   SIGNAL rslew_cram             : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rtx_lst_cram           : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rtx_rlpbk_cram         : STD_LOGIC;
   SIGNAL rtx_term_sel_cram      : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rtx_vtt_cram           : STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   SIGNAL mdpriodisable          : STD_LOGIC;
   
   -- ---------------------------------------------------------------------------
   --  Model / Submodule Instantiations                                         -
   -- ---------------------------------------------------------------------------
   -- ***************************************************************************
   --  -- uses only *_cram                                                      *
   --  -- should NOT use parameters nor *_dprioin                               *
   -- ***************************************************************************
   
   --  common supply wires
   SIGNAL vccetxqyx              : STD_LOGIC;
   SIGNAL vccelxqyx              : STD_LOGIC;
   SIGNAL vssexqyx               : STD_LOGIC;
   
   -- for the tx_clkmux instance
   -- input wires
   SIGNAL xtxclkmux_cpulse_ht    : STD_LOGIC;
   SIGNAL xtxclkmux_cpulse_x1    : STD_LOGIC;
   SIGNAL xtxclkmux_cpulse_x4    : STD_LOGIC;
   SIGNAL xtxclkmux_cpulse_x8_b  : STD_LOGIC;
   SIGNAL xtxclkmux_cpulse_x8_t  : STD_LOGIC;
   
   SIGNAL xtxclkmux_hfclkn_ht    : STD_LOGIC;
   SIGNAL xtxclkmux_hfclkn_x1    : STD_LOGIC;
   SIGNAL xtxclkmux_hfclkn_x4    : STD_LOGIC;
   SIGNAL xtxclkmux_hfclkn_x8_b  : STD_LOGIC;
   SIGNAL xtxclkmux_hfclkn_x8_t  : STD_LOGIC;
   
   SIGNAL xtxclkmux_hfclkp_ht    : STD_LOGIC;
   SIGNAL xtxclkmux_hfclkp_x1    : STD_LOGIC;
   SIGNAL xtxclkmux_hfclkp_x4    : STD_LOGIC;
   SIGNAL xtxclkmux_hfclkp_x8_b  : STD_LOGIC;
   SIGNAL xtxclkmux_hfclkp_x8_t  : STD_LOGIC;
   
   SIGNAL xtxclkmux_ht_sel       : STD_LOGIC;
   
   SIGNAL xtxclkmux_lfclkn_ht    : STD_LOGIC;
   SIGNAL xtxclkmux_lfclkn_x1    : STD_LOGIC;
   SIGNAL xtxclkmux_lfclkn_x4    : STD_LOGIC;
   SIGNAL xtxclkmux_lfclkn_x8_b  : STD_LOGIC;
   SIGNAL xtxclkmux_lfclkn_x8_t  : STD_LOGIC;
   
   SIGNAL xtxclkmux_lfclkp_ht    : STD_LOGIC;
   SIGNAL xtxclkmux_lfclkp_x1    : STD_LOGIC;
   SIGNAL xtxclkmux_lfclkp_x4    : STD_LOGIC;
   SIGNAL xtxclkmux_lfclkp_x8_b  : STD_LOGIC;
   SIGNAL xtxclkmux_lfclkp_x8_t  : STD_LOGIC;
   
   SIGNAL xtxclkmux_pdb          : STD_LOGIC;
   SIGNAL xtxclkmux_rdelay_sel   : STD_LOGIC;
   SIGNAL xtxclkmux_rsel         : STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   -- output wires
   SIGNAL xtxclkmux_cpulse       : STD_LOGIC;
   SIGNAL xtxclkmux_hfclkn       : STD_LOGIC;
   SIGNAL xtxclkmux_hfclkp       : STD_LOGIC;
   SIGNAL xtxclkmux_lfclkn       : STD_LOGIC;
   SIGNAL xtxclkmux_lfclkp       : STD_LOGIC;
     
   -- for the serializer instance
   -- input wires
   SIGNAL xser_cpulse            : STD_LOGIC;
   SIGNAL xser_data              : STD_LOGIC_VECTOR(19 DOWNTO 0);
   SIGNAL xser_data_dprio        : STD_LOGIC_VECTOR(19 DOWNTO 0);
   SIGNAL xser_hfclkn            : STD_LOGIC;
   SIGNAL xser_hfclkp            : STD_LOGIC;
   SIGNAL xser_lfclkn            : STD_LOGIC;
   SIGNAL xser_lfclkp            : STD_LOGIC;
   SIGNAL xser_pclk              : STD_LOGIC;
   SIGNAL xser_pdb               : STD_LOGIC;
   SIGNAL xser_rpclksel          : STD_LOGIC;
   SIGNAL xser_rpre_em           : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL xser_rpre_em_2t        : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL xser_rpre_em_pretap    : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL xser_rdiv2             : STD_LOGIC;
   SIGNAL xser_rdiv5             : STD_LOGIC;
   SIGNAL xser_rs_lpbk           : STD_LOGIC;
   SIGNAL xser_rst_n             : STD_LOGIC;
   SIGNAL vccetx                 : STD_LOGIC;
   
   -- 10g input wires
   SIGNAL xser_10g_clk_skew      : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL xser_10g_cpulse        : STD_LOGIC;
   SIGNAL xser_10g_cpulseb       : STD_LOGIC;
   SIGNAL xser_10g_data_in       : STD_LOGIC_VECTOR(63 DOWNTO 0);
   SIGNAL xser_10g_hfclkn        : STD_LOGIC;
   SIGNAL xser_10g_hfclkp        : STD_LOGIC;
   SIGNAL xser_10g_lfclkn        : STD_LOGIC;
   SIGNAL xser_10g_lfclkp        : STD_LOGIC;
   SIGNAL xser_10g_pdb           : STD_LOGIC;
   SIGNAL xser_10g_rpre_em       : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL xser_10g_rst_n         : STD_LOGIC;
   SIGNAL xser_10g_rs_lpbk       : STD_LOGIC;
   
   -- output wires
   SIGNAL xser_clk_divtx         : STD_LOGIC;
   SIGNAL xser_lbvop             : STD_LOGIC;
   SIGNAL xser_lbvon             : STD_LOGIC;
   SIGNAL xser_pre_en_out        : STD_LOGIC;
   SIGNAL xser_von               : STD_LOGIC;
   SIGNAL xser_von_op1           : STD_LOGIC;
   SIGNAL xser_von_op2           : STD_LOGIC;
   SIGNAL xser_von_pre           : STD_LOGIC;
   SIGNAL xser_vop               : STD_LOGIC;
   SIGNAL xser_vop_op1           : STD_LOGIC;
   SIGNAL xser_vop_op2           : STD_LOGIC;
   SIGNAL xser_vop_pre           : STD_LOGIC;
   
   -- 10g output wires
   SIGNAL xser_10g_clk_divtx     : STD_LOGIC;
   SIGNAL xser_10g_lbvon         : STD_LOGIC;
   SIGNAL xser_10g_von           : STD_LOGIC;
   SIGNAL xser_10g_von_op1       : STD_LOGIC;
   SIGNAL xser_10g_lbvop         : STD_LOGIC;
   SIGNAL xser_10g_vop           : STD_LOGIC;
   SIGNAL xser_10g_vop_op1       : STD_LOGIC;
   
   SIGNAL xser_10g_pre_em        : STD_LOGIC;
   
   -- serializer outputs
   
   -- for the TX driver instance
   -- input wires
   SIGNAL xtx_bsmode             : STD_LOGIC;
   SIGNAL xtx_bstxn_in           : STD_LOGIC;
   SIGNAL xtx_bstxp_in           : STD_LOGIC;
   SIGNAL xtx_cgb_vccelxqyx      : STD_LOGIC;
   SIGNAL xtx_cgb_vssexqyx       : STD_LOGIC;
   SIGNAL xtx_rlpbkp             : STD_LOGIC;
   SIGNAL xtx_rlpbkn             : STD_LOGIC;
   SIGNAL xtx_rlpbkn_em          : STD_LOGIC;
   SIGNAL xtx_rlpbkp_em          : STD_LOGIC;
   SIGNAL xtx_r_dft_sel          : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL xtx_r_dis_idlegate     : STD_LOGIC;
   SIGNAL xtx_r_highv            : STD_LOGIC;
   SIGNAL xtx_r_lowv             : STD_LOGIC;
   SIGNAL xtx_r_rx_det           : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL xtx_rpre_em_1t         : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL xtx_rpre_em_2t         : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL xtx_rpre_em_pt         : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL xtx_rsig_inv_2t        : STD_LOGIC;
   SIGNAL xtx_rsig_inv_ptap      : STD_LOGIC;
   SIGNAL xtx_rslew              : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL xtx_rlst               : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL xtx_rtx_rlpbk          : STD_LOGIC;
   SIGNAL xtx_rterm_sel          : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL xtx_rtx_vtt            : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL xtx_rvod_sel           : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL xtx_rx_det_clk         : STD_LOGIC;
   SIGNAL xtx_rx_det_pdb         : STD_LOGIC;
   SIGNAL xtx_rx_n               : STD_LOGIC;
   SIGNAL xtx_rx_p               : STD_LOGIC;
   SIGNAL xtx_tx_det_rx          : STD_LOGIC;
   SIGNAL xtx_tx_elec_idl        : STD_LOGIC;
   SIGNAL xtx_pdb                : STD_LOGIC;
   SIGNAL xtx_tx50               : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL xtx_vin                : STD_LOGIC;
   SIGNAL xtx_vin_op1            : STD_LOGIC;
   SIGNAL xtx_vin_op2            : STD_LOGIC;
   SIGNAL xtx_vin_pre            : STD_LOGIC;
   SIGNAL xtx_vip                : STD_LOGIC;
   SIGNAL xtx_vip_op1            : STD_LOGIC;
   SIGNAL xtx_vip_op2            : STD_LOGIC;
   SIGNAL xtx_vip_pre            : STD_LOGIC;
   SIGNAL vccehtxqyx             : STD_LOGIC;
   SIGNAL vccehxqyx              : STD_LOGIC;
   
   -- inout wires
   SIGNAL xtx_atb0               : STD_LOGIC;
   SIGNAL xtx_atb1               : STD_LOGIC;
   SIGNAL xtx_ib50uc_vcm         : STD_LOGIC;
   SIGNAL xtx_ib50ut_vcm         : STD_LOGIC;
   SIGNAL xtx_ib100uc            : STD_LOGIC;
   SIGNAL xtx_ib50uc_rcvdt       : STD_LOGIC;
   SIGNAL xtx_von                : STD_LOGIC;
   SIGNAL xtx_vop                : STD_LOGIC;
   
   -- output wires
   SIGNAL xtx_com_pass           : STD_LOGIC;
   SIGNAL xtx_detect_on          : STD_LOGIC;
   SIGNAL xtx_fixed_clk          : STD_LOGIC;
   SIGNAL xtx_probe_pass         : STD_LOGIC;
   SIGNAL xtx_rx_detect_valid    : STD_LOGIC;
   SIGNAL xtx_rx_found           : STD_LOGIC;
   SIGNAL xtx_sel_150r           : STD_LOGIC;
   SIGNAL xtx_tx_dftout          : STD_LOGIC_VECTOR(6 DOWNTO 1);
   
   --temporarily generate rxdetectclk - fixed clock of 125 Mhz
   SIGNAL rx_det_clk_reg         : STD_LOGIC;
   -- end
   
   -- workaround incorrect connections of forceeleidle
   -- delay 25 * 4* 1 ps = 100 ns   
   SIGNAL forceelecidle_in      : STD_LOGIC;
   -- end
   
   -- the actual instance
   
   SIGNAL xtx_ib50uc             : STD_LOGIC;
   SIGNAL xtx_ib50ut             : STD_LOGIC;
   
   -- new dprio model --
   -- Table28: PMA Per Channel TX Control Register 1 for Channel 0
   constant rpowdnt_TXPMA_IDX_0	: integer := 0;
   constant rvod_seld_TXPMA_IDX_0	: integer := 1;
   constant rvod_seld_TXPMA_IDX_1	: integer := 2;
   constant rvod_seld_TXPMA_IDX_2	: integer := 3;
   constant rvod_selc_TXPMA_IDX_0	: integer := 4;
   constant rvod_selc_TXPMA_IDX_1	: integer := 5;
   constant rvod_selc_TXPMA_IDX_2	: integer := 6;
   constant rvod_selb_TXPMA_IDX_0	: integer := 7;
   constant rvod_selb_TXPMA_IDX_1	: integer := 8;
   constant rvod_selb_TXPMA_IDX_2	: integer := 9;
   constant rvod_sela_TXPMA_IDX_0	: integer := 10;
   constant rvod_sela_TXPMA_IDX_1	: integer := 11;
   constant rvod_sela_TXPMA_IDX_2	: integer := 12;
   constant rvod_sel_non_pcie_TXPMA_IDX_0	: integer := 13;
   constant rvod_sel_non_pcie_TXPMA_IDX_1	: integer := 14;
   constant rvod_sel_non_pcie_TXPMA_IDX_2	: integer := 15;
   
   -- Table29: PMA Per Channel TX Control Register 2 for Channel 0
   constant reserved_0_TB29_TXPMA_IDX_0	: integer := 16;
   constant rpre_em_1t_b_TXPMA_IDX_0	: integer := 17;
   constant rpre_em_1t_b_TXPMA_IDX_1	: integer := 18;
   constant rpre_em_1t_b_TXPMA_IDX_2	: integer := 19;
   constant rpre_em_1t_b_TXPMA_IDX_3	: integer := 20;
   constant rpre_em_1t_b_TXPMA_IDX_4	: integer := 21;
   constant rpre_em_1t_a_TXPMA_IDX_0	: integer := 22;
   constant rpre_em_1t_a_TXPMA_IDX_1	: integer := 23;
   constant rpre_em_1t_a_TXPMA_IDX_2	: integer := 24;
   constant rpre_em_1t_a_TXPMA_IDX_3	: integer := 25;
   constant rpre_em_1t_a_TXPMA_IDX_4	: integer := 26;
   constant rpre_em_1t_no_pcie_TXPMA_IDX_0	: integer := 27;
   constant rpre_em_1t_no_pcie_TXPMA_IDX_1	: integer := 28;
   constant rpre_em_1t_no_pcie_TXPMA_IDX_2	: integer := 29;
   constant rpre_em_1t_no_pcie_TXPMA_IDX_3	: integer := 30;
   constant rpre_em_1t_no_pcie_TXPMA_IDX_4	: integer := 31;
   
   -- Table30: PMA Per Channel TX Control Register 3 for Channel 0
   constant rpre_em_pt_TXPMA_IDX_0	: integer := 32;
   constant rpre_em_pt_TXPMA_IDX_1	: integer := 33;
   constant rpre_em_pt_TXPMA_IDX_2	: integer := 34;
   constant rpre_em_pt_TXPMA_IDX_3	: integer := 35;
   constant rpre_em_2t_TXPMA_IDX_0	: integer := 36;
   constant rpre_em_2t_TXPMA_IDX_1	: integer := 37;
   constant rpre_em_2t_TXPMA_IDX_2	: integer := 38;
   constant rpre_em_2t_TXPMA_IDX_3	: integer := 39;
   constant rpre_em_1t_c_TXPMA_IDX_0	: integer := 40;
   constant rpre_em_1t_c_TXPMA_IDX_1	: integer := 41;
   constant rpre_em_1t_c_TXPMA_IDX_2	: integer := 42;
   constant rpre_em_1t_c_TXPMA_IDX_3	: integer := 43;
   constant rpre_em_1t_c_TXPMA_IDX_4	: integer := 44;
   constant reserved_0_TB30_TXPMA_IDX_0	: integer := 45;
   constant reserved_0_TB30_TXPMA_IDX_1	: integer := 46;
   constant reserved_0_TB30_TXPMA_IDX_2	: integer := 47;
   
   -- Table31: PMA Per Channel TX Control Register 4 for Channel 0
   constant rlowv_TXPMA_IDX_0	: integer := 48;
   constant rrx_det_TXPMA_IDX_0	: integer := 49;
   constant rrx_det_TXPMA_IDX_1	: integer := 50;
   constant rsig_inv_2t_TXPMA_IDX_0	: integer := 51;
   constant rsig_inv_ptap_TXPMA_IDX_0	: integer := 52;
   constant rslew_TXPMA_IDX_0	: integer := 53;
   constant rslew_TXPMA_IDX_1	: integer := 54;
   constant rtx_lst_TXPMA_IDX_0	: integer := 55;
   constant rtx_lst_TXPMA_IDX_1	: integer := 56;
   constant rtx_lst_TXPMA_IDX_2	: integer := 57;
   constant rtx_lst_TXPMA_IDX_3	: integer := 58;
   constant rtx_vtt_TXPMA_IDX_0	: integer := 59;
   constant rtx_vtt_TXPMA_IDX_1	: integer := 60;
   constant rtx_term_sel_TXPMA_IDX_0	: integer := 61;
   constant rtx_term_sel_TXPMA_IDX_1	: integer := 62;
   constant rtx_term_sel_TXPMA_IDX_2	: integer := 63;
   
   -- Table32: PMA Per Channel TX Control Register 5 for Channel 0
   constant reserved_1_TB32_TXPMA_IDX_0	: integer := 64;
   constant reserved_1_TB32_TXPMA_IDX_1	: integer := 65;
   constant reserved_1_TB32_TXPMA_IDX_2	: integer := 66;
   constant reserved_1_TB32_TXPMA_IDX_3	: integer := 67;
   constant reserved_1_TB32_TXPMA_IDX_4	: integer := 68;
   constant reserved_1_TB32_TXPMA_IDX_5	: integer := 69;
   constant reserved_1_TB32_TXPMA_IDX_6	: integer := 70;
   constant reserved_1_TB32_TXPMA_IDX_7	: integer := 71;
   constant reserved_1_TB32_TXPMA_IDX_8	: integer := 72;
   constant reserved_1_TB32_TXPMA_IDX_9	: integer := 73;
   constant reserved_1_TB32_TXPMA_IDX_10	: integer := 74;
   constant rtx_ob_pdb_TXPMA_IDX_0	: integer := 75;
   constant reserved_0_TB32_TXPMA_IDX_0	: integer := 76;
   constant r_dft_sel_TXPMA_IDX_0	: integer := 77;
   constant r_dft_sel_TXPMA_IDX_1	: integer := 78;
   constant r_dft_sel_TXPMA_IDX_2	: integer := 79;
   
   -- Table33: PMA Per Channel TX Control Register 6 for Channel 0
   constant reserved_0_TB33_TXPMA_IDX_0	: integer := 80;
   constant reserved_0_TB33_TXPMA_IDX_1	: integer := 81;
   constant reserved_0_TB33_TXPMA_IDX_2	: integer := 82;
   constant reserved_0_TB33_TXPMA_IDX_3	: integer := 83;
   constant rtx_cgb_pdb_TXPMA_IDX_0	: integer := 84;
   constant rpclksel_TXPMA_IDX_0	: integer := 85;
   constant rdynamic_sw_TXPMA_IDX_0	: integer := 86;
   constant rs_lpbk_TXPMA_IDX_0	: integer := 87;
   constant rcgb_delay_sel_TXPMA_IDX_0	: integer := 88;
   constant rpmadwidth_tx_TXPMA_IDX_0	: integer := 89;
   constant rpma_doublewidth_tx_TXPMA_IDX_0	: integer := 90;
   constant rcgb_m_sel_TXPMA_IDX_0	: integer := 91;
   constant rcgb_m_sel_TXPMA_IDX_1	: integer := 92;
   constant rcgb_cmu_sel_TXPMA_IDX_0	: integer := 93;
   constant rcgb_x_en_TXPMA_IDX_0	: integer := 94;
   constant rcgb_x_en_TXPMA_IDX_1	: integer := 95;
   
   -- Table34: PMA Per Channel TX Control Register 7 for Channel 0
   constant reserved_1_TB34_TXPMA_IDX_0	: integer := 96;
   constant reserved_1_TB34_TXPMA_IDX_1	: integer := 97;
   constant reserved_1_TB34_TXPMA_IDX_2	: integer := 98;
   constant rpcs_sd_sel_TXPMA_IDX_0	: integer := 99;
   constant rrx_refclk_TXPMA_IDX_0	: integer := 100;
   constant rimpctrl_TXPMA_IDX_0	: integer := 101;
   constant reserved_0_TB34_TXPMA_IDX_0	: integer := 102;
   constant reserved_0_TB34_TXPMA_IDX_1	: integer := 103;
   constant reserved_0_TB34_TXPMA_IDX_2	: integer := 104;
   constant reserved_0_TB34_TXPMA_IDX_3	: integer := 105;
   constant rrevlb_sw_TXPMA_IDX_0	: integer := 106;
   constant rvcobypass_TXPMA_IDX_0	: integer := 107;
   constant rrefclk_sel_TXPMA_IDX_0	: integer := 108;
   constant rrefclk_sel_TXPMA_IDX_1	: integer := 109;
   constant riqclk_sel_TXPMA_IDX_0	: integer := 110;
   constant riqclk_sel_TXPMA_IDX_1	: integer := 111;
   
   -- Table35: PMA Per Channel TX Control Register 8 for Channel 0
   constant rpma_reserved_0_TB35_TXPMA_IDX_0	: integer := 112;
   constant rpma_reserved_0_TB35_TXPMA_IDX_1	: integer := 113;
   constant rpma_reserved_0_TB35_TXPMA_IDX_2	: integer := 114;
   constant rpma_reserved_0_TB35_TXPMA_IDX_3	: integer := 115;
   constant rpma_reserved_0_TB35_TXPMA_IDX_4	: integer := 116;
   constant rpma_reserved_0_TB35_TXPMA_IDX_5	: integer := 117;
   constant rpma_reserved_0_TB35_TXPMA_IDX_6	: integer := 118;
   constant rpma_reserved_0_TB35_TXPMA_IDX_7	: integer := 119;
   constant rpma_reserved_0_TB35_TXPMA_IDX_8	: integer := 120;
   constant rpma_reserved_0_TB35_TXPMA_IDX_9	: integer := 121;
   constant rpma_reserved_0_TB35_TXPMA_IDX_10	: integer := 122;
   constant rpma_reserved_0_TB35_TXPMA_IDX_11	: integer := 123;
   constant rpma_reserved_0_TB35_TXPMA_IDX_12	: integer := 124;
   constant rpma_reserved_0_TB35_TXPMA_IDX_13	: integer := 125;
   constant rpma_reserved_0_TB35_TXPMA_IDX_14	: integer := 126;
   constant rpma_reserved_0_TB35_TXPMA_IDX_15	: integer := 127;
  
   -- Extra
   constant ht_sel_TX_PMA_IDX  : integer := 128;
  
   constant DPRIO_CHANNEL_INTERFACE_BIT : INTEGER := 4;
 
   -- ---------------------------------------------------------------------------
   -- DPRIO input CRAM  
   -- ---------------------------------------------------------------------------
   -- PMA Per Channel TX Control Register 1 for Channel 0
   SIGNAL dprioin_rpowdnt	: STD_LOGIC;
   SIGNAL dprioin_rvod_seld	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_rvod_selc	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_rvod_selb	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_rvod_sela	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_rvod_sel_non_pcie	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 2 for Channel 0
   SIGNAL dprioin_reserved_0_TB29	: STD_LOGIC;
   SIGNAL dprioin_rpre_em_1t_b	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL dprioin_rpre_em_1t_a	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL dprioin_rpre_em_1t_no_pcie	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 3 for Channel 0
   SIGNAL dprioin_rpre_em_pt	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dprioin_rpre_em_2t	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dprioin_rpre_em_1t_c	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL dprioin_reserved_0_TB30	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 4 for Channel 0
   SIGNAL dprioin_rlowv	: STD_LOGIC;
   SIGNAL dprioin_rrx_det	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_rsig_inv_2t	: STD_LOGIC;
   SIGNAL dprioin_rsig_inv_ptap	: STD_LOGIC;
   SIGNAL dprioin_rslew	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_rtx_lst	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dprioin_rtx_vtt	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_rtx_term_sel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 5 for Channel 0
   SIGNAL dprioin_reserved_1_TB32	: STD_LOGIC_VECTOR(10 DOWNTO 0);
   SIGNAL dprioin_rtx_ob_pdb	: STD_LOGIC;
   SIGNAL dprioin_reserved_0_TB32	: STD_LOGIC;
   SIGNAL dprioin_r_dft_sel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 6 for Channel 0
   SIGNAL dprioin_reserved_0_TB33	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dprioin_rtx_cgb_pdb	: STD_LOGIC;
   SIGNAL dprioin_rpclksel	: STD_LOGIC;
   SIGNAL dprioin_rdynamic_sw	: STD_LOGIC;
   SIGNAL dprioin_rs_lpbk	: STD_LOGIC;
   SIGNAL dprioin_rcgb_delay_sel	: STD_LOGIC;
   SIGNAL dprioin_rpmadwidth_tx	: STD_LOGIC;
   SIGNAL dprioin_rpma_doublewidth_tx	: STD_LOGIC;
   SIGNAL dprioin_rcgb_m_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_rcgb_cmu_sel	: STD_LOGIC;
   SIGNAL dprioin_rcgb_x_en	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 7 for Channel 0
   SIGNAL dprioin_reserved_1_TB34	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_rpcs_sd_sel	: STD_LOGIC;
   SIGNAL dprioin_rrx_refclk	: STD_LOGIC;
   SIGNAL dprioin_rimpctrl	: STD_LOGIC;
   SIGNAL dprioin_reserved_0_TB34	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dprioin_rrevlb_sw	: STD_LOGIC;
   SIGNAL dprioin_rvcobypass	: STD_LOGIC;
   SIGNAL dprioin_rrefclk_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_riqclk_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 8 for Channel 0
   SIGNAL dprioin_rpma_reserved_0_TB35	: STD_LOGIC_VECTOR(15 DOWNTO 0);
   
   -- Extra
   SIGNAL dprioin_ht_sel : STD_LOGIC;
   
   -- SW logical index ---------------------------------------------------------- 
   constant CLKIN_SELECT_TXPMA_IDX_0	: integer := 200;
   constant CLKIN_SELECT_TXPMA_IDX_1	: integer := 201;
   constant CLKIN_SELECT_TXPMA_IDX_2	: integer := 202;
   
   -- ---------------------------------------------------------------------------
   -- Initial CRAM  
   -- ---------------------------------------------------------------------------
   -- PMA Per Channel TX Control Register 1 for Channel 0
   SIGNAL init_rpowdnt	: STD_LOGIC;
   SIGNAL init_rvod_seld	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_rvod_selc	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_rvod_selb	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_rvod_sela	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_rvod_sel_non_pcie	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 2 for Channel 0
   SIGNAL init_reserved_0_TB29	: STD_LOGIC;
   SIGNAL init_rpre_em_1t_b	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL init_rpre_em_1t_a	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL init_rpre_em_1t_no_pcie	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 3 for Channel 0
   SIGNAL init_rpre_em_pt	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rpre_em_2t	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rpre_em_1t_c	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL init_reserved_0_TB30	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 4 for Channel 0
   SIGNAL init_rlowv	: STD_LOGIC;
   SIGNAL init_rrx_det	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rsig_inv_2t	: STD_LOGIC;
   SIGNAL init_rsig_inv_ptap	: STD_LOGIC;
   SIGNAL init_rslew	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rtx_lst	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rtx_vtt	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rtx_term_sel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 5 for Channel 0
   SIGNAL init_reserved_1_TB32	: STD_LOGIC_VECTOR(10 DOWNTO 0);
   SIGNAL init_rtx_ob_pdb	: STD_LOGIC;
   SIGNAL init_reserved_0_TB32	: STD_LOGIC;
   SIGNAL init_r_dft_sel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 6 for Channel 0
   SIGNAL init_reserved_0_TB33	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rtx_cgb_pdb	: STD_LOGIC;
   SIGNAL init_rpclksel	: STD_LOGIC;
   SIGNAL init_rdynamic_sw	: STD_LOGIC;
   SIGNAL init_rs_lpbk	: STD_LOGIC;
   SIGNAL init_rcgb_delay_sel	: STD_LOGIC;
   SIGNAL init_rpmadwidth_tx	: STD_LOGIC;
   SIGNAL init_rpma_doublewidth_tx	: STD_LOGIC;
   SIGNAL init_rcgb_m_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rcgb_cmu_sel	: STD_LOGIC;
   SIGNAL init_rcgb_x_en	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 7 for Channel 0
   SIGNAL init_reserved_1_TB34	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_rpcs_sd_sel	: STD_LOGIC;
   SIGNAL init_rrx_refclk	: STD_LOGIC;
   SIGNAL init_rimpctrl	: STD_LOGIC;
   SIGNAL init_reserved_0_TB34	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rrevlb_sw	: STD_LOGIC;
   SIGNAL init_rvcobypass	: STD_LOGIC;
   SIGNAL init_rrefclk_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_riqclk_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 8 for Channel 0
   SIGNAL init_rpma_reserved_0_TB35	: STD_LOGIC_VECTOR(15 DOWNTO 0);
   
   -- Extra
   SIGNAL init_ht_sel : STD_LOGIC;
   
   -- ---------------------------------------------------------------------------
   -- CRAM  
   -- ---------------------------------------------------------------------------
   -- PMA Per Channel TX Control Register 1 for Channel 0
   SIGNAL cram_rpowdnt	: STD_LOGIC;
   SIGNAL cram_rvod_seld	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_rvod_selc	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_rvod_selb	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_rvod_sela	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_rvod_sel_non_pcie	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 2 for Channel 0
   SIGNAL cram_reserved_0_TB29	: STD_LOGIC;
   SIGNAL cram_rpre_em_1t_b	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL cram_rpre_em_1t_a	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL cram_rpre_em_1t_no_pcie	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 3 for Channel 0
   SIGNAL cram_rpre_em_pt	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rpre_em_2t	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rpre_em_1t_c	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL cram_reserved_0_TB30	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 4 for Channel 0
   SIGNAL cram_rlowv	: STD_LOGIC;
   SIGNAL cram_rrx_det	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rsig_inv_2t	: STD_LOGIC;
   SIGNAL cram_rsig_inv_ptap	: STD_LOGIC;
   SIGNAL cram_rslew	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rtx_lst	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rtx_vtt	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rtx_term_sel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 5 for Channel 0
   SIGNAL cram_reserved_1_TB32	: STD_LOGIC_VECTOR(10 DOWNTO 0);
   SIGNAL cram_rtx_ob_pdb	: STD_LOGIC;
   SIGNAL cram_reserved_0_TB32	: STD_LOGIC;
   SIGNAL cram_r_dft_sel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 6 for Channel 0
   SIGNAL cram_reserved_0_TB33	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rtx_cgb_pdb	: STD_LOGIC;
   SIGNAL cram_rpclksel	: STD_LOGIC;
   SIGNAL cram_rdynamic_sw	: STD_LOGIC;
   SIGNAL cram_rs_lpbk	: STD_LOGIC;
   SIGNAL cram_rcgb_delay_sel	: STD_LOGIC;
   SIGNAL cram_rpmadwidth_tx	: STD_LOGIC;
   SIGNAL cram_rpma_doublewidth_tx	: STD_LOGIC;
   SIGNAL cram_rcgb_m_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rcgb_cmu_sel	: STD_LOGIC;
   SIGNAL cram_rcgb_x_en	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 7 for Channel 0
   SIGNAL cram_reserved_1_TB34	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_rpcs_sd_sel	: STD_LOGIC;
   SIGNAL cram_rrx_refclk	: STD_LOGIC;
   SIGNAL cram_rimpctrl	: STD_LOGIC;
   SIGNAL cram_reserved_0_TB34	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rrevlb_sw	: STD_LOGIC;
   SIGNAL cram_rvcobypass	: STD_LOGIC;
   SIGNAL cram_rrefclk_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_riqclk_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   -- PMA Per Channel TX Control Register 8 for Channel 0
   SIGNAL cram_rpma_reserved_0_TB35	: STD_LOGIC_VECTOR(15 DOWNTO 0); 
   
   -- Extra
   SIGNAL cram_ht_sel : STD_LOGIC;
   
   SIGNAL dpriodisable_in           : STD_LOGIC;
   
   -- SW logical index ------------------------------------------
   SIGNAL dprioin_clkin_sel	: STD_LOGIC_VECTOR(2 DOWNTO 0) := "000";
   SIGNAL init_clkin_sel	    : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000";
   SIGNAL cram_clkin_sel	    : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000";
      
BEGIN
      ------------------------
      --  Wire Delay Block --
      ------------------------
      WireDelay : BLOCK
      BEGIN
       bits_datain : FOR i in datain'RANGE GENERATE
           VitalWireDelay (datain_ipd(i),datain(i), tipd_datain(i));
       END GENERATE;
       bits_datainfull : FOR i in datainfull'RANGE GENERATE
           VitalWireDelay (datainfull_ipd(i),datainfull(i), tipd_datainfull(i));
       END GENERATE;
           VitalWireDelay (refclk0inpulse_ipd,refclk0inpulse, tipd_refclk0inpulse);
           VitalWireDelay (forceelecidle_ipd,forceelecidle, tipd_forceelecidle);
       bits_pclk : FOR i in pclk'RANGE GENERATE
           VitalWireDelay (pclk_ipd(i),pclk(i), tipd_pclk(i));
       END GENERATE;
       bits_fastrefclk4in : FOR i in fastrefclk4in'RANGE GENERATE
           VitalWireDelay (fastrefclk4in_ipd(i),fastrefclk4in(i), tipd_fastrefclk4in(i));
       END GENERATE;
       bits_refclk0in : FOR i in refclk0in'RANGE GENERATE
           VitalWireDelay (refclk0in_ipd(i),refclk0in(i), tipd_refclk0in(i));
       END GENERATE;
       bits_refclk1in : FOR i in refclk1in'RANGE GENERATE
           VitalWireDelay (refclk1in_ipd(i),refclk1in(i), tipd_refclk1in(i));
       END GENERATE;
           VitalWireDelay (dpriodisable_ipd,dpriodisable, tipd_dpriodisable);
       bits_refclk4in : FOR i in refclk4in'RANGE GENERATE
           VitalWireDelay (refclk4in_ipd(i),refclk4in(i), tipd_refclk4in(i));
       END GENERATE;
           VitalWireDelay (refclk4inpulse_ipd,refclk4inpulse, tipd_refclk4inpulse);
           VitalWireDelay (rxdetecten_ipd,rxdetecten, tipd_rxdetecten);
       bits_fastrefclk3in : FOR i in fastrefclk3in'RANGE GENERATE
           VitalWireDelay (fastrefclk3in_ipd(i),fastrefclk3in(i), tipd_fastrefclk3in(i));
       END GENERATE;
           VitalWireDelay (refclk1inpulse_ipd,refclk1inpulse, tipd_refclk1inpulse);
       bits_fastrefclk0in : FOR i in fastrefclk0in'RANGE GENERATE
           VitalWireDelay (fastrefclk0in_ipd(i),fastrefclk0in(i), tipd_fastrefclk0in(i));
       END GENERATE;
           VitalWireDelay (txpmareset_ipd,txpmareset, tipd_txpmareset);
           VitalWireDelay (revserialfdbk_ipd,revserialfdbk, tipd_revserialfdbk);
       bits_refclk3in : FOR i in refclk3in'RANGE GENERATE
           VitalWireDelay (refclk3in_ipd(i),refclk3in(i), tipd_refclk3in(i));
       END GENERATE;
           VitalWireDelay (powerdn_ipd,powerdn, tipd_powerdn);
       bits_fastrefclk2in : FOR i in fastrefclk2in'RANGE GENERATE
           VitalWireDelay (fastrefclk2in_ipd(i),fastrefclk2in(i), tipd_fastrefclk2in(i));
       END GENERATE;
           VitalWireDelay (detectrxpowerdown_ipd,detectrxpowerdown, tipd_detectrxpowerdown);
           VitalWireDelay (refclk3inpulse_ipd,refclk3inpulse, tipd_refclk3inpulse);
       bits_refclk2in : FOR i in refclk2in'RANGE GENERATE
           VitalWireDelay (refclk2in_ipd(i),refclk2in(i), tipd_refclk2in(i));
       END GENERATE;
           VitalWireDelay (refclk2inpulse_ipd,refclk2inpulse, tipd_refclk2inpulse);
       bits_fastrefclk1in : FOR i in fastrefclk1in'RANGE GENERATE
           VitalWireDelay (fastrefclk1in_ipd(i),fastrefclk1in(i), tipd_fastrefclk1in(i));
       END GENERATE;
           VitalWireDelay (rxdetectclk_ipd,rxdetectclk, tipd_rxdetectclk);
       bits_dprioin : FOR i in dprioin'RANGE GENERATE
           VitalWireDelay (dprioin_ipd(i),dprioin(i), tipd_dprioin(i));
       END GENERATE;
      END BLOCK;
   
    -- new DPRIO model begin --
         -- ---------------------------------------------------------------------------
         -- Set DPRIO CRAM input from dprioin  
         -- ---------------------------------------------------------------------------
         
         -- PMA Per Channel TX Control Register 1 for Channel 0
         dprioin_rpowdnt	<= dprioin(rpowdnt_TXPMA_IDX_0);
         dprioin_rvod_seld	<= dprioin(rvod_seld_TXPMA_IDX_2 DOWNTO rvod_seld_TXPMA_IDX_0);
         dprioin_rvod_selc	<= dprioin(rvod_selc_TXPMA_IDX_2 DOWNTO rvod_selc_TXPMA_IDX_0);
         dprioin_rvod_selb	<= dprioin(rvod_selb_TXPMA_IDX_2 DOWNTO rvod_selb_TXPMA_IDX_0);
         dprioin_rvod_sela	<= dprioin(rvod_sela_TXPMA_IDX_2 DOWNTO rvod_sela_TXPMA_IDX_0);
         dprioin_rvod_sel_non_pcie	<= dprioin(rvod_sel_non_pcie_TXPMA_IDX_2 DOWNTO rvod_sel_non_pcie_TXPMA_IDX_0);
         
         -- PMA Per Channel TX Control Register 2 for Channel 0
         dprioin_reserved_0_TB29	<= dprioin(reserved_0_TB29_TXPMA_IDX_0);
         dprioin_rpre_em_1t_b	<= dprioin(rpre_em_1t_b_TXPMA_IDX_4 DOWNTO rpre_em_1t_b_TXPMA_IDX_0);
         dprioin_rpre_em_1t_a	<= dprioin(rpre_em_1t_a_TXPMA_IDX_4 DOWNTO rpre_em_1t_a_TXPMA_IDX_0);
         dprioin_rpre_em_1t_no_pcie	<= dprioin(rpre_em_1t_no_pcie_TXPMA_IDX_4 DOWNTO rpre_em_1t_no_pcie_TXPMA_IDX_0);
         
         -- PMA Per Channel TX Control Register 3 for Channel 0
         dprioin_rpre_em_pt	<= dprioin(rpre_em_pt_TXPMA_IDX_3 DOWNTO rpre_em_pt_TXPMA_IDX_0);
         dprioin_rpre_em_2t	<= dprioin(rpre_em_2t_TXPMA_IDX_3 DOWNTO rpre_em_2t_TXPMA_IDX_0);
         dprioin_rpre_em_1t_c	<= dprioin(rpre_em_1t_c_TXPMA_IDX_4 DOWNTO rpre_em_1t_c_TXPMA_IDX_0);
         dprioin_reserved_0_TB30	<= dprioin(reserved_0_TB30_TXPMA_IDX_2 DOWNTO reserved_0_TB30_TXPMA_IDX_0);
         
         -- PMA Per Channel TX Control Register 4 for Channel 0
         dprioin_rlowv	<= dprioin(rlowv_TXPMA_IDX_0);
         dprioin_rrx_det	<= dprioin(rrx_det_TXPMA_IDX_1 DOWNTO rrx_det_TXPMA_IDX_0);
         dprioin_rsig_inv_2t	<= dprioin(rsig_inv_2t_TXPMA_IDX_0);
         dprioin_rsig_inv_ptap	<= dprioin(rsig_inv_ptap_TXPMA_IDX_0);
         dprioin_rslew	<= dprioin(rslew_TXPMA_IDX_1 DOWNTO rslew_TXPMA_IDX_0);
         dprioin_rtx_lst	<= dprioin(rtx_lst_TXPMA_IDX_3 DOWNTO rtx_lst_TXPMA_IDX_0);
         dprioin_rtx_vtt	<= dprioin(rtx_vtt_TXPMA_IDX_1 DOWNTO rtx_vtt_TXPMA_IDX_0);
         dprioin_rtx_term_sel	<= dprioin(rtx_term_sel_TXPMA_IDX_2 DOWNTO rtx_term_sel_TXPMA_IDX_0);
         
         -- PMA Per Channel TX Control Register 5 for Channel 0
         dprioin_reserved_1_TB32	<= dprioin(reserved_1_TB32_TXPMA_IDX_10 DOWNTO reserved_1_TB32_TXPMA_IDX_0);
         dprioin_rtx_ob_pdb	<= dprioin(rtx_ob_pdb_TXPMA_IDX_0);
         dprioin_reserved_0_TB32	<= dprioin(reserved_0_TB32_TXPMA_IDX_0);
         dprioin_r_dft_sel	<= dprioin(r_dft_sel_TXPMA_IDX_2 DOWNTO r_dft_sel_TXPMA_IDX_0);
         
         -- PMA Per Channel TX Control Register 6 for Channel 0
         dprioin_reserved_0_TB33	<= dprioin(reserved_0_TB33_TXPMA_IDX_3 DOWNTO reserved_0_TB33_TXPMA_IDX_0);
         dprioin_rtx_cgb_pdb	<= dprioin(rtx_cgb_pdb_TXPMA_IDX_0);
         dprioin_rpclksel	<= dprioin(rpclksel_TXPMA_IDX_0);
         dprioin_rdynamic_sw	<= dprioin(rdynamic_sw_TXPMA_IDX_0);
         dprioin_rs_lpbk	<= dprioin(rs_lpbk_TXPMA_IDX_0);
         dprioin_rcgb_delay_sel	<= dprioin(rcgb_delay_sel_TXPMA_IDX_0);
         dprioin_rpmadwidth_tx	<= dprioin(rpmadwidth_tx_TXPMA_IDX_0);
         dprioin_rpma_doublewidth_tx	<= dprioin(rpma_doublewidth_tx_TXPMA_IDX_0);
         dprioin_rcgb_m_sel	<= dprioin(rcgb_m_sel_TXPMA_IDX_1 DOWNTO rcgb_m_sel_TXPMA_IDX_0);
         dprioin_rcgb_cmu_sel	<= dprioin(rcgb_cmu_sel_TXPMA_IDX_0);
         dprioin_rcgb_x_en	<= dprioin(rcgb_x_en_TXPMA_IDX_1 DOWNTO rcgb_x_en_TXPMA_IDX_0);
         
         -- PMA Per Channel TX Control Register 7 for Channel 0
         dprioin_reserved_1_TB34	<= dprioin(reserved_1_TB34_TXPMA_IDX_2 DOWNTO reserved_1_TB34_TXPMA_IDX_0);
         dprioin_rpcs_sd_sel	<= dprioin(rpcs_sd_sel_TXPMA_IDX_0);
         dprioin_rrx_refclk	<= dprioin(rrx_refclk_TXPMA_IDX_0);
         dprioin_rimpctrl	<= dprioin(rimpctrl_TXPMA_IDX_0);
         dprioin_reserved_0_TB34	<= dprioin(reserved_0_TB34_TXPMA_IDX_3 DOWNTO reserved_0_TB34_TXPMA_IDX_0);
         dprioin_rrevlb_sw	<= dprioin(rrevlb_sw_TXPMA_IDX_0);
         dprioin_rvcobypass	<= dprioin(rvcobypass_TXPMA_IDX_0);
         dprioin_rrefclk_sel	<= dprioin(rrefclk_sel_TXPMA_IDX_1 DOWNTO rrefclk_sel_TXPMA_IDX_0);
         dprioin_riqclk_sel	<= dprioin(riqclk_sel_TXPMA_IDX_1 DOWNTO riqclk_sel_TXPMA_IDX_0);
         
         -- PMA Per Channel TX Control Register 8 for Channel 0
         dprioin_rpma_reserved_0_TB35	<= dprioin(rpma_reserved_0_TB35_TXPMA_IDX_15 DOWNTO rpma_reserved_0_TB35_TXPMA_IDX_0);
         
         -- Extra
	 dprioin_ht_sel	<= dprioin(ht_sel_TX_PMA_IDX);
         
         -- ---------------------------------------------------------------------------
         -- Set DPRIO output from initial CRAM
         -- ---------------------------------------------------------------------------
         
         -- PMA Per Channel TX Control Register 1 for Channel 0
         dprioout(rpowdnt_TXPMA_IDX_0) <= init_rpowdnt;
         dprioout(rvod_seld_TXPMA_IDX_2 DOWNTO rvod_seld_TXPMA_IDX_0) <= init_rvod_seld;
         dprioout(rvod_selc_TXPMA_IDX_2 DOWNTO rvod_selc_TXPMA_IDX_0) <= init_rvod_selc;
         dprioout(rvod_selb_TXPMA_IDX_2 DOWNTO rvod_selb_TXPMA_IDX_0) <= init_rvod_selb;
         dprioout(rvod_sela_TXPMA_IDX_2 DOWNTO rvod_sela_TXPMA_IDX_0) <= init_rvod_sela;
         dprioout(rvod_sel_non_pcie_TXPMA_IDX_2 DOWNTO rvod_sel_non_pcie_TXPMA_IDX_0) <= init_rvod_sel_non_pcie;
         
         -- PMA Per Channel TX Control Register 2 for Channel 0
         dprioout(reserved_0_TB29_TXPMA_IDX_0) <= init_reserved_0_TB29;
         dprioout(rpre_em_1t_b_TXPMA_IDX_4 DOWNTO rpre_em_1t_b_TXPMA_IDX_0) <= init_rpre_em_1t_b;
         dprioout(rpre_em_1t_a_TXPMA_IDX_4 DOWNTO rpre_em_1t_a_TXPMA_IDX_0) <= init_rpre_em_1t_a;
         dprioout(rpre_em_1t_no_pcie_TXPMA_IDX_4 DOWNTO rpre_em_1t_no_pcie_TXPMA_IDX_0) <= init_rpre_em_1t_no_pcie;
         
         -- PMA Per Channel TX Control Register 3 for Channel 0
         dprioout(rpre_em_pt_TXPMA_IDX_3 DOWNTO rpre_em_pt_TXPMA_IDX_0) <= init_rpre_em_pt;
         dprioout(rpre_em_2t_TXPMA_IDX_3 DOWNTO rpre_em_2t_TXPMA_IDX_0) <= init_rpre_em_2t;
         dprioout(rpre_em_1t_c_TXPMA_IDX_4 DOWNTO rpre_em_1t_c_TXPMA_IDX_0) <= init_rpre_em_1t_c;
         dprioout(reserved_0_TB30_TXPMA_IDX_2 DOWNTO reserved_0_TB30_TXPMA_IDX_0) <= init_reserved_0_TB30;
         
         -- PMA Per Channel TX Control Register 4 for Channel 0
         dprioout(rlowv_TXPMA_IDX_0) <= init_rlowv;
         dprioout(rrx_det_TXPMA_IDX_1 DOWNTO rrx_det_TXPMA_IDX_0) <= init_rrx_det;
         dprioout(rsig_inv_2t_TXPMA_IDX_0) <= init_rsig_inv_2t;
         dprioout(rsig_inv_ptap_TXPMA_IDX_0) <= init_rsig_inv_ptap;
         dprioout(rslew_TXPMA_IDX_1 DOWNTO rslew_TXPMA_IDX_0) <= init_rslew;
         dprioout(rtx_lst_TXPMA_IDX_3 DOWNTO rtx_lst_TXPMA_IDX_0) <= init_rtx_lst;
         dprioout(rtx_vtt_TXPMA_IDX_1 DOWNTO rtx_vtt_TXPMA_IDX_0) <= init_rtx_vtt;
         dprioout(rtx_term_sel_TXPMA_IDX_2 DOWNTO rtx_term_sel_TXPMA_IDX_0) <= init_rtx_term_sel;
         
         -- PMA Per Channel TX Control Register 5 for Channel 0
         dprioout(reserved_1_TB32_TXPMA_IDX_10 DOWNTO reserved_1_TB32_TXPMA_IDX_0) <= init_reserved_1_TB32;
         dprioout(rtx_ob_pdb_TXPMA_IDX_0) <= init_rtx_ob_pdb;
         dprioout(reserved_0_TB32_TXPMA_IDX_0) <= init_reserved_0_TB32;
         dprioout(r_dft_sel_TXPMA_IDX_2 DOWNTO r_dft_sel_TXPMA_IDX_0) <= init_r_dft_sel;
         
         -- PMA Per Channel TX Control Register 6 for Channel 0
         dprioout(reserved_0_TB33_TXPMA_IDX_3 DOWNTO reserved_0_TB33_TXPMA_IDX_0) <= init_reserved_0_TB33;
         dprioout(rtx_cgb_pdb_TXPMA_IDX_0) <= init_rtx_cgb_pdb;
         dprioout(rpclksel_TXPMA_IDX_0) <= init_rpclksel;
         dprioout(rdynamic_sw_TXPMA_IDX_0) <= init_rdynamic_sw;
         dprioout(rs_lpbk_TXPMA_IDX_0) <= init_rs_lpbk;
         dprioout(rcgb_delay_sel_TXPMA_IDX_0) <= init_rcgb_delay_sel;
         dprioout(rpmadwidth_tx_TXPMA_IDX_0) <= init_rpmadwidth_tx;
         dprioout(rpma_doublewidth_tx_TXPMA_IDX_0) <= init_rpma_doublewidth_tx;
         dprioout(rcgb_m_sel_TXPMA_IDX_1 DOWNTO rcgb_m_sel_TXPMA_IDX_0) <= init_rcgb_m_sel;
         dprioout(rcgb_cmu_sel_TXPMA_IDX_0) <= init_rcgb_cmu_sel;
         dprioout(rcgb_x_en_TXPMA_IDX_1 DOWNTO rcgb_x_en_TXPMA_IDX_0) <= init_rcgb_x_en;
         
         -- PMA Per Channel TX Control Register 7 for Channel 0
         dprioout(reserved_1_TB34_TXPMA_IDX_2 DOWNTO reserved_1_TB34_TXPMA_IDX_0) <= init_reserved_1_TB34;
         dprioout(rpcs_sd_sel_TXPMA_IDX_0) <= init_rpcs_sd_sel;
         dprioout(rrx_refclk_TXPMA_IDX_0) <= init_rrx_refclk;
         dprioout(rimpctrl_TXPMA_IDX_0) <= init_rimpctrl;
         dprioout(reserved_0_TB34_TXPMA_IDX_3 DOWNTO reserved_0_TB34_TXPMA_IDX_0) <= init_reserved_0_TB34;
         dprioout(rrevlb_sw_TXPMA_IDX_0) <= init_rrevlb_sw;
         dprioout(rvcobypass_TXPMA_IDX_0) <= init_rvcobypass;
         dprioout(rrefclk_sel_TXPMA_IDX_1 DOWNTO rrefclk_sel_TXPMA_IDX_0) <= init_rrefclk_sel;
         dprioout(riqclk_sel_TXPMA_IDX_1 DOWNTO riqclk_sel_TXPMA_IDX_0) <= init_riqclk_sel;
         
         -- PMA Per Channel TX Control Register 8 for Channel 0
         dprioout(rpma_reserved_0_TB35_TXPMA_IDX_15 DOWNTO rpma_reserved_0_TB35_TXPMA_IDX_0) <= init_rpma_reserved_0_TB35;
         
         -- Extra
	 dprioout(ht_sel_TX_PMA_IDX) <= init_ht_sel;
         
         -- ---------------------------------------------------------------------------
         -- Set DPRIO CRAM
         -- ---------------------------------------------------------------------------
         dpriodisable_in <= '0' WHEN (dpriodisable = '0') ELSE '1';

         -- PMA Per Channel TX Control Register 1 for Channel 0
         cram_rpowdnt <= init_rpowdnt WHEN (dpriodisable_in /= '0') ELSE dprioin_rpowdnt;
         cram_rvod_seld <= init_rvod_seld WHEN (dpriodisable_in /= '0') ELSE dprioin_rvod_seld;
         cram_rvod_selc <= init_rvod_selc WHEN (dpriodisable_in /= '0') ELSE dprioin_rvod_selc;
         cram_rvod_selb <= init_rvod_selb WHEN (dpriodisable_in /= '0') ELSE dprioin_rvod_selb;
         cram_rvod_sela <= init_rvod_sela WHEN (dpriodisable_in /= '0') ELSE dprioin_rvod_sela;
         cram_rvod_sel_non_pcie <= init_rvod_sel_non_pcie WHEN (dpriodisable_in /= '0') ELSE dprioin_rvod_sel_non_pcie;
         
         -- PMA Per Channel TX Control Register 2 for Channel 0
         cram_reserved_0_TB29 <= init_reserved_0_TB29 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB29;
         cram_rpre_em_1t_b <= init_rpre_em_1t_b WHEN (dpriodisable_in /= '0') ELSE dprioin_rpre_em_1t_b;
         cram_rpre_em_1t_a <= init_rpre_em_1t_a WHEN (dpriodisable_in /= '0') ELSE dprioin_rpre_em_1t_a;
         cram_rpre_em_1t_no_pcie <= init_rpre_em_1t_no_pcie WHEN (dpriodisable_in /= '0') ELSE dprioin_rpre_em_1t_no_pcie;
         
         -- PMA Per Channel TX Control Register 3 for Channel 0
         cram_rpre_em_pt <= init_rpre_em_pt WHEN (dpriodisable_in /= '0') ELSE dprioin_rpre_em_pt;
         cram_rpre_em_2t <= init_rpre_em_2t WHEN (dpriodisable_in /= '0') ELSE dprioin_rpre_em_2t;
         cram_rpre_em_1t_c <= init_rpre_em_1t_c WHEN (dpriodisable_in /= '0') ELSE dprioin_rpre_em_1t_c;
         cram_reserved_0_TB30 <= init_reserved_0_TB30 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB30;
         
         -- PMA Per Channel TX Control Register 4 for Channel 0
         cram_rlowv <= init_rlowv WHEN (dpriodisable_in /= '0') ELSE dprioin_rlowv;
         cram_rrx_det <= init_rrx_det WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_det;
         cram_rsig_inv_2t <= init_rsig_inv_2t WHEN (dpriodisable_in /= '0') ELSE dprioin_rsig_inv_2t;
         cram_rsig_inv_ptap <= init_rsig_inv_ptap WHEN (dpriodisable_in /= '0') ELSE dprioin_rsig_inv_ptap;
         cram_rslew <= init_rslew WHEN (dpriodisable_in /= '0') ELSE dprioin_rslew;
         cram_rtx_lst <= init_rtx_lst WHEN (dpriodisable_in /= '0') ELSE dprioin_rtx_lst;
         cram_rtx_vtt <= init_rtx_vtt WHEN (dpriodisable_in /= '0') ELSE dprioin_rtx_vtt;
         cram_rtx_term_sel <= init_rtx_term_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rtx_term_sel;
         
         -- PMA Per Channel TX Control Register 5 for Channel 0
         cram_reserved_1_TB32 <= init_reserved_1_TB32 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_1_TB32;
         cram_rtx_ob_pdb <= init_rtx_ob_pdb WHEN (dpriodisable_in /= '0') ELSE dprioin_rtx_ob_pdb;
         cram_reserved_0_TB32 <= init_reserved_0_TB32 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB32;
         cram_r_dft_sel <= init_r_dft_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_r_dft_sel;
         
         -- PMA Per Channel TX Control Register 6 for Channel 0
         cram_reserved_0_TB33 <= init_reserved_0_TB33 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB33;
         cram_rtx_cgb_pdb <= init_rtx_cgb_pdb WHEN (dpriodisable_in /= '0') ELSE dprioin_rtx_cgb_pdb;
         cram_rpclksel <= init_rpclksel WHEN (dpriodisable_in /= '0') ELSE dprioin_rpclksel;
         cram_rdynamic_sw <= init_rdynamic_sw WHEN (dpriodisable_in /= '0') ELSE dprioin_rdynamic_sw;
         cram_rs_lpbk <= init_rs_lpbk WHEN (dpriodisable_in /= '0') ELSE dprioin_rs_lpbk;
--         cram_rcgb_delay_sel <= init_rcgb_delay_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rcgb_delay_sel;
         cram_rcgb_delay_sel <= '0';
         cram_rpmadwidth_tx <= init_rpmadwidth_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rpmadwidth_tx;
         cram_rpma_doublewidth_tx <= init_rpma_doublewidth_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rpma_doublewidth_tx;
         cram_rcgb_m_sel <= init_rcgb_m_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rcgb_m_sel;
         cram_rcgb_cmu_sel <= init_rcgb_cmu_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rcgb_cmu_sel;
         cram_rcgb_x_en <= init_rcgb_x_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rcgb_x_en;
         
         -- PMA Per Channel TX Control Register 7 for Channel 0
         cram_reserved_1_TB34 <= init_reserved_1_TB34 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_1_TB34;
         cram_rpcs_sd_sel <= init_rpcs_sd_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rpcs_sd_sel;
         cram_rrx_refclk <= init_rrx_refclk WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_refclk;
         cram_rimpctrl <= init_rimpctrl WHEN (dpriodisable_in /= '0') ELSE dprioin_rimpctrl;
         cram_reserved_0_TB34 <= init_reserved_0_TB34 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB34;
         cram_rrevlb_sw <= init_rrevlb_sw WHEN (dpriodisable_in /= '0') ELSE dprioin_rrevlb_sw;
         cram_rvcobypass <= init_rvcobypass WHEN (dpriodisable_in /= '0') ELSE dprioin_rvcobypass;
         cram_rrefclk_sel <= init_rrefclk_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rrefclk_sel;
         cram_riqclk_sel <= init_riqclk_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_riqclk_sel;
         
         -- PMA Per Channel TX Control Register 8 for Channel 0
         cram_rpma_reserved_0_TB35 <= init_rpma_reserved_0_TB35 WHEN (dpriodisable_in /= '0') ELSE dprioin_rpma_reserved_0_TB35;
         
         -- Extra
	    cram_ht_sel <= init_ht_sel;	-- SPR 288513
  
	    	    -- SW logical index --
   	    dprioin_clkin_sel <= dprioin(CLKIN_SELECT_TXPMA_IDX_2 DOWNTO CLKIN_SELECT_TXPMA_IDX_0);
        cram_clkin_sel    <= init_clkin_sel WHEN (dpriodisable /= '0') ELSE dprioin_clkin_sel;
        dprioout(CLKIN_SELECT_TXPMA_IDX_2 DOWNTO CLKIN_SELECT_TXPMA_IDX_0) <= init_clkin_sel;
       
   PROCESS 
   BEGIN
           -- map to parameter name
      	   -- TX PMA control register 1
             init_rpowdnt           <= '0';
             init_rvod_sel_non_pcie <= mux_select((vod_selection = 0), "000", mux_select((vod_selection = 1), "001", mux_select((vod_selection = 2), "010", mux_select((vod_selection = 3), "110", mux_select((vod_selection = 4), "011", mux_select((vod_selection = 5), "111", mux_select((vod_selection = 6), "100", mux_select((vod_selection = 7), "101", "000"))))))));
             init_rvod_seld         <= int2bin(vod_selection_d, 3);
             init_rvod_selc         <= int2bin(vod_selection_c, 3);
             init_rvod_selb         <= int2bin(vod_selection_b, 3);
             init_rvod_sela         <= int2bin(vod_selection_a, 3);
             
             -- TX PMA control register 2
             init_rpre_em_1t_b		<= int2bin(preemp_tap_1_b, 5);
             init_rpre_em_1t_a		<= int2bin(preemp_tap_1_a, 5);
             init_rpre_em_1t_no_pcie	<= int2bin(preemp_tap_1, 5);
             
             -- TX PMA control register 3
             init_rpre_em_pt	<= int2bin(preemp_pretap, 4);
             init_rpre_em_2t	<= int2bin(preemp_tap_2, 4);
             init_rpre_em_1t_c	<= int2bin(preemp_tap_1_c, 5);
             
             -- TX PMA control register 4
             init_rlowv			<= '0';
             init_rrx_det		<= int2bin(rx_detect, 2);
             init_rsig_inv_2t	<= mux_select((preemp_tap_2_inv = ("true")), '1', '0');
             init_rsig_inv_ptap <= mux_select((preemp_pretap_inv = ("true")), '1', '0');
             init_rslew			<= (mux_select((slew_rate = ("low")), "01", mux_select((slew_rate = ("medium")), "10", mux_select((slew_rate = ("high")), "11", "00"))));
             init_rtx_lst		<= int2bin(low_speed_test_select, 4);
             init_rtx_vtt		<= mux_select((alpha_tolower(common_mode) = ("tristate")), "00", mux_select((alpha_tolower(common_mode) = ("0.6v")), "01", mux_select((alpha_tolower(common_mode) = ("0.7v")), "10", "11")));
             init_rtx_term_sel	<= (mux_select((alpha_tolower(termination) = ("off")), "000", mux_select((alpha_tolower(termination) = ("oct 85 ohms") OR alpha_tolower(termination) = ("85_ohms")), "111", mux_select((alpha_tolower(termination) = ("100_ohms") OR alpha_tolower(termination) = ("oct 100 ohms")), "110", mux_select((alpha_tolower(termination) = ("oct 120 ohms") OR alpha_tolower(termination) = ("120_ohms")), "101", "100")))));
             
             -- TX PMA Control Register 6
	     init_rpma_doublewidth_tx 	<= (mux_select((serialization_factor = 16 OR serialization_factor = 20), '1', '0'));   	--init_rpma_doublewidth_tx = rser_div2_init;
	     init_rpmadwidth_tx 	<= (mux_select((serialization_factor = 10 OR serialization_factor = 20), '1', '0'));	--init_rpmadwidth_tx 	   = rser_div5_init;
	     init_rcgb_delay_sel	<= mux_select((clkmux_delay = ("true")), '1', '0');
 	     init_rcgb_x_en 		<= int2bin(clkin_select, 2);
	     init_rpclksel 		<= mux_select((use_pclk = ("true")), '1', '0');
	     init_rs_lpbk 		<= mux_select((enable_reverse_serial_loopback = ("true")), '1', '0');   
	     
	     -- Extra
    	 init_ht_sel 		<= mux_select((clkin_select > 3), '1', '0');  
    	 
    	 -- SW logic index
    	 init_clkin_sel  	<= int2bin(clkin_select, 3);
             
      WAIT;
   END PROCESS;       
      -- new DPRIO model end --
      ------------------------
      --  Functionality Section --
      ------------------------
   PROCESS 
   BEGIN
      ht_sel_init <= mux_select((clkin_select > 3), '1', '0');
      rcgb_delay_sel_init <= mux_select((clkmux_delay = ("true")), '1', '0');
      rcgb_x_en_init <= int2bin(clkin_select, 2);
      rpmphs_1tap_init <= int2bin(preemp_tap_1, 5);
      rpmphs_2tap_init <= int2bin(preemp_tap_2, 4);
      rpmphs_ptap_init <= int2bin(preemp_pretap, 4);
      r_rx_det_init <= int2bin(rx_detect, 2);
      rser_div2_init <= (mux_select((serialization_factor = 16 OR serialization_factor = 20), '1', '0'));
      rser_div5_init <= (mux_select((serialization_factor = 10 OR serialization_factor = 20), '1', '0'));
      rsig_inv_2t_init <= mux_select((preemp_tap_2_inv = ("true")), '1', '0');
      rsig_inv_ptap_init <= mux_select((preemp_pretap_inv = ("true")), '1', '0');
      rslew_init <= (mux_select((slew_rate = ("low")), "01", mux_select((slew_rate = ("medium")), "10", mux_select((slew_rate = ("high")), "11", "00"))));
      rtx_lst_init <= int2bin(low_speed_test_select, 4);
      rtx_rlpbk_init <= mux_select((enable_reverse_serial_loopback = ("true")), '1', '0');
      rtx_term_sel_init <= (mux_select((termination = ("off")), "000", mux_select((termination = ("OCT 85 Ohms")), "111", mux_select((termination = ("100_ohms")), "110", mux_select((termination = ("OCT 120 Ohms")), "101", "100")))));
      rtx_vtt_init <= mux_select((common_mode = ("tristate")), "00", mux_select((common_mode = ("0.6V")), "01", mux_select((common_mode = ("0.7V")), "10", "11")));
      rpclksel_init <= mux_select((use_pclk = ("true")), '1', '0');
      WAIT;
   END PROCESS;
   
   vccelxqyx <= '1';
   vccetxqyx <= '0';
   vssexqyx <= '0';
   xtxclkmux_cpulse_ht <= refclk4inpulse;
   xtxclkmux_cpulse_x1 <= refclk0inpulse;
   xtxclkmux_cpulse_x4 <= refclk1inpulse;
   xtxclkmux_cpulse_x8_b <= refclk3inpulse;
   xtxclkmux_cpulse_x8_t <= refclk2inpulse;
   xtxclkmux_hfclkp_x1 <= fastrefclk0in(0);
   xtxclkmux_hfclkp_x4 <= fastrefclk1in(0);
   xtxclkmux_hfclkp_x8_b <= fastrefclk3in(0);
   xtxclkmux_hfclkp_x8_t <= fastrefclk2in(0);
   xtxclkmux_hfclkp_ht <= fastrefclk4in(0);
   xtxclkmux_hfclkn_x1 <= fastrefclk0in(1);
   xtxclkmux_hfclkn_x4 <= fastrefclk1in(1);
   xtxclkmux_hfclkn_x8_b <= fastrefclk3in(1);
   xtxclkmux_hfclkn_x8_t <= fastrefclk2in(1);
   xtxclkmux_hfclkn_ht <= fastrefclk4in(1);
   xtxclkmux_ht_sel <= cram_ht_sel WHEN (serialization_factor <= 20) ELSE
                       '0';
   xtxclkmux_lfclkp_x1 <= refclk0in(0);
   xtxclkmux_lfclkp_x4 <= refclk1in(0);
   xtxclkmux_lfclkp_x8_b <= refclk3in(0);
   xtxclkmux_lfclkp_x8_t <= refclk2in(0);
   xtxclkmux_lfclkp_ht <= refclk4in(0);
   xtxclkmux_lfclkn_x1 <= refclk0in(1);
   xtxclkmux_lfclkn_x4 <= refclk1in(1);
   xtxclkmux_lfclkn_x8_b <= refclk3in(1);
   xtxclkmux_lfclkn_x8_t <= refclk2in(1);
   xtxclkmux_lfclkn_ht <= refclk4in(1);
   xtxclkmux_pdb <= '0' WHEN (powerdn = '1') ELSE
                    '1';
   xtxclkmux_rdelay_sel <= cram_rcgb_delay_sel;
   xtxclkmux_rsel <= cram_clkin_sel(1 DOWNTO 0); -- shawn cram_rcgb_x_en;
   
   
   xtxclkmux : stratixiv_hssi_pma_c_tx_clkmux_cmu
      PORT MAP (
         cpulse_ht    => xtxclkmux_cpulse_ht,
         cpulse_x1    => xtxclkmux_cpulse_x1,
         cpulse_x4    => xtxclkmux_cpulse_x4,
         cpulse_xn_b  => xtxclkmux_cpulse_x8_b,
         cpulse_xn_t  => xtxclkmux_cpulse_x8_t,
         delay_sel    => xtxclkmux_rdelay_sel,
         hfclkn_ht    => xtxclkmux_hfclkn_ht,
         hfclkn_x1    => xtxclkmux_hfclkn_x1,
         hfclkn_x4    => xtxclkmux_hfclkn_x4,
         hfclkn_xn_b  => xtxclkmux_hfclkn_x8_b,
         hfclkn_xn_t  => xtxclkmux_hfclkn_x8_t,
         hfclkp_ht    => xtxclkmux_hfclkp_ht,
         hfclkp_x1    => xtxclkmux_hfclkp_x1,
         hfclkp_x4    => xtxclkmux_hfclkp_x4,
         hfclkp_xn_b  => xtxclkmux_hfclkp_x8_b,
         hfclkp_xn_t  => xtxclkmux_hfclkp_x8_t,
         ht_sel       => xtxclkmux_ht_sel,
         lfclkn_ht    => xtxclkmux_lfclkn_ht,
         lfclkn_x1    => xtxclkmux_lfclkn_x1,
         lfclkn_x4    => xtxclkmux_lfclkn_x4,
         lfclkn_xn_b  => xtxclkmux_lfclkn_x8_b,
         lfclkn_xn_t  => xtxclkmux_lfclkn_x8_t,
         lfclkp_ht    => xtxclkmux_lfclkp_ht,
         lfclkp_x1    => xtxclkmux_lfclkp_x1,
         lfclkp_x4    => xtxclkmux_lfclkp_x4,
         lfclkp_xn_b  => xtxclkmux_lfclkp_x8_b,
         lfclkp_xn_t  => xtxclkmux_lfclkp_x8_t,
         pdb          => xtxclkmux_pdb,
         sel          => xtxclkmux_rsel,
         vccelxqyx    => vccelxqyx,
         vssexqyx     => vssexqyx,
         cpulse       => xtxclkmux_cpulse,
         hfclk_n      => xtxclkmux_hfclkn,
         hfclk_p      => xtxclkmux_hfclkp,
         lfclk_n      => xtxclkmux_lfclkn,
         lfclk_p      => xtxclkmux_lfclkp
      );
   xser_data <= ("00" & datain(15 DOWNTO 8) & "00" & datain(7 DOWNTO 0)) WHEN (use_pma_direct = "true" and serialization_factor = 16) ELSE datain(19 DOWNTO 0);

   xser_data_dprio <= datainfull_ipd WHEN (((dprio_config_mode(5 DOWNTO 0) AND "000100") = "000100") AND use_pma_direct = "true") ELSE xser_data;

   xser_pdb <= '0' WHEN (powerdn = '1') ELSE
               '1';
               
   -- (clkin_select);
   xser_pclk <= pclk_ipd(0) WHEN (cram_clkin_sel = "000")  ELSE
                pclk_ipd(1) WHEN (cram_clkin_sel = "001")  ELSE
                pclk_ipd(2) WHEN (cram_clkin_sel = "010")  ELSE
                pclk_ipd(3) WHEN (cram_clkin_sel = "011")  ELSE
                pclk_ipd(4) WHEN (cram_clkin_sel = "100")  ELSE
                pclk_ipd(0);
                       
   xser_rpclksel <= cram_rpclksel;
   xser_rpre_em <= cram_rpre_em_1t_no_pcie;
   xser_rpre_em_2t <= cram_rpre_em_2t;
   xser_rpre_em_pretap <= cram_rpre_em_pt;
   xser_rdiv2 <= cram_rpma_doublewidth_tx;
   xser_rdiv5 <= cram_rpmadwidth_tx;
   xser_rs_lpbk <= '1'; -- always enabled - allow serial_loop_back
   xser_rst_n <= '0' WHEN (txpmareset = '1') ELSE
                 '1';
   xser_cpulse <= '0' WHEN (serialization_factor > 20) ELSE xtxclkmux_cpulse;
   xser_hfclkn <= '0' WHEN (serialization_factor > 20) ELSE xtxclkmux_hfclkn;
   xser_hfclkp <= '0' WHEN (serialization_factor > 20) ELSE xtxclkmux_hfclkp;
   xser_lfclkn <= '0' WHEN (serialization_factor > 20) ELSE xtxclkmux_lfclkn;
   xser_lfclkp <= '0' WHEN (serialization_factor > 20) ELSE xtxclkmux_lfclkp;
   xser_10g_data_in <= datain(63 DOWNTO 0);
   xser_10g_pdb <= '0' WHEN (powerdn = '1') ELSE
                   '1';
   xser_10g_rpre_em <= rpmphs_1tap_cram;
   xser_10g_rst_n <= '0' WHEN (txpmareset = '1') ELSE
                     '1';
   xser_10g_rs_lpbk <= '1';
   xser_10g_cpulse <= xtxclkmux_cpulse WHEN (serialization_factor > 20) ELSE '0';
   xser_10g_hfclkn <= xtxclkmux_hfclkn WHEN (serialization_factor > 20) ELSE '0';
   xser_10g_hfclkp <= xtxclkmux_hfclkp WHEN (serialization_factor > 20) ELSE '0';
   xser_10g_lfclkn <= xtxclkmux_lfclkn WHEN (serialization_factor > 20) ELSE '0';
   xser_10g_lfclkp <= xtxclkmux_lfclkp WHEN (serialization_factor > 20) ELSE '0';
   xser_10g_cpulseb <= NOT xser_10g_cpulse WHEN (serialization_factor > 20) ELSE '0';
   
   xser : stratixiv_hssi_pma_c_ser
      PORT MAP (
         cpulse         => xser_cpulse,
         data           => xser_data_dprio,
         div2           => xser_rdiv2,
         div5           => xser_rdiv5,
         hfclkn         => xser_hfclkn,
         hfclkp         => xser_hfclkp,
         lfclkn         => xser_lfclkn,
         lfclkp         => xser_lfclkp,
         pclk_in        => xser_pclk,
         pclksel        => xser_rpclksel,
         pdb            => xser_pdb,
         pre_em         => xser_rpre_em,
         pre_em_2t      => xser_rpre_em_2t,
         pre_em_pretap  => xser_rpre_em_pretap,
         rst_n          => xser_rst_n,
         s_lpbk         => xser_rs_lpbk,
         vccelxqyx      => vccelxqyx,
         vccetxqyx      => vccetxqyx,
         vssexqyx       => vssexqyx,
         clk_divtx      => xser_clk_divtx,
         lbvon          => xser_lbvon,
         lbvop          => xser_lbvop,
         pre_en_out     => xser_pre_en_out,
         von            => xser_von,
         von_op1        => xser_von_op1,
         von_op2        => xser_von_op2,
         von_pre        => xser_von_pre,
         vop            => xser_vop,
         vop_op1        => xser_vop_op1,
         vop_op2        => xser_vop_op2,
         vop_pre        => xser_vop_pre
      );
   
   
   xser_10g : stratixiv_hssi_pma_c_ser_10g
      PORT MAP (
         clk_skew   => xser_10g_clk_skew,
         cpulse     => xser_10g_cpulse,
         cpulseb    => xser_10g_cpulseb,
         data_in    => xser_10g_data_in,
         hfclkn     => xser_10g_hfclkn,
         hfclkp     => xser_10g_hfclkp,
         lfclkn     => xser_10g_lfclkn,
         lfclkp     => xser_10g_lfclkp,
         pdb        => xser_10g_pdb,
         pre_em     => xser_10g_rpre_em,
         rst_n      => xser_10g_rst_n,
         s_lpbk     => xser_10g_rs_lpbk,
         vccelxqyx  => vccelxqyx,
         vccetxqyx  => vccetxqyx,
         vssexqyx   => vssexqyx,
         clk_divtx  => xser_10g_clk_divtx,
         lbvon      => xser_10g_lbvon,
         lbvop      => xser_10g_lbvop,
         von        => xser_10g_von,
         von_op1    => xser_10g_von_op1,
         vop        => xser_10g_vop,
         vop_op1    => xser_10g_vop_op1
      );
   clockout <= xser_10g_clk_divtx WHEN (serialization_factor > 20) ELSE
               xser_clk_divtx;
   seriallpbkout <= xser_10g_lbvop WHEN (serialization_factor > 20) ELSE
                    xser_lbvop;
   PROCESS 
   BEGIN
      rx_det_clk_reg <= '0';
      WHILE (TRUE) LOOP
         WAIT FOR 4000 ps;
         rx_det_clk_reg <= NOT(rx_det_clk_reg);
      END LOOP;
      WAIT;
   END PROCESS;
   
   forceelecidle_in <= '1' WHEN (forceelecidle = '1') ELSE '0';
   
   xtx_rx_det_clk <= rx_det_clk_reg;
   xtx_cgb_vccelxqyx <= '1';
   xtx_cgb_vssexqyx <= '0';
   xtx_pdb <= '0' WHEN (powerdn = '1') ELSE
              '1';
   xtx_rlpbkp <= revserialfdbk;
   xtx_rlpbkn <= NOT(revserialfdbk);
   xtx_r_rx_det <= r_rx_det_cram;
   xtx_rpre_em_1t <= rpmphs_1tap_cram;
   xtx_rpre_em_2t <= rpmphs_2tap_cram WHEN (serialization_factor <= 20) ELSE
                     "0000";
   xtx_rpre_em_pt <= rpmphs_ptap_cram WHEN (serialization_factor <= 20) ELSE
                     "0000";
   xtx_rsig_inv_2t <= cram_rsig_inv_2t;
   xtx_rsig_inv_ptap <= cram_rsig_inv_ptap;
   xtx_rslew <= cram_rslew;
   xtx_rlst <= cram_rtx_lst;
   xtx_rtx_rlpbk <= cram_rs_lpbk;
   xtx_rterm_sel <= cram_rtx_term_sel;
   xtx_rtx_vtt <= cram_rtx_vtt;
   xtx_rvod_sel <= int2bin(vod_selection, 3);
   xtx_rx_det_pdb <= '0' WHEN (detectrxpowerdown = '1') ELSE
                     '1';
   xtx_tx_det_rx <= rxdetecten;
   xtx_tx_elec_idl <= forceelecidle_in;
   xtx_vin <= xser_von WHEN (serialization_factor <= 20) ELSE
              xser_10g_von;
   xtx_vin_op1 <= xser_von_op1 WHEN (serialization_factor <= 20) ELSE
                  xser_10g_von_op1;
   xtx_vin_op2 <= xser_von_op2;
   xtx_vin_pre <= xser_von_pre;
   xtx_vip <= xser_vop WHEN (serialization_factor <= 20) ELSE
              xser_10g_vop;
   xtx_vip_op1 <= xser_vop_op1 WHEN (serialization_factor <= 20) ELSE
                  xser_10g_vop_op1;
   xtx_vip_op2 <= xser_vop_op2;
   xtx_vip_pre <= xser_vop_pre;
   vccehtxqyx <= '0';
   vccehxqyx <= '0';
   
   
   xtx : stratixiv_hssi_pma_c_tx
      PORT MAP (
         bsmode           => xtx_bsmode,
         bstxn_in         => xtx_bstxn_in,
         bstxp_in         => xtx_bstxp_in,
         cgb_vccelxqyx    => xtx_cgb_vccelxqyx,
         cgb_vssexqyx     => xtx_cgb_vssexqyx,
         lst              => xtx_rlst,
         pdb              => xtx_pdb,
         r_dft_sel        => xtx_r_dft_sel,
         r_dis_idlegate   => xtx_r_dis_idlegate,
         r_highv          => xtx_r_highv,
         r_lowv           => xtx_r_lowv,
         r_rx_det         => xtx_r_rx_det,
         r_slew           => xtx_rslew,
         rlpbkn           => xtx_rlpbkn,
         rlpbkn_em        => xtx_rlpbkn_em,
         rlpbkp           => xtx_rlpbkp,
         rlpbkp_em        => xtx_rlpbkp_em,
         rpre_em_1t       => xtx_rpre_em_1t,
         rpre_em_2t       => xtx_rpre_em_2t,
         rpre_em_pt       => xtx_rpre_em_pt,
         rsig_inv_2t      => xtx_rsig_inv_2t,
         rsig_inv_ptap    => xtx_rsig_inv_ptap,
         rterm_sel        => xtx_rterm_sel,
         rtx_rlpbk        => xtx_rtx_rlpbk,
         rtx_vtt          => xtx_rtx_vtt,
         rvod_sel         => xtx_rvod_sel,
         rx_det_clk       => xtx_rx_det_clk,
         rx_det_pdb       => xtx_rx_det_pdb,
         rx_n             => xtx_rx_n,
         rx_p             => xtx_rx_p,
         tx50             => xtx_tx50,
         tx_det_rx        => xtx_tx_det_rx,
         tx_elec_idl      => xtx_tx_elec_idl,
         vccehtxqyx       => vccehtxqyx,
         vccehxqyx        => vccehxqyx,
         vccesdh_la       => vccetxqyx,
         vccesdp_la       => vccetxqyx,
         vccetxqyx        => vccetxqyx,
         vin              => xtx_vin,
         vin_po1          => xtx_vin_op1,
         vin_po2          => xtx_vin_op2,
         vin_pre          => xtx_vin_pre,
         vip              => xtx_vip,
         vip_po1          => xtx_vip_op1,
         vip_po2          => xtx_vip_op2,
         vip_pre          => xtx_vip_pre,
         vssexqyx         => vssexqyx,
         atb0             => xtx_atb0,
         atb1             => xtx_atb1,
         ib50uc_rcvdt     => xtx_ib50uc_rcvdt,
         ib50uc_vcm       => xtx_ib50uc,
         ib50ut_vcm       => xtx_ib50ut,
         ib100uc          => xtx_ib100uc,
         von              => xtx_von,
         vop              => xtx_vop,
         
         com_pass         => xtx_com_pass,
         detect_on        => xtx_detect_on,
         fixed_clk_out    => xtx_fixed_clk,
         probe_pass       => xtx_probe_pass,
         rx_detect_valid  => xtx_rx_detect_valid,
         rx_found         => xtx_rx_found,
         sel_150r         => xtx_sel_150r,
         tx_dftout        => xtx_tx_dftout
      );
   
   -- driver outputs
   dataout <= xtx_vop;
   dftout <= xtx_tx_dftout;
   rxdetectvalidout <= xtx_rx_detect_valid;
   rxfoundout <= xtx_rx_found;
   
END trans;



-- ---------------------------------------------------------------------------
--  Model Implementation End                                                 -
-- ---------------------------------------------------------------------------

-- ***********************************************************
-- This WYSIWYG atom header was automatically generated by the
-- Atmgen build tool. To change it, alter data stored in the 
-- corresponding WYS file(s) in the tools/atmgen subdirectory.
-- ***********************************************************

-- *** Section 1 -- Header ***

-- -----------------------------------------------------------
--
-- Module Name : stratixiv_hssi_rx_pma
--
-- Description : DEV_FAMILY_STRATIXIV stratixiv_hssi_rx_pma Verilog simulation model
--
-- -----------------------------------------------------------

-- *** End of Section 1 ***

-- *** Section 3 -- Module declaration ***


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

USE IEEE.VITAL_Timing.all;
USE IEEE.VITAL_Primitives.all;
ENTITY stratixiv_hssi_rx_pma IS
   GENERIC (

          --  generic control parameters  --
       MsgOn                   : Boolean := DefGlitchMsgOn;
       XOn                     : Boolean := DefGlitchXOn;
       MsgOnChecks             : Boolean := DefMsgOnChecks;
       XOnChecks               : Boolean := DefXOnChecks;
       InstancePath            : String := "*";
       TimingChecksOn          : Boolean := True;
          --  tipd  :interconnect path delays --
      tipd_ppmdetectdividedclk                : VitalDelayType01 := DefpropDelay01;
      tipd_datain                : VitalDelayType01 := DefpropDelay01;
      tipd_rxpmareset                : VitalDelayType01 := DefpropDelay01;
      tipd_plllocked                : VitalDelayType01 := DefpropDelay01;
      tipd_dpriodisable                : VitalDelayType01 := DefpropDelay01;
      tipd_ignorephslck                : VitalDelayType01 := DefpropDelay01;
      tipd_locktoref                : VitalDelayType01 := DefpropDelay01;
      tipd_adcepowerdn                : VitalDelayType01 := DefpropDelay01;
      tipd_ppmdetectrefclk                : VitalDelayType01 := DefpropDelay01;
      tipd_adcestandby                : VitalDelayType01 := DefpropDelay01;
      tipd_powerdn                : VitalDelayType01 := DefpropDelay01;
      tipd_seriallpbken                : VitalDelayType01 := DefpropDelay01;
      tipd_adcereset                : VitalDelayType01 := DefpropDelay01;
      tipd_deserclock               :VitalDelayArrayType01(4 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_locktodata                : VitalDelayType01 := DefpropDelay01;
      tipd_freqlock                : VitalDelayType01 := DefpropDelay01;
      tipd_offsetcancellationen                : VitalDelayType01 := DefpropDelay01;
      tipd_testbussel               :VitalDelayArrayType01(4 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_recoverdatain               :VitalDelayArrayType01(2 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_seriallpbkin                : VitalDelayType01 := DefpropDelay01;
      tipd_dprioin               :VitalDelayArrayType01(300 - 1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_adaptcapture                : VitalDelayType01 := DefpropDelay01;
          --  tpd: Edge-Sensitive Paths --
          --  tpd: parallel and Full Connection Paths --
          --  tsetup and thold values : setup and hold times  --
          --  Pulse Width parameters  --
      
      -- *** End of Section 3 ***
      
      -- *** Section 4 -- Port size declarations ***
      
      -- *** End of Section 4 ***
      
      -- *** Section 5 -- Port declarations ***
      
      lpm_type                                  : STRING := "stratixiv_hssi_rx_pma";
      adaptive_equalization_mode                : STRING := "none";
      allow_serial_loopback                     : STRING := "false";
      allow_vco_bypass                          : INTEGER := 0;
      analog_power                              : STRING := "1.4V";
      channel_number                            : INTEGER := 0;
      channel_type                              : STRING := "auto";
      common_mode                               : STRING := "0.82V";
      deserialization_factor                    : INTEGER := 8;
      dfe_piclk_bandwidth                       : INTEGER := 0;
      dfe_piclk_phase                           : INTEGER := 0;
      dfe_piclk_sel                             : INTEGER := 0;
      dprio_config_mode                         : STD_LOGIC_VECTOR(5 DOWNTO 0) := "000000";
      enable_ltd                                : STRING := "false";
      enable_ltr                                : STRING := "false";
      eq_adapt_seq_control                      : INTEGER := 0;
      eq_dc_gain                                : INTEGER := 0;
      eq_max_gradient_control                   : INTEGER := 0;
      eqa_ctrl                                  : INTEGER := 0;
      eqb_ctrl                                  : INTEGER := 0;
      eqc_ctrl                                  : INTEGER := 0;
      eqd_ctrl                                  : INTEGER := 0;
      eqv_ctrl                                  : INTEGER := 0;
      eyemon_bandwidth                          : INTEGER := 0;
      force_signal_detect                       : STRING := "true";
      ignore_lock_detect                        : STRING := "false";
      logical_channel_address                   : INTEGER := 0;
      low_speed_test_select                     : INTEGER := 0;
      offset_cancellation                       : INTEGER := 0;
      ppm_gen1_2_xcnt_en                        : INTEGER := 1;
      ppm_post_eidle                            : INTEGER := 0;
      ppmselect                                 : INTEGER := 0;
      protocol_hint                             : STRING := "basic";
      send_direct_reverse_serial_loopback       : STRING := "None";
      signal_detect_hysteresis                  : INTEGER := 4;
      signal_detect_hysteresis_valid_threshold  : INTEGER := 2;
      signal_detect_loss_threshold              : INTEGER := 3;
      termination                               : STRING := "OCT 100 Ohms";
      use_deser_double_data_width               : STRING := "false";
      use_external_termination                  : STRING := "false";
      use_pma_direct                            : STRING := "false";
      PARAM_DELAY                               : INTEGER := 0
   );
   PORT (
      adaptcapture                              : IN STD_LOGIC := '0';
      adcepowerdn                               : IN STD_LOGIC := '0';
      adcereset                                 : IN STD_LOGIC := '0';
      adcestandby                               : IN STD_LOGIC := '0';
      datain                                    : IN STD_LOGIC := '0';
      deserclock                                : IN STD_LOGIC_VECTOR(4 - 1 DOWNTO 0) := (others => '0');
      dpriodisable                              : IN STD_LOGIC := '1';
      dprioin                                   : IN STD_LOGIC_VECTOR(300 - 1 DOWNTO 0) := (others => '0');
      extra10gin                                : IN STD_LOGIC_VECTOR(38 - 1 DOWNTO 0) := (others => '0');
      freqlock                                  : IN STD_LOGIC := '0';
      ignorephslck                              : IN STD_LOGIC := '0';
      locktodata                                : IN STD_LOGIC := '0';
      locktoref                                 : IN STD_LOGIC := '0';
      offsetcancellationen                      : IN STD_LOGIC := '0';
      plllocked                                 : IN STD_LOGIC := '0';
      powerdn                                   : IN STD_LOGIC := '0';
      ppmdetectdividedclk                       : IN STD_LOGIC := '0';
      ppmdetectrefclk                           : IN STD_LOGIC := '0';
      recoverdatain                             : IN STD_LOGIC_VECTOR(2 - 1 DOWNTO 0) := (others => '0');
      rxpmareset                                : IN STD_LOGIC := '0';
      seriallpbken                              : IN STD_LOGIC := '0';
      seriallpbkin                              : IN STD_LOGIC := '0';
      testbussel                                : IN STD_LOGIC_VECTOR(4 - 1 DOWNTO 0) := (others => '0');
      adaptdone                                 : OUT STD_LOGIC;
      analogtestbus                             : OUT STD_LOGIC_VECTOR(8 - 1 DOWNTO 0);
      clockout                                  : OUT STD_LOGIC;
      dataout                                   : OUT STD_LOGIC;
      dataoutfull                               : OUT STD_LOGIC_VECTOR(20 - 1 DOWNTO 0);
      dprioout                                  : OUT STD_LOGIC_VECTOR(300 - 1 DOWNTO 0);
      locktorefout                              : OUT STD_LOGIC;
      ppmdetectclkrel                           : OUT STD_LOGIC;
      recoverdataout                            : OUT STD_LOGIC_VECTOR(64 - 1 DOWNTO 0);
      reverselpbkout                            : OUT STD_LOGIC;
      revserialfdbkout                          : OUT STD_LOGIC;
      signaldetect                              : OUT STD_LOGIC
   );
END stratixiv_hssi_rx_pma;

ARCHITECTURE trans OF stratixiv_hssi_rx_pma IS

  signal ppmdetectdividedclk_ipd  :STD_LOGIC;
  signal datain_ipd  :STD_LOGIC;
  signal rxpmareset_ipd  :STD_LOGIC;
  signal plllocked_ipd  :STD_LOGIC;
  signal dpriodisable_ipd  :STD_LOGIC;
  signal ignorephslck_ipd  :STD_LOGIC;
  signal locktoref_ipd  :STD_LOGIC;
  signal adcepowerdn_ipd  :STD_LOGIC;
  signal ppmdetectrefclk_ipd  :STD_LOGIC;
  signal adcestandby_ipd  :STD_LOGIC;
  signal powerdn_ipd  :STD_LOGIC;
  signal seriallpbken_ipd  :STD_LOGIC;
  signal adcereset_ipd  :STD_LOGIC;
  signal deserclock_ipd  :STD_LOGIC_VECTOR(4 - 1 DOWNTO 0);
  signal locktodata_ipd  :STD_LOGIC;
  signal freqlock_ipd  :STD_LOGIC;
  signal offsetcancellationen_ipd  :STD_LOGIC;
  signal testbussel_ipd  :STD_LOGIC_VECTOR(4 - 1 DOWNTO 0);
  signal recoverdatain_ipd  :STD_LOGIC_VECTOR(2 - 1 DOWNTO 0);
  signal seriallpbkin_ipd  :STD_LOGIC;
  signal dprioin_ipd  :STD_LOGIC_VECTOR(300 - 1 DOWNTO 0);
  signal adaptcapture_ipd  :STD_LOGIC;
   COMPONENT stratixiv_hssi_pma_c_rlpbk_mux
      PORT (
         doddn                                     : IN STD_LOGIC;
         doddp                                     : IN STD_LOGIC;
         dodn                                      : IN STD_LOGIC;
         dodp                                      : IN STD_LOGIC;
         don                                       : IN STD_LOGIC;
         don_pre                                   : IN STD_LOGIC;
         dop                                       : IN STD_LOGIC;
         dop_pre                                   : IN STD_LOGIC;
         drxn                                      : IN STD_LOGIC;
         drxp                                      : IN STD_LOGIC;
         sel                                       : IN STD_LOGIC;
         vcce_la                                   : IN STD_LOGIC;
         voddn                                     : OUT STD_LOGIC;
         voddp                                     : OUT STD_LOGIC;
         vodn                                      : OUT STD_LOGIC;
         vodp                                      : OUT STD_LOGIC;
         von                                       : OUT STD_LOGIC;
         von_pre                                   : OUT STD_LOGIC;
         vop                                       : OUT STD_LOGIC;
         vop_pre                                   : OUT STD_LOGIC;
         vssex                                     : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_c_deser
      GENERIC (
         PARAM_DELAY                               : INTEGER := 0;
         RST_SD_PULSE_WIDTH                        : INTEGER := 1
      );
      PORT (
         clk90b                                    : IN STD_LOGIC;
         clk_divrx                                 : OUT STD_LOGIC;
         deser_div2                                : IN STD_LOGIC;
         deser_div5                                : IN STD_LOGIC;
         deser_pdb                                 : IN STD_LOGIC;
         deven                                     : IN STD_LOGIC;
         devenb                                    : IN STD_LOGIC;
         dodd                                      : IN STD_LOGIC;
         doddb                                     : IN STD_LOGIC;
         dout                                      : OUT STD_LOGIC_VECTOR(19 DOWNTO 0);
         fsd                                       : OUT STD_LOGIC;
         pcie_sw                                   : IN STD_LOGIC;
         pcieo                                     : OUT STD_LOGIC;
         rdynamic_sw                               : IN STD_LOGIC;
         rfast_sd                                  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         rst_n                                     : IN STD_LOGIC;
         rtest_fastsd                              : IN STD_LOGIC;
         rxinn                                     : IN STD_LOGIC;
         rxinp                                     : IN STD_LOGIC;
         vcce_la                                   : IN STD_LOGIC;
         vssexqyx                                  : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_c_deser_10g
      GENERIC (
         PARAM_DELAY                               : INTEGER := 0
      );
      PORT (
         clk90b                                    : IN STD_LOGIC;
         clk_divrx                                 : OUT STD_LOGIC;
         deser_pdb                                 : IN STD_LOGIC;
         deven                                     : IN STD_LOGIC;
         devenb                                    : IN STD_LOGIC;
         dodd                                      : IN STD_LOGIC;
         doddb                                     : IN STD_LOGIC;
         dout                                      : OUT STD_LOGIC_VECTOR(63 DOWNTO 0);
         rst_n                                     : IN STD_LOGIC;
         vcce_la                                   : IN STD_LOGIC;
         vssexqyx                                  : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_c_adce
      PORT (
         adapt_capture                             : IN STD_LOGIC;
         adapt_done                                : OUT STD_LOGIC;
         atb0                                      : INOUT STD_LOGIC;
         atb1                                      : INOUT STD_LOGIC;
         atb_0                                     : INOUT STD_LOGIC;
         atb_1                                     : INOUT STD_LOGIC;
	 atben	 				   : IN  STD_LOGIC;
         atbsel                                    : IN STD_LOGIC_VECTOR(23 DOWNTO 0);
         e_clk                                     : OUT STD_LOGIC;
         eqa_ctrl                                  : OUT STD_LOGIC;
         eqa_set                                   : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         eqb_ctrl                                  : OUT STD_LOGIC;
         eqb_set                                   : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         eqc_ctrl                                  : OUT STD_LOGIC;
         eqc_set                                   : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         eqctrlout                                 : OUT STD_LOGIC_VECTOR(5 DOWNTO 0);
         eqd_ctrl                                  : OUT STD_LOGIC;
         eqd_set                                   : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         eqin_n                                    : IN STD_LOGIC;
         eqin_p                                    : IN STD_LOGIC;
         eqv_ctrl                                  : OUT STD_LOGIC;
         eqv_set                                   : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         fine_d2aout                               : OUT STD_LOGIC;
         fixed_clk                                 : IN STD_LOGIC;
         hf_adapt_done                             : OUT STD_LOGIC;
         hfclk_macro                               : OUT STD_LOGIC;
         hfmac_cnt0_nclr                           : OUT STD_LOGIC;
         hfmac_cnt2_nclr                           : OUT STD_LOGIC;
         ib50u_c                                   : INOUT STD_LOGIC;
         ib50u_t                                   : INOUT STD_LOGIC;
	 ibrgen1				   : OUT  STD_LOGIC;
	 ibrgen2				   : OUT  STD_LOGIC;
         lf_adapt_done                             : OUT STD_LOGIC;
         lfclk_macro                               : OUT STD_LOGIC;
         lfmac_cnt0_nclr                           : OUT STD_LOGIC;
         lfmac_cnt2_nclr                           : OUT STD_LOGIC;
         lock_lf_ovd                               : IN STD_LOGIC;
         lst                                       : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         outeqn                                    : INOUT STD_LOGIC;
         outeqp                                    : INOUT STD_LOGIC;
         r_clk                                     : OUT STD_LOGIC;
         radce_adapt                               : IN STD_LOGIC;
         radce_digital                             : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         radce_hflck                               : IN STD_LOGIC_VECTOR(14 DOWNTO 0);
         radce_lflck                               : IN STD_LOGIC_VECTOR(14 DOWNTO 0);
         radce_pdb                                 : IN STD_LOGIC;
         radce_rstb                                : IN STD_LOGIC;
	 radce_vod_int				   : IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
	 radce_vod_lsb				   : IN  STD_LOGIC;
         rbit_dc                                   : IN STD_LOGIC;
         rclkdiv                                   : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         rd2a_res                                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rdc_freq                                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
	 rdfe_en				   : IN  STD_LOGIC;
         rf_hpf                                    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rf_lpf                                    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rgenctrlout                               : OUT STD_LOGIC_VECTOR(5 DOWNTO 0);
         rhf_os                                    : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         rhyst_hf                                  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rhyst_lf                                  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rlf_os                                    : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         rrect_adj                                 : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rrgen_bw                                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rrgen_set                                 : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rrgen_vod                                 : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rseq_sel                                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         standby                                   : IN STD_LOGIC;
         tmxselan                                  : OUT STD_LOGIC;
         tmxselbn                                  : OUT STD_LOGIC;
         tmxselcn                                  : OUT STD_LOGIC;
         tmxseldn                                  : OUT STD_LOGIC;
         tmxselvn                                  : OUT STD_LOGIC;
         updnn_hf                                  : OUT STD_LOGIC;
         updnn_lf                                  : OUT STD_LOGIC;
         vbn                                       : IN STD_LOGIC;
         vccehxqyx                                 : INOUT STD_LOGIC;
         vccerxqyx                                 : INOUT STD_LOGIC;
         vctl_quiet                                : INOUT STD_LOGIC;
         vssexqyx                                  : INOUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_c_rx
      GENERIC (
         PARAM_DELAY                               : INTEGER := 0;
         INVALID_SD_ON_OFF                         : INTEGER := 500
      );
      PORT (
         analog_sd                                 : OUT STD_LOGIC;
         atb_0                                     : INOUT STD_LOGIC;
         atb_1                                     : INOUT STD_LOGIC;
         atbsel                                    : IN STD_LOGIC_VECTOR(5 DOWNTO 0);
         ck0_sigdet                                : IN STD_LOGIC;
         eqa_ctrl                                  : IN STD_LOGIC;
         eqb_ctrl                                  : IN STD_LOGIC;
         eqc_ctrl                                  : IN STD_LOGIC;
         eqd_ctrl                                  : IN STD_LOGIC;
         eqv_ctrl                                  : IN STD_LOGIC;
         ibc50u                                    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         ibp50u                                    : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         ibp150u                                   : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         inn                                       : IN STD_LOGIC;
         inn3                                      : OUT STD_LOGIC;
         inp                                       : IN STD_LOGIC;
         inp3                                      : OUT STD_LOGIC;
         lpbkn                                     : IN STD_LOGIC;
         lpbkp                                     : IN STD_LOGIC;
         oc_calpd                                  : IN STD_LOGIC;
         oc_en                                     : IN STD_LOGIC;
         pdb                                       : IN STD_LOGIC;
         rbit_dc                                   : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         rdlpbkn                                   : OUT STD_LOGIC;
         rdlpbkp                                   : OUT STD_LOGIC;
         refclk                                    : IN STD_LOGIC;
         rx_b50                                    : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         rx_oc                                     : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         rx_test                                   : IN STD_LOGIC;
         rx_testclk                                : IN STD_LOGIC;
         rxbuf_ibias                               : OUT STD_LOGIC;
         rxn                                       : OUT STD_LOGIC;
         rxp                                       : OUT STD_LOGIC;
         s_lpbk                                    : IN STD_LOGIC;
         s_rdlpbk                                  : IN STD_LOGIC;
         sd_cdr                                    : OUT STD_LOGIC;
         sd_cpon                                   : OUT STD_LOGIC;
         sd_cpop                                   : OUT STD_LOGIC;
         sd_force                                  : IN STD_LOGIC;
         sd_off                                    : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         sd_on                                     : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         sdlv                                      : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         term                                      : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         vcce_la                                   : IN STD_LOGIC;
         vcce_oa                                   : IN STD_LOGIC;
         vccehtxqyx                                : IN STD_LOGIC;
         vssexqyx                                  : IN STD_LOGIC;
         vtt                                       : IN STD_LOGIC_VECTOR(2 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pma_ppmdetect
      PORT (
         scan_mode                                 : IN STD_LOGIC;
         ppmsel                                    : IN STD_LOGIC_VECTOR(5 DOWNTO 0);
         fref                                      : IN STD_LOGIC;
         fvcobyn                                   : IN STD_LOGIC;
         pd                                        : IN STD_LOGIC;
         hard_reset                                : IN STD_LOGIC;
         rforcehigh                                : IN STD_LOGIC;
         rforcelow                                 : IN STD_LOGIC;
         freq_lock                                 : OUT STD_LOGIC;
         ppm_cnt_latch                             : OUT STD_LOGIC_VECTOR(6 DOWNTO 0);
         ppm_cnt_reset                             : IN STD_LOGIC
      );
   END COMPONENT;
   
   
   -- *** End of Section 5 ***
   
   -- *** Section 6 -- Parameter declarations and default values ***
   
   -- *** End of Section 6 ***
   
   -- *** Section 7 -- Port declarations with defaults, if any ***
   
   -- This section will always be empty for WYSIWYG atoms
   -- tri1 devclrn;		//sample
   
   -- *** End of Section 7 ***
   
   -- ---------------------------------------------------------------------------
   --  Model Implementation Begin                                               -
   -- ---------------------------------------------------------------------------
   
   -- Simulation only parameters
      
   -- ---------------------------------------------------------------------------
   --  Model / Submodule Instantiations                                         -
   -- ---------------------------------------------------------------------------
   
   -- ***************************************************************************
   --  -- uses only *_cram                                                      *
   --  -- should NOT use parameters nor *_dprioin                               *
   -- ***************************************************************************
   
   -- supply wires common to modules
   SIGNAL vcce_la                   : STD_LOGIC;
   SIGNAL vcce_oa                   : STD_LOGIC;
   SIGNAL vccehtx                   : STD_LOGIC;
   SIGNAL vssex                     : STD_LOGIC;
   
   -- input wires for c_adce
   
   SIGNAL xadce_atbsel               : STD_LOGIC_VECTOR(23 DOWNTO 0);
   SIGNAL xadce_adapt_capture        : STD_LOGIC;
   SIGNAL xadce_atben                : STD_LOGIC;
   SIGNAL xadce_eqin_n               : STD_LOGIC;
   SIGNAL xadce_eqin_p               : STD_LOGIC;
   SIGNAL xadce_fixed_clk            : STD_LOGIC;
   SIGNAL xadce_pdb                  : STD_LOGIC;
   SIGNAL xadce_rdfe_en              : STD_LOGIC;
   SIGNAL xadce_rstb                 : STD_LOGIC;
   SIGNAL xadce_standby              : STD_LOGIC;
   SIGNAL radce_digital             : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL radce_hflck               : STD_LOGIC_VECTOR(14 DOWNTO 0);
   SIGNAL radce_lflck               : STD_LOGIC_VECTOR(14 DOWNTO 0);
   SIGNAL rclkdiv                   : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rd2a_res                  : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rdc_freq                  : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rf_hpf                    : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rf_lpf                    : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rhf_os                    : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rhyst_hf                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rhyst_lf                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rlf_os                    : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rrect_adj                 : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rrgen_bw                  : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rrgen_set                 : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rrgen_vod                 : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rseq_sel                  : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL radce_vod_int             : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL radce_vod_lsb             : STD_LOGIC;
   
   SIGNAL reqa_set                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL reqb_set                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL reqc_set                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL reqd_set                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL reqv_set                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rrx_lst                   : STD_LOGIC_VECTOR(4 DOWNTO 0);
   
   -- supply wires for adce
   SIGNAL vccehxqyx                 : STD_LOGIC;
   SIGNAL vccerxqyx                 : STD_LOGIC;
   SIGNAL vssexqyx                  : STD_LOGIC;
   
   -- assign the inputs
   
   -- output wires
   
   SIGNAL xadce_adapt_done           : STD_LOGIC;
   SIGNAL xadce_eqctrlout                 : STD_LOGIC_VECTOR(5 DOWNTO 0);
   SIGNAL xadce_rgenctrlout               : STD_LOGIC_VECTOR(5 DOWNTO 0);
   
   SIGNAL eqa_ctrl_wire             : STD_LOGIC;
   SIGNAL eqb_ctrl_wire             : STD_LOGIC;
   SIGNAL eqc_ctrl_wire             : STD_LOGIC;
   SIGNAL eqd_ctrl_wire             : STD_LOGIC;
   SIGNAL eqv_ctrl_wire             : STD_LOGIC;
   
   SIGNAL xadce_rxn                 : STD_LOGIC;
   SIGNAL xadce_rxp                 : STD_LOGIC;
   SIGNAL xadce_ib50u_c             : STD_LOGIC;
   SIGNAL xadce_ib50u_t             : STD_LOGIC;
   SIGNAL xadce_lock_lf_ovd         : STD_LOGIC;
   SIGNAL radce_adapt               : STD_LOGIC;
   SIGNAL xadce_vbn                 : STD_LOGIC;
   
   SIGNAL atb_0                     : STD_LOGIC;
   SIGNAL atb_1                     : STD_LOGIC;
   SIGNAL adce_rxn                  : STD_LOGIC;
   SIGNAL adce_rxp                  : STD_LOGIC;
   
   SIGNAL xadce_atb0                : STD_LOGIC;
   SIGNAL xadce_atb1                : STD_LOGIC;
   SIGNAL xadce_fine_d2aout               : STD_LOGIC;
   SIGNAL xadce_hf_clk                    : STD_LOGIC;
   SIGNAL xadce_hf_adapt_done             : STD_LOGIC;
   SIGNAL xadce_hfclk_macro               : STD_LOGIC;
   SIGNAL xadce_hfmac_cnt0_nclr           : STD_LOGIC;
   SIGNAL xadce_hfmac_cnt2_nclr           : STD_LOGIC;
   SIGNAL xadce_ibrgen1                   : STD_LOGIC;
   SIGNAL xadce_ibrgen2                   : STD_LOGIC;
   SIGNAL xadce_lf_adapt_done             : STD_LOGIC;
   SIGNAL xadce_lfclk_macro               : STD_LOGIC;
   SIGNAL xadce_lfmac_cnt0_nclr           : STD_LOGIC;
   SIGNAL xadce_lfmac_cnt2_nclr           : STD_LOGIC;
   SIGNAL xadce_lf_clk                    : STD_LOGIC;
   SIGNAL xadce_tmxselan                  : STD_LOGIC;
   SIGNAL xadce_tmxselbn                  : STD_LOGIC;
   SIGNAL xadce_tmxselcn                  : STD_LOGIC;
   SIGNAL xadce_tmxseldn                  : STD_LOGIC;
   SIGNAL xadce_tmxselvn                  : STD_LOGIC;
   SIGNAL xadce_updnn_hf                  : STD_LOGIC;
   SIGNAL xadce_updnn_lf                  : STD_LOGIC;
   SIGNAL xadce_vctl_quiet                : STD_LOGIC;
   
   -- input wires for c_rx
   SIGNAL rx_atbsel                 : STD_LOGIC_VECTOR(5 DOWNTO 0);
   SIGNAL ck0_sigdet                : STD_LOGIC;
   SIGNAL ibp50u                    : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL ibc50u                    : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL ibp150u                   : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL lpbkn                     : STD_LOGIC;
   SIGNAL lpbkp                     : STD_LOGIC;
   SIGNAL rx_refclk                 : STD_LOGIC;
   SIGNAL rs_lpbk                   : STD_LOGIC;
   SIGNAL rx_50                     : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rx_n                      : STD_LOGIC;
   SIGNAL rx_p                      : STD_LOGIC;
   SIGNAL rrx_bit_dc                : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rrx_oc                    : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL rx_pdb                    : STD_LOGIC;
   SIGNAL rrx_sd_force              : STD_LOGIC;
   SIGNAL rrx_sd_off                : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL rrx_sd_on                 : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rrx_sdlv                  : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rrx_term                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rrx_test                  : STD_LOGIC;
   SIGNAL rx_testclk                : STD_LOGIC;
   SIGNAL rrx_vtt                   : STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- output wires
   SIGNAL analog_sd_icd             : STD_LOGIC;
   SIGNAL analog_sd_sw              : STD_LOGIC;
   SIGNAL analog_sd                 : STD_LOGIC;
   SIGNAL cdr_rxn                   : STD_LOGIC;
   SIGNAL cdr_rxp                   : STD_LOGIC;
   SIGNAL sd_cdr                    : STD_LOGIC;
   SIGNAL rx_rlpbkp                 : STD_LOGIC;		-- to lpbk_mux
   SIGNAL rx_rlpbkn                 : STD_LOGIC;		-- to lpbk_mux
   SIGNAL wire_sd_cpon              : STD_LOGIC;
   SIGNAL wire_sd_cpop              : STD_LOGIC;
   SIGNAL rx_eqout_n                : STD_LOGIC;
   SIGNAL rx_eqout_p                : STD_LOGIC;

   -- connect inputs
   --filtering X/Z
   --prevent x/z propagate to gate netlist
   SIGNAL rrx_oc_en                 : STD_LOGIC;
   SIGNAL rrx_s_rdlpbk              : STD_LOGIC;
      
   -- c_rx instance
   SIGNAL wire_oc_calpd             : STD_LOGIC;
   SIGNAL vccehtxqyx                : STD_LOGIC;
   
   SIGNAL wire_rxbuf_ibias          : STD_LOGIC;
   
   -- outputs from the c_rx
   
   -- simplified signal detect model like S2GX - SW ----------------
   -- input
   SIGNAL sd_rx                     : STD_LOGIC;
   SIGNAL sd_reset                  : STD_LOGIC;
   -- output
   SIGNAL signaldetect_reg          : STD_LOGIC := '0';
   
   -- PPMDETECT MODULE
   -- ppmdetect module input wires
   SIGNAL ppmdetect_fref_in         : STD_LOGIC;
   SIGNAL ppmdetect_fvcobyn_in      : STD_LOGIC;
   SIGNAL ppmdetect_hardreset_in    : STD_LOGIC;
   SIGNAL ppmdetect_pd_in           : STD_LOGIC;
   SIGNAL ppmdetect_ppmcntreset_in  : STD_LOGIC;
   SIGNAL ppmdetect_ppmsel_in       : STD_LOGIC_VECTOR(5 DOWNTO 0);
   SIGNAL ppmdetect_scanmode_in     : STD_LOGIC;
   SIGNAL ppmdetect_rforcehigh_in   : STD_LOGIC;
   SIGNAL ppmdetect_rforcelow_in    : STD_LOGIC;
   
   -- output wires
   SIGNAL ppmdetect_freqlock_out    : STD_LOGIC;
   SIGNAL ppmdetect_ppmcntlatch_out : STD_LOGIC_VECTOR(6 DOWNTO 0);
    
   -- simplified freqlock behavior:
   --  (1). Responding to rising edge of rxpll_lock with small counter;
   --  (2). Responding to analogreset
   --  (3). Not responding to loss of rxpll_lock
   
   -- freqlock
   SIGNAL mrxpll_not_locked         : STD_LOGIC;
   SIGNAL mfreqlocked_reg           : STD_LOGIC := '0';
   SIGNAL mfreqlocked_cnt           : STD_LOGIC_VECTOR(3 DOWNTO 0) := "0000";
   
   SIGNAL signal_detect_reg_n       : STD_LOGIC;
   
   SIGNAL lck2refctl_freqlock_in    : STD_LOGIC;
   
   -- CDR
   -- input wires for cdr
   SIGNAL ltd                       : STD_LOGIC;
   SIGNAL ltr                       : STD_LOGIC;
   SIGNAL ignore_phslck             : STD_LOGIC;
   
   SIGNAL devenout                  : STD_LOGIC;
   SIGNAL devenbout                 : STD_LOGIC;
   SIGNAL doddout                   : STD_LOGIC;
   SIGNAL oddbout                   : STD_LOGIC;
   SIGNAL doddx                     : STD_LOGIC;
   SIGNAL oddbx                     : STD_LOGIC;
   SIGNAL oe1                       : STD_LOGIC;
   SIGNAL oeb1                      : STD_LOGIC;
   SIGNAL oo1                       : STD_LOGIC;
   SIGNAL oob1                      : STD_LOGIC;
   SIGNAL oe2                       : STD_LOGIC;
   SIGNAL oeb2                      : STD_LOGIC;
   SIGNAL oo2                       : STD_LOGIC;
   SIGNAL oob2                      : STD_LOGIC;
   SIGNAL rxlpbp_int                : STD_LOGIC;
   SIGNAL rxlpbn_int                : STD_LOGIC;
   SIGNAL rxlpbdp_int               : STD_LOGIC;
   SIGNAL rxlpbdn_int               : STD_LOGIC;
   
   SIGNAL deven                     : STD_LOGIC;
   SIGNAL devenb                    : STD_LOGIC;
   SIGNAL dodd                      : STD_LOGIC;
   SIGNAL doddb                     : STD_LOGIC;
   
   SIGNAL cdr_pdb                   : STD_LOGIC;
   SIGNAL ck0_pd                    : STD_LOGIC;
   SIGNAL ck90_pd                   : STD_LOGIC;
   SIGNAL ck180_pd                  : STD_LOGIC;
   SIGNAL ck270_pd                  : STD_LOGIC;
   SIGNAL clk90_slpbk               : STD_LOGIC;
   SIGNAL clk270_slpbk              : STD_LOGIC;
   SIGNAL lck2ref                   : STD_LOGIC;
   SIGNAL pdbx                      : STD_LOGIC;
   SIGNAL pe                        : STD_LOGIC;
   SIGNAL rlbk                      : STD_LOGIC;
   SIGNAL rlpbk_pre_en              : STD_LOGIC;
   SIGNAL rstb_slpbk                : STD_LOGIC;
   SIGNAL rst_n                     : STD_LOGIC;
   SIGNAL rstn2                     : STD_LOGIC;
   SIGNAL rxpll_lock                : STD_LOGIC;
   SIGNAL rxlpbp                    : STD_LOGIC;
   SIGNAL rxlpbn                    : STD_LOGIC;
   SIGNAL rxlpbdp                   : STD_LOGIC;
   SIGNAL rxlpbdn                   : STD_LOGIC;
   
   -- connect inputs
   
   -- * * c_lck2refctl * *
   --     ltd ? 1'b0 :  **** lack ltr/ltd control logic ***
   --    (~sd_cdr | ~lck2refctl_freqlock_in | ltr ) ? 1'b1 :
   
   -- rclk_mon
   --   assign { rxlpbp, rxlpbn} = rclk_mon ? { clk90_slpbk, ~clk90_slpbk} : { rxlpbp_int, rxlpbn_int};
   --   assign {rxlpbdp,rxlpbdn} = rclk_mon ? {clk270_slpbk,~clk270_slpbk} : {rxlpbdp_int,rxlpbdn_int};
   
   -- outputs from the c_cdr
   
   --//////////////end cdr
   
   -- input wires for loopback_mux
   SIGNAL rrevlb_sw                 : STD_LOGIC;
   
   -- output wires
   
   SIGNAL cdr_rlpbkn                : STD_LOGIC;
   SIGNAL cdr_rlpbkp                : STD_LOGIC;
   
   SIGNAL cdr_rlpbkdn               : STD_LOGIC;
   SIGNAL cdr_rlpbkdp               : STD_LOGIC;
   
   SIGNAL ncvondp                   : STD_LOGIC;
   SIGNAL ncvopdp                   : STD_LOGIC;
   SIGNAL rlpbkdn                   : STD_LOGIC;
   SIGNAL rlpbkdp                   : STD_LOGIC;
   SIGNAL rlpbkn                    : STD_LOGIC;
   SIGNAL ncvonp                    : STD_LOGIC;
   SIGNAL rlpbkp                    : STD_LOGIC;
   SIGNAL ncvopp                    : STD_LOGIC;
   
   -- outputs from the lpbk_mux
   
   -- input wires for the deserializer
   SIGNAL xdeser_clk90_in           : STD_LOGIC;
   SIGNAL xdeser_pdb_in             : STD_LOGIC;
   SIGNAL xdeser_rst_n              : STD_LOGIC;
   SIGNAL xdeser_pcie_sw            : STD_LOGIC;
   SIGNAL xdeser_div2_in            : STD_LOGIC;
   SIGNAL xdeser_div5_in            : STD_LOGIC;
   SIGNAL rdynamic_sw               : STD_LOGIC;
   SIGNAL rfast_sd                  : STD_LOGIC_VECTOR(3 DOWNTO 0);
   
   -- input wires for the 10g deserializer
   SIGNAL xdeser_10g_clk90b         : STD_LOGIC;
   SIGNAL xdeser_10g_pdb            : STD_LOGIC;
   SIGNAL xdeser_10g_deven          : STD_LOGIC;
   SIGNAL xdeser_10g_devenb         : STD_LOGIC;
   SIGNAL xdeser_10g_dodd           : STD_LOGIC;
   SIGNAL xdeser_10g_doddb          : STD_LOGIC;
   SIGNAL xdeser_10g_rst_n          : STD_LOGIC;
   
   -- output wires
   SIGNAL xdeser_clkdivrx_out       : STD_LOGIC;
   SIGNAL xdeser_dout_out           : STD_LOGIC_VECTOR(19 DOWNTO 0);
   SIGNAL xdeser_fsd_out            : STD_LOGIC;
   SIGNAL xdeser_pcieo_out          : STD_LOGIC;
   
   -- 10g output wires
   SIGNAL xdeser_10g_clk_divrx      : STD_LOGIC;
   SIGNAL xdeser_10g_dout           : STD_LOGIC_VECTOR(63 DOWNTO 0);
   
   SIGNAL wire_rtest_fastsd         : STD_LOGIC;
  
   -- Table36: PMA Per Channel RX Control Register 1 for Channel 0
   constant rrx_term_sel_RXPMA_IDX_0	: integer := 0;
   constant rrx_term_sel_RXPMA_IDX_1	: integer := 1;
   constant rrx_term_sel_RXPMA_IDX_2	: integer := 2;
   constant rrx_vtt_RXPMA_IDX_0	: integer := 3;
   constant rrx_vtt_RXPMA_IDX_1	: integer := 4;
   constant rrx_vtt_RXPMA_IDX_2	: integer := 5;
   constant rrx_s_rdlpbk_RXPMA_IDX_0	: integer := 6;
   constant rrx_bit_dc_RXPMA_IDX_0	: integer := 7;
   constant rrx_bit_dc_RXPMA_IDX_1	: integer := 8;
   constant rrx_bit_dc_RXPMA_IDX_2	: integer := 9;
   constant rrx_bit_dc_RXPMA_IDX_3	: integer := 10;
   constant rrx_lst_RXPMA_IDX_0	: integer := 11;
   constant rrx_lst_RXPMA_IDX_1	: integer := 12;
   constant rrx_lst_RXPMA_IDX_2	: integer := 13;
   constant rrx_lst_RXPMA_IDX_3	: integer := 14;
   constant rrx_lst_RXPMA_IDX_4	: integer := 15;
   
   -- Table37: PMA Per Channel RX Control Register 2 for Channel 0
   constant rrxurstpma_RXPMA_IDX_0	: integer := 16;
   constant rrx_test_RXPMA_IDX_0	: integer := 17;
   constant rrx_sd_force_RXPMA_IDX_0	: integer := 18;
   constant rrx_oc_RXPMA_IDX_0	: integer := 19;
   constant rrx_oc_RXPMA_IDX_1	: integer := 20;
   constant rrx_oc_RXPMA_IDX_2	: integer := 21;
   constant rrx_oc_RXPMA_IDX_3	: integer := 22;
   constant rrx_oc_RXPMA_IDX_4	: integer := 23;
   constant rrx_oc_RXPMA_IDX_5	: integer := 24;
   constant rrx_oc_RXPMA_IDX_6	: integer := 25;
   constant rrx_oc_RXPMA_IDX_7	: integer := 26;
   constant rrx_oc_en_RXPMA_IDX_0	: integer := 27;
   constant rrx_sdlv_RXPMA_IDX_0	: integer := 28;
   constant rrx_sdlv_RXPMA_IDX_1	: integer := 29;
   constant rrx_sdlv_RXPMA_IDX_2	: integer := 30;
   constant rrx_sdlv_RXPMA_IDX_3	: integer := 31;
   
   -- Table38: PMA Per Channel RX Control Register 3 for Channel 0
   constant reserved_0_TB38_RXPMA_IDX_0	: integer := 32;
   constant reserved_0_TB38_RXPMA_IDX_1	: integer := 33;
   constant reserved_0_TB38_RXPMA_IDX_2	: integer := 34;
   constant rpowdnr_RXPMA_IDX_0	: integer := 35;
   constant rrx_ib_pdb_RXPMA_IDX_0	: integer := 36;
   constant rurx_pdb_RXPMA_IDX_0	: integer := 37;
   constant rrx_oc_calpd_RXPMA_IDX_0	: integer := 38;
   constant rrx_sd_off_RXPMA_IDX_0	: integer := 39;
   constant rrx_sd_off_RXPMA_IDX_1	: integer := 40;
   constant rrx_sd_off_RXPMA_IDX_2	: integer := 41;
   constant rrx_sd_off_RXPMA_IDX_3	: integer := 42;
   constant rrx_sd_off_RXPMA_IDX_4	: integer := 43;
   constant rrx_sd_on_RXPMA_IDX_0	: integer := 44;
   constant rrx_sd_on_RXPMA_IDX_1	: integer := 45;
   constant rrx_sd_on_RXPMA_IDX_2	: integer := 46;
   constant rrx_sd_on_RXPMA_IDX_3	: integer := 47;
   
   -- Table43: PMA Per Channel RX Control Register 8 for Channel 0
   constant reye_monitor_RXPMA_IDX_0	: integer := 112;
   constant reye_monitor_RXPMA_IDX_1	: integer := 113;
   constant reye_monitor_RXPMA_IDX_2	: integer := 114;
   constant reye_monitor_RXPMA_IDX_3	: integer := 115;
   constant reye_monitor_RXPMA_IDX_4	: integer := 116;
   constant reye_monitor_RXPMA_IDX_5	: integer := 117;
   constant reye_monitor_RXPMA_IDX_6	: integer := 118;
   constant reye_monitor_RXPMA_IDX_7	: integer := 119;
   constant reserved_0_TB43_RXPMA_IDX_0	: integer := 120;
   constant reserved_0_TB43_RXPMA_IDX_1	: integer := 121;
   constant reserved_0_TB43_RXPMA_IDX_2	: integer := 122;
   constant reserved_0_TB43_RXPMA_IDX_3	: integer := 123;
   constant reserved_0_TB43_RXPMA_IDX_4	: integer := 124;
   constant reserved_0_TB43_RXPMA_IDX_5	: integer := 125;
   constant reserved_0_TB43_RXPMA_IDX_6	: integer := 126;
   constant reserved_0_TB43_RXPMA_IDX_7	: integer := 127;
   
   -- Table44: PMA Per Channel RX Control Register 9 for Channel 0
   constant rpma_reserved_0_TB44_RXPMA_IDX_0	: integer := 128;
   constant rpma_reserved_0_TB44_RXPMA_IDX_1	: integer := 129;
   constant rpma_reserved_0_TB44_RXPMA_IDX_2	: integer := 130;
   constant rpma_reserved_0_TB44_RXPMA_IDX_3	: integer := 131;
   constant rpma_reserved_0_TB44_RXPMA_IDX_4	: integer := 132;
   constant rpma_reserved_0_TB44_RXPMA_IDX_5	: integer := 133;
   constant rpma_reserved_0_TB44_RXPMA_IDX_6	: integer := 134;
   constant rpma_reserved_0_TB44_RXPMA_IDX_7	: integer := 135;
   constant rpma_reserved_0_TB44_RXPMA_IDX_8	: integer := 136;
   constant rpma_reserved_0_TB44_RXPMA_IDX_9	: integer := 137;
   constant rpma_reserved_0_TB44_RXPMA_IDX_10	: integer := 138;
   constant rpma_reserved_0_TB44_RXPMA_IDX_11	: integer := 139;
   constant rpma_reserved_0_TB44_RXPMA_IDX_12	: integer := 140;
   constant rpma_reserved_0_TB44_RXPMA_IDX_13	: integer := 141;
   constant rpma_reserved_0_TB44_RXPMA_IDX_14	: integer := 142;
   constant rpma_reserved_0_TB44_RXPMA_IDX_15	: integer := 143;
   
   -- Table45: PMA Per Channel RX Control Register 10 for Channel 0
   constant rppm_cnt_reset_RXPMA_IDX_0	: integer := 144;
   constant rforce1_freqdet_RXPMA_IDX_0	: integer := 145;
   constant rforce0_freqdet_RXPMA_IDX_0	: integer := 146;
   constant rppmsel_RXPMA_IDX_0	: integer := 147;
   constant rppmsel_RXPMA_IDX_1	: integer := 148;
   constant rppmsel_RXPMA_IDX_2	: integer := 149;
   constant rppmsel_RXPMA_IDX_3	: integer := 150;
   constant rppmsel_RXPMA_IDX_4	: integer := 151;
   constant rppmsel_RXPMA_IDX_5	: integer := 152;
   constant rfastsd_RXPMA_IDX_0	: integer := 153;
   constant rfastsd_RXPMA_IDX_1	: integer := 154;
   constant rfastsd_RXPMA_IDX_2	: integer := 155;
   constant rfastsd_RXPMA_IDX_3	: integer := 156;
   constant rtest_fastsd_RXPMA_IDX_0	: integer := 157;
   constant rpmadwidth_rx_RXPMA_IDX_0	: integer := 158;
   constant rpma_doublewidth_rx_RXPMA_IDX_0	: integer := 159;
   
   -- Table46: PMA Per Channel RX Control Register 11 for Channel 0
   constant reserved_0_TB46_RXPMA_IDX_0	: integer := 160;
   constant reserved_0_TB46_RXPMA_IDX_1	: integer := 161;
   constant reserved_0_TB46_RXPMA_IDX_2	: integer := 162;
   constant reserved_0_TB46_RXPMA_IDX_3	: integer := 163;
   constant reserved_0_TB46_RXPMA_IDX_4	: integer := 164;
   constant reserved_0_TB46_RXPMA_IDX_5	: integer := 165;
   constant reserved_0_TB46_RXPMA_IDX_6	: integer := 166;
   constant reserved_0_TB46_RXPMA_IDX_7	: integer := 167;
   constant rppm_gen1_2xcnt_en_RXPMA_IDX_0	: integer := 168;
   constant rppm_post_eidle_del_RXPMA_IDX_0	: integer := 169;
   constant r_dfe_2t_RXPMA_IDX_0	: integer := 170;
   constant r_dfe_2t_RXPMA_IDX_1	: integer := 171;
   constant r_dfe_2t_RXPMA_IDX_2	: integer := 172;
   constant r_dfe_1t_RXPMA_IDX_0	: integer := 173;
   constant r_dfe_1t_RXPMA_IDX_1	: integer := 174;
   constant r_dfe_1t_RXPMA_IDX_2	: integer := 175;
   
   -- Table47: PMA Per Channel RX Control Register 12 for Channel 0
   constant reqv_set_RXPMA_IDX_0	: integer := 176;
   constant reqv_set_RXPMA_IDX_1	: integer := 177;
   constant reqv_set_RXPMA_IDX_2	: integer := 178;
   constant reqd_set_RXPMA_IDX_0	: integer := 179;
   constant reqd_set_RXPMA_IDX_1	: integer := 180;
   constant reqd_set_RXPMA_IDX_2	: integer := 181;
   constant reqc_set_RXPMA_IDX_0	: integer := 182;
   constant reqc_set_RXPMA_IDX_1	: integer := 183;
   constant reqc_set_RXPMA_IDX_2	: integer := 184;
   constant reqb_set_RXPMA_IDX_0	: integer := 185;
   constant reqb_set_RXPMA_IDX_1	: integer := 186;
   constant reqb_set_RXPMA_IDX_2	: integer := 187;
   constant reqa_set_RXPMA_IDX_0	: integer := 188;
   constant reqa_set_RXPMA_IDX_1	: integer := 189;
   constant reqa_set_RXPMA_IDX_2	: integer := 190;
   constant reserved_0_TB47_RXPMA_IDX_0	: integer := 191;
   
   -- Table48: PMA Per Channel RX Control Register 13 for Channel 0
   constant rdc_freq_RXPMA_IDX_0	: integer := 192;
   constant rdc_freq_RXPMA_IDX_1	: integer := 193;
   constant rhyst_lf_RXPMA_IDX_0	: integer := 194;
   constant rhyst_lf_RXPMA_IDX_1	: integer := 195;
   constant rhyst_lf_RXPMA_IDX_2	: integer := 196;
   constant rclkdiv_RXPMA_IDX_0	: integer := 197;
   constant rclkdiv_RXPMA_IDX_1	: integer := 198;
   constant rclkdiv_RXPMA_IDX_2	: integer := 199;
   constant rclkdiv_RXPMA_IDX_3	: integer := 200;
   constant rrgen_set_RXPMA_IDX_0	: integer := 201;
   constant rrgen_set_RXPMA_IDX_1	: integer := 202;
   constant rrgen_set_RXPMA_IDX_2	: integer := 203;
   constant radce_adapt_RXPMA_IDX_0	: integer := 204;
   constant rseq_sel_RXPMA_IDX_0	: integer := 205;
   constant rseq_sel_RXPMA_IDX_1	: integer := 206;
   constant rlock_lf_ovd_RXPMA_IDX_0	: integer := 207;
   
   -- Table49: PMA Per Channel RX Control Register 14 for Channel 0
   constant rrgen_vod_RXPMA_IDX_0	: integer := 208;
   constant rrgen_vod_RXPMA_IDX_1	: integer := 209;
   constant rrgen_vod_RXPMA_IDX_2	: integer := 210;
   constant rf_hpf_RXPMA_IDX_0	: integer := 211;
   constant rf_hpf_RXPMA_IDX_1	: integer := 212;
   constant rf_lpf_RXPMA_IDX_0	: integer := 213;
   constant rf_lpf_RXPMA_IDX_1	: integer := 214;
   constant reserved_1_TB49_RXPMA_IDX_0	: integer := 215;
   constant reserved_1_TB49_RXPMA_IDX_1	: integer := 216;
   constant reserved_1_TB49_RXPMA_IDX_2	: integer := 217;
   constant reserved_0_TB49_RXPMA_IDX_0	: integer := 218;
   constant reserved_0_TB49_RXPMA_IDX_1	: integer := 219;
   constant reserved_0_TB49_RXPMA_IDX_2	: integer := 220;
   constant rhyst_hf_RXPMA_IDX_0	: integer := 221;
   constant rhyst_hf_RXPMA_IDX_1	: integer := 222;
   constant rhyst_hf_RXPMA_IDX_2	: integer := 223;
   
   -- Table50: PMA Per Channel RX Control Register 15 for Channel 0
   constant radce_pdb_RXPMA_IDX_0	: integer := 224;
   constant radce_rst_RXPMA_IDX_0	: integer := 225;
   constant rhf_os_RXPMA_IDX_0	: integer := 226;
   constant rhf_os_RXPMA_IDX_1	: integer := 227;
   constant rhf_os_RXPMA_IDX_2	: integer := 228;
   constant rhf_os_RXPMA_IDX_3	: integer := 229;
   constant rlf_os_RXPMA_IDX_0	: integer := 230;
   constant rlf_os_RXPMA_IDX_1	: integer := 231;
   constant rlf_os_RXPMA_IDX_2	: integer := 232;
   constant rlf_os_RXPMA_IDX_3	: integer := 233;
   constant rd2a_res_RXPMA_IDX_0	: integer := 234;
   constant rd2a_res_RXPMA_IDX_1	: integer := 235;
   constant rrect_adj_RXPMA_IDX_0	: integer := 236;
   constant rrect_adj_RXPMA_IDX_1	: integer := 237;
   constant rrgen_bw_RXPMA_IDX_0	: integer := 238;
   constant rrgen_bw_RXPMA_IDX_1	: integer := 239;
   
   -- Table51: PMA Per Channel RX Control Register 16 for Channel 0
   constant radce_hflck_RXPMA_IDX_0	: integer := 240;
   constant radce_hflck_RXPMA_IDX_1	: integer := 241;
   constant radce_hflck_RXPMA_IDX_2	: integer := 242;
   constant radce_hflck_RXPMA_IDX_3	: integer := 243;
   constant radce_hflck_RXPMA_IDX_4	: integer := 244;
   constant radce_hflck_RXPMA_IDX_5	: integer := 245;
   constant radce_hflck_RXPMA_IDX_6	: integer := 246;
   constant radce_hflck_RXPMA_IDX_7	: integer := 247;
   constant radce_hflck_RXPMA_IDX_8	: integer := 248;
   constant radce_hflck_RXPMA_IDX_9	: integer := 249;
   constant radce_hflck_RXPMA_IDX_10	: integer := 250;
   constant radce_hflck_RXPMA_IDX_11	: integer := 251;
   constant radce_hflck_RXPMA_IDX_12	: integer := 252;
   constant radce_hflck_RXPMA_IDX_13	: integer := 253;
   constant radce_hflck_RXPMA_IDX_14	: integer := 254;
   constant reserved_0_TB51_RXPMA_IDX_0	: integer := 255;
   
   -- Table52: PMA Per Channel RX Control Register 17 for Channel 0
   constant radce_lflck_RXPMA_IDX_0	: integer := 256;
   constant radce_lflck_RXPMA_IDX_1	: integer := 257;
   constant radce_lflck_RXPMA_IDX_2	: integer := 258;
   constant radce_lflck_RXPMA_IDX_3	: integer := 259;
   constant radce_lflck_RXPMA_IDX_4	: integer := 260;
   constant radce_lflck_RXPMA_IDX_5	: integer := 261;
   constant radce_lflck_RXPMA_IDX_6	: integer := 262;
   constant radce_lflck_RXPMA_IDX_7	: integer := 263;
   constant radce_lflck_RXPMA_IDX_8	: integer := 264;
   constant radce_lflck_RXPMA_IDX_9	: integer := 265;
   constant radce_lflck_RXPMA_IDX_10	: integer := 266;
   constant radce_lflck_RXPMA_IDX_11	: integer := 267;
   constant radce_lflck_RXPMA_IDX_12	: integer := 268;
   constant radce_lflck_RXPMA_IDX_13	: integer := 269;
   constant radce_lflck_RXPMA_IDX_14	: integer := 270;
   constant reserved_0_TB52_RXPMA_IDX_0	: integer := 271;
   
   -- Table53: PMA Per Channel RX Control Register 18 for Channel 0
   constant radce_digital_RXPMA_IDX_0	: integer := 272;
   constant radce_digital_RXPMA_IDX_1	: integer := 273;
   constant radce_digital_RXPMA_IDX_2	: integer := 274;
   constant radce_digital_RXPMA_IDX_3	: integer := 275;
   constant radce_digital_RXPMA_IDX_4	: integer := 276;
   constant radce_digital_RXPMA_IDX_5	: integer := 277;
   constant radce_digital_RXPMA_IDX_6	: integer := 278;
   constant radce_digital_RXPMA_IDX_7	: integer := 279;
   constant radce_digital_RXPMA_IDX_8	: integer := 280;
   constant radce_digital_RXPMA_IDX_9	: integer := 281;
   constant reserved_0_TB53_RXPMA_IDX_0	: integer := 282;
   constant reserved_0_TB53_RXPMA_IDX_1	: integer := 283;
   constant reserved_0_TB53_RXPMA_IDX_2	: integer := 284;
   constant reserved_0_TB53_RXPMA_IDX_3	: integer := 285;
   constant reserved_0_TB53_RXPMA_IDX_4	: integer := 286;
   constant reserved_0_TB53_RXPMA_IDX_5	: integer := 287;
   
   -- Extra
   constant RLPBK_RXPMA_IDX             : integer := 290;
   constant RREVLB_SW_RXPMA_IDX         : integer := 291;
   constant RRX_S_LPBK_RXPMA_IDX        : integer := 292;

   -- ---------------------------------------------------------------------------
   -- DPRIO input CRAM  
   -- ---------------------------------------------------------------------------
   
   -- PMA Per Channel RX Control Register 1 for Channel 0
   SIGNAL dprioin_rrx_term_sel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_rrx_vtt	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_rrx_s_rdlpbk	: STD_LOGIC;
   SIGNAL dprioin_rrx_bit_dc	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dprioin_rrx_lst	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 2 for Channel 0
   SIGNAL dprioin_rrxurstpma	: STD_LOGIC;
   SIGNAL dprioin_rrx_test	: STD_LOGIC;
   SIGNAL dprioin_rrx_sd_force	: STD_LOGIC;
   SIGNAL dprioin_rrx_oc	: STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL dprioin_rrx_oc_en	: STD_LOGIC;
   SIGNAL dprioin_rrx_sdlv	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 3 for Channel 0
   SIGNAL dprioin_reserved_0_TB38	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_rpowdnr	: STD_LOGIC;
   SIGNAL dprioin_rrx_ib_pdb	: STD_LOGIC;
   SIGNAL dprioin_rurx_pdb	: STD_LOGIC;
   SIGNAL dprioin_rrx_oc_calpd	: STD_LOGIC;
   SIGNAL dprioin_rrx_sd_off	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL dprioin_rrx_sd_on	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 8 for Channel 0
   SIGNAL dprioin_reye_monitor	: STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL dprioin_reserved_0_TB43	: STD_LOGIC_VECTOR(7 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 9 for Channel 0
   SIGNAL dprioin_rpma_reserved_0_TB44	: STD_LOGIC_VECTOR(15 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 10 for Channel 0
   SIGNAL dprioin_rppm_cnt_reset	: STD_LOGIC;
   SIGNAL dprioin_rforce1_freqdet	: STD_LOGIC;
   SIGNAL dprioin_rforce0_freqdet	: STD_LOGIC;
   SIGNAL dprioin_rppmsel	: STD_LOGIC_VECTOR(5 DOWNTO 0);
   SIGNAL dprioin_rfastsd	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dprioin_rtest_fastsd	: STD_LOGIC;
   SIGNAL dprioin_rpmadwidth_rx	: STD_LOGIC;
   SIGNAL dprioin_rpma_doublewidth_rx	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 11 for Channel 0
   SIGNAL dprioin_reserved_0_TB46	: STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL dprioin_rppm_gen1_2xcnt_en	: STD_LOGIC;
   SIGNAL dprioin_rppm_post_eidle_del	: STD_LOGIC;
   SIGNAL dprioin_r_dfe_2t	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_r_dfe_1t	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 12 for Channel 0
   SIGNAL dprioin_reqv_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_reqd_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_reqc_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_reqb_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_reqa_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_reserved_0_TB47	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 13 for Channel 0
   SIGNAL dprioin_rdc_freq	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_rhyst_lf	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_rclkdiv	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dprioin_rrgen_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_radce_adapt	: STD_LOGIC;
   SIGNAL dprioin_rseq_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_rlock_lf_ovd	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 14 for Channel 0
   SIGNAL dprioin_rrgen_vod	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_rf_hpf	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_rf_lpf	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_reserved_1_TB49	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_reserved_0_TB49	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL dprioin_rhyst_hf	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 15 for Channel 0
   SIGNAL dprioin_radce_pdb	: STD_LOGIC;
   SIGNAL dprioin_radce_rst	: STD_LOGIC;
   SIGNAL dprioin_rhf_os	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dprioin_rlf_os	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dprioin_rd2a_res	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_rrect_adj	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dprioin_rrgen_bw	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 16 for Channel 0
   SIGNAL dprioin_radce_hflck	: STD_LOGIC_VECTOR(14 DOWNTO 0);
   SIGNAL dprioin_reserved_0_TB51	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 17 for Channel 0
   SIGNAL dprioin_radce_lflck	: STD_LOGIC_VECTOR(14 DOWNTO 0);
   SIGNAL dprioin_reserved_0_TB52	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 18 for Channel 0
   SIGNAL dprioin_radce_digital	: STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL dprioin_reserved_0_TB53	: STD_LOGIC_VECTOR(5 DOWNTO 0);
   
   -- Extra
   SIGNAL dprioin_rlpbk		: STD_LOGIC;
   SIGNAL dprioin_rrevlb_sw	: STD_LOGIC;
   SIGNAL dprioin_rrx_s_lpbk	: STD_LOGIC;

   -- ---------------------------------------------------------------------------
   -- Initial CRAM  
   -- ---------------------------------------------------------------------------
   
   -- PMA Per Channel RX Control Register 1 for Channel 0
   SIGNAL init_rrx_term_sel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_rrx_vtt	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_rrx_s_rdlpbk	: STD_LOGIC;
   SIGNAL init_rrx_bit_dc	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rrx_lst	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 2 for Channel 0
   SIGNAL init_rrxurstpma	: STD_LOGIC;
   SIGNAL init_rrx_test	: STD_LOGIC;
   SIGNAL init_rrx_sd_force	: STD_LOGIC;
   SIGNAL init_rrx_oc	: STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL init_rrx_oc_en	: STD_LOGIC;
   SIGNAL init_rrx_sdlv	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 3 for Channel 0
   SIGNAL init_reserved_0_TB38	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_rpowdnr	: STD_LOGIC;
   SIGNAL init_rrx_ib_pdb	: STD_LOGIC;
   SIGNAL init_rurx_pdb	: STD_LOGIC;
   SIGNAL init_rrx_oc_calpd	: STD_LOGIC;
   SIGNAL init_rrx_sd_off	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL init_rrx_sd_on	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 8 for Channel 0
   SIGNAL init_reye_monitor	: STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL init_reserved_0_TB43	: STD_LOGIC_VECTOR(7 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 9 for Channel 0
   SIGNAL init_rpma_reserved_0_TB44	: STD_LOGIC_VECTOR(15 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 10 for Channel 0
   SIGNAL init_rppm_cnt_reset	: STD_LOGIC;
   SIGNAL init_rforce1_freqdet	: STD_LOGIC;
   SIGNAL init_rforce0_freqdet	: STD_LOGIC;
   SIGNAL init_rppmsel	: STD_LOGIC_VECTOR(5 DOWNTO 0);
   SIGNAL init_rfastsd	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rtest_fastsd	: STD_LOGIC;
   SIGNAL init_rpmadwidth_rx	: STD_LOGIC;
   SIGNAL init_rpma_doublewidth_rx	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 11 for Channel 0
   SIGNAL init_reserved_0_TB46	: STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL init_rppm_gen1_2xcnt_en	: STD_LOGIC;
   SIGNAL init_rppm_post_eidle_del	: STD_LOGIC;
   SIGNAL init_r_dfe_2t	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_r_dfe_1t	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 12 for Channel 0
   SIGNAL init_reqv_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_reqd_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_reqc_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_reqb_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_reqa_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_reserved_0_TB47	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 13 for Channel 0
   SIGNAL init_rdc_freq	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rhyst_lf	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_rclkdiv	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rrgen_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_radce_adapt	: STD_LOGIC;
   SIGNAL init_rseq_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rlock_lf_ovd	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 14 for Channel 0
   SIGNAL init_rrgen_vod	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_rf_hpf	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rf_lpf	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_reserved_1_TB49	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_reserved_0_TB49	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL init_rhyst_hf	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 15 for Channel 0
   SIGNAL init_radce_pdb	: STD_LOGIC;
   SIGNAL init_radce_rst	: STD_LOGIC;
   SIGNAL init_rhf_os	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rlf_os	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rd2a_res	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rrect_adj	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rrgen_bw	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 16 for Channel 0
   SIGNAL init_radce_hflck	: STD_LOGIC_VECTOR(14 DOWNTO 0);
   SIGNAL init_reserved_0_TB51	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 17 for Channel 0
   SIGNAL init_radce_lflck	: STD_LOGIC_VECTOR(14 DOWNTO 0);
   SIGNAL init_reserved_0_TB52	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 18 for Channel 0
   SIGNAL init_radce_digital	: STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL init_reserved_0_TB53	: STD_LOGIC_VECTOR(5 DOWNTO 0);
   
   -- Extra
   SIGNAL init_rlpbk		: STD_LOGIC;
   SIGNAL init_rrevlb_sw	: STD_LOGIC;
   SIGNAL init_rrx_s_lpbk	: STD_LOGIC;
   
   -- ---------------------------------------------------------------------------
   -- CRAM  
   -- ---------------------------------------------------------------------------
   
   -- PMA Per Channel RX Control Register 1 for Channel 0
   SIGNAL cram_rrx_term_sel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_rrx_vtt	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_rrx_s_rdlpbk	: STD_LOGIC;
   SIGNAL cram_rrx_bit_dc	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rrx_lst	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 2 for Channel 0
   SIGNAL cram_rrxurstpma	: STD_LOGIC;
   SIGNAL cram_rrx_test	: STD_LOGIC;
   SIGNAL cram_rrx_sd_force	: STD_LOGIC;
   SIGNAL cram_rrx_oc	: STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL cram_rrx_oc_en	: STD_LOGIC;
   SIGNAL cram_rrx_sdlv	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 3 for Channel 0
   SIGNAL cram_reserved_0_TB38	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_rpowdnr	: STD_LOGIC;
   SIGNAL cram_rrx_ib_pdb	: STD_LOGIC;
   SIGNAL cram_rurx_pdb	: STD_LOGIC;
   SIGNAL cram_rrx_oc_calpd	: STD_LOGIC;
   SIGNAL cram_rrx_sd_off	: STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL cram_rrx_sd_on	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 8 for Channel 0
   SIGNAL cram_reye_monitor	: STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL cram_reserved_0_TB43	: STD_LOGIC_VECTOR(7 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 9 for Channel 0
   SIGNAL cram_rpma_reserved_0_TB44	: STD_LOGIC_VECTOR(15 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 10 for Channel 0
   SIGNAL cram_rppm_cnt_reset	: STD_LOGIC;
   SIGNAL cram_rforce1_freqdet	: STD_LOGIC;
   SIGNAL cram_rforce0_freqdet	: STD_LOGIC;
   SIGNAL cram_rppmsel	: STD_LOGIC_VECTOR(5 DOWNTO 0);
   SIGNAL cram_rfastsd	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rtest_fastsd	: STD_LOGIC;
   SIGNAL cram_rpmadwidth_rx	: STD_LOGIC;
   SIGNAL cram_rpma_doublewidth_rx	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 11 for Channel 0
   SIGNAL cram_reserved_0_TB46	: STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL cram_rppm_gen1_2xcnt_en	: STD_LOGIC;
   SIGNAL cram_rppm_post_eidle_del	: STD_LOGIC;
   SIGNAL cram_r_dfe_2t	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_r_dfe_1t	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 12 for Channel 0
   SIGNAL cram_reqv_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_reqd_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_reqc_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_reqb_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_reqa_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_reserved_0_TB47	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 13 for Channel 0
   SIGNAL cram_rdc_freq	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rhyst_lf	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_rclkdiv	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rrgen_set	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_radce_adapt	: STD_LOGIC;
   SIGNAL cram_rseq_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rlock_lf_ovd	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 14 for Channel 0
   SIGNAL cram_rrgen_vod	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_rf_hpf	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rf_lpf	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_reserved_1_TB49	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_reserved_0_TB49	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL cram_rhyst_hf	: STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 15 for Channel 0
   SIGNAL cram_radce_pdb	: STD_LOGIC;
   SIGNAL cram_radce_rst	: STD_LOGIC;
   SIGNAL cram_rhf_os	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rlf_os	: STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rd2a_res	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rrect_adj	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rrgen_bw	: STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   -- PMA Per Channel RX Control Register 16 for Channel 0
   SIGNAL cram_radce_hflck	: STD_LOGIC_VECTOR(14 DOWNTO 0);
   SIGNAL cram_reserved_0_TB51	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 17 for Channel 0
   SIGNAL cram_radce_lflck	: STD_LOGIC_VECTOR(14 DOWNTO 0);
   SIGNAL cram_reserved_0_TB52	: STD_LOGIC;
   
   -- PMA Per Channel RX Control Register 18 for Channel 0
   SIGNAL cram_radce_digital	: STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL cram_reserved_0_TB53	: STD_LOGIC_VECTOR(5 DOWNTO 0); 
   
   -- Extra
   SIGNAL cram_rlpbk		: STD_LOGIC;
   SIGNAL cram_rrevlb_sw	: STD_LOGIC;
   SIGNAL cram_rrx_s_lpbk	: STD_LOGIC;
   
   SIGNAL dpriodisable_in       : STD_LOGIC;

BEGIN
       
      ------------------------
      --  Wire Delay Block --
      ------------------------
      WireDelay : BLOCK
      BEGIN
           VitalWireDelay (datain_ipd,datain, tipd_datain);
           VitalWireDelay (ppmdetectdividedclk_ipd,ppmdetectdividedclk, tipd_ppmdetectdividedclk);
           VitalWireDelay (rxpmareset_ipd,rxpmareset, tipd_rxpmareset);
           VitalWireDelay (plllocked_ipd,plllocked, tipd_plllocked);
           VitalWireDelay (dpriodisable_ipd,dpriodisable, tipd_dpriodisable);
           VitalWireDelay (ignorephslck_ipd,ignorephslck, tipd_ignorephslck);
           VitalWireDelay (locktoref_ipd,locktoref, tipd_locktoref);
           VitalWireDelay (adcepowerdn_ipd,adcepowerdn, tipd_adcepowerdn);
           VitalWireDelay (adcestandby_ipd,adcestandby, tipd_adcestandby);
           VitalWireDelay (ppmdetectrefclk_ipd,ppmdetectrefclk, tipd_ppmdetectrefclk);
           VitalWireDelay (powerdn_ipd,powerdn, tipd_powerdn);
           VitalWireDelay (seriallpbken_ipd,seriallpbken, tipd_seriallpbken);
           VitalWireDelay (adcereset_ipd,adcereset, tipd_adcereset);
       bits_deserclock : FOR i in deserclock'RANGE GENERATE
           VitalWireDelay (deserclock_ipd(i),deserclock(i), tipd_deserclock(i));
       END GENERATE;
           VitalWireDelay (locktodata_ipd,locktodata, tipd_locktodata);
           VitalWireDelay (freqlock_ipd,freqlock, tipd_freqlock);
           VitalWireDelay (offsetcancellationen_ipd,offsetcancellationen, tipd_offsetcancellationen);
       bits_testbussel : FOR i in testbussel'RANGE GENERATE
           VitalWireDelay (testbussel_ipd(i),testbussel(i), tipd_testbussel(i));
       END GENERATE;
       bits_recoverdatain : FOR i in recoverdatain'RANGE GENERATE
           VitalWireDelay (recoverdatain_ipd(i),recoverdatain(i), tipd_recoverdatain(i));
       END GENERATE;
           VitalWireDelay (seriallpbkin_ipd,seriallpbkin, tipd_seriallpbkin);
       bits_dprioin : FOR i in dprioin'RANGE GENERATE
           VitalWireDelay (dprioin_ipd(i),dprioin(i), tipd_dprioin(i));
       END GENERATE;
           VitalWireDelay (adaptcapture_ipd,adaptcapture, tipd_adaptcapture);
      END BLOCK;
  
        -- new DPRIO model begin --
        -- ---------------------------------------------------------------------------
        -- Set DPRIO CRAM input from dprioin  
        -- ---------------------------------------------------------------------------
        
        -- PMA Per Channel RX Control Register 1 for Channel 0
        dprioin_rrx_term_sel	<= dprioin(rrx_term_sel_RXPMA_IDX_2 DOWNTO rrx_term_sel_RXPMA_IDX_0);
        dprioin_rrx_vtt	<= dprioin(rrx_vtt_RXPMA_IDX_2 DOWNTO rrx_vtt_RXPMA_IDX_0);
        dprioin_rrx_s_rdlpbk	<= dprioin(rrx_s_rdlpbk_RXPMA_IDX_0);
        dprioin_rrx_bit_dc	<= dprioin(rrx_bit_dc_RXPMA_IDX_3 DOWNTO rrx_bit_dc_RXPMA_IDX_0);
        dprioin_rrx_lst	<= dprioin(rrx_lst_RXPMA_IDX_4 DOWNTO rrx_lst_RXPMA_IDX_0);
        
        -- PMA Per Channel RX Control Register 2 for Channel 0
        dprioin_rrxurstpma	<= dprioin(rrxurstpma_RXPMA_IDX_0);
        dprioin_rrx_test	<= dprioin(rrx_test_RXPMA_IDX_0);
        dprioin_rrx_sd_force	<= dprioin(rrx_sd_force_RXPMA_IDX_0);
        dprioin_rrx_oc	<= dprioin(rrx_oc_RXPMA_IDX_7 DOWNTO rrx_oc_RXPMA_IDX_0);
        dprioin_rrx_oc_en	<= dprioin(rrx_oc_en_RXPMA_IDX_0);
        dprioin_rrx_sdlv	<= dprioin(rrx_sdlv_RXPMA_IDX_3 DOWNTO rrx_sdlv_RXPMA_IDX_0);
        
        -- PMA Per Channel RX Control Register 3 for Channel 0
        dprioin_reserved_0_TB38	<= dprioin(reserved_0_TB38_RXPMA_IDX_2 DOWNTO reserved_0_TB38_RXPMA_IDX_0);
        dprioin_rpowdnr	<= dprioin(rpowdnr_RXPMA_IDX_0);
        dprioin_rrx_ib_pdb	<= dprioin(rrx_ib_pdb_RXPMA_IDX_0);
        dprioin_rurx_pdb	<= dprioin(rurx_pdb_RXPMA_IDX_0);
        dprioin_rrx_oc_calpd	<= dprioin(rrx_oc_calpd_RXPMA_IDX_0);
        dprioin_rrx_sd_off	<= dprioin(rrx_sd_off_RXPMA_IDX_4 DOWNTO rrx_sd_off_RXPMA_IDX_0);
        dprioin_rrx_sd_on	<= dprioin(rrx_sd_on_RXPMA_IDX_3 DOWNTO rrx_sd_on_RXPMA_IDX_0);
        
        -- PMA Per Channel RX Control Register 8 for Channel 0
        dprioin_reye_monitor	<= dprioin(reye_monitor_RXPMA_IDX_7 DOWNTO reye_monitor_RXPMA_IDX_0);
        dprioin_reserved_0_TB43	<= dprioin(reserved_0_TB43_RXPMA_IDX_7 DOWNTO reserved_0_TB43_RXPMA_IDX_0);
        
        -- PMA Per Channel RX Control Register 9 for Channel 0
        dprioin_rpma_reserved_0_TB44	<= dprioin(rpma_reserved_0_TB44_RXPMA_IDX_15 DOWNTO rpma_reserved_0_TB44_RXPMA_IDX_0);
        
        -- PMA Per Channel RX Control Register 10 for Channel 0
        dprioin_rppm_cnt_reset	<= dprioin(rppm_cnt_reset_RXPMA_IDX_0);
        dprioin_rforce1_freqdet	<= dprioin(rforce1_freqdet_RXPMA_IDX_0);
        dprioin_rforce0_freqdet	<= dprioin(rforce0_freqdet_RXPMA_IDX_0);
        dprioin_rppmsel	<= dprioin(rppmsel_RXPMA_IDX_5 DOWNTO rppmsel_RXPMA_IDX_0);
        dprioin_rfastsd	<= dprioin(rfastsd_RXPMA_IDX_3 DOWNTO rfastsd_RXPMA_IDX_0);
        dprioin_rtest_fastsd	<= dprioin(rtest_fastsd_RXPMA_IDX_0);
        dprioin_rpmadwidth_rx	<= dprioin(rpmadwidth_rx_RXPMA_IDX_0);
        dprioin_rpma_doublewidth_rx	<= dprioin(rpma_doublewidth_rx_RXPMA_IDX_0);
        
        -- PMA Per Channel RX Control Register 11 for Channel 0
        dprioin_reserved_0_TB46	<= dprioin(reserved_0_TB46_RXPMA_IDX_7 DOWNTO reserved_0_TB46_RXPMA_IDX_0);
        dprioin_rppm_gen1_2xcnt_en	<= dprioin(rppm_gen1_2xcnt_en_RXPMA_IDX_0);
        dprioin_rppm_post_eidle_del	<= dprioin(rppm_post_eidle_del_RXPMA_IDX_0);
        dprioin_r_dfe_2t	<= dprioin(r_dfe_2t_RXPMA_IDX_2 DOWNTO r_dfe_2t_RXPMA_IDX_0);
        dprioin_r_dfe_1t	<= dprioin(r_dfe_1t_RXPMA_IDX_2 DOWNTO r_dfe_1t_RXPMA_IDX_0);
        
        -- PMA Per Channel RX Control Register 12 for Channel 0
        dprioin_reqv_set	<= dprioin(reqv_set_RXPMA_IDX_2 DOWNTO reqv_set_RXPMA_IDX_0);
        dprioin_reqd_set	<= dprioin(reqd_set_RXPMA_IDX_2 DOWNTO reqd_set_RXPMA_IDX_0);
        dprioin_reqc_set	<= dprioin(reqc_set_RXPMA_IDX_2 DOWNTO reqc_set_RXPMA_IDX_0);
        dprioin_reqb_set	<= dprioin(reqb_set_RXPMA_IDX_2 DOWNTO reqb_set_RXPMA_IDX_0);
        dprioin_reqa_set	<= dprioin(reqa_set_RXPMA_IDX_2 DOWNTO reqa_set_RXPMA_IDX_0);
        dprioin_reserved_0_TB47	<= dprioin(reserved_0_TB47_RXPMA_IDX_0);
        
        -- PMA Per Channel RX Control Register 13 for Channel 0
        dprioin_rdc_freq	<= dprioin(rdc_freq_RXPMA_IDX_1 DOWNTO rdc_freq_RXPMA_IDX_0);
        dprioin_rhyst_lf	<= dprioin(rhyst_lf_RXPMA_IDX_2 DOWNTO rhyst_lf_RXPMA_IDX_0);
        dprioin_rclkdiv	<= dprioin(rclkdiv_RXPMA_IDX_3 DOWNTO rclkdiv_RXPMA_IDX_0);
        dprioin_rrgen_set	<= dprioin(rrgen_set_RXPMA_IDX_2 DOWNTO rrgen_set_RXPMA_IDX_0);
        dprioin_radce_adapt	<= dprioin(radce_adapt_RXPMA_IDX_0);
        dprioin_rseq_sel	<= dprioin(rseq_sel_RXPMA_IDX_1 DOWNTO rseq_sel_RXPMA_IDX_0);
        dprioin_rlock_lf_ovd	<= dprioin(rlock_lf_ovd_RXPMA_IDX_0);
        
        -- PMA Per Channel RX Control Register 14 for Channel 0
        dprioin_rrgen_vod	<= dprioin(rrgen_vod_RXPMA_IDX_2 DOWNTO rrgen_vod_RXPMA_IDX_0);
        dprioin_rf_hpf	<= dprioin(rf_hpf_RXPMA_IDX_1 DOWNTO rf_hpf_RXPMA_IDX_0);
        dprioin_rf_lpf	<= dprioin(rf_lpf_RXPMA_IDX_1 DOWNTO rf_lpf_RXPMA_IDX_0);
        dprioin_reserved_1_TB49	<= dprioin(reserved_1_TB49_RXPMA_IDX_2 DOWNTO reserved_1_TB49_RXPMA_IDX_0);
        dprioin_reserved_0_TB49	<= dprioin(reserved_0_TB49_RXPMA_IDX_2 DOWNTO reserved_0_TB49_RXPMA_IDX_0);
        dprioin_rhyst_hf	<= dprioin(rhyst_hf_RXPMA_IDX_2 DOWNTO rhyst_hf_RXPMA_IDX_0);
        
        -- PMA Per Channel RX Control Register 15 for Channel 0
        dprioin_radce_pdb	<= dprioin(radce_pdb_RXPMA_IDX_0);
        dprioin_radce_rst	<= dprioin(radce_rst_RXPMA_IDX_0);
        dprioin_rhf_os	<= dprioin(rhf_os_RXPMA_IDX_3 DOWNTO rhf_os_RXPMA_IDX_0);
        dprioin_rlf_os	<= dprioin(rlf_os_RXPMA_IDX_3 DOWNTO rlf_os_RXPMA_IDX_0);
        dprioin_rd2a_res	<= dprioin(rd2a_res_RXPMA_IDX_1 DOWNTO rd2a_res_RXPMA_IDX_0);
        dprioin_rrect_adj	<= dprioin(rrect_adj_RXPMA_IDX_1 DOWNTO rrect_adj_RXPMA_IDX_0);
        dprioin_rrgen_bw	<= dprioin(rrgen_bw_RXPMA_IDX_1 DOWNTO rrgen_bw_RXPMA_IDX_0);
        
        -- PMA Per Channel RX Control Register 16 for Channel 0
        dprioin_radce_hflck	<= dprioin(radce_hflck_RXPMA_IDX_14 DOWNTO radce_hflck_RXPMA_IDX_0);
        dprioin_reserved_0_TB51	<= dprioin(reserved_0_TB51_RXPMA_IDX_0);
        
        -- PMA Per Channel RX Control Register 17 for Channel 0
        dprioin_radce_lflck	<= dprioin(radce_lflck_RXPMA_IDX_14 DOWNTO radce_lflck_RXPMA_IDX_0);
        dprioin_reserved_0_TB52	<= dprioin(reserved_0_TB52_RXPMA_IDX_0);
        
        -- PMA Per Channel RX Control Register 18 for Channel 0
        dprioin_radce_digital	<= dprioin(radce_digital_RXPMA_IDX_9 DOWNTO radce_digital_RXPMA_IDX_0);
        dprioin_reserved_0_TB53	<= dprioin(reserved_0_TB53_RXPMA_IDX_5 DOWNTO reserved_0_TB53_RXPMA_IDX_0);
        
        -- Extra
	dprioin_rlpbk 		<= dprioin(RLPBK_RXPMA_IDX);
	dprioin_rrevlb_sw  	<= dprioin(RREVLB_SW_RXPMA_IDX);
	dprioin_rrx_s_lpbk 	<= dprioin(RRX_S_LPBK_RXPMA_IDX);
        
        -- ---------------------------------------------------------------------------
        -- Set DPRIO output from initial CRAM
        -- ---------------------------------------------------------------------------
        
        -- PMA Per Channel RX Control Register 1 for Channel 0
        dprioout(rrx_term_sel_RXPMA_IDX_2 DOWNTO rrx_term_sel_RXPMA_IDX_0) <= init_rrx_term_sel;
        dprioout(rrx_vtt_RXPMA_IDX_2 DOWNTO rrx_vtt_RXPMA_IDX_0) <= init_rrx_vtt;
        dprioout(rrx_s_rdlpbk_RXPMA_IDX_0) <= init_rrx_s_rdlpbk;
        dprioout(rrx_bit_dc_RXPMA_IDX_3 DOWNTO rrx_bit_dc_RXPMA_IDX_0) <= init_rrx_bit_dc;
        dprioout(rrx_lst_RXPMA_IDX_4 DOWNTO rrx_lst_RXPMA_IDX_0) <= init_rrx_lst;
        
        -- PMA Per Channel RX Control Register 2 for Channel 0
        dprioout(rrxurstpma_RXPMA_IDX_0) <= init_rrxurstpma;
        dprioout(rrx_test_RXPMA_IDX_0) <= init_rrx_test;
        dprioout(rrx_sd_force_RXPMA_IDX_0) <= init_rrx_sd_force;
        dprioout(rrx_oc_RXPMA_IDX_7 DOWNTO rrx_oc_RXPMA_IDX_0) <= init_rrx_oc;
        dprioout(rrx_oc_en_RXPMA_IDX_0) <= init_rrx_oc_en;
        dprioout(rrx_sdlv_RXPMA_IDX_3 DOWNTO rrx_sdlv_RXPMA_IDX_0) <= init_rrx_sdlv;
        
        -- PMA Per Channel RX Control Register 3 for Channel 0
        dprioout(reserved_0_TB38_RXPMA_IDX_2 DOWNTO reserved_0_TB38_RXPMA_IDX_0) <= init_reserved_0_TB38;
        dprioout(rpowdnr_RXPMA_IDX_0) <= init_rpowdnr;
        dprioout(rrx_ib_pdb_RXPMA_IDX_0) <= init_rrx_ib_pdb;
        dprioout(rurx_pdb_RXPMA_IDX_0) <= init_rurx_pdb;
        dprioout(rrx_oc_calpd_RXPMA_IDX_0) <= init_rrx_oc_calpd;
        dprioout(rrx_sd_off_RXPMA_IDX_4 DOWNTO rrx_sd_off_RXPMA_IDX_0) <= init_rrx_sd_off;
        dprioout(rrx_sd_on_RXPMA_IDX_3 DOWNTO rrx_sd_on_RXPMA_IDX_0) <= init_rrx_sd_on;
        
        -- PMA Per Channel RX Control Register 8 for Channel 0
        dprioout(reye_monitor_RXPMA_IDX_7 DOWNTO reye_monitor_RXPMA_IDX_0) <= init_reye_monitor;
        dprioout(reserved_0_TB43_RXPMA_IDX_7 DOWNTO reserved_0_TB43_RXPMA_IDX_0) <= init_reserved_0_TB43;
        
        -- PMA Per Channel RX Control Register 9 for Channel 0
        dprioout(rpma_reserved_0_TB44_RXPMA_IDX_15 DOWNTO rpma_reserved_0_TB44_RXPMA_IDX_0) <= init_rpma_reserved_0_TB44;
        
        -- PMA Per Channel RX Control Register 10 for Channel 0
        dprioout(rppm_cnt_reset_RXPMA_IDX_0) <= init_rppm_cnt_reset;
        dprioout(rforce1_freqdet_RXPMA_IDX_0) <= init_rforce1_freqdet;
        dprioout(rforce0_freqdet_RXPMA_IDX_0) <= init_rforce0_freqdet;
        dprioout(rppmsel_RXPMA_IDX_5 DOWNTO rppmsel_RXPMA_IDX_0) <= init_rppmsel;
        dprioout(rfastsd_RXPMA_IDX_3 DOWNTO rfastsd_RXPMA_IDX_0) <= init_rfastsd;
        dprioout(rtest_fastsd_RXPMA_IDX_0) <= init_rtest_fastsd;
        dprioout(rpmadwidth_rx_RXPMA_IDX_0) <= init_rpmadwidth_rx;
        dprioout(rpma_doublewidth_rx_RXPMA_IDX_0) <= init_rpma_doublewidth_rx;
        
        -- PMA Per Channel RX Control Register 11 for Channel 0
        dprioout(reserved_0_TB46_RXPMA_IDX_7 DOWNTO reserved_0_TB46_RXPMA_IDX_0) <= init_reserved_0_TB46;
        dprioout(rppm_gen1_2xcnt_en_RXPMA_IDX_0) <= init_rppm_gen1_2xcnt_en;
        dprioout(rppm_post_eidle_del_RXPMA_IDX_0) <= init_rppm_post_eidle_del;
        dprioout(r_dfe_2t_RXPMA_IDX_2 DOWNTO r_dfe_2t_RXPMA_IDX_0) <= init_r_dfe_2t;
        dprioout(r_dfe_1t_RXPMA_IDX_2 DOWNTO r_dfe_1t_RXPMA_IDX_0) <= init_r_dfe_1t;
        
        -- PMA Per Channel RX Control Register 12 for Channel 0
        dprioout(reqv_set_RXPMA_IDX_2 DOWNTO reqv_set_RXPMA_IDX_0) <= init_reqv_set;
        dprioout(reqd_set_RXPMA_IDX_2 DOWNTO reqd_set_RXPMA_IDX_0) <= init_reqd_set;
        dprioout(reqc_set_RXPMA_IDX_2 DOWNTO reqc_set_RXPMA_IDX_0) <= init_reqc_set;
        dprioout(reqb_set_RXPMA_IDX_2 DOWNTO reqb_set_RXPMA_IDX_0) <= init_reqb_set;
        dprioout(reqa_set_RXPMA_IDX_2 DOWNTO reqa_set_RXPMA_IDX_0) <= init_reqa_set;
        dprioout(reserved_0_TB47_RXPMA_IDX_0) <= init_reserved_0_TB47;
        
        -- PMA Per Channel RX Control Register 13 for Channel 0
        dprioout(rdc_freq_RXPMA_IDX_1 DOWNTO rdc_freq_RXPMA_IDX_0) <= init_rdc_freq;
        dprioout(rhyst_lf_RXPMA_IDX_2 DOWNTO rhyst_lf_RXPMA_IDX_0) <= init_rhyst_lf;
        dprioout(rclkdiv_RXPMA_IDX_3 DOWNTO rclkdiv_RXPMA_IDX_0) <= init_rclkdiv;
        dprioout(rrgen_set_RXPMA_IDX_2 DOWNTO rrgen_set_RXPMA_IDX_0) <= init_rrgen_set;
        dprioout(radce_adapt_RXPMA_IDX_0) <= init_radce_adapt;
        dprioout(rseq_sel_RXPMA_IDX_1 DOWNTO rseq_sel_RXPMA_IDX_0) <= init_rseq_sel;
        dprioout(rlock_lf_ovd_RXPMA_IDX_0) <= init_rlock_lf_ovd;
        
        -- PMA Per Channel RX Control Register 14 for Channel 0
        dprioout(rrgen_vod_RXPMA_IDX_2 DOWNTO rrgen_vod_RXPMA_IDX_0) <= init_rrgen_vod;
        dprioout(rf_hpf_RXPMA_IDX_1 DOWNTO rf_hpf_RXPMA_IDX_0) <= init_rf_hpf;
        dprioout(rf_lpf_RXPMA_IDX_1 DOWNTO rf_lpf_RXPMA_IDX_0) <= init_rf_lpf;
        dprioout(reserved_1_TB49_RXPMA_IDX_2 DOWNTO reserved_1_TB49_RXPMA_IDX_0) <= init_reserved_1_TB49;
        dprioout(reserved_0_TB49_RXPMA_IDX_2 DOWNTO reserved_0_TB49_RXPMA_IDX_0) <= init_reserved_0_TB49;
        dprioout(rhyst_hf_RXPMA_IDX_2 DOWNTO rhyst_hf_RXPMA_IDX_0) <= init_rhyst_hf;
        
        -- PMA Per Channel RX Control Register 15 for Channel 0
        dprioout(radce_pdb_RXPMA_IDX_0) <= init_radce_pdb;
        dprioout(radce_rst_RXPMA_IDX_0) <= init_radce_rst;
        dprioout(rhf_os_RXPMA_IDX_3 DOWNTO rhf_os_RXPMA_IDX_0) <= init_rhf_os;
        dprioout(rlf_os_RXPMA_IDX_3 DOWNTO rlf_os_RXPMA_IDX_0) <= init_rlf_os;
        dprioout(rd2a_res_RXPMA_IDX_1 DOWNTO rd2a_res_RXPMA_IDX_0) <= init_rd2a_res;
        dprioout(rrect_adj_RXPMA_IDX_1 DOWNTO rrect_adj_RXPMA_IDX_0) <= init_rrect_adj;
        dprioout(rrgen_bw_RXPMA_IDX_1 DOWNTO rrgen_bw_RXPMA_IDX_0) <= init_rrgen_bw;
        
        -- PMA Per Channel RX Control Register 16 for Channel 0
        dprioout(radce_hflck_RXPMA_IDX_14 DOWNTO radce_hflck_RXPMA_IDX_0) <= init_radce_hflck;
        dprioout(reserved_0_TB51_RXPMA_IDX_0) <= init_reserved_0_TB51;
        
        -- PMA Per Channel RX Control Register 17 for Channel 0
        dprioout(radce_lflck_RXPMA_IDX_14 DOWNTO radce_lflck_RXPMA_IDX_0) <= init_radce_lflck;
        dprioout(reserved_0_TB52_RXPMA_IDX_0) <= init_reserved_0_TB52;
        
        -- PMA Per Channel RX Control Register 18 for Channel 0
        dprioout(radce_digital_RXPMA_IDX_9 DOWNTO radce_digital_RXPMA_IDX_0) <= init_radce_digital;
        dprioout(reserved_0_TB53_RXPMA_IDX_5 DOWNTO reserved_0_TB53_RXPMA_IDX_0) <= init_reserved_0_TB53;
        
        -- Extra
	dprioout(RLPBK_RXPMA_IDX) <= init_rlpbk;
	dprioout(RREVLB_SW_RXPMA_IDX) <= init_rrevlb_sw;
	dprioout(RRX_S_LPBK_RXPMA_IDX) <= init_rrx_s_lpbk;
        
        -- ---------------------------------------------------------------------------
        -- Set DPRIO CRAM
        -- ---------------------------------------------------------------------------
        dpriodisable_in <= '0' WHEN (dpriodisable = '0') ELSE '1';
                      
        -- PMA Per Channel RX Control Register 1 for Channel 0
        cram_rrx_term_sel <= init_rrx_term_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_term_sel;
        cram_rrx_vtt <= init_rrx_vtt WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_vtt;
        cram_rrx_s_rdlpbk <= init_rrx_s_rdlpbk WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_s_rdlpbk;
        cram_rrx_bit_dc <= init_rrx_bit_dc WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_bit_dc;
        cram_rrx_lst <= init_rrx_lst WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_lst;
        
        -- PMA Per Channel RX Control Register 2 for Channel 0
        cram_rrxurstpma <= init_rrxurstpma WHEN (dpriodisable_in /= '0') ELSE dprioin_rrxurstpma;
        cram_rrx_test <= init_rrx_test WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_test;
        cram_rrx_sd_force <= init_rrx_sd_force WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_sd_force;
        cram_rrx_oc <= init_rrx_oc WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_oc;
        cram_rrx_oc_en <= init_rrx_oc_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_oc_en;
        cram_rrx_sdlv <= init_rrx_sdlv WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_sdlv;
        
        -- PMA Per Channel RX Control Register 3 for Channel 0
        cram_reserved_0_TB38 <= init_reserved_0_TB38 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB38;
        cram_rpowdnr <= init_rpowdnr WHEN (dpriodisable_in /= '0') ELSE dprioin_rpowdnr;
        cram_rrx_ib_pdb <= init_rrx_ib_pdb WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_ib_pdb;
        cram_rurx_pdb <= init_rurx_pdb WHEN (dpriodisable_in /= '0') ELSE dprioin_rurx_pdb;
        cram_rrx_oc_calpd <= init_rrx_oc_calpd WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_oc_calpd;
        cram_rrx_sd_off <= init_rrx_sd_off WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_sd_off;
        cram_rrx_sd_on <= init_rrx_sd_on WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_sd_on;
        
        -- PMA Per Channel RX Control Register 8 for Channel 0
        cram_reye_monitor <= init_reye_monitor WHEN (dpriodisable_in /= '0') ELSE dprioin_reye_monitor;
        cram_reserved_0_TB43 <= init_reserved_0_TB43 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB43;
        
        -- PMA Per Channel RX Control Register 9 for Channel 0
        cram_rpma_reserved_0_TB44 <= init_rpma_reserved_0_TB44 WHEN (dpriodisable_in /= '0') ELSE dprioin_rpma_reserved_0_TB44;
        
        -- PMA Per Channel RX Control Register 10 for Channel 0
        cram_rppm_cnt_reset <= init_rppm_cnt_reset WHEN (dpriodisable_in /= '0') ELSE dprioin_rppm_cnt_reset;
        cram_rforce1_freqdet <= init_rforce1_freqdet WHEN (dpriodisable_in /= '0') ELSE dprioin_rforce1_freqdet;
        cram_rforce0_freqdet <= init_rforce0_freqdet WHEN (dpriodisable_in /= '0') ELSE dprioin_rforce0_freqdet;
        cram_rppmsel <= init_rppmsel WHEN (dpriodisable_in /= '0') ELSE dprioin_rppmsel;
        cram_rfastsd <= init_rfastsd WHEN (dpriodisable_in /= '0') ELSE dprioin_rfastsd;
        cram_rtest_fastsd <= init_rtest_fastsd WHEN (dpriodisable_in /= '0') ELSE dprioin_rtest_fastsd;
        cram_rpmadwidth_rx <= init_rpmadwidth_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rpmadwidth_rx;
        cram_rpma_doublewidth_rx <= init_rpma_doublewidth_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rpma_doublewidth_rx;
        
        -- PMA Per Channel RX Control Register 11 for Channel 0
        cram_reserved_0_TB46 <= init_reserved_0_TB46 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB46;
        cram_rppm_gen1_2xcnt_en <= init_rppm_gen1_2xcnt_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rppm_gen1_2xcnt_en;
        cram_rppm_post_eidle_del <= init_rppm_post_eidle_del WHEN (dpriodisable_in /= '0') ELSE dprioin_rppm_post_eidle_del;
        cram_r_dfe_2t <= init_r_dfe_2t WHEN (dpriodisable_in /= '0') ELSE dprioin_r_dfe_2t;
        cram_r_dfe_1t <= init_r_dfe_1t WHEN (dpriodisable_in /= '0') ELSE dprioin_r_dfe_1t;
        
        -- PMA Per Channel RX Control Register 12 for Channel 0
        cram_reqv_set <= init_reqv_set WHEN (dpriodisable_in /= '0') ELSE dprioin_reqv_set;
        cram_reqd_set <= init_reqd_set WHEN (dpriodisable_in /= '0') ELSE dprioin_reqd_set;
        cram_reqc_set <= init_reqc_set WHEN (dpriodisable_in /= '0') ELSE dprioin_reqc_set;
        cram_reqb_set <= init_reqb_set WHEN (dpriodisable_in /= '0') ELSE dprioin_reqb_set;
        cram_reqa_set <= init_reqa_set WHEN (dpriodisable_in /= '0') ELSE dprioin_reqa_set;
        cram_reserved_0_TB47 <= init_reserved_0_TB47 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB47;
        
        -- PMA Per Channel RX Control Register 13 for Channel 0
        cram_rdc_freq <= init_rdc_freq WHEN (dpriodisable_in /= '0') ELSE dprioin_rdc_freq;
        cram_rhyst_lf <= init_rhyst_lf WHEN (dpriodisable_in /= '0') ELSE dprioin_rhyst_lf;
        cram_rclkdiv <= init_rclkdiv WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkdiv;
        cram_rrgen_set <= init_rrgen_set WHEN (dpriodisable_in /= '0') ELSE dprioin_rrgen_set;
        cram_radce_adapt <= init_radce_adapt WHEN (dpriodisable_in /= '0') ELSE dprioin_radce_adapt;
        cram_rseq_sel <= init_rseq_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rseq_sel;
        cram_rlock_lf_ovd <= init_rlock_lf_ovd WHEN (dpriodisable_in /= '0') ELSE dprioin_rlock_lf_ovd;
        
        -- PMA Per Channel RX Control Register 14 for Channel 0
        cram_rrgen_vod <= init_rrgen_vod WHEN (dpriodisable_in /= '0') ELSE dprioin_rrgen_vod;
        cram_rf_hpf <= init_rf_hpf WHEN (dpriodisable_in /= '0') ELSE dprioin_rf_hpf;
        cram_rf_lpf <= init_rf_lpf WHEN (dpriodisable_in /= '0') ELSE dprioin_rf_lpf;
        cram_reserved_1_TB49 <= init_reserved_1_TB49 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_1_TB49;
        cram_reserved_0_TB49 <= init_reserved_0_TB49 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB49;
        cram_rhyst_hf <= init_rhyst_hf WHEN (dpriodisable_in /= '0') ELSE dprioin_rhyst_hf;
        
        -- PMA Per Channel RX Control Register 15 for Channel 0
        cram_radce_pdb <= init_radce_pdb WHEN (dpriodisable_in /= '0') ELSE dprioin_radce_pdb;
        cram_radce_rst <= init_radce_rst WHEN (dpriodisable_in /= '0') ELSE dprioin_radce_rst;
        cram_rhf_os <= init_rhf_os WHEN (dpriodisable_in /= '0') ELSE dprioin_rhf_os;
        cram_rlf_os <= init_rlf_os WHEN (dpriodisable_in /= '0') ELSE dprioin_rlf_os;
        cram_rd2a_res <= init_rd2a_res WHEN (dpriodisable_in /= '0') ELSE dprioin_rd2a_res;
        cram_rrect_adj <= init_rrect_adj WHEN (dpriodisable_in /= '0') ELSE dprioin_rrect_adj;
        cram_rrgen_bw <= init_rrgen_bw WHEN (dpriodisable_in /= '0') ELSE dprioin_rrgen_bw;
        
        -- PMA Per Channel RX Control Register 16 for Channel 0
        cram_radce_hflck <= init_radce_hflck WHEN (dpriodisable_in /= '0') ELSE dprioin_radce_hflck;
        cram_reserved_0_TB51 <= init_reserved_0_TB51 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB51;
        
        -- PMA Per Channel RX Control Register 17 for Channel 0
        cram_radce_lflck <= init_radce_lflck WHEN (dpriodisable_in /= '0') ELSE dprioin_radce_lflck;
        cram_reserved_0_TB52 <= init_reserved_0_TB52 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB52;
        
        -- PMA Per Channel RX Control Register 18 for Channel 0
        cram_radce_digital <= init_radce_digital WHEN (dpriodisable_in /= '0') ELSE dprioin_radce_digital;
        cram_reserved_0_TB53 <= init_reserved_0_TB53 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB53;
  
  	-- Extra
  	cram_rlpbk 	<= init_rlpbk WHEN (dpriodisable_in /= '0') ELSE dprioin_rlpbk;
  	cram_rrevlb_sw 	<= init_rrevlb_sw WHEN (dpriodisable_in /= '0') ELSE dprioin_rrevlb_sw;
	cram_rrx_s_lpbk <= init_rrx_s_lpbk WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_s_lpbk;
  
    PROCESS 
   	BEGIN
  
      -- RX PMA control register 1
  	init_rrx_term_sel	<= "000";
  	init_rrx_vtt		<= (mux_select((alpha_tolower(common_mode) = ("0.82v")), "010", mux_select((alpha_tolower(common_mode) = ("tristate")), "100", mux_select((alpha_tolower(common_mode) = ("1.1v")), "001", "000"))));
  	init_rrx_s_rdlpbk	<= mux_select((alpha_tolower(send_direct_reverse_serial_loopback) = ("pre-cdr")), '1', '0');
  	init_rrx_bit_dc		<= (mux_select((eq_dc_gain = 3), "0001", mux_select((eq_dc_gain = 6), "0011", mux_select((eq_dc_gain = 9), "0111", mux_select((eq_dc_gain = 12), "1111", "0000")))));
  	init_rrx_lst		<= int2bin(low_speed_test_select, 5);
  	
  	-- RX PMA control register 2
  	init_rrxurstpma		<= '0';
  	init_rrx_test		<= '0';
  	init_rrx_sd_force	<= mux_select((force_signal_detect = ("true")), '1', '0');
  	init_rrx_oc			<= int2bin(offset_cancellation, 8);
  	init_rrx_oc_en		<= '0';
  	init_rrx_sdlv		<= "0000";
  
  	-- RX PMA control register 3
  	init_reserved_0_TB38	<= "000";
  	init_rpowdnr		<= '0';	
  	init_rrx_ib_pdb		<= '0';	
  	init_rurx_pdb		<= '0';	
  	init_rrx_oc_calpd	<= '0';
  	init_rrx_sd_off		<= int2bin(signal_detect_loss_threshold, 5); 
  	init_rrx_sd_on		<= int2bin(signal_detect_hysteresis_valid_threshold, 4);
  	
  	-- RX PMA control register 12
  	init_reqv_set	<= int2bin(eqv_ctrl, 3);
  	init_reqd_set	<= int2bin(eqd_ctrl, 3);
  	init_reqc_set	<= int2bin(eqc_ctrl, 3);
  	init_reqb_set	<= int2bin(eqb_ctrl, 3);
  	init_reqa_set	<= int2bin(eqa_ctrl, 3);
  	init_reserved_0_TB47 <= '0';
  	
  	-- RX PMA Control Register 10
	init_rppmsel <= int2bin(ppmselect, 6);
  	
  	-- extra
	init_rpma_doublewidth_rx <= mux_select((deserialization_factor = 16 OR deserialization_factor = 20), '1', '0'); --rdeser_div2_init
	init_rpmadwidth_rx 	 <= mux_select((deserialization_factor = 10 OR deserialization_factor = 20), '1', '0');		--rdeser_div5_init
	init_rlpbk 		 <= mux_select((alpha_tolower(send_direct_reverse_serial_loopback) = ("post-cdr")), '1', '0');
	init_rrevlb_sw 		 <= init_rlpbk;    
   	init_rrx_s_lpbk 	 <= (mux_select((allow_serial_loopback = ("true")), '1', '0'));  
  	
      WAIT;
   END PROCESS;
      -- new DPRIO model end --     
      
      ------------------------
      --  Functionality Section --
      ------------------------
   vcce_la <= '1';
   vcce_oa <= '1';
   vccehtx <= '1';
   vssex <= '0';

   xadce_adapt_capture <= adaptcapture;
   xadce_eqin_n <= rx_eqout_n;
   xadce_eqin_p <= rx_eqout_p;

   xadce_pdb <= '0' WHEN (adcepowerdn = '1') ELSE '1';
   xadce_rstb <= '0' WHEN (adcereset = '1') ELSE '1';
   xadce_standby <= '0' WHEN (adcestandby = '1') ELSE '1';
   
   reqa_set <= cram_reqa_set(2 DOWNTO 0);
   reqb_set <= cram_reqb_set(2 DOWNTO 0);
   reqc_set <= cram_reqc_set;
   reqd_set <= cram_reqd_set;
   reqv_set <= cram_reqv_set;
   
   xadce : stratixiv_hssi_pma_c_adce
      PORT MAP (
         adapt_capture    => xadce_adapt_capture,
         atben            => xadce_atben,
         atbsel           => xadce_atbsel,
         eqa_set          => reqa_set,
         eqb_set          => reqb_set,
         eqc_set          => reqc_set,
         eqd_set          => reqd_set,
         eqin_n           => xadce_eqin_n,
         eqin_p           => xadce_eqin_p,
         eqv_set          => reqv_set,
         fixed_clk        => xadce_fixed_clk,
         lock_lf_ovd      => xadce_lock_lf_ovd,
         lst              => rrx_lst,
         radce_adapt      => radce_adapt,
         radce_digital    => radce_digital,
         radce_hflck      => radce_hflck,
         radce_lflck      => radce_lflck,
         radce_pdb        => xadce_pdb,
         radce_rstb       => xadce_rstb,
         radce_vod_int    => radce_vod_int,
         radce_vod_lsb    => radce_vod_lsb,
         rbit_dc          => vssex,
         rclkdiv          => rclkdiv,
         rd2a_res         => rd2a_res,
         rdc_freq         => rdc_freq,
         rdfe_en          => xadce_rdfe_en,
         rf_hpf           => rf_hpf,
         rf_lpf           => rf_lpf,
         rhf_os           => rhf_os,
         rhyst_hf         => rhyst_hf,
         rhyst_lf         => rhyst_lf,
         rlf_os           => rlf_os,
         rrect_adj        => rrect_adj,
         rrgen_bw         => rrgen_bw,
         rrgen_set        => rrgen_set,
         rrgen_vod        => rrgen_vod,
         rseq_sel         => rseq_sel,
         standby          => xadce_standby,
         vbn              => xadce_vbn,

         atb0             => xadce_atb0,
         atb1             => xadce_atb1,
         atb_0            => atb_0,
         atb_1            => atb_1,
         ib50u_c          => xadce_ib50u_c,
         ib50u_t          => xadce_ib50u_t,
         outeqn           => xadce_rxn,
         outeqp           => xadce_rxp,
         vccehxqyx        => vccehxqyx,
         vccerxqyx        => vccerxqyx,
         vctl_quiet       => xadce_vctl_quiet,
         vssexqyx         => vssexqyx,

         adapt_done       => xadce_adapt_done,
         e_clk            => xadce_hf_clk,
         eqa_ctrl         => eqa_ctrl_wire,
         eqb_ctrl         => eqb_ctrl_wire,
         eqc_ctrl         => eqc_ctrl_wire,
         eqctrlout        => xadce_eqctrlout,
         eqd_ctrl         => eqd_ctrl_wire,
         eqv_ctrl         => eqv_ctrl_wire,
         fine_d2aout      => xadce_fine_d2aout,
         hf_adapt_done    => xadce_hf_adapt_done,
         hfclk_macro      => xadce_hfclk_macro,
         hfmac_cnt0_nclr  => xadce_hfmac_cnt0_nclr,
         hfmac_cnt2_nclr  => xadce_hfmac_cnt2_nclr,
         ibrgen1          => xadce_ibrgen1,
         ibrgen2          => xadce_ibrgen2,
         lf_adapt_done    => xadce_lf_adapt_done,
         lfclk_macro      => xadce_lfclk_macro,
         lfmac_cnt0_nclr  => xadce_lfmac_cnt0_nclr,
         lfmac_cnt2_nclr  => xadce_lfmac_cnt2_nclr,
         r_clk            => xadce_lf_clk,
         rgenctrlout      => xadce_rgenctrlout,
         tmxselan         => xadce_tmxselan,
         tmxselbn         => xadce_tmxselbn,
         tmxselcn         => xadce_tmxselcn,
         tmxseldn         => xadce_tmxseldn,
         tmxselvn         => xadce_tmxselvn,
         updnn_hf         => xadce_updnn_hf,
         updnn_lf         => xadce_updnn_lf
      );
   adaptdone <= xadce_adapt_done;
   ck0_sigdet <= NOT(deserclock(3));
   lpbkp <= seriallpbkin WHEN (seriallpbkin = '0' OR seriallpbkin = '1') ELSE '0';
   rs_lpbk <= '0' WHEN (cram_rrx_s_lpbk = '0') ELSE seriallpbken;
   rx_p <= datain WHEN (datain = '1' OR datain = '0') ELSE '0';
   rx_n <= NOT(rx_p);
   rx_refclk <= '0';
   rx_testclk <= '0';
   rrx_bit_dc <= cram_rrx_bit_dc;
   rrx_lst <= cram_rrx_lst;
   rrx_oc <= cram_rrx_oc;
   rrx_oc_en <= offsetcancellationen;
   rx_pdb <= '0' WHEN (powerdn = '1') ELSE '1';
   rrx_sd_force <= cram_rrx_sd_force;
   rrx_sd_off <= cram_rrx_sd_off;
   rrx_sd_on <= cram_rrx_sd_on;
   rrx_sdlv <= cram_rrx_sdlv;
   rrx_s_rdlpbk <= cram_rrx_s_rdlpbk;
   rrx_test <= '0';
   rrx_vtt <= cram_rrx_vtt;
      
   xrx : stratixiv_hssi_pma_c_rx
      PORT MAP (
         atbsel       => rx_atbsel,
         ck0_sigdet   => ck0_sigdet,
         eqa_ctrl     => eqa_ctrl_wire,
         eqb_ctrl     => eqb_ctrl_wire,
         eqc_ctrl     => eqc_ctrl_wire,
         eqd_ctrl     => eqd_ctrl_wire,
         eqv_ctrl     => eqv_ctrl_wire,
         ibc50u       => ibc50u,
         ibp50u       => ibp50u,
         ibp150u      => ibp150u,
         inn          => rx_n,
         inp          => rx_p,
         lpbkn        => lpbkn,
         lpbkp        => lpbkp,
         oc_calpd     => wire_oc_calpd,
         oc_en        => rrx_oc_en,
         pdb          => rx_pdb,
         rbit_dc      => rrx_bit_dc,
         refclk       => rx_refclk,
         rx_b50       => rx_50,
         rx_oc        => rrx_oc,
         rx_test      => rrx_test,
         rx_testclk   => rx_testclk,
         s_lpbk       => rs_lpbk,
         s_rdlpbk     => rrx_s_rdlpbk,
         sd_force     => rrx_sd_force,
         sd_off       => rrx_sd_off,
         sd_on        => rrx_sd_on,
         sdlv         => rrx_sdlv,
         term         => rrx_term,
         vccehtxqyx   => vccehtxqyx,
         vcce_la      => vcce_la,
         vcce_oa      => vcce_oa,
         vssexqyx     => vssexqyx,
         vtt          => rrx_vtt(2 DOWNTO 0),
         atb_0        => atb_0,
         atb_1        => atb_1,
         analog_sd    => analog_sd_icd,
         inn3         => rx_eqout_n,
         inp3         => rx_eqout_p,
         rdlpbkn      => rx_rlpbkn,
         rdlpbkp      => rx_rlpbkp,
         rxn          => cdr_rxn,
         rxp          => cdr_rxp,
         sd_cdr       => sd_cdr,
         rxbuf_ibias  => wire_rxbuf_ibias,
         sd_cpon      => wire_sd_cpon,
         sd_cpop      => wire_sd_cpop
      );
   
   dataout <= cdr_rxp;
   signaldetect <= analog_sd;
   analog_sd <= analog_sd_sw;
   analog_sd_sw <= signaldetect_reg;
   sd_rx <= seriallpbkin WHEN (rs_lpbk = '1') ELSE datain;
   sd_reset <= '1' WHEN (powerdn = '1' OR rxpmareset = '1') ELSE '0';
   
   PROCESS (sd_reset, sd_rx)
VARIABLE  txt : LINE;
   BEGIN
      IF (sd_reset = '1') THEN
         signaldetect_reg <= '0';
      ELSIF (sd_rx = '0' OR sd_rx = '1') THEN
         signaldetect_reg <= '1';
      ELSE
         signaldetect_reg <= '0';
      END IF;
   END PROCESS;
   
   ppmdetect_fref_in <= ppmdetectrefclk;
   ppmdetect_fvcobyn_in <= ppmdetectdividedclk;
   ppmdetect_hardreset_in <= '0' WHEN (rxpmareset = '1') ELSE '1';
   ppmdetect_pd_in <= '0' WHEN (powerdn = '1') ELSE '1';
   ppmdetect_ppmsel_in <= cram_rppmsel;
     
   xppmdetect : stratixiv_hssi_pma_ppmdetect
      PORT MAP (
         fref           => ppmdetect_fref_in,
         fvcobyn        => ppmdetect_fvcobyn_in,
         hard_reset     => ppmdetect_hardreset_in,
         pd             => ppmdetect_pd_in,
         ppmsel         => ppmdetect_ppmsel_in,
         ppm_cnt_reset  => ppmdetect_ppmcntreset_in,
         scan_mode      => ppmdetect_scanmode_in,
         rforcehigh     => ppmdetect_rforcehigh_in,
         rforcelow      => ppmdetect_rforcelow_in,
         freq_lock      => ppmdetect_freqlock_out,
         ppm_cnt_latch  => ppmdetect_ppmcntlatch_out
      );
   mrxpll_not_locked <= '0' WHEN (plllocked = '1') ELSE
                        '1';
   signal_detect_reg_n <= NOT(analog_sd);
   
   PROCESS (ppmdetectrefclk, rxpmareset)
VARIABLE  txt : LINE;
   BEGIN
      IF (rxpmareset = '1') THEN
         mfreqlocked_reg <= '0';
      ELSIF (ppmdetectrefclk'EVENT AND ppmdetectrefclk = '1') THEN
         IF (mfreqlocked_cnt = "1111") THEN
            mfreqlocked_reg <= '1';
         ELSE
            mfreqlocked_reg <= '0';
         END IF;
      END IF;
   END PROCESS;
   
   PROCESS (ppmdetectrefclk, mrxpll_not_locked, signal_detect_reg_n)
VARIABLE  txt : LINE;
   BEGIN
      IF (ppmdetectrefclk'EVENT AND ppmdetectrefclk = '1') THEN
         IF (mrxpll_not_locked = '1' OR signal_detect_reg_n = '1') THEN
            mfreqlocked_cnt <= "0000";
         ELSIF (mfreqlocked_cnt /= "1111") THEN
            mfreqlocked_cnt <= mfreqlocked_cnt + "0001";
         END IF;
      END IF;
   END PROCESS;
   
   lck2refctl_freqlock_in <= mfreqlocked_reg;
   cdr_pdb <= '0' WHEN (powerdn = '1') ELSE
              '1';
   ck0_pd <= deserclock(0);
   ck90_pd <= deserclock(1);
   ck180_pd <= deserclock(2);
   ck270_pd <= deserclock(3);
   ignore_phslck <= ignorephslck;
   ltd <= locktodata;
   ltr <= locktoref;
   rlbk <= cram_rlpbk;
   rlpbk_pre_en <= cram_rrx_s_rdlpbk;
   rst_n <= '0' WHEN (rxpmareset = '1') ELSE
            '1';
   deven <= recoverdatain(0);
   dodd <= recoverdatain(1);
   devenb <= NOT(recoverdatain(0));
   doddb <= NOT(recoverdatain(1));
   lck2ref <= '1' WHEN ((NOT(cdr_pdb)) = '1') ELSE
              '1' WHEN ((NOT(sd_cdr) OR NOT(lck2refctl_freqlock_in)) = '1') ELSE
              '1' WHEN ((sd_cdr AND lck2refctl_freqlock_in AND NOT(plllocked) AND NOT(ignore_phslck)) = '1') ELSE
              '0' WHEN ((sd_cdr AND lck2refctl_freqlock_in AND plllocked) = '1') ELSE
              '0';
   rxpll_lock <= NOT(lck2ref);
   pdbx <= cdr_pdb AND rlbk;
   rstb_slpbk <= pdbx AND rst_n;
   clk90_slpbk <= NOT((ck90_pd AND pdbx));
   clk270_slpbk <= NOT((ck270_pd AND pdbx));
   rstn2 <= pe AND vssex;
   pe <= NOT(pdbx) AND rst_n AND rlpbk_pre_en;
   PROCESS (clk90_slpbk, rstb_slpbk)
VARIABLE  txt : LINE;
   BEGIN
      IF (rstb_slpbk = '0') THEN
         devenout <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
         devenbout <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
         doddx <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
         oddbx <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (clk90_slpbk'EVENT AND clk90_slpbk = '1') THEN
         devenout <=  TRANSPORT deven AFTER (PARAM_DELAY)*1 ps;
          
         devenbout <=  TRANSPORT devenb AFTER (PARAM_DELAY)*1 ps;
          
         doddx <=  TRANSPORT dodd AFTER (PARAM_DELAY)*1 ps;
          
         oddbx <=  TRANSPORT doddb AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (clk270_slpbk, rstb_slpbk)
VARIABLE  txt : LINE;
   BEGIN
      IF (rstb_slpbk = '0') THEN
         doddout <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
         oddbout <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (clk270_slpbk'EVENT AND clk270_slpbk = '1') THEN
         doddout <=  TRANSPORT doddx AFTER (PARAM_DELAY)*1 ps;
          
         oddbout <=  TRANSPORT oddbx AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (clk270_slpbk, rst_n)
VARIABLE  txt : LINE;
   BEGIN
      IF (rst_n = '0') THEN
         oe1 <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
         oeb1 <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (clk270_slpbk'EVENT AND clk270_slpbk = '1') THEN
         oe1 <=  TRANSPORT devenout AFTER (PARAM_DELAY)*1 ps;
          
         oeb1 <=  TRANSPORT devenbout AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (clk90_slpbk, rst_n)
VARIABLE  txt : LINE;
   BEGIN
      IF (rst_n = '0') THEN
         oo1 <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
         oob1 <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (clk90_slpbk'EVENT AND clk90_slpbk = '1') THEN
         oo1 <=  TRANSPORT doddout AFTER (PARAM_DELAY)*1 ps;
          
         oob1 <=  TRANSPORT oddbout AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (clk270_slpbk, pdbx)
VARIABLE  txt : LINE;
   BEGIN
      IF (pdbx = '0') THEN
         rxlpbp_int <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
         rxlpbn_int <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (clk270_slpbk'EVENT AND clk270_slpbk = '1') THEN
         rxlpbp_int <=  TRANSPORT devenout AFTER (PARAM_DELAY)*1 ps;
          
         rxlpbn_int <=  TRANSPORT devenbout AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (clk90_slpbk, pdbx)
VARIABLE  txt : LINE;
   BEGIN
      IF (pdbx = '0') THEN
         rxlpbp_int <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
         rxlpbn_int <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (clk90_slpbk'EVENT AND clk90_slpbk = '1') THEN
         rxlpbp_int <=  TRANSPORT doddout AFTER (PARAM_DELAY)*1 ps;
          
         rxlpbn_int <=  TRANSPORT oddbout AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (clk90_slpbk, pe)
VARIABLE  txt : LINE;
   BEGIN
      IF (pe = '0') THEN
         rxlpbdp_int <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
         rxlpbdn_int <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (clk90_slpbk'EVENT AND clk90_slpbk = '1') THEN
         rxlpbdp_int <=  TRANSPORT oe1 AFTER (PARAM_DELAY)*1 ps;
          
         rxlpbdn_int <=  TRANSPORT oeb1 AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   PROCESS (clk270_slpbk, pe)
VARIABLE  txt : LINE;
   BEGIN
      IF (pe = '0') THEN
         rxlpbdp_int <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
         rxlpbdn_int <=  TRANSPORT '1' AFTER (PARAM_DELAY)*1 ps;
          
      ELSIF (clk270_slpbk'EVENT AND clk270_slpbk = '1') THEN
         rxlpbdp_int <=  TRANSPORT oo1 AFTER (PARAM_DELAY)*1 ps;
          
         rxlpbdn_int <=  TRANSPORT oob1 AFTER (PARAM_DELAY)*1 ps;
          
      END IF;
   END PROCESS;
   
   rxlpbp <= rxlpbp_int;
   rxlpbn <= rxlpbn_int;
   rxlpbdp <= rxlpbdp_int;
   rxlpbdn <= rxlpbdn_int;
   locktorefout <= lck2ref;
   revserialfdbkout <= rxlpbp;
   rrevlb_sw <= cram_rrevlb_sw;
   cdr_rlpbkn <= rxlpbn;
   cdr_rlpbkp <= rxlpbp;
   cdr_rlpbkdn <= rxlpbdn;
   cdr_rlpbkdp <= rxlpbdp;
   
   
   xrlpbk_mux : stratixiv_hssi_pma_c_rlpbk_mux
      PORT MAP (
         doddn    => vssex,
         doddp    => vssex,
         dodn     => cdr_rlpbkdn,
         dodp     => cdr_rlpbkdp,
         don      => cdr_rlpbkn,
         don_pre  => vssex,
         dop      => cdr_rlpbkp,
         dop_pre  => vssex,
         drxn     => rx_rlpbkn,
         drxp     => rx_rlpbkp,
         sel      => rrevlb_sw,
         vcce_la  => vcce_la,
         vssex    => vssex,
         voddn    => ncvondp,
         voddp    => ncvopdp,
         vodn     => rlpbkdn,
         vodp     => rlpbkdp,
         von      => rlpbkn,
         von_pre  => ncvonp,
         vop      => rlpbkp,
         vop_pre  => ncvopp
      );

   reverselpbkout <= cdr_rxp;
   xdeser_clk90_in <= NOT(deserclock(1)) WHEN (deserialization_factor <= 20) ELSE
                      '0';
   xdeser_pdb_in <= '0' WHEN (powerdn = '1') ELSE
                   '1';
   xdeser_div2_in <= cram_rpma_doublewidth_rx;
   xdeser_div5_in <= cram_rpmadwidth_rx;
   xdeser_rst_n <= '0' WHEN (rxpmareset = '1') ELSE
                  '1';
   xdeser_pcie_sw <= '0';
   rdynamic_sw <= '0';
   xdeser_10g_clk90b <= NOT(deserclock(1)) WHEN (deserialization_factor > 20) ELSE
                        '0';
   xdeser_10g_deven <= recoverdatain(0) WHEN (deserialization_factor > 20) ELSE
                       '0';
   xdeser_10g_dodd <= recoverdatain(1) WHEN (deserialization_factor > 20) ELSE
                      '0';
   xdeser_10g_devenb <= NOT(recoverdatain(0)) WHEN (deserialization_factor > 20) ELSE
                        '0';
   xdeser_10g_doddb <= NOT(recoverdatain(1)) WHEN (deserialization_factor > 20) ELSE
                       '0';
   xdeser_10g_pdb <= '0' WHEN (powerdn = '1') ELSE
                     '1';
   xdeser_10g_rst_n <= '0' WHEN (rxpmareset = '1') ELSE
                       '1';
   
   
   xdeser : stratixiv_hssi_pma_c_deser
      PORT MAP (
         clk90b        => xdeser_clk90_in,
         deser_div2    => xdeser_div2_in,
         deser_div5    => xdeser_div5_in,
         deser_pdb     => xdeser_pdb_in,
         deven         => deven,
         devenb        => devenb,
         dodd          => dodd,
         doddb         => doddb,
         pcie_sw       => xdeser_pcie_sw,
         rdynamic_sw   => rdynamic_sw,
         rfast_sd      => rfast_sd,
         rst_n         => xdeser_rst_n,
         rtest_fastsd  => wire_rtest_fastsd,
         rxinn         => rx_rlpbkn,		-- from c_rx
         rxinp         => rx_rlpbkp,		-- from c_rx
         vcce_la       => vcce_la,
         vssexqyx      => vssexqyx,
         
         clk_divrx     => xdeser_clkdivrx_out,
         dout          => xdeser_dout_out,
         fsd           => xdeser_fsd_out,
         pcieo         => xdeser_pcieo_out
      );  
   
   xdeser_10g : stratixiv_hssi_pma_c_deser_10g
      PORT MAP (
         clk90b     => xdeser_10g_clk90b,
         deser_pdb  => xdeser_10g_pdb,
         deven      => xdeser_10g_deven,
         devenb     => xdeser_10g_devenb,
         dodd       => xdeser_10g_dodd,
         doddb      => xdeser_10g_doddb,
         rst_n      => xdeser_10g_rst_n,
         vcce_la    => vcce_la,
         vssexqyx   => vssexqyx,
         
         clk_divrx  => xdeser_10g_clk_divrx,
         dout       => xdeser_10g_dout
      );
   
   -- outputs from the deserializer
   clockout <= xdeser_clkdivrx_out WHEN (allow_vco_bypass = 0 AND deserialization_factor <= 20) ELSE
               xdeser_10g_clk_divrx WHEN (allow_vco_bypass = 0) ELSE
               (NOT ppmdetectrefclk) WHEN (allow_vco_bypass = 1) ELSE
               ppmdetectdividedclk WHEN (allow_vco_bypass = 2) ELSE
               xdeser_clkdivrx_out;
   recoverdataout(19 DOWNTO 0) <= ('Z' & 'Z' & 'Z' & 'Z' & xdeser_dout_out(17 DOWNTO 10) & xdeser_dout_out(7 DOWNTO 0)) WHEN (use_pma_direct = "true" and deserialization_factor = 16) ELSE
                                  xdeser_dout_out WHEN (deserialization_factor <= 20) ELSE
                                  xdeser_10g_dout(19 DOWNTO 0);
   recoverdataout(63 DOWNTO 20) <= ('Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z' & 'Z') WHEN (deserialization_factor <= 20) ELSE
                                   xdeser_10g_dout(63 DOWNTO 20);
  
   dataoutfull <= xdeser_dout_out; 

   analogtestbus <= "00000000";

END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_pcs_reset IS
   PORT (
      
      hard_reset   : IN STD_LOGIC;
      clk_2_b      : IN STD_LOGIC;
      refclk_b_in  : IN STD_LOGIC;
      scan_mode    : IN STD_LOGIC;
      rxpcs_rst    : IN STD_LOGIC;
      txpcs_rst    : IN STD_LOGIC;
      
      rxrst_int    : OUT STD_LOGIC;
      txrst_int    : OUT STD_LOGIC
   );
END stratixiv_hssi_pcs_reset;

ARCHITECTURE trans OF stratixiv_hssi_pcs_reset IS
   
   SIGNAL txrst_sync1 : STD_LOGIC := '0';
   SIGNAL txrst_sync2 : STD_LOGIC := '0';
   SIGNAL rxrst_sync1 : STD_LOGIC := '0';
   SIGNAL rxrst_sync2 : STD_LOGIC := '0';
BEGIN
   
   PROCESS (hard_reset, clk_2_b)
VARIABLE  txt : LINE;
   BEGIN
      IF (hard_reset = '1') THEN
         rxrst_sync2 <= '1';
         rxrst_sync1 <= '1';
      ELSIF (clk_2_b'EVENT AND clk_2_b = '1') THEN
         rxrst_sync2 <=  TRANSPORT rxrst_sync1 AFTER 1* 1 ps;
         rxrst_sync1 <= rxpcs_rst;
      END IF;
   END PROCESS;
   
   PROCESS (hard_reset, refclk_b_in)
VARIABLE  txt : LINE;
   BEGIN
      IF (hard_reset = '1') THEN
         txrst_sync2 <= '1';
         txrst_sync1 <= '1';
      ELSIF (refclk_b_in'EVENT AND refclk_b_in = '1') THEN
         txrst_sync2 <=  TRANSPORT txrst_sync1 AFTER 1* 1 ps;
         txrst_sync1 <= txpcs_rst;
      END IF;
   END PROCESS;
   
   -- 06-14-02 BT Changed SCAN_SHIFT signal to SCAN_MODE
   --assign rxrst_int = !SCAN_SHIFT & rxrst_sync2;
   --assign txrst_int = !SCAN_SHIFT & txrst_sync2;
   rxrst_int <= NOT(scan_mode) AND rxrst_sync2;
   txrst_int <= NOT(scan_mode) AND txrst_sync2;
   
END trans;



LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_digi_chnl_hip_spt IS
   PORT (
      
      rhip_ena                : IN STD_LOGIC;
      
      pcs_rxd_ch              : IN STD_LOGIC_VECTOR(8 DOWNTO 0);
      pcs_rxvalid             : IN STD_LOGIC;
      pcs_rxelecidle          : IN STD_LOGIC;
      pcs_rxstatus_ch         : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      pcs_phystatus           : IN STD_LOGIC;
      txpma_local_clk         : IN STD_LOGIC;
      txd_ch                  : IN STD_LOGIC_VECTOR(10 DOWNTO 0);
      hip_txd_ch              : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
      txdetectrxloopback      : IN STD_LOGIC;
      hip_txdetectrxloopback  : IN STD_LOGIC;
      rxpolarity              : IN STD_LOGIC;
      hip_rxpolarity          : IN STD_LOGIC;
      powerdown_ch            : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      hip_powerdown_ch        : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      txdeemph                : IN STD_LOGIC;
      hip_txdeemph            : IN STD_LOGIC;
      txmargin_ch             : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      hip_txmargin_ch         : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      eidleinfersel_ch        : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      hip_eidleinfersel_ch    : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      rate                    : IN STD_LOGIC;
      hip_rate                : IN STD_LOGIC;
      hip_txelecidle          : IN STD_LOGIC;
      
      rxd_ch                  : OUT STD_LOGIC_VECTOR(8 DOWNTO 0);
      hip_rxd_ch              : OUT STD_LOGIC_VECTOR(8 DOWNTO 0);
      rxvalid                 : OUT STD_LOGIC;
      hip_rxvalid             : OUT STD_LOGIC;
      rxelecidle              : OUT STD_LOGIC;
      hip_rxelecidle          : OUT STD_LOGIC;
      rxstatus_ch             : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      hip_rxstatus_ch         : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      phystatus               : OUT STD_LOGIC;
      hip_phystatus           : OUT STD_LOGIC;
      hip_tx_clk              : OUT STD_LOGIC;
      pcs_txd_ch              : OUT STD_LOGIC_VECTOR(10 DOWNTO 0);
      pcs_txdetectrxloopback  : OUT STD_LOGIC;
      pcs_rxpolarity          : OUT STD_LOGIC;
      pcs_powerdown_ch        : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pcs_txdeemph            : OUT STD_LOGIC;
      pcs_txmargin_ch         : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      pcs_eidleinfersel_ch    : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      pcs_rate                : OUT STD_LOGIC
   );
END stratixiv_hssi_digi_chnl_hip_spt;

ARCHITECTURE trans OF stratixiv_hssi_digi_chnl_hip_spt IS
BEGIN
   
   --// SECTION for SPLIT signals
   --// ===============================
   --//
   -- MUX/SPLIT #5,6,7,8 in Excel spreadsheet
   rxd_ch <= pcs_rxd_ch;
   hip_rxd_ch <= pcs_rxd_ch WHEN (rhip_ena = '1') ELSE
                 "000000000";
   
   -- MUX/SPLIT #16 in Excel spreadsheet
   rxvalid <= pcs_rxvalid;
   hip_rxvalid <= pcs_rxvalid WHEN (rhip_ena = '1') ELSE
                  '0';
   
   -- MUX/SPLIT #17 in Excel spreadsheet
   rxelecidle <= pcs_rxelecidle;
   hip_rxelecidle <= pcs_rxelecidle WHEN (rhip_ena = '1') ELSE
                     '1';
   
   -- MUX/SPLIT #18,19,20,21 in Excel spreadsheet
   rxstatus_ch <= pcs_rxstatus_ch;
   hip_rxstatus_ch <= pcs_rxstatus_ch WHEN (rhip_ena = '1') ELSE
                      "000";
   
   -- MUX/SPLIT #22 in Excel spreadsheet
   phystatus <= pcs_phystatus;
   hip_phystatus <= pcs_phystatus WHEN (rhip_ena = '1') ELSE
                    '0';
   
   hip_tx_clk <= txpma_local_clk;
   
   --// SECTION for MUX signals
   --// ===============================
   --//
   -- MUX/SPLIT #1,2,3,4 in Excel spreadsheet
   pcs_txd_ch <= (hip_txelecidle & hip_txd_ch) WHEN (rhip_ena = '1') ELSE
                 txd_ch;
   
   -- MUX/SPLIT #10 in Excel spreadsheet
   pcs_txdetectrxloopback <= hip_txdetectrxloopback WHEN (rhip_ena = '1') ELSE
                             txdetectrxloopback;
   
   -- MUX/SPLIT #11 in Excel spreadsheet
   pcs_rxpolarity <= hip_rxpolarity WHEN (rhip_ena = '1') ELSE
                     rxpolarity;
   
   -- MUX/SPLIT #12,13,14,15 in Excel spreadsheet
   pcs_powerdown_ch <= hip_powerdown_ch WHEN (rhip_ena = '1') ELSE
                       powerdown_ch;
   
   -- MUX/SPLIT #23 in Excel spreadsheet
   pcs_txdeemph <= hip_txdeemph WHEN (rhip_ena = '1') ELSE
                   txdeemph;
   
   -- MUX/SPLIT #24,25,26,27 in Excel spreadsheet
   pcs_txmargin_ch <= hip_txmargin_ch WHEN (rhip_ena = '1') ELSE
                      txmargin_ch;
   
   -- MUX/SPLIT #28,29,30,31 in Excel spreadsheet
   pcs_eidleinfersel_ch <= hip_eidleinfersel_ch WHEN (rhip_ena = '1') ELSE
                           eidleinfersel_ch;
   
   -- MUX/SPLIT #32 in Excel spreadsheet
   pcs_rate <= hip_rate WHEN (rhip_ena = '1') ELSE
               rate;
   
END trans;





LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_phystatus_generator_fsm IS
   PORT (
      
      -- General signals
      
      --CRAM
      -- OR of rtx_pipe_enable and rrx_pipe_enable
      -- no toggle (gen 2) = 0, toggle (option for gen 1) = 1
      
      -- PLD Interface
      -- power state control
      -- communicate completion of power state transitions, receiver 
      -- detection, rate change
      
      -- Auto Negotiation Module
      -- asserted when signaling rate change between Gen 1 and Gen 2
      
      -- RX PIPE Interface
      --	p1_sync,
      
      -- PMA interface
      -- TX PMA
      -- rx_detect_bypass = 0 : Validation of rx_found: 
      -- 					synchronized at pipe_interface_top level
      -- rx_detect_bypass = 1 : delayed version of txdetectrx
      
      -- RX PMA
      -- asserted when successful power state transition occurs
      -- validates power_state_transition_done, currently tied to 0
      
      -- Latched Power State Signals
      -- P1 power state from TX PIPE interface
      
      -- Internal Power State Done Generator
      -- faked successful power state transition generated by internal	
      -- power state transition done module
      
      --********************************************************************************
      -- INCLUDE STATEMENTS
      --********************************************************************************
      
      --********************************************************************************
      -- I/O SIGNALS
      --********************************************************************************
      -- General signals
      clk                              : IN STD_LOGIC;
      reset_n                          : IN STD_LOGIC;
      
      -- CRAM
      phystat_ena                      : IN STD_LOGIC;
      rphystatus_rst_toggle            : IN STD_LOGIC;
      
      -- PLD Interface
      powerdown                        : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      phystatus                        : OUT STD_LOGIC;
      
      rindv_rx                         : IN STD_LOGIC;		-- Select between XAUI mode or indiv  channel mode
      rmaster_rx                       : IN STD_LOGIC;		-- New bundle mode MDIO, selects master quad
      rmaster_up_rx                    : IN STD_LOGIC;		-- New bundle mode MDIO, selects master quad
      
      -- Auto Negotiation Module
      speed_change                     : IN STD_LOGIC;
      speed_change_centrl              : IN STD_LOGIC;
      speed_change_quad_up             : IN STD_LOGIC;
      speed_change_quad_down           : IN STD_LOGIC;
      
      -- RX PIPE Interface
      --output			p1_sync;
      
      -- PMA interface
      -- TX PMA
      rx_detect_valid                  : IN STD_LOGIC;
      
      -- RX PMA
      power_state_transition_done      : IN STD_LOGIC;
      power_state_transition_done_ena  : IN STD_LOGIC;
      
      -- Latched Power state signals
      p1                               : IN STD_LOGIC;		-- longer recovery time (64 us max) latency
      
      -- Internal Power State Done Generator
      internal_done                    : IN STD_LOGIC
   );
END stratixiv_hssi_phystatus_generator_fsm;

ARCHITECTURE trans OF stratixiv_hssi_phystatus_generator_fsm IS
   
   --********************************************************************************
   -- PARAMETERS
   --********************************************************************************
   
   --********************************************************************************
   -- DECLARATIONS
   --********************************************************************************
   --reg		phystatus;
   
   -- select between PMA done and internally generated done
   SIGNAL done                                 : STD_LOGIC;
   SIGNAL pre_power_state_transition_done_sync : STD_LOGIC;
   SIGNAL power_state_transition_done_sync     : STD_LOGIC;
   SIGNAL power_state_transition_done_sync_reg : STD_LOGIC;
   
   -- Reset condition
   SIGNAL reset_phystatus                      : STD_LOGIC;
   
   -- State transition
   SIGNAL state_transition_phystatus           : STD_LOGIC;
   
   -- Speed Negotiation
   SIGNAL speed_change_reg                     : STD_LOGIC;
   SIGNAL speed_change_sync                    : STD_LOGIC;
   SIGNAL speed_change_sync_reg                : STD_LOGIC;
   SIGNAL speed_change_phystatus               : STD_LOGIC;
   
   -- Receiver Detection
   --reg		p1_reg;				// synchronize from tx clk domain to rx clk domain
   --reg		p1_sync;
   
   SIGNAL rx_detect_valid_reg                  : STD_LOGIC;		-- Edge detection of receiver detection status signal
   SIGNAL rx_detect_valid_phystatus            : STD_LOGIC;
   
   -- P2 exit detection
   SIGNAL decode_p2                            : STD_LOGIC;
   SIGNAL decode_p2_reg                        : STD_LOGIC;
   SIGNAL decode_p2_reg1                       : STD_LOGIC;
   SIGNAL phystatus_high_sel                   : STD_LOGIC;
   SIGNAL phystatus_high_sel_reg               : STD_LOGIC;
   
   -- Reset
   SIGNAL phystatus_toggle_sel                 : STD_LOGIC;
   SIGNAL phystatus_toggle_sel_reg             : STD_LOGIC;
   
   SIGNAL pre_phystatus                        : STD_LOGIC;
   
   SIGNAL speed_change_local                   : STD_LOGIC;
   
   SIGNAL speed_change_centrl_del1             : STD_LOGIC;
   SIGNAL speed_change_centrl_del2             : STD_LOGIC;
BEGIN
   
   --********************************************************************************
   -- ASSIGN STATEMENTS
   --********************************************************************************
   -- Move to PLD interface
   phystatus <= '1' WHEN ((NOT(decode_p2) AND decode_p2_reg1) = '1') ELSE
                pre_phystatus;
   --assign phystatus= pre_phystatus;
   
   done <= (power_state_transition_done_sync AND NOT(power_state_transition_done_sync_reg)) WHEN (power_state_transition_done_ena = '1') ELSE
           internal_done;
   
   decode_p2 <= phystat_ena WHEN (powerdown = "11") ELSE
                '0';
   
   --********************************************************************************
   -- SUBMODULE INSTANTIATIONS
   --********************************************************************************
   
   --********************************************************************************
   -- MAIN CODE
   --********************************************************************************
   -- Reset phystatus generation
   
   -- Phystatus is asserted during reset and then the successful 'transition' into P1 is signal by the assertion
   -- phystatus for 1 cycle.  Unlike regular operation, the first entry into P1 is not indicated by a 'done' signal
   -- The assertion of phystatus occurs 4 cycles after reset is released
   PROCESS (reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(reset_n)) = '1') THEN
         reset_phystatus <= '1';
      ELSE
         reset_phystatus <= '0';
      END IF;
   END PROCESS;
   
   PROCESS (reset_n, rphystatus_rst_toggle, done, phystatus_toggle_sel_reg)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(reset_n)) = '1') THEN
         phystatus_toggle_sel <= '1';
      ELSIF ((rphystatus_rst_toggle OR done) = '1') THEN
         phystatus_toggle_sel <= '0';
      ELSE
         phystatus_toggle_sel <= phystatus_toggle_sel_reg;
      END IF;
   END PROCESS;
   
   PROCESS (clk, reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(reset_n)) = '1') THEN
         phystatus_toggle_sel_reg <=  TRANSPORT '1' AFTER 1* 1 ps;
         phystatus_high_sel_reg <=  TRANSPORT '1' AFTER 1* 1 ps;
      ELSIF (clk'EVENT AND clk = '1') THEN
         phystatus_toggle_sel_reg <=  TRANSPORT phystatus_toggle_sel AFTER 1* 1 ps;
         phystatus_high_sel_reg <=  TRANSPORT phystatus_high_sel AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   -- State transition: sync PMA signal to local clk.  Currently not being used
   -- State transition: Internal done generator indicates that there was a successful state transition.  
   -- Illegal transitions have been taken into account by the previous module.
   PROCESS (clk, reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(reset_n)) = '1') THEN
         pre_power_state_transition_done_sync <=  TRANSPORT '0' AFTER 1* 1 ps;
         power_state_transition_done_sync <=  TRANSPORT '0' AFTER 1* 1 ps;
         
         power_state_transition_done_sync_reg <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (clk'EVENT AND clk = '1') THEN
         pre_power_state_transition_done_sync <=  TRANSPORT power_state_transition_done AFTER 1* 1 ps;
         power_state_transition_done_sync <=  TRANSPORT pre_power_state_transition_done_sync AFTER 1* 1 ps;
         
         power_state_transition_done_sync_reg <=  TRANSPORT power_state_transition_done_sync AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (reset_n, done)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(reset_n)) = '1') THEN
         state_transition_phystatus <= '0';
      ELSIF (done = '1') THEN
            state_transition_phystatus <= '1';
         ELSE
            state_transition_phystatus <= '0';
         END IF;
   END PROCESS;
   
   PROCESS (clk, reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(reset_n)) = '1') THEN
         speed_change_centrl_del1 <=  TRANSPORT '0' AFTER 1* 1 ps;
         
         speed_change_centrl_del2 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (clk'EVENT AND clk = '1') THEN
         speed_change_centrl_del1 <=  TRANSPORT speed_change_centrl AFTER 1* 1 ps;
         speed_change_centrl_del2 <=  TRANSPORT speed_change_centrl_del1 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   -- always @ (posedge clk or negedge reset_n)
   
   speed_change_local <= speed_change WHEN (rindv_rx = '1') ELSE
                         speed_change_centrl_del2 WHEN (rmaster_rx = '1') ELSE
                         speed_change_quad_up WHEN (rmaster_up_rx = '1') ELSE
                         speed_change_quad_down;
   
   -- Speed Negotiation
   PROCESS (clk, reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(reset_n)) = '1') THEN
         speed_change_reg <=  TRANSPORT '0' AFTER 1* 1 ps;
         speed_change_sync <=  TRANSPORT '0' AFTER 1* 1 ps;
         
         speed_change_sync_reg <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (clk'EVENT AND clk = '1') THEN
         speed_change_reg <=  TRANSPORT speed_change_local AFTER 1* 1 ps;
         speed_change_sync <=  TRANSPORT speed_change_reg AFTER 1* 1 ps;
         speed_change_sync_reg <=  TRANSPORT speed_change_sync AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (reset_n, speed_change_sync, speed_change_sync_reg)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(reset_n)) = '1') THEN
         speed_change_phystatus <= '0';
      ELSIF ((NOT(speed_change_sync) AND speed_change_sync_reg) = '1') THEN
         speed_change_phystatus <= '1';
      ELSE
         speed_change_phystatus <= '0';
      END IF;
   END PROCESS;
   
   -- Receiver Detection
   PROCESS (clk, reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(reset_n)) = '1') THEN
         --		p1_reg					<= 1'b0;
         --		p1_sync					<= 1'b0;
         
         --		rx_detect_valid_phystatus	<= 1'b0;
         rx_detect_valid_reg <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (clk'EVENT AND clk = '1') THEN
         --		p1_reg					<= p1;
         --		p1_sync					<= p1_reg;
         
         --		rx_detect_valid_phystatus	<= p1_sync && rx_detect_valid && !rx_detect_valid_reg;
         rx_detect_valid_reg <=  TRANSPORT rx_detect_valid AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (reset_n, p1, rx_detect_valid, rx_detect_valid_reg)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(reset_n)) = '1') THEN
         --	else if (p1_sync && rx_detect_valid && !rx_detect_valid_reg)
         rx_detect_valid_phystatus <= '0';
      ELSIF ((p1 AND rx_detect_valid AND NOT(rx_detect_valid_reg)) = '1') THEN
         rx_detect_valid_phystatus <= '1';
      ELSE
         
         rx_detect_valid_phystatus <= '0';
      END IF;
   END PROCESS;
   
   -- P2 state exit Detection
   PROCESS (clk, reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(reset_n)) = '1') THEN
         decode_p2_reg <=  TRANSPORT '0' AFTER 1* 1 ps;
         decode_p2_reg1 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (clk'EVENT AND clk = '1') THEN
         decode_p2_reg <=  TRANSPORT decode_p2 AFTER 1* 1 ps;
         decode_p2_reg1 <=  TRANSPORT decode_p2_reg AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (reset_n, decode_p2, decode_p2_reg, phystatus_high_sel_reg, done)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(reset_n)) = '1') THEN
         phystatus_high_sel <= '0';
      ELSIF ((NOT(decode_p2) AND decode_p2_reg) = '1') THEN
         phystatus_high_sel <= '1';
      ELSIF (done = '1') THEN
         phystatus_high_sel <= '0';
      ELSE
         phystatus_high_sel <= phystatus_high_sel_reg;
      END IF;
   END PROCESS;
   
   PROCESS (reset_n, phystatus_high_sel, reset_phystatus, state_transition_phystatus, rx_detect_valid_phystatus, phystatus_toggle_sel, speed_change_phystatus)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(reset_n)) = '1') THEN
         pre_phystatus <= '1';
      ELSE
         IF ((phystatus_high_sel OR reset_phystatus OR state_transition_phystatus OR rx_detect_valid_phystatus OR phystatus_toggle_sel OR speed_change_phystatus) = '1') THEN
            pre_phystatus <= '1';
         ELSE
            pre_phystatus <= '0';
         END IF;
      END IF;
   END PROCESS;
   
END trans;


-- always @ (reset_n or phystatus_high_sel or reset_phystatus or state_transition_phystatus or rx_detect_valid_phystatus...

-- phystatus_generator_fsm--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 53 oper_mux 1 stratixiv_hssi_phystatus_generator_fsm 1 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_phystatus_generator IS 
	 PORT 
	 ( 
		 clk	:	IN  STD_LOGIC;
		 latched_p0	:	IN  STD_LOGIC;
		 latched_p0s	:	IN  STD_LOGIC;
		 latched_p1	:	IN  STD_LOGIC;
		 latched_p2	:	IN  STD_LOGIC;
		 phystat_ena	:	IN  STD_LOGIC;
		 phystatus	:	OUT  STD_LOGIC;
		 power_state_transition_done	:	IN  STD_LOGIC;
		 power_state_transition_done_ena	:	IN  STD_LOGIC;
		 powerdown	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 reset_n	:	IN  STD_LOGIC;
		 rindv_rx	:	IN  STD_LOGIC;
		 rmaster_rx	:	IN  STD_LOGIC;
		 rmaster_up_rx	:	IN  STD_LOGIC;
		 rphystatus_delay	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 rphystatus_rst_toggle	:	IN  STD_LOGIC;
		 rx_detect_valid	:	IN  STD_LOGIC;
		 speed_change	:	IN  STD_LOGIC;
		 speed_change_centrl	:	IN  STD_LOGIC;
		 speed_change_quad_down	:	IN  STD_LOGIC;
		 speed_change_quad_up	:	IN  STD_LOGIC
	 ); 
 END stratixiv_hssi_phystatus_generator;

 ARCHITECTURE RTL OF stratixiv_hssi_phystatus_generator IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 nllOi21	:	STD_LOGIC := '0';
	 SIGNAL	 nllOi22	:	STD_LOGIC := '0';
	 SIGNAL  wire_nllOi22_w_lg_w_lg_q82w83w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllOi22_w_lg_q82w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nllOl19	:	STD_LOGIC := '0';
	 SIGNAL	 nllOl20	:	STD_LOGIC := '0';
	 SIGNAL  wire_nllOl20_w_lg_w_lg_q79w80w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllOl20_w_lg_q79w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nllOO17	:	STD_LOGIC := '0';
	 SIGNAL	 nllOO18	:	STD_LOGIC := '0';
	 SIGNAL  wire_nllOO18_w_lg_w_lg_q72w73w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllOO18_w_lg_q72w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO0l11	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0l12	:	STD_LOGIC := '0';
	 SIGNAL	 nlO1i15	:	STD_LOGIC := '0';
	 SIGNAL	 nlO1i16	:	STD_LOGIC := '0';
	 SIGNAL	 nlO1O13	:	STD_LOGIC := '0';
	 SIGNAL	 nlO1O14	:	STD_LOGIC := '0';
	 SIGNAL	 nlOii10	:	STD_LOGIC := '0';
	 SIGNAL	 nlOii9	:	STD_LOGIC := '0';
	 SIGNAL	 nlOil7	:	STD_LOGIC := '0';
	 SIGNAL	 nlOil8	:	STD_LOGIC := '0';
	 SIGNAL	 nlOli5	:	STD_LOGIC := '0';
	 SIGNAL	 nlOli6	:	STD_LOGIC := '0';
	 SIGNAL	 nlOlO3	:	STD_LOGIC := '0';
	 SIGNAL	 nlOlO4	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOl1	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOl2	:	STD_LOGIC := '0';
	 SIGNAL	ni0i	:	STD_LOGIC := '0';
	 SIGNAL	ni0l	:	STD_LOGIC := '0';
	 SIGNAL	ni1O	:	STD_LOGIC := '0';
	 SIGNAL	niii	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni0O_CLRN	:	STD_LOGIC;
	 SIGNAL	n00i	:	STD_LOGIC := '0';
	 SIGNAL	n00l	:	STD_LOGIC := '0';
	 SIGNAL	n00O	:	STD_LOGIC := '0';
	 SIGNAL	n01i	:	STD_LOGIC := '0';
	 SIGNAL	n01l	:	STD_LOGIC := '0';
	 SIGNAL	n01O	:	STD_LOGIC := '0';
	 SIGNAL	n0ii	:	STD_LOGIC := '0';
	 SIGNAL	n0il	:	STD_LOGIC := '0';
	 SIGNAL	n0iO	:	STD_LOGIC := '0';
	 SIGNAL	n0li	:	STD_LOGIC := '0';
	 SIGNAL	n0ll	:	STD_LOGIC := '0';
	 SIGNAL	n0lO	:	STD_LOGIC := '0';
	 SIGNAL	n0Ol	:	STD_LOGIC := '0';
	 SIGNAL	n0OO	:	STD_LOGIC := '0';
	 SIGNAL	n1lO	:	STD_LOGIC := '0';
	 SIGNAL	n1Ol	:	STD_LOGIC := '0';
	 SIGNAL	n1OO	:	STD_LOGIC := '0';
	 SIGNAL	ni1i	:	STD_LOGIC := '0';
	 SIGNAL	ni1l	:	STD_LOGIC := '0';
	 SIGNAL	niil	:	STD_LOGIC := '0';
	 SIGNAL	niiO	:	STD_LOGIC := '0';
	 SIGNAL	nili	:	STD_LOGIC := '0';
	 SIGNAL	nill	:	STD_LOGIC := '0';
	 SIGNAL	nilO	:	STD_LOGIC := '0';
	 SIGNAL	niOi	:	STD_LOGIC := '0';
	 SIGNAL	niOl	:	STD_LOGIC := '0';
	 SIGNAL	nl1i	:	STD_LOGIC := '0';
	 SIGNAL	wire_niOO_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_niOO_PRN	:	STD_LOGIC;
	 SIGNAL  wire_niOO_w_lg_w_lg_w_lg_w_lg_nill7w9w11w12w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOO_w_lg_w_lg_w_lg_nill7w9w11w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOO_w_lg_w_lg_w_lg_nill7w9w16w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOO_w_lg_w_lg_nill7w9w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOO_w_lg_w_lg_nill7w24w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOO_w_lg_nill32w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOO_w_lg_niil17w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOO_w_lg_niiO10w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOO_w_lg_nili8w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOO_w_lg_nill7w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1Oi_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n1Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oi_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0O_phystatus	:	STD_LOGIC;
	 SIGNAL  wire_nl0O_powerdown	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_w_lg_power_state_transition_done_ena60w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  nlO0O :	STD_LOGIC;
	 SIGNAL  nlOiO :	STD_LOGIC;
	 COMPONENT  stratixiv_hssi_phystatus_generator_fsm
	 PORT
	 ( 
		clk	:	IN STD_LOGIC;
		internal_done	:	IN STD_LOGIC;
		p1	:	IN STD_LOGIC;
		phystat_ena	:	IN STD_LOGIC;
		phystatus	:	OUT STD_LOGIC;
		power_state_transition_done	:	IN STD_LOGIC;
		power_state_transition_done_ena	:	IN STD_LOGIC;
		powerdown	:	IN STD_LOGIC_VECTOR(1 DOWNTO 0);
		reset_n	:	IN STD_LOGIC;
		rindv_rx	:	IN STD_LOGIC;
		rmaster_rx	:	IN STD_LOGIC;
		rmaster_up_rx	:	IN STD_LOGIC;
		rphystatus_rst_toggle	:	IN STD_LOGIC;
		rx_detect_valid	:	IN STD_LOGIC;
		speed_change	:	IN STD_LOGIC;
		speed_change_centrl	:	IN STD_LOGIC;
		speed_change_quad_down	:	IN STD_LOGIC;
		speed_change_quad_up	:	IN STD_LOGIC
	 ); 
	 END COMPONENT;
 BEGIN

	wire_w_lg_power_state_transition_done_ena60w(0) <= NOT power_state_transition_done_ena;
	nlO0O <= '1';
	nlOiO <= ((((((wire_niOO_w_lg_w_lg_w_lg_w_lg_nill7w9w11w12w(0) AND (nlOOl2 XOR nlOOl1)) OR (wire_niOO_w_lg_w_lg_w_lg_nill7w9w16w(0) AND wire_niOO_w_lg_niil17w(0))) OR (NOT (nlOlO4 XOR nlOlO3))) OR ((wire_niOO_w_lg_w_lg_nill7w24w(0) AND wire_niOO_w_lg_niiO10w(0)) AND wire_niOO_w_lg_niil17w(0))) OR (NOT (nlOli6 XOR nlOli5))) OR ((wire_niOO_w_lg_nill32w(0) AND wire_niOO_w_lg_niiO10w(0)) AND wire_niOO_w_lg_niil17w(0)));
	phystatus <= wire_nl0O_phystatus;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nllOi21 <= nllOi22;
		END IF;
		if (now = 0 ns) then
			nllOi21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nllOi22 <= nllOi21;
		END IF;
	END PROCESS;
	wire_nllOi22_w_lg_w_lg_q82w83w(0) <= wire_nllOi22_w_lg_q82w(0) AND n1OO;
	wire_nllOi22_w_lg_q82w(0) <= nllOi22 XOR nllOi21;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nllOl19 <= nllOl20;
		END IF;
		if (now = 0 ns) then
			nllOl19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nllOl20 <= nllOl19;
		END IF;
	END PROCESS;
	wire_nllOl20_w_lg_w_lg_q79w80w(0) <= wire_nllOl20_w_lg_q79w(0) AND n01i;
	wire_nllOl20_w_lg_q79w(0) <= nllOl20 XOR nllOl19;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nllOO17 <= nllOO18;
		END IF;
		if (now = 0 ns) then
			nllOO17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nllOO18 <= nllOO17;
		END IF;
	END PROCESS;
	wire_nllOO18_w_lg_w_lg_q72w73w(0) <= wire_nllOO18_w_lg_q72w(0) AND n00l;
	wire_nllOO18_w_lg_q72w(0) <= nllOO18 XOR nllOO17;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlO0l11 <= nlO0l12;
		END IF;
		if (now = 0 ns) then
			nlO0l11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlO0l12 <= nlO0l11;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlO1i15 <= nlO1i16;
		END IF;
		if (now = 0 ns) then
			nlO1i15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlO1i16 <= nlO1i15;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlO1O13 <= nlO1O14;
		END IF;
		if (now = 0 ns) then
			nlO1O13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlO1O14 <= nlO1O13;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOii10 <= nlOii9;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOii9 <= nlOii10;
		END IF;
		if (now = 0 ns) then
			nlOii9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOil7 <= nlOil8;
		END IF;
		if (now = 0 ns) then
			nlOil7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOil8 <= nlOil7;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOli5 <= nlOli6;
		END IF;
		if (now = 0 ns) then
			nlOli5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOli6 <= nlOli5;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOlO3 <= nlOlO4;
		END IF;
		if (now = 0 ns) then
			nlOlO3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOlO4 <= nlOlO3;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOOl1 <= nlOOl2;
		END IF;
		if (now = 0 ns) then
			nlOOl1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOOl2 <= nlOOl1;
		END IF;
	END PROCESS;
	PROCESS (clk, wire_ni0O_CLRN)
	BEGIN
		IF (wire_ni0O_CLRN = '0') THEN
				ni0i <= '0';
				ni0l <= '0';
				ni1O <= '0';
				niii <= '0';
		ELSIF (clk = '1' AND clk'event) THEN
			IF (nlOiO = '1') THEN
				ni0i <= niiO;
				ni0l <= nili;
				ni1O <= niil;
				niii <= nill;
			END IF;
		END IF;
	END PROCESS;
	wire_ni0O_CLRN <= ((nlO0l12 XOR nlO0l11) AND reset_n);
	PROCESS (clk, wire_niOO_PRN, wire_niOO_CLRN)
	BEGIN
		IF (wire_niOO_PRN = '0') THEN
				n00i <= '1';
				n00l <= '1';
				n00O <= '1';
				n01i <= '1';
				n01l <= '1';
				n01O <= '1';
				n0ii <= '1';
				n0il <= '1';
				n0iO <= '1';
				n0li <= '1';
				n0ll <= '1';
				n0lO <= '1';
				n0Ol <= '1';
				n0OO <= '1';
				n1lO <= '1';
				n1Ol <= '1';
				n1OO <= '1';
				ni1i <= '1';
				ni1l <= '1';
				niil <= '1';
				niiO <= '1';
				nili <= '1';
				nill <= '1';
				nilO <= '1';
				niOi <= '1';
				niOl <= '1';
				nl1i <= '1';
		ELSIF (wire_niOO_CLRN = '0') THEN
				n00i <= '0';
				n00l <= '0';
				n00O <= '0';
				n01i <= '0';
				n01l <= '0';
				n01O <= '0';
				n0ii <= '0';
				n0il <= '0';
				n0iO <= '0';
				n0li <= '0';
				n0ll <= '0';
				n0lO <= '0';
				n0Ol <= '0';
				n0OO <= '0';
				n1lO <= '0';
				n1Ol <= '0';
				n1OO <= '0';
				ni1i <= '0';
				ni1l <= '0';
				niil <= '0';
				niiO <= '0';
				nili <= '0';
				nill <= '0';
				nilO <= '0';
				niOi <= '0';
				niOl <= '0';
				nl1i <= '0';
		ELSIF (clk = '1' AND clk'event) THEN
				n00i <= n00l;
				n00l <= n0ii;
				n00O <= wire_n1Oi_o;
				n01i <= n01l;
				n01l <= n01O;
				n01O <= n00i;
				n0ii <= n0il;
				n0il <= n0iO;
				n0iO <= n0li;
				n0li <= n0ll;
				n0ll <= ((phystat_ena AND wire_w_lg_power_state_transition_done_ena60w(0)) AND n0lO);
				n0lO <= (NOT (((((NOT ((ni1O XOR n0Ol) XOR (NOT (nlO1O14 XOR nlO1O13)))) AND (NOT (ni0i XOR n0OO))) AND (NOT (ni0l XOR ni1i))) AND (NOT (niii XOR ni1l))) AND (nlO1i16 XOR nlO1i15)));
				n0Ol <= ni1O;
				n0OO <= ni0i;
				n1lO <= n1Ol;
				n1Ol <= n1OO;
				n1OO <= n01i;
				ni1i <= ni0l;
				ni1l <= niii;
				niil <= nilO;
				niiO <= niOi;
				nili <= niOl;
				nill <= nl1i;
				nilO <= latched_p0;
				niOi <= latched_p0s;
				niOl <= latched_p1;
				nl1i <= latched_p2;
		END IF;
	END PROCESS;
	wire_niOO_CLRN <= ((nlOil8 XOR nlOil7) AND reset_n);
	wire_niOO_PRN <= (nlOii10 XOR nlOii9);
	wire_niOO_w_lg_w_lg_w_lg_w_lg_nill7w9w11w12w(0) <= wire_niOO_w_lg_w_lg_w_lg_nill7w9w11w(0) AND niil;
	wire_niOO_w_lg_w_lg_w_lg_nill7w9w11w(0) <= wire_niOO_w_lg_w_lg_nill7w9w(0) AND wire_niOO_w_lg_niiO10w(0);
	wire_niOO_w_lg_w_lg_w_lg_nill7w9w16w(0) <= wire_niOO_w_lg_w_lg_nill7w9w(0) AND niiO;
	wire_niOO_w_lg_w_lg_nill7w9w(0) <= wire_niOO_w_lg_nill7w(0) AND wire_niOO_w_lg_nili8w(0);
	wire_niOO_w_lg_w_lg_nill7w24w(0) <= wire_niOO_w_lg_nill7w(0) AND nili;
	wire_niOO_w_lg_nill32w(0) <= nill AND wire_niOO_w_lg_nili8w(0);
	wire_niOO_w_lg_niil17w(0) <= NOT niil;
	wire_niOO_w_lg_niiO10w(0) <= NOT niiO;
	wire_niOO_w_lg_nili8w(0) <= NOT nili;
	wire_niOO_w_lg_nill7w(0) <= NOT nill;
	wire_n1Oi_data <= ( n1lO & n1Ol & wire_nllOi22_w_lg_w_lg_q82w83w & wire_nllOl20_w_lg_w_lg_q79w80w & n01l & n01O & n00i & wire_nllOO18_w_lg_w_lg_q72w73w);
	wire_n1Oi_sel <= ( rphystatus_delay(2 DOWNTO 0));
	n1Oi :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n1Oi_data,
		o => wire_n1Oi_o,
		sel => wire_n1Oi_sel
	  );
	wire_nl0O_powerdown <= ( powerdown(1 DOWNTO 0));
	nl0O :  stratixiv_hssi_phystatus_generator_fsm
	  PORT MAP ( 
		clk => clk,
		internal_done => n00O,
		p1 => latched_p1,
		phystat_ena => phystat_ena,
		phystatus => wire_nl0O_phystatus,
		power_state_transition_done => power_state_transition_done,
		power_state_transition_done_ena => power_state_transition_done_ena,
		powerdown => wire_nl0O_powerdown,
		reset_n => reset_n,
		rindv_rx => rindv_rx,
		rmaster_rx => rmaster_rx,
		rmaster_up_rx => rmaster_up_rx,
		rphystatus_rst_toggle => rphystatus_rst_toggle,
		rx_detect_valid => rx_detect_valid,
		speed_change => speed_change,
		speed_change_centrl => speed_change_centrl,
		speed_change_quad_down => speed_change_quad_down,
		speed_change_quad_up => speed_change_quad_up
	  );

 END RTL; --stratixiv_hssi_phystatus_generator
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

--synthesis_resources = lut 50 mux21 146 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_rx_pipe_interface IS 
	 PORT 
	 ( 
		 clk	:	IN  STD_LOGIC;
		 latched_p1	:	IN  STD_LOGIC;
		 polinv_rx	:	IN  STD_LOGIC;
		 polinv_rx_int	:	OUT  STD_LOGIC;
		 rclkcmpinsertpad	:	IN  STD_LOGIC;
		 reset_n	:	IN  STD_LOGIC;
		 rind_error_reporting	:	IN  STD_LOGIC;
		 rrdwidth_rx	:	IN  STD_LOGIC;
		 rrx_pipe_enable	:	IN  STD_LOGIC;
		 rx_detect_valid	:	IN  STD_LOGIC;
		 rx_detect_valid_sync	:	IN  STD_LOGIC;
		 rx_found	:	IN  STD_LOGIC;
		 rx_found_sync	:	IN  STD_LOGIC;
		 rxd	:	IN  STD_LOGIC_VECTOR (63 DOWNTO 0);
		 rxd_ch	:	OUT  STD_LOGIC_VECTOR (63 DOWNTO 0);
		 rxelecidle	:	OUT  STD_LOGIC;
		 rxelectricalidle	:	IN  STD_LOGIC;
		 rxpolarity	:	IN  STD_LOGIC;
		 rxstatus	:	OUT  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 rxvalid	:	OUT  STD_LOGIC;
		 sigdetni	:	IN  STD_LOGIC;
		 txdetectrx	:	IN  STD_LOGIC
	 ); 
 END stratixiv_hssi_rx_pipe_interface;

 ARCHITECTURE RTL OF stratixiv_hssi_rx_pipe_interface IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 n110l7	:	STD_LOGIC := '0';
	 SIGNAL	 n110l8	:	STD_LOGIC := '0';
	 SIGNAL  wire_n110l8_w_lg_q84w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n111i11	:	STD_LOGIC := '0';
	 SIGNAL	 n111i12	:	STD_LOGIC := '0';
	 SIGNAL  wire_n111i12_w_lg_q92w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n111O10	:	STD_LOGIC := '0';
	 SIGNAL  wire_n111O10_w_lg_q88w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n111O9	:	STD_LOGIC := '0';
	 SIGNAL	 n11ii5	:	STD_LOGIC := '0';
	 SIGNAL	 n11ii6	:	STD_LOGIC := '0';
	 SIGNAL  wire_n11ii6_w_lg_q77w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n11iO3	:	STD_LOGIC := '0';
	 SIGNAL	 n11iO4	:	STD_LOGIC := '0';
	 SIGNAL	 n11Ol1	:	STD_LOGIC := '0';
	 SIGNAL	 n11Ol2	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0ll41	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0ll42	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0Oi39	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0Oi40	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0OO37	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0OO38	:	STD_LOGIC := '0';
	 SIGNAL	 nlOi0l35	:	STD_LOGIC := '0';
	 SIGNAL	 nlOi0l36	:	STD_LOGIC := '0';
	 SIGNAL	 nlOiil33	:	STD_LOGIC := '0';
	 SIGNAL	 nlOiil34	:	STD_LOGIC := '0';
	 SIGNAL	 nlOilO31	:	STD_LOGIC := '0';
	 SIGNAL	 nlOilO32	:	STD_LOGIC := '0';
	 SIGNAL	 nlOiOl29	:	STD_LOGIC := '0';
	 SIGNAL	 nlOiOl30	:	STD_LOGIC := '0';
	 SIGNAL	 nlOl1l27	:	STD_LOGIC := '0';
	 SIGNAL	 nlOl1l28	:	STD_LOGIC := '0';
	 SIGNAL	 nlOlii25	:	STD_LOGIC := '0';
	 SIGNAL	 nlOlii26	:	STD_LOGIC := '0';
	 SIGNAL	 nlOlli23	:	STD_LOGIC := '0';
	 SIGNAL	 nlOlli24	:	STD_LOGIC := '0';
	 SIGNAL	 nlOlOi21	:	STD_LOGIC := '0';
	 SIGNAL	 nlOlOi22	:	STD_LOGIC := '0';
	 SIGNAL	 nlOO0i17	:	STD_LOGIC := '0';
	 SIGNAL	 nlOO0i18	:	STD_LOGIC := '0';
	 SIGNAL	 nlOO1i19	:	STD_LOGIC := '0';
	 SIGNAL	 nlOO1i20	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOiO15	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOiO16	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOOl13	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOOl14	:	STD_LOGIC := '0';
	 SIGNAL	n00ii	:	STD_LOGIC := '0';
	 SIGNAL	n0ill	:	STD_LOGIC := '0';
	 SIGNAL	n0iOi	:	STD_LOGIC := '0';
	 SIGNAL	n1l1l	:	STD_LOGIC := '0';
	 SIGNAL	n1O0i	:	STD_LOGIC := '0';
	 SIGNAL	n1O1O	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0ilO_w_lg_w_lg_w_lg_n0iOi81w94w95w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0ilO_w_lg_w_lg_w_lg_n1O0i73w79w80w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0ilO_w_lg_w_lg_n0iOi81w94w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0ilO_w_lg_w_lg_n1O0i73w79w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0ilO_w_lg_n0iOi81w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0ilO_w_lg_n1O0i73w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nlOOO	:	STD_LOGIC := '0';
	 SIGNAL	nO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_n000i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_rrdwidth_rx82w85w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rx_detect_valid_sync90w93w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rx_detect_valid_sync75w78w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rx_found_sync86w89w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlO0iO267w268w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlOl0l211w212w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_latched_p174w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOl0i226w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOl0i220w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOii110w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rclkcmpinsertpad227w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rclkcmpinsertpad221w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rrdwidth_rx82w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rx_detect_valid_sync90w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rx_detect_valid_sync75w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rx_detect_valid_sync193w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rx_detect_valid_sync259w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rx_found_sync86w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rxd_range52w279w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rxd_range20w235w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlO00l272w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlO0iO267w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlO0li263w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOili225w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOl0l211w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOliO197w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rclkcmpinsertpad205w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_reset_n72w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rind_error_reporting109w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rrdwidth_rx199w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_sigdetni66w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rxd_range51w277w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rxd_range19w233w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  n11lO :	STD_LOGIC;
	 SIGNAL  nlO00i :	STD_LOGIC;
	 SIGNAL  nlO00l :	STD_LOGIC;
	 SIGNAL  nlO00O :	STD_LOGIC;
	 SIGNAL  nlO01i :	STD_LOGIC;
	 SIGNAL  nlO01l :	STD_LOGIC;
	 SIGNAL  nlO01O :	STD_LOGIC;
	 SIGNAL  nlO0ii :	STD_LOGIC;
	 SIGNAL  nlO0il :	STD_LOGIC;
	 SIGNAL  nlO0iO :	STD_LOGIC;
	 SIGNAL  nlO0li :	STD_LOGIC;
	 SIGNAL  nlOi0i :	STD_LOGIC;
	 SIGNAL  nlOi1l :	STD_LOGIC;
	 SIGNAL  nlOi1O :	STD_LOGIC;
	 SIGNAL  nlOiii :	STD_LOGIC;
	 SIGNAL  nlOili :	STD_LOGIC;
	 SIGNAL  nlOill :	STD_LOGIC;
	 SIGNAL  nlOl0i :	STD_LOGIC;
	 SIGNAL  nlOl0l :	STD_LOGIC;
	 SIGNAL  nlOl0O :	STD_LOGIC;
	 SIGNAL  nlOl1i :	STD_LOGIC;
	 SIGNAL  nlOliO :	STD_LOGIC;
	 SIGNAL  nlOllO :	STD_LOGIC;
	 SIGNAL  nlOlOO :	STD_LOGIC;
	 SIGNAL  nlOO0O :	STD_LOGIC;
	 SIGNAL  nlOO1O :	STD_LOGIC;
	 SIGNAL  nlOOii :	STD_LOGIC;
	 SIGNAL  nlOOil :	STD_LOGIC;
	 SIGNAL  nlOOll :	STD_LOGIC;
	 SIGNAL  nlOOlO :	STD_LOGIC;
	 SIGNAL  nlOOOi :	STD_LOGIC;
	 SIGNAL  wire_w_rxd_range52w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rxd_range51w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rxd_range20w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rxd_range19w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_w_lg_w_lg_rrdwidth_rx82w85w(0) <= wire_w_lg_rrdwidth_rx82w(0) AND wire_n110l8_w_lg_q84w(0);
	wire_w_lg_w_lg_rx_detect_valid_sync90w93w(0) <= wire_w_lg_rx_detect_valid_sync90w(0) AND wire_n111i12_w_lg_q92w(0);
	wire_w_lg_w_lg_rx_detect_valid_sync75w78w(0) <= wire_w_lg_rx_detect_valid_sync75w(0) AND wire_n11ii6_w_lg_q77w(0);
	wire_w_lg_w_lg_rx_found_sync86w89w(0) <= wire_w_lg_rx_found_sync86w(0) AND wire_n111O10_w_lg_q88w(0);
	wire_w_lg_w_lg_nlO0iO267w268w(0) <= wire_w_lg_nlO0iO267w(0) AND nlO0il;
	wire_w_lg_w_lg_nlOl0l211w212w(0) <= wire_w_lg_nlOl0l211w(0) AND nlOl0i;
	wire_w_lg_latched_p174w(0) <= latched_p1 AND rx_found_sync;
	wire_w_lg_nlOl0i226w(0) <= nlOl0i AND wire_w_lg_nlOili225w(0);
	wire_w_lg_nlOl0i220w(0) <= nlOl0i AND nlOili;
	wire_w_lg_nlOOii110w(0) <= nlOOii AND wire_w_lg_rind_error_reporting109w(0);
	wire_w_lg_rclkcmpinsertpad227w(0) <= rclkcmpinsertpad AND wire_w_lg_nlOl0i226w(0);
	wire_w_lg_rclkcmpinsertpad221w(0) <= rclkcmpinsertpad AND wire_w_lg_nlOl0i220w(0);
	wire_w_lg_rrdwidth_rx82w(0) <= rrdwidth_rx AND latched_p1;
	wire_w_lg_rx_detect_valid_sync90w(0) <= rx_detect_valid_sync AND wire_w_lg_w_lg_rx_found_sync86w89w(0);
	wire_w_lg_rx_detect_valid_sync75w(0) <= rx_detect_valid_sync AND wire_w_lg_latched_p174w(0);
	wire_w_lg_rx_detect_valid_sync193w(0) <= rx_detect_valid_sync AND wire_n0ilO_w_lg_n0iOi81w(0);
	wire_w_lg_rx_detect_valid_sync259w(0) <= rx_detect_valid_sync AND wire_n0ilO_w_lg_n1O0i73w(0);
	wire_w_lg_rx_found_sync86w(0) <= rx_found_sync AND wire_w_lg_w_lg_rrdwidth_rx82w85w(0);
	wire_w_lg_w_rxd_range52w279w(0) <= wire_w_rxd_range52w(0) AND wire_w_lg_w_rxd_range51w277w(0);
	wire_w_lg_w_rxd_range20w235w(0) <= wire_w_rxd_range20w(0) AND wire_w_lg_w_rxd_range19w233w(0);
	wire_w_lg_nlO00l272w(0) <= NOT nlO00l;
	wire_w_lg_nlO0iO267w(0) <= NOT nlO0iO;
	wire_w_lg_nlO0li263w(0) <= NOT nlO0li;
	wire_w_lg_nlOili225w(0) <= NOT nlOili;
	wire_w_lg_nlOl0l211w(0) <= NOT nlOl0l;
	wire_w_lg_nlOliO197w(0) <= NOT nlOliO;
	wire_w_lg_rclkcmpinsertpad205w(0) <= NOT rclkcmpinsertpad;
	wire_w_lg_reset_n72w(0) <= NOT reset_n;
	wire_w_lg_rind_error_reporting109w(0) <= NOT rind_error_reporting;
	wire_w_lg_rrdwidth_rx199w(0) <= NOT rrdwidth_rx;
	wire_w_lg_sigdetni66w(0) <= NOT sigdetni;
	wire_w_lg_w_rxd_range51w277w(0) <= NOT wire_w_rxd_range51w(0);
	wire_w_lg_w_rxd_range19w233w(0) <= NOT wire_w_rxd_range19w(0);
	n11lO <= '1';
	nlO00i <= (rclkcmpinsertpad AND (nlO0il AND nlO00l));
	nlO00l <= (((((((rxd(0) AND rxd(1)) AND rxd(2)) AND (NOT rxd(3))) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7));
	nlO00O <= (wire_w_lg_rclkcmpinsertpad205w(0) AND wire_w_lg_w_lg_nlO0iO267w268w(0));
	nlO01i <= ((NOT rxd(13)) AND wire_w_lg_w_rxd_range51w277w(0));
	nlO01l <= wire_w_lg_w_rxd_range52w279w(0);
	nlO01O <= (rclkcmpinsertpad AND (nlO0il AND wire_w_lg_nlO00l272w(0)));
	nlO0ii <= (wire_w_lg_rclkcmpinsertpad205w(0) AND (nlO0iO AND nlO0il));
	nlO0il <= ((NOT rxd(13)) AND rxd(14));
	nlO0iO <= ((((((((NOT rxd(0)) AND rxd(1)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7));
	nlO0li <= (wire_w_lg_rx_detect_valid_sync259w(0) AND (nlO0ll42 XOR nlO0ll41));
	nlOi0i <= (wire_w_lg_rclkcmpinsertpad227w(0) AND (nlOi0l36 XOR nlOi0l35));
	nlOi1l <= ((NOT rxd(45)) AND wire_w_lg_w_rxd_range19w233w(0));
	nlOi1O <= (wire_w_lg_w_rxd_range20w235w(0) AND (nlO0OO38 XOR nlO0OO37));
	nlOiii <= (wire_w_lg_rclkcmpinsertpad221w(0) AND (nlOiil34 XOR nlOiil33));
	nlOili <= ((((((((rxd(32) AND rxd(33)) AND rxd(34)) AND (NOT rxd(35))) AND rxd(36)) AND rxd(37)) AND rxd(38)) AND rxd(39)) AND (nlO0Oi40 XOR nlO0Oi39));
	nlOill <= ((wire_w_lg_rclkcmpinsertpad205w(0) AND (wire_w_lg_w_lg_nlOl0l211w212w(0) AND (nlOiOl30 XOR nlOiOl29))) AND (nlOilO32 XOR nlOilO31));
	nlOl0i <= ((NOT rxd(45)) AND rxd(46));
	nlOl0l <= ((((((((NOT rxd(32)) AND rxd(33)) AND rxd(34)) AND rxd(35)) AND rxd(36)) AND rxd(37)) AND rxd(38)) AND rxd(39));
	nlOl0O <= ((wire_w_lg_reset_n72w(0) OR wire_w_lg_rrdwidth_rx199w(0)) OR (NOT (nlOlii26 XOR nlOlii25)));
	nlOl1i <= ((wire_w_lg_rclkcmpinsertpad205w(0) AND (nlOl0l AND nlOl0i)) AND (nlOl1l28 XOR nlOl1l27));
	nlOliO <= (wire_w_lg_rx_detect_valid_sync193w(0) AND (nlOlli24 XOR nlOlli23));
	nlOllO <= ((reset_n AND rrdwidth_rx) AND (nlOlOi22 XOR nlOlOi21));
	nlOlOO <= ((wire_n10ii_dataout OR wire_n1OlO_dataout) OR (NOT (nlOO1i20 XOR nlOO1i19)));
	nlOO0O <= (nlOOii AND rind_error_reporting);
	nlOO1O <= (wire_w_lg_nlOOii110w(0) AND (nlOO0i18 XOR nlOO0i17));
	nlOOii <= (wire_n1liO_dataout OR wire_n00OO_dataout);
	nlOOil <= ((wire_n10il_dataout OR wire_n1OOi_dataout) OR (NOT (nlOOiO16 XOR nlOOiO15)));
	nlOOll <= (wire_n10iO_dataout OR wire_n1OOl_dataout);
	nlOOlO <= (wire_n1lll_dataout OR wire_n0i1l_dataout);
	nlOOOi <= (wire_n0ilO_w_lg_w_lg_w_lg_n1O0i73w79w80w(0) OR (wire_n0ilO_w_lg_w_lg_w_lg_n0iOi81w94w95w(0) AND (nlOOOl14 XOR nlOOOl13)));
	polinv_rx_int <= wire_n1iO_dataout;
	rxd_ch <= ( wire_ni_dataout & wire_nlO_dataout & wire_nll_dataout & wire_nli_dataout & wire_niO_dataout & wire_nil_dataout & wire_nii_dataout & wire_n0O_dataout & wire_n0l_dataout & wire_n0i_dataout & wire_n1O_dataout & wire_n1l_dataout & wire_n1i_dataout & wire_nlOO_dataout & wire_nlOl_dataout & wire_nlOi_dataout & wire_nllO_dataout & wire_nlll_dataout & wire_nlli_dataout & wire_nliO_dataout & wire_nlil_dataout & wire_nlii_dataout & wire_nl0O_dataout & wire_nl0l_dataout & wire_nl0i_dataout & wire_nl1O_dataout & wire_nl1l_dataout & wire_nl1i_dataout & wire_niOO_dataout & wire_niOl_dataout & wire_niOi_dataout & wire_nilO_dataout & wire_nill_dataout & wire_nili_dataout & wire_niiO_dataout & wire_niil_dataout & wire_niii_dataout & wire_ni0O_dataout & wire_ni0l_dataout & wire_ni0i_dataout & wire_ni1O_dataout & wire_ni1l_dataout & wire_ni1i_dataout & wire_n0OO_dataout & wire_n0Ol_dataout & wire_n0Oi_dataout & wire_n0lO_dataout & wire_n0ll_dataout & wire_n0li_dataout & wire_n0iO_dataout & wire_n0il_dataout & wire_n0ii_dataout & wire_n00O_dataout & wire_n00l_dataout & wire_n00i_dataout & wire_n01O_dataout & wire_n01l_dataout & wire_n01i_dataout & wire_n1OO_dataout & wire_n1Ol_dataout & wire_n1Oi_dataout & wire_n1lO_dataout & wire_n1ll_dataout & wire_n1li_dataout);
	rxelecidle <= wire_n1ii_dataout;
	rxstatus <= ( wire_n10O_dataout & wire_n10l_dataout & wire_n10i_dataout);
	rxvalid <= wire_n1il_dataout;
	wire_w_rxd_range52w(0) <= rxd(13);
	wire_w_rxd_range51w(0) <= rxd(14);
	wire_w_rxd_range20w(0) <= rxd(45);
	wire_w_rxd_range19w(0) <= rxd(46);
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n110l7 <= n110l8;
		END IF;
		if (now = 0 ns) then
			n110l7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n110l8 <= n110l7;
		END IF;
	END PROCESS;
	wire_n110l8_w_lg_q84w(0) <= n110l8 XOR n110l7;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n111i11 <= n111i12;
		END IF;
		if (now = 0 ns) then
			n111i11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n111i12 <= n111i11;
		END IF;
	END PROCESS;
	wire_n111i12_w_lg_q92w(0) <= n111i12 XOR n111i11;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n111O10 <= n111O9;
		END IF;
	END PROCESS;
	wire_n111O10_w_lg_q88w(0) <= n111O10 XOR n111O9;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n111O9 <= n111O10;
		END IF;
		if (now = 0 ns) then
			n111O9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n11ii5 <= n11ii6;
		END IF;
		if (now = 0 ns) then
			n11ii5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n11ii6 <= n11ii5;
		END IF;
	END PROCESS;
	wire_n11ii6_w_lg_q77w(0) <= n11ii6 XOR n11ii5;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n11iO3 <= n11iO4;
		END IF;
		if (now = 0 ns) then
			n11iO3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n11iO4 <= n11iO3;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n11Ol1 <= n11Ol2;
		END IF;
		if (now = 0 ns) then
			n11Ol1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n11Ol2 <= n11Ol1;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlO0ll41 <= nlO0ll42;
		END IF;
		if (now = 0 ns) then
			nlO0ll41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlO0ll42 <= nlO0ll41;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlO0Oi39 <= nlO0Oi40;
		END IF;
		if (now = 0 ns) then
			nlO0Oi39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlO0Oi40 <= nlO0Oi39;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlO0OO37 <= nlO0OO38;
		END IF;
		if (now = 0 ns) then
			nlO0OO37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlO0OO38 <= nlO0OO37;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOi0l35 <= nlOi0l36;
		END IF;
		if (now = 0 ns) then
			nlOi0l35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOi0l36 <= nlOi0l35;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOiil33 <= nlOiil34;
		END IF;
		if (now = 0 ns) then
			nlOiil33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOiil34 <= nlOiil33;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOilO31 <= nlOilO32;
		END IF;
		if (now = 0 ns) then
			nlOilO31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOilO32 <= nlOilO31;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOiOl29 <= nlOiOl30;
		END IF;
		if (now = 0 ns) then
			nlOiOl29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOiOl30 <= nlOiOl29;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOl1l27 <= nlOl1l28;
		END IF;
		if (now = 0 ns) then
			nlOl1l27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOl1l28 <= nlOl1l27;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOlii25 <= nlOlii26;
		END IF;
		if (now = 0 ns) then
			nlOlii25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOlii26 <= nlOlii25;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOlli23 <= nlOlli24;
		END IF;
		if (now = 0 ns) then
			nlOlli23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOlli24 <= nlOlli23;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOlOi21 <= nlOlOi22;
		END IF;
		if (now = 0 ns) then
			nlOlOi21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOlOi22 <= nlOlOi21;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOO0i17 <= nlOO0i18;
		END IF;
		if (now = 0 ns) then
			nlOO0i17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOO0i18 <= nlOO0i17;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOO1i19 <= nlOO1i20;
		END IF;
		if (now = 0 ns) then
			nlOO1i19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOO1i20 <= nlOO1i19;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOOiO15 <= nlOOiO16;
		END IF;
		if (now = 0 ns) then
			nlOOiO15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOOiO16 <= nlOOiO15;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOOOl13 <= nlOOOl14;
		END IF;
		if (now = 0 ns) then
			nlOOOl13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nlOOOl14 <= nlOOOl13;
		END IF;
	END PROCESS;
	PROCESS (clk, reset_n)
	BEGIN
		IF (reset_n = '0') THEN
				n00ii <= '0';
				n0ill <= '0';
				n0iOi <= '0';
				n1l1l <= '0';
				n1O0i <= '0';
				n1O1O <= '0';
		ELSIF (clk = '1' AND clk'event) THEN
				n00ii <= n0ill;
				n0ill <= txdetectrx;
				n0iOi <= rx_detect_valid_sync;
				n1l1l <= n1O1O;
				n1O0i <= rx_detect_valid_sync;
				n1O1O <= txdetectrx;
		END IF;
	END PROCESS;
	wire_n0ilO_w_lg_w_lg_w_lg_n0iOi81w94w95w(0) <= wire_n0ilO_w_lg_w_lg_n0iOi81w94w(0) AND n00ii;
	wire_n0ilO_w_lg_w_lg_w_lg_n1O0i73w79w80w(0) <= wire_n0ilO_w_lg_w_lg_n1O0i73w79w(0) AND n1l1l;
	wire_n0ilO_w_lg_w_lg_n0iOi81w94w(0) <= wire_n0ilO_w_lg_n0iOi81w(0) AND wire_w_lg_w_lg_rx_detect_valid_sync90w93w(0);
	wire_n0ilO_w_lg_w_lg_n1O0i73w79w(0) <= wire_n0ilO_w_lg_n1O0i73w(0) AND wire_w_lg_w_lg_rx_detect_valid_sync75w78w(0);
	wire_n0ilO_w_lg_n0iOi81w(0) <= NOT n0iOi;
	wire_n0ilO_w_lg_n1O0i73w(0) <= NOT n1O0i;
	PROCESS (clk, reset_n, wire_nl_CLRN)
	BEGIN
		IF (reset_n = '0') THEN
				nlOOO <= '1';
				nO <= '1';
		ELSIF (wire_nl_CLRN = '0') THEN
				nlOOO <= '0';
				nO <= '0';
		ELSIF (clk = '1' AND clk'event) THEN
				nlOOO <= rxelectricalidle;
				nO <= nlOOO;
		END IF;
		if (now = 0 ns) then
			nlOOO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nO <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nl_CLRN <= (n11Ol2 XOR n11Ol1);
	wire_n000i_dataout <= (rxd(45) AND rxd(46)) AND NOT(nlOi0i);
	wire_n001i_dataout <= wire_n001O_dataout AND NOT(nlOill);
	wire_n001l_dataout <= nlOi0i AND NOT(nlOiii);
	wire_n001O_dataout <= wire_n000i_dataout AND NOT(nlOiii);
	wire_n00i_dataout <= rxd(9) AND rrx_pipe_enable;
	wire_n00l_dataout <= rxd(10) AND rrx_pipe_enable;
	wire_n00O_dataout <= rxd(11) AND rrx_pipe_enable;
	wire_n00OO_dataout <= rxd(43) AND (nlOllO AND wire_w_lg_nlOliO197w(0));
	wire_n010i_dataout <= wire_n01il_dataout AND NOT(nlOi1l);
	wire_n010l_dataout <= nlOi1O AND NOT(nlOi1l);
	wire_n010O_dataout <= wire_n01iO_dataout AND NOT(nlOi1l);
	wire_n011i_dataout <= wire_n010l_dataout AND NOT(nlOliO);
	wire_n011l_dataout <= wire_n010O_dataout AND NOT(nlOliO);
	wire_n011O_dataout <= wire_n01ii_dataout AND NOT(nlOliO);
	wire_n01i_dataout <= rxd(6) AND rrx_pipe_enable;
	wire_n01ii_dataout <= wire_n01li_dataout AND NOT(nlOi1l);
	wire_n01il_dataout <= wire_n01ll_dataout AND NOT(nlOi1O);
	wire_n01iO_dataout <= wire_n01lO_dataout AND NOT(nlOi1O);
	wire_n01l_dataout <= rxd(7) AND rrx_pipe_enable;
	wire_n01li_dataout <= wire_n01Oi_dataout AND NOT(nlOi1O);
	wire_n01ll_dataout <= wire_n01Ol_dataout AND NOT(nlOl1i);
	wire_n01lO_dataout <= wire_n01OO_dataout OR nlOl1i;
	wire_n01O_dataout <= rxd(8) AND rrx_pipe_enable;
	wire_n01Oi_dataout <= wire_n001i_dataout AND NOT(nlOl1i);
	wire_n01Ol_dataout <= wire_n001l_dataout OR nlOill;
	wire_n01OO_dataout <= nlOiii AND NOT(nlOill);
	wire_n0i_dataout <= rxd(54) AND rrx_pipe_enable;
	wire_n0i1l_dataout <= rxd(41) AND (nlOllO AND wire_w_lg_nlOliO197w(0));
	wire_n0ii_dataout <= rxd(12) AND rrx_pipe_enable;
	wire_n0il_dataout <= rxd(13) AND rrx_pipe_enable;
	wire_n0iO_dataout <= rxd(14) AND rrx_pipe_enable;
	wire_n0l_dataout <= rxd(55) AND rrx_pipe_enable;
	wire_n0li_dataout <= rxd(15) AND rrx_pipe_enable;
	wire_n0ll_dataout <= rxd(16) AND rrx_pipe_enable;
	wire_n0lO_dataout <= rxd(17) AND rrx_pipe_enable;
	wire_n0O_dataout <= rxd(56) AND rrx_pipe_enable;
	wire_n0Oi_dataout <= rxd(18) AND rrx_pipe_enable;
	wire_n0Ol_dataout <= rxd(19) AND rrx_pipe_enable;
	wire_n0OO_dataout <= rxd(20) AND rrx_pipe_enable;
	wire_n100O_dataout <= wire_n10li_dataout AND NOT(wire_w_lg_reset_n72w(0));
	wire_n10i_dataout <= wire_nliOl_dataout WHEN rrx_pipe_enable = '1'  ELSE rx_found;
	wire_n10ii_dataout <= wire_n10ll_dataout AND NOT(wire_w_lg_reset_n72w(0));
	wire_n10il_dataout <= wire_n10lO_dataout AND NOT(wire_w_lg_reset_n72w(0));
	wire_n10iO_dataout <= wire_n10Oi_dataout AND NOT(wire_w_lg_reset_n72w(0));
	wire_n10l_dataout <= wire_nliOO_dataout WHEN rrx_pipe_enable = '1'  ELSE rx_detect_valid;
	wire_n10li_dataout <= wire_n10Ol_dataout AND NOT(nlO0li);
	wire_n10ll_dataout <= wire_n10OO_dataout AND NOT(nlO0li);
	wire_n10lO_dataout <= wire_n1i1i_dataout AND NOT(nlO0li);
	wire_n10O_dataout <= wire_nll1i_dataout AND rrx_pipe_enable;
	wire_n10Oi_dataout <= wire_n1i1l_dataout AND NOT(nlO0li);
	wire_n10Ol_dataout <= wire_n1i1O_dataout AND NOT(nlO01i);
	wire_n10OO_dataout <= nlO01l AND NOT(nlO01i);
	wire_n11i_dataout <= wire_n11l_dataout AND NOT(wire_w_lg_reset_n72w(0));
	wire_n11l_dataout <= ((rxd(10) OR rxd(42)) OR (NOT (n11iO4 XOR n11iO3))) WHEN rrdwidth_rx = '1'  ELSE rxd(10);
	wire_n1i_dataout <= rxd(51) AND rrx_pipe_enable;
	wire_n1i0i_dataout <= wire_n1iii_dataout AND NOT(nlO01l);
	wire_n1i0l_dataout <= wire_n1iil_dataout AND NOT(nlO01l);
	wire_n1i0O_dataout <= wire_n1iiO_dataout AND NOT(nlO0ii);
	wire_n1i1i_dataout <= wire_n1i0i_dataout AND NOT(nlO01i);
	wire_n1i1l_dataout <= wire_n1i0l_dataout AND NOT(nlO01i);
	wire_n1i1O_dataout <= wire_n1i0O_dataout AND NOT(nlO01l);
	wire_n1ii_dataout <= wire_nlOOl_dataout WHEN rrx_pipe_enable = '1'  ELSE wire_w_lg_sigdetni66w(0);
	wire_n1iii_dataout <= wire_n1ili_dataout OR nlO0ii;
	wire_n1iil_dataout <= wire_n1ill_dataout AND NOT(nlO0ii);
	wire_n1iiO_dataout <= wire_n1ilO_dataout OR nlO00O;
	wire_n1il_dataout <= wire_n11i_dataout AND rrx_pipe_enable;
	wire_n1ili_dataout <= nlO00i AND NOT(nlO00O);
	wire_n1ill_dataout <= wire_n1iOi_dataout AND NOT(nlO00O);
	wire_n1ilO_dataout <= nlO01O AND NOT(nlO00i);
	wire_n1iO_dataout <= rxpolarity WHEN rrx_pipe_enable = '1'  ELSE polinv_rx;
	wire_n1iOi_dataout <= wire_n1iOl_dataout AND NOT(nlO00i);
	wire_n1iOl_dataout <= (rxd(13) AND rxd(14)) AND NOT(nlO01O);
	wire_n1l_dataout <= rxd(52) AND rrx_pipe_enable;
	wire_n1li_dataout <= rxd(0) AND rrx_pipe_enable;
	wire_n1liO_dataout <= rxd(11) AND (reset_n AND wire_w_lg_nlO0li263w(0));
	wire_n1ll_dataout <= rxd(1) AND rrx_pipe_enable;
	wire_n1lll_dataout <= rxd(9) AND (reset_n AND wire_w_lg_nlO0li263w(0));
	wire_n1lO_dataout <= rxd(2) AND rrx_pipe_enable;
	wire_n1O_dataout <= rxd(53) AND rrx_pipe_enable;
	wire_n1Oi_dataout <= rxd(3) AND rrx_pipe_enable;
	wire_n1Ol_dataout <= rxd(4) AND rrx_pipe_enable;
	wire_n1Oll_dataout <= wire_n1OOO_dataout AND NOT(nlOl0O);
	wire_n1OlO_dataout <= wire_n011i_dataout AND NOT(nlOl0O);
	wire_n1OO_dataout <= rxd(5) AND rrx_pipe_enable;
	wire_n1OOi_dataout <= wire_n011l_dataout AND NOT(nlOl0O);
	wire_n1OOl_dataout <= wire_n011O_dataout AND NOT(nlOl0O);
	wire_n1OOO_dataout <= wire_n010i_dataout AND NOT(nlOliO);
	wire_ni_dataout <= rxd(63) AND rrx_pipe_enable;
	wire_ni0i_dataout <= rxd(24) AND rrx_pipe_enable;
	wire_ni0l_dataout <= rxd(25) AND rrx_pipe_enable;
	wire_ni0O_dataout <= rxd(26) AND rrx_pipe_enable;
	wire_ni1i_dataout <= rxd(21) AND rrx_pipe_enable;
	wire_ni1l_dataout <= rxd(22) AND rrx_pipe_enable;
	wire_ni1O_dataout <= rxd(23) AND rrx_pipe_enable;
	wire_nii_dataout <= rxd(57) AND rrx_pipe_enable;
	wire_niii_dataout <= rxd(27) AND rrx_pipe_enable;
	wire_niil_dataout <= rxd(28) AND rrx_pipe_enable;
	wire_niiO_dataout <= rxd(29) AND rrx_pipe_enable;
	wire_nil_dataout <= rxd(58) AND rrx_pipe_enable;
	wire_nili_dataout <= rxd(30) AND rrx_pipe_enable;
	wire_nill_dataout <= rxd(31) AND rrx_pipe_enable;
	wire_nilO_dataout <= rxd(32) AND rrx_pipe_enable;
	wire_niO_dataout <= rxd(59) AND rrx_pipe_enable;
	wire_niOi_dataout <= rxd(33) AND rrx_pipe_enable;
	wire_niOl_dataout <= rxd(34) AND rrx_pipe_enable;
	wire_niOO_dataout <= rxd(35) AND rrx_pipe_enable;
	wire_nl0i_dataout <= rxd(39) AND rrx_pipe_enable;
	wire_nl0l_dataout <= rxd(40) AND rrx_pipe_enable;
	wire_nl0O_dataout <= rxd(41) AND rrx_pipe_enable;
	wire_nl1i_dataout <= rxd(36) AND rrx_pipe_enable;
	wire_nl1l_dataout <= rxd(37) AND rrx_pipe_enable;
	wire_nl1O_dataout <= rxd(38) AND rrx_pipe_enable;
	wire_nli_dataout <= rxd(60) AND rrx_pipe_enable;
	wire_nlii_dataout <= rxd(42) AND rrx_pipe_enable;
	wire_nlil_dataout <= rxd(43) AND rrx_pipe_enable;
	wire_nliO_dataout <= rxd(44) AND rrx_pipe_enable;
	wire_nliOl_dataout <= wire_nll1l_dataout AND NOT(wire_w_lg_reset_n72w(0));
	wire_nliOO_dataout <= wire_nll1O_dataout AND NOT(wire_w_lg_reset_n72w(0));
	wire_nll_dataout <= rxd(61) AND rrx_pipe_enable;
	wire_nll0i_dataout <= wire_nllii_dataout AND NOT(nlOOOi);
	wire_nll0l_dataout <= wire_nllil_dataout AND NOT(nlOOlO);
	wire_nll0O_dataout <= wire_nlliO_dataout AND NOT(nlOOlO);
	wire_nll1i_dataout <= wire_nll0i_dataout AND NOT(wire_w_lg_reset_n72w(0));
	wire_nll1l_dataout <= wire_nll0l_dataout OR nlOOOi;
	wire_nll1O_dataout <= wire_nll0O_dataout OR nlOOOi;
	wire_nlli_dataout <= rxd(45) AND rrx_pipe_enable;
	wire_nllii_dataout <= wire_nllli_dataout OR nlOOlO;
	wire_nllil_dataout <= wire_nllll_dataout OR nlOOll;
	wire_nlliO_dataout <= wire_nlllO_dataout AND NOT(nlOOll);
	wire_nlll_dataout <= rxd(46) AND rrx_pipe_enable;
	wire_nllli_dataout <= wire_nllOi_dataout OR nlOOll;
	wire_nllll_dataout <= wire_nllOl_dataout AND NOT(nlOOil);
	wire_nlllO_dataout <= wire_nllOO_dataout OR nlOOil;
	wire_nllO_dataout <= rxd(47) AND rrx_pipe_enable;
	wire_nllOi_dataout <= wire_nlO1i_dataout OR nlOOil;
	wire_nllOl_dataout <= wire_nlO1l_dataout OR nlOO0O;
	wire_nllOO_dataout <= wire_nlO1O_dataout OR nlOO0O;
	wire_nlO_dataout <= rxd(62) AND rrx_pipe_enable;
	wire_nlO0i_dataout <= (wire_n100O_dataout OR wire_n1Oll_dataout) AND NOT(nlOlOO);
	wire_nlO1i_dataout <= nlOO1O OR nlOO0O;
	wire_nlO1l_dataout <= wire_nlO0i_dataout AND NOT(nlOO1O);
	wire_nlO1O_dataout <= nlOlOO AND NOT(nlOO1O);
	wire_nlOi_dataout <= rxd(48) AND rrx_pipe_enable;
	wire_nlOl_dataout <= rxd(49) AND rrx_pipe_enable;
	wire_nlOO_dataout <= rxd(50) AND rrx_pipe_enable;
	wire_nlOOl_dataout <= nO OR wire_w_lg_reset_n72w(0);

 END RTL; --stratixiv_hssi_rx_pipe_interface
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 36 mux21 13 oper_mux 1 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_tx_pipe_interface IS 
	 PORT 
	 ( 
		 clk	:	IN  STD_LOGIC;
		 powerdown	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 powerstate	:	OUT  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 refclk_b	:	IN  STD_LOGIC;
		 refclk_b_reset_n	:	IN  STD_LOGIC;
		 reset_n	:	IN  STD_LOGIC;
		 rev_loopbk	:	OUT  STD_LOGIC;
		 revloopback	:	IN  STD_LOGIC;
		 rtx_elec_idle_delay	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 rtx_pipe_enable	:	IN  STD_LOGIC;
		 rtxswing_sel_ena	:	IN  STD_LOGIC;
		 tx_elec_idle	:	OUT  STD_LOGIC;
		 tx_elec_idle_comp	:	IN  STD_LOGIC;
		 txd	:	OUT  STD_LOGIC_VECTOR (43 DOWNTO 0);
		 txd_ch	:	IN  STD_LOGIC_VECTOR (43 DOWNTO 0);
		 txdeemph	:	IN  STD_LOGIC;
		 txdeemph_int	:	OUT  STD_LOGIC;
		 txdetectrx	:	OUT  STD_LOGIC;
		 txdetectrxloopback	:	IN  STD_LOGIC;
		 txelecidle	:	IN  STD_LOGIC;
		 txmargin	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 txmargin_int	:	OUT  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 txswing	:	IN  STD_LOGIC;
		 txswing_int	:	OUT  STD_LOGIC
	 ); 
 END stratixiv_hssi_tx_pipe_interface;

 ARCHITECTURE RTL OF stratixiv_hssi_tx_pipe_interface IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 niiOl23	:	STD_LOGIC := '0';
	 SIGNAL	 niiOl24	:	STD_LOGIC := '0';
	 SIGNAL	 nil0i19	:	STD_LOGIC := '0';
	 SIGNAL	 nil0i20	:	STD_LOGIC := '0';
	 SIGNAL  wire_nil0i20_w_lg_w_lg_q190w191w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nil0i20_w_lg_q190w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nil0l17	:	STD_LOGIC := '0';
	 SIGNAL	 nil0l18	:	STD_LOGIC := '0';
	 SIGNAL  wire_nil0l18_w_lg_w_lg_q184w185w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nil0l18_w_lg_q184w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nil0O15	:	STD_LOGIC := '0';
	 SIGNAL	 nil0O16	:	STD_LOGIC := '0';
	 SIGNAL  wire_nil0O16_w_lg_w_lg_q171w172w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nil0O16_w_lg_q171w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nil1i21	:	STD_LOGIC := '0';
	 SIGNAL	 nil1i22	:	STD_LOGIC := '0';
	 SIGNAL	 nilii13	:	STD_LOGIC := '0';
	 SIGNAL	 nilii14	:	STD_LOGIC := '0';
	 SIGNAL	 niliO11	:	STD_LOGIC := '0';
	 SIGNAL	 niliO12	:	STD_LOGIC := '0';
	 SIGNAL	 nilli10	:	STD_LOGIC := '0';
	 SIGNAL	 nilli9	:	STD_LOGIC := '0';
	 SIGNAL	 nilOi7	:	STD_LOGIC := '0';
	 SIGNAL	 nilOi8	:	STD_LOGIC := '0';
	 SIGNAL	 nilOl5	:	STD_LOGIC := '0';
	 SIGNAL	 nilOl6	:	STD_LOGIC := '0';
	 SIGNAL	 niO1i3	:	STD_LOGIC := '0';
	 SIGNAL	 niO1i4	:	STD_LOGIC := '0';
	 SIGNAL	 niO1O1	:	STD_LOGIC := '0';
	 SIGNAL	 niO1O2	:	STD_LOGIC := '0';
	 SIGNAL	nl00i	:	STD_LOGIC := '0';
	 SIGNAL	nl10i	:	STD_LOGIC := '0';
	 SIGNAL	nl10l	:	STD_LOGIC := '0';
	 SIGNAL	nl10O	:	STD_LOGIC := '0';
	 SIGNAL	nl11O	:	STD_LOGIC := '0';
	 SIGNAL	nl1ii	:	STD_LOGIC := '0';
	 SIGNAL	nl1il	:	STD_LOGIC := '0';
	 SIGNAL	nl1iO	:	STD_LOGIC := '0';
	 SIGNAL	nl1li	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl01O_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nl01O_PRN	:	STD_LOGIC;
	 SIGNAL	nl1lO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl1ll_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nl1ll_PRN	:	STD_LOGIC;
	 SIGNAL	wire_nl1ll_ENA	:	STD_LOGIC;
	 SIGNAL	nl1Oi	:	STD_LOGIC := '0';
	 SIGNAL	nl1OO	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl1Ol_w_lg_nl1Oi168w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl11l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl11l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl11l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_powerdown_range196w204w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOO193w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_reset_n194w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rtx_pipe_enable151w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_powerdown_range198w199w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  nil1O :	STD_LOGIC;
	 SIGNAL  nilll :	STD_LOGIC;
	 SIGNAL  nillO :	STD_LOGIC;
	 SIGNAL  nilOO :	STD_LOGIC;
	 SIGNAL  wire_w_powerdown_range196w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_powerdown_range198w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rtx_elec_idle_delay_range170w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_w_lg_w_powerdown_range196w204w(0) <= wire_w_powerdown_range196w(0) AND wire_w_lg_w_powerdown_range198w199w(0);
	wire_w_lg_nilOO193w(0) <= NOT nilOO;
	wire_w_lg_reset_n194w(0) <= NOT reset_n;
	wire_w_lg_rtx_pipe_enable151w(0) <= NOT rtx_pipe_enable;
	wire_w_lg_w_powerdown_range198w199w(0) <= NOT wire_w_powerdown_range198w(0);
	nil1O <= (wire_w_lg_reset_n194w(0) OR wire_w_lg_rtx_pipe_enable151w(0));
	nilll <= '0';
	nillO <= '1';
	nilOO <= ((tx_elec_idle_comp OR nl1lO) OR (NOT (niO1i4 XOR niO1i3)));
	powerstate <= ( wire_nl0OO_dataout & wire_nl0Ol_dataout & wire_nl0Oi_dataout & wire_nl0lO_dataout);
	rev_loopbk <= wire_nl0iO_dataout;
	tx_elec_idle <= wire_nl0il_dataout;
	txd <= ( txd_ch(43 DOWNTO 0));
	txdeemph_int <= txdeemph;
	txdetectrx <= wire_nl00O_dataout;
	txmargin_int <= ( txmargin(2 DOWNTO 0));
	txswing_int <= wire_nl0ll_dataout;
	wire_w_powerdown_range196w(0) <= powerdown(0);
	wire_w_powerdown_range198w(0) <= powerdown(1);
	wire_w_rtx_elec_idle_delay_range170w(0) <= rtx_elec_idle_delay(0);
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN niiOl23 <= niiOl24;
		END IF;
		if (now = 0 ns) then
			niiOl23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN niiOl24 <= niiOl23;
		END IF;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nil0i19 <= nil0i20;
		END IF;
		if (now = 0 ns) then
			nil0i19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nil0i20 <= nil0i19;
		END IF;
	END PROCESS;
	wire_nil0i20_w_lg_w_lg_q190w191w(0) <= wire_nil0i20_w_lg_q190w(0) AND nl00i;
	wire_nil0i20_w_lg_q190w(0) <= nil0i20 XOR nil0i19;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nil0l17 <= nil0l18;
		END IF;
		if (now = 0 ns) then
			nil0l17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nil0l18 <= nil0l17;
		END IF;
	END PROCESS;
	wire_nil0l18_w_lg_w_lg_q184w185w(0) <= wire_nil0l18_w_lg_q184w(0) AND nl10O;
	wire_nil0l18_w_lg_q184w(0) <= nil0l18 XOR nil0l17;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nil0O15 <= nil0O16;
		END IF;
		if (now = 0 ns) then
			nil0O15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nil0O16 <= nil0O15;
		END IF;
	END PROCESS;
	wire_nil0O16_w_lg_w_lg_q171w172w(0) <= wire_nil0O16_w_lg_q171w(0) AND wire_w_rtx_elec_idle_delay_range170w(0);
	wire_nil0O16_w_lg_q171w(0) <= nil0O16 XOR nil0O15;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nil1i21 <= nil1i22;
		END IF;
		if (now = 0 ns) then
			nil1i21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nil1i22 <= nil1i21;
		END IF;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nilii13 <= nilii14;
		END IF;
		if (now = 0 ns) then
			nilii13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nilii14 <= nilii13;
		END IF;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN niliO11 <= niliO12;
		END IF;
		if (now = 0 ns) then
			niliO11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN niliO12 <= niliO11;
		END IF;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nilli10 <= nilli9;
		END IF;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nilli9 <= nilli10;
		END IF;
		if (now = 0 ns) then
			nilli9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nilOi7 <= nilOi8;
		END IF;
		if (now = 0 ns) then
			nilOi7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nilOi8 <= nilOi7;
		END IF;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nilOl5 <= nilOl6;
		END IF;
		if (now = 0 ns) then
			nilOl5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN nilOl6 <= nilOl5;
		END IF;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN niO1i3 <= niO1i4;
		END IF;
		if (now = 0 ns) then
			niO1i3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN niO1i4 <= niO1i3;
		END IF;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN niO1O1 <= niO1O2;
		END IF;
		if (now = 0 ns) then
			niO1O1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b)
	BEGIN
		IF (refclk_b = '1' AND refclk_b'event) THEN niO1O2 <= niO1O1;
		END IF;
	END PROCESS;
	PROCESS (refclk_b, wire_nl01O_PRN, wire_nl01O_CLRN)
	BEGIN
		IF (wire_nl01O_PRN = '0') THEN
				nl00i <= '1';
				nl10i <= '1';
				nl10l <= '1';
				nl10O <= '1';
				nl11O <= '1';
				nl1ii <= '1';
				nl1il <= '1';
				nl1iO <= '1';
				nl1li <= '1';
		ELSIF (wire_nl01O_CLRN = '0') THEN
				nl00i <= '0';
				nl10i <= '0';
				nl10l <= '0';
				nl10O <= '0';
				nl11O <= '0';
				nl1ii <= '0';
				nl1il <= '0';
				nl1iO <= '0';
				nl1li <= '0';
		ELSIF (refclk_b = '1' AND refclk_b'event) THEN
				nl00i <= nl11O;
				nl10i <= nl10l;
				nl10l <= nl10O;
				nl10O <= nl1ii;
				nl11O <= nl10i;
				nl1ii <= nl1il;
				nl1il <= nl1iO;
				nl1iO <= nl1li;
				nl1li <= nilOO;
		END IF;
		if (now = 0 ns) then
			nl00i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl10i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl10l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl10O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl11O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl1ii <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl1il <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl1iO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl1li <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nl01O_CLRN <= (nilOl6 XOR nilOl5);
	wire_nl01O_PRN <= ((nilOi8 XOR nilOi7) AND refclk_b_reset_n);
	PROCESS (refclk_b, wire_nl1ll_PRN, wire_nl1ll_CLRN)
	BEGIN
		IF (wire_nl1ll_PRN = '0') THEN
				nl1lO <= '1';
		ELSIF (wire_nl1ll_CLRN = '0') THEN
				nl1lO <= '0';
		ELSIF (refclk_b = '1' AND refclk_b'event) THEN
			IF (wire_nl1ll_ENA = '1') THEN
				nl1lO <= nilll;
			END IF;
		END IF;
		if (now = 0 ns) then
			nl1lO <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nl1ll_CLRN <= (nilli10 XOR nilli9);
	wire_nl1ll_ENA <= (((nl1OO AND nl1lO) AND (nilii14 XOR nilii13)) AND wire_nl1Ol_w_lg_nl1Oi168w(0));
	wire_nl1ll_PRN <= ((niliO12 XOR niliO11) AND refclk_b_reset_n);
	PROCESS (refclk_b, refclk_b_reset_n)
	BEGIN
		IF (refclk_b_reset_n = '0') THEN
				nl1Oi <= '0';
				nl1OO <= '0';
		ELSIF (refclk_b = '1' AND refclk_b'event) THEN
				nl1Oi <= nl1OO;
				nl1OO <= tx_elec_idle_comp;
		END IF;
	END PROCESS;
	wire_nl1Ol_w_lg_nl1Oi168w(0) <= NOT nl1Oi;
	wire_niOll_dataout <= (powerdown(0) AND powerdown(1)) AND NOT(nil1O);
	wire_niOlO_dataout <= ((NOT powerdown(0)) AND powerdown(1)) AND NOT(nil1O);
	wire_niOOi_dataout <= (wire_w_lg_w_powerdown_range196w204w(0) AND (niiOl24 XOR niiOl23)) AND NOT(nil1O);
	wire_niOOl_dataout <= (((NOT powerdown(0)) AND wire_w_lg_w_powerdown_range198w199w(0)) AND (nil1i22 XOR nil1i21)) AND NOT(nil1O);
	wire_nl00O_dataout <= txdetectrxloopback WHEN wire_w_lg_rtx_pipe_enable151w(0) = '1'  ELSE (txdetectrxloopback AND wire_niOlO_dataout);
	wire_nl0il_dataout <= txelecidle WHEN wire_w_lg_rtx_pipe_enable151w(0) = '1'  ELSE wire_nl11i_dataout;
	wire_nl0iO_dataout <= revloopback WHEN wire_w_lg_rtx_pipe_enable151w(0) = '1'  ELSE ((txdetectrxloopback AND wire_niOOl_dataout) AND (niO1O2 XOR niO1O1));
	wire_nl0ll_dataout <= txswing AND rtxswing_sel_ena;
	wire_nl0lO_dataout <= wire_niOOl_dataout AND rtx_pipe_enable;
	wire_nl0Oi_dataout <= wire_niOOi_dataout AND rtx_pipe_enable;
	wire_nl0Ol_dataout <= wire_niOlO_dataout AND rtx_pipe_enable;
	wire_nl0OO_dataout <= wire_niOll_dataout AND rtx_pipe_enable;
	wire_nl11i_dataout <= nl1li WHEN wire_w_lg_nilOO193w(0) = '1'  ELSE wire_nl11l_o;
	wire_nl11l_data <= ( wire_nil0i20_w_lg_w_lg_q190w191w & nl11O & nl10i & nl10l & wire_nil0l18_w_lg_w_lg_q184w185w & nl1ii & nl1il & nl1iO);
	wire_nl11l_sel <= ( rtx_elec_idle_delay(2 DOWNTO 1) & wire_nil0O16_w_lg_w_lg_q171w172w);
	nl11l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl11l_data,
		o => wire_nl11l_o,
		sel => wire_nl11l_sel
	  );

 END RTL; --stratixiv_hssi_tx_pipe_interface
--synopsys translate_on
--VALID FILE


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_q_pipe_interface_top IS
   PORT (
      
      -- General signals
      -- TX PIPE interface clock == TX Phase Comp write clock
      -- RX PIPE interface clock == RX Phase Comp read clock
      -- TX Phase Comp FIFO read clock
      -- synchronized reset i.e TX Phase Comp write clock
      -- synchronized reset i.e.RX Phase Comp read clock
      -- synchronized reset i.e.TX Phase Comp read clock
      
      -- CRAM 
      -- enable tx pipe interface
      -- enable rx pipe interface
      -- Single width = 0, double width = 1
      -- programmable delay for controlling output buffer
      -- Enables control of voltage swing level.  Implementation 
      -- is optional under PIPE 1.87.  When this CRAM is not set, full swing is the default mode
      -- normal = 0, bypass = 1
      -- recognize EDB = 0, PAD = 1 insertion for 8b/10b decode errors
      -- Combined reporting = 0 i.e. 8b/10b error|disparity error=> rxstatus=3'b100
      -- individual reporting = 1 i.e. 8b/10b error => rxstatus = 3'b111;
      -- disparity error => rxstatus = 3'b100
      -- no toggle (gen 2) = 0, toggle (option for gen 1) = 1
      
      -- programmable delay for the emulation circuitry of successfull power state
      -- transition.  Default delay between the change of power state and the assertion
      -- of ~ 13 parallel cycles.  Setting of this CRAM to 3'b000 will result in a delay
      -- of ~ 13 parallel cycles.
      
      -- PLD - PIPE Interface
      -- TX PIPE Interface: Command 
      -- P0 ==> loopback, P1 ==> RX detection
      -- output buffer control
      --			   txcompliance,				// compliance pattern command
      -- power state control
      
      -- Selects transmitter de-emphasis under Gen 2 speeds
      -- Selects transmitter voltage levels 
      -- Selects transmitter voltage swing levels
      
      -- TX PIPE Interface: Data
      -- TX data path	
      
      -- RX PIPE Interface: Command/Status
      -- polarity inversion command
      
      -- indicates symbol lock and valid data
      -- indicates receiver detection of electrical idle.  
      -- encodes receiver status and error codes when receiving data
      -- encodes compliance pattern speed when doing receiver detection
      
      -- RX PIPE Interface: Data
      -- RX data path
      
      -- PHYStatus Generator
      -- communicate completion of power state transitions, receiver 
      -- detection, rate change
      
      -- Commands
      -- enables reverse parallel loopback when in PIPE bypass mode
      -- enables polarity inversion when in PIPE bypass mode
      
      -- PIPE - PCS Inteface
      -- TX PIPE Interface
      -- TX data path to TX Phase Comp FIFO
      -- reverse parallel loopback control to MUX after the encoder
      -- compensated txelecidle from the TX Phase Comp FIFO
      -- synchronous to refclk_b
      
      -- Auto Speed Negotiation
      
      -- Auto Negotiation Module
      -- asserted when signaling rate change between Gen 1 and Gen 2 is in process.  Sychronization occurs within PIPE module
      
      -- RX PIPE Interface
      -- RX data path from the RX Phase comp FIFO
      -- polarity inversion control; sychronization occurs at 8b/10b decoder
      
      -- PIPE - PMA Interface
      -- TX PIPE Interface
      -- command to the output buffer
      -- command to the PMA module for receiver detection
      -- decoded power state: used internally to the PIPE interface
      
      -- RX PIPE Interface
      -- PMA indication of receiver being detected
      -- Validation of rx_found
      -- electrical idle detection from Rx Electrical Idle inference module
      
      --shawn
      --shawn
      --shawn
      
      -- PHYStatus Generator
      -- asserted when successful power state transition occurs
      -- validates power_state_transition_done, currently tied to 0
      
      -- PIPE-DPRIO interface
      -- Selects transmitter de-emphasis under Gen 2 speeds
      -- Selects transmitter voltage levels 
      -- Selects transmitter voltage swing levels
      
      --********************************************************************************
      -- INCLUDE STATEMENTS
      --********************************************************************************
      
      --********************************************************************************
      -- I/O SIGNALS
      --********************************************************************************
      -- General signals
      --shawn
      --shawn
      --shawn
      
      pipe_tx_clk                      : IN STD_LOGIC;
      pipe_rx_clk                      : IN STD_LOGIC;
      refclk_b                         : IN STD_LOGIC;
      tx_pipe_reset                    : IN STD_LOGIC;
      rx_pipe_reset                    : IN STD_LOGIC;
      refclk_b_reset                   : IN STD_LOGIC;
      
      -- CRAM 
      rtx_pipe_enable                  : IN STD_LOGIC;
      rrx_pipe_enable                  : IN STD_LOGIC;
      rrdwidth_rx                      : IN STD_LOGIC;
      rtx_elec_idle_delay              : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      rtxswing_sel_ena                 : IN STD_LOGIC;
      rrx_detect_bypass                : IN STD_LOGIC;
      rclkcmpinsertpad                 : IN STD_LOGIC;
      rind_error_reporting             : IN STD_LOGIC;
      rphystatus_rst_toggle            : IN STD_LOGIC;
      rphystatus_delay                 : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      -- PLD - PIPE Interface
      -- TX PIPE Interface: Command 
      txdetectrxloopback               : IN STD_LOGIC;
      txelecidle                       : IN STD_LOGIC;
      powerdown                        : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      
      txdeemph                         : IN STD_LOGIC;
      txmargin                         : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      txswing                          : IN STD_LOGIC;
      
      -- TX PIPE Interface: Data
      txd_ch                           : IN STD_LOGIC_VECTOR(43 DOWNTO 0);
      
      -- RX PIPE Interface: Command/Status
      rxpolarity                       : IN STD_LOGIC;
      
      rxvalid                          : OUT STD_LOGIC;
      rxelecidle                       : OUT STD_LOGIC;
      rxstatus                         : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      -- RX PIPE Interface: Data
      rxd_ch                           : OUT STD_LOGIC_VECTOR(63 DOWNTO 0);
      
      -- PHYStatus Generator
      phystatus                        : OUT STD_LOGIC;
      
      -- Commands
      revloopback                      : IN STD_LOGIC;
      polinv_rx                        : IN STD_LOGIC;
      
      -- PIPE - PCS Inteface
      -- TX PIPE Interface
      txd                              : OUT STD_LOGIC_VECTOR(43 DOWNTO 0);
      rev_loopbk                       : OUT STD_LOGIC;
      tx_elec_idle_comp                : IN STD_LOGIC;
      
      rindv_rx                         : IN STD_LOGIC;
      rmaster_rx                       : IN STD_LOGIC;		-- New bundle mode MDIO, selects master quad
      rmaster_up_rx                    : IN STD_LOGIC;		-- New bundle mode MDIO, selects master quad
      
      -- Auto Negotiation Module
      speed_change                     : IN STD_LOGIC;
      speed_change_centrl              : IN STD_LOGIC;
      speed_change_quad_up             : IN STD_LOGIC;
      speed_change_quad_down           : IN STD_LOGIC;
      
      -- RX PIPE Interface
      rxd                              : IN STD_LOGIC_VECTOR(63 DOWNTO 0);
      polinv_rx_int                    : OUT STD_LOGIC;
      
      -- PIPE - PMA Interface
      -- TX PIPE Interface
      tx_elec_idle                     : OUT STD_LOGIC;
      txdetectrx                       : OUT STD_LOGIC;
      powerstate                       : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      
      sigdetni                         : IN STD_LOGIC;  -- ww25_2008
      
      -- RX PIPE Interface
      rx_found                         : IN STD_LOGIC;
      rx_detect_valid                  : IN STD_LOGIC;
      rxelectricalidle                 : IN STD_LOGIC;
      txdetectrxin                     : IN STD_LOGIC;
      powerstatein                     : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      use_powerstatein                 : IN STD_LOGIC;
      
      -- PHYStatus Generator
      power_state_transition_done      : IN STD_LOGIC;
      power_state_transition_done_ena  : IN STD_LOGIC;
      
      -- PIPE-DPRIO interface
      txdeemph_int                     : OUT STD_LOGIC;
      txmargin_int                     : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      txswing_int                      : OUT STD_LOGIC
   );
END stratixiv_hssi_q_pipe_interface_top;

ARCHITECTURE trans OF stratixiv_hssi_q_pipe_interface_top IS
   COMPONENT stratixiv_hssi_tx_pipe_interface
      PORT (
         clk                              : IN STD_LOGIC;
         refclk_b                         : IN STD_LOGIC;
         reset_n                          : IN STD_LOGIC;
         refclk_b_reset_n                 : IN STD_LOGIC;
         rtx_pipe_enable                  : IN STD_LOGIC;
         rtx_elec_idle_delay              : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rtxswing_sel_ena                 : IN STD_LOGIC;
         txdetectrxloopback               : IN STD_LOGIC;
         txelecidle                       : IN STD_LOGIC;
         powerdown                        : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         txdeemph                         : IN STD_LOGIC;
         txmargin                         : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         txswing                          : IN STD_LOGIC;
         txd_ch                           : IN STD_LOGIC_VECTOR(43 DOWNTO 0);
         revloopback                      : IN STD_LOGIC;
         txd                              : OUT STD_LOGIC_VECTOR(43 DOWNTO 0);
         rev_loopbk                       : OUT STD_LOGIC;
         tx_elec_idle_comp                : IN STD_LOGIC;
         tx_elec_idle                     : OUT STD_LOGIC;
         txdetectrx                       : OUT STD_LOGIC;
         powerstate                       : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
         txdeemph_int                     : OUT STD_LOGIC;
         txmargin_int                     : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         txswing_int                      : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_phystatus_generator
      PORT (
         clk                              : IN STD_LOGIC;
         reset_n                          : IN STD_LOGIC;
         phystat_ena                      : IN STD_LOGIC;
         rphystatus_rst_toggle            : IN STD_LOGIC;
         rphystatus_delay                 : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         powerdown                        : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         phystatus                        : OUT STD_LOGIC;
         latched_p0                       : IN STD_LOGIC;
         latched_p0s                      : IN STD_LOGIC;
         latched_p1                       : IN STD_LOGIC;
         latched_p2                       : IN STD_LOGIC;
         rindv_rx                         : IN STD_LOGIC;
         rmaster_rx                       : IN STD_LOGIC;
         rmaster_up_rx                    : IN STD_LOGIC;
         speed_change                     : IN STD_LOGIC;
         speed_change_centrl              : IN STD_LOGIC;
         speed_change_quad_up             : IN STD_LOGIC;
         speed_change_quad_down           : IN STD_LOGIC;
         rx_detect_valid                  : IN STD_LOGIC;
         power_state_transition_done      : IN STD_LOGIC;
         power_state_transition_done_ena  : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_rx_pipe_interface
      PORT (
         clk                              : IN STD_LOGIC;
         reset_n                          : IN STD_LOGIC;
         rrx_pipe_enable                  : IN STD_LOGIC;
         rrdwidth_rx                      : IN STD_LOGIC;
         rclkcmpinsertpad                 : IN STD_LOGIC;
         rind_error_reporting             : IN STD_LOGIC;
         rxpolarity                       : IN STD_LOGIC;
         rxvalid                          : OUT STD_LOGIC;
         rxelecidle                       : OUT STD_LOGIC;
         rxstatus                         : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         rxd_ch                           : OUT STD_LOGIC_VECTOR(63 DOWNTO 0);
         polinv_rx                        : IN STD_LOGIC;
         rxd                              : IN STD_LOGIC_VECTOR(63 DOWNTO 0);
         polinv_rx_int                    : OUT STD_LOGIC;
         latched_p1                       : IN STD_LOGIC;
         txdetectrx                       : IN STD_LOGIC;
         rx_found                         : IN STD_LOGIC;
         rx_found_sync                    : IN STD_LOGIC;
         rx_detect_valid                  : IN STD_LOGIC;
         rx_detect_valid_sync             : IN STD_LOGIC;
         sigdetni                         : IN STD_LOGIC;  -- ww25_2008
         rxelectricalidle                 : IN STD_LOGIC
      );
   END COMPONENT;
   
   
   --********************************************************************************
   -- PARAMETERS
   --********************************************************************************
   
   --********************************************************************************
   -- DECLARATIONS
   --********************************************************************************
   
   SIGNAL phystat_ena            : STD_LOGIC;
   
   SIGNAL rx_found_reg_0         : STD_LOGIC;
   SIGNAL rx_found_reg_1         : STD_LOGIC;
   
   SIGNAL rx_detect_valid_reg_0  : STD_LOGIC;
   SIGNAL rx_detect_valid_reg_1  : STD_LOGIC;
   
   SIGNAL tx_pipe_reset_n        : STD_LOGIC;
   SIGNAL rx_pipe_reset_n        : STD_LOGIC;
   SIGNAL refclk_b_reset_n       : STD_LOGIC;		-- reset for txelecidle_d_generator
   
   SIGNAL txdetectrx_reg_0       : STD_LOGIC;
   SIGNAL txdetectrx_reg_1       : STD_LOGIC;
   SIGNAL txdetectrx_reg_2       : STD_LOGIC;
   SIGNAL txdetectrx_reg_3       : STD_LOGIC;
   SIGNAL txdetectrx_reg_4       : STD_LOGIC;
   SIGNAL txdetectrx_reg_5       : STD_LOGIC;
   SIGNAL txdetectrx_reg_6       : STD_LOGIC;
   
   SIGNAL bypass_rx_found        : STD_LOGIC;
   SIGNAL bypass_rx_detect_valid : STD_LOGIC;
   
   SIGNAL rx_found_int           : STD_LOGIC;
   SIGNAL rx_detect_valid_int    : STD_LOGIC;
   
   SIGNAL latched_p0             : STD_LOGIC;
   SIGNAL latched_p0s            : STD_LOGIC;
   SIGNAL latched_p1             : STD_LOGIC;
   SIGNAL latched_p2             : STD_LOGIC;
   
   SIGNAL p1_sync                : STD_LOGIC;
   
   SIGNAL tmp_txdetectrxin       : STD_LOGIC;		--shawn
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL rxvalid_xhdl7          : STD_LOGIC;
   SIGNAL rxelecidle_xhdl5       : STD_LOGIC;
   SIGNAL rxstatus_xhdl6         : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rxd_ch_xhdl4           : STD_LOGIC_VECTOR(63 DOWNTO 0);
   SIGNAL phystatus_xhdl0        : STD_LOGIC;
   SIGNAL txd_xhdl9              : STD_LOGIC_VECTOR(43 DOWNTO 0);
   SIGNAL rev_loopbk_xhdl3       : STD_LOGIC;
   SIGNAL polinv_rx_int_xhdl1    : STD_LOGIC;
   SIGNAL tx_elec_idle_xhdl8     : STD_LOGIC;
   SIGNAL txdetectrx_xhdl11      : STD_LOGIC;
   SIGNAL powerstate_xhdl2       : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL txdeemph_int_xhdl10    : STD_LOGIC;
   SIGNAL txmargin_int_xhdl12    : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL txswing_int_xhdl13     : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   rxvalid <= rxvalid_xhdl7;
   rxelecidle <= rxelecidle_xhdl5;
   rxstatus <= rxstatus_xhdl6;
   rxd_ch <= rxd_ch_xhdl4;
   phystatus <= phystatus_xhdl0;
   txd <= txd_xhdl9;
   rev_loopbk <= rev_loopbk_xhdl3;
   polinv_rx_int <= polinv_rx_int_xhdl1;
   tx_elec_idle <= tx_elec_idle_xhdl8;
   txdetectrx <= txdetectrx_xhdl11;
   powerstate <= powerstate_xhdl2;
   txdeemph_int <= txdeemph_int_xhdl10;
   txmargin_int <= txmargin_int_xhdl12;
   txswing_int <= txswing_int_xhdl13;
   
   --********************************************************************************
   -- ASSIGN STATEMENTS
   --********************************************************************************
   phystat_ena <= rtx_pipe_enable OR rrx_pipe_enable;
   
   tx_pipe_reset_n <= NOT(tx_pipe_reset);
   rx_pipe_reset_n <= NOT(rx_pipe_reset);
   refclk_b_reset_n <= NOT(refclk_b_reset);
   
   rx_found_int <= bypass_rx_found WHEN (rrx_detect_bypass = '1') ELSE
                   rx_found_reg_1;
   rx_detect_valid_int <= bypass_rx_detect_valid WHEN (rrx_detect_bypass = '1') ELSE
                          rx_detect_valid_reg_1;
   
   tmp_txdetectrxin <= txdetectrxin WHEN (use_powerstatein = '1') ELSE		--shawn
                       txdetectrx_xhdl11;
   
   latched_p0 <= powerstatein(0) WHEN (use_powerstatein = '1') ELSE		--shawn
                 powerstate_xhdl2(0);
   latched_p0s <= powerstatein(1) WHEN (use_powerstatein = '1') ELSE		--shawn;
                  powerstate_xhdl2(1);
   latched_p1 <= powerstatein(2) WHEN (use_powerstatein = '1') ELSE		--shawn;
                 powerstate_xhdl2(2);
   latched_p2 <= powerstatein(3) WHEN (use_powerstatein = '1') ELSE		--shawn;
                 powerstate_xhdl2(3);
   
   --********************************************************************************
   -- SUBMODULE INSTANTIATIONS
   --********************************************************************************
   
   
   
   tx_pipe_interface_inst : stratixiv_hssi_tx_pipe_interface
      PORT MAP (
         
         -- General signals
         clk                  => pipe_tx_clk,
         refclk_b             => refclk_b,
         reset_n              => tx_pipe_reset_n,
         refclk_b_reset_n     => refclk_b_reset_n,
         
         -- CRAM 
         rtx_pipe_enable      => rtx_pipe_enable,
         rtx_elec_idle_delay  => rtx_elec_idle_delay,
         
         rtxswing_sel_ena     => rtxswing_sel_ena,
         
         -- PLD - PIPE Interface
         -- TX PIPE Interface: Command
         txdetectrxloopback   => txdetectrxloopback,
         txelecidle           => txelecidle,
         --					     .txcompliance					(txcompliance),
         powerdown            => powerdown,
         
         txdeemph             => txdeemph,
         txmargin             => txmargin,
         txswing              => txswing,
         
         -- TX PIPE Interface: Data
         txd_ch               => txd_ch,
         
         -- Commands
         revloopback          => revloopback,
         
         -- PIPE - PCS Inteface
         -- TX PIPE Interface
         txd                  => txd_xhdl9,
         rev_loopbk           => rev_loopbk_xhdl3,
         tx_elec_idle_comp    => tx_elec_idle_comp,
         
         -- PIPE - PMA Interface
         tx_elec_idle         => tx_elec_idle_xhdl8,
         txdetectrx           => txdetectrx_xhdl11,
         
         -- Central PCS
         powerstate           => powerstate_xhdl2,
         
         -- PIPE - DPRIO
         txdeemph_int         => txdeemph_int_xhdl10,
         txmargin_int         => txmargin_int_xhdl12,
         txswing_int          => txswing_int_xhdl13
      );
   
   
   
   rx_pipe_interface_inst : stratixiv_hssi_rx_pipe_interface
      PORT MAP (
         
         -- General signals
         clk                   => pipe_rx_clk,
         reset_n               => rx_pipe_reset_n,
         
         -- CRAM 
         rrx_pipe_enable       => rrx_pipe_enable,
         rrdwidth_rx           => rrdwidth_rx,
         rclkcmpinsertpad      => rclkcmpinsertpad,
         rind_error_reporting  => rind_error_reporting,
         
         -- PLD - PIPE Interface
         -- RX PIPE Interface: Command/Status
         rxpolarity            => rxpolarity,
         
         rxvalid               => rxvalid_xhdl7,
         rxelecidle            => rxelecidle_xhdl5,
         rxstatus              => rxstatus_xhdl6,
         
         -- RX PIPE Interface: Data
         rxd_ch                => rxd_ch_xhdl4,
         
         -- Commands
         polinv_rx             => polinv_rx,
         
         -- PIPE - PCS Inteface
         -- RX PIPE Interface
         rxd                   => rxd,
         polinv_rx_int         => polinv_rx_int_xhdl1,
         
         -- TX PIPE Interface
         -- Latched Power State Signals
         latched_p1            => latched_p1,
         
         txdetectrx            => tmp_txdetectrxin,		--shawn (txdetectrx),
         
         -- PIPE - PMA Interface
         -- TX PIPE Interface
         rx_found              => rx_found,
         rx_found_sync         => rx_found_int,
         rx_detect_valid       => rx_detect_valid,
         rx_detect_valid_sync  => rx_detect_valid_int,
         
         sigdetni              => sigdetni,  -- ww25_2008
         
         -- RX PIPE Interface
         rxelectricalidle      => rxelectricalidle
      );
   
   
   
   phystatus_generator_inst : stratixiv_hssi_phystatus_generator
      PORT MAP (
         
         -- General signals
         clk                              => pipe_rx_clk,
         reset_n                          => rx_pipe_reset_n,
         
         --CRAM
         phystat_ena                      => phystat_ena,
         rphystatus_rst_toggle            => rphystatus_rst_toggle,
         rphystatus_delay                 => rphystatus_delay,
         
         -- PLD Interface
         powerdown                        => powerdown,
         phystatus                        => phystatus_xhdl0,
         
         -- Latched Power State Signals
         latched_p0                       => latched_p0,
         latched_p0s                      => latched_p0s,
         latched_p1                       => latched_p1,
         latched_p2                       => latched_p2,
         
         rindv_rx                         => rindv_rx,
         rmaster_rx                       => rmaster_rx,
         rmaster_up_rx                    => rmaster_up_rx,
         
         -- Auto Negotiation Module
         speed_change                     => speed_change,
         speed_change_centrl              => speed_change_centrl,
         speed_change_quad_up             => speed_change_quad_up,
         speed_change_quad_down           => speed_change_quad_down,
         
         -- TX PMA Interface
         rx_detect_valid                  => rx_detect_valid_int,
         
         -- RX PMA Interface
         power_state_transition_done      => power_state_transition_done,
         power_state_transition_done_ena  => power_state_transition_done_ena
      );
   
   --********************************************************************************
   -- MAIN CODE 
   --********************************************************************************
   
   PROCESS (pipe_rx_clk, rx_pipe_reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rx_pipe_reset_n)) = '1') THEN
         rx_detect_valid_reg_0 <=  TRANSPORT '0' AFTER 1* 1 ps;
         rx_found_reg_0 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (pipe_rx_clk'EVENT AND pipe_rx_clk = '1') THEN
         rx_detect_valid_reg_0 <=  TRANSPORT rx_detect_valid AFTER 1* 1 ps;
         rx_found_reg_0 <=  TRANSPORT rx_found AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (pipe_rx_clk, rx_pipe_reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rx_pipe_reset_n)) = '1') THEN
         rx_detect_valid_reg_1 <=  TRANSPORT '0' AFTER 1* 1 ps;
         rx_found_reg_1 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (pipe_rx_clk'EVENT AND pipe_rx_clk = '1') THEN
         rx_detect_valid_reg_1 <=  TRANSPORT rx_detect_valid_reg_0 AFTER 1* 1 ps;
         rx_found_reg_1 <=  TRANSPORT rx_found_reg_0 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (pipe_rx_clk, rx_pipe_reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rx_pipe_reset_n)) = '1') THEN
         txdetectrx_reg_0 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (pipe_rx_clk'EVENT AND pipe_rx_clk = '1') THEN
         txdetectrx_reg_0 <=  TRANSPORT tmp_txdetectrxin AFTER 1* 1 ps;		-- txdetectrx; shawn
      END IF;
   END PROCESS;
   
   PROCESS (pipe_rx_clk, rx_pipe_reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rx_pipe_reset_n)) = '1') THEN
         txdetectrx_reg_1 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (pipe_rx_clk'EVENT AND pipe_rx_clk = '1') THEN
         txdetectrx_reg_1 <=  TRANSPORT txdetectrx_reg_0 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (pipe_rx_clk, rx_pipe_reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rx_pipe_reset_n)) = '1') THEN
         txdetectrx_reg_2 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (pipe_rx_clk'EVENT AND pipe_rx_clk = '1') THEN
         txdetectrx_reg_2 <=  TRANSPORT txdetectrx_reg_1 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (pipe_rx_clk, rx_pipe_reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rx_pipe_reset_n)) = '1') THEN
         txdetectrx_reg_3 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (pipe_rx_clk'EVENT AND pipe_rx_clk = '1') THEN
         txdetectrx_reg_3 <=  TRANSPORT txdetectrx_reg_2 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (pipe_rx_clk, rx_pipe_reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rx_pipe_reset_n)) = '1') THEN
         txdetectrx_reg_4 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (pipe_rx_clk'EVENT AND pipe_rx_clk = '1') THEN
         txdetectrx_reg_4 <=  TRANSPORT txdetectrx_reg_3 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (pipe_rx_clk, rx_pipe_reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rx_pipe_reset_n)) = '1') THEN
         txdetectrx_reg_5 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (pipe_rx_clk'EVENT AND pipe_rx_clk = '1') THEN
         txdetectrx_reg_5 <=  TRANSPORT txdetectrx_reg_4 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (pipe_rx_clk, rx_pipe_reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rx_pipe_reset_n)) = '1') THEN
         txdetectrx_reg_6 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (pipe_rx_clk'EVENT AND pipe_rx_clk = '1') THEN
         txdetectrx_reg_6 <=  TRANSPORT txdetectrx_reg_5 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (pipe_rx_clk, rx_pipe_reset_n)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rx_pipe_reset_n)) = '1') THEN
         bypass_rx_found <=  TRANSPORT '0' AFTER 1* 1 ps;
         bypass_rx_detect_valid <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (pipe_rx_clk'EVENT AND pipe_rx_clk = '1') THEN
         bypass_rx_found <=  TRANSPORT txdetectrx_reg_6 AFTER 1* 1 ps;
         bypass_rx_detect_valid <=  TRANSPORT txdetectrx_reg_6 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
END trans;



-- pipe_interface_top

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_tx_digis_txclk_gating IS
    PORT (
        
        select_n   : IN STD_LOGIC;
        clk1       : IN STD_LOGIC;
        clk2       : IN STD_LOGIC;
        clk1out_n  : OUT STD_LOGIC;
        clk2out_n  : OUT STD_LOGIC
    );
END stratixiv_hssi_tx_digis_txclk_gating;

ARCHITECTURE trans OF stratixiv_hssi_tx_digis_txclk_gating IS
BEGIN
    
    clk1out_n <= NOT((select_n OR clk1));
    clk2out_n <= NOT((NOT(select_n) OR clk2));
    
END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_tx_digi_txclk_ctl IS
   PORT (
      
      -- Clock Inputs
      pld_tx_clk              : IN STD_LOGIC;		-- PLD clock from PLD clock trees, the transmit clock from XGMII.
      refclk_pma              : IN STD_LOGIC;		-- Quad based clk from TXPLL
      txpma_local_clk         : IN STD_LOGIC;		-- Local channel TX PMA clock.
      
      -- Control Inputs
      txrst                   : IN STD_LOGIC;		-- reset for the tx_pcs
      scan_mode               : IN STD_LOGIC;		-- Scan mode enable signal for selecting scan_clk from refclk_pma
      
      -- New Control Inputs
      gen2ngen1               : IN STD_LOGIC;		-- from PMA for PCIexp Gen1/Gen2 datawidth scaling
      gen2ngen1_bundle        : IN STD_LOGIC;		-- from PMA for PCIexp Gen1/Gen2 datawidth scaling in x4 and x8
      tx_div2_sync_centrl     : IN STD_LOGIC;		-- divided clock from the central channel (x2, x4 mode)
      tx_div2_sync_quad_up    : IN STD_LOGIC;		-- divided clock from quad above (> x4 mode)
      tx_div2_sync_quad_down  : IN STD_LOGIC;		-- divided clock from quad below (> x4 mode)
      
      -- MDIO Inputs
      rindv_tx                : IN STD_LOGIC;		-- Selects between indiv chan. mode and bundled mode
      rtxwrclksel             : IN STD_LOGIC;		-- Selects which clock writes into FIFO
      rtxrdclksel             : IN STD_LOGIC;		-- Selects which clock reads from FIFO and also clocks reest of TX logic
      rdwidth_tx              : IN STD_LOGIC;		-- divide by 1 or 2 before feeding to FIFO read clock
      rfreerun_tx             : IN STD_LOGIC;		-- Select whether divider is permamently enabled (free -running) or  divider should be enabled / reset by TX PCS reset  
      
      -- New MDIO Inputs
      rauto_speed_ena         : IN STD_LOGIC;		-- auto speed negotiation enable
      rfreq_sel               : IN STD_LOGIC;		-- freq scaling or data width scaling
      rtxpcsclkpwdn           : IN STD_LOGIC;		-- TX clocking power down enable
      rmaster_tx              : IN STD_LOGIC;		-- New bundle mode MDIO, selects master quad
      rmaster_up_tx           : IN STD_LOGIC;		-- New bundle mode MDIO, selects master quad
      rself_sw_en_tx          : IN STD_LOGIC;		-- enables self-switch to have correct /2 clock in all quads in bundle mode
      
      -- Removed Inputs
      -- input        tx_div2_sync_in_ch0;    // from the channel zero tx_div2_sync_out
      -- input        tx_div2_sync_in_q0_ch0; // From channel0 of Master Quad
      -- input        rphfifo_master_sel_tx;  // TX Phase comp. FIFO tx_div2_sync selection CRAM
      
      -- Clock Outputs wtih CTS
      refclk_b                : OUT STD_LOGIC;		-- Drives the tx channel clock
      wr_clk_pos              : OUT STD_LOGIC;		-- Drives tx phase comp fifo write side
      fifo_rd_clk             : OUT STD_LOGIC;		-- Drives tx phase comp fifo read side
      
      -- Clock Outputs to PLD, w/o CTS
      tx_clk_out              : OUT STD_LOGIC;		-- Drives to the PLD clock tree -- unconnected
      
      -- New Clock Outputs with CTS
      refclk_b_raw            : OUT STD_LOGIC;		-- same as refclk_b, but with no clock gating
      wr_clk_pos_raw          : OUT STD_LOGIC;		-- same as wr_clk_pos, but with no clock gating
      fifo_rd_clk_raw         : OUT STD_LOGIC;		-- same as fifo_rd_clk, but with no clock gating
      
      -- Control Outputs
      tx_div2_sync_out        : OUT STD_LOGIC		-- Synchronizes the divided by two clock
   );
END stratixiv_hssi_tx_digi_txclk_ctl;

ARCHITECTURE trans OF stratixiv_hssi_tx_digi_txclk_ctl IS
   COMPONENT stratixiv_hssi_tx_digis_txclk_gating
        PORT (
            select_n                : IN STD_LOGIC;
            clk1                    : IN STD_LOGIC;
            clk2                    : IN STD_LOGIC;
            clk1out_n               : OUT STD_LOGIC;
            clk2out_n               : OUT STD_LOGIC
        );
    END COMPONENT;
   
   
   SIGNAL fifo_rd_clk_by2        : STD_LOGIC := '0';
   SIGNAL gen2ngen1_local_sync   : STD_LOGIC;
   SIGNAL counter                : STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   SIGNAL tx_rst_n               : STD_LOGIC;
   SIGNAL tx_div2_sync           : STD_LOGIC;
   SIGNAL dynamic_div2ndiv1      : STD_LOGIC;
   SIGNAL gen2ngen1_local        : STD_LOGIC;
   SIGNAL tx_div2_this_quad      : STD_LOGIC;
   SIGNAL tx_div2_this_channel   : STD_LOGIC;
   SIGNAL tx_div2_other_quad     : STD_LOGIC;
   SIGNAL force_master           : STD_LOGIC;
   SIGNAL rtxpcsclkpwdn_nscan    : STD_LOGIC;
   
    SIGNAL select_div1_n          : STD_LOGIC;
    SIGNAL clk1out_n              : STD_LOGIC;
    SIGNAL clk2out_n              : STD_LOGIC;
    
   -- Declare intermediate signals for referenced outputs
   SIGNAL fifo_rd_clk_xhdl0      : STD_LOGIC;
   SIGNAL refclk_b_raw_xhdl2     : STD_LOGIC;
   SIGNAL wr_clk_pos_raw_xhdl4   : STD_LOGIC;
   SIGNAL fifo_rd_clk_raw_xhdl1  : STD_LOGIC;
   SIGNAL tx_div2_sync_out_xhdl3 : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   fifo_rd_clk <= fifo_rd_clk_xhdl0;
   refclk_b_raw <= refclk_b_raw_xhdl2;
   wr_clk_pos_raw <= wr_clk_pos_raw_xhdl4;
   fifo_rd_clk_raw <= fifo_rd_clk_raw_xhdl1;
   tx_div2_sync_out <= tx_div2_sync_out_xhdl3;
   

   -- Old bundle logic:   
   -- Select between the local synchronization signal or the global synchronization signal (either from Channel0 or 
   -- Channel0 of Master Quad
   --assign tx_div2_sync = rindv_tx ? tx_div2_sync_out : tx_div2_sync_in;
   -- assign 	tx_div2_sync = (rphfifo_master_sel_tx == 1'b0) ? tx_div2_sync_in_q0_ch0 :
   --                            (rindv_tx == 1'b0) ? tx_div2_sync_in_ch0 : 
   --                            (rauto_speed_ena & ~rfreq_sel) ? (tx_div2_sync_out | ~gen2ngen1_local_sync) : tx_div2_sync_out;
   
   PROCESS (txrst, refclk_b_raw_xhdl2)
VARIABLE  txt : LINE;
   BEGIN
      IF (txrst = '1') THEN
         counter <=  TRANSPORT "00" AFTER 1* 1 ps;
      ELSIF (refclk_b_raw_xhdl2'EVENT AND refclk_b_raw_xhdl2 = '1') THEN
         IF (((rauto_speed_ena AND NOT(rfreq_sel) AND rself_sw_en_tx) AND NOT(force_master)) = '1') THEN
            counter <=  TRANSPORT counter + "01" AFTER 1* 1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   force_master <= '1' WHEN ((counter = "11") AND ((rauto_speed_ena AND NOT(rfreq_sel) AND rself_sw_en_tx) = '1')) ELSE
                   '0';
   
   tx_div2_sync <= tx_div2_this_quad WHEN ((rmaster_tx OR force_master) = '1') ELSE
                   tx_div2_other_quad;
   tx_div2_this_quad <= tx_div2_this_channel WHEN ((rindv_tx OR force_master) = '1') ELSE
                        tx_div2_sync_centrl;
   tx_div2_this_channel <= (tx_div2_sync_out_xhdl3 OR NOT(gen2ngen1_local_sync)) WHEN ((rauto_speed_ena AND NOT(rfreq_sel)) = '1') ELSE
                           tx_div2_sync_out_xhdl3;
   tx_div2_other_quad <= tx_div2_sync_quad_up WHEN (rmaster_up_tx = '1') ELSE
                         tx_div2_sync_quad_down;
   
   gen2ngen1_local <= gen2ngen1_bundle WHEN (rindv_tx = '0') ELSE
                      gen2ngen1;
   
   PROCESS (txrst, refclk_b_raw_xhdl2)
VARIABLE  txt : LINE;
   BEGIN
      IF (txrst = '1') THEN
         gen2ngen1_local_sync <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (refclk_b_raw_xhdl2'EVENT AND refclk_b_raw_xhdl2 = '1') THEN
         gen2ngen1_local_sync <=  TRANSPORT gen2ngen1_local AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   dynamic_div2ndiv1 <= rdwidth_tx OR (gen2ngen1_local_sync AND rauto_speed_ena AND NOT(rfreq_sel));
   
   -- Reset for Divide-by-2 FF
   tx_rst_n <= '1' WHEN (rfreerun_tx = '1') ELSE
               NOT(txrst);
   
   rtxpcsclkpwdn_nscan <= rtxpcsclkpwdn AND NOT(scan_mode);
   
   -- Full speed clock for TX PCS
   refclk_b_raw_xhdl2 <= refclk_pma WHEN ((scan_mode OR rtxrdclksel) = '1') ELSE
                         txpma_local_clk;
   
   refclk_b <= '1' WHEN (rtxpcsclkpwdn_nscan = '1') ELSE
               refclk_b_raw_xhdl2;
   
   -- Divide-by-2 FF
   PROCESS (tx_rst_n, refclk_b_raw_xhdl2)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(tx_rst_n)) = '1') THEN
         fifo_rd_clk_by2 <= '1';
      ELSIF (refclk_b_raw_xhdl2'EVENT AND refclk_b_raw_xhdl2 = '1') THEN
         fifo_rd_clk_by2 <= tx_div2_sync;		-- local divided clock
      END IF;
   END PROCESS;
   
   tx_div2_sync_out_xhdl3 <= NOT(fifo_rd_clk_by2);
   
   -- TX FIFO read clock: could be fast or divided by 2
   -- old code:
   -- assign fifo_rd_clk = ((rdwidth_tx == 1'b0) || scan_mode) ? refclk_b_raw : fifo_rd_clk_by2;
   
   select_div1_n <= NOT((scan_mode OR NOT(dynamic_div2ndiv1)));
   
   stratixiv_hssi_tx_digis_txclk_gating_inst : stratixiv_hssi_tx_digis_txclk_gating
        PORT MAP (
            select_n   => select_div1_n,
            clk1       => refclk_b_raw_xhdl2,
            clk2       => fifo_rd_clk_by2,
            clk1out_n  => clk1out_n,
            clk2out_n  => clk2out_n
        );
        
  fifo_rd_clk_raw_xhdl1 <= NOT (clk1out_n OR clk2out_n);

   fifo_rd_clk_xhdl0 <= '1' WHEN (rtxpcsclkpwdn_nscan = '1') ELSE
                        fifo_rd_clk_raw_xhdl1;
   
   -- TX FIFO write clock: used internal clock when in BIST or scan or HIP
   wr_clk_pos_raw_xhdl4 <= fifo_rd_clk_raw_xhdl1 WHEN ((scan_mode OR rtxwrclksel) = '1') ELSE
                           pld_tx_clk;
   wr_clk_pos <= '1' WHEN (rtxpcsclkpwdn_nscan = '1') ELSE
                 wr_clk_pos_raw_xhdl4;
   
   -- TX Clock Out
   tx_clk_out <= fifo_rd_clk_xhdl0;		-- drives PLD clock tree
   
END trans;




-- txclk_ctl


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_tx_digis_ram8x49_syn IS
   GENERIC (
      
      read_access_time   : INTEGER := 0;
      write_access_time  : INTEGER := 0;
      ram_width          : INTEGER := 54
   );
   PORT (
      data_in            : IN STD_LOGIC_VECTOR(53 DOWNTO 0);
      clk                : IN STD_LOGIC;
      fifo_wr            : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
      rst_l              : IN STD_LOGIC;
      fifo_re            : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
      data_out           : OUT STD_LOGIC_VECTOR(53 DOWNTO 0)
   );
END stratixiv_hssi_tx_digis_ram8x49_syn;

ARCHITECTURE trans OF stratixiv_hssi_tx_digis_ram8x49_syn IS
   
   SIGNAL data_out_i    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_0 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_1 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_2 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_3 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_4 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_5 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_6 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_7 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_0 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_1 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_2 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_3 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_4 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_5 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_6 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_7 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   
   SIGNAL data_reg_0    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_1    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_2    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_3    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_4    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_5    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_6    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_7    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   
   SIGNAL we            : STD_LOGIC;
   SIGNAL re_l          : STD_LOGIC;
BEGIN
   
   we <= '1';
   re_l <= '0';
   
   data_reg_0 <= data_in WHEN (fifo_wr(0) = '1') ELSE
                 ram_array_q_0;
   data_reg_1 <= data_in WHEN (fifo_wr(1) = '1') ELSE
                 ram_array_q_1;
   data_reg_2 <= data_in WHEN (fifo_wr(2) = '1') ELSE
                 ram_array_q_2;
   data_reg_3 <= data_in WHEN (fifo_wr(3) = '1') ELSE
                 ram_array_q_3;
   data_reg_4 <= data_in WHEN (fifo_wr(4) = '1') ELSE
                 ram_array_q_4;
   data_reg_5 <= data_in WHEN (fifo_wr(5) = '1') ELSE
                 ram_array_q_5;
   data_reg_6 <= data_in WHEN (fifo_wr(6) = '1') ELSE
                 ram_array_q_6;
   data_reg_7 <= data_in WHEN (fifo_wr(7) = '1') ELSE
                 ram_array_q_7;
   
   data_out <= "100001000000000000000000000000000000000000000000000000" WHEN (re_l = '1') ELSE
               data_out_i;
   
   PROCESS (ram_array_q_0, ram_array_q_1, ram_array_q_2, ram_array_q_3, ram_array_q_4, ram_array_q_5, ram_array_q_6, ram_array_q_7, fifo_re)
VARIABLE  txt : LINE;
   BEGIN
      CASE fifo_re IS		-- synopsys parallel_case full_case
         WHEN "00000001" =>
            data_out_i <= ram_array_q_0;
         WHEN "00000010" =>
            data_out_i <= ram_array_q_1;
         WHEN "00000100" =>
            data_out_i <= ram_array_q_2;
         WHEN "00001000" =>
            data_out_i <= ram_array_q_3;
         WHEN "00010000" =>
            data_out_i <= ram_array_q_4;
         WHEN "00100000" =>
            data_out_i <= ram_array_q_5;
         WHEN "01000000" =>
            data_out_i <= ram_array_q_6;
         WHEN "10000000" =>
            data_out_i <= ram_array_q_7;
         WHEN OTHERS =>
            data_out_i <= ram_array_q_0;
      END CASE;
   END PROCESS;
   
   
   PROCESS (clk, rst_l)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rst_l)) = '1') THEN
         ram_array_q_0 <=  TRANSPORT "100001000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_1 <=  TRANSPORT "100001000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_2 <=  TRANSPORT "100001000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_3 <=  TRANSPORT "100001000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_4 <=  TRANSPORT "100001000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_5 <=  TRANSPORT "100001000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_6 <=  TRANSPORT "100001000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_7 <=  TRANSPORT "100001000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
      ELSIF (clk'EVENT AND clk = '1') THEN
         ram_array_q_0 <=  TRANSPORT ram_array_d_0 AFTER (write_access_time)*1 ps;
         ram_array_q_1 <=  TRANSPORT ram_array_d_1 AFTER (write_access_time)*1 ps;
         ram_array_q_2 <=  TRANSPORT ram_array_d_2 AFTER (write_access_time)*1 ps;
         ram_array_q_3 <=  TRANSPORT ram_array_d_3 AFTER (write_access_time)*1 ps;
         ram_array_q_4 <=  TRANSPORT ram_array_d_4 AFTER (write_access_time)*1 ps;
         ram_array_q_5 <=  TRANSPORT ram_array_d_5 AFTER (write_access_time)*1 ps;
         ram_array_q_6 <=  TRANSPORT ram_array_d_6 AFTER (write_access_time)*1 ps;
         ram_array_q_7 <=  TRANSPORT ram_array_d_7 AFTER (write_access_time)*1 ps;
      END IF;
   END PROCESS;
   
   
   PROCESS (we, data_reg_0, data_reg_1, data_reg_2, data_reg_3, data_reg_4, data_reg_5, data_reg_6, data_reg_7, ram_array_q_0, ram_array_q_1, ram_array_q_2, ram_array_q_3, ram_array_q_4, ram_array_q_5, ram_array_q_6, ram_array_q_7)
VARIABLE  txt : LINE;
   BEGIN
      IF (we = '1') THEN
         ram_array_d_0 <= data_reg_0;
         ram_array_d_1 <= data_reg_1;
         ram_array_d_2 <= data_reg_2;
         ram_array_d_3 <= data_reg_3;
         ram_array_d_4 <= data_reg_4;
         ram_array_d_5 <= data_reg_5;
         ram_array_d_6 <= data_reg_6;
         ram_array_d_7 <= data_reg_7;
      ELSE
         ram_array_d_0 <= ram_array_q_0;
         ram_array_d_1 <= ram_array_q_1;
         ram_array_d_2 <= ram_array_q_2;
         ram_array_d_3 <= ram_array_q_3;
         ram_array_d_4 <= ram_array_q_4;
         ram_array_d_5 <= ram_array_q_5;
         ram_array_d_6 <= ram_array_q_6;
         ram_array_d_7 <= ram_array_q_7;
      END IF;
   END PROCESS;
   
   
END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_tx_digis_ph_fifo IS
   PORT (
      -- inputs
      --en,
      -- outputs
      
      -- =======
      -- inputs
      -- =======
      rst_wclk                 : IN STD_LOGIC;		-- wr clk rst
      rst_rclk                 : IN STD_LOGIC;		-- rd clk rst
      wr_clk                   : IN STD_LOGIC;		-- Write Clock
      rd_clk                   : IN STD_LOGIC;		-- Read Clock
      bypass_en                : IN STD_LOGIC;		-- FIFO bypass enable - only for Altera internal debug
      --input         en;		// Disable FIFO, reset wptr and rptr 
      -- only for Altera internal debug
      lowlatency_en            : IN STD_LOGIC;		-- Enable low latency option 
      we                       : IN STD_LOGIC;		-- PLD dynamic write pointer enable  
      re                       : IN STD_LOGIC;		-- PLD dynamic read pointer enable  
      din                      : IN STD_LOGIC_VECTOR(53 DOWNTO 0);		-- 10-bit code-group bus from deskew module.
      
      rphfifo_regmode_tx       : IN STD_LOGIC;
      rindv_tx                 : IN STD_LOGIC;
      rauto_speed_ena          : IN STD_LOGIC;
      reset_pc_ptrs            : IN STD_LOGIC;
      reset_pc_ptrs_centrl     : IN STD_LOGIC;
      reset_pc_ptrs_quad_up    : IN STD_LOGIC;
      reset_pc_ptrs_quad_down  : IN STD_LOGIC;
      rmaster_tx               : IN STD_LOGIC;
      rmaster_up_tx            : IN STD_LOGIC;
      
      -- =======
      -- outputs
      -- =======
      -- Indicates overflow (rd_clk)
      -- FIFO empty (rd_clk)
      data_out                 : OUT STD_LOGIC_VECTOR(53 DOWNTO 0);		-- output data (rd_clk synchronous if not FIFO bypass)
      ph_fifo_full             : OUT STD_LOGIC;
      ph_fifo_empty            : OUT STD_LOGIC;
      wptr_bin                 : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);		-- wptr test bus
      rptr_bin                 : OUT STD_LOGIC_VECTOR(2 DOWNTO 0)		-- rptr test bus
   );
END stratixiv_hssi_tx_digis_ph_fifo;

ARCHITECTURE trans OF stratixiv_hssi_tx_digis_ph_fifo IS
   COMPONENT stratixiv_hssi_tx_digis_ram8x49_syn
      GENERIC (
         read_access_time         : INTEGER := 0;
         write_access_time        : INTEGER := 0;
         ram_width                : INTEGER := 54
      );
      PORT (
         data_in                  : IN STD_LOGIC_VECTOR(53 DOWNTO 0);
         clk                      : IN STD_LOGIC;
         fifo_wr                  : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         rst_l                    : IN STD_LOGIC;
         fifo_re                  : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         data_out                 : OUT STD_LOGIC_VECTOR(53 DOWNTO 0)
      );
   END COMPONENT;
   
   
   -- ===================
   -- signal declaration
   -- ===================
   SIGNAL wptr                   : STD_LOGIC_VECTOR(7 DOWNTO 0) := "00000000" ;
   SIGNAL rptr                   : STD_LOGIC_VECTOR(7 DOWNTO 0) := "00000000" ;
   SIGNAL wptr0_pre              : STD_LOGIC_VECTOR(7 DOWNTO 0) := "00000000" ;
   SIGNAL wptr0                  : STD_LOGIC_VECTOR(7 DOWNTO 0) := "00000000" ;
   SIGNAL wptr1                  : STD_LOGIC_VECTOR(7 DOWNTO 0) := "00000000" ;
   SIGNAL rptr_gray              : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000" ;
   SIGNAL rptr_gray0             : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rptr0                  : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000" ;
   SIGNAL rptr1                  : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000" ;
   SIGNAL rptr1_onehot           : STD_LOGIC_VECTOR(7 DOWNTO 0);
   -- wptr test bus
   -- rptr test bus
   SIGNAL first_rd               : STD_LOGIC;		-- first read after reset
   SIGNAL ram_data_out           : STD_LOGIC_VECTOR(53 DOWNTO 0);
   SIGNAL ram_data_out_pre       : STD_LOGIC_VECTOR(53 DOWNTO 0);
   
   SIGNAL ph_fifo_full_pre       : STD_LOGIC;
   
   -- Invert rst for new FIFO     
   SIGNAL rst_n                  : STD_LOGIC;
   
   SIGNAL fifo_cnt               : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL fifo_cnt_pre           : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL wptr1_bin              : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rptr1_bin_wclk         : STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   SIGNAL reset_ptrs_local       : STD_LOGIC;
   
   SIGNAL reset_ptrs_local_sync1 : STD_LOGIC;
   SIGNAL reset_ptrs_local_sync2 : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL ph_fifo_empty_xhdl0    : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   ph_fifo_empty <= ph_fifo_empty_xhdl0;
   
   -- =============
   -- functionality
   -- =============
   rst_n <= NOT(rst_wclk);
   
   data_out(53 DOWNTO 0) <= din WHEN (bypass_en = '1') ELSE
                            ram_data_out;
   
   reset_ptrs_local <= rauto_speed_ena AND reset_pc_ptrs WHEN (rindv_tx = '1') ELSE
                       reset_pc_ptrs_centrl WHEN (rmaster_tx = '1') ELSE
                       reset_pc_ptrs_quad_up WHEN (rmaster_up_tx = '1') ELSE
                       reset_pc_ptrs_quad_down;
   
   --newly added fifo_cnt and fifo_cnt_pre logic for full/empty flag use
   -- manually translated
   PROCESS(fifo_cnt_pre, rst_wclk, rptr1_bin_wclk, wptr1_bin)
   BEGIN
       IF (rptr1_bin_wclk = wptr1_bin) THEN
           IF (rst_wclk /= '1') THEN
               IF (fifo_cnt_pre = "0111" OR fifo_cnt_pre = "0110" OR fifo_cnt_pre = "1000") THEN
                   fifo_cnt <= "1000";
               ELSE
                   fifo_cnt <= "0000";
               END IF;    
           ELSE
               fifo_cnt <= "0000";
           END IF;
       ELSE
           IF (wptr1_bin > rptr1_bin_wclk) THEN
               fifo_cnt <= ('0' & (wptr1_bin - rptr1_bin_wclk));
           ELSE
               fifo_cnt <= ("1000" - ('0' & (rptr1_bin_wclk - wptr1_bin)));
           END IF;     
       END IF;
   END PROCESS;
   
   --newly added fifo_cnt and fifo_cnt_pre logic for full/empty flag use 
   -- incorrect translation - replaced above section
   --fifo_cnt <= "1000" WHEN (fifo_cnt_pre = "0111" OR fifo_cnt_pre = "0110" OR fifo_cnt_pre = "1000") ELSE
   --            "0000" WHEN (rst_wclk /= '1') ELSE
   --            "0000" WHEN (wptr1_bin = rptr1_bin_wclk) ELSE
   --            ('0' & (wptr1_bin - rptr1_bin_wclk)) WHEN (wptr1_bin > rptr1_bin_wclk) ELSE
   --            ("1000" - ('0' & (rptr1_bin_wclk - wptr1_bin)));
   
   PROCESS (rst_wclk, wr_clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (rst_wclk = '1') THEN
         reset_ptrs_local_sync1 <=  TRANSPORT '0' AFTER 1 ps;
         reset_ptrs_local_sync2 <=  TRANSPORT '0' AFTER 1 ps;
      ELSIF (wr_clk'EVENT AND wr_clk = '1') THEN
         IF (rphfifo_regmode_tx = '1') THEN
            reset_ptrs_local_sync1 <=  TRANSPORT '0' AFTER 1 ps;
            reset_ptrs_local_sync2 <=  TRANSPORT '0' AFTER 1 ps;
         ELSE
            reset_ptrs_local_sync1 <=  TRANSPORT reset_ptrs_local AFTER 1 ps;
            reset_ptrs_local_sync2 <=  TRANSPORT reset_ptrs_local_sync1 AFTER 1 ps;
         END IF;
      END IF;
   END PROCESS; -- always @ (posedge rst_wclk or posedge wr_clk)

    --ECO for S4GX to fix metastability issue
    -- replace the 1st FF with new flop w/o reset
    -- replace the 2nd FF with an enhanced flop
    PROCESS (wr_clk)
    BEGIN
        IF (wr_clk'EVENT AND wr_clk = '1') THEN
            IF (reset_ptrs_local_sync2 = '1' OR rphfifo_regmode_tx = '1') THEN
                rptr0 <=  TRANSPORT "000" AFTER 1 ps;
            ELSE
                rptr0 <=  TRANSPORT rptr_gray(2 DOWNTO 0) AFTER 1 ps;
            END IF;
        END IF;
    END PROCESS; -- always @ (posedge rst_wclk or posedge wr_clk)
      
    PROCESS(rst_wclk, wr_clk)
    BEGIN
      IF (rst_wclk = '1') THEN
         rptr1 <=  TRANSPORT "000" AFTER 1 ps;
      ELSIF (wr_clk'EVENT AND wr_clk = '1') THEN
         IF ((reset_ptrs_local_sync2 OR rphfifo_regmode_tx) = '1') THEN
            rptr1 <=  TRANSPORT "000" AFTER 1 ps;
         ELSE
            rptr1 <=  TRANSPORT rptr0 AFTER 1 ps;
         END IF;
      END IF;
     END PROCESS;  -- always @ (posedge rst_wclk or posedge wr_clk)
      
   PROCESS (rst_wclk, wr_clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (rst_wclk = '1') THEN
         wptr <=  TRANSPORT "00000001" AFTER 1 ps;
         wptr0_pre <=  TRANSPORT "00000001" AFTER 1 ps;
         wptr0 <=  TRANSPORT "00000001" AFTER 1 ps;
         wptr1 <=  TRANSPORT "00000001" AFTER 1 ps;
         --rptr0 <=  TRANSPORT "000" AFTER 1 ps;
         --rptr1 <=  TRANSPORT "000" AFTER 1 ps;
         ph_fifo_full_pre <=  TRANSPORT '0' AFTER 1 ps;
         ph_fifo_full <=  TRANSPORT '0' AFTER 1 ps;
         ph_fifo_empty_xhdl0 <=  TRANSPORT '0' AFTER 1 ps;		-- fifo_cnt previous value
         fifo_cnt_pre <=  TRANSPORT "0000" AFTER 1 ps;		-- if (rst_wclk == 1'b1)
      ELSIF (wr_clk'EVENT AND wr_clk = '1') THEN
         IF ((reset_ptrs_local_sync2 OR rphfifo_regmode_tx) = '1') THEN
            wptr <=  TRANSPORT "00000001" AFTER 1 ps;
            wptr0_pre <=  TRANSPORT "00000001" AFTER 1 ps;
            wptr0 <=  TRANSPORT "00000001" AFTER 1 ps;
            wptr1 <=  TRANSPORT "00000001" AFTER 1 ps;
            --rptr0 <=  TRANSPORT "000" AFTER 1 ps;
            --rptr1 <=  TRANSPORT "000" AFTER 1 ps;
            ph_fifo_full_pre <=  TRANSPORT '0' AFTER 1 ps;
            ph_fifo_full <=  TRANSPORT '0' AFTER 1 ps;
            ph_fifo_empty_xhdl0 <=  TRANSPORT '0' AFTER 1 ps;		-- fifo_cnt previous value
            fifo_cnt_pre <=  TRANSPORT "0000" AFTER 1 ps;		-- if (reset_ptrs_local_sync2)
         ELSE
            
            fifo_cnt_pre <=  TRANSPORT fifo_cnt AFTER 1 ps;
            ph_fifo_full <=  TRANSPORT ph_fifo_full_pre AFTER 1 ps;
            wptr0_pre <=  TRANSPORT wptr AFTER 1 ps;
            wptr0 <=  TRANSPORT wptr0_pre AFTER 1 ps;
            wptr1 <=  TRANSPORT wptr0 AFTER 1 ps;
            
            --rptr0 <=  TRANSPORT rptr_gray(2 DOWNTO 0) AFTER 1 ps;
            --rptr1 <=  TRANSPORT rptr0 AFTER 1 ps;
            
            -- wptr operation
            IF (we = '1') THEN
               
               -- full condition
               --$if ({wptr1[6:0],wptr1[7]} == rptr1_onehot)
               --new full flag requirement
               wptr <=  TRANSPORT (wptr(6 DOWNTO 0) & wptr(7)) AFTER 1 ps;
            END IF;
            IF ((fifo_cnt = "1000") AND ((NOT(ph_fifo_empty_xhdl0))) = '1') THEN
               --else if (ph_fifo_full_pre == 1'b1 & (wptr1 != rptr1_onehot)) //now become sticky flag until reset
               --ph_fifo_full_pre <= #1 1'b0;
               
               -- empty condition
               --$if ({rptr1_onehot[6:0],rptr1_onehot[7]} == wptr1)
               --new empty flag requirement
               ph_fifo_full_pre <=  TRANSPORT '1' AFTER 1 ps;		--==1 to cover if wptr not moving
            END IF;
            IF ((((wptr1(6 DOWNTO 0)) & (wptr1(7))) = rptr1_onehot) AND (fifo_cnt_pre = "0001" OR fifo_cnt_pre = "0000") AND ((NOT(ph_fifo_full_pre))) = '1') THEN
               --else if (ph_fifo_empty == 1'b1 & ({wptr1[6:0],wptr1[7]} != rptr1_onehot)) //now become sticky flag until reset
               --ph_fifo_empty <= #1 1'b0;
               ph_fifo_empty_xhdl0 <=  TRANSPORT '1' AFTER 1 ps;
            END IF;
         END IF;
      END IF;
   END PROCESS; -- always @ (posedge rst_wclk or posedge wr_clk)
   -- end of eco
   
   PROCESS (rst_rclk, rd_clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (rst_rclk = '1') THEN
         first_rd <=  TRANSPORT '1' AFTER 1 ps;
         rptr <=  TRANSPORT "00100000" AFTER 1 ps;
      ELSIF (rd_clk'EVENT AND rd_clk = '1') THEN
         IF ((reset_ptrs_local OR rphfifo_regmode_tx) = '1') THEN
            first_rd <=  TRANSPORT '1' AFTER 1 ps;
            rptr <=  TRANSPORT "00100000" AFTER 1 ps;
         ELSE
            
            IF (first_rd = '1' AND re = '1') THEN
               
               -- read pointer operation
               first_rd <=  TRANSPORT '0' AFTER 1 ps;
            END IF;
            IF (re = '1') THEN
               -- low latency option, advance 2 on the first read 
               IF (first_rd = '1' AND lowlatency_en = '1') THEN
                  rptr <=  TRANSPORT (rptr(5 DOWNTO 0) & rptr(7 DOWNTO 6)) AFTER 1 ps;
               ELSE
                  rptr <=  TRANSPORT (rptr(6 DOWNTO 0) & rptr(7)) AFTER 1 ps;
               END IF;
            END IF;
         END IF;
      END IF;
   END PROCESS;
   
   -- always @ (posedge rst_rclk or posedge rd_clk)
   
   -- Instantiate FIFO CORE Module. Fifo 8 words deep, 44 bits wide
   
   
   
   ram8x49_syn_1 : stratixiv_hssi_tx_digis_ram8x49_syn
      PORT MAP (
         rst_l     => rst_n,
         clk       => wr_clk,
         fifo_wr   => wptr,
         data_in   => din,
         fifo_re   => rptr,
         data_out  => ram_data_out_pre
      );
   
   PROCESS (rst_rclk, rd_clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (rst_rclk = '1') THEN
         ram_data_out <=  TRANSPORT "100000000000000000000000000000000000000000000000000000" AFTER 1 ps;
      ELSIF (rd_clk'EVENT AND rd_clk = '1') THEN
         IF (rphfifo_regmode_tx = '1') THEN
            ram_data_out <=  TRANSPORT din AFTER 1 ps;
         ELSE
            ram_data_out <=  TRANSPORT ram_data_out_pre AFTER 1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   -- always @ (posedge rst_rclk or posedge rd_clk)
   
   PROCESS (wptr)
VARIABLE  txt : LINE;
   BEGIN
      CASE wptr IS
         WHEN "00000001" =>
            wptr_bin <= "000";
         WHEN "00000010" =>
            wptr_bin <= "001";
         WHEN "00000100" =>
            wptr_bin <= "010";
         WHEN "00001000" =>
            wptr_bin <= "011";
         WHEN "00010000" =>
            wptr_bin <= "100";
         WHEN "00100000" =>
            wptr_bin <= "101";
         WHEN "01000000" =>
            wptr_bin <= "110";
         WHEN "10000000" =>
            wptr_bin <= "111";
         WHEN OTHERS =>		-- case(wptr)
            wptr_bin <= "111";
      END CASE;
   END PROCESS;
   
   -- always@ (wptr)
   
   PROCESS (wptr1)
VARIABLE  txt : LINE;
   BEGIN
      CASE wptr1 IS
         WHEN "00000001" =>
            wptr1_bin <= "000";
         WHEN "00000010" =>
            wptr1_bin <= "001";
         WHEN "00000100" =>
            wptr1_bin <= "010";
         WHEN "00001000" =>
            wptr1_bin <= "011";
         WHEN "00010000" =>
            wptr1_bin <= "100";
         WHEN "00100000" =>
            wptr1_bin <= "101";
         WHEN "01000000" =>
            wptr1_bin <= "110";
         WHEN "10000000" =>
            wptr1_bin <= "111";
         WHEN OTHERS =>		-- case(wptr1)
            wptr1_bin <= "111";
      END CASE;
   END PROCESS;
   
   -- always@ (wptr1)
   
   PROCESS (rptr)
VARIABLE  txt : LINE;
   BEGIN
      CASE rptr IS
         WHEN "00000001" =>
            rptr_bin <= "000";
         WHEN "00000010" =>
            rptr_bin <= "001";
         WHEN "00000100" =>
            rptr_bin <= "010";
         WHEN "00001000" =>
            rptr_bin <= "011";
         WHEN "00010000" =>
            rptr_bin <= "100";
         WHEN "00100000" =>
            rptr_bin <= "101";
         WHEN "01000000" =>
            rptr_bin <= "110";
         WHEN "10000000" =>
            rptr_bin <= "111";
         WHEN OTHERS =>		-- case(rptr)
            rptr_bin <= "111";
      END CASE;
   END PROCESS;
   
   -- always@ (rptr)
   
   PROCESS (rst_rclk, rd_clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (rst_rclk = '1') THEN
         rptr_gray <=  TRANSPORT "000" AFTER 1 ps;
      ELSIF (rd_clk'EVENT AND rd_clk = '1') THEN
         rptr_gray <=  TRANSPORT rptr_gray0 AFTER 1 ps;
      END IF;
   END PROCESS;
   
   
   PROCESS (rptr)
VARIABLE  txt : LINE;
   BEGIN
      CASE rptr IS
         WHEN "00000001" =>
            rptr_gray0 <= "000";
         WHEN "00000010" =>
            rptr_gray0 <= "001";
         WHEN "00000100" =>
            rptr_gray0 <= "011";
         WHEN "00001000" =>
            rptr_gray0 <= "010";
         WHEN "00010000" =>
            rptr_gray0 <= "110";
         WHEN "00100000" =>
            rptr_gray0 <= "111";
         WHEN "01000000" =>
            rptr_gray0 <= "101";
         WHEN "10000000" =>
            rptr_gray0 <= "100";
         WHEN OTHERS =>		-- case(rptr)
            rptr_gray0 <= "000";
      END CASE;
   END PROCESS;
   
   -- always@ (rptr)
   
   PROCESS (rptr1)
VARIABLE  txt : LINE;
   BEGIN
      CASE rptr1 IS
         WHEN "000" =>
            rptr1_onehot <= "00000001";
         WHEN "001" =>
            rptr1_onehot <= "00000010";
         WHEN "011" =>
            rptr1_onehot <= "00000100";
         WHEN "010" =>
            rptr1_onehot <= "00001000";
         WHEN "110" =>
            rptr1_onehot <= "00010000";
         WHEN "111" =>
            rptr1_onehot <= "00100000";
         WHEN "101" =>
            rptr1_onehot <= "01000000";
         WHEN "100" =>
            rptr1_onehot <= "10000000";
         WHEN OTHERS =>		-- case(rptr1)
            rptr1_onehot <= "00000001";
      END CASE;
   END PROCESS;
   
   -- always@ (rptr1)
   
   PROCESS (rptr1)
VARIABLE  txt : LINE;
   BEGIN
      CASE rptr1 IS
         WHEN "000" =>
            rptr1_bin_wclk <= "000";
         WHEN "001" =>
            rptr1_bin_wclk <= "001";
         WHEN "011" =>
            rptr1_bin_wclk <= "010";
         WHEN "010" =>
            rptr1_bin_wclk <= "011";
         WHEN "110" =>
            rptr1_bin_wclk <= "100";
         WHEN "111" =>
            rptr1_bin_wclk <= "101";
         WHEN "101" =>
            rptr1_bin_wclk <= "110";
         WHEN "100" =>
            rptr1_bin_wclk <= "111";
         WHEN OTHERS =>		-- case(rptr1)
            rptr1_bin_wclk <= "000";
      END CASE;
   END PROCESS;
   
   
END trans;


-- always@ (rptr1)


-- ph_fifo_tx

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_tx_digi_tx_ctrl IS
   PORT (
      -- inputs
      --is_lane0,
      -- PCS bypass
      
      -- TX PIPE signals
      
      -- RX PIPE signals
      
      -- New inputs for new bundling scheme and new PCIE features like autospeed
      
      -- New MDIO for new bundling scheme and new PCIE features like autospeed
      
      -- outputs
      
      -- TX PIPE signals
      
      -- RX PIPE signals
      
      -- test bus
      -- fifo_select_out	// test_bus[8], bit re-used in test bus
      -- test_bus[7]
      -- test_bus[6:4]
      -- test_bus[3]
      -- test_bus[2:0]
      -- *_xgmii = from XGMII interface
      -- *_sg    = from selftest_gen
      -- *_rc    = from rx_ctrl
      
      -- ======
      -- inputs
      -- ======
      soft_reset                : IN STD_LOGIC;		-- Reset
      fifo_wr_clk               : IN STD_LOGIC;		-- Used to be wr_clk_pos
      fifo_rd_clk               : IN STD_LOGIC;		-- Coming from txclk_xg_ctl 
      refclk_b_in               : IN STD_LOGIC;		-- The local reference clock used by the internal
      -- transmit logic. Used to be tx_clk.
      scan_mode                 : IN STD_LOGIC;		-- scan enable
      -- Control bit/pin to enable parallel loop back at XGMII
      -- To select XGMII signals from selftest_gen (*_sg)
      -- Control bit to support double-width data bus on xgmii.
      -- When set, fifo_wr_clk is running at half frequency
      -- as refclk_b_in and 2-byte/code-group of data should be sampled
      -- at the rising edge of fifo_wr_clk. When DWIDTH=1'b0, the
      -- fifo_wr_clk is running at the same frequency as refclk_b_in.
      rindv_tx                  : IN STD_LOGIC;
      p_rlpbk                   : IN STD_LOGIC;
      selftest_en               : IN STD_LOGIC;
      rdwidth_tx                : IN STD_LOGIC;
      --input		is_lane0; 	// lane 0 of the quad
      -- rx data from rx_ctrl.
      txfifo_dis                : IN STD_LOGIC;
      
      -- Tx data 
      -- These extension bits may be used to force disparity or other uses.
      -- Extend txd by 2 bits. Used to force disparity.
      -- The xgmii data from selftest_gen..
      -- The xgmii control from selftest_gen.
      -- redundant Tx data , unused
      -- redundant Tx data select, unused
      -- Acting with {txd_extend, TXD[9]	forces current disparity to 1 or 0
      
      rtxfifo_urst_en           : IN STD_LOGIC;		-- user reset CRAM enable
      txfifo_urst               : IN STD_LOGIC;		-- user reset 
      rtxfifo_lowlatency_en     : IN STD_LOGIC;		-- low latency enable
      rtxphfifopldctl_en        : IN STD_LOGIC;		-- CRAM to enable PLD controlled write/read enable
      rtx_pipe_enable           : IN STD_LOGIC;		-- enable pipe
      pld_we                    : IN STD_LOGIC;		-- PLD phase comp. fifo we, level active
      pld_rd_dis                : IN STD_LOGIC;		-- PLD phase comp. fifo rd dis, edge active
      txd                       : IN STD_LOGIC_VECTOR(39 DOWNTO 0);
      txd_extend                : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      rforce_disp               : IN STD_LOGIC;
      tx_data_sg                : IN STD_LOGIC_VECTOR(31 DOWNTO 0);
      tx_control_sg             : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      rxd_lpbk                  : IN STD_LOGIC_VECTOR(39 DOWNTO 0);
      redund_ctl                : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      txd_redun                 : IN STD_LOGIC_VECTOR(39 DOWNTO 0);
      rforce_kchar              : IN STD_LOGIC;
      rforce_echar              : IN STD_LOGIC;
      -- PCS Bypass mode
      rtxpcsbypass_en           : IN STD_LOGIC;
      
      -- TX PIPE interface signals
      txdetectrxloopback        : IN STD_LOGIC;
      --input			txelecidle; 	txd[9]
      --input			txcompliance;	txd[10] and txd[32]
      powerdown                 : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      
      revloopback               : IN STD_LOGIC;
      
      txswing                   : IN STD_LOGIC;
      txdeemph                  : IN STD_LOGIC;
      txmargin                  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      -- RX PIPE interface signals
      rxpolarity                : IN STD_LOGIC;
      polinv_rx                 : IN STD_LOGIC;
      eidleinfersel             : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      -- New Inputs for new bundling scheme and new PCIE features like autospeed
      reset_pc_ptrs             : IN STD_LOGIC;
      reset_pc_ptrs_centrl      : IN STD_LOGIC;
      reset_pc_ptrs_quad_up     : IN STD_LOGIC;
      reset_pc_ptrs_quad_down   : IN STD_LOGIC;
      gen2ngen1                 : IN STD_LOGIC;
      gen2ngen1_bundle          : IN STD_LOGIC;
      dis_pc_byte               : IN STD_LOGIC;
      wr_enable_centrl          : IN STD_LOGIC;
      wr_enable_quad_up         : IN STD_LOGIC;
      wr_enable_quad_down       : IN STD_LOGIC;
      rd_enable_centrl          : IN STD_LOGIC;
      rd_enable_quad_up         : IN STD_LOGIC;
      rd_enable_quad_down       : IN STD_LOGIC;
      fifo_select_in_centrl     : IN STD_LOGIC;
      fifo_select_in_quad_up    : IN STD_LOGIC;
      fifo_select_in_quad_down  : IN STD_LOGIC;
      
      -- New MDIO for new bundling scheme and new PCIE features like autospeed
      rauto_speed_ena           : IN STD_LOGIC;
      rfreq_sel                 : IN STD_LOGIC;
      rphfifo_regmode_tx        : IN STD_LOGIC;
      rmaster_tx                : IN STD_LOGIC;
      rmaster_up_tx             : IN STD_LOGIC;
      
      -- =======
      -- outputs
      -- =======
      txd_extend_tc             : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);		-- This will go to the encoder. This is serialized (muxed) txd_extend_int. But 
      -- txd_extend_int has to go through the FIFOs first to be serialized. 
      -- ch0 wr_enable1 output for X4/X8 mode
      -- ch0 rd_enable1 output for X4/X8 mode
      tx_data_tc                : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);		-- 8-bit data passed onto the internal transmit logic.
      tx_ctl_tc                 : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Control passed onto the internal transmit logic.
      -- Can be bit 8 of the 10-bit code group.
      tx_data_9_tc              : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Bit 9 of the 10-bit code group passed onto the internal transmit logic.
      rd_enable_sync            : OUT STD_LOGIC;
      k_det                     : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      d21_5_eq_n                : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      d2_2_eq_n                 : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      wr_enable_out             : OUT STD_LOGIC;
      rd_enable_out             : OUT STD_LOGIC;
      fifo_select_out           : OUT STD_LOGIC;		-- New output for Rev.B 
      ph_fifo_full              : OUT STD_LOGIC;		-- fifo full flag
      ph_fifo_empty             : OUT STD_LOGIC;		-- fifo empty flag
      soft_reset_wclk1          : OUT STD_LOGIC;		-- synchronized reset for BIST;
      soft_reset_rclk1          : OUT STD_LOGIC;		-- syncrhonized reset for PIPE
      pipe_electric_idle        : OUT STD_LOGIC;		-- PIPE electric idle bit
      
      -- TX PIPE interface signals
      txdetectrxloopback_int    : OUT STD_LOGIC;
      --output			txelecidle; 	txd[9]
      --output			txcompliance;	txd[10] and txd[32]
      powerdown_int             : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      
      revloopback_int           : OUT STD_LOGIC;
      
      phfifo_txswing            : OUT STD_LOGIC;
      phfifo_txdeemph           : OUT STD_LOGIC;
      phfifo_txmargin           : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      -- RX PIPE interface signals
      rxpolarity_int            : OUT STD_LOGIC;
      polinv_rx_int             : OUT STD_LOGIC;
      gray_eidleinfersel        : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      -- test bus
      -- testbus[8]   = fifo_select_out
      -- testbus[7]   = wr_enable2
      -- testbus[6:4] = wptr_bin
      -- testbus[3]   = rd_enable2
      -- testbus[2:0] = rptr_bin
      wr_enable2                : OUT STD_LOGIC;
      wptr_bin                  : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      rd_enable2                : OUT STD_LOGIC;
      rptr_bin                  : OUT STD_LOGIC_VECTOR(2 DOWNTO 0)
   );
END stratixiv_hssi_tx_digi_tx_ctrl;

ARCHITECTURE trans OF stratixiv_hssi_tx_digi_tx_ctrl IS
   COMPONENT stratixiv_hssi_tx_digis_ph_fifo
      PORT (
         rst_wclk                  : IN STD_LOGIC;
         rst_rclk                  : IN STD_LOGIC;
         wr_clk                    : IN STD_LOGIC;
         rd_clk                    : IN STD_LOGIC;
         bypass_en                 : IN STD_LOGIC;
         lowlatency_en             : IN STD_LOGIC;
         we                        : IN STD_LOGIC;
         re                        : IN STD_LOGIC;
         din                       : IN STD_LOGIC_VECTOR(53 DOWNTO 0);
         rphfifo_regmode_tx        : IN STD_LOGIC;
         rindv_tx                  : IN STD_LOGIC;
         rauto_speed_ena           : IN STD_LOGIC;
         reset_pc_ptrs             : IN STD_LOGIC;
         reset_pc_ptrs_centrl      : IN STD_LOGIC;
         reset_pc_ptrs_quad_up     : IN STD_LOGIC;
         reset_pc_ptrs_quad_down   : IN STD_LOGIC;
         rmaster_tx                : IN STD_LOGIC;
         rmaster_up_tx             : IN STD_LOGIC;
         data_out                  : OUT STD_LOGIC_VECTOR(53 DOWNTO 0);
         ph_fifo_full              : OUT STD_LOGIC;
         ph_fifo_empty             : OUT STD_LOGIC;
         wptr_bin                  : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         rptr_bin                  : OUT STD_LOGIC_VECTOR(2 DOWNTO 0)
      );
   END COMPONENT;
   
   
   -- ================
   -- internal signals
   -- ================
   
   -- Begin: 22 Bits output of this module (44 to 22 / 22 to 22)
   SIGNAL tx_data_tc_mux             : STD_LOGIC_VECTOR(15 DOWNTO 0);		--temp holder for non PCS bypass data branch before mux
   SIGNAL tx_ctl_tc_mux              : STD_LOGIC_VECTOR(1 DOWNTO 0);		--temp holder for non PCS bypass branch before mux
   SIGNAL tx_data_9_tc_mux           : STD_LOGIC_VECTOR(1 DOWNTO 0);		--temp holder for non PCS bypass branch before mux
   SIGNAL txd_extend_tc_mux          : STD_LOGIC_VECTOR(1 DOWNTO 0);		--temp holder for non PCS bypass branch before mux
   -- End:   22 bits output of this module
   
   SIGNAL tx_data_lt                 : STD_LOGIC_VECTOR(19 DOWNTO 0);
   
   SIGNAL tx_data                    : STD_LOGIC_VECTOR(39 DOWNTO 0);
   SIGNAL din0                       : STD_LOGIC_VECTOR(53 DOWNTO 0);
   SIGNAL fifo_data_out              : STD_LOGIC_VECTOR(39 DOWNTO 0);
   SIGNAL tx_data_9_tc_d             : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL tx_data_9_tc_d_others      : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL tx_ctl_tc_d                : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL tx_ctl_tc_d_others         : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL tx_data_tc_d               : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL tx_data_tc_d_others        : STD_LOGIC_VECTOR(17 DOWNTO 0);
   SIGNAL d21_5_eq_n_d               : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL d2_2_eq_n_d                : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL k_det_sync1                : STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   SIGNAL txfifo_en_refclk0          : STD_LOGIC;
   SIGNAL txfifo_en_refclk1          : STD_LOGIC;
   
   SIGNAL wr_enable0                 : STD_LOGIC;
   SIGNAL wr_enable0p5               : STD_LOGIC;
   SIGNAL wr_enable1                 : STD_LOGIC;
   SIGNAL rd_enable0                 : STD_LOGIC;
   SIGNAL rd_enable0p5               : STD_LOGIC;
   SIGNAL rd_enable1                 : STD_LOGIC;
   
   SIGNAL txd_extend_int             : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL txd_extend_tc_d            : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- This is registered and sent out to the encoder as txd_extend_tc. 
   -- This is serialized (muxed) txd_extend_int. But 
   -- txd_extend_int has to go through the FIFOs first to be serialized. 
   SIGNAL txd_extend_low             : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL txd_extend_high            : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL txd_data_extend_tmp        : STD_LOGIC_VECTOR(17 DOWNTO 0);
   
   SIGNAL txfifo_en_rclk0            : STD_LOGIC;
   SIGNAL txfifo_en_rclk1            : STD_LOGIC;
   SIGNAL txfifo_en                  : STD_LOGIC;
   
   SIGNAL soft_reset_local           : STD_LOGIC;
   SIGNAL soft_reset_wclk0           : STD_LOGIC;
   SIGNAL soft_reset_wclk1_b4scan    : STD_LOGIC;
   SIGNAL soft_reset_wclk1_wire      : STD_LOGIC;
   SIGNAL soft_reset_rclk0           : STD_LOGIC;
   SIGNAL soft_reset_rclk1_b4scan    : STD_LOGIC;
   SIGNAL soft_reset_rclk1_wire      : STD_LOGIC;
   SIGNAL data_out_temp              : STD_LOGIC_VECTOR(53 DOWNTO 0);
   
   SIGNAL pld_rd_dis0                : STD_LOGIC;
   SIGNAL pld_rd_dis1                : STD_LOGIC;
   SIGNAL pld_rd_dis2                : STD_LOGIC;
   SIGNAL pld_rd_dis_edge            : STD_LOGIC;
   
   -- PIPE electric idle bit
   
   -- register rd_enable_sync to fast clock domain. Necessary to send out low 
   -- byte first after soft_reset.
   SIGNAL rd_enable_sync_refclk_b_in : STD_LOGIC;
   
   -- PIPE command signals
   SIGNAL pipe_cmd                   : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL pipe_cmd_out               : STD_LOGIC_VECTOR(4 DOWNTO 0);
   
   SIGNAL rdwidth_or_auto            : STD_LOGIC;
   SIGNAL gen2ngen1_int              : STD_LOGIC;
   SIGNAL gen2ngen1_reg              : STD_LOGIC;
   SIGNAL gen2ngen1_sync              : STD_LOGIC;
   
   SIGNAL pipe_tx_trans              : STD_LOGIC_VECTOR(4 DOWNTO 0);		-- PIPE transmitter settings
   -- {txswing, txdeemph, txmargin}
   SIGNAL pipe_tx_trans_out          : STD_LOGIC_VECTOR(4 DOWNTO 0);
   -- X-HDL generated signals

   SIGNAL xhdl8 : STD_LOGIC;
   SIGNAL xhdl9 : STD_LOGIC;
   SIGNAL xhdl10 : STD_LOGIC;
   SIGNAL xhdl11 : STD_LOGIC;
   SIGNAL xhdl12 : STD_LOGIC;
   SIGNAL xhdl13 : STD_LOGIC;
   SIGNAL xhdl14 : STD_LOGIC;
   SIGNAL xhdl15 : STD_LOGIC;
   SIGNAL xhdl16 : STD_LOGIC;
   SIGNAL xhdl17 : STD_LOGIC;
   SIGNAL xhdl18 : STD_LOGIC;
   SIGNAL xhdl19 : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL xhdl20 : STD_LOGIC;
   SIGNAL xhdl21 : STD_LOGIC;
   SIGNAL xhdl22 : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL rd_enable_sync_xhdl4       : STD_LOGIC;
   SIGNAL fifo_select_out_xhdl0      : STD_LOGIC;
   SIGNAL ph_fifo_full_xhdl2         : STD_LOGIC;
   SIGNAL ph_fifo_empty_xhdl1        : STD_LOGIC;
   SIGNAL wr_enable2_xhdl7           : STD_LOGIC;
   SIGNAL wptr_bin_xhdl6             : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rd_enable2_xhdl3           : STD_LOGIC;
   SIGNAL rptr_bin_xhdl5             : STD_LOGIC_VECTOR(2 DOWNTO 0);
BEGIN
   -- Drive referenced outputs
   rd_enable_sync <= rd_enable_sync_xhdl4;
   fifo_select_out <= fifo_select_out_xhdl0;
   ph_fifo_full <= ph_fifo_full_xhdl2;
   ph_fifo_empty <= ph_fifo_empty_xhdl1;
   wr_enable2 <= wr_enable2_xhdl7;
   wptr_bin <= wptr_bin_xhdl6;
   rd_enable2 <= rd_enable2_xhdl3;
   rptr_bin <= rptr_bin_xhdl5;
   
   -- =============
   -- functionality
   -- =============
   soft_reset_wclk1 <= soft_reset_wclk1_wire;
   soft_reset_rclk1 <= soft_reset_rclk1_wire;
   txd_extend_int <= txd_extend WHEN (rforce_disp = '1') ELSE
                     "0000";
   
   -- GiGE Idle Detection, replaced in 8b10b encoder
   d21_5_eq_n_d(0) <= int2bit(((tx_ctl_tc_d(0) & tx_data_tc_d(7 DOWNTO 0)) /= "010110101"));
   d21_5_eq_n_d(1) <= int2bit(((tx_ctl_tc_d(1) & tx_data_tc_d(15 DOWNTO 8)) /= "010110101"));
   d2_2_eq_n_d(0) <= int2bit(((tx_ctl_tc_d(0) & tx_data_tc_d(7 DOWNTO 0)) /= "001000010"));
   d2_2_eq_n_d(1) <= int2bit(((tx_ctl_tc_d(1) & tx_data_tc_d(15 DOWNTO 8)) /= "001000010"));
   
   wr_enable_out <= wr_enable1;
   rd_enable_out <= rd_enable1;
   
   -- 2-17-04 BT: Tied the tx_data[9] to 1'b0 in selftest mode since it effects the 
   --             disparity input in the 8B/10B encoder
   tx_data(19 DOWNTO 0) <= rxd_lpbk(19 DOWNTO 0) WHEN (p_rlpbk = '1') ELSE
                           ('0' & tx_control_sg(1) & tx_data_sg(15 DOWNTO 8) & '0' & tx_control_sg(0) & tx_data_sg(7 DOWNTO 0)) WHEN (selftest_en = '1') ELSE
                           txd_redun(19 DOWNTO 0) WHEN (redund_ctl /= "0000") ELSE
                           txd(19 DOWNTO 0);
   
   -- enable 3G double-width BIST by mapping tx_data_sg[15:8] & tx_control_sg[1] to the 3rd symbol location
   tx_data(39 DOWNTO 20) <= rxd_lpbk(39 DOWNTO 20) WHEN (p_rlpbk = '1') ELSE
                            ('0' & tx_control_sg(3) & tx_data_sg(31 DOWNTO 24) & '0' & tx_control_sg(1) & tx_data_sg(15 DOWNTO 8)) WHEN (selftest_en = '1') ELSE
                            txd_redun(39 DOWNTO 20) WHEN (redund_ctl /= "0000") ELSE
                            txd(39 DOWNTO 20);
   
   txfifo_en <= NOT(txfifo_urst) WHEN (rtxfifo_urst_en = '1') ELSE
                '1';
   
   -- PIPE electric idle is on txd[10]
   --assign pipe_electric_idle = txd_extend_tc_d[0];
   
   soft_reset_local <= soft_reset OR (rtxfifo_urst_en AND txfifo_urst);
   
   -- PIPE cmd
   pipe_cmd <= (powerdown & txdetectrxloopback & revloopback & '0');
   
   revloopback_int <= pipe_cmd(1) WHEN (txfifo_dis = '1') ELSE
                      pipe_cmd_out(1);
   txdetectrxloopback_int <= pipe_cmd(2) WHEN (txfifo_dis = '1') ELSE
                             pipe_cmd_out(2);
   powerdown_int <= pipe_cmd(4 DOWNTO 3) WHEN (txfifo_dis = '1') ELSE
                    pipe_cmd_out(4 DOWNTO 3);
   
   rxpolarity_int <= rxpolarity;
   polinv_rx_int <= polinv_rx;
   
   gen2ngen1_int <= gen2ngen1 WHEN (rindv_tx = '1') ELSE
                    gen2ngen1_bundle;
   --//************************************
   --// Synchronization of gen2ngen1
   --//************************************
   PROCESS (soft_reset, refclk_b_in)
   BEGIN
	IF (soft_reset = '1') THEN
	     gen2ngen1_reg  <= '0';
	     gen2ngen1_sync <= '0';
	ELSIF (refclk_b_in'EVENT AND refclk_b_in = '1') THEN
	     gen2ngen1_reg <= gen2ngen1_int;
	     gen2ngen1_sync <= gen2ngen1_reg;
	END IF;
   END PROCESS; -- always @ (posedge soft_reset or posedge refclk_b_in)
                          
   rdwidth_or_auto <= (rdwidth_tx OR (rauto_speed_ena AND NOT(rfreq_sel) AND gen2ngen1_sync));
   
   pipe_tx_trans <= (txswing & txdeemph & txmargin);
   
   phfifo_txswing <= pipe_tx_trans(4) WHEN (txfifo_dis = '1') ELSE
                     pipe_tx_trans_out(4);
   phfifo_txdeemph <= pipe_tx_trans(3) WHEN (txfifo_dis = '1') ELSE
                      pipe_tx_trans_out(3);
   phfifo_txmargin <= pipe_tx_trans(2 DOWNTO 0) WHEN (txfifo_dis = '1') ELSE
                      pipe_tx_trans_out(2 DOWNTO 0);
   
   -- synchronize reset input (in refclk_b domain)
   PROCESS (soft_reset_local, fifo_wr_clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (soft_reset_local = '1') THEN
         soft_reset_wclk0 <=  TRANSPORT '1' AFTER 1 ps;
         soft_reset_wclk1_b4scan <=  TRANSPORT '1' AFTER 1 ps;
      ELSIF (fifo_wr_clk'EVENT AND fifo_wr_clk = '1') THEN
         soft_reset_wclk0 <=  TRANSPORT '0' AFTER 1 ps;
         soft_reset_wclk1_b4scan <=  TRANSPORT soft_reset_wclk0 AFTER 1 ps;
      END IF;
   END PROCESS;
   
   -- always @ (posedge soft_reset_local or posedge fifo_wr_clk)
   
   soft_reset_wclk1_wire <= '0' WHEN (scan_mode = '1') ELSE
                            soft_reset_wclk1_b4scan;
   
   -- synchronize reset input (in refclk_b domain) and balance it with fifo_wr_clk reset
   PROCESS (soft_reset_local, fifo_rd_clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (soft_reset_local = '1') THEN
         soft_reset_rclk0 <=  TRANSPORT '1' AFTER 1 ps;
         soft_reset_rclk1_b4scan <=  TRANSPORT '1' AFTER 1 ps;
      ELSIF (fifo_rd_clk'EVENT AND fifo_rd_clk = '1') THEN
         soft_reset_rclk0 <=  TRANSPORT '0' AFTER 1 ps;
         soft_reset_rclk1_b4scan <=  TRANSPORT soft_reset_rclk0 AFTER 1 ps;
      END IF;
   END PROCESS;
   
   -- always @ (posedge soft_reset_local or posedge fifo_rd_clk)
   
   soft_reset_rclk1_wire <= '0' WHEN (scan_mode = '1') ELSE
                            soft_reset_rclk1_b4scan;
   
   -- write enable
   --wr_enable0   <= txfifo_en;
   --wr_enable0   <= 1'b1;
   xhdl8 <= (wr_enable0p5 AND pld_we) WHEN (rtxphfifopldctl_en = '1') ELSE
                            wr_enable0p5;
   xhdl9 <= wr_enable1 WHEN (rindv_tx = '1') ELSE
                            wr_enable_centrl;
   xhdl10 <= wr_enable_quad_up WHEN (rmaster_up_tx = '1') ELSE
                            wr_enable_quad_down;
   xhdl11 <= (xhdl9) WHEN (rmaster_tx = '1') ELSE
                            (xhdl10);
   PROCESS (soft_reset_wclk1_wire, fifo_wr_clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (soft_reset_wclk1_wire = '1') THEN
         wr_enable0 <=  TRANSPORT '0' AFTER 1 ps;
         wr_enable0p5 <=  TRANSPORT '0' AFTER 1 ps;
         wr_enable1 <=  TRANSPORT '0' AFTER 1 ps;
         wr_enable2_xhdl7 <=  TRANSPORT '0' AFTER 1 ps;
      ELSIF (fifo_wr_clk'EVENT AND fifo_wr_clk = '1') THEN
         wr_enable0 <=  TRANSPORT NOT((rauto_speed_ena AND dis_pc_byte)) AFTER 1 ps;
         wr_enable0p5 <=  TRANSPORT wr_enable0 AFTER 1 ps;
         wr_enable1 <=  TRANSPORT xhdl8 AFTER 1 ps;
         wr_enable2_xhdl7 <=  TRANSPORT xhdl11 AFTER 1 ps;
      END IF;
   END PROCESS;
   
   -- always @ (posedge soft_reset_wclk1 or posedge fifo_wr_clk)
   
   din0 <= (pipe_tx_trans & pipe_cmd & txd_extend_int(3 DOWNTO 2) & tx_data(39 DOWNTO 20) & txd_extend_int(1 DOWNTO 0) & tx_data(19 DOWNTO 0));
   
   -- Instantiate new FIFO
   
   
   ph_fifo_tx_1 : stratixiv_hssi_tx_digis_ph_fifo
      PORT MAP (
         rst_wclk                 => soft_reset_wclk1_wire,
         rst_rclk                 => soft_reset_rclk1_wire,
         wr_clk                   => fifo_wr_clk,
         rd_clk                   => fifo_rd_clk,
         bypass_en                => txfifo_dis,
         --.en(1'b1),
         lowlatency_en            => rtxfifo_lowlatency_en,
         we                       => wr_enable2_xhdl7,
         re                       => rd_enable2_xhdl3,
         din                      => din0,
         data_out                 => data_out_temp,
         ph_fifo_full             => ph_fifo_full_xhdl2,
         ph_fifo_empty            => ph_fifo_empty_xhdl1,
         wptr_bin                 => wptr_bin_xhdl6,
         rptr_bin                 => rptr_bin_xhdl5,
         rphfifo_regmode_tx       => rphfifo_regmode_tx,
         rindv_tx                 => rindv_tx,
         rmaster_tx               => rmaster_tx,
         rmaster_up_tx            => rmaster_up_tx,
         rauto_speed_ena          => rauto_speed_ena,
         reset_pc_ptrs            => reset_pc_ptrs,
         reset_pc_ptrs_centrl     => reset_pc_ptrs_centrl,
         reset_pc_ptrs_quad_up    => reset_pc_ptrs_quad_up,
         reset_pc_ptrs_quad_down  => reset_pc_ptrs_quad_down
      );
   pipe_tx_trans_out <= data_out_temp(53 DOWNTO 49);
   pipe_cmd_out <= data_out_temp(48 DOWNTO 44);
   txd_extend_high <= data_out_temp(43 DOWNTO 42);
   fifo_data_out(39 DOWNTO 20) <= data_out_temp(41 DOWNTO 22);
   txd_extend_low <= data_out_temp(21 DOWNTO 20);
   fifo_data_out(19 DOWNTO 0) <= data_out_temp(19 DOWNTO 0);
   
   -- Modified Byte Serializer logic to use fifo_select_out to ping-pong between 
   -- low and high banks of FIFO during normal mode
   -- Toggle between {19,9} and {39,29} when DWIDTH is set, else fixed to {19,9}
   tx_data_9_tc_d <= (fifo_data_out(19) & fifo_data_out(9)) WHEN ((NOT(txfifo_dis) AND rd_enable_sync_xhdl4 AND (NOT(rdwidth_or_auto) OR fifo_select_out_xhdl0) AND NOT(rforce_kchar) AND NOT(rforce_echar)) = '1') ELSE
                     (fifo_data_out(39) & fifo_data_out(29)) WHEN ((NOT(txfifo_dis) AND rd_enable_sync_xhdl4 AND (rdwidth_or_auto AND NOT(fifo_select_out_xhdl0)) AND NOT(rforce_kchar) AND NOT(rforce_echar)) = '1') ELSE
                     (tx_data(19) & tx_data(9)) WHEN ((txfifo_dis AND (NOT(rdwidth_or_auto) OR NOT(fifo_select_out_xhdl0)) AND NOT(rforce_kchar) AND NOT(rforce_echar)) = '1') ELSE
                     tx_data_9_tc_d_others;
   
   tx_data_9_tc_d_others <= "00" WHEN ((NOT(rforce_kchar) AND rforce_echar) = '1') ELSE
                            (tx_data_lt(19) & tx_data_lt(9)) WHEN ((txfifo_dis AND rdwidth_or_auto AND fifo_select_out_xhdl0 AND NOT(rforce_kchar) AND NOT(rforce_echar)) = '1') ELSE
                            "00";
   
   -- 8th bit in each word. Toggle between {18,8} and {38,28} when DWIDTH is set, else fixed to {18,8}
   tx_ctl_tc_d <= (fifo_data_out(18) & fifo_data_out(8)) WHEN ((NOT(txfifo_dis) AND rd_enable_sync_xhdl4 AND (NOT(rdwidth_or_auto) OR fifo_select_out_xhdl0) AND NOT(rforce_kchar) AND NOT(rforce_echar)) = '1') ELSE
                  (fifo_data_out(38) & fifo_data_out(28)) WHEN ((NOT(txfifo_dis) AND rd_enable_sync_xhdl4 AND (rdwidth_or_auto AND NOT(fifo_select_out_xhdl0)) AND NOT(rforce_kchar) AND NOT(rforce_echar)) = '1') ELSE
                  (tx_data(18) & tx_data(8)) WHEN ((txfifo_dis AND (NOT(rdwidth_or_auto) OR NOT(fifo_select_out_xhdl0)) AND NOT(rforce_kchar) AND NOT(rforce_echar)) = '1') ELSE
                  tx_ctl_tc_d_others;
   
   -- When transmitting Error(FE) or bypassing FIFO, transmit 11 in the former case and transmit bypassed data/ctl in the latter
   tx_ctl_tc_d_others <= "11" WHEN ((NOT(rforce_kchar) AND rforce_echar) = '1') ELSE
                         (tx_data_lt(18) & tx_data_lt(8)) WHEN ((txfifo_dis AND rdwidth_or_auto AND fifo_select_out_xhdl0 AND NOT(rforce_kchar) AND NOT(rforce_echar)) = '1') ELSE
                         "11";
   
   -- After rd_enable_sync goes high, start transmitting. Initially, fifo_select_out is zero, so MSByte transmitted first.
   -- Transmit data if not forced Error or K-char.
   txd_extend_tc_d <= txd_data_extend_tmp(17 DOWNTO 16);
   tx_data_tc_d <= txd_data_extend_tmp(15 DOWNTO 0);
   txd_data_extend_tmp <= (txd_extend_low & fifo_data_out(17 DOWNTO 10) & fifo_data_out(7 DOWNTO 0)) WHEN ((NOT(txfifo_dis) AND rd_enable_sync_xhdl4 AND (NOT(rdwidth_or_auto) OR fifo_select_out_xhdl0) AND NOT(rforce_kchar) AND NOT(rforce_echar)) = '1') ELSE
                          (txd_extend_high & fifo_data_out(37 DOWNTO 30) & fifo_data_out(27 DOWNTO 20)) WHEN ((NOT(txfifo_dis) AND rd_enable_sync_xhdl4 AND (rdwidth_or_auto AND NOT(fifo_select_out_xhdl0)) AND NOT(rforce_kchar) AND NOT(rforce_echar)) = '1') ELSE
                          (txd_extend_int(1 DOWNTO 0) & tx_data(17 DOWNTO 10) & tx_data(7 DOWNTO 0)) WHEN ((txfifo_dis AND (NOT(rdwidth_or_auto) OR NOT(fifo_select_out_xhdl0)) AND NOT(rforce_kchar) AND NOT(rforce_echar)) = '1') ELSE
                          tx_data_tc_d_others;
   
   -- When transmitting Error(FE) or bypassing FIFO, transmit FE in the former case and transmit bypassed data/ctl in the latter
   tx_data_tc_d_others <= ("00" & "11111110" & "11111110") WHEN ((NOT(rforce_kchar) AND rforce_echar) = '1') ELSE
                          (txd_extend_int(3 DOWNTO 2) & tx_data_lt(17 DOWNTO 10) & tx_data_lt(7 DOWNTO 0)) WHEN ((txfifo_dis AND rdwidth_or_auto AND fifo_select_out_xhdl0 AND NOT(rforce_kchar) AND NOT(rforce_echar)) = '1') ELSE
                          ("00" & "00000111" & "00000111") WHEN ((NOT(rindv_tx)) = '1') ELSE
                          ("00" & "10111100" & "10111100");
   
   -- read enable & 
   -- read enable sync (for byte serializer output enable)
   
   --rd_enable0   <= txfifo_en;
   -- rd_enable0   <= 1'b1;
   xhdl12 <= (rd_enable0p5 AND NOT(pld_rd_dis_edge)) WHEN (rtxphfifopldctl_en = '1') ELSE
                          rd_enable0p5;
   xhdl13 <= rd_enable1 WHEN (rindv_tx = '1') ELSE
                          rd_enable_centrl;
   xhdl14 <= rd_enable_quad_up WHEN (rmaster_up_tx = '1') ELSE
                          rd_enable_quad_down;
   xhdl15 <= (xhdl13) WHEN (rmaster_tx = '1') ELSE
                          (xhdl14);
   
   --txfifo_en_rclk0 <= txfifo_en;
   
   -- start with valid data, so rd_enable_sync serves as dout valid
   -- ideally should be "rptr_bin == 3'd7", 
   -- but fifo_data_out is registered (1 clk delay). rd_enable_sync is
   -- used in high/low byte selection enable
   xhdl16 <= rd_enable1 WHEN (rindv_tx = '1') ELSE
                          rd_enable_centrl;
   xhdl17 <= rd_enable_quad_up WHEN (rmaster_up_tx = '1') ELSE
                          rd_enable_quad_down;
   xhdl18 <= (xhdl16) WHEN (rmaster_tx = '1') ELSE
                          (xhdl17);
   PROCESS (soft_reset_rclk1_wire, fifo_rd_clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (soft_reset_rclk1_wire = '1') THEN
         pld_rd_dis0 <=  TRANSPORT '0' AFTER 1 ps;
         pld_rd_dis1 <=  TRANSPORT '0' AFTER 1 ps;
         pld_rd_dis2 <=  TRANSPORT '0' AFTER 1 ps;
         pld_rd_dis_edge <=  TRANSPORT '0' AFTER 1 ps;
         rd_enable0 <=  TRANSPORT '0' AFTER 1 ps;
         rd_enable0p5 <=  TRANSPORT '0' AFTER 1 ps;
         rd_enable1 <=  TRANSPORT '0' AFTER 1 ps;
         rd_enable2_xhdl3 <=  TRANSPORT '0' AFTER 1 ps;
         txfifo_en_rclk0 <=  TRANSPORT '0' AFTER 1 ps;
         txfifo_en_rclk1 <=  TRANSPORT '0' AFTER 1 ps;
         rd_enable_sync_xhdl4 <=  TRANSPORT '0' AFTER 1 ps;
      ELSIF (fifo_rd_clk'EVENT AND fifo_rd_clk = '1') THEN
         pld_rd_dis0 <=  TRANSPORT pld_rd_dis AFTER 1 ps;
         pld_rd_dis1 <=  TRANSPORT pld_rd_dis0 AFTER 1 ps;
         pld_rd_dis2 <=  TRANSPORT pld_rd_dis1 AFTER 1 ps;
         pld_rd_dis_edge <=  TRANSPORT int2bit((pld_rd_dis2 /= pld_rd_dis1)) AFTER 1 ps;
         rd_enable0 <=  TRANSPORT NOT((rauto_speed_ena AND dis_pc_byte)) AFTER 1 ps;
         rd_enable0p5 <=  TRANSPORT rd_enable0 AFTER 1 ps;
         rd_enable1 <=  TRANSPORT xhdl12 AFTER 1 ps;
         rd_enable2_xhdl3 <=  TRANSPORT xhdl15 AFTER 1 ps;
         txfifo_en_rclk0 <=  TRANSPORT '1' AFTER 1 ps;
         txfifo_en_rclk1 <=  TRANSPORT txfifo_en_rclk0 AFTER 1 ps;
         IF (rphfifo_regmode_tx = '1') THEN
            rd_enable_sync_xhdl4 <=  TRANSPORT '1' AFTER 1 ps;
         ELSIF (rd_enable_sync_xhdl4 = '0' AND rptr_bin_xhdl5 = "000") THEN
            rd_enable_sync_xhdl4 <=  TRANSPORT xhdl18 AFTER 1 ps;
         ELSIF (txfifo_en_rclk1 = '0') THEN
            rd_enable_sync_xhdl4 <=  TRANSPORT '0' AFTER 1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   -- always @ (posedge soft_reset_rclk1 or posedge fifo_rd_clk)
   
   
   -- PIPE enabled, txd[21] & txd[10] are used as PIPE electric idle
   -- hence in PIPE mode, txd[21] & txd[10](crd_enforce_value) are forced to txd[20] & txd[9] 
   -- (crd_enforce_enable) to have crd negative enable.
   -- crd positive enable is not provided in PIPE mode
   xhdl19 <= (txd_extend_tc_d(1) & tx_data_9_tc_d(0)) WHEN (rtx_pipe_enable = '1') ELSE
                           txd_extend_tc_d;
   PROCESS (soft_reset, refclk_b_in)
VARIABLE  txt : LINE;
   BEGIN
      IF (soft_reset = '1') THEN
         tx_data_9_tc_mux <=  TRANSPORT "00" AFTER 1 ps;
         tx_ctl_tc_mux <=  TRANSPORT "00" AFTER 1 ps;
         tx_data_tc_mux <=  TRANSPORT "0000000000000000" AFTER 1 ps;
         txd_extend_tc_mux <=  TRANSPORT "00" AFTER 1 ps;
         tx_data_lt <=  TRANSPORT "00000000000000000000" AFTER 1 ps;
         d21_5_eq_n <=  TRANSPORT "11" AFTER 1 ps;
         d2_2_eq_n <=  TRANSPORT "11" AFTER 1 ps;
         k_det_sync1 <=  TRANSPORT "00" AFTER 1 ps;
         k_det <=  TRANSPORT "00" AFTER 1 ps;
         pipe_electric_idle <=  TRANSPORT '0' AFTER 1 ps;
      ELSIF (refclk_b_in'EVENT AND refclk_b_in = '1') THEN
         tx_data_9_tc_mux <=  TRANSPORT tx_data_9_tc_d AFTER 1 ps;
         tx_ctl_tc_mux <=  TRANSPORT tx_ctl_tc_d AFTER 1 ps;
         tx_data_tc_mux <=  TRANSPORT tx_data_tc_d AFTER 1 ps;
         txd_extend_tc_mux <=  TRANSPORT xhdl19 AFTER 1 ps;
         
         pipe_electric_idle <=  TRANSPORT txd_extend_tc_d(0) AFTER 1 ps;
         d21_5_eq_n <=  TRANSPORT d21_5_eq_n_d AFTER 1 ps;
         d2_2_eq_n <=  TRANSPORT d2_2_eq_n_d AFTER 1 ps;
         
         k_det <=  TRANSPORT k_det_sync1 AFTER 1 ps;
         IF ((rdwidth_or_auto AND NOT(fifo_select_out_xhdl0)) = '1') THEN
            
            tx_data_lt <=  TRANSPORT tx_data(39 DOWNTO 20) AFTER 1 ps;
         END IF;
         IF (((tx_ctl_tc_d(0)) & (tx_data_tc_d(7 DOWNTO 0))) = "110111100") THEN
            k_det_sync1(0) <=  TRANSPORT '1' AFTER 1 ps;
         ELSE
            
            k_det_sync1(0) <=  TRANSPORT '0' AFTER 1 ps;
         END IF;
         IF (((tx_ctl_tc_d(1)) & (tx_data_tc_d(15 DOWNTO 8))) = "110111100") THEN
            k_det_sync1(1) <=  TRANSPORT '1' AFTER 1 ps;
         ELSE
            k_det_sync1(1) <=  TRANSPORT '0' AFTER 1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   -- always @ (posedge soft_reset or posedge refclk_b_in)
   
   -- byte serializer high/low select
   --txfifo_en_refclk0 <= txfifo_en;
   -- txfifo_en_refclk0 <= 1'b1;
   
   -- was ~fifo_select_in, it allows 1 cycle to send the signal across x4, x8 channels
   xhdl20 <= NOT(fifo_select_out_xhdl0) WHEN (rindv_tx = '1') ELSE
                     NOT(fifo_select_in_centrl);
   xhdl21 <= NOT(fifo_select_in_quad_up) WHEN (rmaster_up_tx = '1') ELSE
                     NOT(fifo_select_in_quad_down);
   xhdl22 <= (xhdl20) WHEN (rmaster_tx = '1') ELSE
                     (xhdl21);
   PROCESS (soft_reset, refclk_b_in)
VARIABLE  txt : LINE;
   BEGIN
      IF (soft_reset = '1') THEN
         rd_enable_sync_refclk_b_in <=  TRANSPORT '0' AFTER 1 ps;
         txfifo_en_refclk0 <=  TRANSPORT '0' AFTER 1 ps;
         txfifo_en_refclk1 <=  TRANSPORT '0' AFTER 1 ps;
         fifo_select_out_xhdl0 <=  TRANSPORT '0' AFTER 1 ps;
      ELSIF (refclk_b_in'EVENT AND refclk_b_in = '1') THEN
         txfifo_en_refclk0 <=  TRANSPORT NOT((rauto_speed_ena AND dis_pc_byte)) AFTER 1 ps;
         txfifo_en_refclk1 <=  TRANSPORT txfifo_en_refclk0 AFTER 1 ps;
         IF (txfifo_en_refclk1 = '0') THEN
            rd_enable_sync_refclk_b_in <=  TRANSPORT '0' AFTER 1 ps;
         ELSIF (rd_enable_sync_refclk_b_in = '0') THEN
            rd_enable_sync_refclk_b_in <=  TRANSPORT rd_enable2_xhdl3 AFTER 1 ps;
         END IF;
         IF (rd_enable_sync_refclk_b_in = '1') THEN
            fifo_select_out_xhdl0 <=  TRANSPORT xhdl22 AFTER 1 ps;
         ELSE
            fifo_select_out_xhdl0 <=  TRANSPORT '0' AFTER 1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   -- always @ (posedge soft_reset or posedge refclk_b_in)
   
   tx_data_9_tc <= tx_data_9_tc_d WHEN ((rtxpcsbypass_en AND (NOT(rdwidth_or_auto))) = '1') ELSE
                   tx_data_9_tc_mux;
   tx_ctl_tc <= tx_ctl_tc_d WHEN ((rtxpcsbypass_en AND (NOT(rdwidth_or_auto))) = '1') ELSE
                tx_ctl_tc_mux;
   tx_data_tc <= tx_data_tc_d WHEN ((rtxpcsbypass_en AND (NOT(rdwidth_or_auto))) = '1') ELSE
                 tx_data_tc_mux;
   txd_extend_tc <= txd_extend_tc_d WHEN ((rtxpcsbypass_en AND (NOT(rdwidth_or_auto))) = '1') ELSE
                    txd_extend_tc_mux;
   
   -- LMC bin to gray for eidlinfersel
   
   PROCESS (fifo_wr_clk, soft_reset_wclk1_wire)
VARIABLE  txt : LINE;
   BEGIN
      IF (soft_reset_wclk1_wire = '1') THEN
         gray_eidleinfersel <= "000";
      ELSIF (fifo_wr_clk'EVENT AND fifo_wr_clk = '1') THEN
         CASE eidleinfersel IS
            WHEN "000" =>
               gray_eidleinfersel <= "000";
            WHEN "001" =>
               gray_eidleinfersel <= "001";
            WHEN "010" =>
               gray_eidleinfersel <= "011";
            WHEN "011" =>
               gray_eidleinfersel <= "010";
            WHEN "100" =>
               gray_eidleinfersel <= "110";
            WHEN "101" =>
               gray_eidleinfersel <= "111";
            WHEN "110" =>
               gray_eidleinfersel <= "101";
            WHEN "111" =>
               gray_eidleinfersel <= "100";
            WHEN OTHERS =>
               gray_eidleinfersel <= "000";
         END CASE;
      END IF;
   END PROCESS;
   
   
END trans;



-- tx_ctrl--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 211 mux21 446 oper_add 10 oper_selector 88 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_tx_digi_bist_gen IS 
	 PORT 
	 ( 
		 bist_ctl_sg	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 bist_data_sg	:	OUT  STD_LOGIC_VECTOR (15 DOWNTO 0);
		 rbist_sel	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rbisten_tx	:	IN  STD_LOGIC;
		 rcxpat_chnl_sel	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rdwidth_tx	:	IN  STD_LOGIC;
		 rpma_doublewidth_tx	:	IN  STD_LOGIC;
		 rpmadwidth_tx	:	IN  STD_LOGIC;
		 soft_reset	:	IN  STD_LOGIC;
		 tx_clk	:	IN  STD_LOGIC
	 ); 
 END stratixiv_hssi_tx_digi_bist_gen;

 ARCHITECTURE RTL OF stratixiv_hssi_tx_digi_bist_gen IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 ni001l45	:	STD_LOGIC := '0';
	 SIGNAL	 ni001l46	:	STD_LOGIC := '0';
	 SIGNAL	 nii00O39	:	STD_LOGIC := '0';
	 SIGNAL	 nii00O40	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii00O40_w_lg_w_lg_q228w230w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii00O40_w_lg_q228w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii01O41	:	STD_LOGIC := '0';
	 SIGNAL	 nii01O42	:	STD_LOGIC := '0';
	 SIGNAL	 nii0il37	:	STD_LOGIC := '0';
	 SIGNAL	 nii0il38	:	STD_LOGIC := '0';
	 SIGNAL	 nii0li35	:	STD_LOGIC := '0';
	 SIGNAL	 nii0li36	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii0li36_w_lg_w_lg_q207w208w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii0li36_w_lg_q207w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii0lO33	:	STD_LOGIC := '0';
	 SIGNAL	 nii0lO34	:	STD_LOGIC := '0';
	 SIGNAL	 nii0OO31	:	STD_LOGIC := '0';
	 SIGNAL	 nii0OO32	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii0OO32_w_lg_w_lg_q155w156w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii0OO32_w_lg_q155w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii1OO43	:	STD_LOGIC := '0';
	 SIGNAL	 nii1OO44	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii1OO44_w_lg_w_lg_q295w296w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii1OO44_w_lg_q295w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niii0i23	:	STD_LOGIC := '0';
	 SIGNAL	 niii0i24	:	STD_LOGIC := '0';
	 SIGNAL  wire_niii0i24_w_lg_w_lg_q129w130w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niii0i24_w_lg_q129w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niii0O21	:	STD_LOGIC := '0';
	 SIGNAL	 niii0O22	:	STD_LOGIC := '0';
	 SIGNAL	 niii1i29	:	STD_LOGIC := '0';
	 SIGNAL	 niii1i30	:	STD_LOGIC := '0';
	 SIGNAL  wire_niii1i30_w_lg_w_lg_q152w153w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niii1i30_w_lg_q152w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niii1l27	:	STD_LOGIC := '0';
	 SIGNAL	 niii1l28	:	STD_LOGIC := '0';
	 SIGNAL  wire_niii1l28_w_lg_w_lg_q141w142w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niii1l28_w_lg_q141w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niii1O25	:	STD_LOGIC := '0';
	 SIGNAL	 niii1O26	:	STD_LOGIC := '0';
	 SIGNAL  wire_niii1O26_w_lg_w_lg_q132w133w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niii1O26_w_lg_q132w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niillO19	:	STD_LOGIC := '0';
	 SIGNAL	 niillO20	:	STD_LOGIC := '0';
	 SIGNAL	 niilOi17	:	STD_LOGIC := '0';
	 SIGNAL	 niilOi18	:	STD_LOGIC := '0';
	 SIGNAL	 niilOO15	:	STD_LOGIC := '0';
	 SIGNAL	 niilOO16	:	STD_LOGIC := '0';
	 SIGNAL  wire_niilOO16_w_lg_w_lg_q78w79w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niilOO16_w_lg_q78w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niiO0i10	:	STD_LOGIC := '0';
	 SIGNAL	 niiO0i9	:	STD_LOGIC := '0';
	 SIGNAL	 niiO0O7	:	STD_LOGIC := '0';
	 SIGNAL	 niiO0O8	:	STD_LOGIC := '0';
	 SIGNAL	 niiO1i13	:	STD_LOGIC := '0';
	 SIGNAL	 niiO1i14	:	STD_LOGIC := '0';
	 SIGNAL  wire_niiO1i14_w_lg_w_lg_q53w54w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiO1i14_w_lg_q53w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niiO1l11	:	STD_LOGIC := '0';
	 SIGNAL	 niiO1l12	:	STD_LOGIC := '0';
	 SIGNAL	 niiOll5	:	STD_LOGIC := '0';
	 SIGNAL	 niiOll6	:	STD_LOGIC := '0';
	 SIGNAL	 niiOOl3	:	STD_LOGIC := '0';
	 SIGNAL	 niiOOl4	:	STD_LOGIC := '0';
	 SIGNAL	 nil11i1	:	STD_LOGIC := '0';
	 SIGNAL	 nil11i2	:	STD_LOGIC := '0';
	 SIGNAL  wire_nil11i2_w_lg_q4w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n100i	:	STD_LOGIC := '0';
	 SIGNAL	n100l	:	STD_LOGIC := '0';
	 SIGNAL	n100O	:	STD_LOGIC := '0';
	 SIGNAL	n101i	:	STD_LOGIC := '0';
	 SIGNAL	n101l	:	STD_LOGIC := '0';
	 SIGNAL	n101O	:	STD_LOGIC := '0';
	 SIGNAL	n10ii	:	STD_LOGIC := '0';
	 SIGNAL	n10il	:	STD_LOGIC := '0';
	 SIGNAL	n10iO	:	STD_LOGIC := '0';
	 SIGNAL	n10li	:	STD_LOGIC := '0';
	 SIGNAL	n10ll	:	STD_LOGIC := '0';
	 SIGNAL	n10lO	:	STD_LOGIC := '0';
	 SIGNAL	n10Oi	:	STD_LOGIC := '0';
	 SIGNAL	n10Ol	:	STD_LOGIC := '0';
	 SIGNAL	n10OO	:	STD_LOGIC := '0';
	 SIGNAL	n110i	:	STD_LOGIC := '0';
	 SIGNAL	n110l	:	STD_LOGIC := '0';
	 SIGNAL	n110O	:	STD_LOGIC := '0';
	 SIGNAL	n111i	:	STD_LOGIC := '0';
	 SIGNAL	n111l	:	STD_LOGIC := '0';
	 SIGNAL	n111O	:	STD_LOGIC := '0';
	 SIGNAL	n11ii	:	STD_LOGIC := '0';
	 SIGNAL	n11il	:	STD_LOGIC := '0';
	 SIGNAL	n11iO	:	STD_LOGIC := '0';
	 SIGNAL	n11li	:	STD_LOGIC := '0';
	 SIGNAL	n11ll	:	STD_LOGIC := '0';
	 SIGNAL	n11lO	:	STD_LOGIC := '0';
	 SIGNAL	n11Oi	:	STD_LOGIC := '0';
	 SIGNAL	n11Ol	:	STD_LOGIC := '0';
	 SIGNAL	n11OO	:	STD_LOGIC := '0';
	 SIGNAL	n1i0i	:	STD_LOGIC := '0';
	 SIGNAL	n1i0l	:	STD_LOGIC := '0';
	 SIGNAL	n1i0O	:	STD_LOGIC := '0';
	 SIGNAL	n1i1i	:	STD_LOGIC := '0';
	 SIGNAL	n1i1l	:	STD_LOGIC := '0';
	 SIGNAL	n1i1O	:	STD_LOGIC := '0';
	 SIGNAL	n1iii	:	STD_LOGIC := '0';
	 SIGNAL	n1iil	:	STD_LOGIC := '0';
	 SIGNAL	n1iiO	:	STD_LOGIC := '0';
	 SIGNAL	n1ili	:	STD_LOGIC := '0';
	 SIGNAL	n1ill	:	STD_LOGIC := '0';
	 SIGNAL	n1ilO	:	STD_LOGIC := '0';
	 SIGNAL	n1iOi	:	STD_LOGIC := '0';
	 SIGNAL	n1iOl	:	STD_LOGIC := '0';
	 SIGNAL	n1iOO	:	STD_LOGIC := '0';
	 SIGNAL	n1l0i	:	STD_LOGIC := '0';
	 SIGNAL	n1l0l	:	STD_LOGIC := '0';
	 SIGNAL	n1l1i	:	STD_LOGIC := '0';
	 SIGNAL	n1l1l	:	STD_LOGIC := '0';
	 SIGNAL	n1l1O	:	STD_LOGIC := '0';
	 SIGNAL	n1lii	:	STD_LOGIC := '0';
	 SIGNAL	nliliO	:	STD_LOGIC := '0';
	 SIGNAL	nlOOil	:	STD_LOGIC := '0';
	 SIGNAL	nlOOiO	:	STD_LOGIC := '0';
	 SIGNAL	nlOOli	:	STD_LOGIC := '0';
	 SIGNAL	nlOOll	:	STD_LOGIC := '0';
	 SIGNAL	nlOOlO	:	STD_LOGIC := '0';
	 SIGNAL	nlOOOi	:	STD_LOGIC := '0';
	 SIGNAL	nlOOOl	:	STD_LOGIC := '0';
	 SIGNAL	nlOOOO	:	STD_LOGIC := '0';
	 SIGNAL  wire_n1l0O_w_lg_w_lg_w_lg_w1501w1502w1503w1504w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_w1510w1511w1512w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_w1501w1502w1503w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w1510w1511w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w1501w1502w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w1510w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w1501w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_w_lg_w_lg_n101i1506w1507w1508w1509w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_w_lg_w_lg_n101i1480w1497w1499w1500w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_w_lg_w_lg_n11ii897w899w900w901w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_w_lg_n101i1506w1507w1508w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_w_lg_n11ii902w903w904w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_w_lg_n101i1480w1482w1483w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_w_lg_n101i1480w1497w1499w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_w_lg_n11ii897w899w900w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_n101i1506w1507w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_n11ii902w903w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_n101i1480w1482w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_n101i1480w1497w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_n11ii897w899w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_nlOOiO1476w1543w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_nlOOOO1529w1530w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n101i1506w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n11ii902w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_nlOOOO1538w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n101i1480w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n110i1516w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n110O898w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n111O1524w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n11ii897w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n11il1494w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n11iO1492w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n11li1490w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n11ll1488w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n11lO1486w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n11Oi1484w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n11Ol1498w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n11OO1481w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_nliliO1544w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_nlOOil1477w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_nlOOiO1476w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_nlOOlO1533w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_nlOOOi1531w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_nlOOOl1537w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_nlOOOO1529w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_w_lg_n1ill1401w1402w1403w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_w_lg_n1ill1401w1402w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n1ill1401w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l0O_w_lg_n1l0i1211w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n1liO	:	STD_LOGIC := '0';
	 SIGNAL  wire_n1lil_w_lg_w_lg_w_lg_n1liO1051w1092w1093w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lil_w_lg_w_lg_n1liO1051w1092w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lil_w_lg_n1liO1051w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nl00il	:	STD_LOGIC := '0';
	 SIGNAL	nl00iO	:	STD_LOGIC := '0';
	 SIGNAL	nl00li	:	STD_LOGIC := '0';
	 SIGNAL	nl00ll	:	STD_LOGIC := '0';
	 SIGNAL	nl00lO	:	STD_LOGIC := '0';
	 SIGNAL	nl00Oi	:	STD_LOGIC := '0';
	 SIGNAL	nl00Ol	:	STD_LOGIC := '0';
	 SIGNAL	nl00OO	:	STD_LOGIC := '0';
	 SIGNAL	nl0i0i	:	STD_LOGIC := '0';
	 SIGNAL	nl0i0l	:	STD_LOGIC := '0';
	 SIGNAL	nl0i0O	:	STD_LOGIC := '0';
	 SIGNAL	nl0i1i	:	STD_LOGIC := '0';
	 SIGNAL	nl0i1l	:	STD_LOGIC := '0';
	 SIGNAL	nl0i1O	:	STD_LOGIC := '0';
	 SIGNAL	nl0iii	:	STD_LOGIC := '0';
	 SIGNAL	nl0iil	:	STD_LOGIC := '0';
	 SIGNAL	nl0iiO	:	STD_LOGIC := '0';
	 SIGNAL	nl0ili	:	STD_LOGIC := '0';
	 SIGNAL	nl0ill	:	STD_LOGIC := '0';
	 SIGNAL	nl0ilO	:	STD_LOGIC := '0';
	 SIGNAL	nl0iOi	:	STD_LOGIC := '0';
	 SIGNAL	nl0iOl	:	STD_LOGIC := '0';
	 SIGNAL	nl0iOO	:	STD_LOGIC := '0';
	 SIGNAL	nl0l0i	:	STD_LOGIC := '0';
	 SIGNAL	nl0l0l	:	STD_LOGIC := '0';
	 SIGNAL	nl0l0O	:	STD_LOGIC := '0';
	 SIGNAL	nl0l1i	:	STD_LOGIC := '0';
	 SIGNAL	nl0l1l	:	STD_LOGIC := '0';
	 SIGNAL	nl0l1O	:	STD_LOGIC := '0';
	 SIGNAL	nl0lii	:	STD_LOGIC := '0';
	 SIGNAL	nl0lil	:	STD_LOGIC := '0';
	 SIGNAL	nl0liO	:	STD_LOGIC := '0';
	 SIGNAL	nl0lli	:	STD_LOGIC := '0';
	 SIGNAL	nl0lll	:	STD_LOGIC := '0';
	 SIGNAL	nl0llO	:	STD_LOGIC := '0';
	 SIGNAL	nl0lOi	:	STD_LOGIC := '0';
	 SIGNAL	nl0lOl	:	STD_LOGIC := '0';
	 SIGNAL	nl0lOO	:	STD_LOGIC := '0';
	 SIGNAL	nl0O0i	:	STD_LOGIC := '0';
	 SIGNAL	nl0O0l	:	STD_LOGIC := '0';
	 SIGNAL	nl0O0O	:	STD_LOGIC := '0';
	 SIGNAL	nl0O1i	:	STD_LOGIC := '0';
	 SIGNAL	nl0O1l	:	STD_LOGIC := '0';
	 SIGNAL	nl0O1O	:	STD_LOGIC := '0';
	 SIGNAL	nl0Oii	:	STD_LOGIC := '0';
	 SIGNAL	nl0Oil	:	STD_LOGIC := '0';
	 SIGNAL	nl0OiO	:	STD_LOGIC := '0';
	 SIGNAL	nl0Oli	:	STD_LOGIC := '0';
	 SIGNAL	nl0Oll	:	STD_LOGIC := '0';
	 SIGNAL	nl0OlO	:	STD_LOGIC := '0';
	 SIGNAL	nl0OOi	:	STD_LOGIC := '0';
	 SIGNAL	nl0OOl	:	STD_LOGIC := '0';
	 SIGNAL	nli11i	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl0OOO_PRN	:	STD_LOGIC;
	 SIGNAL  wire_nl0OOO_w_lg_w_lg_w_lg_w_lg_nl0iOl2241w2243w2245w2253w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OOO_w_lg_w_lg_w_lg_nl0iOl2241w2243w2245w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OOO_w_lg_w_lg_nl0iOl2241w2243w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OOO_w_lg_nl0iii2259w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OOO_w_lg_nl0iil2257w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OOO_w_lg_nl0iiO2255w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OOO_w_lg_nl0ili2248w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OOO_w_lg_nl0ill2246w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OOO_w_lg_nl0ilO2244w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OOO_w_lg_nl0iOi2242w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OOO_w_lg_nl0iOl2241w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OOO_w_lg_nl0O0l2201w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OOO_w_lg_nl0O0l2215w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nli11O	:	STD_LOGIC := '0';
	 SIGNAL  wire_nli11l_w_lg_nli11O2169w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n0lOi	:	STD_LOGIC := '0';
	 SIGNAL	niO0l	:	STD_LOGIC := '0';
	 SIGNAL	niO0O	:	STD_LOGIC := '0';
	 SIGNAL	niOii	:	STD_LOGIC := '0';
	 SIGNAL	niOil	:	STD_LOGIC := '0';
	 SIGNAL	niOiO	:	STD_LOGIC := '0';
	 SIGNAL	niOli	:	STD_LOGIC := '0';
	 SIGNAL	niOll	:	STD_LOGIC := '0';
	 SIGNAL	niOlO	:	STD_LOGIC := '0';
	 SIGNAL	niOOi	:	STD_LOGIC := '0';
	 SIGNAL	niOOl	:	STD_LOGIC := '0';
	 SIGNAL	niOOO	:	STD_LOGIC := '0';
	 SIGNAL	nl00i	:	STD_LOGIC := '0';
	 SIGNAL	nl00l	:	STD_LOGIC := '0';
	 SIGNAL	nl00O	:	STD_LOGIC := '0';
	 SIGNAL	nl01i	:	STD_LOGIC := '0';
	 SIGNAL	nl01l	:	STD_LOGIC := '0';
	 SIGNAL	nl01O	:	STD_LOGIC := '0';
	 SIGNAL	nl0ii	:	STD_LOGIC := '0';
	 SIGNAL	nl0il	:	STD_LOGIC := '0';
	 SIGNAL	nl0iO	:	STD_LOGIC := '0';
	 SIGNAL	nl0li	:	STD_LOGIC := '0';
	 SIGNAL	nl0ll	:	STD_LOGIC := '0';
	 SIGNAL	nl0lO	:	STD_LOGIC := '0';
	 SIGNAL	nl0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nl0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nl0OO	:	STD_LOGIC := '0';
	 SIGNAL	nl10i	:	STD_LOGIC := '0';
	 SIGNAL	nl10l	:	STD_LOGIC := '0';
	 SIGNAL	nl10O	:	STD_LOGIC := '0';
	 SIGNAL	nl11i	:	STD_LOGIC := '0';
	 SIGNAL	nl11l	:	STD_LOGIC := '0';
	 SIGNAL	nl11O	:	STD_LOGIC := '0';
	 SIGNAL	nl1ii	:	STD_LOGIC := '0';
	 SIGNAL	nl1il	:	STD_LOGIC := '0';
	 SIGNAL	nl1iO	:	STD_LOGIC := '0';
	 SIGNAL	nl1li	:	STD_LOGIC := '0';
	 SIGNAL	nl1ll	:	STD_LOGIC := '0';
	 SIGNAL	nl1lO	:	STD_LOGIC := '0';
	 SIGNAL	nl1Oi	:	STD_LOGIC := '0';
	 SIGNAL	nl1Ol	:	STD_LOGIC := '0';
	 SIGNAL	nl1OO	:	STD_LOGIC := '0';
	 SIGNAL	nli0i	:	STD_LOGIC := '0';
	 SIGNAL	nli0l	:	STD_LOGIC := '0';
	 SIGNAL	nli0O	:	STD_LOGIC := '0';
	 SIGNAL	nli1i	:	STD_LOGIC := '0';
	 SIGNAL	nli1l	:	STD_LOGIC := '0';
	 SIGNAL	nli1O	:	STD_LOGIC := '0';
	 SIGNAL	nliil	:	STD_LOGIC := '0';
	 SIGNAL  wire_nliii_w_lg_w_lg_w_lg_niOll766w767w768w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliii_w_lg_w_lg_niOll766w767w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliii_w_lg_w_lg_niO0O762w771w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliii_w_lg_niOll766w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliii_w_lg_n0lOi772w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliii_w_lg_niO0l763w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliii_w_lg_niO0O762w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliii_w_lg_niOii769w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliii_w_lg_w_lg_w_lg_nl00O654w655w656w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliii_w_lg_w_lg_nl00O654w655w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliii_w_lg_nl00O654w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nlili	:	STD_LOGIC := '0';
	 SIGNAL	wire_nliiO_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nliiO_PRN	:	STD_LOGIC;
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w194w195w196w197w198w199w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_w194w195w196w197w198w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w194w195w196w197w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w120w121w122w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w194w195w196w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w120w121w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w194w195w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w262w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w223w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w120w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w194w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w256w257w258w259w260w261w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w217w218w219w220w221w222w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w114w115w116w117w118w119w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w188w189w190w191w192w193w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_w256w257w258w259w260w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_w217w218w219w220w221w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_w114w115w116w117w118w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_w188w189w190w191w192w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w256w257w258w259w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w217w218w219w220w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w114w115w116w117w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w188w189w190w191w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w256w257w258w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w217w218w219w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w114w115w116w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w188w189w190w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w256w257w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w217w218w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w114w115w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w188w189w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w256w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w217w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w114w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w188w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_nlili160w161w162w254w255w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_nlili160w161w214w215w216w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_nlili109w110w111w112w113w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_nlili109w184w185w186w187w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_nlili160w161w162w254w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_nlili160w161w214w215w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_nlili109w110w111w112w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_w_lg_nlili109w184w185w186w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_nlili160w161w162w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_nlili160w161w214w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_nlili109w110w111w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_w_lg_nlili109w184w185w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_nlili160w161w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_nlili109w110w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_w_lg_nlili109w184w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_nlili160w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliiO_w_lg_nlili109w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n000i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl100i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl100l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl100O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl101i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl101l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl101O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl110i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl110l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl111i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl111l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl111O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO_w_lg_dataout1647w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlO00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n00Oi_a	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_n00Oi_b	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_gnd	:	STD_LOGIC;
	 SIGNAL  wire_n00Oi_o	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_n01iO_a	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n01iO_b	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n01iO_o	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1lOi_a	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n1lOi_b	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n1lOi_o	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n1Oll_a	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n1Oll_b	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n1Oll_o	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n1OOO_a	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n1OOO_b	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n1OOO_o	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nli0ll_a	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nli0ll_b	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nli0ll_o	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nli0lO_a	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nli0lO_b	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nli0lO_o	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nli0Oi_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nli0Oi_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nli0Oi_o	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nliOl_a	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nliOl_b	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nliOl_o	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllli_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllli_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllli_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0iii_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0iii_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iii_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0iil_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0iil_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iil_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0iiO_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0iiO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iiO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0ilO_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n0ilO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0ilO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n0iOl_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0iOl_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iOl_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0l1i_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0l1i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0l1i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0l1O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0l1O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0l1O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0lii_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0lii_o	:	STD_LOGIC;
	 SIGNAL  wire_n0lii_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0lil_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0lil_o	:	STD_LOGIC;
	 SIGNAL  wire_n0lil_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0liO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0liO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0liO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0lli_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0lli_o	:	STD_LOGIC;
	 SIGNAL  wire_n0lli_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0lOl_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0lOl_o	:	STD_LOGIC;
	 SIGNAL  wire_n0lOl_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0O0l_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0O0l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O0l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0O1l_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0O1l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O1l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0Oil_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0Oil_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oil_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0Oll_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0Oll_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oll_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0OOl_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n0OOl_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OOl_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_ni00l_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni00l_o	:	STD_LOGIC;
	 SIGNAL  wire_ni00l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni01i_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni01i_o	:	STD_LOGIC;
	 SIGNAL  wire_ni01i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni01O_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni01O_o	:	STD_LOGIC;
	 SIGNAL  wire_ni01O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni0ii_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni0ii_o	:	STD_LOGIC;
	 SIGNAL  wire_ni0ii_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni0iO_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni0iO_o	:	STD_LOGIC;
	 SIGNAL  wire_ni0iO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni0ll_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni0ll_o	:	STD_LOGIC;
	 SIGNAL  wire_ni0ll_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni0Oi_data	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_ni0Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_ni0Oi_sel	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_ni10i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni10i_o	:	STD_LOGIC;
	 SIGNAL  wire_ni10i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni11l_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_ni11l_o	:	STD_LOGIC;
	 SIGNAL  wire_ni11l_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_ni1Ol_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_ni1Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1Ol_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nil00l_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nil00l_o	:	STD_LOGIC;
	 SIGNAL  wire_nil00l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nil01O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nil01O_o	:	STD_LOGIC;
	 SIGNAL  wire_nil01O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nil0il_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nil0il_o	:	STD_LOGIC;
	 SIGNAL  wire_nil0il_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nil0li_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nil0li_o	:	STD_LOGIC;
	 SIGNAL  wire_nil0li_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nil0Oi_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nil0Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_nil0Oi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nil1li_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nil1li_o	:	STD_LOGIC;
	 SIGNAL  wire_nil1li_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nil1lO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nil1lO_o	:	STD_LOGIC;
	 SIGNAL  wire_nil1lO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nil1OO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nil1OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nil1OO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nili0i_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nili0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nili0i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nili0O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nili0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nili0O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nili1i_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nili1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nili1i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niliil_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_niliil_o	:	STD_LOGIC;
	 SIGNAL  wire_niliil_sel	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nilili_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nilili_o	:	STD_LOGIC;
	 SIGNAL  wire_nilili_sel	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nililO_data	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_nililO_o	:	STD_LOGIC;
	 SIGNAL  wire_nililO_sel	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_niliOl_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_niliOl_o	:	STD_LOGIC;
	 SIGNAL  wire_niliOl_sel	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nill0O_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nill0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nill0O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nill1i_data	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nill1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nill1i_sel	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nill1O_data	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nill1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nill1O_sel	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nillil_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nillil_o	:	STD_LOGIC;
	 SIGNAL  wire_nillil_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nillli_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nillli_o	:	STD_LOGIC;
	 SIGNAL  wire_nillli_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nilllO_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nilllO_o	:	STD_LOGIC;
	 SIGNAL  wire_nilllO_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nillOl_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nillOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nillOl_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nilO0l_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nilO0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nilO0l_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nilO1i_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nilO1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nilO1i_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nilO1O_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nilO1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nilO1O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nilOii_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nilOii_o	:	STD_LOGIC;
	 SIGNAL  wire_nilOii_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nilOiO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilOiO_o	:	STD_LOGIC;
	 SIGNAL  wire_nilOiO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilOli_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nilOli_o	:	STD_LOGIC;
	 SIGNAL  wire_nilOli_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nilOlO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilOlO_o	:	STD_LOGIC;
	 SIGNAL  wire_nilOlO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilOOl_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nilOOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nilOOl_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_niO11i_data	:	STD_LOGIC_VECTOR (13 DOWNTO 0);
	 SIGNAL  wire_niO11i_o	:	STD_LOGIC;
	 SIGNAL  wire_niO11i_sel	:	STD_LOGIC_VECTOR (13 DOWNTO 0);
	 SIGNAL  wire_nlilOi_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nlilOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nlilOi_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nliO0l_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nliO0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nliO0l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nliO1i_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nliO1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nliO1i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nliO1O_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nliO1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nliO1O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nliOii_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nliOii_o	:	STD_LOGIC;
	 SIGNAL  wire_nliOii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nliOli_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nliOli_o	:	STD_LOGIC;
	 SIGNAL  wire_nliOli_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nliOlO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nliOlO_o	:	STD_LOGIC;
	 SIGNAL  wire_nliOlO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nliOOi_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nliOOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nliOOi_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nliOOl_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nliOOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nliOOl_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll00O_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll00O_o	:	STD_LOGIC;
	 SIGNAL  wire_nll00O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll01i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll01i_o	:	STD_LOGIC;
	 SIGNAL  wire_nll01i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll01O_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll01O_o	:	STD_LOGIC;
	 SIGNAL  wire_nll01O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll0iO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll0iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nll0iO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll0lO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll0lO_o	:	STD_LOGIC;
	 SIGNAL  wire_nll0lO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll0OO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll0OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nll0OO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll10i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll10i_o	:	STD_LOGIC;
	 SIGNAL  wire_nll10i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll10O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll10O_o	:	STD_LOGIC;
	 SIGNAL  wire_nll10O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll11l_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll11l_o	:	STD_LOGIC;
	 SIGNAL  wire_nll11l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll1il_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nll1il_o	:	STD_LOGIC;
	 SIGNAL  wire_nll1il_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nll1ll_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll1ll_o	:	STD_LOGIC;
	 SIGNAL  wire_nll1ll_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll1Ol_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nll1Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_nll1Ol_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nlli0i_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlli0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlli0i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlliil_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlliil_o	:	STD_LOGIC;
	 SIGNAL  wire_nlliil_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllili_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllili_o	:	STD_LOGIC;
	 SIGNAL  wire_nllili_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllilO_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllilO_o	:	STD_LOGIC;
	 SIGNAL  wire_nllilO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlliOi_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlliOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nlliOi_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlliOO_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlliOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlliOO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlll0i_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlll0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlll0i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlll0O_data	:	STD_LOGIC_VECTOR (10 DOWNTO 0);
	 SIGNAL  wire_nlll0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlll0O_sel	:	STD_LOGIC_VECTOR (10 DOWNTO 0);
	 SIGNAL  wire_nlll1l_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlll1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlll1l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_rpmadwidth_tx2w5w6w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rpmadwidth_tx2w5w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rpmadwidth_tx2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rbist_sel_range12w20w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rcxpat_chnl_sel_range755w760w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni000l1442w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0iOi1037w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0iOl1019w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0iOO996w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0l0l913w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0l0O912w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0l1i983w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0l1l970w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0l1O957w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0lii914w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0lil911w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0liO910w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0lll909w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0llO908w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0lOl907w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0O0i894w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0O0O893w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0O1i896w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0O1l895w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0Oii1237w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0Oil891w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0OiO892w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0Oli906w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0OOi889w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0OOl888w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni1lll2233w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni1Oil2081w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nii00l246w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nii01i291w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nii01l267w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nii0ii229w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nii0ll204w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nii0Ol176w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nii11i695w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nii1Ol312w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiiil107w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiiiO106w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiili108w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiill105w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiilO447w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiiOi102w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiiOl103w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiiOO104w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niil0l99w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niil0O98w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niil1O100w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niilii97w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niilil96w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiliO95w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiOOi445w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rpma_doublewidth_tx1w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_soft_reset93w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rbist_sel_range14w15w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rcxpat_chnl_sel_range757w758w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  ni000i :	STD_LOGIC;
	 SIGNAL  ni000l :	STD_LOGIC;
	 SIGNAL  ni000O :	STD_LOGIC;
	 SIGNAL  ni001i :	STD_LOGIC;
	 SIGNAL  ni001O :	STD_LOGIC;
	 SIGNAL  ni00ii :	STD_LOGIC;
	 SIGNAL  ni00il :	STD_LOGIC;
	 SIGNAL  ni00iO :	STD_LOGIC;
	 SIGNAL  ni00li :	STD_LOGIC;
	 SIGNAL  ni00ll :	STD_LOGIC;
	 SIGNAL  ni00lO :	STD_LOGIC;
	 SIGNAL  ni00Oi :	STD_LOGIC;
	 SIGNAL  ni00Ol :	STD_LOGIC;
	 SIGNAL  ni00OO :	STD_LOGIC;
	 SIGNAL  ni010i :	STD_LOGIC;
	 SIGNAL  ni010l :	STD_LOGIC;
	 SIGNAL  ni010O :	STD_LOGIC;
	 SIGNAL  ni011i :	STD_LOGIC;
	 SIGNAL  ni011l :	STD_LOGIC;
	 SIGNAL  ni011O :	STD_LOGIC;
	 SIGNAL  ni01ii :	STD_LOGIC;
	 SIGNAL  ni01il :	STD_LOGIC;
	 SIGNAL  ni01iO :	STD_LOGIC;
	 SIGNAL  ni01li :	STD_LOGIC;
	 SIGNAL  ni01ll :	STD_LOGIC;
	 SIGNAL  ni01lO :	STD_LOGIC;
	 SIGNAL  ni01Oi :	STD_LOGIC;
	 SIGNAL  ni01Ol :	STD_LOGIC;
	 SIGNAL  ni01OO :	STD_LOGIC;
	 SIGNAL  ni0i0i :	STD_LOGIC;
	 SIGNAL  ni0i0l :	STD_LOGIC;
	 SIGNAL  ni0i0O :	STD_LOGIC;
	 SIGNAL  ni0i1i :	STD_LOGIC;
	 SIGNAL  ni0i1l :	STD_LOGIC;
	 SIGNAL  ni0i1O :	STD_LOGIC;
	 SIGNAL  ni0iii :	STD_LOGIC;
	 SIGNAL  ni0iil :	STD_LOGIC;
	 SIGNAL  ni0iiO :	STD_LOGIC;
	 SIGNAL  ni0ili :	STD_LOGIC;
	 SIGNAL  ni0ill :	STD_LOGIC;
	 SIGNAL  ni0ilO :	STD_LOGIC;
	 SIGNAL  ni0iOi :	STD_LOGIC;
	 SIGNAL  ni0iOl :	STD_LOGIC;
	 SIGNAL  ni0iOO :	STD_LOGIC;
	 SIGNAL  ni0l0i :	STD_LOGIC;
	 SIGNAL  ni0l0l :	STD_LOGIC;
	 SIGNAL  ni0l0O :	STD_LOGIC;
	 SIGNAL  ni0l1i :	STD_LOGIC;
	 SIGNAL  ni0l1l :	STD_LOGIC;
	 SIGNAL  ni0l1O :	STD_LOGIC;
	 SIGNAL  ni0lii :	STD_LOGIC;
	 SIGNAL  ni0lil :	STD_LOGIC;
	 SIGNAL  ni0liO :	STD_LOGIC;
	 SIGNAL  ni0lli :	STD_LOGIC;
	 SIGNAL  ni0lll :	STD_LOGIC;
	 SIGNAL  ni0llO :	STD_LOGIC;
	 SIGNAL  ni0lOi :	STD_LOGIC;
	 SIGNAL  ni0lOl :	STD_LOGIC;
	 SIGNAL  ni0lOO :	STD_LOGIC;
	 SIGNAL  ni0O0i :	STD_LOGIC;
	 SIGNAL  ni0O0l :	STD_LOGIC;
	 SIGNAL  ni0O0O :	STD_LOGIC;
	 SIGNAL  ni0O1i :	STD_LOGIC;
	 SIGNAL  ni0O1l :	STD_LOGIC;
	 SIGNAL  ni0O1O :	STD_LOGIC;
	 SIGNAL  ni0Oii :	STD_LOGIC;
	 SIGNAL  ni0Oil :	STD_LOGIC;
	 SIGNAL  ni0OiO :	STD_LOGIC;
	 SIGNAL  ni0Oli :	STD_LOGIC;
	 SIGNAL  ni0Oll :	STD_LOGIC;
	 SIGNAL  ni0OlO :	STD_LOGIC;
	 SIGNAL  ni0OOi :	STD_LOGIC;
	 SIGNAL  ni0OOl :	STD_LOGIC;
	 SIGNAL  ni0OOO :	STD_LOGIC;
	 SIGNAL  ni1lll :	STD_LOGIC;
	 SIGNAL  ni1llO :	STD_LOGIC;
	 SIGNAL  ni1lOi :	STD_LOGIC;
	 SIGNAL  ni1lOl :	STD_LOGIC;
	 SIGNAL  ni1lOO :	STD_LOGIC;
	 SIGNAL  ni1O0i :	STD_LOGIC;
	 SIGNAL  ni1O0l :	STD_LOGIC;
	 SIGNAL  ni1O0O :	STD_LOGIC;
	 SIGNAL  ni1O1i :	STD_LOGIC;
	 SIGNAL  ni1O1l :	STD_LOGIC;
	 SIGNAL  ni1O1O :	STD_LOGIC;
	 SIGNAL  ni1Oii :	STD_LOGIC;
	 SIGNAL  ni1Oil :	STD_LOGIC;
	 SIGNAL  ni1OiO :	STD_LOGIC;
	 SIGNAL  ni1Oli :	STD_LOGIC;
	 SIGNAL  ni1Oll :	STD_LOGIC;
	 SIGNAL  ni1OlO :	STD_LOGIC;
	 SIGNAL  ni1OOi :	STD_LOGIC;
	 SIGNAL  ni1OOl :	STD_LOGIC;
	 SIGNAL  ni1OOO :	STD_LOGIC;
	 SIGNAL  nii00l :	STD_LOGIC;
	 SIGNAL  nii01i :	STD_LOGIC;
	 SIGNAL  nii01l :	STD_LOGIC;
	 SIGNAL  nii0ii :	STD_LOGIC;
	 SIGNAL  nii0ll :	STD_LOGIC;
	 SIGNAL  nii0Ol :	STD_LOGIC;
	 SIGNAL  nii10i :	STD_LOGIC;
	 SIGNAL  nii10l :	STD_LOGIC;
	 SIGNAL  nii10O :	STD_LOGIC;
	 SIGNAL  nii11i :	STD_LOGIC;
	 SIGNAL  nii11l :	STD_LOGIC;
	 SIGNAL  nii11O :	STD_LOGIC;
	 SIGNAL  nii1ii :	STD_LOGIC;
	 SIGNAL  nii1il :	STD_LOGIC;
	 SIGNAL  nii1iO :	STD_LOGIC;
	 SIGNAL  nii1li :	STD_LOGIC;
	 SIGNAL  nii1ll :	STD_LOGIC;
	 SIGNAL  nii1lO :	STD_LOGIC;
	 SIGNAL  nii1Oi :	STD_LOGIC;
	 SIGNAL  nii1Ol :	STD_LOGIC;
	 SIGNAL  niii0l :	STD_LOGIC;
	 SIGNAL  niiiil :	STD_LOGIC;
	 SIGNAL  niiiiO :	STD_LOGIC;
	 SIGNAL  niiili :	STD_LOGIC;
	 SIGNAL  niiill :	STD_LOGIC;
	 SIGNAL  niiilO :	STD_LOGIC;
	 SIGNAL  niiiOi :	STD_LOGIC;
	 SIGNAL  niiiOl :	STD_LOGIC;
	 SIGNAL  niiiOO :	STD_LOGIC;
	 SIGNAL  niil0i :	STD_LOGIC;
	 SIGNAL  niil0l :	STD_LOGIC;
	 SIGNAL  niil0O :	STD_LOGIC;
	 SIGNAL  niil1i :	STD_LOGIC;
	 SIGNAL  niil1l :	STD_LOGIC;
	 SIGNAL  niil1O :	STD_LOGIC;
	 SIGNAL  niilii :	STD_LOGIC;
	 SIGNAL  niilil :	STD_LOGIC;
	 SIGNAL  niiliO :	STD_LOGIC;
	 SIGNAL  niilli :	STD_LOGIC;
	 SIGNAL  niilll :	STD_LOGIC;
	 SIGNAL  niilOl :	STD_LOGIC;
	 SIGNAL  niiOil :	STD_LOGIC;
	 SIGNAL  niiOiO :	STD_LOGIC;
	 SIGNAL  niiOli :	STD_LOGIC;
	 SIGNAL  niiOOi :	STD_LOGIC;
	 SIGNAL  wire_w_rbist_sel_range12w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rbist_sel_range14w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rcxpat_chnl_sel_range755w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rcxpat_chnl_sel_range757w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_gnd <= '0';
	wire_w_lg_w_lg_w_lg_rpmadwidth_tx2w5w6w(0) <= wire_w_lg_w_lg_rpmadwidth_tx2w5w(0) AND rdwidth_tx;
	wire_w_lg_w_lg_rpmadwidth_tx2w5w(0) <= wire_w_lg_rpmadwidth_tx2w(0) AND wire_nil11i2_w_lg_q4w(0);
	wire_w_lg_rpmadwidth_tx2w(0) <= rpmadwidth_tx AND wire_w_lg_rpma_doublewidth_tx1w(0);
	wire_w_lg_w_rbist_sel_range12w20w(0) <= wire_w_rbist_sel_range12w(0) AND wire_w_lg_w_rbist_sel_range14w15w(0);
	wire_w_lg_w_rcxpat_chnl_sel_range755w760w(0) <= wire_w_rcxpat_chnl_sel_range755w(0) AND wire_w_lg_w_rcxpat_chnl_sel_range757w758w(0);
	wire_w_lg_ni000l1442w(0) <= NOT ni000l;
	wire_w_lg_ni0iOi1037w(0) <= NOT ni0iOi;
	wire_w_lg_ni0iOl1019w(0) <= NOT ni0iOl;
	wire_w_lg_ni0iOO996w(0) <= NOT ni0iOO;
	wire_w_lg_ni0l0l913w(0) <= NOT ni0l0l;
	wire_w_lg_ni0l0O912w(0) <= NOT ni0l0O;
	wire_w_lg_ni0l1i983w(0) <= NOT ni0l1i;
	wire_w_lg_ni0l1l970w(0) <= NOT ni0l1l;
	wire_w_lg_ni0l1O957w(0) <= NOT ni0l1O;
	wire_w_lg_ni0lii914w(0) <= NOT ni0lii;
	wire_w_lg_ni0lil911w(0) <= NOT ni0lil;
	wire_w_lg_ni0liO910w(0) <= NOT ni0liO;
	wire_w_lg_ni0lll909w(0) <= NOT ni0lll;
	wire_w_lg_ni0llO908w(0) <= NOT ni0llO;
	wire_w_lg_ni0lOl907w(0) <= NOT ni0lOl;
	wire_w_lg_ni0O0i894w(0) <= NOT ni0O0i;
	wire_w_lg_ni0O0O893w(0) <= NOT ni0O0O;
	wire_w_lg_ni0O1i896w(0) <= NOT ni0O1i;
	wire_w_lg_ni0O1l895w(0) <= NOT ni0O1l;
	wire_w_lg_ni0Oii1237w(0) <= NOT ni0Oii;
	wire_w_lg_ni0Oil891w(0) <= NOT ni0Oil;
	wire_w_lg_ni0OiO892w(0) <= NOT ni0OiO;
	wire_w_lg_ni0Oli906w(0) <= NOT ni0Oli;
	wire_w_lg_ni0OOi889w(0) <= NOT ni0OOi;
	wire_w_lg_ni0OOl888w(0) <= NOT ni0OOl;
	wire_w_lg_ni1lll2233w(0) <= NOT ni1lll;
	wire_w_lg_ni1Oil2081w(0) <= NOT ni1Oil;
	wire_w_lg_nii00l246w(0) <= NOT nii00l;
	wire_w_lg_nii01i291w(0) <= NOT nii01i;
	wire_w_lg_nii01l267w(0) <= NOT nii01l;
	wire_w_lg_nii0ii229w(0) <= NOT nii0ii;
	wire_w_lg_nii0ll204w(0) <= NOT nii0ll;
	wire_w_lg_nii0Ol176w(0) <= NOT nii0Ol;
	wire_w_lg_nii11i695w(0) <= NOT nii11i;
	wire_w_lg_nii1Ol312w(0) <= NOT nii1Ol;
	wire_w_lg_niiiil107w(0) <= NOT niiiil;
	wire_w_lg_niiiiO106w(0) <= NOT niiiiO;
	wire_w_lg_niiili108w(0) <= NOT niiili;
	wire_w_lg_niiill105w(0) <= NOT niiill;
	wire_w_lg_niiilO447w(0) <= NOT niiilO;
	wire_w_lg_niiiOi102w(0) <= NOT niiiOi;
	wire_w_lg_niiiOl103w(0) <= NOT niiiOl;
	wire_w_lg_niiiOO104w(0) <= NOT niiiOO;
	wire_w_lg_niil0l99w(0) <= NOT niil0l;
	wire_w_lg_niil0O98w(0) <= NOT niil0O;
	wire_w_lg_niil1O100w(0) <= NOT niil1O;
	wire_w_lg_niilii97w(0) <= NOT niilii;
	wire_w_lg_niilil96w(0) <= NOT niilil;
	wire_w_lg_niiliO95w(0) <= NOT niiliO;
	wire_w_lg_niiOOi445w(0) <= NOT niiOOi;
	wire_w_lg_rpma_doublewidth_tx1w(0) <= NOT rpma_doublewidth_tx;
	wire_w_lg_soft_reset93w(0) <= NOT soft_reset;
	wire_w_lg_w_rbist_sel_range14w15w(0) <= NOT wire_w_rbist_sel_range14w(0);
	wire_w_lg_w_rcxpat_chnl_sel_range757w758w(0) <= NOT wire_w_rcxpat_chnl_sel_range757w(0);
	bist_ctl_sg <= ( wire_ni1O_dataout & wire_ni1l_dataout);
	bist_data_sg <= ( wire_ni1i_dataout & wire_n0OO_dataout & wire_n0Ol_dataout & wire_n0Oi_dataout & wire_n0lO_dataout & wire_n0ll_dataout & wire_n0li_dataout & wire_n0iO_dataout & wire_n0il_dataout & wire_n0ii_dataout & wire_n00O_dataout & wire_n00l_dataout & wire_n00i_dataout & wire_n01O_dataout & wire_n01l_dataout & wire_n01i_dataout);
	ni000i <= (((((((((((((n1liO OR n1lii) OR n1l0i) OR n1l1O) OR n1l1l) OR n1l1i) OR n1iOO) OR n1iOl) OR n1iOi) OR n1ilO) OR n1ill) OR n1ili) OR n1iiO) OR n1iil);
	ni000l <= ((((((((((((n1liO OR n1lii) OR n1l0l) OR n1l0i) OR n1l1O) OR n1l1l) OR n1l1i) OR n1iOO) OR n1iOl) OR n1iOi) OR n1iiO) OR n1i0O) OR n1i0l);
	ni000O <= (((((((((((((((n1liO OR n1lii) OR n1l0l) OR n1l0i) OR n1l1O) OR n1l1l) OR n1l1i) OR n1iOO) OR n1iOl) OR n1iOi) OR n1ilO) OR n1ill) OR n1ili) OR n1iiO) OR n1iil) OR n1iii);
	ni001i <= (((((wire_nl0OOO_w_lg_w_lg_w_lg_nl0iOl2241w2243w2245w(0) AND wire_nl0OOO_w_lg_nl0ill2246w(0)) AND wire_nl0OOO_w_lg_nl0ili2248w(0)) AND nl0iiO) AND nl0iil) AND nl0iii);
	ni001O <= (nli11i OR nl0OOi);
	ni00ii <= (((((((((((((((n1liO OR n1lii) OR n1l0l) OR n1l0i) OR n1l1O) OR n1l1l) OR n1l1i) OR n1iOO) OR n1iOl) OR n1iOi) OR n1ilO) OR n1ill) OR n1ili) OR n1iiO) OR n1iil) OR n1i0l);
	ni00il <= (((((((((((n1liO OR n1lii) OR n1l0l) OR n1l0i) OR n1l1O) OR n1l1l) OR n1l1i) OR n1iOO) OR n1iOl) OR n1iOi) OR n1i0O) OR n1i0l);
	ni00iO <= (((((((((((((((n1liO OR n1lii) OR n1l0l) OR n1l0i) OR n1l1O) OR n1l1l) OR n1iOl) OR n1iOi) OR n1ilO) OR n1ill) OR n1ili) OR n1iiO) OR n1iil) OR n1iii) OR n1i0O) OR n1i0l);
	ni00li <= (((((((((((((((n1liO OR n1lii) OR n1l0l) OR n1l0i) OR n1l1O) OR n1l1l) OR n1l1i) OR n1iOO) OR n1ilO) OR n1ill) OR n1ili) OR n1iiO) OR n1iil) OR n1iii) OR n1i0O) OR n1i0l);
	ni00ll <= ((((((((((((((n1liO OR n1lii) OR n1l0l) OR n1l0i) OR n1l1O) OR n1l1l) OR n1iOi) OR n1ilO) OR n1ill) OR n1ili) OR n1iiO) OR n1iil) OR n1iii) OR n1i0O) OR n1i0l);
	ni00lO <= ((((((((((((((n1liO OR n1lii) OR n1l0l) OR n1l0i) OR n1l1O) OR n1iOl) OR n1iOi) OR n1ilO) OR n1ill) OR n1ili) OR n1iiO) OR n1iil) OR n1iii) OR n1i0O) OR n1i0l);
	ni00Oi <= (((((((((((n1liO OR n1lii) OR n1iOl) OR n1iOi) OR n1ilO) OR n1ill) OR n1ili) OR n1iiO) OR n1iil) OR n1iii) OR n1i0O) OR n1i0l);
	ni00Ol <= (((((((((((((((n1liO OR n1l0i) OR n1l1O) OR n1l1l) OR n1l1i) OR n1iOO) OR n1iOl) OR n1iOi) OR n1ilO) OR n1ill) OR n1ili) OR n1iiO) OR n1iil) OR n1iii) OR n1i0O) OR n1i0l);
	ni00OO <= (((((((((((wire_n1l0O_w_lg_n1l0i1211w(0) OR n1l1l) OR n1l1i) OR n1iOO) OR n1iOl) OR n1iOi) OR n1ilO) OR n1ill) OR n1ili) OR n1iiO) OR n1iil) OR n1i0O);
	ni010i <= ((((((((nl0OOl OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0O0O) OR nl0O0l) OR nl0O0i) OR nl0O1O);
	ni010l <= (((((((((nl0OOl OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oii) OR nl0O0O) OR nl0O0l) OR nl0O0i) OR nl0O1O);
	ni010O <= ((((((((nl0OOl OR nl0OlO) OR nl0Oll) OR nl0Oil) OR nl0Oii) OR nl0O0O) OR nl0O0l) OR nl0O0i) OR nl0O1O);
	ni011i <= (((((((((nl0OOl OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0O) OR nl0O0l) OR nl0O1O);
	ni011l <= ((((((((nl0OOl OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0i) OR nl0O1O);
	ni011O <= (((((((((nl0OOl OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0l) OR nl0O0i) OR nl0O1O);
	ni01ii <= (((((((((nl0OOl OR nl0OlO) OR nl0Oll) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0O) OR nl0O0l) OR nl0O0i) OR nl0O1O);
	ni01il <= ((((((((nl0OOl OR nl0Oli) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0O) OR nl0O0l) OR nl0O0i) OR nl0O1O);
	ni01iO <= (((((((((nl0OOl OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0O) OR nl0O0l) OR nl0O0i) OR nl0O1O);
	ni01li <= (((((((((nl0OlO OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0O) OR nl0O0l) OR nl0O0i) OR nl0O1O);
	ni01ll <= ((((((((((nl0OOl OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0O) OR nl0O0l) OR nl0O0i) OR nl0O1O);
	ni01lO <= ((((((((nl0OOl OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0O) OR nl0O0l);
	ni01Oi <= (((((((nl0iOl AND nl0iOi) AND nl0ilO) AND nl0ill) AND nl0ili) AND nl0iiO) AND nl0iil) AND nl0iii);
	ni01Ol <= ((((((nl00Ol AND nl00Oi) AND nl00lO) AND nl00ll) AND nl00li) AND nl00iO) AND nl00il);
	ni01OO <= ((((wire_nl0OOO_w_lg_w_lg_w_lg_w_lg_nl0iOl2241w2243w2245w2253w(0) AND wire_nl0OOO_w_lg_nl0ili2248w(0)) AND wire_nl0OOO_w_lg_nl0iiO2255w(0)) AND wire_nl0OOO_w_lg_nl0iil2257w(0)) AND wire_nl0OOO_w_lg_nl0iii2259w(0));
	ni0i0i <= ((((((n1lii OR n1l1O) OR n1l1l) OR n1iOO) OR n1ill) OR n1ili) OR n1iil);
	ni0i0l <= (((((((((n1liO OR n1l0l) OR n1l0i) OR n1l1i) OR n1iOl) OR n1ilO) OR n1iiO) OR n1iii) OR n1i0O) OR n1i0l);
	ni0i0O <= (((((((((((n1l0l OR n1l0i) OR n1l1l) OR n1l1i) OR n1iOl) OR n1ilO) OR n1ill) OR n1ili) OR n1iiO) OR n1iii) OR n1i0O) OR n1i0l);
	ni0i1i <= ((((((((((((((n1lii OR n1l0l) OR n1l0i) OR n1l1O) OR n1l1l) OR n1l1i) OR n1iOO) OR n1iOl) OR n1iOi) OR n1ilO) OR n1ill) OR n1ili) OR n1iiO) OR n1iil) OR n1i0O);
	ni0i1l <= (((((((((n1lii OR n1l0l) OR n1l0i) OR n1l1O) OR n1iOO) OR n1iOl) OR n1ilO) OR n1ill) OR n1iiO) OR n1iil);
	ni0i1O <= ((((((n1liO OR n1l1l) OR n1l1i) OR n1ili) OR n1iii) OR n1i0O) OR n1i0l);
	ni0iii <= ((((n1liO OR n1lii) OR n1l1O) OR n1iOO) OR n1iil);
	ni0iil <= (((((((((((n1lii OR n1l1O) OR n1l1l) OR n1iOO) OR n1ilO) OR n1ill) OR n1ili) OR n1iiO) OR n1iil) OR n1iii) OR n1i0O) OR n1i0l);
	ni0iiO <= ((((n1liO OR n1l0l) OR n1l0i) OR n1l1i) OR n1iOl);
	ni0ili <= ((((((((((((n1lii OR n1l0l) OR n1l0i) OR n1l1l) OR n1l1i) OR n1iOl) OR n1ilO) OR n1ill) OR n1ili) OR n1iiO) OR n1iii) OR n1i0O) OR n1i0l);
	ni0ill <= (((((((n1lii OR n1l0l) OR n1l0i) OR n1l1l) OR n1l1i) OR n1iOO) OR n1iiO) OR n1i0O);
	ni0ilO <= (((((((wire_n1lil_w_lg_n1liO1051w(0) OR n1iOl) OR n1ilO) OR n1ill) OR n1ili) OR n1iil) OR n1iii) OR n1i0l);
	ni0iOi <= (((((((((((n1liO OR n1l0i) OR n1l1O) OR n1l1l) OR n1iOO) OR n1ill) OR n1ili) OR n1iiO) OR n1iil) OR n1iii) OR n1i0O) OR n1i0l);
	ni0iOl <= (((((((((((((n1liO OR n1lii) OR n1l0l) OR n1l0i) OR n1iOO) OR n1iOl) OR n1ilO) OR n1ill) OR n1ili) OR n1iiO) OR n1iil) OR n1iii) OR n1i0O) OR n1i0l);
	ni0iOO <= ((((((((n1liO OR n1lii) OR n1l0l) OR n1l0i) OR n1iOO) OR n1iOl) OR n1iiO) OR n1i0O) OR n1i0l);
	ni0l0i <= (((((((n1liO OR n1lii) OR n1l0i) OR n1l1O) OR n1l1l) OR n1iiO) OR n1i0O) OR n1i0l);
	ni0l0l <= ((nlOOiO AND wire_n1l0O_w_lg_nlOOil1477w(0)) AND nliliO);
	ni0l0O <= ((nlOOiO AND nlOOil) AND wire_n1l0O_w_lg_nliliO1544w(0));
	ni0l1i <= ((((((n1liO OR n1l0i) OR n1l1i) OR n1iOi) OR n1iiO) OR n1i0O) OR n1i0l);
	ni0l1l <= ((((((n1liO OR n1lii) OR n1l0l) OR n1l0i) OR n1iiO) OR n1i0O) OR n1i0l);
	ni0l1O <= ((((((((((n1liO OR n1l0i) OR n1iOl) OR n1iOi) OR n1ill) OR n1ili) OR n1iiO) OR n1iil) OR n1iii) OR n1i0O) OR n1i0l);
	ni0lii <= (wire_n1l0O_w_lg_w_lg_nlOOiO1476w1543w(0) AND wire_n1l0O_w_lg_nliliO1544w(0));
	ni0lil <= ((((wire_n1l0O_w_lg_w_lg_nlOOOO1529w1530w(0) AND wire_n1l0O_w_lg_nlOOOi1531w(0)) AND wire_n1l0O_w_lg_nlOOlO1533w(0)) AND nlOOll) AND nlOOli);
	ni0liO <= ((((wire_n1l0O_w_lg_nlOOOO1538w(0) AND wire_n1l0O_w_lg_nlOOOi1531w(0)) AND nlOOlO) AND nlOOll) AND nlOOli);
	ni0lli <= ((wire_n1l0O_w_lg_n111O1524w(0) AND n111l) AND n111i);
	ni0lll <= ((n111O AND n111l) AND n111i);
	ni0llO <= (wire_n1l0O_w_lg_w_lg_w_lg_n11ii897w899w900w(0) AND wire_n1l0O_w_lg_n110i1516w(0));
	ni0lOi <= (((wire_n1l0O_w_lg_n11ii897w(0) AND n110O) AND n110l) AND n110i);
	ni0lOl <= (((n11ii AND n110O) AND n110l) AND n110i);
	ni0lOO <= (wire_n1l0O_w_lg_w_lg_w_lg_w_lg_n11ii897w899w900w901w(0) OR wire_n1l0O_w_lg_w_lg_w_lg_n11ii902w903w904w(0));
	ni0O0i <= (wire_n1l0O_w_lg_w_lg_w_lg_w1501w1502w1503w1504w(0) AND n11il);
	ni0O0l <= ((((((wire_n1l0O_w_lg_w_lg_w_lg_n101i1480w1482w1483w(0) AND wire_n1l0O_w_lg_n11Oi1484w(0)) AND wire_n1l0O_w_lg_n11lO1486w(0)) AND wire_n1l0O_w_lg_n11ll1488w(0)) AND wire_n1l0O_w_lg_n11li1490w(0)) AND wire_n1l0O_w_lg_n11iO1492w(0)) AND wire_n1l0O_w_lg_n11il1494w(0));
	ni0O0O <= (wire_n1l0O_w_lg_w_lg_w_lg_w1501w1502w1503w1504w(0) AND wire_n1l0O_w_lg_n11il1494w(0));
	ni0O1i <= (wire_n1l0O_w_lg_w_lg_w1510w1511w1512w(0) AND n11il);
	ni0O1l <= (wire_n1l0O_w_lg_w_lg_w1510w1511w1512w(0) AND wire_n1l0O_w_lg_n11il1494w(0));
	ni0O1O <= ((((((wire_n1l0O_w_lg_w_lg_w_lg_n101i1480w1482w1483w(0) AND wire_n1l0O_w_lg_n11Oi1484w(0)) AND wire_n1l0O_w_lg_n11lO1486w(0)) AND wire_n1l0O_w_lg_n11ll1488w(0)) AND wire_n1l0O_w_lg_n11li1490w(0)) AND wire_n1l0O_w_lg_n11iO1492w(0)) AND n11il);
	ni0Oii <= ((NOT rcxpat_chnl_sel(0)) AND wire_w_lg_w_rcxpat_chnl_sel_range757w758w(0));
	ni0Oil <= ((wire_n1l0O_w_lg_nlOOiO1476w(0) AND wire_n1l0O_w_lg_nlOOil1477w(0)) AND nliliO);
	ni0OiO <= (ni0Oll OR ni0Oli);
	ni0Oli <= ((NOT rcxpat_chnl_sel(0)) AND rcxpat_chnl_sel(1));
	ni0Oll <= wire_w_lg_w_rcxpat_chnl_sel_range755w760w(0);
	ni0OlO <= ((((n1lii OR n1iiO) OR n1iii) OR n1i0O) OR n1i0l);
	ni0OOi <= ((((((n1liO OR n1l0l) OR n1l0i) OR n1l1O) OR n1ill) OR n1ili) OR n1i0l);
	ni0OOl <= ((((((n1liO OR n1l0l) OR n1l1O) OR n1l1l) OR n1ili) OR n1i0O) OR n1i0l);
	ni0OOO <= (((((((((((((((((wire_nliiO_w_lg_w_lg_nlili109w110w(0) OR nli0i) OR nli1O) OR nli1l) OR nli1i) OR nl0OO) OR nl0Ol) OR nl0Oi) OR nl0lO) OR nl0ll) OR nl0li) OR nl0iO) OR nl0il) OR nl0ii) OR nl00O) OR nl00l) OR nl00i) OR nl01O);
	ni1lll <= ((((((nli11O OR nl0OOi) OR nl0Oll) OR nl0OiO) OR nl0Oii) OR nl0O0l) OR nl0O1O);
	ni1llO <= (((((((((nli11O OR nli11i) OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0O) OR nl0O0i);
	ni1lOi <= (((((((((nli11O OR nli11i) OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0O) OR nl0O1O);
	ni1lOl <= ((((((((((nli11i OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0O) OR nl0O0l) OR nl0O0i) OR nl0O1O);
	ni1lOO <= ((((((((((nli11i OR nl0OOl) OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0O) OR nl0O0i) OR nl0O1O);
	ni1O0i <= ((((((nl0Oli OR nl0OiO) OR nl0Oii) OR nl0O0O) OR nl0O0l) OR nl0O0i) OR nl0O1O);
	ni1O0l <= ((((nli11O OR nli11i) OR nl0OlO) OR nl0Oll) OR nl0Oil);
	ni1O0O <= (((((((nli11i OR nl0OOl) OR nl0Oil) OR nl0Oii) OR nl0O0O) OR nl0O0l) OR nl0O0i) OR nl0O1O);
	ni1O1i <= (((((((((((nli11i OR nl0OOl) OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0O) OR nl0O0l) OR nl0O0i) OR nl0O1O);
	ni1O1l <= (((((((nli11i OR nl0OOl) OR nl0Oll) OR nl0OiO) OR nl0O0O) OR nl0O0l) OR nl0O0i) OR nl0O1O);
	ni1O1O <= ((((nli11O OR nl0OlO) OR nl0Oli) OR nl0Oil) OR nl0Oii);
	ni1Oii <= ((((nli11O OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO);
	ni1Oil <= (((((((((nli11O OR nli11i) OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0l) OR nl0O1O);
	ni1OiO <= ((((((((((nli11O OR nli11i) OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0l) OR nl0O0i) OR nl0O1O);
	ni1Oli <= ((((((nli11O OR nl0OOl) OR nl0Oll) OR nl0OiO) OR nl0Oii) OR nl0O0l) OR nl0O1O);
	ni1Oll <= ((((((nli11O OR nl0Oll) OR nl0OiO) OR nl0Oii) OR nl0O0O) OR nl0O0l) OR nl0O1O);
	ni1OlO <= (((((nli11O OR nl0Oll) OR nl0OiO) OR nl0Oii) OR nl0O0l) OR nl0O1O);
	ni1OOi <= ((((((nli11O OR nl0Oll) OR nl0OiO) OR nl0Oil) OR nl0Oii) OR nl0O0l) OR nl0O1O);
	ni1OOl <= (((((((nli11O OR nli11i) OR nl0OlO) OR nl0Oll) OR nl0OiO) OR nl0Oii) OR nl0O0l) OR nl0O1O);
	ni1OOO <= (((((((nli11O OR nl0OlO) OR nl0Oll) OR nl0Oli) OR nl0OiO) OR nl0Oii) OR nl0O0l) OR nl0O1O);
	nii00l <= ((((((((wire_nliiO_w_lg_w188w189w(0) OR nl0Ol) OR nl0Oi) OR nl0lO) OR nl0li) OR nl0il) OR nl01O) OR nl01i) OR nl1OO);
	nii01i <= ((((((((((((((((wire_nliiO_w_lg_w_lg_w_lg_nlili109w184w185w(0) OR nli1O) OR nli1i) OR nl0Ol) OR nl0Oi) OR nl0lO) OR nl0li) OR nl0iO) OR nl0il) OR nl0ii) OR nl00O) OR nl00l) OR nl00i) OR nl01O) OR nl01l) OR nl01i) OR nl1OO);
	nii01l <= (wire_nliiO_w262w(0) OR (NOT (nii01O42 XOR nii01O41)));
	nii0ii <= (wire_nliiO_w223w(0) OR (NOT (nii0il38 XOR nii0il37)));
	nii0ll <= (wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w194w195w196w197w198w199w(0) OR (NOT (nii0lO34 XOR nii0lO33)));
	nii0Ol <= (((((((((((((wire_nliiO_w_lg_w_lg_w_lg_nlili160w161w162w(0) OR nl0OO) OR nl0Ol) OR nl0Oi) OR nl0lO) OR nl0li) OR nl0il) OR nl00O) OR nl00l) OR nl00i) OR nl01O) OR nl01l) OR nl01i) OR nl1OO);
	nii10i <= ((((((wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w188w189w190w191w192w193w(0) OR nl0ll) OR nl0li) OR nl0iO) OR nl0il) OR nl01i) OR nl1OO);
	nii10l <= ((((((((((wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w188w189w190w191w192w193w(0) OR nl0ll) OR nl0li) OR nl0ii) OR nl00O) OR nl00l) OR nl00i) OR nl01O) OR nl01l) OR nl01i) OR nl1OO);
	nii10O <= ((((((((((wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w188w189w190w191w192w193w(0) OR nl0iO) OR nl0il) OR nl0ii) OR nl00O) OR nl00l) OR nl00i) OR nl01O) OR nl01l) OR nl01i) OR nl1OO);
	nii11i <= (((((((wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w188w189w190w191w192w193w(0) OR nl0ll) OR nl0li) OR nl0iO) OR nl0il) OR nl01O) OR nl01i) OR nl1OO);
	nii11l <= ((((((((((wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w188w189w190w191w192w193w(0) OR nl0ll) OR nl0li) OR nl0iO) OR nl0il) OR nl0ii) OR nl00O) OR nl00l) OR nl00i) OR nl01O) OR nl01l);
	nii11O <= ((((((((((wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w188w189w190w191w192w193w(0) OR nl0ll) OR nl0li) OR nl0iO) OR nl0il) OR nl0ii) OR nl00O) OR nl00l) OR nl00i) OR nl01O) OR nl1OO);
	nii1ii <= ((((((((((((wire_nliiO_w_lg_w_lg_w_lg_w188w189w190w191w(0) OR nl0ll) OR nl0li) OR nl0iO) OR nl0il) OR nl0ii) OR nl00O) OR nl00l) OR nl00i) OR nl01O) OR nl01l) OR nl01i) OR nl1OO);
	nii1il <= ((((((((((((((wire_nliiO_w_lg_w188w189w(0) OR nl0Oi) OR nl0lO) OR nl0ll) OR nl0li) OR nl0iO) OR nl0il) OR nl0ii) OR nl00O) OR nl00l) OR nl00i) OR nl01O) OR nl01l) OR nl01i) OR nl1OO);
	nii1iO <= ((((((((((((((((wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_nlili109w184w185w186w187w(0) OR nl0OO) OR nl0Ol) OR nl0Oi) OR nl0lO) OR nl0ll) OR nl0li) OR nl0iO) OR nl0il) OR nl0ii) OR nl00O) OR nl00l) OR nl00i) OR nl01O) OR nl01l) OR nl01i) OR nl1OO);
	nii1li <= ((((((((((((((((((wire_nliiO_w_lg_w_lg_w_lg_nlili109w184w185w(0) OR nli1l) OR nli1i) OR nl0OO) OR nl0Ol) OR nl0Oi) OR nl0lO) OR nl0ll) OR nl0li) OR nl0iO) OR nl0il) OR nl0ii) OR nl00O) OR nl00l) OR nl00i) OR nl01O) OR nl01l) OR nl01i) OR nl1OO);
	nii1ll <= ((((((((((((((((((nlili OR nli0i) OR nli1O) OR nli1l) OR nli1i) OR nl0OO) OR nl0Ol) OR nl0Oi) OR nl0lO) OR nl0ll) OR nl0li) OR nl0ii) OR nl00O) OR nl00l) OR nl00i) OR nl01O) OR nl01l) OR nl01i) OR nl1OO);
	nii1lO <= ((((((((((((((((((nli0l OR nli0i) OR nli1O) OR nli1l) OR nli1i) OR nl0OO) OR nl0Ol) OR nl0Oi) OR nl0lO) OR nl0ll) OR nl0li) OR nl0iO) OR nl0il) OR nl0ii) OR nl00O) OR nl00l) OR nl00i) OR nl01O) OR nl01i);
	nii1Oi <= ((((((((((((((((((((nliil OR nli0O) OR nli0l) OR nli0i) OR nli1O) OR nli1l) OR nli1i) OR nl0OO) OR nl0Ol) OR nl0Oi) OR nl0lO) OR nl0ll) OR nl0li) OR nl0iO) OR nl0il) OR nl0ii) OR nl00O) OR nl00l) OR nl00i) OR nl01O) OR nl01i);
	nii1Ol <= (((((((((((wire_nliiO_w_lg_w_lg_w_lg_w_lg_nlili160w161w162w254w(0) OR nl0Oi) OR nl0lO) OR nl0li) OR nl0il) OR nl00O) OR nl00l) OR nl00i) OR nl01O) OR nl01l) OR nl01i) OR nl1OO);
	niii0l <= (wire_nliiO_w_lg_w_lg_w120w121w122w(0) OR (NOT (niii0O22 XOR niii0O21)));
	niiiil <= ((niO0O AND wire_nliii_w_lg_niO0l763w(0)) AND n0lOi);
	niiiiO <= ((niO0O AND niO0l) AND wire_nliii_w_lg_n0lOi772w(0));
	niiili <= (wire_nliii_w_lg_w_lg_niO0O762w771w(0) AND wire_nliii_w_lg_n0lOi772w(0));
	niiill <= (wire_nliii_w_lg_w_lg_w_lg_niOll766w767w768w(0) AND wire_nliii_w_lg_niOii769w(0));
	niiilO <= ((NOT rcxpat_chnl_sel(0)) AND wire_w_lg_w_rcxpat_chnl_sel_range757w758w(0));
	niiiOi <= ((wire_nliii_w_lg_niO0O762w(0) AND wire_nliii_w_lg_niO0l763w(0)) AND n0lOi);
	niiiOl <= (niil1i OR niiiOO);
	niiiOO <= ((NOT rcxpat_chnl_sel(0)) AND rcxpat_chnl_sel(1));
	niil0i <= (((((((((nliil OR nli0i) OR nli1O) OR nli1l) OR nli1i) OR nl0OO) OR nl0Ol) OR nl0Oi) OR nl0ll) OR nl0li);
	niil0l <= ((((((((wire_nliiO_w_lg_nlili109w(0) OR nli1l) OR nl0OO) OR nl0Oi) OR nl0li) OR nl0il) OR nl0ii) OR nl00O) OR nl00i);
	niil0O <= (((((((((nlili OR nli0O) OR nli0l) OR nli1O) OR nli1l) OR nli1i) OR nl0Oi) OR nl0lO) OR nl0iO) OR nl00l);
	niil1i <= wire_w_lg_w_rcxpat_chnl_sel_range755w760w(0);
	niil1l <= ((((nliil OR nl01O) OR nl01l) OR nl01i) OR nl1OO);
	niil1O <= (((((((nlili OR nli0i) OR nl0lO) OR nl0ll) OR nl0ii) OR nl01l) OR nl01i) OR nl1OO);
	niilii <= (((((nlili OR nli1l) OR nli1i) OR nl0OO) OR nl0Ol) OR nl00l);
	niilil <= (((((((((((nlili OR nli0O) OR nli0l) OR nli1O) OR nli1i) OR nl0Ol) OR nl0lO) OR nl0ll) OR nl0il) OR nl00l) OR nl00i) OR nl1OO);
	niiliO <= (((((((((nlili OR nli0i) OR nli1l) OR nl0Ol) OR nl0Oi) OR nl0lO) OR nl0iO) OR nl00l) OR nl01l) OR nl1OO);
	niilli <= (((((((((nliil OR nli0l) OR nli0i) OR nli1O) OR nl0Ol) OR nl0Oi) OR nl0li) OR nl0ii) OR nl01O) OR nl01l);
	niilll <= '1';
	niilOl <= '0';
	niiOil <= (((NOT rbist_sel(0)) AND wire_w_lg_w_rbist_sel_range14w15w(0)) AND (niiO0O8 XOR niiO0O7));
	niiOiO <= (wire_w_lg_w_rbist_sel_range12w20w(0) AND (niiO0i10 XOR niiO0i9));
	niiOli <= (((NOT rbist_sel(0)) AND rbist_sel(1)) AND (niiO1l12 XOR niiO1l11));
	niiOOi <= (wire_w_lg_w_lg_w_lg_rpmadwidth_tx2w5w6w(0) OR ((rpmadwidth_tx AND rpma_doublewidth_tx) AND (niiOOl4 XOR niiOOl3)));
	wire_w_rbist_sel_range12w(0) <= rbist_sel(0);
	wire_w_rbist_sel_range14w(0) <= rbist_sel(1);
	wire_w_rcxpat_chnl_sel_range755w(0) <= rcxpat_chnl_sel(0);
	wire_w_rcxpat_chnl_sel_range757w(0) <= rcxpat_chnl_sel(1);
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN ni001l45 <= ni001l46;
		END IF;
		if (now = 0 ns) then
			ni001l45 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN ni001l46 <= ni001l45;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nii00O39 <= nii00O40;
		END IF;
		if (now = 0 ns) then
			nii00O39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nii00O40 <= nii00O39;
		END IF;
	END PROCESS;
	wire_nii00O40_w_lg_w_lg_q228w230w(0) <= wire_nii00O40_w_lg_q228w(0) AND wire_w_lg_nii0ii229w(0);
	wire_nii00O40_w_lg_q228w(0) <= nii00O40 XOR nii00O39;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nii01O41 <= nii01O42;
		END IF;
		if (now = 0 ns) then
			nii01O41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nii01O42 <= nii01O41;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nii0il37 <= nii0il38;
		END IF;
		if (now = 0 ns) then
			nii0il37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nii0il38 <= nii0il37;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nii0li35 <= nii0li36;
		END IF;
		if (now = 0 ns) then
			nii0li35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nii0li36 <= nii0li35;
		END IF;
	END PROCESS;
	wire_nii0li36_w_lg_w_lg_q207w208w(0) <= wire_nii0li36_w_lg_q207w(0) AND nii0ll;
	wire_nii0li36_w_lg_q207w(0) <= nii0li36 XOR nii0li35;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nii0lO33 <= nii0lO34;
		END IF;
		if (now = 0 ns) then
			nii0lO33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nii0lO34 <= nii0lO33;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nii0OO31 <= nii0OO32;
		END IF;
		if (now = 0 ns) then
			nii0OO31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nii0OO32 <= nii0OO31;
		END IF;
	END PROCESS;
	wire_nii0OO32_w_lg_w_lg_q155w156w(0) <= wire_nii0OO32_w_lg_q155w(0) AND wire_nilli_dataout;
	wire_nii0OO32_w_lg_q155w(0) <= nii0OO32 XOR nii0OO31;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nii1OO43 <= nii1OO44;
		END IF;
		if (now = 0 ns) then
			nii1OO43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nii1OO44 <= nii1OO43;
		END IF;
	END PROCESS;
	wire_nii1OO44_w_lg_w_lg_q295w296w(0) <= wire_nii1OO44_w_lg_q295w(0) AND niiOOi;
	wire_nii1OO44_w_lg_q295w(0) <= nii1OO44 XOR nii1OO43;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niii0i23 <= niii0i24;
		END IF;
		if (now = 0 ns) then
			niii0i23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niii0i24 <= niii0i23;
		END IF;
	END PROCESS;
	wire_niii0i24_w_lg_w_lg_q129w130w(0) <= wire_niii0i24_w_lg_q129w(0) AND nl00i;
	wire_niii0i24_w_lg_q129w(0) <= niii0i24 XOR niii0i23;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niii0O21 <= niii0O22;
		END IF;
		if (now = 0 ns) then
			niii0O21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niii0O22 <= niii0O21;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niii1i29 <= niii1i30;
		END IF;
		if (now = 0 ns) then
			niii1i29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niii1i30 <= niii1i29;
		END IF;
	END PROCESS;
	wire_niii1i30_w_lg_w_lg_q152w153w(0) <= wire_niii1i30_w_lg_q152w(0) AND niiOOi;
	wire_niii1i30_w_lg_q152w(0) <= niii1i30 XOR niii1i29;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niii1l27 <= niii1l28;
		END IF;
		if (now = 0 ns) then
			niii1l27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niii1l28 <= niii1l27;
		END IF;
	END PROCESS;
	wire_niii1l28_w_lg_w_lg_q141w142w(0) <= wire_niii1l28_w_lg_q141w(0) AND niii0l;
	wire_niii1l28_w_lg_q141w(0) <= niii1l28 XOR niii1l27;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niii1O25 <= niii1O26;
		END IF;
		if (now = 0 ns) then
			niii1O25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niii1O26 <= niii1O25;
		END IF;
	END PROCESS;
	wire_niii1O26_w_lg_w_lg_q132w133w(0) <= wire_niii1O26_w_lg_q132w(0) AND nl00l;
	wire_niii1O26_w_lg_q132w(0) <= niii1O26 XOR niii1O25;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niillO19 <= niillO20;
		END IF;
		if (now = 0 ns) then
			niillO19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niillO20 <= niillO19;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niilOi17 <= niilOi18;
		END IF;
		if (now = 0 ns) then
			niilOi17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niilOi18 <= niilOi17;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niilOO15 <= niilOO16;
		END IF;
		if (now = 0 ns) then
			niilOO15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niilOO16 <= niilOO15;
		END IF;
	END PROCESS;
	wire_niilOO16_w_lg_w_lg_q78w79w(0) <= wire_niilOO16_w_lg_q78w(0) AND niO0O;
	wire_niilOO16_w_lg_q78w(0) <= niilOO16 XOR niilOO15;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niiO0i10 <= niiO0i9;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niiO0i9 <= niiO0i10;
		END IF;
		if (now = 0 ns) then
			niiO0i9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niiO0O7 <= niiO0O8;
		END IF;
		if (now = 0 ns) then
			niiO0O7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niiO0O8 <= niiO0O7;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niiO1i13 <= niiO1i14;
		END IF;
		if (now = 0 ns) then
			niiO1i13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niiO1i14 <= niiO1i13;
		END IF;
	END PROCESS;
	wire_niiO1i14_w_lg_w_lg_q53w54w(0) <= wire_niiO1i14_w_lg_q53w(0) AND niOil;
	wire_niiO1i14_w_lg_q53w(0) <= niiO1i14 XOR niiO1i13;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niiO1l11 <= niiO1l12;
		END IF;
		if (now = 0 ns) then
			niiO1l11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niiO1l12 <= niiO1l11;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niiOll5 <= niiOll6;
		END IF;
		if (now = 0 ns) then
			niiOll5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niiOll6 <= niiOll5;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niiOOl3 <= niiOOl4;
		END IF;
		if (now = 0 ns) then
			niiOOl3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niiOOl4 <= niiOOl3;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nil11i1 <= nil11i2;
		END IF;
		if (now = 0 ns) then
			nil11i1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nil11i2 <= nil11i1;
		END IF;
	END PROCESS;
	wire_nil11i2_w_lg_q4w(0) <= nil11i2 XOR nil11i1;
	PROCESS (tx_clk, soft_reset)
	BEGIN
		IF (soft_reset = '1') THEN
				n100i <= '0';
				n100l <= '0';
				n100O <= '0';
				n101i <= '0';
				n101l <= '0';
				n101O <= '0';
				n10ii <= '0';
				n10il <= '0';
				n10iO <= '0';
				n10li <= '0';
				n10ll <= '0';
				n10lO <= '0';
				n10Oi <= '0';
				n10Ol <= '0';
				n10OO <= '0';
				n110i <= '0';
				n110l <= '0';
				n110O <= '0';
				n111i <= '0';
				n111l <= '0';
				n111O <= '0';
				n11ii <= '0';
				n11il <= '0';
				n11iO <= '0';
				n11li <= '0';
				n11ll <= '0';
				n11lO <= '0';
				n11Oi <= '0';
				n11Ol <= '0';
				n11OO <= '0';
				n1i0i <= '0';
				n1i0l <= '0';
				n1i0O <= '0';
				n1i1i <= '0';
				n1i1l <= '0';
				n1i1O <= '0';
				n1iii <= '0';
				n1iil <= '0';
				n1iiO <= '0';
				n1ili <= '0';
				n1ill <= '0';
				n1ilO <= '0';
				n1iOi <= '0';
				n1iOl <= '0';
				n1iOO <= '0';
				n1l0i <= '0';
				n1l0l <= '0';
				n1l1i <= '0';
				n1l1l <= '0';
				n1l1O <= '0';
				n1lii <= '0';
				nliliO <= '0';
				nlOOil <= '0';
				nlOOiO <= '0';
				nlOOli <= '0';
				nlOOll <= '0';
				nlOOlO <= '0';
				nlOOOi <= '0';
				nlOOOl <= '0';
				nlOOOO <= '0';
		ELSIF (tx_clk = '1' AND tx_clk'event) THEN
			IF (wire_nll_dataout = '1') THEN
				n100i <= wire_nll01O_o;
				n100l <= wire_nll00O_o;
				n100O <= wire_nll0iO_o;
				n101i <= wire_n001O_dataout;
				n101l <= ni0OlO;
				n101O <= wire_nliO1i_o;
				n10ii <= wire_nll0lO_o;
				n10il <= wire_nll0OO_o;
				n10iO <= wire_w_lg_ni0OOi889w(0);
				n10li <= wire_nlli0i_o;
				n10ll <= wire_w_lg_ni0OOl888w(0);
				n10lO <= wire_nlliil_o;
				n10Oi <= wire_nllili_o;
				n10Ol <= wire_nllilO_o;
				n10OO <= wire_nlliOi_o;
				n110i <= wire_n011i_dataout;
				n110l <= wire_n011l_dataout;
				n110O <= wire_n011O_dataout;
				n111i <= wire_n1OlO_dataout;
				n111l <= wire_n1OOi_dataout;
				n111O <= wire_n1OOl_dataout;
				n11ii <= wire_n010i_dataout;
				n11il <= wire_n01li_dataout;
				n11iO <= wire_n01ll_dataout;
				n11li <= wire_n01lO_dataout;
				n11ll <= wire_n01Oi_dataout;
				n11lO <= wire_n01Ol_dataout;
				n11Oi <= wire_n01OO_dataout;
				n11Ol <= wire_n001i_dataout;
				n11OO <= wire_n001l_dataout;
				n1i0i <= wire_nlll0O_o;
				n1i0l <= wire_nliO1O_o;
				n1i0O <= wire_nliO0l_o;
				n1i1i <= wire_nlliOO_o;
				n1i1l <= wire_nlll1l_o;
				n1i1O <= wire_nlll0i_o;
				n1iii <= wire_nliOii_o;
				n1iil <= wire_nliOli_o;
				n1iiO <= wire_nliOll_dataout;
				n1ili <= wire_nliOlO_o;
				n1ill <= wire_nliOOi_o;
				n1ilO <= wire_nliOOl_o;
				n1iOi <= wire_nll11i_dataout;
				n1iOl <= wire_nll11l_o;
				n1iOO <= wire_nll10i_o;
				n1l0i <= wire_nll1Oi_dataout;
				n1l0l <= wire_nll1Ol_o;
				n1l1i <= wire_nll10O_o;
				n1l1l <= wire_nll1il_o;
				n1l1O <= wire_nll1ll_o;
				n1lii <= wire_nll01i_o;
				nliliO <= wire_n1lli_dataout;
				nlOOil <= wire_n1lll_dataout;
				nlOOiO <= wire_n1llO_dataout;
				nlOOli <= wire_n1lOl_dataout;
				nlOOll <= wire_n1lOO_dataout;
				nlOOlO <= wire_n1O1i_dataout;
				nlOOOi <= wire_n1O1l_dataout;
				nlOOOl <= wire_n1O1O_dataout;
				nlOOOO <= wire_n1O0i_dataout;
			END IF;
		END IF;
	END PROCESS;
	wire_n1l0O_w_lg_w_lg_w_lg_w1501w1502w1503w1504w(0) <= wire_n1l0O_w_lg_w_lg_w1501w1502w1503w(0) AND n11iO;
	wire_n1l0O_w_lg_w_lg_w1510w1511w1512w(0) <= wire_n1l0O_w_lg_w1510w1511w(0) AND n11iO;
	wire_n1l0O_w_lg_w_lg_w1501w1502w1503w(0) <= wire_n1l0O_w_lg_w1501w1502w(0) AND wire_n1l0O_w_lg_n11li1490w(0);
	wire_n1l0O_w_lg_w1510w1511w(0) <= wire_n1l0O_w1510w(0) AND n11li;
	wire_n1l0O_w_lg_w1501w1502w(0) <= wire_n1l0O_w1501w(0) AND wire_n1l0O_w_lg_n11ll1488w(0);
	wire_n1l0O_w1510w(0) <= wire_n1l0O_w_lg_w_lg_w_lg_w_lg_n101i1506w1507w1508w1509w(0) AND wire_n1l0O_w_lg_n11ll1488w(0);
	wire_n1l0O_w1501w(0) <= wire_n1l0O_w_lg_w_lg_w_lg_w_lg_n101i1480w1497w1499w1500w(0) AND wire_n1l0O_w_lg_n11lO1486w(0);
	wire_n1l0O_w_lg_w_lg_w_lg_w_lg_n101i1506w1507w1508w1509w(0) <= wire_n1l0O_w_lg_w_lg_w_lg_n101i1506w1507w1508w(0) AND wire_n1l0O_w_lg_n11lO1486w(0);
	wire_n1l0O_w_lg_w_lg_w_lg_w_lg_n101i1480w1497w1499w1500w(0) <= wire_n1l0O_w_lg_w_lg_w_lg_n101i1480w1497w1499w(0) AND wire_n1l0O_w_lg_n11Oi1484w(0);
	wire_n1l0O_w_lg_w_lg_w_lg_w_lg_n11ii897w899w900w901w(0) <= wire_n1l0O_w_lg_w_lg_w_lg_n11ii897w899w900w(0) AND n110i;
	wire_n1l0O_w_lg_w_lg_w_lg_n101i1506w1507w1508w(0) <= wire_n1l0O_w_lg_w_lg_n101i1506w1507w(0) AND wire_n1l0O_w_lg_n11Oi1484w(0);
	wire_n1l0O_w_lg_w_lg_w_lg_n11ii902w903w904w(0) <= wire_n1l0O_w_lg_w_lg_n11ii902w903w(0) AND n110i;
	wire_n1l0O_w_lg_w_lg_w_lg_n101i1480w1482w1483w(0) <= wire_n1l0O_w_lg_w_lg_n101i1480w1482w(0) AND n11Ol;
	wire_n1l0O_w_lg_w_lg_w_lg_n101i1480w1497w1499w(0) <= wire_n1l0O_w_lg_w_lg_n101i1480w1497w(0) AND wire_n1l0O_w_lg_n11Ol1498w(0);
	wire_n1l0O_w_lg_w_lg_w_lg_n11ii897w899w900w(0) <= wire_n1l0O_w_lg_w_lg_n11ii897w899w(0) AND n110l;
	wire_n1l0O_w_lg_w_lg_n101i1506w1507w(0) <= wire_n1l0O_w_lg_n101i1506w(0) AND wire_n1l0O_w_lg_n11Ol1498w(0);
	wire_n1l0O_w_lg_w_lg_n11ii902w903w(0) <= wire_n1l0O_w_lg_n11ii902w(0) AND n110l;
	wire_n1l0O_w_lg_w_lg_n101i1480w1482w(0) <= wire_n1l0O_w_lg_n101i1480w(0) AND wire_n1l0O_w_lg_n11OO1481w(0);
	wire_n1l0O_w_lg_w_lg_n101i1480w1497w(0) <= wire_n1l0O_w_lg_n101i1480w(0) AND n11OO;
	wire_n1l0O_w_lg_w_lg_n11ii897w899w(0) <= wire_n1l0O_w_lg_n11ii897w(0) AND wire_n1l0O_w_lg_n110O898w(0);
	wire_n1l0O_w_lg_w_lg_nlOOiO1476w1543w(0) <= wire_n1l0O_w_lg_nlOOiO1476w(0) AND nlOOil;
	wire_n1l0O_w_lg_w_lg_nlOOOO1529w1530w(0) <= wire_n1l0O_w_lg_nlOOOO1529w(0) AND nlOOOl;
	wire_n1l0O_w_lg_n101i1506w(0) <= n101i AND wire_n1l0O_w_lg_n11OO1481w(0);
	wire_n1l0O_w_lg_n11ii902w(0) <= n11ii AND wire_n1l0O_w_lg_n110O898w(0);
	wire_n1l0O_w_lg_nlOOOO1538w(0) <= nlOOOO AND wire_n1l0O_w_lg_nlOOOl1537w(0);
	wire_n1l0O_w_lg_n101i1480w(0) <= NOT n101i;
	wire_n1l0O_w_lg_n110i1516w(0) <= NOT n110i;
	wire_n1l0O_w_lg_n110O898w(0) <= NOT n110O;
	wire_n1l0O_w_lg_n111O1524w(0) <= NOT n111O;
	wire_n1l0O_w_lg_n11ii897w(0) <= NOT n11ii;
	wire_n1l0O_w_lg_n11il1494w(0) <= NOT n11il;
	wire_n1l0O_w_lg_n11iO1492w(0) <= NOT n11iO;
	wire_n1l0O_w_lg_n11li1490w(0) <= NOT n11li;
	wire_n1l0O_w_lg_n11ll1488w(0) <= NOT n11ll;
	wire_n1l0O_w_lg_n11lO1486w(0) <= NOT n11lO;
	wire_n1l0O_w_lg_n11Oi1484w(0) <= NOT n11Oi;
	wire_n1l0O_w_lg_n11Ol1498w(0) <= NOT n11Ol;
	wire_n1l0O_w_lg_n11OO1481w(0) <= NOT n11OO;
	wire_n1l0O_w_lg_nliliO1544w(0) <= NOT nliliO;
	wire_n1l0O_w_lg_nlOOil1477w(0) <= NOT nlOOil;
	wire_n1l0O_w_lg_nlOOiO1476w(0) <= NOT nlOOiO;
	wire_n1l0O_w_lg_nlOOlO1533w(0) <= NOT nlOOlO;
	wire_n1l0O_w_lg_nlOOOi1531w(0) <= NOT nlOOOi;
	wire_n1l0O_w_lg_nlOOOl1537w(0) <= NOT nlOOOl;
	wire_n1l0O_w_lg_nlOOOO1529w(0) <= NOT nlOOOO;
	wire_n1l0O_w_lg_w_lg_w_lg_n1ill1401w1402w1403w(0) <= wire_n1l0O_w_lg_w_lg_n1ill1401w1402w(0) OR n1iil;
	wire_n1l0O_w_lg_w_lg_n1ill1401w1402w(0) <= wire_n1l0O_w_lg_n1ill1401w(0) OR n1iiO;
	wire_n1l0O_w_lg_n1ill1401w(0) <= n1ill OR n1ili;
	wire_n1l0O_w_lg_n1l0i1211w(0) <= n1l0i OR n1l1O;
	PROCESS (tx_clk, soft_reset)
	BEGIN
		IF (soft_reset = '1') THEN
				n1liO <= '1';
		ELSIF (tx_clk = '1' AND tx_clk'event) THEN
			IF (wire_nll_dataout = '1') THEN
				n1liO <= niilOl;
			END IF;
		END IF;
		if (now = 0 ns) then
			n1liO <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_n1lil_w_lg_w_lg_w_lg_n1liO1051w1092w1093w(0) <= wire_n1lil_w_lg_w_lg_n1liO1051w1092w(0) OR n1iil;
	wire_n1lil_w_lg_w_lg_n1liO1051w1092w(0) <= wire_n1lil_w_lg_n1liO1051w(0) OR n1iOO;
	wire_n1lil_w_lg_n1liO1051w(0) <= n1liO OR n1l1O;
	PROCESS (tx_clk, wire_nl0OOO_PRN, soft_reset)
	BEGIN
		IF (wire_nl0OOO_PRN = '0') THEN
				nl00il <= '1';
				nl00iO <= '1';
				nl00li <= '1';
				nl00ll <= '1';
				nl00lO <= '1';
				nl00Oi <= '1';
				nl00Ol <= '1';
				nl00OO <= '1';
				nl0i0i <= '1';
				nl0i0l <= '1';
				nl0i0O <= '1';
				nl0i1i <= '1';
				nl0i1l <= '1';
				nl0i1O <= '1';
				nl0iii <= '1';
				nl0iil <= '1';
				nl0iiO <= '1';
				nl0ili <= '1';
				nl0ill <= '1';
				nl0ilO <= '1';
				nl0iOi <= '1';
				nl0iOl <= '1';
				nl0iOO <= '1';
				nl0l0i <= '1';
				nl0l0l <= '1';
				nl0l0O <= '1';
				nl0l1i <= '1';
				nl0l1l <= '1';
				nl0l1O <= '1';
				nl0lii <= '1';
				nl0lil <= '1';
				nl0liO <= '1';
				nl0lli <= '1';
				nl0lll <= '1';
				nl0llO <= '1';
				nl0lOi <= '1';
				nl0lOl <= '1';
				nl0lOO <= '1';
				nl0O0i <= '1';
				nl0O0l <= '1';
				nl0O0O <= '1';
				nl0O1i <= '1';
				nl0O1l <= '1';
				nl0O1O <= '1';
				nl0Oii <= '1';
				nl0Oil <= '1';
				nl0OiO <= '1';
				nl0Oli <= '1';
				nl0Oll <= '1';
				nl0OlO <= '1';
				nl0OOi <= '1';
				nl0OOl <= '1';
				nli11i <= '1';
		ELSIF (soft_reset = '1') THEN
				nl00il <= '0';
				nl00iO <= '0';
				nl00li <= '0';
				nl00ll <= '0';
				nl00lO <= '0';
				nl00Oi <= '0';
				nl00Ol <= '0';
				nl00OO <= '0';
				nl0i0i <= '0';
				nl0i0l <= '0';
				nl0i0O <= '0';
				nl0i1i <= '0';
				nl0i1l <= '0';
				nl0i1O <= '0';
				nl0iii <= '0';
				nl0iil <= '0';
				nl0iiO <= '0';
				nl0ili <= '0';
				nl0ill <= '0';
				nl0ilO <= '0';
				nl0iOi <= '0';
				nl0iOl <= '0';
				nl0iOO <= '0';
				nl0l0i <= '0';
				nl0l0l <= '0';
				nl0l0O <= '0';
				nl0l1i <= '0';
				nl0l1l <= '0';
				nl0l1O <= '0';
				nl0lii <= '0';
				nl0lil <= '0';
				nl0liO <= '0';
				nl0lli <= '0';
				nl0lll <= '0';
				nl0llO <= '0';
				nl0lOi <= '0';
				nl0lOl <= '0';
				nl0lOO <= '0';
				nl0O0i <= '0';
				nl0O0l <= '0';
				nl0O0O <= '0';
				nl0O1i <= '0';
				nl0O1l <= '0';
				nl0O1O <= '0';
				nl0Oii <= '0';
				nl0Oil <= '0';
				nl0OiO <= '0';
				nl0Oli <= '0';
				nl0Oll <= '0';
				nl0OlO <= '0';
				nl0OOi <= '0';
				nl0OOl <= '0';
				nli11i <= '0';
		ELSIF (tx_clk = '1' AND tx_clk'event) THEN
				nl00il <= wire_nli10i_dataout;
				nl00iO <= wire_nli10l_dataout;
				nl00li <= wire_nli10O_dataout;
				nl00ll <= wire_nli1ii_dataout;
				nl00lO <= wire_nli1il_dataout;
				nl00Oi <= wire_nli1iO_dataout;
				nl00Ol <= wire_nli1li_dataout;
				nl00OO <= wire_nli1ll_dataout;
				nl0i0i <= wire_nli1OO_dataout;
				nl0i0l <= wire_nli01i_dataout;
				nl0i0O <= wire_nli01l_dataout;
				nl0i1i <= wire_nli1lO_dataout;
				nl0i1l <= wire_nli1Oi_dataout;
				nl0i1O <= wire_nli1Ol_dataout;
				nl0iii <= wire_nli01O_dataout;
				nl0iil <= wire_nli00i_dataout;
				nl0iiO <= wire_nli00l_dataout;
				nl0ili <= wire_nli00O_dataout;
				nl0ill <= wire_nli0ii_dataout;
				nl0ilO <= wire_nli0il_dataout;
				nl0iOi <= wire_nli0iO_dataout;
				nl0iOl <= wire_nli0li_dataout;
				nl0iOO <= (NOT (nli11O OR nl0OOi));
				nl0l0i <= wire_nil01O_o;
				nl0l0l <= wire_nil00l_o;
				nl0l0O <= wire_nil0il_o;
				nl0l1i <= wire_nil1li_o;
				nl0l1l <= wire_nil1lO_o;
				nl0l1O <= wire_nil1OO_o;
				nl0lii <= wire_nil0li_o;
				nl0lil <= wire_nil0Oi_o;
				nl0liO <= wire_nili1i_o;
				nl0lli <= wire_nili0i_o;
				nl0lll <= wire_nili0O_o;
				nl0llO <= wire_niliil_o;
				nl0lOi <= wire_nilili_o;
				nl0lOl <= wire_nililO_o;
				nl0lOO <= wire_niliOl_o;
				nl0O0i <= wire_nillil_o;
				nl0O0l <= wire_nillli_o;
				nl0O0O <= wire_nilllO_o;
				nl0O1i <= wire_nill1i_o;
				nl0O1l <= wire_nill1O_o;
				nl0O1O <= wire_nill0O_o;
				nl0Oii <= wire_nillOl_o;
				nl0Oil <= wire_nilO1i_o;
				nl0OiO <= wire_nilO1O_o;
				nl0Oli <= wire_nilO0l_o;
				nl0Oll <= wire_nilOii_o;
				nl0OlO <= wire_nilOiO_o;
				nl0OOi <= wire_nilOli_o;
				nl0OOl <= wire_nilOlO_o;
				nli11i <= wire_nilOOl_o;
		END IF;
	END PROCESS;
	wire_nl0OOO_PRN <= (ni001l46 XOR ni001l45);
	wire_nl0OOO_w_lg_w_lg_w_lg_w_lg_nl0iOl2241w2243w2245w2253w(0) <= wire_nl0OOO_w_lg_w_lg_w_lg_nl0iOl2241w2243w2245w(0) AND nl0ill;
	wire_nl0OOO_w_lg_w_lg_w_lg_nl0iOl2241w2243w2245w(0) <= wire_nl0OOO_w_lg_w_lg_nl0iOl2241w2243w(0) AND wire_nl0OOO_w_lg_nl0ilO2244w(0);
	wire_nl0OOO_w_lg_w_lg_nl0iOl2241w2243w(0) <= wire_nl0OOO_w_lg_nl0iOl2241w(0) AND wire_nl0OOO_w_lg_nl0iOi2242w(0);
	wire_nl0OOO_w_lg_nl0iii2259w(0) <= NOT nl0iii;
	wire_nl0OOO_w_lg_nl0iil2257w(0) <= NOT nl0iil;
	wire_nl0OOO_w_lg_nl0iiO2255w(0) <= NOT nl0iiO;
	wire_nl0OOO_w_lg_nl0ili2248w(0) <= NOT nl0ili;
	wire_nl0OOO_w_lg_nl0ill2246w(0) <= NOT nl0ill;
	wire_nl0OOO_w_lg_nl0ilO2244w(0) <= NOT nl0ilO;
	wire_nl0OOO_w_lg_nl0iOi2242w(0) <= NOT nl0iOi;
	wire_nl0OOO_w_lg_nl0iOl2241w(0) <= NOT nl0iOl;
	wire_nl0OOO_w_lg_nl0O0l2201w(0) <= nl0O0l OR nl0O0i;
	wire_nl0OOO_w_lg_nl0O0l2215w(0) <= nl0O0l OR nl0O1O;
	PROCESS (tx_clk, soft_reset)
	BEGIN
		IF (soft_reset = '1') THEN
				nli11O <= '1';
		ELSIF (tx_clk = '1' AND tx_clk'event) THEN
				nli11O <= wire_niO11i_o;
		END IF;
		if (now = 0 ns) then
			nli11O <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nli11l_w_lg_nli11O2169w(0) <= nli11O OR nl0O0l;
	PROCESS (tx_clk, soft_reset)
	BEGIN
		IF (soft_reset = '1') THEN
				n0lOi <= '0';
				niO0l <= '0';
				niO0O <= '0';
				niOii <= '0';
				niOil <= '0';
				niOiO <= '0';
				niOli <= '0';
				niOll <= '0';
				niOlO <= '0';
				niOOi <= '0';
				niOOl <= '0';
				niOOO <= '0';
				nl00i <= '0';
				nl00l <= '0';
				nl00O <= '0';
				nl01i <= '0';
				nl01l <= '0';
				nl01O <= '0';
				nl0ii <= '0';
				nl0il <= '0';
				nl0iO <= '0';
				nl0li <= '0';
				nl0ll <= '0';
				nl0lO <= '0';
				nl0Oi <= '0';
				nl0Ol <= '0';
				nl0OO <= '0';
				nl10i <= '0';
				nl10l <= '0';
				nl10O <= '0';
				nl11i <= '0';
				nl11l <= '0';
				nl11O <= '0';
				nl1ii <= '0';
				nl1il <= '0';
				nl1iO <= '0';
				nl1li <= '0';
				nl1ll <= '0';
				nl1lO <= '0';
				nl1Oi <= '0';
				nl1Ol <= '0';
				nl1OO <= '0';
				nli0i <= '0';
				nli0l <= '0';
				nli0O <= '0';
				nli1i <= '0';
				nli1l <= '0';
				nli1O <= '0';
				nliil <= '0';
		ELSIF (tx_clk = '1' AND tx_clk'event) THEN
			IF (wire_nli_dataout = '1') THEN
				n0lOi <= wire_nlill_dataout;
				niO0l <= wire_nlilO_dataout;
				niO0O <= wire_nliOi_dataout;
				niOii <= wire_nliOO_dataout;
				niOil <= wire_nll1i_dataout;
				niOiO <= wire_nll1l_dataout;
				niOli <= wire_nll1O_dataout;
				niOll <= wire_nll0i_dataout;
				niOlO <= niil1l;
				niOOi <= wire_n0ilO_o;
				niOOl <= wire_w_lg_niil1O100w(0);
				niOOO <= niil0i;
				nl00i <= wire_n0lii_o;
				nl00l <= wire_n0lil_o;
				nl00O <= wire_n0liO_o;
				nl01i <= wire_n0l1i_o;
				nl01l <= wire_n0l1O_o;
				nl01O <= wire_n0l0O_dataout;
				nl0ii <= wire_n0lli_o;
				nl0il <= wire_n0llO_dataout;
				nl0iO <= wire_n0lOl_o;
				nl0li <= wire_n0O1i_dataout;
				nl0ll <= wire_n0O1l_o;
				nl0lO <= wire_n0O0i_dataout;
				nl0Oi <= wire_n0O0l_o;
				nl0Ol <= wire_n0Oii_dataout;
				nl0OO <= wire_n0Oil_o;
				nl10i <= wire_w_lg_niilil96w(0);
				nl10l <= wire_w_lg_niiliO95w(0);
				nl10O <= niilli;
				nl11i <= wire_w_lg_niil0l99w(0);
				nl11l <= wire_w_lg_niil0O98w(0);
				nl11O <= wire_w_lg_niilii97w(0);
				nl1ii <= wire_ni1Ol_o;
				nl1il <= wire_ni01i_o;
				nl1iO <= wire_ni01O_o;
				nl1li <= wire_ni00l_o;
				nl1ll <= wire_ni0ii_o;
				nl1lO <= wire_ni0iO_o;
				nl1Oi <= wire_ni0ll_o;
				nl1Ol <= wire_ni0Oi_o;
				nl1OO <= wire_n0iOl_o;
				nli0i <= wire_n0OOl_o;
				nli0l <= wire_ni11i_dataout;
				nli0O <= wire_ni11l_o;
				nli1i <= wire_n0Oli_dataout;
				nli1l <= wire_n0Oll_o;
				nli1O <= wire_n0OOi_dataout;
				nliil <= wire_ni10i_o;
			END IF;
		END IF;
	END PROCESS;
	wire_nliii_w_lg_w_lg_w_lg_niOll766w767w768w(0) <= wire_nliii_w_lg_w_lg_niOll766w767w(0) AND niOil;
	wire_nliii_w_lg_w_lg_niOll766w767w(0) <= wire_nliii_w_lg_niOll766w(0) AND niOiO;
	wire_nliii_w_lg_w_lg_niO0O762w771w(0) <= wire_nliii_w_lg_niO0O762w(0) AND niO0l;
	wire_nliii_w_lg_niOll766w(0) <= niOll AND niOli;
	wire_nliii_w_lg_n0lOi772w(0) <= NOT n0lOi;
	wire_nliii_w_lg_niO0l763w(0) <= NOT niO0l;
	wire_nliii_w_lg_niO0O762w(0) <= NOT niO0O;
	wire_nliii_w_lg_niOii769w(0) <= NOT niOii;
	wire_nliii_w_lg_w_lg_w_lg_nl00O654w655w656w(0) <= wire_nliii_w_lg_w_lg_nl00O654w655w(0) OR nl01O;
	wire_nliii_w_lg_w_lg_nl00O654w655w(0) <= wire_nliii_w_lg_nl00O654w(0) OR nl00i;
	wire_nliii_w_lg_nl00O654w(0) <= nl00O OR nl00l;
	PROCESS (tx_clk, wire_nliiO_PRN, wire_nliiO_CLRN)
	BEGIN
		IF (wire_nliiO_PRN = '0') THEN
				nlili <= '1';
		ELSIF (wire_nliiO_CLRN = '0') THEN
				nlili <= '0';
		ELSIF (tx_clk = '1' AND tx_clk'event) THEN
			IF (wire_nli_dataout = '1') THEN
				nlili <= niilOl;
			END IF;
		END IF;
		if (now = 0 ns) then
			nlili <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nliiO_CLRN <= (niilOi18 XOR niilOi17);
	wire_nliiO_PRN <= ((niillO20 XOR niillO19) AND wire_w_lg_soft_reset93w(0));
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w194w195w196w197w198w199w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_w194w195w196w197w198w(0) OR nl1OO;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_w194w195w196w197w198w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w194w195w196w197w(0) OR nl01i;
	wire_nliiO_w_lg_w_lg_w_lg_w194w195w196w197w(0) <= wire_nliiO_w_lg_w_lg_w194w195w196w(0) OR nl01O;
	wire_nliiO_w_lg_w_lg_w120w121w122w(0) <= wire_nliiO_w_lg_w120w121w(0) OR nl1OO;
	wire_nliiO_w_lg_w_lg_w194w195w196w(0) <= wire_nliiO_w_lg_w194w195w(0) OR nl0il;
	wire_nliiO_w_lg_w120w121w(0) <= wire_nliiO_w120w(0) OR nl01i;
	wire_nliiO_w_lg_w194w195w(0) <= wire_nliiO_w194w(0) OR nl0iO;
	wire_nliiO_w262w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w256w257w258w259w260w261w(0) OR nl1OO;
	wire_nliiO_w223w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w217w218w219w220w221w222w(0) OR nl1OO;
	wire_nliiO_w120w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w114w115w116w117w118w119w(0) OR nl01O;
	wire_nliiO_w194w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w188w189w190w191w192w193w(0) OR nl0li;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w256w257w258w259w260w261w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_w256w257w258w259w260w(0) OR nl01i;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w217w218w219w220w221w222w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_w217w218w219w220w221w(0) OR nl01i;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w114w115w116w117w118w119w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_w114w115w116w117w118w(0) OR nl0il;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_w188w189w190w191w192w193w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_w188w189w190w191w192w(0) OR nl0lO;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_w256w257w258w259w260w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w256w257w258w259w(0) OR nl01O;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_w217w218w219w220w221w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w217w218w219w220w(0) OR nl01O;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_w114w115w116w117w118w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w114w115w116w117w(0) OR nl0iO;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_w188w189w190w191w192w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w188w189w190w191w(0) OR nl0Oi;
	wire_nliiO_w_lg_w_lg_w_lg_w256w257w258w259w(0) <= wire_nliiO_w_lg_w_lg_w256w257w258w(0) OR nl0il;
	wire_nliiO_w_lg_w_lg_w_lg_w217w218w219w220w(0) <= wire_nliiO_w_lg_w_lg_w217w218w219w(0) OR nl0il;
	wire_nliiO_w_lg_w_lg_w_lg_w114w115w116w117w(0) <= wire_nliiO_w_lg_w_lg_w114w115w116w(0) OR nl0li;
	wire_nliiO_w_lg_w_lg_w_lg_w188w189w190w191w(0) <= wire_nliiO_w_lg_w_lg_w188w189w190w(0) OR nl0Ol;
	wire_nliiO_w_lg_w_lg_w256w257w258w(0) <= wire_nliiO_w_lg_w256w257w(0) OR nl0iO;
	wire_nliiO_w_lg_w_lg_w217w218w219w(0) <= wire_nliiO_w_lg_w217w218w(0) OR nl0li;
	wire_nliiO_w_lg_w_lg_w114w115w116w(0) <= wire_nliiO_w_lg_w114w115w(0) OR nl0lO;
	wire_nliiO_w_lg_w_lg_w188w189w190w(0) <= wire_nliiO_w_lg_w188w189w(0) OR nl0OO;
	wire_nliiO_w_lg_w256w257w(0) <= wire_nliiO_w256w(0) OR nl0li;
	wire_nliiO_w_lg_w217w218w(0) <= wire_nliiO_w217w(0) OR nl0lO;
	wire_nliiO_w_lg_w114w115w(0) <= wire_nliiO_w114w(0) OR nl0Oi;
	wire_nliiO_w_lg_w188w189w(0) <= wire_nliiO_w188w(0) OR nli1i;
	wire_nliiO_w256w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_nlili160w161w162w254w255w(0) OR nl0ll;
	wire_nliiO_w217w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_nlili160w161w214w215w216w(0) OR nl0Ol;
	wire_nliiO_w114w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_nlili109w110w111w112w113w(0) OR nl0Ol;
	wire_nliiO_w188w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_nlili109w184w185w186w187w(0) OR nli1l;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_nlili160w161w162w254w255w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_nlili160w161w162w254w(0) OR nl0lO;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_nlili160w161w214w215w216w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_nlili160w161w214w215w(0) OR nl0OO;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_nlili109w110w111w112w113w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_nlili109w110w111w112w(0) OR nli1i;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_w_lg_nlili109w184w185w186w187w(0) <= wire_nliiO_w_lg_w_lg_w_lg_w_lg_nlili109w184w185w186w(0) OR nli1O;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_nlili160w161w162w254w(0) <= wire_nliiO_w_lg_w_lg_w_lg_nlili160w161w162w(0) OR nl0Ol;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_nlili160w161w214w215w(0) <= wire_nliiO_w_lg_w_lg_w_lg_nlili160w161w214w(0) OR nli1i;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_nlili109w110w111w112w(0) <= wire_nliiO_w_lg_w_lg_w_lg_nlili109w110w111w(0) OR nli1l;
	wire_nliiO_w_lg_w_lg_w_lg_w_lg_nlili109w184w185w186w(0) <= wire_nliiO_w_lg_w_lg_w_lg_nlili109w184w185w(0) OR nli0i;
	wire_nliiO_w_lg_w_lg_w_lg_nlili160w161w162w(0) <= wire_nliiO_w_lg_w_lg_nlili160w161w(0) OR nli1i;
	wire_nliiO_w_lg_w_lg_w_lg_nlili160w161w214w(0) <= wire_nliiO_w_lg_w_lg_nlili160w161w(0) OR nli1l;
	wire_nliiO_w_lg_w_lg_w_lg_nlili109w110w111w(0) <= wire_nliiO_w_lg_w_lg_nlili109w110w(0) OR nli1O;
	wire_nliiO_w_lg_w_lg_w_lg_nlili109w184w185w(0) <= wire_nliiO_w_lg_w_lg_nlili109w184w(0) OR nli0l;
	wire_nliiO_w_lg_w_lg_nlili160w161w(0) <= wire_nliiO_w_lg_nlili160w(0) OR nli1O;
	wire_nliiO_w_lg_w_lg_nlili109w110w(0) <= wire_nliiO_w_lg_nlili109w(0) OR nli0l;
	wire_nliiO_w_lg_w_lg_nlili109w184w(0) <= wire_nliiO_w_lg_nlili109w(0) OR nli0O;
	wire_nliiO_w_lg_nlili160w(0) <= nlili OR nli0l;
	wire_nliiO_w_lg_nlili109w(0) <= nlili OR nliil;
	wire_n000i_dataout <= wire_n00Oi_o(0) WHEN n1l1l = '1'  ELSE n11il;
	wire_n000l_dataout <= wire_n00Oi_o(1) WHEN n1l1l = '1'  ELSE n11iO;
	wire_n000O_dataout <= wire_n00Oi_o(2) WHEN n1l1l = '1'  ELSE n11li;
	wire_n001i_dataout <= wire_n00li_dataout AND NOT(wire_nlillO_dataout);
	wire_n001l_dataout <= wire_n00ll_dataout AND NOT(wire_nlillO_dataout);
	wire_n001O_dataout <= wire_n00lO_dataout AND NOT(wire_nlillO_dataout);
	wire_n00i_dataout <= nl0l0l WHEN niiOil = '1'  ELSE wire_niii_dataout;
	wire_n00ii_dataout <= wire_n00Oi_o(3) WHEN n1l1l = '1'  ELSE n11ll;
	wire_n00il_dataout <= wire_n00Oi_o(4) WHEN n1l1l = '1'  ELSE n11lO;
	wire_n00iO_dataout <= wire_n00Oi_o(5) WHEN n1l1l = '1'  ELSE n11Oi;
	wire_n00l_dataout <= nl0l0O WHEN niiOil = '1'  ELSE wire_niil_dataout;
	wire_n00li_dataout <= wire_n00Oi_o(6) WHEN n1l1l = '1'  ELSE n11Ol;
	wire_n00ll_dataout <= wire_n00Oi_o(7) WHEN n1l1l = '1'  ELSE n11OO;
	wire_n00lO_dataout <= wire_n00Oi_o(8) WHEN n1l1l = '1'  ELSE n101i;
	wire_n00O_dataout <= nl0lii WHEN niiOil = '1'  ELSE wire_niiO_dataout;
	wire_n010i_dataout <= wire_n01il_dataout AND NOT(wire_nlilll_dataout);
	wire_n010l_dataout <= wire_n01iO_o(0) WHEN wire_nlilli_dataout = '1'  ELSE n110i;
	wire_n010O_dataout <= wire_n01iO_o(1) WHEN wire_nlilli_dataout = '1'  ELSE n110l;
	wire_n011i_dataout <= wire_n010l_dataout AND NOT(wire_nlilll_dataout);
	wire_n011l_dataout <= wire_n010O_dataout AND NOT(wire_nlilll_dataout);
	wire_n011O_dataout <= wire_n01ii_dataout AND NOT(wire_nlilll_dataout);
	wire_n01i_dataout <= nl0l1l WHEN niiOil = '1'  ELSE wire_ni0i_dataout;
	wire_n01ii_dataout <= wire_n01iO_o(2) WHEN wire_nlilli_dataout = '1'  ELSE n110O;
	wire_n01il_dataout <= wire_n01iO_o(3) WHEN wire_nlilli_dataout = '1'  ELSE n11ii;
	wire_n01l_dataout <= nl0l1O WHEN niiOil = '1'  ELSE wire_ni0l_dataout;
	wire_n01li_dataout <= wire_n000i_dataout AND NOT(wire_nlillO_dataout);
	wire_n01ll_dataout <= wire_n000l_dataout AND NOT(wire_nlillO_dataout);
	wire_n01lO_dataout <= wire_n000O_dataout AND NOT(wire_nlillO_dataout);
	wire_n01O_dataout <= nl0l0i WHEN niiOil = '1'  ELSE wire_ni0O_dataout;
	wire_n01Oi_dataout <= wire_n00ii_dataout AND NOT(wire_nlillO_dataout);
	wire_n01Ol_dataout <= wire_n00il_dataout AND NOT(wire_nlillO_dataout);
	wire_n01OO_dataout <= wire_n00iO_dataout AND NOT(wire_nlillO_dataout);
	wire_n0i_dataout <= nl1ll AND niiOli;
	wire_n0ii_dataout <= nl0lil WHEN niiOil = '1'  ELSE wire_nili_dataout;
	wire_n0il_dataout <= nl0liO WHEN niiOil = '1'  ELSE wire_nill_dataout;
	wire_n0iO_dataout <= nl0lli WHEN niiOil = '1'  ELSE wire_nilO_dataout;
	wire_n0l_dataout <= nl1lO AND niiOli;
	wire_n0l0O_dataout <= wire_w_lg_niiOOi445w(0) AND nl0ii;
	wire_n0li_dataout <= nl0lll WHEN niiOil = '1'  ELSE wire_niOi_dataout;
	wire_n0ll_dataout <= nl0llO WHEN niiOil = '1'  ELSE wire_niOl_dataout;
	wire_n0llO_dataout <= wire_w_lg_niiOOi445w(0) AND nl0iO;
	wire_n0lO_dataout <= nl0lOi WHEN niiOil = '1'  ELSE wire_niOO_dataout;
	wire_n0O_dataout <= nl1Oi AND niiOli;
	wire_n0O0i_dataout <= wire_w_lg_niiOOi445w(0) AND nl0Oi;
	wire_n0O1i_dataout <= wire_w_lg_niiOOi445w(0) AND nl0ll;
	wire_n0Oi_dataout <= nl0lOl WHEN niiOil = '1'  ELSE wire_nl1i_dataout;
	wire_n0Oii_dataout <= wire_w_lg_niiOOi445w(0) AND nl0OO;
	wire_n0Ol_dataout <= nl0lOO WHEN niiOil = '1'  ELSE wire_nl1l_dataout;
	wire_n0Oli_dataout <= wire_w_lg_niiOOi445w(0) AND nli1l;
	wire_n0OO_dataout <= nl0O1i WHEN niiOil = '1'  ELSE wire_nl1O_dataout;
	wire_n0OOi_dataout <= wire_w_lg_niiOOi445w(0) AND nli0i;
	wire_n1i_dataout <= nl1il AND niiOli;
	wire_n1l_dataout <= nl1iO AND niiOli;
	wire_n1lli_dataout <= wire_n1lOi_o(0) AND wire_nlilOi_o;
	wire_n1lll_dataout <= wire_n1lOi_o(1) AND wire_nlilOi_o;
	wire_n1llO_dataout <= wire_n1lOi_o(2) AND wire_nlilOi_o;
	wire_n1lOl_dataout <= wire_n1Oll_o(0) WHEN wire_nlil0O_dataout = '1'  ELSE wire_n1O0l_dataout;
	wire_n1lOO_dataout <= wire_n1Oll_o(1) WHEN wire_nlil0O_dataout = '1'  ELSE wire_n1O0O_dataout;
	wire_n1O_dataout <= nl1li AND niiOli;
	wire_n1O0i_dataout <= wire_n1Oll_o(5) WHEN wire_nlil0O_dataout = '1'  ELSE wire_n1Oli_dataout;
	wire_n1O0l_dataout <= nlOOli AND NOT(wire_nlilii_dataout);
	wire_n1O0O_dataout <= nlOOll AND NOT(wire_nlilii_dataout);
	wire_n1O1i_dataout <= wire_n1Oll_o(2) WHEN wire_nlil0O_dataout = '1'  ELSE wire_n1Oii_dataout;
	wire_n1O1l_dataout <= wire_n1Oll_o(3) WHEN wire_nlil0O_dataout = '1'  ELSE wire_n1Oil_dataout;
	wire_n1O1O_dataout <= wire_n1Oll_o(4) WHEN wire_nlil0O_dataout = '1'  ELSE wire_n1OiO_dataout;
	wire_n1Oii_dataout <= nlOOlO AND NOT(wire_nlilii_dataout);
	wire_n1Oil_dataout <= nlOOOi AND NOT(wire_nlilii_dataout);
	wire_n1OiO_dataout <= nlOOOl AND NOT(wire_nlilii_dataout);
	wire_n1Oli_dataout <= nlOOOO AND NOT(wire_nlilii_dataout);
	wire_n1OlO_dataout <= wire_n1OOO_o(0) WHEN wire_nlilil_dataout = '1'  ELSE n111i;
	wire_n1OOi_dataout <= wire_n1OOO_o(1) WHEN wire_nlilil_dataout = '1'  ELSE n111l;
	wire_n1OOl_dataout <= wire_n1OOO_o(2) WHEN wire_nlilil_dataout = '1'  ELSE n111O;
	wire_ni0i_dataout <= n100i WHEN niiOiO = '1'  ELSE wire_nlii_dataout;
	wire_ni0l_dataout <= n100l WHEN niiOiO = '1'  ELSE wire_nlil_dataout;
	wire_ni0O_dataout <= n100O WHEN niiOiO = '1'  ELSE wire_nliO_dataout;
	wire_ni0OO_dataout <= niiiil AND NOT(niiilO);
	wire_ni11i_dataout <= wire_nillO_dataout AND nli0O;
	wire_ni1i_dataout <= nl0O1l WHEN niiOil = '1'  ELSE wire_nl0i_dataout;
	wire_ni1l_dataout <= nl0iOO WHEN niiOil = '1'  ELSE wire_nl0l_dataout;
	wire_ni1O_dataout <= nl0l1i WHEN niiOil = '1'  ELSE wire_nl0O_dataout;
	wire_nii_dataout <= nl1Ol AND niiOli;
	wire_nii0i_dataout <= wire_niiil_dataout AND niiOOi;
	wire_nii0l_dataout <= wire_niiiO_dataout AND niiOOi;
	wire_nii0O_dataout <= niiiil WHEN niiilO = '1'  ELSE niiiiO;
	wire_nii1i_dataout <= niiiil AND niiilO;
	wire_nii1l_dataout <= wire_nii0O_dataout AND NOT(niiOOi);
	wire_nii1O_dataout <= wire_w_lg_niiili108w(0) WHEN niiOOi = '1'  ELSE wire_niiii_dataout;
	wire_niii_dataout <= n10ii WHEN niiOiO = '1'  ELSE wire_nlli_dataout;
	wire_niiii_dataout <= wire_w_lg_niiiil107w(0) WHEN niiilO = '1'  ELSE wire_w_lg_niiiiO106w(0);
	wire_niiil_dataout <= niiili AND NOT(niiilO);
	wire_niiiO_dataout <= niiili AND niiilO;
	wire_niil_dataout <= n10il WHEN niiOiO = '1'  ELSE wire_nlll_dataout;
	wire_niili_dataout <= wire_nil1i_dataout AND niiOOi;
	wire_niill_dataout <= wire_nil1l_dataout AND niiOOi;
	wire_niilO_dataout <= wire_nil1O_dataout AND niiOOi;
	wire_niiO_dataout <= n10iO WHEN niiOiO = '1'  ELSE wire_nllO_dataout;
	wire_niiOi_dataout <= wire_nil0i_dataout AND niiOOi;
	wire_niiOl_dataout <= wire_w_lg_niiill105w(0) AND niiOOi;
	wire_niiOO_dataout <= niiill AND niiOOi;
	wire_nil_dataout <= niOlO AND niiOli;
	wire_nil0i_dataout <= niiilO AND niiill;
	wire_nil0l_dataout <= wire_nilil_dataout AND NOT(niiilO);
	wire_nil0O_dataout <= wire_niliO_dataout AND NOT(niiilO);
	wire_nil1i_dataout <= wire_nil0l_dataout AND niiill;
	wire_nil1l_dataout <= wire_nil0O_dataout AND niiill;
	wire_nil1O_dataout <= wire_nilii_dataout AND niiill;
	wire_nili_dataout <= n10li WHEN niiOiO = '1'  ELSE wire_nlOi_dataout;
	wire_nilii_dataout <= niil1i AND NOT(niiilO);
	wire_nilil_dataout <= wire_w_lg_niiiOO104w(0) AND NOT(niil1i);
	wire_niliO_dataout <= niiiOO AND NOT(niil1i);
	wire_nill_dataout <= n10ll WHEN niiOiO = '1'  ELSE wire_nlOl_dataout;
	wire_nilli_dataout <= wire_w_lg_niiiOl103w(0) AND niiOOi;
	wire_nilll_dataout <= wire_nilOl_dataout OR niiOOi;
	wire_nillO_dataout <= wire_nilOO_dataout AND NOT(niiOOi);
	wire_nilO_dataout <= n10lO WHEN niiOiO = '1'  ELSE wire_nlOO_dataout;
	wire_nilOi_dataout <= wire_niO1i_dataout AND NOT(niiOOi);
	wire_nilOl_dataout <= wire_niO1l_dataout OR niiilO;
	wire_nilOO_dataout <= wire_w_lg_niiiOl103w(0) AND NOT(niiilO);
	wire_niO_dataout <= niOOi AND niiOli;
	wire_niO00i_dataout <= nl00OO WHEN niiOOi = '1'  ELSE nl0iil;
	wire_niO00l_dataout <= nl0i1i WHEN niiOOi = '1'  ELSE nl0iiO;
	wire_niO00O_dataout <= nl0i1l WHEN niiOOi = '1'  ELSE nl0ili;
	wire_niO01i_dataout <= wire_niOOOi_dataout WHEN niiOOi = '1'  ELSE wire_niOiOO_dataout;
	wire_niO01l_dataout <= wire_niOOOl_dataout WHEN niiOOi = '1'  ELSE wire_niOl1i_dataout;
	wire_niO01O_dataout <= nl0iii AND NOT(niiOOi);
	wire_niO0ii_dataout <= nl0i1O WHEN niiOOi = '1'  ELSE nl0ill;
	wire_niO0il_dataout <= nl0i0i WHEN niiOOi = '1'  ELSE nl0ilO;
	wire_niO0iO_dataout <= nl0i0l WHEN niiOOi = '1'  ELSE nl0iOi;
	wire_niO0li_dataout <= nl0i0O WHEN niiOOi = '1'  ELSE nl0iOl;
	wire_niO0ll_dataout <= nl00il AND niiOOi;
	wire_niO0lO_dataout <= nl00iO AND niiOOi;
	wire_niO0Oi_dataout <= nl00li AND niiOOi;
	wire_niO0Ol_dataout <= nl00ll AND niiOOi;
	wire_niO0OO_dataout <= nl00lO AND niiOOi;
	wire_niO10i_dataout <= wire_niOO1i_dataout WHEN niiOOi = '1'  ELSE wire_niOi1O_dataout;
	wire_niO10l_dataout <= wire_niOO1l_dataout WHEN niiOOi = '1'  ELSE wire_niOi0i_dataout;
	wire_niO10O_dataout <= wire_niOO1O_dataout WHEN niiOOi = '1'  ELSE wire_niOi0l_dataout;
	wire_niO11l_dataout <= wire_nlO_dataout AND niiOOi;
	wire_niO11O_dataout <= wire_nlO_dataout AND NOT(niiOOi);
	wire_niO1i_dataout <= wire_niO1O_dataout AND NOT(niiilO);
	wire_niO1ii_dataout <= wire_niOO0i_dataout WHEN niiOOi = '1'  ELSE wire_niOi0O_dataout;
	wire_niO1il_dataout <= wire_niOO0l_dataout WHEN niiOOi = '1'  ELSE wire_niOiii_dataout;
	wire_niO1iO_dataout <= wire_niOO0O_dataout WHEN niiOOi = '1'  ELSE wire_niOiil_dataout;
	wire_niO1l_dataout <= niiiOi AND niiiOl;
	wire_niO1li_dataout <= wire_niOOii_dataout WHEN niiOOi = '1'  ELSE wire_niOiiO_dataout;
	wire_niO1ll_dataout <= wire_niOOil_dataout WHEN niiOOi = '1'  ELSE wire_niOili_dataout;
	wire_niO1lO_dataout <= wire_niOOiO_dataout WHEN niiOOi = '1'  ELSE wire_niOill_dataout;
	wire_niO1O_dataout <= wire_w_lg_niiiOi102w(0) AND niiiOl;
	wire_niO1Oi_dataout <= wire_niOOli_dataout WHEN niiOOi = '1'  ELSE wire_niOilO_dataout;
	wire_niO1Ol_dataout <= wire_niOOll_dataout WHEN niiOOi = '1'  ELSE wire_niOiOi_dataout;
	wire_niO1OO_dataout <= wire_niOOlO_dataout WHEN niiOOi = '1'  ELSE wire_niOiOl_dataout;
	wire_niOi_dataout <= n10Oi WHEN niiOiO = '1'  ELSE wire_n1i_dataout;
	wire_niOi0i_dataout <= wire_niOl1O_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOi0l_dataout <= wire_niOl0i_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOi0O_dataout <= wire_niOl0l_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOi1i_dataout <= nl00Oi AND niiOOi;
	wire_niOi1l_dataout <= nl00Ol AND niiOOi;
	wire_niOi1O_dataout <= wire_niOl1l_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOiii_dataout <= wire_niOl0O_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOiil_dataout <= wire_niOlii_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOiiO_dataout <= wire_niOlil_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOili_dataout <= wire_niOliO_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOill_dataout <= wire_niOlli_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOilO_dataout <= wire_niOlll_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOiOi_dataout <= wire_niOllO_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOiOl_dataout <= wire_niOlOi_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOiOO_dataout <= wire_niOlOl_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOl_dataout <= n10Ol WHEN niiOiO = '1'  ELSE wire_n1l_dataout;
	wire_niOl0i_dataout <= nl0O0l AND NOT(ni01Oi);
	wire_niOl0l_dataout <= nl0O0O AND NOT(ni01Oi);
	wire_niOl0O_dataout <= nl0Oii AND NOT(ni01Oi);
	wire_niOl1i_dataout <= wire_niOlOO_dataout OR wire_nlO_w_lg_dataout1647w(0);
	wire_niOl1l_dataout <= nl0O1O AND NOT(ni01Oi);
	wire_niOl1O_dataout <= nl0O0i AND NOT(ni01Oi);
	wire_niOlii_dataout <= nl0Oil AND NOT(ni01Oi);
	wire_niOlil_dataout <= nl0OiO AND NOT(ni01Oi);
	wire_niOliO_dataout <= nl0Oli AND NOT(ni01Oi);
	wire_niOlli_dataout <= nl0Oll AND NOT(ni01Oi);
	wire_niOlll_dataout <= nl0OlO OR ni01Oi;
	wire_niOllO_dataout <= nl0OOi AND NOT(ni01Oi);
	wire_niOlOi_dataout <= nl0OOl AND NOT(ni01Oi);
	wire_niOlOl_dataout <= nli11i AND NOT(ni01Oi);
	wire_niOlOO_dataout <= nli11O AND NOT(ni01Oi);
	wire_niOO_dataout <= n10OO WHEN niiOiO = '1'  ELSE wire_n1O_dataout;
	wire_niOO0i_dataout <= wire_nl111O_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOO0l_dataout <= wire_nl110i_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOO0O_dataout <= wire_nl110l_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOO1i_dataout <= wire_niOOOO_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOO1l_dataout <= wire_nl111i_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOO1O_dataout <= wire_nl111l_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOOii_dataout <= wire_nl110O_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOOil_dataout <= wire_nl11ii_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOOiO_dataout <= wire_nl11il_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOOli_dataout <= wire_nl11iO_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOOll_dataout <= wire_nl11li_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOOlO_dataout <= wire_nl11ll_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOOOi_dataout <= wire_nl11lO_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_niOOOl_dataout <= wire_nl11Oi_dataout OR wire_nlO_w_lg_dataout1647w(0);
	wire_niOOOO_dataout <= nl0O1O AND NOT(ni01Ol);
	wire_nl000i_dataout <= nl0OOi AND NOT(wire_nlO_dataout);
	wire_nl000l_dataout <= nl0OOl AND NOT(wire_nlO_dataout);
	wire_nl000O_dataout <= nli11i OR wire_nlO_dataout;
	wire_nl001i_dataout <= nl0Oli AND NOT(wire_nlO_dataout);
	wire_nl001l_dataout <= nl0Oll AND NOT(wire_nlO_dataout);
	wire_nl001O_dataout <= nl0OlO AND NOT(wire_nlO_dataout);
	wire_nl00ii_dataout <= nli11O AND NOT(wire_nlO_dataout);
	wire_nl010i_dataout <= nl0OlO AND NOT(ni001i);
	wire_nl010l_dataout <= nl0OOi AND NOT(ni001i);
	wire_nl010O_dataout <= nl0OOl OR ni001i;
	wire_nl011i_dataout <= nl0OiO AND NOT(ni001i);
	wire_nl011l_dataout <= nl0Oli AND NOT(ni001i);
	wire_nl011O_dataout <= nl0Oll AND NOT(ni001i);
	wire_nl01ii_dataout <= nli11i AND NOT(ni001i);
	wire_nl01il_dataout <= nli11O AND NOT(ni001i);
	wire_nl01iO_dataout <= nl0O1O AND NOT(wire_nlO_dataout);
	wire_nl01li_dataout <= nl0O0i AND NOT(wire_nlO_dataout);
	wire_nl01ll_dataout <= nl0O0l AND NOT(wire_nlO_dataout);
	wire_nl01lO_dataout <= nl0O0O AND NOT(wire_nlO_dataout);
	wire_nl01Oi_dataout <= nl0Oii AND NOT(wire_nlO_dataout);
	wire_nl01Ol_dataout <= nl0Oil AND NOT(wire_nlO_dataout);
	wire_nl01OO_dataout <= nl0OiO AND NOT(wire_nlO_dataout);
	wire_nl0i_dataout <= n1i0i WHEN niiOiO = '1'  ELSE wire_nii_dataout;
	wire_nl0l_dataout <= n101l WHEN niiOiO = '1'  ELSE wire_nil_dataout;
	wire_nl0O_dataout <= n101O WHEN niiOiO = '1'  ELSE wire_niO_dataout;
	wire_nl100i_dataout <= wire_nl1O1i_dataout WHEN niiOOi = '1'  ELSE wire_nl1i1O_dataout;
	wire_nl100l_dataout <= wire_nl1O1l_dataout WHEN niiOOi = '1'  ELSE wire_nl1i0i_dataout;
	wire_nl100O_dataout <= wire_nl1O1O_dataout WHEN niiOOi = '1'  ELSE wire_nl1i0l_dataout;
	wire_nl101i_dataout <= wire_nl1lOi_dataout WHEN niiOOi = '1'  ELSE wire_nl10OO_dataout;
	wire_nl101l_dataout <= wire_nl1lOl_dataout WHEN niiOOi = '1'  ELSE wire_nl1i1i_dataout;
	wire_nl101O_dataout <= wire_nl1lOO_dataout WHEN niiOOi = '1'  ELSE wire_nl1i1l_dataout;
	wire_nl10ii_dataout <= wire_nl1O0i_dataout WHEN niiOOi = '1'  ELSE wire_nl1i0O_dataout;
	wire_nl10il_dataout <= wire_nl1O0l_dataout WHEN niiOOi = '1'  ELSE wire_nl1iii_dataout;
	wire_nl10iO_dataout <= wire_nl1O0O_dataout WHEN niiOOi = '1'  ELSE wire_nl1iil_dataout;
	wire_nl10li_dataout <= wire_nl1Oii_dataout WHEN niiOOi = '1'  ELSE wire_nl1iiO_dataout;
	wire_nl10ll_dataout <= wire_nl1Oil_dataout WHEN niiOOi = '1'  ELSE wire_nl1ili_dataout;
	wire_nl10lO_dataout <= wire_nl1OiO_dataout WHEN niiOOi = '1'  ELSE wire_nl1ill_dataout;
	wire_nl10Oi_dataout <= wire_nl1ilO_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl10Ol_dataout <= wire_nl1iOi_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl10OO_dataout <= wire_nl1iOl_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl110i_dataout <= nl0Oii AND NOT(ni01Ol);
	wire_nl110l_dataout <= nl0Oil AND NOT(ni01Ol);
	wire_nl110O_dataout <= nl0OiO AND NOT(ni01Ol);
	wire_nl111i_dataout <= nl0O0i AND NOT(ni01Ol);
	wire_nl111l_dataout <= nl0O0l AND NOT(ni01Ol);
	wire_nl111O_dataout <= nl0O0O AND NOT(ni01Ol);
	wire_nl11ii_dataout <= nl0Oli AND NOT(ni01Ol);
	wire_nl11il_dataout <= nl0Oll AND NOT(ni01Ol);
	wire_nl11iO_dataout <= nl0OlO OR ni01Ol;
	wire_nl11li_dataout <= nl0OOi AND NOT(ni01Ol);
	wire_nl11ll_dataout <= nl0OOl AND NOT(ni01Ol);
	wire_nl11lO_dataout <= nli11i AND NOT(ni01Ol);
	wire_nl11Oi_dataout <= nli11O AND NOT(ni01Ol);
	wire_nl11Ol_dataout <= wire_nl1lll_dataout WHEN niiOOi = '1'  ELSE wire_nl10Oi_dataout;
	wire_nl11OO_dataout <= wire_nl1llO_dataout WHEN niiOOi = '1'  ELSE wire_nl10Ol_dataout;
	wire_nl1i_dataout <= n1i1i WHEN niiOiO = '1'  ELSE wire_n0i_dataout;
	wire_nl1i0i_dataout <= wire_nl1l1O_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1i0l_dataout <= wire_nl1l0i_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1i0O_dataout <= wire_nl1l0l_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1i1i_dataout <= wire_nl1iOO_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1i1l_dataout <= wire_nl1l1i_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1i1O_dataout <= wire_nl1l1l_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1iii_dataout <= wire_nl1l0O_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1iil_dataout <= wire_nl1lii_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1iiO_dataout <= wire_nl1lil_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1ili_dataout <= wire_nl1liO_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1ill_dataout <= wire_nl1lli_dataout OR wire_nlO_w_lg_dataout1647w(0);
	wire_nl1ilO_dataout <= nl0O1O AND NOT(ni01OO);
	wire_nl1iOi_dataout <= nl0O0i AND NOT(ni01OO);
	wire_nl1iOl_dataout <= nl0O0l AND NOT(ni01OO);
	wire_nl1iOO_dataout <= nl0O0O AND NOT(ni01OO);
	wire_nl1l_dataout <= n1i1l WHEN niiOiO = '1'  ELSE wire_n0l_dataout;
	wire_nl1l0i_dataout <= nl0Oli AND NOT(ni01OO);
	wire_nl1l0l_dataout <= nl0Oll AND NOT(ni01OO);
	wire_nl1l0O_dataout <= nl0OlO AND NOT(ni01OO);
	wire_nl1l1i_dataout <= nl0Oii AND NOT(ni01OO);
	wire_nl1l1l_dataout <= nl0Oil AND NOT(ni01OO);
	wire_nl1l1O_dataout <= nl0OiO AND NOT(ni01OO);
	wire_nl1lii_dataout <= nl0OOi AND NOT(ni01OO);
	wire_nl1lil_dataout <= nl0OOl OR ni01OO;
	wire_nl1liO_dataout <= nli11i AND NOT(ni01OO);
	wire_nl1lli_dataout <= nli11O AND NOT(ni01OO);
	wire_nl1lll_dataout <= wire_nl1Oli_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1llO_dataout <= wire_nl1Oll_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1lOi_dataout <= wire_nl1OlO_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1lOl_dataout <= wire_nl1OOi_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1lOO_dataout <= wire_nl1OOl_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1O_dataout <= n1i1O WHEN niiOiO = '1'  ELSE wire_n0O_dataout;
	wire_nl1O0i_dataout <= wire_nl011O_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1O0l_dataout <= wire_nl010i_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1O0O_dataout <= wire_nl010l_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1O1i_dataout <= wire_nl1OOO_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1O1l_dataout <= wire_nl011i_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1O1O_dataout <= wire_nl011l_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1Oii_dataout <= wire_nl010O_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1Oil_dataout <= wire_nl01ii_dataout AND NOT(wire_nlO_w_lg_dataout1647w(0));
	wire_nl1OiO_dataout <= wire_nl01il_dataout OR wire_nlO_w_lg_dataout1647w(0);
	wire_nl1Oli_dataout <= nl0O1O AND NOT(ni001i);
	wire_nl1Oll_dataout <= nl0O0i AND NOT(ni001i);
	wire_nl1OlO_dataout <= nl0O0l AND NOT(ni001i);
	wire_nl1OOi_dataout <= nl0O0O AND NOT(ni001i);
	wire_nl1OOl_dataout <= nl0Oii AND NOT(ni001i);
	wire_nl1OOO_dataout <= nl0Oil AND NOT(ni001i);
	wire_nli_dataout <= rbisten_tx AND ((NOT rbist_sel(0)) AND rbist_sel(1));
	wire_nli00i_dataout <= wire_nli0Oi_o(1) AND ni001O;
	wire_nli00l_dataout <= wire_nli0Oi_o(2) AND ni001O;
	wire_nli00O_dataout <= wire_nli0Oi_o(3) AND ni001O;
	wire_nli01i_dataout <= wire_nli0lO_o(5) AND ni001O;
	wire_nli01l_dataout <= wire_nli0lO_o(6) AND ni001O;
	wire_nli01O_dataout <= wire_nli0Oi_o(0) AND ni001O;
	wire_nli0ii_dataout <= wire_nli0Oi_o(4) AND ni001O;
	wire_nli0il_dataout <= wire_nli0Oi_o(5) AND ni001O;
	wire_nli0iO_dataout <= wire_nli0Oi_o(6) AND ni001O;
	wire_nli0li_dataout <= wire_nli0Oi_o(7) AND ni001O;
	wire_nli10i_dataout <= wire_nli0ll_o(0) AND ni001O;
	wire_nli10l_dataout <= wire_nli0ll_o(1) AND ni001O;
	wire_nli10O_dataout <= wire_nli0ll_o(2) AND ni001O;
	wire_nli1ii_dataout <= wire_nli0ll_o(3) AND ni001O;
	wire_nli1il_dataout <= wire_nli0ll_o(4) AND ni001O;
	wire_nli1iO_dataout <= wire_nli0ll_o(5) AND ni001O;
	wire_nli1li_dataout <= wire_nli0ll_o(6) AND ni001O;
	wire_nli1ll_dataout <= wire_nli0lO_o(0) AND ni001O;
	wire_nli1lO_dataout <= wire_nli0lO_o(1) AND ni001O;
	wire_nli1Oi_dataout <= wire_nli0lO_o(2) AND ni001O;
	wire_nli1Ol_dataout <= wire_nli0lO_o(3) AND ni001O;
	wire_nli1OO_dataout <= wire_nli0lO_o(4) AND ni001O;
	wire_nlii_dataout <= niOOl AND niiOli;
	wire_nlil_dataout <= niOOO AND niiOli;
	wire_nlil0O_dataout <= wire_nllO1O_dataout AND n1iOl;
	wire_nlilii_dataout <= wire_nllO0i_dataout AND n1iOl;
	wire_nlilil_dataout <= niiOOi AND n1iOO;
	wire_nlill_dataout <= wire_nliOl_o(0) AND wire_n0iiO_o;
	wire_nlilli_dataout <= wire_nlO10l_dataout AND n1l1i;
	wire_nlilll_dataout <= wire_nlO10O_dataout AND n1l1i;
	wire_nlillO_dataout <= wire_nlOi0O_dataout AND n1l1l;
	wire_nlilO_dataout <= wire_nliOl_o(1) AND wire_n0iiO_o;
	wire_nliO_dataout <= nl11i AND niiOli;
	wire_nliOi_dataout <= wire_nliOl_o(2) AND wire_n0iiO_o;
	wire_nliOll_dataout <= wire_w_lg_niiOOi445w(0) AND n1ilO;
	wire_nliOO_dataout <= wire_nllli_o(0) WHEN wire_n0iii_o = '1'  ELSE wire_nll0l_dataout;
	wire_nll_dataout <= rbisten_tx AND wire_w_lg_w_rbist_sel_range12w20w(0);
	wire_nll0i_dataout <= wire_nllli_o(4) WHEN wire_n0iii_o = '1'  ELSE wire_nlliO_dataout;
	wire_nll0l_dataout <= niOii AND NOT(wire_n0iil_o);
	wire_nll0O_dataout <= niOil AND NOT(wire_n0iil_o);
	wire_nll11i_dataout <= wire_nlO1ll_dataout AND n1l1i;
	wire_nll1i_dataout <= wire_nllli_o(1) WHEN wire_n0iii_o = '1'  ELSE wire_nll0O_dataout;
	wire_nll1l_dataout <= wire_nllli_o(2) WHEN wire_n0iii_o = '1'  ELSE wire_nllii_dataout;
	wire_nll1O_dataout <= wire_nllli_o(3) WHEN wire_n0iii_o = '1'  ELSE wire_nllil_dataout;
	wire_nll1Oi_dataout <= wire_nlOlOO_dataout AND n1l0l;
	wire_nlli_dataout <= nl11l AND niiOli;
	wire_nllii_dataout <= niOiO AND NOT(wire_n0iil_o);
	wire_nllil_dataout <= niOli AND NOT(wire_n0iil_o);
	wire_nlliO_dataout <= niOll AND NOT(wire_n0iil_o);
	wire_nlll_dataout <= nl11O AND niiOli;
	wire_nlllil_dataout <= ni0l0l AND NOT(ni0Oii);
	wire_nllliO_dataout <= ni0l0l AND ni0Oii;
	wire_nlllli_dataout <= wire_nlllOl_dataout AND NOT(niiOOi);
	wire_nlllll_dataout <= wire_w_lg_ni0lii914w(0) WHEN niiOOi = '1'  ELSE wire_nlllOO_dataout;
	wire_nllllO_dataout <= wire_nllO1i_dataout AND niiOOi;
	wire_nlllOi_dataout <= wire_nllO1l_dataout AND niiOOi;
	wire_nlllOl_dataout <= ni0l0l WHEN ni0Oii = '1'  ELSE ni0l0O;
	wire_nlllOO_dataout <= wire_w_lg_ni0l0l913w(0) WHEN ni0Oii = '1'  ELSE wire_w_lg_ni0l0O912w(0);
	wire_nllO_dataout <= nl10i AND niiOli;
	wire_nllO0i_dataout <= ni0lil WHEN niiOOi = '1'  ELSE ni0liO;
	wire_nllO0l_dataout <= wire_nllOll_dataout AND niiOOi;
	wire_nllO0O_dataout <= wire_nllOlO_dataout AND niiOOi;
	wire_nllO1i_dataout <= ni0lii AND NOT(ni0Oii);
	wire_nllO1l_dataout <= ni0lii AND ni0Oii;
	wire_nllO1O_dataout <= wire_w_lg_ni0lil911w(0) WHEN niiOOi = '1'  ELSE wire_w_lg_ni0liO910w(0);
	wire_nllOii_dataout <= wire_nllOOi_dataout AND niiOOi;
	wire_nllOil_dataout <= wire_nllOOl_dataout AND niiOOi;
	wire_nllOiO_dataout <= wire_nllOOO_dataout AND niiOOi;
	wire_nllOli_dataout <= ni0lli AND niiOOi;
	wire_nllOll_dataout <= wire_nlO11i_dataout AND NOT(ni0lli);
	wire_nllOlO_dataout <= wire_nlO11l_dataout AND NOT(ni0lli);
	wire_nllOOi_dataout <= wire_nlO11O_dataout AND NOT(ni0lli);
	wire_nllOOl_dataout <= wire_nlO10i_dataout AND NOT(ni0lli);
	wire_nllOOO_dataout <= wire_w_lg_ni0lll909w(0) AND NOT(ni0lli);
	wire_nlO_dataout <= rbisten_tx AND (((NOT rbist_sel(0)) AND wire_w_lg_w_rbist_sel_range14w15w(0)) AND (niiOll6 XOR niiOll5));
	wire_nlO_w_lg_dataout1647w(0) <= NOT wire_nlO_dataout;
	wire_nlO00i_dataout <= wire_nlO0li_dataout AND NOT(ni0lOO);
	wire_nlO00l_dataout <= ni0lOi AND NOT(ni0lOO);
	wire_nlO00O_dataout <= wire_nlO0ll_dataout AND NOT(ni0lOi);
	wire_nlO01i_dataout <= wire_nlO0ii_dataout AND NOT(ni0lOO);
	wire_nlO01l_dataout <= wire_nlO0il_dataout AND NOT(ni0lOO);
	wire_nlO01O_dataout <= wire_nlO0iO_dataout AND NOT(ni0lOO);
	wire_nlO0ii_dataout <= wire_nlO0lO_dataout AND NOT(ni0lOi);
	wire_nlO0il_dataout <= wire_nlO0Oi_dataout AND NOT(ni0lOi);
	wire_nlO0iO_dataout <= wire_nlO0Ol_dataout AND NOT(ni0lOi);
	wire_nlO0li_dataout <= wire_w_lg_ni0lOl907w(0) AND NOT(ni0lOi);
	wire_nlO0ll_dataout <= wire_nlO0OO_dataout AND ni0lOl;
	wire_nlO0lO_dataout <= wire_nlOi1i_dataout AND ni0lOl;
	wire_nlO0Oi_dataout <= wire_nlOi1l_dataout AND ni0lOl;
	wire_nlO0Ol_dataout <= ni0Oii AND ni0lOl;
	wire_nlO0OO_dataout <= wire_nlOi1O_dataout AND NOT(ni0Oii);
	wire_nlO10i_dataout <= ni0Oii AND ni0lll;
	wire_nlO10l_dataout <= wire_w_lg_ni0llO908w(0) OR NOT(niiOOi);
	wire_nlO10O_dataout <= ni0llO AND niiOOi;
	wire_nlO11i_dataout <= wire_nlO0OO_dataout AND ni0lll;
	wire_nlO11l_dataout <= wire_nlOi1i_dataout AND ni0lll;
	wire_nlO11O_dataout <= wire_nlOi1l_dataout AND ni0lll;
	wire_nlO1ii_dataout <= wire_nlO1OO_dataout AND NOT(niiOOi);
	wire_nlO1il_dataout <= wire_nlO01i_dataout AND NOT(niiOOi);
	wire_nlO1iO_dataout <= wire_nlO01l_dataout AND NOT(niiOOi);
	wire_nlO1li_dataout <= wire_nlO01O_dataout AND NOT(niiOOi);
	wire_nlO1ll_dataout <= ni0llO WHEN niiOOi = '1'  ELSE ni0lOO;
	wire_nlO1lO_dataout <= wire_nlO00i_dataout AND NOT(niiOOi);
	wire_nlO1Oi_dataout <= wire_w_lg_ni0llO908w(0) AND niiOOi;
	wire_nlO1Ol_dataout <= wire_nlO00l_dataout AND NOT(niiOOi);
	wire_nlO1OO_dataout <= wire_nlO00O_dataout AND NOT(ni0lOO);
	wire_nlOi_dataout <= nl10l AND niiOli;
	wire_nlOi0i_dataout <= ni0Oli AND NOT(ni0Oll);
	wire_nlOi0O_dataout <= wire_nlOl1O_dataout WHEN niiOOi = '1'  ELSE wire_nlOiiO_dataout;
	wire_nlOi1i_dataout <= wire_nlOi0i_dataout AND NOT(ni0Oii);
	wire_nlOi1l_dataout <= ni0Oll AND NOT(ni0Oii);
	wire_nlOi1O_dataout <= wire_w_lg_ni0Oli906w(0) AND NOT(ni0Oll);
	wire_nlOiii_dataout <= wire_nlOl0i_dataout WHEN niiOOi = '1'  ELSE wire_nlOili_dataout;
	wire_nlOiil_dataout <= wire_nlOl0l_dataout WHEN niiOOi = '1'  ELSE wire_nlOill_dataout;
	wire_nlOiiO_dataout <= wire_nlOiOO_dataout WHEN ni0Oii = '1'  ELSE wire_nlOilO_dataout;
	wire_nlOili_dataout <= wire_nlOl1i_dataout WHEN ni0Oii = '1'  ELSE wire_nlOiOi_dataout;
	wire_nlOill_dataout <= wire_nlOl1l_dataout WHEN ni0Oii = '1'  ELSE wire_nlOiOl_dataout;
	wire_nlOilO_dataout <= ni0O1i AND NOT(ni0O0i);
	wire_nlOiOi_dataout <= ni0O1i OR ni0O0i;
	wire_nlOiOl_dataout <= wire_w_lg_ni0O1i896w(0) AND NOT(ni0O0i);
	wire_nlOiOO_dataout <= ni0O1l AND NOT(ni0O0O);
	wire_nlOl_dataout <= nl10O AND niiOli;
	wire_nlOl0i_dataout <= wire_nlOlli_dataout WHEN ni0Oii = '1'  ELSE wire_nlOlii_dataout;
	wire_nlOl0l_dataout <= wire_nlOlll_dataout WHEN ni0Oii = '1'  ELSE wire_nlOlil_dataout;
	wire_nlOl0O_dataout <= ni0O0i AND NOT(ni0O1O);
	wire_nlOl1i_dataout <= ni0O1l OR ni0O0O;
	wire_nlOl1l_dataout <= wire_w_lg_ni0O1l895w(0) AND NOT(ni0O0O);
	wire_nlOl1O_dataout <= wire_nlOliO_dataout WHEN ni0Oii = '1'  ELSE wire_nlOl0O_dataout;
	wire_nlOlii_dataout <= ni0O0i OR ni0O1O;
	wire_nlOlil_dataout <= wire_w_lg_ni0O0i894w(0) AND NOT(ni0O1O);
	wire_nlOliO_dataout <= ni0O0O AND NOT(ni0O0l);
	wire_nlOlli_dataout <= ni0O0O OR ni0O0l;
	wire_nlOlll_dataout <= wire_w_lg_ni0O0O893w(0) AND NOT(ni0O0l);
	wire_nlOllO_dataout <= wire_w_lg_ni0OiO892w(0) AND niiOOi;
	wire_nlOlOi_dataout <= wire_nlOO1l_dataout OR niiOOi;
	wire_nlOlOl_dataout <= ni0Oii AND NOT(niiOOi);
	wire_nlOlOO_dataout <= wire_nlOO1O_dataout AND NOT(niiOOi);
	wire_nlOO_dataout <= nl1ii AND niiOli;
	wire_nlOO0i_dataout <= wire_nlOO0O_dataout AND NOT(ni0Oii);
	wire_nlOO0l_dataout <= ni0Oil AND ni0OiO;
	wire_nlOO0O_dataout <= wire_w_lg_ni0Oil891w(0) AND ni0OiO;
	wire_nlOO1i_dataout <= wire_nlOO0i_dataout AND NOT(niiOOi);
	wire_nlOO1l_dataout <= wire_nlOO0l_dataout AND NOT(ni0Oii);
	wire_nlOO1O_dataout <= wire_w_lg_ni0OiO892w(0) AND NOT(ni0Oii);
	wire_n00Oi_a <= ( n101i & n11OO & n11Ol & n11Oi & n11lO & n11ll & n11li & n11iO & n11il);
	wire_n00Oi_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	n00Oi :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 9,
		width_b => 9,
		width_o => 9
	  )
	  PORT MAP ( 
		a => wire_n00Oi_a,
		b => wire_n00Oi_b,
		cin => wire_gnd,
		o => wire_n00Oi_o
	  );
	wire_n01iO_a <= ( n11ii & n110O & n110l & n110i);
	wire_n01iO_b <= ( "0" & "0" & "0" & "1");
	n01iO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 4,
		width_b => 4,
		width_o => 4
	  )
	  PORT MAP ( 
		a => wire_n01iO_a,
		b => wire_n01iO_b,
		cin => wire_gnd,
		o => wire_n01iO_o
	  );
	wire_n1lOi_a <= ( nlOOiO & nlOOil & nliliO);
	wire_n1lOi_b <= ( "0" & "0" & "1");
	n1lOi :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 3,
		width_b => 3,
		width_o => 3
	  )
	  PORT MAP ( 
		a => wire_n1lOi_a,
		b => wire_n1lOi_b,
		cin => wire_gnd,
		o => wire_n1lOi_o
	  );
	wire_n1Oll_a <= ( nlOOOO & nlOOOl & nlOOOi & nlOOlO & nlOOll & nlOOli);
	wire_n1Oll_b <= ( "0" & "0" & "0" & "0" & "0" & "1");
	n1Oll :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 6,
		width_b => 6,
		width_o => 6
	  )
	  PORT MAP ( 
		a => wire_n1Oll_a,
		b => wire_n1Oll_b,
		cin => wire_gnd,
		o => wire_n1Oll_o
	  );
	wire_n1OOO_a <= ( n111O & n111l & n111i);
	wire_n1OOO_b <= ( "0" & "0" & "1");
	n1OOO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 3,
		width_b => 3,
		width_o => 3
	  )
	  PORT MAP ( 
		a => wire_n1OOO_a,
		b => wire_n1OOO_b,
		cin => wire_gnd,
		o => wire_n1OOO_o
	  );
	wire_nli0ll_a <= ( nl00Ol & nl00Oi & nl00lO & nl00ll & nl00li & nl00iO & nl00il);
	wire_nli0ll_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "1");
	nli0ll :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 7,
		width_b => 7,
		width_o => 7
	  )
	  PORT MAP ( 
		a => wire_nli0ll_a,
		b => wire_nli0ll_b,
		cin => wire_gnd,
		o => wire_nli0ll_o
	  );
	wire_nli0lO_a <= ( nl0i0O & nl0i0l & nl0i0i & nl0i1O & nl0i1l & nl0i1i & nl00OO);
	wire_nli0lO_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "1");
	nli0lO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 7,
		width_b => 7,
		width_o => 7
	  )
	  PORT MAP ( 
		a => wire_nli0lO_a,
		b => wire_nli0lO_b,
		cin => wire_gnd,
		o => wire_nli0lO_o
	  );
	wire_nli0Oi_a <= ( nl0iOl & nl0iOi & nl0ilO & nl0ill & nl0ili & nl0iiO & nl0iil & nl0iii);
	wire_nli0Oi_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	nli0Oi :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8,
		width_o => 8
	  )
	  PORT MAP ( 
		a => wire_nli0Oi_a,
		b => wire_nli0Oi_b,
		cin => wire_gnd,
		o => wire_nli0Oi_o
	  );
	wire_nliOl_a <= ( wire_niilOO16_w_lg_w_lg_q78w79w & niO0l & n0lOi);
	wire_nliOl_b <= ( "0" & "0" & "1");
	nliOl :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 3,
		width_b => 3,
		width_o => 3
	  )
	  PORT MAP ( 
		a => wire_nliOl_a,
		b => wire_nliOl_b,
		cin => wire_gnd,
		o => wire_nliOl_o
	  );
	wire_nllli_a <= ( niOll & niOli & niOiO & wire_niiO1i14_w_lg_w_lg_q53w54w & niOii);
	wire_nllli_b <= ( "0" & "0" & "0" & "0" & "1");
	nllli :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_nllli_a,
		b => wire_nllli_b,
		cin => wire_gnd,
		o => wire_nllli_o
	  );
	wire_n0iii_data <= ( "0" & wire_niiOl_dataout & wire_w_lg_niiill105w);
	wire_n0iii_sel <= ( nii10l & nl0iO & nl0il);
	n0iii :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0iii_data,
		o => wire_n0iii_o,
		sel => wire_n0iii_sel
	  );
	wire_n0iil_data <= ( "0" & wire_niiOO_dataout & niiill);
	wire_n0iil_sel <= ( nii10l & nl0iO & nl0il);
	n0iil :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0iil_data,
		o => wire_n0iil_o,
		sel => wire_n0iil_sel
	  );
	wire_n0iiO_data <= ( "0" & wire_nilOi_dataout & wire_nii1O_dataout & wire_w_lg_niiiil107w & wire_w_lg_niiiil107w);
	wire_n0iiO_sel <= ( ni0OOO & nli0O & nl01l & nl01i & nl1OO);
	n0iiO :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0iiO_data,
		o => wire_n0iiO_o,
		sel => wire_n0iiO_sel
	  );
	wire_n0ilO_data <= ( "0" & niiOOi);
	wire_n0ilO_sel <= ( nii11i & wire_w_lg_nii11i695w);
	n0ilO :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_n0ilO_data,
		o => wire_n0ilO_o,
		sel => wire_n0ilO_sel
	  );
	wire_n0iOl_data <= ( "0" & niiiil & wire_w_lg_niiiil107w);
	wire_n0iOl_sel <= ( nii11l & nl01i & nl1OO);
	n0iOl :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0iOl_data,
		o => wire_n0iOl_o,
		sel => wire_n0iOl_sel
	  );
	wire_n0l1i_data <= ( "0" & wire_nii1l_dataout & wire_w_lg_niiiil107w);
	wire_n0l1i_sel <= ( nii11O & nl01l & nl01i);
	n0l1i :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0l1i_data,
		o => wire_n0l1i_o,
		sel => wire_n0l1i_sel
	  );
	wire_n0l1O_data <= ( "0" & niiOOi & "1" & wire_nii1O_dataout);
	wire_n0l1O_sel <= ( nii10i & nl0ii & wire_nliii_w_lg_w_lg_w_lg_nl00O654w655w656w & nl01l);
	n0l1O :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0l1O_data,
		o => wire_n0l1O_o,
		sel => wire_n0l1O_sel
	  );
	wire_n0lii_data <= ( "0" & wire_niili_dataout & wire_nil1i_dataout);
	wire_n0lii_sel <= ( nii10l & nl0iO & nl0il);
	n0lii :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0lii_data,
		o => wire_n0lii_o,
		sel => wire_n0lii_sel
	  );
	wire_n0lil_data <= ( "0" & wire_niill_dataout & wire_nil1l_dataout);
	wire_n0lil_sel <= ( nii10l & nl0iO & nl0il);
	n0lil :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0lil_data,
		o => wire_n0lil_o,
		sel => wire_n0lil_sel
	  );
	wire_n0liO_data <= ( "0" & wire_niilO_dataout & wire_nil1O_dataout);
	wire_n0liO_sel <= ( nii10l & nl0iO & nl0il);
	n0liO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0liO_data,
		o => wire_n0liO_o,
		sel => wire_n0liO_sel
	  );
	wire_n0lli_data <= ( "0" & wire_niiOi_dataout & wire_nil0i_dataout);
	wire_n0lli_sel <= ( nii10l & nl0iO & nl0il);
	n0lli :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0lli_data,
		o => wire_n0lli_o,
		sel => wire_n0lli_sel
	  );
	wire_n0lOl_data <= ( "0" & niiOOi & "1");
	wire_n0lOl_sel <= ( nii10O & nl0ll & nl0li);
	n0lOl :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0lOl_data,
		o => wire_n0lOl_o,
		sel => wire_n0lOl_sel
	  );
	wire_n0O0l_data <= ( "0" & niiOOi & "1");
	wire_n0O0l_sel <= ( nii1il & nl0OO & nl0Ol);
	n0O0l :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0O0l_data,
		o => wire_n0O0l_o,
		sel => wire_n0O0l_sel
	  );
	wire_n0O1l_data <= ( "0" & niiOOi & "1");
	wire_n0O1l_sel <= ( nii1ii & nl0Oi & nl0lO);
	n0O1l :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0O1l_data,
		o => wire_n0O1l_o,
		sel => wire_n0O1l_sel
	  );
	wire_n0Oil_data <= ( "0" & niiOOi & "1");
	wire_n0Oil_sel <= ( nii1iO & nli1l & nli1i);
	n0Oil :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0Oil_data,
		o => wire_n0Oil_o,
		sel => wire_n0Oil_sel
	  );
	wire_n0Oll_data <= ( "0" & niiOOi & "1");
	wire_n0Oll_sel <= ( nii1li & nli0i & nli1O);
	n0Oll :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0Oll_data,
		o => wire_n0Oll_o,
		sel => wire_n0Oll_sel
	  );
	wire_n0OOl_data <= ( "0" & niiOOi & wire_nilll_dataout & "1" & wire_niiOl_dataout & wire_w_lg_niiill105w);
	wire_n0OOl_sel <= ( nii1ll & nliil & nli0O & nli0l & nl0iO & nl0il);
	n0OOl :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_n0OOl_data,
		o => wire_n0OOl_o,
		sel => wire_n0OOl_sel
	  );
	wire_ni00l_data <= ( "0" & niiOOi);
	wire_ni00l_sel <= ( nii00l & wire_w_lg_nii00l246w);
	ni00l :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_ni00l_data,
		o => wire_ni00l_o,
		sel => wire_ni00l_sel
	  );
	wire_ni01i_data <= ( "0" & wire_nii1OO44_w_lg_w_lg_q295w296w);
	wire_ni01i_sel <= ( nii01i & wire_w_lg_nii01i291w);
	ni01i :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_ni01i_data,
		o => wire_ni01i_o,
		sel => wire_ni01i_sel
	  );
	wire_ni01O_data <= ( "0" & niiOOi);
	wire_ni01O_sel <= ( nii01l & wire_w_lg_nii01l267w);
	ni01O :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_ni01O_data,
		o => wire_ni01O_o,
		sel => wire_ni01O_sel
	  );
	wire_ni0ii_data <= ( "0" & niiOOi);
	wire_ni0ii_sel <= ( nii0ii & wire_nii00O40_w_lg_w_lg_q228w230w);
	ni0ii :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_ni0ii_data,
		o => wire_ni0ii_o,
		sel => wire_ni0ii_sel
	  );
	wire_ni0iO_data <= ( "0" & niiOOi);
	wire_ni0iO_sel <= ( wire_nii0li36_w_lg_w_lg_q207w208w & wire_w_lg_nii0ll204w);
	ni0iO :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_ni0iO_data,
		o => wire_ni0iO_o,
		sel => wire_ni0iO_sel
	  );
	wire_ni0ll_data <= ( "0" & niiOOi);
	wire_ni0ll_sel <= ( nii0Ol & wire_w_lg_nii0Ol176w);
	ni0ll :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_ni0ll_data,
		o => wire_ni0ll_o,
		sel => wire_ni0ll_sel
	  );
	wire_ni0Oi_data <= ( "0" & wire_nii0OO32_w_lg_w_lg_q155w156w & wire_niii1i30_w_lg_w_lg_q152w153w & niiOOi & niiOOi & niiOOi & niiOOi & niiOOi & niiOOi & niiOOi);
	wire_ni0Oi_sel <= ( wire_niii1l28_w_lg_w_lg_q141w142w & nli0O & nli0i & nl0OO & nl0ll & nl0ii & nl00O & wire_niii1O26_w_lg_w_lg_q132w133w & wire_niii0i24_w_lg_w_lg_q129w130w & nl01l);
	ni0Oi :  oper_selector
	  GENERIC MAP (
		width_data => 10,
		width_sel => 10
	  )
	  PORT MAP ( 
		data => wire_ni0Oi_data,
		o => wire_ni0Oi_o,
		sel => wire_ni0Oi_sel
	  );
	wire_ni10i_data <= ( niiilO & "0" & wire_nii0l_dataout & wire_nii1i_dataout);
	wire_ni10i_sel <= ( nlili & nii1Oi & nl01l & nl1OO);
	ni10i :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni10i_data,
		o => wire_ni10i_o,
		sel => wire_ni10i_sel
	  );
	wire_ni11l_data <= ( wire_w_lg_niiilO447w & wire_w_lg_niiOOi445w & wire_nilOi_dataout & "0" & wire_nii0i_dataout & wire_ni0OO_dataout);
	wire_ni11l_sel <= ( nlili & nliil & nli0O & nii1lO & nl01l & nl1OO);
	ni11l :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_ni11l_data,
		o => wire_ni11l_o,
		sel => wire_ni11l_sel
	  );
	wire_ni1Ol_data <= ( "0" & niiOOi);
	wire_ni1Ol_sel <= ( nii1Ol & wire_w_lg_nii1Ol312w);
	ni1Ol :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_ni1Ol_data,
		o => wire_ni1Ol_o,
		sel => wire_ni1Ol_sel
	  );
	wire_nil00l_data <= ( "0" & "1" & wire_niO00O_dataout);
	wire_nil00l_sel <= ( wire_nli11l_w_lg_nli11O2169w & ni1lOO & nl0OOi);
	nil00l :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nil00l_data,
		o => wire_nil00l_o,
		sel => wire_nil00l_sel
	  );
	wire_nil01O_data <= ( "0" & "1" & niiOOi & wire_niO00l_dataout);
	wire_nil01O_sel <= ( nli11O & ni1lOl & nl0OOl & nl0OOi);
	nil01O :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nil01O_data,
		o => wire_nil01O_o,
		sel => wire_nil01O_sel
	  );
	wire_nil0il_data <= ( "0" & "1" & wire_niO0ii_dataout);
	wire_nil0il_sel <= ( nli11O & ni1O1i & nl0OOi);
	nil0il :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nil0il_data,
		o => wire_nil0il_o,
		sel => wire_nil0il_sel
	  );
	wire_nil0li_data <= ( "0" & "1" & wire_niO0il_dataout);
	wire_nil0li_sel <= ( ni1O1O & ni1O1l & nl0OOi);
	nil0li :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nil0li_data,
		o => wire_nil0li_o,
		sel => wire_nil0li_sel
	  );
	wire_nil0Oi_data <= ( "0" & wire_w_lg_niiOOi445w & wire_niO0iO_dataout & "1");
	wire_nil0Oi_sel <= ( ni1O0l & nl0OOl & nl0OOi & ni1O0i);
	nil0Oi :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nil0Oi_data,
		o => wire_nil0Oi_o,
		sel => wire_nil0Oi_sel
	  );
	wire_nil1li_data <= ( "0" & niiOOi);
	wire_nil1li_sel <= ( ni1lll & wire_w_lg_ni1lll2233w);
	nil1li :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nil1li_data,
		o => wire_nil1li_o,
		sel => wire_nil1li_sel
	  );
	wire_nil1lO_data <= ( "0" & wire_w_lg_niiOOi445w & wire_niO01O_dataout & "1");
	wire_nil1lO_sel <= ( ni1llO & nl0OOl & nl0OOi & wire_nl0OOO_w_lg_nl0O0l2215w);
	nil1lO :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nil1lO_data,
		o => wire_nil1lO_o,
		sel => wire_nil1lO_sel
	  );
	wire_nil1OO_data <= ( "0" & wire_w_lg_niiOOi445w & wire_niO00i_dataout & "1");
	wire_nil1OO_sel <= ( ni1lOi & nl0OOl & nl0OOi & wire_nl0OOO_w_lg_nl0O0l2201w);
	nil1OO :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nil1OO_data,
		o => wire_nil1OO_o,
		sel => wire_nil1OO_sel
	  );
	wire_nili0i_data <= ( "0" & niiOOi);
	wire_nili0i_sel <= ( ni1Oil & wire_w_lg_ni1Oil2081w);
	nili0i :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nili0i_data,
		o => wire_nili0i_o,
		sel => wire_nili0i_sel
	  );
	wire_nili0O_data <= ( "0" & niiOOi & wire_niO0ll_dataout & niiOOi);
	wire_nili0O_sel <= ( ni1OiO & nl0OOl & nl0OOi & nl0O0O);
	nili0O :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nili0O_data,
		o => wire_nili0O_o,
		sel => wire_nili0O_sel
	  );
	wire_nili1i_data <= ( "0" & "1" & wire_niO0li_dataout);
	wire_nili1i_sel <= ( ni1Oii & ni1O0O & nl0OOi);
	nili1i :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nili1i_data,
		o => wire_nili1i_o,
		sel => wire_nili1i_sel
	  );
	wire_niliil_data <= ( "0" & niiOOi & wire_niO0lO_dataout & niiOOi & niiOOi & niiOOi & niiOOi & niiOOi);
	wire_niliil_sel <= ( ni1Oli & nli11i & nl0OOi & nl0OlO & nl0Oli & nl0Oil & nl0O0O & nl0O0i);
	niliil :  oper_selector
	  GENERIC MAP (
		width_data => 8,
		width_sel => 8
	  )
	  PORT MAP ( 
		data => wire_niliil_data,
		o => wire_niliil_o,
		sel => wire_niliil_sel
	  );
	wire_nilili_data <= ( "0" & niiOOi & niiOOi & wire_niO0Oi_dataout & niiOOi & niiOOi & niiOOi & niiOOi);
	wire_nilili_sel <= ( ni1Oll & nli11i & nl0OOl & nl0OOi & nl0OlO & nl0Oli & nl0Oil & nl0O0i);
	nilili :  oper_selector
	  GENERIC MAP (
		width_data => 8,
		width_sel => 8
	  )
	  PORT MAP ( 
		data => wire_nilili_data,
		o => wire_nilili_o,
		sel => wire_nilili_sel
	  );
	wire_nililO_data <= ( "0" & niiOOi & niiOOi & wire_niO0Ol_dataout & niiOOi & niiOOi & niiOOi & niiOOi & niiOOi);
	wire_nililO_sel <= ( ni1OlO & nli11i & nl0OOl & nl0OOi & nl0OlO & nl0Oli & nl0Oil & nl0O0O & nl0O0i);
	nililO :  oper_selector
	  GENERIC MAP (
		width_data => 9,
		width_sel => 9
	  )
	  PORT MAP ( 
		data => wire_nililO_data,
		o => wire_nililO_o,
		sel => wire_nililO_sel
	  );
	wire_niliOl_data <= ( "0" & niiOOi & niiOOi & wire_niO0OO_dataout & niiOOi & niiOOi & niiOOi & niiOOi);
	wire_niliOl_sel <= ( ni1OOi & nli11i & nl0OOl & nl0OOi & nl0OlO & nl0Oli & nl0O0O & nl0O0i);
	niliOl :  oper_selector
	  GENERIC MAP (
		width_data => 8,
		width_sel => 8
	  )
	  PORT MAP ( 
		data => wire_niliOl_data,
		o => wire_niliOl_o,
		sel => wire_niliOl_sel
	  );
	wire_nill0O_data <= ( wire_nl01iO_dataout & wire_nl11Ol_dataout & "0" & wire_niO10i_dataout & wire_niO11O_dataout);
	wire_nill0O_sel <= ( nli11O & nli11i & ni011i & nl0OOi & nl0O0i);
	nill0O :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nill0O_data,
		o => wire_nill0O_o,
		sel => wire_nill0O_sel
	  );
	wire_nill1i_data <= ( "0" & niiOOi & wire_niOi1i_dataout & niiOOi & niiOOi & niiOOi & niiOOi);
	wire_nill1i_sel <= ( ni1OOl & nl0OOl & nl0OOi & nl0Oli & nl0Oil & nl0O0O & nl0O0i);
	nill1i :  oper_selector
	  GENERIC MAP (
		width_data => 7,
		width_sel => 7
	  )
	  PORT MAP ( 
		data => wire_nill1i_data,
		o => wire_nill1i_o,
		sel => wire_nill1i_sel
	  );
	wire_nill1O_data <= ( "0" & niiOOi & niiOOi & wire_niOi1l_dataout & niiOOi & niiOOi & niiOOi);
	wire_nill1O_sel <= ( ni1OOO & nli11i & nl0OOl & nl0OOi & nl0Oil & nl0O0O & nl0O0i);
	nill1O :  oper_selector
	  GENERIC MAP (
		width_data => 7,
		width_sel => 7
	  )
	  PORT MAP ( 
		data => wire_nill1O_data,
		o => wire_nill1O_o,
		sel => wire_nill1O_sel
	  );
	wire_nillil_data <= ( wire_nl01li_dataout & wire_nl11OO_dataout & "0" & wire_niO10l_dataout & wire_niO11l_dataout & wire_nlO_dataout);
	wire_nillil_sel <= ( nli11O & nli11i & ni011l & nl0OOi & nl0O0O & nl0O0l);
	nillil :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_nillil_data,
		o => wire_nillil_o,
		sel => wire_nillil_sel
	  );
	wire_nillli_data <= ( wire_nl01ll_dataout & wire_nl101i_dataout & "0" & wire_niO10O_dataout & wire_niO11O_dataout);
	wire_nillli_sel <= ( nli11O & nli11i & ni011O & nl0OOi & nl0O0O);
	nillli :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nillli_data,
		o => wire_nillli_o,
		sel => wire_nillli_sel
	  );
	wire_nilllO_data <= ( wire_nl01lO_dataout & wire_nl101l_dataout & "0" & wire_niO1ii_dataout & wire_niO11l_dataout & wire_nlO_dataout);
	wire_nilllO_sel <= ( nli11O & nli11i & ni010i & nl0OOi & nl0Oil & nl0Oii);
	nilllO :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_nilllO_data,
		o => wire_nilllO_o,
		sel => wire_nilllO_sel
	  );
	wire_nillOl_data <= ( wire_nl01Oi_dataout & wire_nl101O_dataout & "0" & wire_niO1il_dataout & wire_niO11O_dataout);
	wire_nillOl_sel <= ( nli11O & nli11i & ni010l & nl0OOi & nl0Oil);
	nillOl :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nillOl_data,
		o => wire_nillOl_o,
		sel => wire_nillOl_sel
	  );
	wire_nilO0l_data <= ( wire_nl001i_dataout & wire_nl100O_dataout & "0" & wire_niO1ll_dataout & wire_niO11l_dataout & wire_nlO_dataout);
	wire_nilO0l_sel <= ( nli11O & nli11i & ni01il & nl0OOi & nl0OlO & nl0Oll);
	nilO0l :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_nilO0l_data,
		o => wire_nilO0l_o,
		sel => wire_nilO0l_sel
	  );
	wire_nilO1i_data <= ( wire_nl01Ol_dataout & wire_nl100i_dataout & "0" & wire_niO1iO_dataout & wire_niO11l_dataout & wire_nlO_dataout);
	wire_nilO1i_sel <= ( nli11O & nli11i & ni010O & nl0OOi & nl0Oli & nl0OiO);
	nilO1i :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_nilO1i_data,
		o => wire_nilO1i_o,
		sel => wire_nilO1i_sel
	  );
	wire_nilO1O_data <= ( wire_nl01OO_dataout & wire_nl100l_dataout & "0" & wire_niO1li_dataout & wire_niO11O_dataout);
	wire_nilO1O_sel <= ( nli11O & nli11i & ni01ii & nl0OOi & nl0Oli);
	nilO1O :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nilO1O_data,
		o => wire_nilO1O_o,
		sel => wire_nilO1O_sel
	  );
	wire_nilOii_data <= ( wire_nl001l_dataout & wire_nl10ii_dataout & "0" & wire_niO1lO_dataout & wire_niO11O_dataout);
	wire_nilOii_sel <= ( nli11O & nli11i & ni01iO & nl0OOi & nl0OlO);
	nilOii :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nilOii_data,
		o => wire_nilOii_o,
		sel => wire_nilOii_sel
	  );
	wire_nilOiO_data <= ( wire_nl001O_dataout & wire_nl10il_dataout & "0" & wire_niO1Oi_dataout);
	wire_nilOiO_sel <= ( nli11O & nli11i & ni01ll & nl0OOi);
	nilOiO :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nilOiO_data,
		o => wire_nilOiO_o,
		sel => wire_nilOiO_sel
	  );
	wire_nilOli_data <= ( wire_nl000i_dataout & wire_nl10iO_dataout & wire_nlO_dataout & wire_niO1Ol_dataout & "0");
	wire_nilOli_sel <= ( nli11O & nli11i & nl0OOl & nl0OOi & ni01li);
	nilOli :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nilOli_data,
		o => wire_nilOli_o,
		sel => wire_nilOli_sel
	  );
	wire_nilOlO_data <= ( wire_nl000l_dataout & wire_nl10li_dataout & "0" & wire_niO1OO_dataout);
	wire_nilOlO_sel <= ( nli11O & nli11i & ni01ll & nl0OOi);
	nilOlO :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nilOlO_data,
		o => wire_nilOlO_o,
		sel => wire_nilOlO_sel
	  );
	wire_nilOOl_data <= ( wire_nl000O_dataout & wire_nl10ll_dataout & "0" & wire_niO01i_dataout & wire_niO11l_dataout & wire_nlO_dataout);
	wire_nilOOl_sel <= ( nli11O & nli11i & ni01lO & nl0OOi & nl0O0i & nl0O1O);
	nilOOl :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_nilOOl_data,
		o => wire_nilOOl_o,
		sel => wire_nilOOl_sel
	  );
	wire_niO11i_data <= ( wire_nl00ii_dataout & wire_nl10lO_dataout & wire_nlO_w_lg_dataout1647w & wire_niO01l_dataout & wire_nlO_w_lg_dataout1647w & wire_nlO_w_lg_dataout1647w & wire_nlO_w_lg_dataout1647w & wire_nlO_w_lg_dataout1647w & wire_nlO_w_lg_dataout1647w & wire_nlO_w_lg_dataout1647w & wire_nlO_w_lg_dataout1647w & wire_nlO_w_lg_dataout1647w & wire_nlO_w_lg_dataout1647w & wire_nlO_w_lg_dataout1647w);
	wire_niO11i_sel <= ( nli11O & nli11i & nl0OOl & nl0OOi & nl0OlO & nl0Oll & nl0Oli & nl0OiO & nl0Oil & nl0Oii & nl0O0O & nl0O0l & nl0O0i & nl0O1O);
	niO11i :  oper_selector
	  GENERIC MAP (
		width_data => 14,
		width_sel => 14
	  )
	  PORT MAP ( 
		data => wire_niO11i_data,
		o => wire_niO11i_o,
		sel => wire_niO11i_sel
	  );
	wire_nlilOi_data <= ( "0" & wire_nlOO1i_dataout & wire_nlllll_dataout & wire_w_lg_ni0l0l913w & wire_w_lg_ni0l0l913w);
	wire_nlilOi_sel <= ( ni000i & n1l0l & n1iii & n1i0O & n1i0l);
	nlilOi :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nlilOi_data,
		o => wire_nlilOi_o,
		sel => wire_nlilOi_sel
	  );
	wire_nliO0l_data <= ( "0" & wire_nlllli_dataout & wire_w_lg_ni0l0l913w);
	wire_nliO0l_sel <= ( ni00ii & n1iii & n1i0O);
	nliO0l :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nliO0l_data,
		o => wire_nliO0l_o,
		sel => wire_nliO0l_sel
	  );
	wire_nliO1i_data <= ( "0" & niiOOi);
	wire_nliO1i_sel <= ( ni000l & wire_w_lg_ni000l1442w);
	nliO1i :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nliO1i_data,
		o => wire_nliO1i_o,
		sel => wire_nliO1i_sel
	  );
	wire_nliO1O_data <= ( "0" & ni0l0l & wire_w_lg_ni0l0l913w);
	wire_nliO1O_sel <= ( ni000O & n1i0O & n1i0l);
	nliO1O :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nliO1O_data,
		o => wire_nliO1O_o,
		sel => wire_nliO1O_sel
	  );
	wire_nliOii_data <= ( "0" & niiOOi & "1" & wire_nlllll_dataout);
	wire_nliOii_sel <= ( ni00il & n1ilO & wire_n1l0O_w_lg_w_lg_w_lg_n1ill1401w1402w1403w & n1iii);
	nliOii :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nliOii_data,
		o => wire_nliOii_o,
		sel => wire_nliOii_sel
	  );
	wire_nliOli_data <= ( "0" & wire_nlO1ii_dataout & wire_nllO0l_dataout);
	wire_nliOli_sel <= ( ni00iO & n1l1i & n1iOO);
	nliOli :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nliOli_data,
		o => wire_nliOli_o,
		sel => wire_nliOli_sel
	  );
	wire_nliOlO_data <= ( "0" & wire_nlO1il_dataout & wire_nllO0O_dataout);
	wire_nliOlO_sel <= ( ni00iO & n1l1i & n1iOO);
	nliOlO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nliOlO_data,
		o => wire_nliOlO_o,
		sel => wire_nliOlO_sel
	  );
	wire_nliOOi_data <= ( "0" & wire_nlO1iO_dataout & wire_nllOii_dataout);
	wire_nliOOi_sel <= ( ni00iO & n1l1i & n1iOO);
	nliOOi :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nliOOi_data,
		o => wire_nliOOi_o,
		sel => wire_nliOOi_sel
	  );
	wire_nliOOl_data <= ( "0" & wire_nlO1li_dataout & wire_nllOil_dataout);
	wire_nliOOl_sel <= ( ni00iO & n1l1i & n1iOO);
	nliOOl :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nliOOl_data,
		o => wire_nliOOl_o,
		sel => wire_nliOOl_sel
	  );
	wire_nll00O_data <= ( "0" & "1" & wire_w_lg_niiOOi445w);
	wire_nll00O_sel <= ( ni0i0l & ni0i0i & n1iOi);
	nll00O :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nll00O_data,
		o => wire_nll00O_o,
		sel => wire_nll00O_sel
	  );
	wire_nll01i_data <= ( ni0Oii & "0" & wire_nlllOi_dataout & wire_nllliO_dataout);
	wire_nll01i_sel <= ( n1liO & ni0i1i & n1iii & n1i0l);
	nll01i :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nll01i_data,
		o => wire_nll01i_o,
		sel => wire_nll01i_sel
	  );
	wire_nll01O_data <= ( "0" & "1" & wire_w_lg_niiOOi445w);
	wire_nll01O_sel <= ( ni0i1O & ni0i1l & n1iOi);
	nll01O :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nll01O_data,
		o => wire_nll01O_o,
		sel => wire_nll01O_sel
	  );
	wire_nll0iO_data <= ( "0" & "1" & niiOOi);
	wire_nll0iO_sel <= ( ni0iii & ni0i0O & n1iOi);
	nll0iO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nll0iO_data,
		o => wire_nll0iO_o,
		sel => wire_nll0iO_sel
	  );
	wire_nll0lO_data <= ( "0" & "1" & wire_w_lg_niiOOi445w);
	wire_nll0lO_sel <= ( ni0iiO & ni0iil & n1iOi);
	nll0lO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nll0lO_data,
		o => wire_nll0lO_o,
		sel => wire_nll0lO_sel
	  );
	wire_nll0OO_data <= ( "0" & "1" & niiOOi);
	wire_nll0OO_sel <= ( wire_n1lil_w_lg_w_lg_w_lg_n1liO1051w1092w1093w & ni0ili & n1iOi);
	nll0OO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nll0OO_data,
		o => wire_nll0OO_o,
		sel => wire_nll0OO_sel
	  );
	wire_nll10i_data <= ( "0" & wire_nlO1lO_dataout & wire_nllOiO_dataout & wire_nllO0i_dataout);
	wire_nll10i_sel <= ( ni00ll & n1l1i & n1iOO & n1iOl);
	nll10i :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nll10i_data,
		o => wire_nll10i_o,
		sel => wire_nll10i_sel
	  );
	wire_nll10O_data <= ( "0" & wire_nlOiii_dataout & wire_nlO1Oi_dataout & wire_w_lg_niiOOi445w);
	wire_nll10O_sel <= ( ni00lO & n1l1l & n1l1i & n1iOO);
	nll10O :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nll10O_data,
		o => wire_nll10O_o,
		sel => wire_nll10O_sel
	  );
	wire_nll11l_data <= ( "0" & "1" & wire_nllO1O_dataout);
	wire_nll11l_sel <= ( ni00li & n1iOi & n1iOl);
	nll11l :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nll11l_data,
		o => wire_nll11l_o,
		sel => wire_nll11l_sel
	  );
	wire_nll1il_data <= ( "0" & wire_nlOlOi_dataout & "1" & wire_nlOiil_dataout & wire_nlO1Ol_dataout & wire_nllOli_dataout);
	wire_nll1il_sel <= ( ni00Oi & n1l0l & wire_n1l0O_w_lg_n1l0i1211w & n1l1l & n1l1i & n1iOO);
	nll1il :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_nll1il_data,
		o => wire_nll1il_o,
		sel => wire_nll1il_sel
	  );
	wire_nll1ll_data <= ( "0" & niiOOi & wire_nlOlOl_dataout);
	wire_nll1ll_sel <= ( ni00Ol & n1lii & n1l0l);
	nll1ll :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nll1ll_data,
		o => wire_nll1ll_o,
		sel => wire_nll1ll_sel
	  );
	wire_nll1Ol_data <= ( wire_w_lg_ni0Oii1237w & wire_w_lg_niiOOi445w & wire_nlOO1i_dataout & "0" & wire_nllllO_dataout & wire_nlllil_dataout);
	wire_nll1Ol_sel <= ( n1liO & n1lii & n1l0l & ni00OO & n1iii & n1i0l);
	nll1Ol :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_nll1Ol_data,
		o => wire_nll1Ol_o,
		sel => wire_nll1Ol_sel
	  );
	wire_nlli0i_data <= ( "0" & "1" & niiOOi);
	wire_nlli0i_sel <= ( ni0ilO & ni0ill & n1iOi);
	nlli0i :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlli0i_data,
		o => wire_nlli0i_o,
		sel => wire_nlli0i_sel
	  );
	wire_nlliil_data <= ( "0" & niiOOi);
	wire_nlliil_sel <= ( ni0iOi & wire_w_lg_ni0iOi1037w);
	nlliil :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlliil_data,
		o => wire_nlliil_o,
		sel => wire_nlliil_sel
	  );
	wire_nllili_data <= ( "0" & niiOOi);
	wire_nllili_sel <= ( ni0iOl & wire_w_lg_ni0iOl1019w);
	nllili :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nllili_data,
		o => wire_nllili_o,
		sel => wire_nllili_sel
	  );
	wire_nllilO_data <= ( "0" & niiOOi);
	wire_nllilO_sel <= ( ni0l1i & wire_w_lg_ni0l1i983w);
	nllilO :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nllilO_data,
		o => wire_nllilO_o,
		sel => wire_nllilO_sel
	  );
	wire_nlliOi_data <= ( "0" & niiOOi);
	wire_nlliOi_sel <= ( ni0iOO & wire_w_lg_ni0iOO996w);
	nlliOi :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlliOi_data,
		o => wire_nlliOi_o,
		sel => wire_nlliOi_sel
	  );
	wire_nlliOO_data <= ( "0" & niiOOi);
	wire_nlliOO_sel <= ( ni0l1i & wire_w_lg_ni0l1i983w);
	nlliOO :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlliOO_data,
		o => wire_nlliOO_o,
		sel => wire_nlliOO_sel
	  );
	wire_nlll0i_data <= ( "0" & niiOOi);
	wire_nlll0i_sel <= ( ni0l1O & wire_w_lg_ni0l1O957w);
	nlll0i :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlll0i_data,
		o => wire_nlll0i_o,
		sel => wire_nlll0i_sel
	  );
	wire_nlll0O_data <= ( "0" & wire_nlOllO_dataout & niiOOi & niiOOi & niiOOi & niiOOi & niiOOi & niiOOi & niiOOi & niiOOi & niiOOi);
	wire_nlll0O_sel <= ( ni0l0i & n1l0l & n1l1i & n1iOO & n1iOi & n1iOl & n1ilO & n1ill & n1ili & n1iil & n1iii);
	nlll0O :  oper_selector
	  GENERIC MAP (
		width_data => 11,
		width_sel => 11
	  )
	  PORT MAP ( 
		data => wire_nlll0O_data,
		o => wire_nlll0O_o,
		sel => wire_nlll0O_sel
	  );
	wire_nlll1l_data <= ( "0" & niiOOi);
	wire_nlll1l_sel <= ( ni0l1l & wire_w_lg_ni0l1l970w);
	nlll1l :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlll1l_data,
		o => wire_nlll1l_o,
		sel => wire_nlll1l_sel
	  );

 END RTL; --stratixiv_hssi_tx_digi_bist_gen
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 106 mux21 189 oper_add 1 oper_decoder 1 oper_mux 23 oper_selector 23 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_tx_digi_prbs_gen IS 
	 PORT 
	 ( 
		 cid_en	:	IN  STD_LOGIC;
		 prbs_out	:	OUT  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 rcid_len	:	IN  STD_LOGIC_VECTOR (7 DOWNTO 0);
		 rcid_pattern	:	IN  STD_LOGIC;
		 rpma_doublewidth_tx	:	IN  STD_LOGIC;
		 rpmadwidth_tx	:	IN  STD_LOGIC;
		 rprbs_en_tx	:	IN  STD_LOGIC;
		 rprbs_sel	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 soft_reset	:	IN  STD_LOGIC;
		 tx_clk	:	IN  STD_LOGIC
	 ); 
 END stratixiv_hssi_tx_digi_prbs_gen;

 ARCHITECTURE RTL OF stratixiv_hssi_tx_digi_prbs_gen IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 nll00l33	:	STD_LOGIC := '0';
	 SIGNAL	 nll00l34	:	STD_LOGIC := '0';
	 SIGNAL  wire_nll00l34_w_lg_w_lg_q141w142w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll00l34_w_lg_q141w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nll01i37	:	STD_LOGIC := '0';
	 SIGNAL	 nll01i38	:	STD_LOGIC := '0';
	 SIGNAL  wire_nll01i38_w_lg_w_lg_q152w153w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll01i38_w_lg_q152w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nll01O35	:	STD_LOGIC := '0';
	 SIGNAL	 nll01O36	:	STD_LOGIC := '0';
	 SIGNAL	 nll0ii31	:	STD_LOGIC := '0';
	 SIGNAL	 nll0ii32	:	STD_LOGIC := '0';
	 SIGNAL	 nll0iO29	:	STD_LOGIC := '0';
	 SIGNAL	 nll0iO30	:	STD_LOGIC := '0';
	 SIGNAL	 nll0Ol27	:	STD_LOGIC := '0';
	 SIGNAL	 nll0Ol28	:	STD_LOGIC := '0';
	 SIGNAL	 nll1ii45	:	STD_LOGIC := '0';
	 SIGNAL	 nll1ii46	:	STD_LOGIC := '0';
	 SIGNAL	 nll1li43	:	STD_LOGIC := '0';
	 SIGNAL	 nll1li44	:	STD_LOGIC := '0';
	 SIGNAL	 nll1lO41	:	STD_LOGIC := '0';
	 SIGNAL	 nll1lO42	:	STD_LOGIC := '0';
	 SIGNAL	 nll1Ol39	:	STD_LOGIC := '0';
	 SIGNAL	 nll1Ol40	:	STD_LOGIC := '0';
	 SIGNAL  wire_nll1Ol40_w_lg_w_lg_q157w158w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll1Ol40_w_lg_q157w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlli0l23	:	STD_LOGIC := '0';
	 SIGNAL	 nlli0l24	:	STD_LOGIC := '0';
	 SIGNAL	 nlli1O25	:	STD_LOGIC := '0';
	 SIGNAL	 nlli1O26	:	STD_LOGIC := '0';
	 SIGNAL	 nlliil21	:	STD_LOGIC := '0';
	 SIGNAL	 nlliil22	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlliil22_w_lg_w_lg_q93w94w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlliil22_w_lg_q93w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlliiO19	:	STD_LOGIC := '0';
	 SIGNAL	 nlliiO20	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlliiO20_w_lg_w_lg_q88w89w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlliiO20_w_lg_q88w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nllill17	:	STD_LOGIC := '0';
	 SIGNAL	 nllill18	:	STD_LOGIC := '0';
	 SIGNAL  wire_nllill18_w_lg_w_lg_q79w80w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllill18_w_lg_q79w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlliOi15	:	STD_LOGIC := '0';
	 SIGNAL	 nlliOi16	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlliOi16_w_lg_w_lg_q69w70w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlliOi16_w_lg_q69w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlll0O11	:	STD_LOGIC := '0';
	 SIGNAL	 nlll0O12	:	STD_LOGIC := '0';
	 SIGNAL	 nlll1i13	:	STD_LOGIC := '0';
	 SIGNAL	 nlll1i14	:	STD_LOGIC := '0';
	 SIGNAL	 nlllil10	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlllil10_w_lg_w_lg_q20w21w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlllil10_w_lg_q20w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlllil9	:	STD_LOGIC := '0';
	 SIGNAL	 nllliO7	:	STD_LOGIC := '0';
	 SIGNAL	 nllliO8	:	STD_LOGIC := '0';
	 SIGNAL  wire_nllliO8_w_lg_w_lg_q17w18w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllliO8_w_lg_q17w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlllli5	:	STD_LOGIC := '0';
	 SIGNAL	 nlllli6	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlllli6_w_lg_w_lg_q12w13w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlllli6_w_lg_q12w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlllll3	:	STD_LOGIC := '0';
	 SIGNAL	 nlllll4	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlllll4_w_lg_w_lg_q7w8w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlllll4_w_lg_q7w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlllOl1	:	STD_LOGIC := '0';
	 SIGNAL	 nlllOl2	:	STD_LOGIC := '0';
	 SIGNAL	ni0O	:	STD_LOGIC := '0';
	 SIGNAL	nlO0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlO0OO	:	STD_LOGIC := '0';
	 SIGNAL	nlOi0i	:	STD_LOGIC := '0';
	 SIGNAL	nlOi0l	:	STD_LOGIC := '0';
	 SIGNAL	nlOi0O	:	STD_LOGIC := '0';
	 SIGNAL	nlOi1i	:	STD_LOGIC := '0';
	 SIGNAL	nlOi1l	:	STD_LOGIC := '0';
	 SIGNAL	nlOi1O	:	STD_LOGIC := '0';
	 SIGNAL	nlOiii	:	STD_LOGIC := '0';
	 SIGNAL	nlOiil	:	STD_LOGIC := '0';
	 SIGNAL	nlOiiO	:	STD_LOGIC := '0';
	 SIGNAL	nlOili	:	STD_LOGIC := '0';
	 SIGNAL	nlOill	:	STD_LOGIC := '0';
	 SIGNAL	nlOilO	:	STD_LOGIC := '0';
	 SIGNAL	nlOiOi	:	STD_LOGIC := '0';
	 SIGNAL	nlOiOl	:	STD_LOGIC := '0';
	 SIGNAL	nlOiOO	:	STD_LOGIC := '0';
	 SIGNAL	nlOl1i	:	STD_LOGIC := '0';
	 SIGNAL	nlOl1l	:	STD_LOGIC := '0';
	 SIGNAL	nlOl1O	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni0l_PRN	:	STD_LOGIC;
	 SIGNAL  wire_ni0l_w_lg_ni0O182w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n0i	:	STD_LOGIC := '0';
	 SIGNAL	n1i	:	STD_LOGIC := '0';
	 SIGNAL	n1l	:	STD_LOGIC := '0';
	 SIGNAL	n1O	:	STD_LOGIC := '0';
	 SIGNAL	nili	:	STD_LOGIC := '0';
	 SIGNAL	nill	:	STD_LOGIC := '0';
	 SIGNAL	nlll	:	STD_LOGIC := '0';
	 SIGNAL	nllO	:	STD_LOGIC := '0';
	 SIGNAL	nlOi	:	STD_LOGIC := '0';
	 SIGNAL	nlOl	:	STD_LOGIC := '0';
	 SIGNAL	nlOl0i	:	STD_LOGIC := '0';
	 SIGNAL	nlOl0l	:	STD_LOGIC := '0';
	 SIGNAL	nlOl0O	:	STD_LOGIC := '0';
	 SIGNAL	nlOlii	:	STD_LOGIC := '0';
	 SIGNAL	nlOlil	:	STD_LOGIC := '0';
	 SIGNAL	nlOliO	:	STD_LOGIC := '0';
	 SIGNAL	nlOlli	:	STD_LOGIC := '0';
	 SIGNAL	nlOlll	:	STD_LOGIC := '0';
	 SIGNAL	nlOllO	:	STD_LOGIC := '0';
	 SIGNAL	nlOlOi	:	STD_LOGIC := '0';
	 SIGNAL	nlOlOl	:	STD_LOGIC := '0';
	 SIGNAL	nlOlOO	:	STD_LOGIC := '0';
	 SIGNAL	nlOO	:	STD_LOGIC := '0';
	 SIGNAL	nlOO0i	:	STD_LOGIC := '0';
	 SIGNAL	nlOO0l	:	STD_LOGIC := '0';
	 SIGNAL	nlOO0O	:	STD_LOGIC := '0';
	 SIGNAL	nlOO1i	:	STD_LOGIC := '0';
	 SIGNAL	nlOO1l	:	STD_LOGIC := '0';
	 SIGNAL	nlOO1O	:	STD_LOGIC := '0';
	 SIGNAL	nlOOii	:	STD_LOGIC := '0';
	 SIGNAL	nlOOil	:	STD_LOGIC := '0';
	 SIGNAL	nlOOiO	:	STD_LOGIC := '0';
	 SIGNAL	nlOOli	:	STD_LOGIC := '0';
	 SIGNAL	nlOOll	:	STD_LOGIC := '0';
	 SIGNAL	nlOOlO	:	STD_LOGIC := '0';
	 SIGNAL	nO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_w_lg_nlOlll2157w2180w2181w2182w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_w_lg_nlOlll2189w2190w2191w2192w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_nlOlll2157w2180w2181w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_nlOlll2189w2190w2191w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_n0i61w62w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlOlll2157w2180w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlOlll2189w2190w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_n0i61w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOlll2157w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_n1i2167w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_n1l2165w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_n1O2164w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlll2177w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nllO2175w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOi2173w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOl0i2187w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOl0l2185w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOl0O2183w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOl2171w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOlii2193w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOliO2179w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOlll2189w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOO2169w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOOlO103w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w144w145w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w144w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_w_lg_nlOlll137w138w139w143w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_nlOlll137w138w139w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlOlll1321w1322w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlOlll137w138w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlOO0i869w870w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlOO0l1760w1761w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlOO0O1692w1693w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlOO1O939w940w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlOOii955w956w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlOOil885w886w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOl0O1719w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOlii1254w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOlii1651w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOliO1625w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOlli1560w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOlli1530w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOlll1321w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOlll1465w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOlll137w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOllO1400w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOlOi1333w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOlOl1744w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOlOO1280w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOlOO1676w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOO0i869w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOO0l1760w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOO0l1227w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOO0O1692w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOO0O1159w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOO1i1212w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOO1l1144w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOO1O939w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOO1O1076w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOOii1091w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOOii955w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOOil885w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOOil1023w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nilO	:	STD_LOGIC := '0';
	 SIGNAL	nlil	:	STD_LOGIC := '0';
	 SIGNAL	nlli	:	STD_LOGIC := '0';
	 SIGNAL	wire_nliO_PRN	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni_a	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_ni_b	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_gnd	:	STD_LOGIC;
	 SIGNAL  wire_ni_o	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_n00ii_w_lg_w_lg_w_o_range106w1878w1941w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00ii_w_lg_w_lg_w_o_range106w1961w1962w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00ii_w_lg_w_o_range106w1878w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00ii_w_lg_w_o_range106w1961w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00ii_i	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n00ii_o	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n00ii_w_o_range106w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00ii_w_o_range1798w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00ii_w_o_range1824w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00ii_w_o_range1839w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00il_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n00il_o	:	STD_LOGIC;
	 SIGNAL  wire_n00il_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n00iO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n00iO_o	:	STD_LOGIC;
	 SIGNAL  wire_n00iO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n00li_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n00li_o	:	STD_LOGIC;
	 SIGNAL  wire_n00li_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n00ll_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n00ll_o	:	STD_LOGIC;
	 SIGNAL  wire_n00ll_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n00lO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n00lO_o	:	STD_LOGIC;
	 SIGNAL  wire_n00lO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n00Oi_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n00Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_n00Oi_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n00Ol_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n00Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_n00Ol_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n00OO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n00OO_o	:	STD_LOGIC;
	 SIGNAL  wire_n00OO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0i0i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0i0i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i0i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0i0l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0i0l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i0l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0i0O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0i0O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i0O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0i1i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0i1i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i1i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0i1l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0i1l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i1l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0i1O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0i1O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i1O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0iii_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0iii_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iii_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0iil_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0iil_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iil_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0iiO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0iiO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iiO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0ili_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0ili_o	:	STD_LOGIC;
	 SIGNAL  wire_n0ili_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0ill_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0ill_o	:	STD_LOGIC;
	 SIGNAL  wire_n0ill_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0ilO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0ilO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0ilO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0iOi_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0iOi_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iOi_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0iOl_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0iOl_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iOl_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0iOO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0iOO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iOO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n000i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n000i_o	:	STD_LOGIC;
	 SIGNAL  wire_n000i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n001O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n001O_o	:	STD_LOGIC;
	 SIGNAL  wire_n001O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n010i_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n010i_o	:	STD_LOGIC;
	 SIGNAL  wire_n010i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n010O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n010O_o	:	STD_LOGIC;
	 SIGNAL  wire_n010O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n011i_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n011i_o	:	STD_LOGIC;
	 SIGNAL  wire_n011i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n011l_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n011l_o	:	STD_LOGIC;
	 SIGNAL  wire_n011l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n011O_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n011O_o	:	STD_LOGIC;
	 SIGNAL  wire_n011O_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n01iO_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n01iO_o	:	STD_LOGIC;
	 SIGNAL  wire_n01iO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n01ll_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n01ll_o	:	STD_LOGIC;
	 SIGNAL  wire_n01ll_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n01lO_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n01lO_o	:	STD_LOGIC;
	 SIGNAL  wire_n01lO_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n01Oi_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n01Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_n01Oi_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n01Ol_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n01Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_n01Ol_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n1O0O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1O0O_o	:	STD_LOGIC;
	 SIGNAL  wire_n1O0O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oii_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oii_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oil_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oil_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1OiO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1OiO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OiO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oli_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oli_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oli_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oll_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oll_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oll_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1OlO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1OlO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OlO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1OOi_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1OOi_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OOi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niOO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOO_o	:	STD_LOGIC;
	 SIGNAL  wire_niOO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl1i_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl1l_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlli0i2123w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlliii115w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nllili85w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nllilO77w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlliOl66w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlll0i60w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rpma_doublewidth_tx2149w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rpmadwidth_tx2148w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_soft_reset2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w160w161w162w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w160w161w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w160w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_nlli1i150w154w155w159w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_nlli1i150w154w155w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nliOli815w816w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nliOll745w746w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nliOlO675w676w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nliOOi538w539w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nliOOl469w470w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nll10i729w730w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nll11O799w800w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlli1i150w154w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliO0O1363w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliO1l1348w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliOli815w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliOll745w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliOlO675w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliOOi607w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliOOi538w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliOOl469w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nll10i729w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nll10l1129w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nll10O1197w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nll11O799w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nll1iO1265w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlli1i150w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  nliiOO :	STD_LOGIC;
	 SIGNAL  nlil0i :	STD_LOGIC;
	 SIGNAL  nlil0l :	STD_LOGIC;
	 SIGNAL  nlil0O :	STD_LOGIC;
	 SIGNAL  nlil1i :	STD_LOGIC;
	 SIGNAL  nlil1l :	STD_LOGIC;
	 SIGNAL  nlil1O :	STD_LOGIC;
	 SIGNAL  nlilii :	STD_LOGIC;
	 SIGNAL  nlilil :	STD_LOGIC;
	 SIGNAL  nliliO :	STD_LOGIC;
	 SIGNAL  nlilli :	STD_LOGIC;
	 SIGNAL  nlilll :	STD_LOGIC;
	 SIGNAL  nlillO :	STD_LOGIC;
	 SIGNAL  nlilOi :	STD_LOGIC;
	 SIGNAL  nlilOl :	STD_LOGIC;
	 SIGNAL  nlilOO :	STD_LOGIC;
	 SIGNAL  nliO0i :	STD_LOGIC;
	 SIGNAL  nliO0l :	STD_LOGIC;
	 SIGNAL  nliO0O :	STD_LOGIC;
	 SIGNAL  nliO1i :	STD_LOGIC;
	 SIGNAL  nliO1l :	STD_LOGIC;
	 SIGNAL  nliO1O :	STD_LOGIC;
	 SIGNAL  nliOii :	STD_LOGIC;
	 SIGNAL  nliOil :	STD_LOGIC;
	 SIGNAL  nliOiO :	STD_LOGIC;
	 SIGNAL  nliOli :	STD_LOGIC;
	 SIGNAL  nliOll :	STD_LOGIC;
	 SIGNAL  nliOlO :	STD_LOGIC;
	 SIGNAL  nliOOi :	STD_LOGIC;
	 SIGNAL  nliOOl :	STD_LOGIC;
	 SIGNAL  nliOOO :	STD_LOGIC;
	 SIGNAL  nll0ll :	STD_LOGIC;
	 SIGNAL  nll0lO :	STD_LOGIC;
	 SIGNAL  nll0Oi :	STD_LOGIC;
	 SIGNAL  nll10i :	STD_LOGIC;
	 SIGNAL  nll10l :	STD_LOGIC;
	 SIGNAL  nll10O :	STD_LOGIC;
	 SIGNAL  nll11i :	STD_LOGIC;
	 SIGNAL  nll11l :	STD_LOGIC;
	 SIGNAL  nll11O :	STD_LOGIC;
	 SIGNAL  nll1iO :	STD_LOGIC;
	 SIGNAL  nlli0i :	STD_LOGIC;
	 SIGNAL  nlli1i :	STD_LOGIC;
	 SIGNAL  nlli1l :	STD_LOGIC;
	 SIGNAL  nlliii :	STD_LOGIC;
	 SIGNAL  nllili :	STD_LOGIC;
	 SIGNAL  nllilO :	STD_LOGIC;
	 SIGNAL  nlliOl :	STD_LOGIC;
	 SIGNAL  nlliOO :	STD_LOGIC;
	 SIGNAL  nlll0i :	STD_LOGIC;
	 SIGNAL  nlll0l :	STD_LOGIC;
	 SIGNAL  nlll1O :	STD_LOGIC;
	 SIGNAL  nllllO :	STD_LOGIC;
 BEGIN

	wire_gnd <= '0';
	wire_w_lg_nlli0i2123w(0) <= NOT nlli0i;
	wire_w_lg_nlliii115w(0) <= NOT nlliii;
	wire_w_lg_nllili85w(0) <= NOT nllili;
	wire_w_lg_nllilO77w(0) <= NOT nllilO;
	wire_w_lg_nlliOl66w(0) <= NOT nlliOl;
	wire_w_lg_nlll0i60w(0) <= NOT nlll0i;
	wire_w_lg_rpma_doublewidth_tx2149w(0) <= NOT rpma_doublewidth_tx;
	wire_w_lg_rpmadwidth_tx2148w(0) <= NOT rpmadwidth_tx;
	wire_w_lg_soft_reset2w(0) <= NOT soft_reset;
	wire_w_lg_w_lg_w160w161w162w(0) <= wire_w_lg_w160w161w(0) XOR nlOl0i;
	wire_w_lg_w160w161w(0) <= wire_w160w(0) XOR nlOl0l;
	wire_w160w(0) <= wire_w_lg_w_lg_w_lg_w_lg_nlli1i150w154w155w159w(0) XOR nlOl0O;
	wire_w_lg_w_lg_w_lg_w_lg_nlli1i150w154w155w159w(0) <= wire_w_lg_w_lg_w_lg_nlli1i150w154w155w(0) XOR wire_nll1Ol40_w_lg_w_lg_q157w158w(0);
	wire_w_lg_w_lg_w_lg_nlli1i150w154w155w(0) <= wire_w_lg_w_lg_nlli1i150w154w(0) XOR nlOlii;
	wire_w_lg_w_lg_nliOli815w816w(0) <= wire_w_lg_nliOli815w(0) XOR nlOO1l;
	wire_w_lg_w_lg_nliOll745w746w(0) <= wire_w_lg_nliOll745w(0) XOR nlOO1O;
	wire_w_lg_w_lg_nliOlO675w676w(0) <= wire_w_lg_nliOlO675w(0) XOR nlOO0i;
	wire_w_lg_w_lg_nliOOi538w539w(0) <= wire_w_lg_nliOOi538w(0) XOR nlOO1l;
	wire_w_lg_w_lg_nliOOl469w470w(0) <= wire_w_lg_nliOOl469w(0) XOR nlOO1l;
	wire_w_lg_w_lg_nll10i729w730w(0) <= wire_w_lg_nll10i729w(0) XOR nlOlOl;
	wire_w_lg_w_lg_nll11O799w800w(0) <= wire_w_lg_nll11O799w(0) XOR nlOlOi;
	wire_w_lg_w_lg_nlli1i150w154w(0) <= wire_w_lg_nlli1i150w(0) XOR wire_nll01i38_w_lg_w_lg_q152w153w(0);
	wire_w_lg_nliO0O1363w(0) <= nliO0O XOR nlOO1l;
	wire_w_lg_nliO1l1348w(0) <= nliO1l XOR nlOlOi;
	wire_w_lg_nliOli815w(0) <= nliOli XOR nlOO1O;
	wire_w_lg_nliOll745w(0) <= nliOll XOR nlOO0i;
	wire_w_lg_nliOlO675w(0) <= nliOlO XOR nlOO0l;
	wire_w_lg_nliOOi607w(0) <= nliOOi XOR nlOO0l;
	wire_w_lg_nliOOi538w(0) <= nliOOi XOR nlOO1O;
	wire_w_lg_nliOOl469w(0) <= nliOOl XOR nlOO0i;
	wire_w_lg_nll10i729w(0) <= nll10i XOR nlOlOO;
	wire_w_lg_nll10l1129w(0) <= nll10l XOR nlOlOi;
	wire_w_lg_nll10O1197w(0) <= nll10O XOR nlOllO;
	wire_w_lg_nll11O799w(0) <= nll11O XOR nlOlOl;
	wire_w_lg_nll1iO1265w(0) <= nll1iO XOR nlOlll;
	wire_w_lg_nlli1i150w(0) <= nlli1i XOR nlOliO;
	nliiOO <= ((wire_n00ii_o(25) OR wire_n00ii_o(17)) OR wire_n00ii_o(4));
	nlil0i <= wire_n00ii_w_lg_w_o_range106w1878w(0);
	nlil0l <= (((((((((wire_n00ii_o(24) OR wire_n00ii_o(2)) OR wire_n00ii_o(28)) OR wire_n00ii_o(27)) OR wire_n00ii_o(26)) OR wire_n00ii_o(11)) OR wire_n00ii_o(10)) OR wire_n00ii_o(9)) OR wire_n00ii_o(8)) OR wire_n00ii_o(1));
	nlil0O <= ((((((((((((((((wire_n00ii_o(31) OR wire_n00ii_o(30)) OR wire_n00ii_o(29)) OR wire_n00ii_o(23)) OR wire_n00ii_o(22)) OR wire_n00ii_o(21)) OR wire_n00ii_o(20)) OR wire_n00ii_o(19)) OR wire_n00ii_o(15)) OR wire_n00ii_o(14)) OR wire_n00ii_o(13)) OR wire_n00ii_o(12)) OR wire_n00ii_o(7)) OR wire_n00ii_o(6)) OR wire_n00ii_o(5)) OR wire_n00ii_o(4)) OR wire_n00ii_o(3));
	nlil1i <= (((((((((((((((wire_n00ii_o(31) OR wire_n00ii_o(30)) OR wire_n00ii_o(29)) OR wire_n00ii_o(23)) OR wire_n00ii_o(22)) OR wire_n00ii_o(21)) OR wire_n00ii_o(20)) OR wire_n00ii_o(19)) OR wire_n00ii_o(15)) OR wire_n00ii_o(14)) OR wire_n00ii_o(13)) OR wire_n00ii_o(12)) OR wire_n00ii_o(7)) OR wire_n00ii_o(6)) OR wire_n00ii_o(5)) OR wire_n00ii_o(3));
	nlil1l <= ((((((((((wire_n00ii_o(24) OR wire_n00ii_o(2)) OR wire_n00ii_o(28)) OR wire_n00ii_o(27)) OR wire_n00ii_o(26)) OR wire_n00ii_o(25)) OR wire_n00ii_o(11)) OR wire_n00ii_o(10)) OR wire_n00ii_o(9)) OR wire_n00ii_o(8)) OR wire_n00ii_o(1));
	nlil1O <= ((((((((((wire_n00ii_o(24) OR wire_n00ii_o(2)) OR wire_n00ii_o(28)) OR wire_n00ii_o(27)) OR wire_n00ii_o(26)) OR wire_n00ii_o(17)) OR wire_n00ii_o(11)) OR wire_n00ii_o(10)) OR wire_n00ii_o(9)) OR wire_n00ii_o(8)) OR wire_n00ii_o(1));
	nlilii <= (((((((((((wire_n00ii_o(24) OR wire_n00ii_o(16)) OR wire_n00ii_o(2)) OR wire_n00ii_o(28)) OR wire_n00ii_o(27)) OR wire_n00ii_o(26)) OR wire_n00ii_o(18)) OR wire_n00ii_o(11)) OR wire_n00ii_o(10)) OR wire_n00ii_o(9)) OR wire_n00ii_o(8)) OR wire_n00ii_o(1));
	nlilil <= (((((((((((((((((wire_n00ii_o(31) OR wire_n00ii_o(30)) OR wire_n00ii_o(29)) OR wire_n00ii_o(23)) OR wire_n00ii_o(22)) OR wire_n00ii_o(21)) OR wire_n00ii_o(20)) OR wire_n00ii_o(19)) OR wire_n00ii_o(17)) OR wire_n00ii_o(15)) OR wire_n00ii_o(14)) OR wire_n00ii_o(13)) OR wire_n00ii_o(12)) OR wire_n00ii_o(7)) OR wire_n00ii_o(6)) OR wire_n00ii_o(5)) OR wire_n00ii_o(4)) OR wire_n00ii_o(3));
	nliliO <= (nlOlll XOR nlOl0O);
	nlilli <= (nlOllO XOR nlOlii);
	nlilll <= (nlOlOi XOR nlOlil);
	nlillO <= (nlOlOl XOR nlOliO);
	nlilOi <= (nlOlOO XOR nlOlli);
	nlilOl <= (nlOO1i XOR nlOlll);
	nlilOO <= (nlOO1l XOR nlOllO);
	nliO0i <= (nlOO0O XOR nlOO1i);
	nliO0l <= (nlOOii XOR nlOO1l);
	nliO0O <= (nlOOil XOR nlOO1O);
	nliO1i <= (nlOO1O XOR nlOlOi);
	nliO1l <= (nlOO0i XOR nlOlOl);
	nliO1O <= (nlOO0l XOR nlOlOO);
	nliOii <= (nlOOiO XOR nlOO0i);
	nliOil <= (nlOOli XOR nlOO0l);
	nliOiO <= (nlOOll XOR nlOO0O);
	nliOli <= (nlOO0l XOR nlOO0i);
	nliOll <= (nlOO0O XOR nlOO0l);
	nliOlO <= (nlOOii XOR nlOO0O);
	nliOOi <= (nliOOl XOR nlOO0O);
	nliOOl <= (nlOOil XOR nlOOii);
	nliOOO <= (nlOO1O XOR nlOO1l);
	nll0ll <= (nlOlil XOR nlOlii);
	nll0lO <= (nlOliO XOR nlOlil);
	nll0Oi <= ((nlOlli XOR nlOliO) XOR (NOT (nll0Ol28 XOR nll0Ol27)));
	nll10i <= (nlOO1l XOR nlOO1i);
	nll10l <= (nlOliO XOR nlOl0O);
	nll10O <= ((nlOlil XOR nlOl0l) XOR (NOT (nll1ii46 XOR nll1ii45)));
	nll11i <= (nlOO0i XOR nlOO1O);
	nll11l <= (nlOO0i XOR nlOO1l);
	nll11O <= (nlOO1i XOR nlOlOO);
	nll1iO <= ((nlOlii XOR nlOl0i) XOR (NOT (nll1li44 XOR nll1li43)));
	nlli0i <= (((wire_n00ii_o(24) OR wire_n00ii_o(16)) OR wire_n00ii_o(2)) OR (NOT (nlli0l24 XOR nlli0l23)));
	nlli1i <= (nlOlll XOR nlOlli);
	nlli1l <= (wire_niOl_dataout OR wire_niOi_dataout);
	nlliii <= (nili AND wire_nl_w_lg_nlOOlO103w(0));
	nllili <= (((((((wire_nl_w_lg_n1O2164w(0) AND wire_nl_w_lg_n1l2165w(0)) AND wire_nl_w_lg_n1i2167w(0)) AND wire_nl_w_lg_nlOO2169w(0)) AND wire_nl_w_lg_nlOl2171w(0)) AND wire_nl_w_lg_nlOi2173w(0)) AND wire_nl_w_lg_nllO2175w(0)) AND nlll);
	nllilO <= ((((((wire_nl_w_lg_nlOlll2157w(0) AND nlOliO) AND nlOlil) AND nlOlii) AND nlOl0O) AND nlOl0l) AND nlOl0i);
	nlliOl <= ((((wire_nl_w_lg_w_lg_w_lg_w_lg_nlOlll2189w2190w2191w2192w(0) AND wire_nl_w_lg_nlOlii2193w(0)) AND wire_nl_w_lg_nlOl0O2183w(0)) AND wire_nl_w_lg_nlOl0l2185w(0)) AND wire_nl_w_lg_nlOl0i2187w(0));
	nlliOO <= (wire_nl_w_lg_w_lg_n0i61w62w(0) AND (nlll1i14 XOR nlll1i13));
	nlll0i <= (((((((wire_nl_w_lg_n1O2164w(0) AND wire_nl_w_lg_n1l2165w(0)) AND wire_nl_w_lg_n1i2167w(0)) AND wire_nl_w_lg_nlOO2169w(0)) AND wire_nl_w_lg_nlOl2171w(0)) AND wire_nl_w_lg_nlOi2173w(0)) AND wire_nl_w_lg_nllO2175w(0)) AND wire_nl_w_lg_nlll2177w(0));
	nlll0l <= ((((wire_w_lg_rpmadwidth_tx2148w(0) AND wire_w_lg_rpma_doublewidth_tx2149w(0)) AND (NOT rprbs_sel(0))) AND (NOT rprbs_sel(1))) AND (NOT rprbs_sel(2)));
	nlll1O <= (((wire_nl_w_lg_w_lg_w_lg_w_lg_nlOlll2157w2180w2181w2182w(0) AND wire_nl_w_lg_nlOl0O2183w(0)) AND wire_nl_w_lg_nlOl0l2185w(0)) AND wire_nl_w_lg_nlOl0i2187w(0));
	nllllO <= '1';
	prbs_out <= ( nlOl1O & nlOl1l & nlOl1i & nlOiOO & nlOiOl & nlOiOi & nlOilO & nlOill & nlOili & nlOiiO & nlOiil & nlOiii & nlOi0O & nlOi0l & nlOi0i & nlOi1O & nlOi1l & nlOi1i & nlO0OO & nlO0Ol);
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll00l33 <= nll00l34;
		END IF;
		if (now = 0 ns) then
			nll00l33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll00l34 <= nll00l33;
		END IF;
	END PROCESS;
	wire_nll00l34_w_lg_w_lg_q141w142w(0) <= NOT wire_nll00l34_w_lg_q141w(0);
	wire_nll00l34_w_lg_q141w(0) <= nll00l34 XOR nll00l33;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll01i37 <= nll01i38;
		END IF;
		if (now = 0 ns) then
			nll01i37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll01i38 <= nll01i37;
		END IF;
	END PROCESS;
	wire_nll01i38_w_lg_w_lg_q152w153w(0) <= NOT wire_nll01i38_w_lg_q152w(0);
	wire_nll01i38_w_lg_q152w(0) <= nll01i38 XOR nll01i37;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll01O35 <= nll01O36;
		END IF;
		if (now = 0 ns) then
			nll01O35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll01O36 <= nll01O35;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll0ii31 <= nll0ii32;
		END IF;
		if (now = 0 ns) then
			nll0ii31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll0ii32 <= nll0ii31;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll0iO29 <= nll0iO30;
		END IF;
		if (now = 0 ns) then
			nll0iO29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll0iO30 <= nll0iO29;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll0Ol27 <= nll0Ol28;
		END IF;
		if (now = 0 ns) then
			nll0Ol27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll0Ol28 <= nll0Ol27;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll1ii45 <= nll1ii46;
		END IF;
		if (now = 0 ns) then
			nll1ii45 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll1ii46 <= nll1ii45;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll1li43 <= nll1li44;
		END IF;
		if (now = 0 ns) then
			nll1li43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll1li44 <= nll1li43;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll1lO41 <= nll1lO42;
		END IF;
		if (now = 0 ns) then
			nll1lO41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll1lO42 <= nll1lO41;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll1Ol39 <= nll1Ol40;
		END IF;
		if (now = 0 ns) then
			nll1Ol39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nll1Ol40 <= nll1Ol39;
		END IF;
	END PROCESS;
	wire_nll1Ol40_w_lg_w_lg_q157w158w(0) <= NOT wire_nll1Ol40_w_lg_q157w(0);
	wire_nll1Ol40_w_lg_q157w(0) <= nll1Ol40 XOR nll1Ol39;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlli0l23 <= nlli0l24;
		END IF;
		if (now = 0 ns) then
			nlli0l23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlli0l24 <= nlli0l23;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlli1O25 <= nlli1O26;
		END IF;
		if (now = 0 ns) then
			nlli1O25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlli1O26 <= nlli1O25;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlliil21 <= nlliil22;
		END IF;
		if (now = 0 ns) then
			nlliil21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlliil22 <= nlliil21;
		END IF;
	END PROCESS;
	wire_nlliil22_w_lg_w_lg_q93w94w(0) <= wire_nlliil22_w_lg_q93w(0) AND nlil;
	wire_nlliil22_w_lg_q93w(0) <= nlliil22 XOR nlliil21;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlliiO19 <= nlliiO20;
		END IF;
		if (now = 0 ns) then
			nlliiO19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlliiO20 <= nlliiO19;
		END IF;
	END PROCESS;
	wire_nlliiO20_w_lg_w_lg_q88w89w(0) <= wire_nlliiO20_w_lg_q88w(0) AND nlliOO;
	wire_nlliiO20_w_lg_q88w(0) <= nlliiO20 XOR nlliiO19;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nllill17 <= nllill18;
		END IF;
		if (now = 0 ns) then
			nllill17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nllill18 <= nllill17;
		END IF;
	END PROCESS;
	wire_nllill18_w_lg_w_lg_q79w80w(0) <= wire_nllill18_w_lg_q79w(0) AND nlil;
	wire_nllill18_w_lg_q79w(0) <= nllill18 XOR nllill17;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlliOi15 <= nlliOi16;
		END IF;
		if (now = 0 ns) then
			nlliOi15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlliOi16 <= nlliOi15;
		END IF;
	END PROCESS;
	wire_nlliOi16_w_lg_w_lg_q69w70w(0) <= wire_nlliOi16_w_lg_q69w(0) AND nilO;
	wire_nlliOi16_w_lg_q69w(0) <= nlliOi16 XOR nlliOi15;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlll0O11 <= nlll0O12;
		END IF;
		if (now = 0 ns) then
			nlll0O11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlll0O12 <= nlll0O11;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlll1i13 <= nlll1i14;
		END IF;
		if (now = 0 ns) then
			nlll1i13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlll1i14 <= nlll1i13;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlllil10 <= nlllil9;
		END IF;
	END PROCESS;
	wire_nlllil10_w_lg_w_lg_q20w21w(0) <= wire_nlllil10_w_lg_q20w(0) AND n1O;
	wire_nlllil10_w_lg_q20w(0) <= nlllil10 XOR nlllil9;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlllil9 <= nlllil10;
		END IF;
		if (now = 0 ns) then
			nlllil9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nllliO7 <= nllliO8;
		END IF;
		if (now = 0 ns) then
			nllliO7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nllliO8 <= nllliO7;
		END IF;
	END PROCESS;
	wire_nllliO8_w_lg_w_lg_q17w18w(0) <= wire_nllliO8_w_lg_q17w(0) AND n1l;
	wire_nllliO8_w_lg_q17w(0) <= nllliO8 XOR nllliO7;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlllli5 <= nlllli6;
		END IF;
		if (now = 0 ns) then
			nlllli5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlllli6 <= nlllli5;
		END IF;
	END PROCESS;
	wire_nlllli6_w_lg_w_lg_q12w13w(0) <= wire_nlllli6_w_lg_q12w(0) AND nlOl;
	wire_nlllli6_w_lg_q12w(0) <= nlllli6 XOR nlllli5;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlllll3 <= nlllll4;
		END IF;
		if (now = 0 ns) then
			nlllll3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlllll4 <= nlllll3;
		END IF;
	END PROCESS;
	wire_nlllll4_w_lg_w_lg_q7w8w(0) <= wire_nlllll4_w_lg_q7w(0) AND nlll;
	wire_nlllll4_w_lg_q7w(0) <= nlllll4 XOR nlllll3;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlllOl1 <= nlllOl2;
		END IF;
		if (now = 0 ns) then
			nlllOl1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nlllOl2 <= nlllOl1;
		END IF;
	END PROCESS;
	PROCESS (tx_clk, wire_ni0l_PRN, soft_reset)
	BEGIN
		IF (wire_ni0l_PRN = '0') THEN
				ni0O <= '1';
				nlO0Ol <= '1';
				nlO0OO <= '1';
				nlOi0i <= '1';
				nlOi0l <= '1';
				nlOi0O <= '1';
				nlOi1i <= '1';
				nlOi1l <= '1';
				nlOi1O <= '1';
				nlOiii <= '1';
				nlOiil <= '1';
				nlOiiO <= '1';
				nlOili <= '1';
				nlOill <= '1';
				nlOilO <= '1';
				nlOiOi <= '1';
				nlOiOl <= '1';
				nlOiOO <= '1';
				nlOl1i <= '1';
				nlOl1l <= '1';
				nlOl1O <= '1';
		ELSIF (soft_reset = '1') THEN
				ni0O <= '0';
				nlO0Ol <= '0';
				nlO0OO <= '0';
				nlOi0i <= '0';
				nlOi0l <= '0';
				nlOi0O <= '0';
				nlOi1i <= '0';
				nlOi1l <= '0';
				nlOi1O <= '0';
				nlOiii <= '0';
				nlOiil <= '0';
				nlOiiO <= '0';
				nlOili <= '0';
				nlOill <= '0';
				nlOilO <= '0';
				nlOiOi <= '0';
				nlOiOl <= '0';
				nlOiOO <= '0';
				nlOl1i <= '0';
				nlOl1l <= '0';
				nlOl1O <= '0';
		ELSIF (tx_clk = '1' AND tx_clk'event) THEN
			IF (nlliii = '0') THEN
				ni0O <= wire_n100O_dataout;
				nlO0Ol <= wire_n10ii_dataout;
				nlO0OO <= wire_n10il_dataout;
				nlOi0i <= wire_n10lO_dataout;
				nlOi0l <= wire_n10Oi_dataout;
				nlOi0O <= wire_n10Ol_dataout;
				nlOi1i <= wire_n10iO_dataout;
				nlOi1l <= wire_n10li_dataout;
				nlOi1O <= wire_n10ll_dataout;
				nlOiii <= wire_n10OO_dataout;
				nlOiil <= wire_n1i1i_dataout;
				nlOiiO <= wire_n1i1l_dataout;
				nlOili <= wire_n1i1O_dataout;
				nlOill <= wire_n1i0i_dataout;
				nlOilO <= wire_n1i0l_dataout;
				nlOiOi <= wire_n1i0O_dataout;
				nlOiOl <= wire_n1iii_dataout;
				nlOiOO <= wire_n1iil_dataout;
				nlOl1i <= wire_n1iiO_dataout;
				nlOl1l <= wire_n1ili_dataout;
				nlOl1O <= wire_n1ill_dataout;
			END IF;
		END IF;
	END PROCESS;
	wire_ni0l_PRN <= (nlli1O26 XOR nlli1O25);
	wire_ni0l_w_lg_ni0O182w(0) <= NOT ni0O;
	PROCESS (tx_clk, wire_nl_CLRN)
	BEGIN
		IF (wire_nl_CLRN = '0') THEN
				n0i <= '0';
				n1i <= '0';
				n1l <= '0';
				n1O <= '0';
				nili <= '0';
				nill <= '0';
				nlll <= '0';
				nllO <= '0';
				nlOi <= '0';
				nlOl <= '0';
				nlOl0i <= '0';
				nlOl0l <= '0';
				nlOl0O <= '0';
				nlOlii <= '0';
				nlOlil <= '0';
				nlOliO <= '0';
				nlOlli <= '0';
				nlOlll <= '0';
				nlOllO <= '0';
				nlOlOi <= '0';
				nlOlOl <= '0';
				nlOlOO <= '0';
				nlOO <= '0';
				nlOO0i <= '0';
				nlOO0l <= '0';
				nlOO0O <= '0';
				nlOO1i <= '0';
				nlOO1l <= '0';
				nlOO1O <= '0';
				nlOOii <= '0';
				nlOOil <= '0';
				nlOOiO <= '0';
				nlOOli <= '0';
				nlOOll <= '0';
				nlOOlO <= '0';
				nO <= '0';
		ELSIF (tx_clk = '1' AND tx_clk'event) THEN
				n0i <= nO;
				n1i <= wire_nli_dataout;
				n1l <= wire_nll_dataout;
				n1O <= wire_nlO_dataout;
				nili <= nill;
				nill <= rprbs_en_tx;
				nlll <= wire_n0l_dataout;
				nllO <= wire_n0O_dataout;
				nlOi <= wire_nii_dataout;
				nlOl <= wire_nil_dataout;
				nlOl0i <= wire_nlOOOi_dataout;
				nlOl0l <= wire_nlOOOl_dataout;
				nlOl0O <= wire_nlOOOO_dataout;
				nlOlii <= wire_n111i_dataout;
				nlOlil <= wire_n111l_dataout;
				nlOliO <= wire_n111O_dataout;
				nlOlli <= wire_n110i_dataout;
				nlOlll <= wire_n110l_dataout;
				nlOllO <= wire_n110O_dataout;
				nlOlOi <= wire_n11ii_dataout;
				nlOlOl <= wire_n11il_dataout;
				nlOlOO <= wire_n11iO_dataout;
				nlOO <= wire_niO_dataout;
				nlOO0i <= wire_n11Oi_dataout;
				nlOO0l <= wire_n11Ol_dataout;
				nlOO0O <= wire_n11OO_dataout;
				nlOO1i <= wire_n11li_dataout;
				nlOO1l <= wire_n11ll_dataout;
				nlOO1O <= wire_n11lO_dataout;
				nlOOii <= wire_n101i_dataout;
				nlOOil <= wire_n101l_dataout;
				nlOOiO <= wire_n101O_dataout;
				nlOOli <= wire_n100i_dataout;
				nlOOll <= wire_n100l_dataout;
				nlOOlO <= nili;
				nO <= cid_en;
		END IF;
	END PROCESS;
	wire_nl_CLRN <= ((nlllOl2 XOR nlllOl1) AND wire_w_lg_soft_reset2w(0));
	wire_nl_w_lg_w_lg_w_lg_w_lg_nlOlll2157w2180w2181w2182w(0) <= wire_nl_w_lg_w_lg_w_lg_nlOlll2157w2180w2181w(0) AND nlOlii;
	wire_nl_w_lg_w_lg_w_lg_w_lg_nlOlll2189w2190w2191w2192w(0) <= wire_nl_w_lg_w_lg_w_lg_nlOlll2189w2190w2191w(0) AND nlOlil;
	wire_nl_w_lg_w_lg_w_lg_nlOlll2157w2180w2181w(0) <= wire_nl_w_lg_w_lg_nlOlll2157w2180w(0) AND nlOlil;
	wire_nl_w_lg_w_lg_w_lg_nlOlll2189w2190w2191w(0) <= wire_nl_w_lg_w_lg_nlOlll2189w2190w(0) AND wire_nl_w_lg_nlOliO2179w(0);
	wire_nl_w_lg_w_lg_n0i61w62w(0) <= wire_nl_w_lg_n0i61w(0) AND nlll1O;
	wire_nl_w_lg_w_lg_nlOlll2157w2180w(0) <= wire_nl_w_lg_nlOlll2157w(0) AND wire_nl_w_lg_nlOliO2179w(0);
	wire_nl_w_lg_w_lg_nlOlll2189w2190w(0) <= wire_nl_w_lg_nlOlll2189w(0) AND nlOlli;
	wire_nl_w_lg_n0i61w(0) <= n0i AND wire_w_lg_nlll0i60w(0);
	wire_nl_w_lg_nlOlll2157w(0) <= nlOlll AND nlOlli;
	wire_nl_w_lg_n1i2167w(0) <= NOT n1i;
	wire_nl_w_lg_n1l2165w(0) <= NOT n1l;
	wire_nl_w_lg_n1O2164w(0) <= NOT n1O;
	wire_nl_w_lg_nlll2177w(0) <= NOT nlll;
	wire_nl_w_lg_nllO2175w(0) <= NOT nllO;
	wire_nl_w_lg_nlOi2173w(0) <= NOT nlOi;
	wire_nl_w_lg_nlOl0i2187w(0) <= NOT nlOl0i;
	wire_nl_w_lg_nlOl0l2185w(0) <= NOT nlOl0l;
	wire_nl_w_lg_nlOl0O2183w(0) <= NOT nlOl0O;
	wire_nl_w_lg_nlOl2171w(0) <= NOT nlOl;
	wire_nl_w_lg_nlOlii2193w(0) <= NOT nlOlii;
	wire_nl_w_lg_nlOliO2179w(0) <= NOT nlOliO;
	wire_nl_w_lg_nlOlll2189w(0) <= NOT nlOlll;
	wire_nl_w_lg_nlOO2169w(0) <= NOT nlOO;
	wire_nl_w_lg_nlOOlO103w(0) <= NOT nlOOlO;
	wire_nl_w_lg_w144w145w(0) <= wire_nl_w144w(0) XOR nlOl0i;
	wire_nl_w144w(0) <= wire_nl_w_lg_w_lg_w_lg_w_lg_nlOlll137w138w139w143w(0) XOR nlOl0O;
	wire_nl_w_lg_w_lg_w_lg_w_lg_nlOlll137w138w139w143w(0) <= wire_nl_w_lg_w_lg_w_lg_nlOlll137w138w139w(0) XOR wire_nll00l34_w_lg_w_lg_q141w142w(0);
	wire_nl_w_lg_w_lg_w_lg_nlOlll137w138w139w(0) <= wire_nl_w_lg_w_lg_nlOlll137w138w(0) XOR nlOlii;
	wire_nl_w_lg_w_lg_nlOlll1321w1322w(0) <= wire_nl_w_lg_nlOlll1321w(0) XOR nlOl0O;
	wire_nl_w_lg_w_lg_nlOlll137w138w(0) <= wire_nl_w_lg_nlOlll137w(0) XOR nlOlil;
	wire_nl_w_lg_w_lg_nlOO0i869w870w(0) <= wire_nl_w_lg_nlOO0i869w(0) XOR nlOlOl;
	wire_nl_w_lg_w_lg_nlOO0l1760w1761w(0) <= wire_nl_w_lg_nlOO0l1760w(0) XOR nlOOli;
	wire_nl_w_lg_w_lg_nlOO0O1692w1693w(0) <= wire_nl_w_lg_nlOO0O1692w(0) XOR nlOOll;
	wire_nl_w_lg_w_lg_nlOO1O939w940w(0) <= wire_nl_w_lg_nlOO1O939w(0) XOR nlOlOi;
	wire_nl_w_lg_w_lg_nlOOii955w956w(0) <= wire_nl_w_lg_nlOOii955w(0) XOR nlOO1l;
	wire_nl_w_lg_w_lg_nlOOil885w886w(0) <= wire_nl_w_lg_nlOOil885w(0) XOR nlOO1O;
	wire_nl_w_lg_nlOl0O1719w(0) <= nlOl0O XOR nlOl0l;
	wire_nl_w_lg_nlOlii1254w(0) <= nlOlii XOR nlOl0l;
	wire_nl_w_lg_nlOlii1651w(0) <= nlOlii XOR nlOl0O;
	wire_nl_w_lg_nlOliO1625w(0) <= nlOliO XOR nlOl0i;
	wire_nl_w_lg_nlOlli1560w(0) <= nlOlli XOR nlOl0l;
	wire_nl_w_lg_nlOlli1530w(0) <= nlOlli XOR nlOlii;
	wire_nl_w_lg_nlOlll1321w(0) <= nlOlll XOR nlOl0l;
	wire_nl_w_lg_nlOlll1465w(0) <= nlOlll XOR nlOlil;
	wire_nl_w_lg_nlOlll137w(0) <= nlOlll XOR nlOliO;
	wire_nl_w_lg_nlOllO1400w(0) <= nlOllO XOR nlOliO;
	wire_nl_w_lg_nlOlOi1333w(0) <= nlOlOi XOR nlOlli;
	wire_nl_w_lg_nlOlOl1744w(0) <= nlOlOl XOR nlOlOi;
	wire_nl_w_lg_nlOlOO1280w(0) <= nlOlOO XOR nlOlOi;
	wire_nl_w_lg_nlOlOO1676w(0) <= nlOlOO XOR nlOlOl;
	wire_nl_w_lg_nlOO0i869w(0) <= nlOO0i XOR nlOlOO;
	wire_nl_w_lg_nlOO0l1760w(0) <= nlOO0l XOR nlOlii;
	wire_nl_w_lg_nlOO0l1227w(0) <= nlOO0l XOR nlOO1O;
	wire_nl_w_lg_nlOO0O1692w(0) <= nlOO0O XOR nlOlil;
	wire_nl_w_lg_nlOO0O1159w(0) <= nlOO0O XOR nlOO0i;
	wire_nl_w_lg_nlOO1i1212w(0) <= nlOO1i XOR nlOlOl;
	wire_nl_w_lg_nlOO1l1144w(0) <= nlOO1l XOR nlOlOO;
	wire_nl_w_lg_nlOO1O939w(0) <= nlOO1O XOR nlOlOl;
	wire_nl_w_lg_nlOO1O1076w(0) <= nlOO1O XOR nlOO1i;
	wire_nl_w_lg_nlOOii1091w(0) <= nlOOii XOR nlOO0l;
	wire_nl_w_lg_nlOOii955w(0) <= nlOOii XOR nlOO1O;
	wire_nl_w_lg_nlOOil885w(0) <= nlOOil XOR nlOO0i;
	wire_nl_w_lg_nlOOil1023w(0) <= nlOOil XOR nlOO0O;
	PROCESS (tx_clk, soft_reset)
	BEGIN
		IF (soft_reset = '1') THEN
				nilO <= '0';
				nlil <= '0';
		ELSIF (tx_clk = '1' AND tx_clk'event) THEN
			IF (nlll0l = '1') THEN
				nilO <= wire_niOO_o;
				nlil <= wire_nl1i_o;
			END IF;
		END IF;
	END PROCESS;
	PROCESS (tx_clk, wire_nliO_PRN)
	BEGIN
		IF (wire_nliO_PRN = '0') THEN
				nlli <= '1';
		ELSIF (tx_clk = '1' AND tx_clk'event) THEN
			IF (nlll0l = '1') THEN
				nlli <= wire_nl1l_o;
			END IF;
		END IF;
		if (now = 0 ns) then
			nlli <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nliO_PRN <= ((nlll0O12 XOR nlll0O11) AND wire_w_lg_soft_reset2w(0));
	wire_n0l_dataout <= wire_ni_o(1) WHEN wire_niOi_dataout = '1'  ELSE rcid_len(0);
	wire_n0O_dataout <= wire_ni_o(2) WHEN wire_niOi_dataout = '1'  ELSE rcid_len(1);
	wire_n100i_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1O1O_dataout;
	wire_n100l_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1O0i_dataout;
	wire_n100O_dataout <= wire_n1O0l_dataout WHEN nlOOlO = '1'  ELSE ni0O;
	wire_n101i_dataout <= (NOT (wire_n00ii_o(16) OR wire_n00ii_o(2))) WHEN nlliii = '1'  ELSE wire_n1lOO_dataout;
	wire_n101l_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1O1i_dataout;
	wire_n101O_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1O1l_dataout;
	wire_n10i_dataout <= nlOO0i AND nlli1l;
	wire_n10ii_dataout <= wire_n1O0O_o WHEN nlOOlO = '1'  ELSE nlO0Ol;
	wire_n10il_dataout <= wire_n1Oii_o WHEN nlOOlO = '1'  ELSE nlO0OO;
	wire_n10iO_dataout <= wire_n1Oil_o WHEN nlOOlO = '1'  ELSE nlOi1i;
	wire_n10l_dataout <= nlOO0l AND nlli1l;
	wire_n10li_dataout <= wire_n1OiO_o WHEN nlOOlO = '1'  ELSE nlOi1l;
	wire_n10ll_dataout <= wire_n1Oli_o WHEN nlOOlO = '1'  ELSE nlOi1O;
	wire_n10lO_dataout <= wire_n1Oll_o WHEN nlOOlO = '1'  ELSE nlOi0i;
	wire_n10O_dataout <= nlOO0O AND nlli1l;
	wire_n10Oi_dataout <= wire_n1OlO_o WHEN nlOOlO = '1'  ELSE nlOi0l;
	wire_n10Ol_dataout <= wire_n1OOi_o WHEN nlOOlO = '1'  ELSE nlOi0O;
	wire_n10OO_dataout <= wire_n011i_o WHEN nlOOlO = '1'  ELSE nlOiii;
	wire_n110i_dataout <= wire_n1l1O_dataout OR nlliii;
	wire_n110l_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1l0i_dataout;
	wire_n110O_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1l0l_dataout;
	wire_n111i_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1iOO_dataout;
	wire_n111l_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1l1i_dataout;
	wire_n111O_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1l1l_dataout;
	wire_n11i_dataout <= nlOO1i AND nlli1l;
	wire_n11ii_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1l0O_dataout;
	wire_n11il_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1lii_dataout;
	wire_n11iO_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1lil_dataout;
	wire_n11l_dataout <= nlOO1l AND nlli1l;
	wire_n11li_dataout <= (NOT wire_n00ii_o(2)) WHEN nlliii = '1'  ELSE wire_n1liO_dataout;
	wire_n11ll_dataout <= (NOT wire_n00ii_o(2)) WHEN nlliii = '1'  ELSE wire_n1lli_dataout;
	wire_n11lO_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1lll_dataout;
	wire_n11O_dataout <= nlOO1O AND nlli1l;
	wire_n11Oi_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1llO_dataout;
	wire_n11Ol_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1lOi_dataout;
	wire_n11OO_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1lOl_dataout;
	wire_n1i0i_dataout <= wire_n010O_o WHEN nlOOlO = '1'  ELSE nlOill;
	wire_n1i0l_dataout <= wire_n01iO_o WHEN nlOOlO = '1'  ELSE nlOilO;
	wire_n1i0O_dataout <= wire_n01ll_o WHEN nlOOlO = '1'  ELSE nlOiOi;
	wire_n1i1i_dataout <= wire_n011l_o WHEN nlOOlO = '1'  ELSE nlOiil;
	wire_n1i1l_dataout <= wire_n011O_o WHEN nlOOlO = '1'  ELSE nlOiiO;
	wire_n1i1O_dataout <= wire_n010i_o WHEN nlOOlO = '1'  ELSE nlOili;
	wire_n1ii_dataout <= nlOOii AND nlli1l;
	wire_n1iii_dataout <= wire_n01lO_o WHEN nlOOlO = '1'  ELSE nlOiOl;
	wire_n1iil_dataout <= wire_n01Oi_o WHEN nlOOlO = '1'  ELSE nlOiOO;
	wire_n1iiO_dataout <= wire_n01Ol_o WHEN nlOOlO = '1'  ELSE nlOl1i;
	wire_n1il_dataout <= nlOOil AND nlli1l;
	wire_n1ili_dataout <= wire_n001O_o WHEN nlOOlO = '1'  ELSE nlOl1l;
	wire_n1ill_dataout <= wire_n000i_o WHEN nlOOlO = '1'  ELSE nlOl1O;
	wire_n1ilO_dataout <= wire_n00il_o WHEN nlOOlO = '1'  ELSE nlOl0i;
	wire_n1iO_dataout <= nlOOiO AND nlli1l;
	wire_n1iOi_dataout <= wire_n00iO_o WHEN nlOOlO = '1'  ELSE nlOl0l;
	wire_n1iOl_dataout <= wire_n00li_o WHEN nlOOlO = '1'  ELSE nlOl0O;
	wire_n1iOO_dataout <= wire_n00ll_o WHEN nlOOlO = '1'  ELSE nlOlii;
	wire_n1l0i_dataout <= wire_n00OO_o WHEN nlOOlO = '1'  ELSE nlOlll;
	wire_n1l0l_dataout <= wire_n0i1i_o WHEN nlOOlO = '1'  ELSE nlOllO;
	wire_n1l0O_dataout <= wire_n0i1l_o WHEN nlOOlO = '1'  ELSE nlOlOi;
	wire_n1l1i_dataout <= wire_n00lO_o WHEN nlOOlO = '1'  ELSE nlOlil;
	wire_n1l1l_dataout <= wire_n00Oi_o WHEN nlOOlO = '1'  ELSE nlOliO;
	wire_n1l1O_dataout <= wire_n00Ol_o WHEN nlOOlO = '1'  ELSE nlOlli;
	wire_n1li_dataout <= nlOOli AND nlli1l;
	wire_n1lii_dataout <= wire_n0i1O_o WHEN nlOOlO = '1'  ELSE nlOlOl;
	wire_n1lil_dataout <= wire_n0i0i_o WHEN nlOOlO = '1'  ELSE nlOlOO;
	wire_n1liO_dataout <= wire_n0i0l_o WHEN nlOOlO = '1'  ELSE nlOO1i;
	wire_n1ll_dataout <= nlOOll AND nlli1l;
	wire_n1lli_dataout <= wire_n0i0O_o WHEN nlOOlO = '1'  ELSE nlOO1l;
	wire_n1lll_dataout <= wire_n0iii_o WHEN nlOOlO = '1'  ELSE nlOO1O;
	wire_n1llO_dataout <= wire_n0iil_o WHEN nlOOlO = '1'  ELSE nlOO0i;
	wire_n1lOi_dataout <= wire_n0iiO_o WHEN nlOOlO = '1'  ELSE nlOO0l;
	wire_n1lOl_dataout <= wire_n0ili_o WHEN nlOOlO = '1'  ELSE nlOO0O;
	wire_n1lOO_dataout <= wire_n0ill_o WHEN nlOOlO = '1'  ELSE nlOOii;
	wire_n1O0i_dataout <= wire_n0iOO_o WHEN nlOOlO = '1'  ELSE nlOOll;
	wire_n1O0l_dataout <= wire_ni0l_w_lg_ni0O182w(0) WHEN wire_n00ii_o(11) = '1'  ELSE ni0O;
	wire_n1O1i_dataout <= wire_n0ilO_o WHEN nlOOlO = '1'  ELSE nlOOil;
	wire_n1O1l_dataout <= wire_n0iOi_o WHEN nlOOlO = '1'  ELSE nlOOiO;
	wire_n1O1O_dataout <= wire_n0iOl_o WHEN nlOOlO = '1'  ELSE nlOOli;
	wire_nii_dataout <= wire_ni_o(3) WHEN wire_niOi_dataout = '1'  ELSE rcid_len(2);
	wire_niiil_dataout <= wire_niO1i_dataout OR wire_ni0l_w_lg_ni0O182w(0);
	wire_niiiO_dataout <= wire_niO1l_dataout OR wire_ni0l_w_lg_ni0O182w(0);
	wire_niili_dataout <= wire_niO1O_dataout OR wire_ni0l_w_lg_ni0O182w(0);
	wire_niill_dataout <= wire_niO0i_dataout OR wire_ni0l_w_lg_ni0O182w(0);
	wire_niilO_dataout <= wire_niO0l_dataout OR wire_ni0l_w_lg_ni0O182w(0);
	wire_niiOi_dataout <= wire_niO0O_dataout AND NOT(wire_ni0l_w_lg_ni0O182w(0));
	wire_niiOl_dataout <= wire_niOii_dataout OR wire_ni0l_w_lg_ni0O182w(0);
	wire_niiOO_dataout <= wire_niOil_dataout AND NOT(wire_ni0l_w_lg_ni0O182w(0));
	wire_nil_dataout <= wire_ni_o(4) WHEN wire_niOi_dataout = '1'  ELSE rcid_len(3);
	wire_nil0i_dataout <= wire_niOlO_dataout AND NOT(wire_ni0l_w_lg_ni0O182w(0));
	wire_nil0l_dataout <= wire_niOOi_dataout AND NOT(wire_ni0l_w_lg_ni0O182w(0));
	wire_nil0O_dataout <= wire_niOOl_dataout AND NOT(wire_ni0l_w_lg_ni0O182w(0));
	wire_nil1i_dataout <= wire_niOiO_dataout OR wire_ni0l_w_lg_ni0O182w(0);
	wire_nil1l_dataout <= wire_niOli_dataout OR wire_ni0l_w_lg_ni0O182w(0);
	wire_nil1O_dataout <= wire_niOll_dataout AND NOT(wire_ni0l_w_lg_ni0O182w(0));
	wire_nilii_dataout <= wire_niOOO_dataout AND NOT(wire_ni0l_w_lg_ni0O182w(0));
	wire_nilil_dataout <= wire_nl11i_dataout AND NOT(wire_ni0l_w_lg_ni0O182w(0));
	wire_niliO_dataout <= wire_nl11l_dataout AND NOT(wire_ni0l_w_lg_ni0O182w(0));
	wire_nilli_dataout <= wire_nl11O_dataout AND NOT(wire_ni0l_w_lg_ni0O182w(0));
	wire_nilll_dataout <= wire_nl10i_dataout AND NOT(wire_ni0l_w_lg_ni0O182w(0));
	wire_nillO_dataout <= wire_nl10l_dataout AND NOT(wire_ni0l_w_lg_ni0O182w(0));
	wire_nilOi_dataout <= wire_nl10O_dataout AND NOT(wire_ni0l_w_lg_ni0O182w(0));
	wire_nilOl_dataout <= wire_nl1ii_dataout AND NOT(wire_ni0l_w_lg_ni0O182w(0));
	wire_nilOO_dataout <= wire_nl1il_dataout AND NOT(wire_ni0l_w_lg_ni0O182w(0));
	wire_niO_dataout <= wire_ni_o(5) WHEN wire_niOi_dataout = '1'  ELSE rcid_len(4);
	wire_niO0i_dataout <= nlOlii AND NOT(ni0O);
	wire_niO0l_dataout <= nlOlil AND NOT(ni0O);
	wire_niO0O_dataout <= nlOliO OR ni0O;
	wire_niO1i_dataout <= nlOl0i AND NOT(ni0O);
	wire_niO1l_dataout <= nlOl0l AND NOT(ni0O);
	wire_niO1O_dataout <= nlOl0O AND NOT(ni0O);
	wire_niOi_dataout <= nlil AND nlll0l;
	wire_niOii_dataout <= nlOlli AND NOT(ni0O);
	wire_niOil_dataout <= nlOlll OR ni0O;
	wire_niOiO_dataout <= nlOllO AND NOT(ni0O);
	wire_niOl_dataout <= nlli AND nlll0l;
	wire_niOli_dataout <= nlOlOi AND NOT(ni0O);
	wire_niOll_dataout <= nlOlOl AND NOT(ni0O);
	wire_niOlO_dataout <= nlOlOO AND NOT(ni0O);
	wire_niOOi_dataout <= nlOO1i AND NOT(ni0O);
	wire_niOOl_dataout <= nlOO1l AND NOT(ni0O);
	wire_niOOO_dataout <= nlOO1O AND NOT(ni0O);
	wire_nl0i_dataout <= nlliOl AND NOT(nlliOO);
	wire_nl0iO_dataout <= wire_nliOl_dataout AND NOT(wire_niOl_dataout);
	wire_nl0li_dataout <= wire_nliOO_dataout OR wire_niOl_dataout;
	wire_nl0ll_dataout <= wire_nll1i_dataout AND NOT(wire_niOl_dataout);
	wire_nl0lO_dataout <= wire_nll1l_dataout OR wire_niOl_dataout;
	wire_nl0Oi_dataout <= wire_nll1O_dataout OR wire_niOl_dataout;
	wire_nl0Ol_dataout <= wire_nll0i_dataout AND NOT(wire_niOl_dataout);
	wire_nl0OO_dataout <= wire_nll0l_dataout OR wire_niOl_dataout;
	wire_nl10i_dataout <= nlOOii AND NOT(ni0O);
	wire_nl10l_dataout <= nlOOil AND NOT(ni0O);
	wire_nl10O_dataout <= nlOOiO AND NOT(ni0O);
	wire_nl11i_dataout <= nlOO0i AND NOT(ni0O);
	wire_nl11l_dataout <= nlOO0l AND NOT(ni0O);
	wire_nl11O_dataout <= nlOO0O AND NOT(ni0O);
	wire_nl1ii_dataout <= nlOOli AND NOT(ni0O);
	wire_nl1il_dataout <= nlOOll AND NOT(ni0O);
	wire_nl1O_dataout <= wire_w_lg_nlliOl66w(0) AND NOT(nlliOO);
	wire_nli_dataout <= wire_ni_o(6) WHEN wire_niOi_dataout = '1'  ELSE rcid_len(5);
	wire_nli0i_dataout <= wire_nlliO_dataout AND NOT(wire_niOl_dataout);
	wire_nli0l_dataout <= wire_nllli_dataout AND NOT(wire_niOl_dataout);
	wire_nli0O_dataout <= wire_nllll_dataout AND NOT(wire_niOl_dataout);
	wire_nli1i_dataout <= wire_nll0O_dataout AND NOT(wire_niOl_dataout);
	wire_nli1l_dataout <= wire_nllii_dataout AND NOT(wire_niOl_dataout);
	wire_nli1O_dataout <= wire_nllil_dataout AND NOT(wire_niOl_dataout);
	wire_nliii_dataout <= wire_nlllO_dataout AND NOT(wire_niOl_dataout);
	wire_nliil_dataout <= wire_nllOi_dataout AND NOT(wire_niOl_dataout);
	wire_nliiO_dataout <= wire_nllOl_dataout AND NOT(wire_niOl_dataout);
	wire_nlili_dataout <= wire_nllOO_dataout AND NOT(wire_niOl_dataout);
	wire_nlill_dataout <= wire_nlO1i_dataout AND NOT(wire_niOl_dataout);
	wire_nlilO_dataout <= wire_nlO1l_dataout AND NOT(wire_niOl_dataout);
	wire_nliOi_dataout <= wire_nlO1O_dataout AND NOT(wire_niOl_dataout);
	wire_nliOl_dataout <= rcid_pattern WHEN wire_niOi_dataout = '1'  ELSE nlOl0i;
	wire_nliOO_dataout <= rcid_pattern WHEN wire_niOi_dataout = '1'  ELSE nlOl0l;
	wire_nll_dataout <= wire_ni_o(7) WHEN wire_niOi_dataout = '1'  ELSE rcid_len(6);
	wire_nll0i_dataout <= rcid_pattern WHEN wire_niOi_dataout = '1'  ELSE nlOliO;
	wire_nll0l_dataout <= rcid_pattern WHEN wire_niOi_dataout = '1'  ELSE nlOlli;
	wire_nll0O_dataout <= rcid_pattern WHEN wire_niOi_dataout = '1'  ELSE nlOlll;
	wire_nll1i_dataout <= rcid_pattern WHEN wire_niOi_dataout = '1'  ELSE nlOl0O;
	wire_nll1l_dataout <= rcid_pattern WHEN wire_niOi_dataout = '1'  ELSE nlOlii;
	wire_nll1O_dataout <= rcid_pattern WHEN wire_niOi_dataout = '1'  ELSE nlOlil;
	wire_nllii_dataout <= nlOllO AND NOT(wire_niOi_dataout);
	wire_nllil_dataout <= nlOlOi AND NOT(wire_niOi_dataout);
	wire_nlliO_dataout <= nlOlOl AND NOT(wire_niOi_dataout);
	wire_nllli_dataout <= nlOlOO AND NOT(wire_niOi_dataout);
	wire_nllll_dataout <= nlOO1i AND NOT(wire_niOi_dataout);
	wire_nlllO_dataout <= nlOO1l AND NOT(wire_niOi_dataout);
	wire_nllOi_dataout <= nlOO1O AND NOT(wire_niOi_dataout);
	wire_nllOl_dataout <= nlOO0i AND NOT(wire_niOi_dataout);
	wire_nllOO_dataout <= nlOO0l AND NOT(wire_niOi_dataout);
	wire_nlO_dataout <= wire_ni_o(8) WHEN wire_niOi_dataout = '1'  ELSE rcid_len(7);
	wire_nlO0i_dataout <= nlOl0i WHEN nlli1l = '1'  ELSE ((nll0Oi XOR nlOl0l) XOR nlOl0i);
	wire_nlO0l_dataout <= nlOl0l WHEN nlli1l = '1'  ELSE ((nlli1i XOR nlOl0O) XOR nlOl0l);
	wire_nlO0O_dataout <= nlOl0O WHEN nlli1l = '1'  ELSE (wire_w_lg_w_lg_w160w161w162w(0) XOR (NOT (nll1lO42 XOR nll1lO41)));
	wire_nlO1i_dataout <= nlOO0O AND NOT(wire_niOi_dataout);
	wire_nlO1l_dataout <= nlOOii AND NOT(wire_niOi_dataout);
	wire_nlO1O_dataout <= nlOOil AND NOT(wire_niOi_dataout);
	wire_nlOii_dataout <= nlOlii WHEN nlli1l = '1'  ELSE (wire_nl_w_lg_w144w145w(0) XOR (NOT (nll01O36 XOR nll01O35)));
	wire_nlOil_dataout <= nlOlil WHEN nlli1l = '1'  ELSE (nll0ll XOR nlOl0i);
	wire_nlOiO_dataout <= nlOliO WHEN nlli1l = '1'  ELSE (nll0lO XOR nlOl0l);
	wire_nlOli_dataout <= nlOlli WHEN nlli1l = '1'  ELSE ((nll0Oi XOR nlOl0O) XOR (NOT (nll0ii32 XOR nll0ii31)));
	wire_nlOll_dataout <= nlOlll WHEN nlli1l = '1'  ELSE ((nlli1i XOR nlOlii) XOR (NOT (nll0iO30 XOR nll0iO29)));
	wire_nlOlO_dataout <= nlOllO AND nlli1l;
	wire_nlOOi_dataout <= nlOlOi AND nlli1l;
	wire_nlOOl_dataout <= nlOlOl AND nlli1l;
	wire_nlOOO_dataout <= nlOlOO AND nlli1l;
	wire_nlOOOi_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1ilO_dataout;
	wire_nlOOOl_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1iOi_dataout;
	wire_nlOOOO_dataout <= wire_w_lg_nlli0i2123w(0) WHEN nlliii = '1'  ELSE wire_n1iOl_dataout;
	wire_ni_a <= ( wire_nlllil10_w_lg_w_lg_q20w21w & wire_nllliO8_w_lg_w_lg_q17w18w & n1i & nlOO & wire_nlllli6_w_lg_w_lg_q12w13w & nlOi & nllO & wire_nlllll4_w_lg_w_lg_q7w8w & "1");
	wire_ni_b <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "1");
	ni :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 9,
		width_b => 9,
		width_o => 9
	  )
	  PORT MAP ( 
		a => wire_ni_a,
		b => wire_ni_b,
		cin => wire_gnd,
		o => wire_ni_o
	  );
	wire_n00ii_w_lg_w_lg_w_o_range106w1878w1941w(0) <= wire_n00ii_w_lg_w_o_range106w1878w(0) OR wire_n00ii_w_o_range1798w(0);
	wire_n00ii_w_lg_w_lg_w_o_range106w1961w1962w(0) <= wire_n00ii_w_lg_w_o_range106w1961w(0) OR wire_n00ii_w_o_range1824w(0);
	wire_n00ii_w_lg_w_o_range106w1878w(0) <= wire_n00ii_w_o_range106w(0) OR wire_n00ii_w_o_range1824w(0);
	wire_n00ii_w_lg_w_o_range106w1961w(0) <= wire_n00ii_w_o_range106w(0) OR wire_n00ii_w_o_range1839w(0);
	wire_n00ii_i <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	wire_n00ii_w_o_range106w(0) <= wire_n00ii_o(16);
	wire_n00ii_w_o_range1798w(0) <= wire_n00ii_o(17);
	wire_n00ii_w_o_range1824w(0) <= wire_n00ii_o(18);
	wire_n00ii_w_o_range1839w(0) <= wire_n00ii_o(25);
	n00ii :  oper_decoder
	  GENERIC MAP (
		width_i => 5,
		width_o => 32
	  )
	  PORT MAP ( 
		i => wire_n00ii_i,
		o => wire_n00ii_o
	  );
	wire_n00il_data <= ( "0" & "0" & "0" & "1" & "1" & "1" & wire_nl_w_lg_w_lg_nlOO0l1760w1761w & nliOOO & "0" & "0" & "0" & "0" & "0" & "1" & nliliO & wire_nl_w_lg_nlOlOl1744w & "0" & "0" & "0" & "0" & wire_niiil_dataout & "1" & "1" & nll1iO & "0" & "0" & "0" & nliO1l & "0" & wire_nl_w_lg_nlOl0O1719w & "1" & wire_nlO0i_dataout);
	wire_n00il_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n00il :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n00il_data,
		o => wire_n00il_o,
		sel => wire_n00il_sel
	  );
	wire_n00iO_data <= ( "0" & "0" & "0" & "1" & "1" & "0" & wire_nl_w_lg_w_lg_nlOO0O1692w1693w & nll11i & "0" & "0" & "0" & "0" & "0" & "0" & nlilli & wire_nl_w_lg_nlOlOO1676w & "0" & "0" & "0" & "0" & wire_niiiO_dataout & "1" & "0" & nll10O & "0" & "0" & "0" & nliO1O & "0" & wire_nl_w_lg_nlOlii1651w & "0" & wire_nlO0l_dataout);
	wire_n00iO_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n00iO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n00iO_data,
		o => wire_n00iO_o,
		sel => wire_n00iO_sel
	  );
	wire_n00li_data <= ( "0" & "0" & "0" & "1" & "1" & "1" & wire_nl_w_lg_nlOliO1625w & nliOli & "0" & "0" & "0" & "0" & "0" & "1" & nlilll & nll11O & "0" & "0" & "0" & "0" & wire_niili_dataout & "1" & "1" & nll10l & "0" & "0" & "0" & nliO0i & "0" & nll0ll & "1" & wire_nlO0O_dataout);
	wire_n00li_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n00li :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n00li_data,
		o => wire_n00li_o,
		sel => wire_n00li_sel
	  );
	wire_n00ll_data <= ( "0" & "0" & "0" & "1" & "1" & "0" & wire_nl_w_lg_nlOlli1560w & nliOll & "0" & "0" & "0" & "0" & "0" & "0" & nlillO & nll10i & "0" & "0" & "0" & "0" & wire_niill_dataout & "1" & "0" & wire_nl_w_lg_nlOlli1530w & "0" & "0" & "0" & nliO0l & "0" & nll0lO & "0" & wire_nlOii_dataout);
	wire_n00ll_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n00ll :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n00ll_data,
		o => wire_n00ll_o,
		sel => wire_n00ll_sel
	  );
	wire_n00lO_data <= ( "0" & "0" & "0" & "1" & "1" & "1" & nliliO & nliOlO & "0" & "0" & "0" & "0" & "0" & "1" & nlilOi & nliOOO & "0" & "0" & "0" & "0" & wire_niilO_dataout & "1" & "1" & wire_nl_w_lg_nlOlll1465w & "0" & "0" & "0" & nliO0O & "0" & nll0Oi & "1" & wire_nlOil_dataout);
	wire_n00lO_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n00lO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n00lO_data,
		o => wire_n00lO_o,
		sel => wire_n00lO_sel
	  );
	wire_n00Oi_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nlilli & nliOOl & "0" & "0" & "0" & "0" & "0" & "0" & nlilOl & nll11i & "0" & "0" & "0" & "0" & wire_niiOi_dataout & "0" & "0" & wire_nl_w_lg_nlOllO1400w & "0" & "0" & "0" & nliOii & "0" & nlli1i & "0" & wire_nlOiO_dataout);
	wire_n00Oi_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n00Oi :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n00Oi_data,
		o => wire_n00Oi_o,
		sel => wire_n00Oi_sel
	  );
	wire_n00Ol_data <= ( "0" & "0" & "0" & "1" & "0" & "1" & nlilll & wire_w_lg_nliO0O1363w & "0" & "0" & "0" & "0" & "0" & "1" & nlilOO & wire_w_lg_nliO1l1348w & "0" & "0" & "0" & "0" & wire_niiOl_dataout & "0" & "1" & wire_nl_w_lg_nlOlOi1333w & "0" & "0" & "0" & nliOil & "0" & wire_nl_w_lg_w_lg_nlOlll1321w1322w & "1" & wire_nlOli_dataout);
	wire_n00Ol_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n00Ol :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n00Ol_data,
		o => wire_n00Ol_o,
		sel => wire_n00Ol_sel
	  );
	wire_n00OO_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nlillO & nll11l & "0" & "0" & "0" & "0" & "0" & "0" & nliO1i & wire_nl_w_lg_nlOlOO1280w & "0" & "0" & "0" & "0" & wire_niiOO_dataout & "0" & "0" & wire_w_lg_nll1iO1265w & "0" & "0" & "0" & nliOiO & "0" & wire_nl_w_lg_nlOlii1254w & "0" & wire_nlOll_dataout);
	wire_n00OO_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n00OO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n00OO_data,
		o => wire_n00OO_o,
		sel => wire_n00OO_sel
	  );
	wire_n0i0i_data <= ( "0" & "0" & "0" & "0" & "1" & "0" & nliO1i & wire_nl_w_lg_nlOOil1023w & "0" & "0" & "0" & "0" & "0" & "0" & nliO0l & nll11l & "0" & "0" & "0" & "0" & wire_nil0i_dataout & "0" & "0" & "0" & "0" & "0" & "0" & nlOlii & "0" & "0" & "0" & wire_nlOOO_dataout);
	wire_n0i0i_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n0i0i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0i0i_data,
		o => wire_n0i0i_o,
		sel => wire_n0i0i_sel
	  );
	wire_n0i0l_data <= ( "0" & "0" & "0" & "0" & "1" & "1" & nliO1l & wire_nl_w_lg_w_lg_nlOOii955w956w & "0" & "0" & "0" & "0" & "0" & "1" & nliO0O & wire_nl_w_lg_w_lg_nlOO1O939w940w & "0" & "0" & "0" & "0" & wire_nil0l_dataout & "0" & "0" & "0" & "0" & "0" & "0" & nlOlil & "0" & "0" & "0" & wire_n11i_dataout);
	wire_n0i0l_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n0i0l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0i0l_data,
		o => wire_n0i0l_o,
		sel => wire_n0i0l_sel
	  );
	wire_n0i0O_data <= ( "0" & "0" & "0" & "0" & "1" & "0" & nliO1O & wire_nl_w_lg_w_lg_nlOOil885w886w & "0" & "0" & "0" & "0" & "0" & "0" & nliOii & wire_nl_w_lg_w_lg_nlOO0i869w870w & "0" & "0" & "0" & "0" & wire_nil0O_dataout & "0" & "0" & "0" & "0" & "0" & "0" & nlOliO & "0" & "0" & "0" & wire_n11l_dataout);
	wire_n0i0O_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n0i0O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0i0O_data,
		o => wire_n0i0O_o,
		sel => wire_n0i0O_sel
	  );
	wire_n0i1i_data <= ( "0" & "0" & "0" & "1" & "0" & "1" & nlilOi & wire_nl_w_lg_nlOO0l1227w & "0" & "0" & "0" & "0" & "0" & "1" & nliO1l & wire_nl_w_lg_nlOO1i1212w & "0" & "0" & "0" & "0" & wire_nil1i_dataout & "0" & "1" & wire_w_lg_nll10O1197w & "0" & "0" & "0" & nlOl0i & "0" & "0" & "0" & wire_nlOlO_dataout);
	wire_n0i1i_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n0i1i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0i1i_data,
		o => wire_n0i1i_o,
		sel => wire_n0i1i_sel
	  );
	wire_n0i1l_data <= ( "0" & "0" & "0" & "1" & "0" & "0" & nlilOl & wire_nl_w_lg_nlOO0O1159w & "0" & "0" & "0" & "0" & "0" & "0" & nliO1O & wire_nl_w_lg_nlOO1l1144w & "0" & "0" & "0" & "0" & wire_nil1l_dataout & "0" & "0" & wire_w_lg_nll10l1129w & "0" & "0" & "0" & nlOl0l & "0" & "0" & "0" & wire_nlOOi_dataout);
	wire_n0i1l_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n0i1l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0i1l_data,
		o => wire_n0i1l_o,
		sel => wire_n0i1l_sel
	  );
	wire_n0i1O_data <= ( "0" & "0" & "0" & "0" & "1" & "1" & nlilOO & wire_nl_w_lg_nlOOii1091w & "0" & "0" & "0" & "0" & "0" & "1" & nliO0i & wire_nl_w_lg_nlOO1O1076w & "0" & "0" & "0" & "0" & wire_nil1O_dataout & "0" & "0" & "0" & "0" & "0" & "0" & nlOl0O & "0" & "0" & "0" & wire_nlOOl_dataout);
	wire_n0i1O_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n0i1O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0i1O_data,
		o => wire_n0i1O_o,
		sel => wire_n0i1O_sel
	  );
	wire_n0iii_data <= ( "0" & "0" & "0" & "0" & "1" & "1" & nliO0i & wire_w_lg_w_lg_nliOli815w816w & "0" & "0" & "0" & "0" & "0" & "1" & nliOil & wire_w_lg_w_lg_nll11O799w800w & "0" & "0" & "0" & "0" & wire_nilii_dataout & "0" & "0" & "0" & "0" & "0" & "0" & nlOlli & "0" & "0" & "0" & wire_n11O_dataout);
	wire_n0iii_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n0iii :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0iii_data,
		o => wire_n0iii_o,
		sel => wire_n0iii_sel
	  );
	wire_n0iil_data <= ( "0" & "0" & "0" & "1" & "0" & "0" & nliO0l & wire_w_lg_w_lg_nliOll745w746w & "0" & "0" & "0" & "0" & "0" & "0" & nliOiO & wire_w_lg_w_lg_nll10i729w730w & "0" & "0" & "0" & "0" & wire_nilil_dataout & "0" & "0" & "0" & "0" & "0" & "0" & nlOlll & "0" & "0" & "0" & wire_n10i_dataout);
	wire_n0iil_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n0iil :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0iil_data,
		o => wire_n0iil_o,
		sel => wire_n0iil_sel
	  );
	wire_n0iiO_data <= ( "0" & "0" & "0" & "0" & "0" & "1" & nliO0O & wire_w_lg_w_lg_nliOlO675w676w & "0" & "0" & "0" & "0" & "0" & "0" & nlOl0i & "0" & "0" & "0" & "0" & "0" & wire_niliO_dataout & "0" & "0" & "0" & "0" & "0" & "0" & nlOllO & "0" & "0" & "0" & wire_n10l_dataout);
	wire_n0iiO_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n0iiO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0iiO_data,
		o => wire_n0iiO_o,
		sel => wire_n0iiO_sel
	  );
	wire_n0ili_data <= ( "0" & "0" & "0" & "1" & "0" & "0" & nliOii & wire_w_lg_nliOOi607w & "0" & "0" & "0" & "0" & "0" & "0" & nlOl0l & "0" & "0" & "0" & "0" & "0" & wire_nilli_dataout & "0" & "0" & "0" & "0" & "0" & "0" & nlOlOi & "0" & "0" & "0" & wire_n10O_dataout);
	wire_n0ili_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n0ili :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0ili_data,
		o => wire_n0ili_o,
		sel => wire_n0ili_sel
	  );
	wire_n0ill_data <= ( "0" & "0" & "0" & "0" & "0" & "1" & nliOil & wire_w_lg_w_lg_nliOOi538w539w & "0" & "0" & "0" & "0" & "0" & "0" & nlOl0O & "0" & "0" & "0" & "0" & "0" & wire_nilll_dataout & "0" & "0" & "0" & "0" & "0" & "0" & nlOlOl & "0" & "0" & "0" & wire_n1ii_dataout);
	wire_n0ill_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n0ill :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0ill_data,
		o => wire_n0ill_o,
		sel => wire_n0ill_sel
	  );
	wire_n0ilO_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nliOiO & wire_w_lg_w_lg_nliOOl469w470w & "0" & "0" & "0" & "0" & "0" & "0" & nlOlii & "0" & "0" & "0" & "0" & "0" & wire_nillO_dataout & "0" & "0" & "0" & "0" & "0" & "0" & nlOlOO & "0" & "0" & "0" & wire_n1il_dataout);
	wire_n0ilO_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n0ilO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0ilO_data,
		o => wire_n0ilO_o,
		sel => wire_n0ilO_sel
	  );
	wire_n0iOi_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nlOl0i & "0" & "0" & "0" & "0" & "0" & "0" & "0" & nlOlil & "0" & "0" & "0" & "0" & "0" & wire_nilOi_dataout & "0" & "0" & "0" & "0" & "0" & "0" & nlOO1i & "0" & "0" & "0" & wire_n1iO_dataout);
	wire_n0iOi_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n0iOi :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0iOi_data,
		o => wire_n0iOi_o,
		sel => wire_n0iOi_sel
	  );
	wire_n0iOl_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nlOl0l & "0" & "0" & "0" & "0" & "0" & "0" & "0" & nlOliO & "0" & "0" & "0" & "0" & "0" & wire_nilOl_dataout & "0" & "0" & "0" & "0" & "0" & "0" & nlOO1l & "0" & "0" & "0" & wire_n1li_dataout);
	wire_n0iOl_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n0iOl :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0iOl_data,
		o => wire_n0iOl_o,
		sel => wire_n0iOl_sel
	  );
	wire_n0iOO_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nlOl0O & "0" & "0" & "0" & "0" & "0" & "0" & "0" & nlOlli & "0" & "0" & "0" & "0" & "0" & wire_nilOO_dataout & "0" & "0" & "0" & "0" & "0" & "0" & nlOO1O & "0" & "0" & "0" & wire_n1ll_dataout);
	wire_n0iOO_sel <= ( rpma_doublewidth_tx & rpmadwidth_tx & rprbs_sel(2 DOWNTO 0));
	n0iOO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n0iOO_data,
		o => wire_n0iOO_o,
		sel => wire_n0iOO_sel
	  );
	wire_n000i_data <= ( "0" & nlOOil & nlOlii & wire_nliOi_dataout);
	wire_n000i_sel <= ( nlilil & nlilii & wire_n00ii_o(25) & wire_n00ii_o(0));
	n000i :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n000i_data,
		o => wire_n000i_o,
		sel => wire_n000i_sel
	  );
	wire_n001O_data <= ( "0" & nlOOii & nlOlil & wire_nlilO_dataout);
	wire_n001O_sel <= ( nlilil & nlilii & wire_n00ii_o(25) & wire_n00ii_o(0));
	n001O :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n001O_data,
		o => wire_n001O_o,
		sel => wire_n001O_sel
	  );
	wire_n010i_data <= ( "0" & nlOlOO & nlOlOi & nlOO1l & wire_nli0l_dataout);
	wire_n010i_sel <= ( nlil0O & nlil1l & nlil0i & wire_n00ii_o(17) & wire_n00ii_o(0));
	n010i :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n010i_data,
		o => wire_n010i_o,
		sel => wire_n010i_sel
	  );
	wire_n010O_data <= ( "0" & nlOO1i & nlOlOl & wire_nli0O_dataout);
	wire_n010O_sel <= ( nlil0O & nlil1O & wire_n00ii_w_lg_w_lg_w_o_range106w1961w1962w & wire_n00ii_o(0));
	n010O :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n010O_data,
		o => wire_n010O_o,
		sel => wire_n010O_sel
	  );
	wire_n011i_data <= ( "0" & nlOllO & nlOO1O & nlOO0l & wire_nli1l_dataout);
	wire_n011i_sel <= ( nlilil & nlil0l & wire_n00ii_o(25) & nlil0i & wire_n00ii_o(0));
	n011i :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n011i_data,
		o => wire_n011i_o,
		sel => wire_n011i_sel
	  );
	wire_n011l_data <= ( "0" & nlOlOi & nlOO1l & nlOO0O & wire_nli1O_dataout);
	wire_n011l_sel <= ( nlilil & nlil0l & wire_n00ii_o(25) & nlil0i & wire_n00ii_o(0));
	n011l :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n011l_data,
		o => wire_n011l_o,
		sel => wire_n011l_sel
	  );
	wire_n011O_data <= ( "0" & nlOlOl & nlOO1i & nlOllO & nlOO1O & wire_nli0i_dataout);
	wire_n011O_sel <= ( nlil0O & nlil0l & wire_n00ii_o(25) & nlil0i & wire_n00ii_o(17) & wire_n00ii_o(0));
	n011O :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_n011O_data,
		o => wire_n011O_o,
		sel => wire_n011O_sel
	  );
	wire_n01iO_data <= ( "0" & nlOO1l & nlOlOi & nlOlOO & wire_nliii_dataout);
	wire_n01iO_sel <= ( nlil0O & nlil0l & wire_n00ii_o(25) & wire_n00ii_w_lg_w_lg_w_o_range106w1878w1941w & wire_n00ii_o(0));
	n01iO :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n01iO_data,
		o => wire_n01iO_o,
		sel => wire_n01iO_sel
	  );
	wire_n01ll_data <= ( "0" & nlOO1O & nlOllO & nlOO1i & nlOlOl & wire_nliil_dataout);
	wire_n01ll_sel <= ( nlil0O & nlil0l & wire_n00ii_o(25) & nlil0i & wire_n00ii_o(17) & wire_n00ii_o(0));
	n01ll :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_n01ll_data,
		o => wire_n01ll_o,
		sel => wire_n01ll_sel
	  );
	wire_n01lO_data <= ( "0" & nlOO0i & nlOlll & nlOO1l & nlOlOi & wire_nliiO_dataout);
	wire_n01lO_sel <= ( nlil0O & nlil0l & wire_n00ii_o(25) & nlil0i & wire_n00ii_o(17) & wire_n00ii_o(0));
	n01lO :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_n01lO_data,
		o => wire_n01lO_o,
		sel => wire_n01lO_sel
	  );
	wire_n01Oi_data <= ( "0" & nlOO0l & nlOlli & nlOO1O & nlOllO & wire_nlili_dataout);
	wire_n01Oi_sel <= ( nlil0O & nlil0l & wire_n00ii_o(25) & nlil0i & wire_n00ii_o(17) & wire_n00ii_o(0));
	n01Oi :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_n01Oi_data,
		o => wire_n01Oi_o,
		sel => wire_n01Oi_sel
	  );
	wire_n01Ol_data <= ( "0" & nlOO0O & nlOliO & nlOO0i & nlOlll & wire_nlill_dataout);
	wire_n01Ol_sel <= ( nlil0O & nlil0l & wire_n00ii_o(25) & nlil0i & wire_n00ii_o(17) & wire_n00ii_o(0));
	n01Ol :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_n01Ol_data,
		o => wire_n01Ol_o,
		sel => wire_n01Ol_sel
	  );
	wire_n1O0O_data <= ( "0" & nlOl0i & nlOOll & wire_nl0iO_dataout);
	wire_n1O0O_sel <= ( nlil1i & nlilii & nliiOO & wire_n00ii_o(0));
	n1O0O :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1O0O_data,
		o => wire_n1O0O_o,
		sel => wire_n1O0O_sel
	  );
	wire_n1Oii_data <= ( "0" & nlOl0l & nlOOli & wire_nl0li_dataout);
	wire_n1Oii_sel <= ( nlil1i & nlilii & nliiOO & wire_n00ii_o(0));
	n1Oii :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1Oii_data,
		o => wire_n1Oii_o,
		sel => wire_n1Oii_sel
	  );
	wire_n1Oil_data <= ( "0" & nlOl0O & nlOOiO & wire_nl0ll_dataout);
	wire_n1Oil_sel <= ( nlil1i & nlilii & nliiOO & wire_n00ii_o(0));
	n1Oil :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1Oil_data,
		o => wire_n1Oil_o,
		sel => wire_n1Oil_sel
	  );
	wire_n1OiO_data <= ( "0" & nlOlii & nlOOil & wire_nl0lO_dataout);
	wire_n1OiO_sel <= ( nlil1i & nlilii & nliiOO & wire_n00ii_o(0));
	n1OiO :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1OiO_data,
		o => wire_n1OiO_o,
		sel => wire_n1OiO_sel
	  );
	wire_n1Oli_data <= ( "0" & nlOlil & nlOOii & wire_nl0Oi_dataout);
	wire_n1Oli_sel <= ( nlil1i & nlilii & nliiOO & wire_n00ii_o(0));
	n1Oli :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1Oli_data,
		o => wire_n1Oli_o,
		sel => wire_n1Oli_sel
	  );
	wire_n1Oll_data <= ( "0" & nlOliO & nlOO0O & wire_nl0Ol_dataout);
	wire_n1Oll_sel <= ( nlil1i & nlilii & nliiOO & wire_n00ii_o(0));
	n1Oll :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1Oll_data,
		o => wire_n1Oll_o,
		sel => wire_n1Oll_sel
	  );
	wire_n1OlO_data <= ( "0" & nlOlli & nlOO0l & wire_nl0OO_dataout);
	wire_n1OlO_sel <= ( nlil1i & nlilii & nliiOO & wire_n00ii_o(0));
	n1OlO :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1OlO_data,
		o => wire_n1OlO_o,
		sel => wire_n1OlO_sel
	  );
	wire_n1OOi_data <= ( "0" & nlOlll & nlOO0i & wire_nli1i_dataout);
	wire_n1OOi_sel <= ( nlil1i & nlilii & nliiOO & wire_n00ii_o(0));
	n1OOi :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1OOi_data,
		o => wire_n1OOi_o,
		sel => wire_n1OOi_sel
	  );
	wire_niOO_data <= ( nllilO & wire_nl1O_dataout & nllili);
	wire_niOO_sel <= ( nlli & nilO & wire_nlliil22_w_lg_w_lg_q93w94w);
	niOO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niOO_data,
		o => wire_niOO_o,
		sel => wire_niOO_sel
	  );
	wire_nl1i_data <= ( "0" & wire_nlliiO20_w_lg_w_lg_q88w89w & wire_w_lg_nllili85w);
	wire_nl1i_sel <= ( nlli & nilO & wire_nllill18_w_lg_w_lg_q79w80w);
	nl1i :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl1i_data,
		o => wire_nl1i_o,
		sel => wire_nl1i_sel
	  );
	wire_nl1l_data <= ( wire_w_lg_nllilO77w & wire_nl0i_dataout & "0");
	wire_nl1l_sel <= ( nlli & wire_nlliOi16_w_lg_w_lg_q69w70w & nlil);
	nl1l :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl1l_data,
		o => wire_nl1l_o,
		sel => wire_nl1l_sel
	  );

 END RTL; --stratixiv_hssi_tx_digi_prbs_gen
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 139 mux21 168 oper_decoder 2 oper_mux 184 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_tx_digi_enc_chnl_top IS 
	 PORT 
	 ( 
		 cascaded_8b10b_en	:	IN  STD_LOGIC;
		 clk	:	IN  STD_LOGIC;
		 d21_5_eq_n	:	IN  STD_LOGIC;
		 d2_2_eq_n	:	IN  STD_LOGIC;
		 disp_out_3b	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 doublewidth	:	IN  STD_LOGIC;
		 dwidth	:	IN  STD_LOGIC;
		 endec	:	IN  STD_LOGIC;
		 enpolinv_tx	:	IN  STD_LOGIC;
		 ge_xaui_sel	:	IN  STD_LOGIC;
		 ib_force_disparity	:	IN  STD_LOGIC;
		 k_det	:	IN  STD_LOGIC;
		 prbs_en	:	IN  STD_LOGIC;
		 pudr	:	OUT  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 r8b10b_enc_ibm_en	:	IN  STD_LOGIC;
		 renbitrev_tx	:	IN  STD_LOGIC;
		 rendec_data_sel_tx	:	IN  STD_LOGIC;
		 renpolinv_tx	:	IN  STD_LOGIC;
		 rensymswap_tx	:	IN  STD_LOGIC;
		 rev_loop_data	:	IN  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 rev_loopbk	:	IN  STD_LOGIC;
		 rforce_disp	:	IN  STD_LOGIC;
		 rrev_loopbk	:	IN  STD_LOGIC;
		 rst	:	IN  STD_LOGIC;
		 rtxbitslip_en	:	IN  STD_LOGIC;
		 tx_boundary_sel	:	IN  STD_LOGIC_VECTOR (4 DOWNTO 0);
		 tx_ctl_pre_en	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 tx_ctl_tc	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 tx_ctl_ts	:	IN  STD_LOGIC;
		 tx_data_9_pre_en	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 tx_data_9_tc	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 tx_data_pg	:	IN  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 tx_data_pre_en	:	OUT  STD_LOGIC_VECTOR (15 DOWNTO 0);
		 tx_data_tc	:	IN  STD_LOGIC_VECTOR (15 DOWNTO 0);
		 tx_data_ts	:	IN  STD_LOGIC_VECTOR (7 DOWNTO 0);
		 txd_extend_tc	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 txlp20b	:	OUT  STD_LOGIC_VECTOR (19 DOWNTO 0)
	 ); 
 END stratixiv_hssi_tx_digi_enc_chnl_top;

 ARCHITECTURE RTL OF stratixiv_hssi_tx_digi_enc_chnl_top IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 ni0O0l49	:	STD_LOGIC := '0';
	 SIGNAL	 ni0O0l50	:	STD_LOGIC := '0';
	 SIGNAL	 ni0O0O47	:	STD_LOGIC := '0';
	 SIGNAL	 ni0O0O48	:	STD_LOGIC := '0';
	 SIGNAL	 ni0Oii45	:	STD_LOGIC := '0';
	 SIGNAL	 ni0Oii46	:	STD_LOGIC := '0';
	 SIGNAL	 ni0OiO43	:	STD_LOGIC := '0';
	 SIGNAL	 ni0OiO44	:	STD_LOGIC := '0';
	 SIGNAL	 ni0Oli41	:	STD_LOGIC := '0';
	 SIGNAL	 ni0Oli42	:	STD_LOGIC := '0';
	 SIGNAL	 ni0Oll39	:	STD_LOGIC := '0';
	 SIGNAL	 ni0Oll40	:	STD_LOGIC := '0';
	 SIGNAL  wire_ni0Oll40_w_lg_w_lg_q202w203w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0Oll40_w_lg_q202w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 ni0OlO37	:	STD_LOGIC := '0';
	 SIGNAL	 ni0OlO38	:	STD_LOGIC := '0';
	 SIGNAL  wire_ni0OlO38_w_lg_w_lg_q195w196w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OlO38_w_lg_q195w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 ni0OOi35	:	STD_LOGIC := '0';
	 SIGNAL	 ni0OOi36	:	STD_LOGIC := '0';
	 SIGNAL  wire_ni0OOi36_w_lg_w_lg_q187w189w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OOi36_w_lg_q187w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 ni0OOl33	:	STD_LOGIC := '0';
	 SIGNAL	 ni0OOl34	:	STD_LOGIC := '0';
	 SIGNAL  wire_ni0OOl34_w_lg_w_lg_q160w161w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OOl34_w_lg_q160w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 ni0OOO31	:	STD_LOGIC := '0';
	 SIGNAL	 ni0OOO32	:	STD_LOGIC := '0';
	 SIGNAL  wire_ni0OOO32_w_lg_w_lg_q139w140w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OOO32_w_lg_q139w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii00i5	:	STD_LOGIC := '0';
	 SIGNAL	 nii00i6	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii00i6_w_lg_q15w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii01l7	:	STD_LOGIC := '0';
	 SIGNAL	 nii01l8	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii01l8_w_lg_q21w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii0ii3	:	STD_LOGIC := '0';
	 SIGNAL	 nii0ii4	:	STD_LOGIC := '0';
	 SIGNAL	 nii0iO1	:	STD_LOGIC := '0';
	 SIGNAL	 nii0iO2	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii0iO2_w_lg_q3w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii10i23	:	STD_LOGIC := '0';
	 SIGNAL	 nii10i24	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii10i24_w_lg_w_lg_q100w101w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii10i24_w_lg_q100w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii10l21	:	STD_LOGIC := '0';
	 SIGNAL	 nii10l22	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii10l22_w_lg_w_lg_q86w87w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii10l22_w_lg_q86w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii10O19	:	STD_LOGIC := '0';
	 SIGNAL	 nii10O20	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii10O20_w_lg_w_lg_q83w84w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii10O20_w_lg_q83w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii11i29	:	STD_LOGIC := '0';
	 SIGNAL	 nii11i30	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii11i30_w_lg_w_lg_q132w134w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii11i30_w_lg_q132w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii11l27	:	STD_LOGIC := '0';
	 SIGNAL	 nii11l28	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii11l28_w_lg_w_lg_q118w120w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii11l28_w_lg_q118w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii11O25	:	STD_LOGIC := '0';
	 SIGNAL	 nii11O26	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii11O26_w_lg_w_lg_q115w116w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii11O26_w_lg_q115w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii1ii17	:	STD_LOGIC := '0';
	 SIGNAL	 nii1ii18	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii1ii18_w_lg_w_lg_q75w76w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii1ii18_w_lg_q75w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii1il15	:	STD_LOGIC := '0';
	 SIGNAL	 nii1il16	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii1il16_w_lg_w_lg_q67w68w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii1il16_w_lg_q67w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii1li13	:	STD_LOGIC := '0';
	 SIGNAL	 nii1li14	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii1li14_w_lg_q33w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii1lO11	:	STD_LOGIC := '0';
	 SIGNAL	 nii1lO12	:	STD_LOGIC := '0';
	 SIGNAL  wire_nii1lO12_w_lg_q28w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nii1OO10	:	STD_LOGIC := '0';
	 SIGNAL	 nii1OO9	:	STD_LOGIC := '0';
	 SIGNAL	n01li	:	STD_LOGIC := '0';
	 SIGNAL	wire_n01iO_PRN	:	STD_LOGIC;
	 SIGNAL	wire_n01iO_ENA	:	STD_LOGIC;
	 SIGNAL  wire_n01iO_w_lg_n01li1049w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n000i	:	STD_LOGIC := '0';
	 SIGNAL	n000l	:	STD_LOGIC := '0';
	 SIGNAL	n000O	:	STD_LOGIC := '0';
	 SIGNAL	n001i	:	STD_LOGIC := '0';
	 SIGNAL	n001l	:	STD_LOGIC := '0';
	 SIGNAL	n001O	:	STD_LOGIC := '0';
	 SIGNAL	n00ii	:	STD_LOGIC := '0';
	 SIGNAL	n00il	:	STD_LOGIC := '0';
	 SIGNAL	n00iO	:	STD_LOGIC := '0';
	 SIGNAL	n00li	:	STD_LOGIC := '0';
	 SIGNAL	n00ll	:	STD_LOGIC := '0';
	 SIGNAL	n00lO	:	STD_LOGIC := '0';
	 SIGNAL	n00Oi	:	STD_LOGIC := '0';
	 SIGNAL	n00Ol	:	STD_LOGIC := '0';
	 SIGNAL	n00OO	:	STD_LOGIC := '0';
	 SIGNAL	n01ii	:	STD_LOGIC := '0';
	 SIGNAL	n01il	:	STD_LOGIC := '0';
	 SIGNAL	n01lO	:	STD_LOGIC := '0';
	 SIGNAL	n01Oi	:	STD_LOGIC := '0';
	 SIGNAL	n01Ol	:	STD_LOGIC := '0';
	 SIGNAL	n01OO	:	STD_LOGIC := '0';
	 SIGNAL	n0i1i	:	STD_LOGIC := '0';
	 SIGNAL	n0i1l	:	STD_LOGIC := '0';
	 SIGNAL	n0i1O	:	STD_LOGIC := '0';
	 SIGNAL	n0iiO	:	STD_LOGIC := '0';
	 SIGNAL	n0ill	:	STD_LOGIC := '0';
	 SIGNAL	n0iOl	:	STD_LOGIC := '0';
	 SIGNAL	n0iOO	:	STD_LOGIC := '0';
	 SIGNAL	n0l0l	:	STD_LOGIC := '0';
	 SIGNAL	n0l1i	:	STD_LOGIC := '0';
	 SIGNAL	n0l1l	:	STD_LOGIC := '0';
	 SIGNAL	n0l1O	:	STD_LOGIC := '0';
	 SIGNAL	n0lii	:	STD_LOGIC := '0';
	 SIGNAL	n0lil	:	STD_LOGIC := '0';
	 SIGNAL	n0liO	:	STD_LOGIC := '0';
	 SIGNAL	n0lli	:	STD_LOGIC := '0';
	 SIGNAL	n0lll	:	STD_LOGIC := '0';
	 SIGNAL	n0llO	:	STD_LOGIC := '0';
	 SIGNAL	n0lOi	:	STD_LOGIC := '0';
	 SIGNAL	ni00i	:	STD_LOGIC := '0';
	 SIGNAL	ni01l	:	STD_LOGIC := '0';
	 SIGNAL	ni0ii	:	STD_LOGIC := '0';
	 SIGNAL	ni0il	:	STD_LOGIC := '0';
	 SIGNAL	ni0iO	:	STD_LOGIC := '0';
	 SIGNAL	ni0li	:	STD_LOGIC := '0';
	 SIGNAL	ni0ll	:	STD_LOGIC := '0';
	 SIGNAL	ni0Ol	:	STD_LOGIC := '0';
	 SIGNAL	ni1li	:	STD_LOGIC := '0';
	 SIGNAL	ni1ll	:	STD_LOGIC := '0';
	 SIGNAL	nii0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nii0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nii0OO	:	STD_LOGIC := '0';
	 SIGNAL	niii0i	:	STD_LOGIC := '0';
	 SIGNAL	niii0l	:	STD_LOGIC := '0';
	 SIGNAL	niii0O	:	STD_LOGIC := '0';
	 SIGNAL	niii1i	:	STD_LOGIC := '0';
	 SIGNAL	niii1l	:	STD_LOGIC := '0';
	 SIGNAL	niii1O	:	STD_LOGIC := '0';
	 SIGNAL	niiiii	:	STD_LOGIC := '0';
	 SIGNAL	niiiil	:	STD_LOGIC := '0';
	 SIGNAL	niiiiO	:	STD_LOGIC := '0';
	 SIGNAL	niiili	:	STD_LOGIC := '0';
	 SIGNAL	niiill	:	STD_LOGIC := '0';
	 SIGNAL	niiilO	:	STD_LOGIC := '0';
	 SIGNAL	niiiOi	:	STD_LOGIC := '0';
	 SIGNAL	niiiOl	:	STD_LOGIC := '0';
	 SIGNAL	niiiOO	:	STD_LOGIC := '0';
	 SIGNAL	niil1i	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni0Oi_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_ni0Oi_PRN	:	STD_LOGIC;
	 SIGNAL  wire_ni0Oi_w_lg_n01il36w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n0i0i	:	STD_LOGIC := '0';
	 SIGNAL	n0i0l	:	STD_LOGIC := '0';
	 SIGNAL	n0i0O	:	STD_LOGIC := '0';
	 SIGNAL	n0iii	:	STD_LOGIC := '0';
	 SIGNAL	n0iil	:	STD_LOGIC := '0';
	 SIGNAL	n0ili	:	STD_LOGIC := '0';
	 SIGNAL	n0ilO	:	STD_LOGIC := '0';
	 SIGNAL	n0iOi	:	STD_LOGIC := '0';
	 SIGNAL	n0l0i	:	STD_LOGIC := '0';
	 SIGNAL	n0l0O	:	STD_LOGIC := '0';
	 SIGNAL	ni00l	:	STD_LOGIC := '0';
	 SIGNAL	ni00O	:	STD_LOGIC := '0';
	 SIGNAL	ni01i	:	STD_LOGIC := '0';
	 SIGNAL	ni01O	:	STD_LOGIC := '0';
	 SIGNAL	ni0lO	:	STD_LOGIC := '0';
	 SIGNAL	ni1lO	:	STD_LOGIC := '0';
	 SIGNAL	ni1Oi	:	STD_LOGIC := '0';
	 SIGNAL	ni1Ol	:	STD_LOGIC := '0';
	 SIGNAL	ni1OO	:	STD_LOGIC := '0';
	 SIGNAL	nii1i	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni0OO_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_ni0OO_PRN	:	STD_LOGIC;
	 SIGNAL	wire_n00i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n00i_w_lg_w_lg_dataout1617w1689w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_w_lg_dataout1617w1640w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_w_lg_dataout1617w1698w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_dataout1751w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_dataout1746w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_dataout1737w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_dataout1734w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_dataout1642w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_dataout1633w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_dataout1740w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_dataout1645w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_dataout1648w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_dataout1617w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_w_lg_w_lg_dataout1617w1689w1691w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_w_lg_w_lg_dataout1617w1640w1643w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_w_lg_w_lg_dataout1617w1698w1699w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_w_lg_w_lg_w_lg_dataout1617w1689w1691w1693w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_w_lg_w_lg_w_lg_dataout1617w1640w1643w1646w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w1695w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w1649w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00i_w_lg_w1695w1696w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n00l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n00l_w_lg_w_lg_w_lg_dataout1637w1638w1650w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00l_w_lg_w_lg_dataout1719w1720w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00l_w_lg_w_lg_dataout1637w1700w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00l_w_lg_w_lg_dataout1637w1638w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00l_w_lg_w_lg_w_lg_dataout1637w1679w1680w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00l_w_lg_dataout1685w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00l_w_lg_dataout1618w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00l_w_lg_dataout1719w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00l_w_lg_dataout1694w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00l_w_lg_dataout1692w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00l_w_lg_dataout1690w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00l_w_lg_dataout1637w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00l_w_lg_w_lg_dataout1637w1679w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n00O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n00O_w_lg_dataout1663w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n01i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n01i_w_lg_dataout1624w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n01l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n01l_w_lg_w_lg_dataout1620w1666w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01l_w_lg_w_lg_dataout1620w1621w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01l_w_lg_dataout1625w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01l_w_lg_dataout1667w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01l_w_lg_dataout1620w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01l_w_lg_dataout1676w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n01O_w_lg_w_lg_dataout1619w1750w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01O_w_lg_w_lg_dataout1619w1745w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01O_w_lg_w_lg_dataout1619w1736w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01O_w_lg_w_lg_dataout1619w1733w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01O_w_lg_w_lg_dataout1619w1641w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01O_w_lg_w_lg_dataout1619w1632w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01O_w_lg_dataout1739w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01O_w_lg_dataout1644w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01O_w_lg_dataout1647w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01O_w_lg_dataout1688w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01O_w_lg_dataout1639w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01O_w_lg_dataout1619w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n01O_w_lg_dataout1677w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0ii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0ii_w_lg_dataout1654w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0ii_w_lg_dataout1616w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0il_w_lg_dataout1655w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0il_w_lg_dataout1612w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0O1l_w_lg_dataout1848w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0O1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0O1O_w_lg_dataout1697w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1il_w_lg_dataout1775w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1iO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1iO_w_lg_w_lg_dataout1771w1817w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1iO_w_lg_w_lg_dataout1771w1772w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1iO_w_lg_dataout1776w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1iO_w_lg_dataout1818w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1iO_w_lg_dataout1771w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1iO_w_lg_dataout1827w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1li_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1li_w_lg_w_lg_dataout1770w1792w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1li_w_lg_w_lg_dataout1770w1783w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1li_w_lg_w_lg_dataout1770w1901w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1li_w_lg_w_lg_dataout1770w1896w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1li_w_lg_w_lg_dataout1770w1887w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1li_w_lg_w_lg_dataout1770w1884w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1li_w_lg_dataout1890w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1li_w_lg_dataout1795w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1li_w_lg_dataout1798w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1li_w_lg_dataout1839w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1li_w_lg_dataout1790w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1li_w_lg_dataout1770w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1li_w_lg_dataout1828w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1ll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1ll_w_lg_w_lg_dataout1768w1840w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_w_lg_dataout1768w1791w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_w_lg_dataout1768w1849w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_dataout1793w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_dataout1784w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_dataout1902w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_dataout1897w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_dataout1888w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_dataout1885w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_dataout1891w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_dataout1796w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_dataout1799w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_dataout1768w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_w_lg_w_lg_dataout1768w1840w1842w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_w_lg_w_lg_dataout1768w1791w1794w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_w_lg_w_lg_dataout1768w1849w1850w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_w_lg_w_lg_w_lg_dataout1768w1840w1842w1844w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_w_lg_w_lg_w_lg_dataout1768w1791w1794w1797w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w1846w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w1800w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ll_w_lg_w1846w1847w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1lO_w_lg_w_lg_w_lg_dataout1788w1789w1801w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lO_w_lg_w_lg_dataout1870w1871w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lO_w_lg_w_lg_dataout1788w1851w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lO_w_lg_w_lg_dataout1788w1789w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lO_w_lg_w_lg_w_lg_dataout1788w1830w1831w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lO_w_lg_dataout1836w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lO_w_lg_dataout1769w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lO_w_lg_dataout1870w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lO_w_lg_dataout1845w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lO_w_lg_dataout1843w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lO_w_lg_dataout1841w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lO_w_lg_dataout1788w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lO_w_lg_w_lg_dataout1788w1830w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1Oi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1Oi_w_lg_dataout1814w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1Ol_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1Ol_w_lg_dataout1805w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1Ol_w_lg_dataout1767w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1OO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1OO_w_lg_dataout1806w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1OO_w_lg_dataout1763w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nil_w_lg_dataout1804w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nil00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niO_w_lg_dataout1653w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOlOi_w_lg_w_lg_dataout1755w1758w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOlOi_w_lg_w_lg_dataout1755w1760w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOlOi_w_lg_dataout1802w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOlOi_w_lg_dataout1755w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOlOi_w_lg_w_lg_w_lg_dataout1755w1758w1759w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl001i_w_lg_dataout1765w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00ll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl00ll_w_lg_dataout1757w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01iO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl01iO_w_lg_dataout1762w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl01li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01Ol_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl01Ol_w_lg_dataout1764w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10Ol_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl10Ol_w_lg_dataout1859w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl10OO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl10OO_w_lg_dataout1860w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl111i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl111l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl111O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1i0O_w_lg_dataout1861w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli1il_w_lg_w_lg_dataout1604w1607w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1il_w_lg_w_lg_dataout1604w1609w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1il_w_lg_dataout1651w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1il_w_lg_dataout1604w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1il_w_lg_w_lg_w_lg_dataout1604w1607w1608w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliliO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliliO_w_lg_dataout1708w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlilli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlilli_w_lg_dataout1709w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliO1i_w_lg_dataout1710w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nliO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlli0i_w_lg_dataout1611w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlli0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliiO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlliiO_w_lg_dataout1613w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nllill_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllill_w_lg_dataout1614w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nllilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlll0O_w_lg_dataout1606w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nili1O_i	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nili1O_o	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nillli_i	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nillli_o	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n010i_w_lg_o200w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n010i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n010i_o	:	STD_LOGIC;
	 SIGNAL  wire_n010i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n010l_w_lg_o188w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n010l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n010l_o	:	STD_LOGIC;
	 SIGNAL  wire_n010l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n010O_w_lg_o178w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n010O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n010O_o	:	STD_LOGIC;
	 SIGNAL  wire_n010O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n011i_w_lg_o229w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n011i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n011i_o	:	STD_LOGIC;
	 SIGNAL  wire_n011i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n011l_w_lg_o220w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n011l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n011l_o	:	STD_LOGIC;
	 SIGNAL  wire_n011l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n011O_w_lg_o211w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n011O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n011O_o	:	STD_LOGIC;
	 SIGNAL  wire_n011O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1O0i_w_lg_o122w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O0i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1O0i_o	:	STD_LOGIC;
	 SIGNAL  wire_n1O0i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1O0l_w_lg_o133w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O0l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1O0l_o	:	STD_LOGIC;
	 SIGNAL  wire_n1O0l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1O0O_w_lg_o130w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O0O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1O0O_o	:	STD_LOGIC;
	 SIGNAL  wire_n1O0O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1O1l_w_lg_o96w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O1l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1O1l_o	:	STD_LOGIC;
	 SIGNAL  wire_n1O1l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1O1O_w_lg_o108w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O1O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1O1O_o	:	STD_LOGIC;
	 SIGNAL  wire_n1O1O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oii_w_lg_o119w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1Oii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1Oii_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oil_w_lg_o106w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1Oil_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1Oil_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1OiO_w_lg_o94w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1OiO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1OiO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OiO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oli_w_lg_o81w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1Oli_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1Oli_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oli_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oll_w_lg_o70w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1Oll_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1Oll_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oll_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1OlO_w_lg_o265w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1OlO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1OlO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OlO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1OOi_w_lg_o256w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1OOi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1OOi_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OOi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1OOl_w_lg_o247w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1OOl_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1OOl_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OOl_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1OOO_w_lg_o238w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1OOO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1OOO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OOO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niil0i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niil0i_o	:	STD_LOGIC;
	 SIGNAL  wire_niil0i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niil0l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niil0l_o	:	STD_LOGIC;
	 SIGNAL  wire_niil0l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niil0O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niil0O_o	:	STD_LOGIC;
	 SIGNAL  wire_niil0O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niil1l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niil1l_o	:	STD_LOGIC;
	 SIGNAL  wire_niil1l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niil1O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niil1O_o	:	STD_LOGIC;
	 SIGNAL  wire_niil1O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niilii_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niilii_o	:	STD_LOGIC;
	 SIGNAL  wire_niilii_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niilil_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niilil_o	:	STD_LOGIC;
	 SIGNAL  wire_niilil_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niiliO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niiliO_o	:	STD_LOGIC;
	 SIGNAL  wire_niiliO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niilli_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niilli_o	:	STD_LOGIC;
	 SIGNAL  wire_niilli_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niilll_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niilll_o	:	STD_LOGIC;
	 SIGNAL  wire_niilll_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niillO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niillO_o	:	STD_LOGIC;
	 SIGNAL  wire_niillO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niilOi_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niilOi_o	:	STD_LOGIC;
	 SIGNAL  wire_niilOi_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niilOl_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niilOl_o	:	STD_LOGIC;
	 SIGNAL  wire_niilOl_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niilOO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niilOO_o	:	STD_LOGIC;
	 SIGNAL  wire_niilOO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niiO0i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niiO0i_o	:	STD_LOGIC;
	 SIGNAL  wire_niiO0i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niiO0l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niiO0l_o	:	STD_LOGIC;
	 SIGNAL  wire_niiO0l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niiO0O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niiO0O_o	:	STD_LOGIC;
	 SIGNAL  wire_niiO0O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niiO1i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niiO1i_o	:	STD_LOGIC;
	 SIGNAL  wire_niiO1i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niiO1l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niiO1l_o	:	STD_LOGIC;
	 SIGNAL  wire_niiO1l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niiO1O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niiO1O_o	:	STD_LOGIC;
	 SIGNAL  wire_niiO1O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niiOii_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_niiOii_o	:	STD_LOGIC;
	 SIGNAL  wire_niiOii_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niiOil_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_niiOil_o	:	STD_LOGIC;
	 SIGNAL  wire_niiOil_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niiOiO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_niiOiO_o	:	STD_LOGIC;
	 SIGNAL  wire_niiOiO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niiOli_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_niiOli_o	:	STD_LOGIC;
	 SIGNAL  wire_niiOli_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niiOll_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_niiOll_o	:	STD_LOGIC;
	 SIGNAL  wire_niiOll_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niiOlO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_niiOlO_o	:	STD_LOGIC;
	 SIGNAL  wire_niiOlO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niiOOi_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_niiOOi_o	:	STD_LOGIC;
	 SIGNAL  wire_niiOOi_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niiOOl_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_niiOOl_o	:	STD_LOGIC;
	 SIGNAL  wire_niiOOl_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niiOOO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_niiOOO_o	:	STD_LOGIC;
	 SIGNAL  wire_niiOOO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil00i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil00i_o	:	STD_LOGIC;
	 SIGNAL  wire_nil00i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil01i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil01i_o	:	STD_LOGIC;
	 SIGNAL  wire_nil01i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil01l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil01l_o	:	STD_LOGIC;
	 SIGNAL  wire_nil01l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil01O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil01O_o	:	STD_LOGIC;
	 SIGNAL  wire_nil01O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil0ii_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil0ii_o	:	STD_LOGIC;
	 SIGNAL  wire_nil0ii_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil0il_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil0il_o	:	STD_LOGIC;
	 SIGNAL  wire_nil0il_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil0iO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil0iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nil0iO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil0li_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil0li_o	:	STD_LOGIC;
	 SIGNAL  wire_nil0li_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil0ll_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil0ll_o	:	STD_LOGIC;
	 SIGNAL  wire_nil0ll_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil0lO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil0lO_o	:	STD_LOGIC;
	 SIGNAL  wire_nil0lO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil0Oi_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil0Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_nil0Oi_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil0Ol_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil0Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_nil0Ol_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil10i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil10i_o	:	STD_LOGIC;
	 SIGNAL  wire_nil10i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil10l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil10l_o	:	STD_LOGIC;
	 SIGNAL  wire_nil10l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil10O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil10O_o	:	STD_LOGIC;
	 SIGNAL  wire_nil10O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil11i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil11i_o	:	STD_LOGIC;
	 SIGNAL  wire_nil11i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil11l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil11l_o	:	STD_LOGIC;
	 SIGNAL  wire_nil11l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil11O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil11O_o	:	STD_LOGIC;
	 SIGNAL  wire_nil11O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil1ii_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil1ii_o	:	STD_LOGIC;
	 SIGNAL  wire_nil1ii_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil1il_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil1il_o	:	STD_LOGIC;
	 SIGNAL  wire_nil1il_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil1iO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil1iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nil1iO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil1li_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil1li_o	:	STD_LOGIC;
	 SIGNAL  wire_nil1li_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil1ll_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil1ll_o	:	STD_LOGIC;
	 SIGNAL  wire_nil1ll_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil1lO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil1lO_o	:	STD_LOGIC;
	 SIGNAL  wire_nil1lO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil1Oi_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil1Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_nil1Oi_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil1Ol_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil1Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_nil1Ol_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil1OO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nil1OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nil1OO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nili0i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nili0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nili0i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nili0l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nili0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nili0l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nili0O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nili0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nili0O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilii_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilii_o	:	STD_LOGIC;
	 SIGNAL  wire_nilii_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niliii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niliii_o	:	STD_LOGIC;
	 SIGNAL  wire_niliii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niliil_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niliil_o	:	STD_LOGIC;
	 SIGNAL  wire_niliil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niliiO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niliiO_o	:	STD_LOGIC;
	 SIGNAL  wire_niliiO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilil_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilil_o	:	STD_LOGIC;
	 SIGNAL  wire_nilil_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nilili_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nilili_o	:	STD_LOGIC;
	 SIGNAL  wire_nilili_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilill_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nilill_o	:	STD_LOGIC;
	 SIGNAL  wire_nilill_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nililO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nililO_o	:	STD_LOGIC;
	 SIGNAL  wire_nililO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niliO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niliO_o	:	STD_LOGIC;
	 SIGNAL  wire_niliO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niliOi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niliOi_o	:	STD_LOGIC;
	 SIGNAL  wire_niliOi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilli_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilli_o	:	STD_LOGIC;
	 SIGNAL  wire_nilli_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nilll_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilll_o	:	STD_LOGIC;
	 SIGNAL  wire_nilll_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nillll_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nillll_o	:	STD_LOGIC;
	 SIGNAL  wire_nillll_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilllO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nilllO_o	:	STD_LOGIC;
	 SIGNAL  wire_nilllO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nillO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nillO_o	:	STD_LOGIC;
	 SIGNAL  wire_nillO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nillOi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nillOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nillOi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nillOl_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nillOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nillOl_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nillOO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nillOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nillOO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilO1i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nilO1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nilO1i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilO1l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nilO1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nilO1l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilO1O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nilO1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nilO1O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilOi_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nilOi_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nilOl_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nilOl_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nilOO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nilOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nilOO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niO0i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niO0i_o	:	STD_LOGIC;
	 SIGNAL  wire_niO0i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niO0l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niO0l_o	:	STD_LOGIC;
	 SIGNAL  wire_niO0l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niO0O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niO0O_o	:	STD_LOGIC;
	 SIGNAL  wire_niO0O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niO1i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niO1i_o	:	STD_LOGIC;
	 SIGNAL  wire_niO1i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niO1l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niO1l_o	:	STD_LOGIC;
	 SIGNAL  wire_niO1l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niO1O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niO1O_o	:	STD_LOGIC;
	 SIGNAL  wire_niO1O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niOii_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niOii_o	:	STD_LOGIC;
	 SIGNAL  wire_niOii_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niOil_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niOil_o	:	STD_LOGIC;
	 SIGNAL  wire_niOil_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niOiO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niOiO_o	:	STD_LOGIC;
	 SIGNAL  wire_niOiO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niOli_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niOli_o	:	STD_LOGIC;
	 SIGNAL  wire_niOli_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niOll_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niOll_o	:	STD_LOGIC;
	 SIGNAL  wire_niOll_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_niOlO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_niOlO_o	:	STD_LOGIC;
	 SIGNAL  wire_niOlO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOOi_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_niOOi_o	:	STD_LOGIC;
	 SIGNAL  wire_niOOi_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOOl_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_niOOl_o	:	STD_LOGIC;
	 SIGNAL  wire_niOOl_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOOO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_niOOO_o	:	STD_LOGIC;
	 SIGNAL  wire_niOOO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl00i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl00i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl00l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl00l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl00O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl00O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl01i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl01i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl01i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl01l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl01l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl01l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl01O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl01O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl01O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0ii_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0ii_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0ii_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0il_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0il_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0il_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0iO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0iO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0li_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0li_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0li_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0ll_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0ll_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0ll_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0lO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0lO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0lO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0Oi_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0Oi_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0Ol_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0Ol_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0OO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0OO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl10i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl10i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl10i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl10l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl10l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl10l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl10O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl10O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl10O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl11i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl11i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl11i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl11l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl11l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl11l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl11O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl11O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl11O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl1ii_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl1ii_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1ii_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl1il_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl1il_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1il_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl1iO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl1iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1iO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl1li_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl1li_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1li_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl1ll_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl1ll_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1ll_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl1lO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl1lO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl1Oi_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl1Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1Oi_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl1Ol_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl1Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1Ol_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl1OO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl1OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1OO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nli0i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nli0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nli0i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nli0l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nli0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nli0l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nli0O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nli0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nli0O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nli1i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nli1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nli1i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nli1l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nli1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nli1l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nli1O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nli1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nli1O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nliii_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nliii_o	:	STD_LOGIC;
	 SIGNAL  wire_nliii_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nliil_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nliil_o	:	STD_LOGIC;
	 SIGNAL  wire_nliil_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nliiO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nliiO_o	:	STD_LOGIC;
	 SIGNAL  wire_nliiO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlili_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlili_o	:	STD_LOGIC;
	 SIGNAL  wire_nlili_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlill_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlill_o	:	STD_LOGIC;
	 SIGNAL  wire_nlill_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlilO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlilO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlilO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nliOi_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nliOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nliOi_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nliOl_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nliOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nliOl_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nliOO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nliOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nliOO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nll0i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nll0i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nll0l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nll0l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nll0O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nll0O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nll1i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nll1i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nll1l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nll1l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nll1O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nll1O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllii_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllii_o	:	STD_LOGIC;
	 SIGNAL  wire_nllii_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllil_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllil_o	:	STD_LOGIC;
	 SIGNAL  wire_nllil_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlliO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlliO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlliO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllli_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllli_o	:	STD_LOGIC;
	 SIGNAL  wire_nllli_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllll_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllll_o	:	STD_LOGIC;
	 SIGNAL  wire_nllll_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlllO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlllO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllOi_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nllOi_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllOl_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nllOl_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllOO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nllOO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlO0i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlO0l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlO0O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlO1i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlO1l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlO1O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_w_lg_w22w23w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w22w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w35w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_w_lg_d21_5_eq_n1w16w17w18w19w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_w_lg_d21_5_eq_n1w29w30w31w34w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_d21_5_eq_n1w16w17w18w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_d21_5_eq_n1w29w30w31w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_d21_5_eq_n1w16w17w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_d21_5_eq_n1w4w5w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_d21_5_eq_n1w29w30w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_ni000i1832w1834w1835w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_ni0l1i1681w1683w1684w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_d21_5_eq_n1w16w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_d21_5_eq_n1w4w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_d21_5_eq_n1w29w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_ni000i1832w1834w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_ni0l1i1681w1683w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_d21_5_eq_n1w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ib_force_disparity1054w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rforce_disp1040w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rforce_disp1047w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rforce_disp1036w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rforce_disp1043w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni000i1832w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni000l1833w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni000O1858w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni001O1857w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0i0O1756w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0iOO1706w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0l1i1681w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0l1l1682w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0l1O1707w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0O1O1605w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rst1030w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_ctl_tc_range6w7w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_txd_extend_tc_range1035w1039w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_txd_extend_tc_range1042w1046w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_ni00lO1852w1853w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_ni0liO1701w1702w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni001l1854w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni00lO1852w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0iOl1703w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0liO1701w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  ni000i :	STD_LOGIC;
	 SIGNAL  ni000l :	STD_LOGIC;
	 SIGNAL  ni000O :	STD_LOGIC;
	 SIGNAL  ni001i :	STD_LOGIC;
	 SIGNAL  ni001l :	STD_LOGIC;
	 SIGNAL  ni001O :	STD_LOGIC;
	 SIGNAL  ni00ii :	STD_LOGIC;
	 SIGNAL  ni00il :	STD_LOGIC;
	 SIGNAL  ni00iO :	STD_LOGIC;
	 SIGNAL  ni00li :	STD_LOGIC;
	 SIGNAL  ni00ll :	STD_LOGIC;
	 SIGNAL  ni00lO :	STD_LOGIC;
	 SIGNAL  ni00Oi :	STD_LOGIC;
	 SIGNAL  ni00Ol :	STD_LOGIC;
	 SIGNAL  ni00OO :	STD_LOGIC;
	 SIGNAL  ni01il :	STD_LOGIC;
	 SIGNAL  ni01iO :	STD_LOGIC;
	 SIGNAL  ni01li :	STD_LOGIC;
	 SIGNAL  ni01ll :	STD_LOGIC;
	 SIGNAL  ni01lO :	STD_LOGIC;
	 SIGNAL  ni01Oi :	STD_LOGIC;
	 SIGNAL  ni01Ol :	STD_LOGIC;
	 SIGNAL  ni01OO :	STD_LOGIC;
	 SIGNAL  ni0i0i :	STD_LOGIC;
	 SIGNAL  ni0i0l :	STD_LOGIC;
	 SIGNAL  ni0i0O :	STD_LOGIC;
	 SIGNAL  ni0i1i :	STD_LOGIC;
	 SIGNAL  ni0i1l :	STD_LOGIC;
	 SIGNAL  ni0i1O :	STD_LOGIC;
	 SIGNAL  ni0iii :	STD_LOGIC;
	 SIGNAL  ni0iil :	STD_LOGIC;
	 SIGNAL  ni0iiO :	STD_LOGIC;
	 SIGNAL  ni0ili :	STD_LOGIC;
	 SIGNAL  ni0ill :	STD_LOGIC;
	 SIGNAL  ni0ilO :	STD_LOGIC;
	 SIGNAL  ni0iOi :	STD_LOGIC;
	 SIGNAL  ni0iOl :	STD_LOGIC;
	 SIGNAL  ni0iOO :	STD_LOGIC;
	 SIGNAL  ni0l0i :	STD_LOGIC;
	 SIGNAL  ni0l0l :	STD_LOGIC;
	 SIGNAL  ni0l0O :	STD_LOGIC;
	 SIGNAL  ni0l1i :	STD_LOGIC;
	 SIGNAL  ni0l1l :	STD_LOGIC;
	 SIGNAL  ni0l1O :	STD_LOGIC;
	 SIGNAL  ni0lii :	STD_LOGIC;
	 SIGNAL  ni0lil :	STD_LOGIC;
	 SIGNAL  ni0liO :	STD_LOGIC;
	 SIGNAL  ni0lli :	STD_LOGIC;
	 SIGNAL  ni0lll :	STD_LOGIC;
	 SIGNAL  ni0llO :	STD_LOGIC;
	 SIGNAL  ni0lOi :	STD_LOGIC;
	 SIGNAL  ni0lOl :	STD_LOGIC;
	 SIGNAL  ni0lOO :	STD_LOGIC;
	 SIGNAL  ni0O0i :	STD_LOGIC;
	 SIGNAL  ni0O1i :	STD_LOGIC;
	 SIGNAL  ni0O1l :	STD_LOGIC;
	 SIGNAL  ni0O1O :	STD_LOGIC;
	 SIGNAL  ni0Oil :	STD_LOGIC;
	 SIGNAL  nii00O :	STD_LOGIC;
	 SIGNAL  nii1iO :	STD_LOGIC;
	 SIGNAL  nii1Ol :	STD_LOGIC;
	 SIGNAL  wire_w_tx_ctl_tc_range6w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tx_data_9_tc_range1037w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_txd_extend_tc_range1035w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_txd_extend_tc_range1042w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_w_lg_w22w23w(0) <= wire_w22w(0) AND n01il;
	wire_w22w(0) <= wire_w_lg_w_lg_w_lg_w_lg_w_lg_d21_5_eq_n1w16w17w18w19w(0) AND wire_nii01l8_w_lg_q21w(0);
	wire_w35w(0) <= wire_w_lg_w_lg_w_lg_w_lg_w_lg_d21_5_eq_n1w29w30w31w34w(0) AND k_det;
	wire_w_lg_w_lg_w_lg_w_lg_w_lg_d21_5_eq_n1w16w17w18w19w(0) <= wire_w_lg_w_lg_w_lg_w_lg_d21_5_eq_n1w16w17w18w(0) AND k_det;
	wire_w_lg_w_lg_w_lg_w_lg_w_lg_d21_5_eq_n1w29w30w31w34w(0) <= wire_w_lg_w_lg_w_lg_w_lg_d21_5_eq_n1w29w30w31w(0) AND wire_nii1li14_w_lg_q33w(0);
	wire_w_lg_w_lg_w_lg_w_lg_d21_5_eq_n1w16w17w18w(0) <= wire_w_lg_w_lg_w_lg_d21_5_eq_n1w16w17w(0) AND wire_w_lg_w_tx_ctl_tc_range6w7w(0);
	wire_w_lg_w_lg_w_lg_w_lg_d21_5_eq_n1w29w30w31w(0) <= wire_w_lg_w_lg_w_lg_d21_5_eq_n1w29w30w(0) AND wire_w_lg_w_tx_ctl_tc_range6w7w(0);
	wire_w_lg_w_lg_w_lg_d21_5_eq_n1w16w17w(0) <= wire_w_lg_w_lg_d21_5_eq_n1w16w(0) AND ge_xaui_sel;
	wire_w_lg_w_lg_w_lg_d21_5_eq_n1w4w5w(0) <= wire_w_lg_w_lg_d21_5_eq_n1w4w(0) AND ge_xaui_sel;
	wire_w_lg_w_lg_w_lg_d21_5_eq_n1w29w30w(0) <= wire_w_lg_w_lg_d21_5_eq_n1w29w(0) AND ge_xaui_sel;
	wire_w_lg_w_lg_w_lg_ni000i1832w1834w1835w(0) <= wire_w_lg_w_lg_ni000i1832w1834w(0) AND ni00ii;
	wire_w_lg_w_lg_w_lg_ni0l1i1681w1683w1684w(0) <= wire_w_lg_w_lg_ni0l1i1681w1683w(0) AND ni0l0i;
	wire_w_lg_w_lg_d21_5_eq_n1w16w(0) <= wire_w_lg_d21_5_eq_n1w(0) AND wire_nii00i6_w_lg_q15w(0);
	wire_w_lg_w_lg_d21_5_eq_n1w4w(0) <= wire_w_lg_d21_5_eq_n1w(0) AND wire_nii0iO2_w_lg_q3w(0);
	wire_w_lg_w_lg_d21_5_eq_n1w29w(0) <= wire_w_lg_d21_5_eq_n1w(0) AND wire_nii1lO12_w_lg_q28w(0);
	wire_w_lg_w_lg_ni000i1832w1834w(0) <= wire_w_lg_ni000i1832w(0) AND wire_w_lg_ni000l1833w(0);
	wire_w_lg_w_lg_ni0l1i1681w1683w(0) <= wire_w_lg_ni0l1i1681w(0) AND wire_w_lg_ni0l1l1682w(0);
	wire_w_lg_d21_5_eq_n1w(0) <= d21_5_eq_n AND d2_2_eq_n;
	wire_w_lg_ib_force_disparity1054w(0) <= ib_force_disparity AND wire_w_tx_data_9_tc_range1037w(0);
	wire_w_lg_rforce_disp1040w(0) <= rforce_disp AND wire_w_lg_w_txd_extend_tc_range1035w1039w(0);
	wire_w_lg_rforce_disp1047w(0) <= rforce_disp AND wire_w_lg_w_txd_extend_tc_range1042w1046w(0);
	wire_w_lg_rforce_disp1036w(0) <= rforce_disp AND wire_w_txd_extend_tc_range1035w(0);
	wire_w_lg_rforce_disp1043w(0) <= rforce_disp AND wire_w_txd_extend_tc_range1042w(0);
	wire_w_lg_ni000i1832w(0) <= NOT ni000i;
	wire_w_lg_ni000l1833w(0) <= NOT ni000l;
	wire_w_lg_ni000O1858w(0) <= NOT ni000O;
	wire_w_lg_ni001O1857w(0) <= NOT ni001O;
	wire_w_lg_ni0i0O1756w(0) <= NOT ni0i0O;
	wire_w_lg_ni0iOO1706w(0) <= NOT ni0iOO;
	wire_w_lg_ni0l1i1681w(0) <= NOT ni0l1i;
	wire_w_lg_ni0l1l1682w(0) <= NOT ni0l1l;
	wire_w_lg_ni0l1O1707w(0) <= NOT ni0l1O;
	wire_w_lg_ni0O1O1605w(0) <= NOT ni0O1O;
	wire_w_lg_rst1030w(0) <= NOT rst;
	wire_w_lg_w_tx_ctl_tc_range6w7w(0) <= NOT wire_w_tx_ctl_tc_range6w(0);
	wire_w_lg_w_txd_extend_tc_range1035w1039w(0) <= NOT wire_w_txd_extend_tc_range1035w(0);
	wire_w_lg_w_txd_extend_tc_range1042w1046w(0) <= NOT wire_w_txd_extend_tc_range1042w(0);
	wire_w_lg_w_lg_ni00lO1852w1853w(0) <= wire_w_lg_ni00lO1852w(0) OR ni001i;
	wire_w_lg_w_lg_ni0liO1701w1702w(0) <= wire_w_lg_ni0liO1701w(0) OR ni0iOi;
	wire_w_lg_ni001l1854w(0) <= ni001l OR wire_w_lg_w_lg_ni00lO1852w1853w(0);
	wire_w_lg_ni00lO1852w(0) <= ni00lO OR wire_n1lO_w_lg_w_lg_dataout1788w1851w(0);
	wire_w_lg_ni0iOl1703w(0) <= ni0iOl OR wire_w_lg_w_lg_ni0liO1701w1702w(0);
	wire_w_lg_ni0liO1701w(0) <= ni0liO OR wire_n00l_w_lg_w_lg_dataout1637w1700w(0);
	disp_out_3b <= ( wire_nlli1i_dataout & wire_nl010O_dataout);
	ni000i <= ((((wire_n1ll_w_lg_dataout1768w(0) AND (wire_n1li_dataout AND ni01ll)) OR wire_n1ll_w_lg_dataout1902w(0)) OR wire_n1ll_w_lg_dataout1796w(0)) OR wire_n1ll_w_lg_dataout1799w(0));
	ni000l <= ((((((wire_n1ll_w_lg_dataout1768w(0) AND (wire_n1li_w_lg_dataout1770w(0) AND wire_n1iO_w_lg_dataout1818w(0))) OR (wire_n1ll_w_lg_dataout1768w(0) AND (wire_n1li_dataout AND ni01Ol))) OR (wire_n1ll_w_lg_dataout1768w(0) AND (wire_n1li_dataout AND ni01Oi))) OR wire_n1ll_w_lg_dataout1885w(0)) OR wire_n1ll_w_lg_dataout1888w(0)) OR wire_n1ll_w_lg_dataout1891w(0));
	ni000O <= (ni00il OR (wire_n1lO_dataout AND ni00ii));
	ni001i <= (wire_n1lO_dataout AND ((wire_n1ll_dataout AND ni00iO) OR ni000i));
	ni001l <= (wire_nl1iii_dataout AND ni000l);
	ni001O <= (wire_n1lO_w_lg_w_lg_w_lg_dataout1788w1830w1831w(0) OR wire_n1lO_w_lg_dataout1836w(0));
	ni00ii <= (wire_n1ll_w_lg_dataout1768w(0) OR wire_n1li_w_lg_dataout1828w(0));
	ni00il <= (wire_n1lO_w_lg_dataout1788w(0) AND ni00iO);
	ni00iO <= ((((wire_n1ll_w_lg_dataout1768w(0) AND (wire_n1li_w_lg_dataout1770w(0) AND wire_n1iO_w_lg_w_lg_dataout1771w1772w(0))) OR (wire_n1ll_w_lg_dataout1768w(0) AND (wire_n1li_w_lg_dataout1770w(0) AND wire_n1iO_w_lg_dataout1776w(0)))) OR (wire_n1ll_w_lg_dataout1768w(0) AND (wire_n1li_dataout AND ni01lO))) OR wire_n1ll_w_lg_dataout1897w(0));
	ni00li <= (wire_n1ll_dataout AND wire_n1li_w_lg_dataout1839w(0));
	ni00ll <= (wire_n1ll_w_lg_dataout1768w(0) AND (wire_n1li_w_lg_dataout1770w(0) AND wire_n1iO_w_lg_w_lg_dataout1771w1817w(0)));
	ni00lO <= (ni00li OR ni00ll);
	ni00Oi <= ((wire_n1lO_w_lg_w_lg_dataout1870w1871w(0) AND wire_n1iO_w_lg_dataout1771w(0)) AND wire_n1il_w_lg_dataout1775w(0));
	ni00Ol <= wire_n1iO_w_lg_dataout1818w(0);
	ni00OO <= wire_n1iO_w_lg_w_lg_dataout1771w1817w(0);
	ni01il <= ((((((((((((((wire_nili1O_o(15) OR wire_nili1O_o(14)) OR wire_nili1O_o(13)) OR wire_nili1O_o(12)) OR wire_nili1O_o(11)) OR wire_nili1O_o(10)) OR wire_nili1O_o(9)) OR wire_nili1O_o(8)) OR wire_nili1O_o(7)) OR wire_nili1O_o(6)) OR wire_nili1O_o(5)) OR wire_nili1O_o(4)) OR wire_nili1O_o(3)) OR wire_nili1O_o(2)) OR wire_nili1O_o(1));
	ni01iO <= ((((((wire_nillli_o(15) OR wire_nillli_o(14)) OR wire_nillli_o(13)) OR wire_nillli_o(12)) OR wire_nillli_o(11)) OR wire_nillli_o(10)) OR wire_nillli_o(0));
	ni01li <= ((((((wire_nillli_o(7) OR wire_nillli_o(6)) OR wire_nillli_o(5)) OR wire_nillli_o(4)) OR wire_nillli_o(3)) OR wire_nillli_o(2)) OR wire_nillli_o(1));
	ni01ll <= wire_n1iO_w_lg_dataout1818w(0);
	ni01lO <= wire_n1iO_w_lg_w_lg_dataout1771w1817w(0);
	ni01Oi <= wire_n1iO_w_lg_dataout1776w(0);
	ni01Ol <= wire_n1iO_w_lg_w_lg_dataout1771w1772w(0);
	ni01OO <= (wire_n1ll_w_lg_w1846w1847w(0) XOR (wire_n0O1l_w_lg_dataout1848w(0) AND wire_w_lg_ni001l1854w(0)));
	ni0i0i <= (wire_niOlOi_w_lg_w_lg_w_lg_dataout1755w1758w1759w(0) XOR wire_niOlOi_w_lg_w_lg_dataout1755w1760w(0));
	ni0i0l <= (wire_n1Ol_dataout AND wire_n1Oi_dataout);
	ni0i0O <= (ni0i0l OR ni0i1l);
	ni0i1i <= (wire_n1OO_w_lg_dataout1763w(0) AND ni0i1l);
	ni0i1l <= (wire_n1Ol_w_lg_dataout1767w(0) AND wire_n1Oi_w_lg_dataout1814w(0));
	ni0i1O <= (wire_n1OO_dataout AND (wire_n1Ol_dataout AND (wire_n1Oi_dataout AND (((wire_niOlOi_w_lg_dataout1755w(0) AND (wire_n1lO_w_lg_dataout1769w(0) AND ((((wire_n1ll_w_lg_dataout1768w(0) AND (wire_n1li_w_lg_dataout1770w(0) AND wire_n1iO_w_lg_w_lg_dataout1771w1772w(0))) OR (wire_n1ll_w_lg_dataout1768w(0) AND (wire_n1li_w_lg_dataout1770w(0) AND wire_n1iO_w_lg_dataout1776w(0)))) OR (wire_n1ll_w_lg_dataout1768w(0) AND (wire_n1li_dataout AND ni00OO))) OR wire_n1ll_w_lg_dataout1784w(0)))) OR wire_niOlOi_w_lg_dataout1802w(0)) OR wire_n1OO_w_lg_dataout1806w(0)))));
	ni0iii <= (wire_nil_dataout AND ni00Oi);
	ni0iil <= wire_n01l_w_lg_dataout1667w(0);
	ni0iiO <= wire_n01l_w_lg_w_lg_dataout1620w1666w(0);
	ni0ili <= wire_n01l_w_lg_dataout1625w(0);
	ni0ill <= wire_n01l_w_lg_w_lg_dataout1620w1621w(0);
	ni0ilO <= (wire_n00i_w_lg_w1695w1696w(0) XOR (wire_n0O1O_w_lg_dataout1697w(0) AND wire_w_lg_ni0iOl1703w(0)));
	ni0iOi <= (wire_n00l_dataout AND ((wire_n00i_dataout AND ni0l0O) OR ni0l1i));
	ni0iOl <= (wire_nliO1l_dataout AND ni0l1l);
	ni0iOO <= (wire_n00l_w_lg_w_lg_w_lg_dataout1637w1679w1680w(0) OR wire_n00l_w_lg_dataout1685w(0));
	ni0l0i <= (wire_n00i_w_lg_dataout1617w(0) OR wire_n01O_w_lg_dataout1677w(0));
	ni0l0l <= (wire_n00l_w_lg_dataout1637w(0) AND ni0l0O);
	ni0l0O <= ((((wire_n00i_w_lg_dataout1617w(0) AND (wire_n01O_w_lg_dataout1619w(0) AND wire_n01l_w_lg_w_lg_dataout1620w1621w(0))) OR (wire_n00i_w_lg_dataout1617w(0) AND (wire_n01O_w_lg_dataout1619w(0) AND wire_n01l_w_lg_dataout1625w(0)))) OR (wire_n00i_w_lg_dataout1617w(0) AND (wire_n01O_dataout AND ni0iiO))) OR wire_n00i_w_lg_dataout1746w(0));
	ni0l1i <= ((((wire_n00i_w_lg_dataout1617w(0) AND (wire_n01O_dataout AND ni0iil)) OR wire_n00i_w_lg_dataout1751w(0)) OR wire_n00i_w_lg_dataout1645w(0)) OR wire_n00i_w_lg_dataout1648w(0));
	ni0l1l <= ((((((wire_n00i_w_lg_dataout1617w(0) AND (wire_n01O_w_lg_dataout1619w(0) AND wire_n01l_w_lg_dataout1667w(0))) OR (wire_n00i_w_lg_dataout1617w(0) AND (wire_n01O_dataout AND ni0ill))) OR (wire_n00i_w_lg_dataout1617w(0) AND (wire_n01O_dataout AND ni0ili))) OR wire_n00i_w_lg_dataout1734w(0)) OR wire_n00i_w_lg_dataout1737w(0)) OR wire_n00i_w_lg_dataout1740w(0));
	ni0l1O <= (ni0l0l OR (wire_n00l_dataout AND ni0l0i));
	ni0lii <= (wire_n00i_dataout AND wire_n01O_w_lg_dataout1688w(0));
	ni0lil <= (wire_n00i_w_lg_dataout1617w(0) AND (wire_n01O_w_lg_dataout1619w(0) AND wire_n01l_w_lg_w_lg_dataout1620w1666w(0)));
	ni0liO <= (ni0lii OR ni0lil);
	ni0lli <= ((wire_n00l_w_lg_w_lg_dataout1719w1720w(0) AND wire_n01l_w_lg_dataout1620w(0)) AND wire_n01i_w_lg_dataout1624w(0));
	ni0lll <= wire_n01l_w_lg_dataout1667w(0);
	ni0llO <= wire_n01l_w_lg_w_lg_dataout1620w1666w(0);
	ni0lOi <= (wire_n0il_w_lg_dataout1612w(0) AND ni0lOl);
	ni0lOl <= (wire_n0ii_w_lg_dataout1616w(0) AND wire_n00O_w_lg_dataout1663w(0));
	ni0lOO <= (wire_n0il_dataout AND (wire_n0ii_dataout AND (wire_n00O_dataout AND (((wire_nli1il_w_lg_dataout1604w(0) AND (wire_n00l_w_lg_dataout1618w(0) AND ((((wire_n00i_w_lg_dataout1617w(0) AND (wire_n01O_w_lg_dataout1619w(0) AND wire_n01l_w_lg_w_lg_dataout1620w1621w(0))) OR (wire_n00i_w_lg_dataout1617w(0) AND (wire_n01O_w_lg_dataout1619w(0) AND wire_n01l_w_lg_dataout1625w(0)))) OR (wire_n00i_w_lg_dataout1617w(0) AND (wire_n01O_dataout AND ni0llO))) OR wire_n00i_w_lg_dataout1633w(0)))) OR wire_nli1il_w_lg_dataout1651w(0)) OR wire_n0il_w_lg_dataout1655w(0)))));
	ni0O0i <= (wire_niO_dataout AND ni0lli);
	ni0O1i <= (wire_nli1il_w_lg_w_lg_w_lg_dataout1604w1607w1608w(0) XOR wire_nli1il_w_lg_w_lg_dataout1604w1609w(0));
	ni0O1l <= (wire_n0ii_dataout AND wire_n00O_dataout);
	ni0O1O <= (ni0O1l OR ni0lOl);
	ni0Oil <= '1';
	nii00O <= (((wire_w_lg_w_lg_w_lg_d21_5_eq_n1w4w5w(0) AND wire_w_lg_w_tx_ctl_tc_range6w7w(0)) AND (nii0ii4 XOR nii0ii3)) AND k_det);
	nii1iO <= (wire_w35w(0) AND wire_ni0Oi_w_lg_n01il36w(0));
	nii1Ol <= (wire_w_lg_w22w23w(0) AND (nii1OO10 XOR nii1OO9));
	pudr <= ( nii1i & ni0Ol & ni0lO & ni0ll & ni0li & ni0iO & ni0il & ni0ii & ni00O & ni00l & ni00i & ni01O & ni01l & ni01i & ni1OO & ni1Ol & ni1Oi & ni1lO & ni1ll & n0lOi);
	tx_ctl_pre_en <= ( n01OO & n01Ol);
	tx_data_9_pre_en <= ( n01Oi & n01lO);
	tx_data_pre_en <= ( n0i1i & n00OO & n00Ol & n00Oi & n00lO & n00ll & n00li & n00iO & n00il & n00ii & n000O & n000l & n000i & n001O & n001l & n001i);
	txlp20b <= ( n0l0O & n0l0l & n0l0i & n0l1O & n0l1l & n0l1i & n0iOO & n0iOl & n0iOi & n0ilO & n0ill & n0ili & n0iiO & n0iil & n0iii & n0i0O & n0i0l & n0i0i & n0i1O & n0i1l);
	wire_w_tx_ctl_tc_range6w(0) <= tx_ctl_tc(0);
	wire_w_tx_data_9_tc_range1037w(0) <= tx_data_9_tc(0);
	wire_w_txd_extend_tc_range1035w(0) <= txd_extend_tc(0);
	wire_w_txd_extend_tc_range1042w(0) <= txd_extend_tc(1);
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0O0l49 <= ni0O0l50;
		END IF;
		if (now = 0 ns) then
			ni0O0l49 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0O0l50 <= ni0O0l49;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0O0O47 <= ni0O0O48;
		END IF;
		if (now = 0 ns) then
			ni0O0O47 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0O0O48 <= ni0O0O47;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0Oii45 <= ni0Oii46;
		END IF;
		if (now = 0 ns) then
			ni0Oii45 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0Oii46 <= ni0Oii45;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0OiO43 <= ni0OiO44;
		END IF;
		if (now = 0 ns) then
			ni0OiO43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0OiO44 <= ni0OiO43;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0Oli41 <= ni0Oli42;
		END IF;
		if (now = 0 ns) then
			ni0Oli41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0Oli42 <= ni0Oli41;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0Oll39 <= ni0Oll40;
		END IF;
		if (now = 0 ns) then
			ni0Oll39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0Oll40 <= ni0Oll39;
		END IF;
	END PROCESS;
	wire_ni0Oll40_w_lg_w_lg_q202w203w(0) <= wire_ni0Oll40_w_lg_q202w(0) AND wire_n010i_w_lg_o200w(0);
	wire_ni0Oll40_w_lg_q202w(0) <= ni0Oll40 XOR ni0Oll39;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0OlO37 <= ni0OlO38;
		END IF;
		if (now = 0 ns) then
			ni0OlO37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0OlO38 <= ni0OlO37;
		END IF;
	END PROCESS;
	wire_ni0OlO38_w_lg_w_lg_q195w196w(0) <= wire_ni0OlO38_w_lg_q195w(0) AND wire_n010i_o;
	wire_ni0OlO38_w_lg_q195w(0) <= ni0OlO38 XOR ni0OlO37;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0OOi35 <= ni0OOi36;
		END IF;
		if (now = 0 ns) then
			ni0OOi35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0OOi36 <= ni0OOi35;
		END IF;
	END PROCESS;
	wire_ni0OOi36_w_lg_w_lg_q187w189w(0) <= wire_ni0OOi36_w_lg_q187w(0) AND wire_n010l_w_lg_o188w(0);
	wire_ni0OOi36_w_lg_q187w(0) <= ni0OOi36 XOR ni0OOi35;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0OOl33 <= ni0OOl34;
		END IF;
		if (now = 0 ns) then
			ni0OOl33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0OOl34 <= ni0OOl33;
		END IF;
	END PROCESS;
	wire_ni0OOl34_w_lg_w_lg_q160w161w(0) <= wire_ni0OOl34_w_lg_q160w(0) AND wire_n1O1O_w_lg_o108w(0);
	wire_ni0OOl34_w_lg_q160w(0) <= ni0OOl34 XOR ni0OOl33;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0OOO31 <= ni0OOO32;
		END IF;
		if (now = 0 ns) then
			ni0OOO31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN ni0OOO32 <= ni0OOO31;
		END IF;
	END PROCESS;
	wire_ni0OOO32_w_lg_w_lg_q139w140w(0) <= wire_ni0OOO32_w_lg_q139w(0) AND wire_n1O0l_o;
	wire_ni0OOO32_w_lg_q139w(0) <= ni0OOO32 XOR ni0OOO31;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii00i5 <= nii00i6;
		END IF;
		if (now = 0 ns) then
			nii00i5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii00i6 <= nii00i5;
		END IF;
	END PROCESS;
	wire_nii00i6_w_lg_q15w(0) <= nii00i6 XOR nii00i5;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii01l7 <= nii01l8;
		END IF;
		if (now = 0 ns) then
			nii01l7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii01l8 <= nii01l7;
		END IF;
	END PROCESS;
	wire_nii01l8_w_lg_q21w(0) <= nii01l8 XOR nii01l7;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii0ii3 <= nii0ii4;
		END IF;
		if (now = 0 ns) then
			nii0ii3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii0ii4 <= nii0ii3;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii0iO1 <= nii0iO2;
		END IF;
		if (now = 0 ns) then
			nii0iO1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii0iO2 <= nii0iO1;
		END IF;
	END PROCESS;
	wire_nii0iO2_w_lg_q3w(0) <= nii0iO2 XOR nii0iO1;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii10i23 <= nii10i24;
		END IF;
		if (now = 0 ns) then
			nii10i23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii10i24 <= nii10i23;
		END IF;
	END PROCESS;
	wire_nii10i24_w_lg_w_lg_q100w101w(0) <= wire_nii10i24_w_lg_q100w(0) AND n0lll;
	wire_nii10i24_w_lg_q100w(0) <= nii10i24 XOR nii10i23;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii10l21 <= nii10l22;
		END IF;
		if (now = 0 ns) then
			nii10l21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii10l22 <= nii10l21;
		END IF;
	END PROCESS;
	wire_nii10l22_w_lg_w_lg_q86w87w(0) <= wire_nii10l22_w_lg_q86w(0) AND n0liO;
	wire_nii10l22_w_lg_q86w(0) <= nii10l22 XOR nii10l21;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii10O19 <= nii10O20;
		END IF;
		if (now = 0 ns) then
			nii10O19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii10O20 <= nii10O19;
		END IF;
	END PROCESS;
	wire_nii10O20_w_lg_w_lg_q83w84w(0) <= wire_nii10O20_w_lg_q83w(0) AND wire_n1Oli_w_lg_o81w(0);
	wire_nii10O20_w_lg_q83w(0) <= nii10O20 XOR nii10O19;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii11i29 <= nii11i30;
		END IF;
		if (now = 0 ns) then
			nii11i29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii11i30 <= nii11i29;
		END IF;
	END PROCESS;
	wire_nii11i30_w_lg_w_lg_q132w134w(0) <= wire_nii11i30_w_lg_q132w(0) AND wire_n1O0l_w_lg_o133w(0);
	wire_nii11i30_w_lg_q132w(0) <= nii11i30 XOR nii11i29;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii11l27 <= nii11l28;
		END IF;
		if (now = 0 ns) then
			nii11l27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii11l28 <= nii11l27;
		END IF;
	END PROCESS;
	wire_nii11l28_w_lg_w_lg_q118w120w(0) <= wire_nii11l28_w_lg_q118w(0) AND wire_n1Oii_w_lg_o119w(0);
	wire_nii11l28_w_lg_q118w(0) <= nii11l28 XOR nii11l27;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii11O25 <= nii11O26;
		END IF;
		if (now = 0 ns) then
			nii11O25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii11O26 <= nii11O25;
		END IF;
	END PROCESS;
	wire_nii11O26_w_lg_w_lg_q115w116w(0) <= wire_nii11O26_w_lg_q115w(0) AND wire_n1O0i_o;
	wire_nii11O26_w_lg_q115w(0) <= nii11O26 XOR nii11O25;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii1ii17 <= nii1ii18;
		END IF;
		if (now = 0 ns) then
			nii1ii17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii1ii18 <= nii1ii17;
		END IF;
	END PROCESS;
	wire_nii1ii18_w_lg_w_lg_q75w76w(0) <= wire_nii1ii18_w_lg_q75w(0) AND n0lll;
	wire_nii1ii18_w_lg_q75w(0) <= nii1ii18 XOR nii1ii17;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii1il15 <= nii1il16;
		END IF;
		if (now = 0 ns) then
			nii1il15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii1il16 <= nii1il15;
		END IF;
	END PROCESS;
	wire_nii1il16_w_lg_w_lg_q67w68w(0) <= wire_nii1il16_w_lg_q67w(0) AND wire_n1Oll_o;
	wire_nii1il16_w_lg_q67w(0) <= nii1il16 XOR nii1il15;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii1li13 <= nii1li14;
		END IF;
		if (now = 0 ns) then
			nii1li13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii1li14 <= nii1li13;
		END IF;
	END PROCESS;
	wire_nii1li14_w_lg_q33w(0) <= nii1li14 XOR nii1li13;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii1lO11 <= nii1lO12;
		END IF;
		if (now = 0 ns) then
			nii1lO11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii1lO12 <= nii1lO11;
		END IF;
	END PROCESS;
	wire_nii1lO12_w_lg_q28w(0) <= nii1lO12 XOR nii1lO11;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii1OO10 <= nii1OO9;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN nii1OO9 <= nii1OO10;
		END IF;
		if (now = 0 ns) then
			nii1OO9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk, wire_n01iO_PRN, rst)
	BEGIN
		IF (wire_n01iO_PRN = '0') THEN
				n01li <= '1';
		ELSIF (rst = '1') THEN
				n01li <= '0';
		ELSIF (clk = '1' AND clk'event) THEN
			IF (wire_n01iO_ENA = '1') THEN
				n01li <= ni0Oil;
			END IF;
		END IF;
	END PROCESS;
	wire_n01iO_ENA <= (wire_w_lg_ib_force_disparity1054w(0) AND wire_n01iO_w_lg_n01li1049w(0));
	wire_n01iO_PRN <= (ni0O0l50 XOR ni0O0l49);
	wire_n01iO_w_lg_n01li1049w(0) <= NOT n01li;
	PROCESS (clk, wire_ni0Oi_PRN, wire_ni0Oi_CLRN)
	BEGIN
		IF (wire_ni0Oi_PRN = '0') THEN
				n000i <= '1';
				n000l <= '1';
				n000O <= '1';
				n001i <= '1';
				n001l <= '1';
				n001O <= '1';
				n00ii <= '1';
				n00il <= '1';
				n00iO <= '1';
				n00li <= '1';
				n00ll <= '1';
				n00lO <= '1';
				n00Oi <= '1';
				n00Ol <= '1';
				n00OO <= '1';
				n01ii <= '1';
				n01il <= '1';
				n01lO <= '1';
				n01Oi <= '1';
				n01Ol <= '1';
				n01OO <= '1';
				n0i1i <= '1';
				n0i1l <= '1';
				n0i1O <= '1';
				n0iiO <= '1';
				n0ill <= '1';
				n0iOl <= '1';
				n0iOO <= '1';
				n0l0l <= '1';
				n0l1i <= '1';
				n0l1l <= '1';
				n0l1O <= '1';
				n0lii <= '1';
				n0lil <= '1';
				n0liO <= '1';
				n0lli <= '1';
				n0lll <= '1';
				n0llO <= '1';
				n0lOi <= '1';
				ni00i <= '1';
				ni01l <= '1';
				ni0ii <= '1';
				ni0il <= '1';
				ni0iO <= '1';
				ni0li <= '1';
				ni0ll <= '1';
				ni0Ol <= '1';
				ni1li <= '1';
				ni1ll <= '1';
				nii0Oi <= '1';
				nii0Ol <= '1';
				nii0OO <= '1';
				niii0i <= '1';
				niii0l <= '1';
				niii0O <= '1';
				niii1i <= '1';
				niii1l <= '1';
				niii1O <= '1';
				niiiii <= '1';
				niiiil <= '1';
				niiiiO <= '1';
				niiili <= '1';
				niiill <= '1';
				niiilO <= '1';
				niiiOi <= '1';
				niiiOl <= '1';
				niiiOO <= '1';
				niil1i <= '1';
		ELSIF (wire_ni0Oi_CLRN = '0') THEN
				n000i <= '0';
				n000l <= '0';
				n000O <= '0';
				n001i <= '0';
				n001l <= '0';
				n001O <= '0';
				n00ii <= '0';
				n00il <= '0';
				n00iO <= '0';
				n00li <= '0';
				n00ll <= '0';
				n00lO <= '0';
				n00Oi <= '0';
				n00Ol <= '0';
				n00OO <= '0';
				n01ii <= '0';
				n01il <= '0';
				n01lO <= '0';
				n01Oi <= '0';
				n01Ol <= '0';
				n01OO <= '0';
				n0i1i <= '0';
				n0i1l <= '0';
				n0i1O <= '0';
				n0iiO <= '0';
				n0ill <= '0';
				n0iOl <= '0';
				n0iOO <= '0';
				n0l0l <= '0';
				n0l1i <= '0';
				n0l1l <= '0';
				n0l1O <= '0';
				n0lii <= '0';
				n0lil <= '0';
				n0liO <= '0';
				n0lli <= '0';
				n0lll <= '0';
				n0llO <= '0';
				n0lOi <= '0';
				ni00i <= '0';
				ni01l <= '0';
				ni0ii <= '0';
				ni0il <= '0';
				ni0iO <= '0';
				ni0li <= '0';
				ni0ll <= '0';
				ni0Ol <= '0';
				ni1li <= '0';
				ni1ll <= '0';
				nii0Oi <= '0';
				nii0Ol <= '0';
				nii0OO <= '0';
				niii0i <= '0';
				niii0l <= '0';
				niii0O <= '0';
				niii1i <= '0';
				niii1l <= '0';
				niii1O <= '0';
				niiiii <= '0';
				niiiil <= '0';
				niiiiO <= '0';
				niiili <= '0';
				niiill <= '0';
				niiilO <= '0';
				niiiOi <= '0';
				niiiOl <= '0';
				niiiOO <= '0';
				niil1i <= '0';
		ELSIF (clk = '1' AND clk'event) THEN
				n000i <= tx_data_tc(3);
				n000l <= tx_data_tc(4);
				n000O <= tx_data_tc(5);
				n001i <= tx_data_tc(0);
				n001l <= tx_data_tc(1);
				n001O <= tx_data_tc(2);
				n00ii <= tx_data_tc(6);
				n00il <= tx_data_tc(7);
				n00iO <= tx_data_tc(8);
				n00li <= tx_data_tc(9);
				n00ll <= tx_data_tc(10);
				n00lO <= tx_data_tc(11);
				n00Oi <= tx_data_tc(12);
				n00Ol <= tx_data_tc(13);
				n00OO <= tx_data_tc(14);
				n01ii <= rev_loopbk;
				n01il <= wire_n01ll_dataout;
				n01lO <= tx_data_9_tc(0);
				n01Oi <= tx_data_9_tc(1);
				n01Ol <= tx_ctl_tc(0);
				n01OO <= tx_ctl_tc(1);
				n0i1i <= tx_data_tc(15);
				n0i1l <= n0lOi;
				n0i1O <= ni1ll;
				n0iiO <= ni01l;
				n0ill <= ni00i;
				n0iOl <= ni0ii;
				n0iOO <= ni0il;
				n0l0l <= ni0Ol;
				n0l1i <= ni0iO;
				n0l1l <= ni0li;
				n0l1O <= ni0ll;
				n0lii <= n0lil;
				n0lil <= rensymswap_tx;
				n0liO <= n0lli;
				n0lli <= renbitrev_tx;
				n0lll <= n0llO;
				n0llO <= (renpolinv_tx AND enpolinv_tx);
				n0lOi <= wire_nii1l_dataout;
				ni00i <= wire_niill_dataout;
				ni01l <= wire_niiiO_dataout;
				ni0ii <= wire_niiOl_dataout;
				ni0il <= wire_niiOO_dataout;
				ni0iO <= wire_nil1i_dataout;
				ni0li <= wire_nil1l_dataout;
				ni0ll <= wire_nil1O_dataout;
				ni0Ol <= wire_nil0l_dataout;
				ni1li <= n01ii;
				ni1ll <= wire_nii1O_dataout;
				nii0Oi <= wire_niliO_o;
				nii0Ol <= wire_nilli_o;
				nii0OO <= wire_nilll_o;
				niii0i <= wire_nilOO_o;
				niii0l <= wire_niO1i_o;
				niii0O <= wire_niO1l_o;
				niii1i <= wire_nillO_o;
				niii1l <= wire_nilOi_o;
				niii1O <= wire_nilOl_o;
				niiiii <= wire_niO1O_o;
				niiiil <= wire_niO0i_o;
				niiiiO <= wire_niO0l_o;
				niiili <= wire_niO0O_o;
				niiill <= wire_niOii_o;
				niiilO <= wire_niOil_o;
				niiiOi <= wire_niOiO_o;
				niiiOl <= wire_niOli_o;
				niiiOO <= wire_niOll_o;
				niil1i <= wire_nilil_o;
		END IF;
	END PROCESS;
	wire_ni0Oi_CLRN <= ((ni0Oii46 XOR ni0Oii45) AND wire_w_lg_rst1030w(0));
	wire_ni0Oi_PRN <= (ni0O0O48 XOR ni0O0O47);
	wire_ni0Oi_w_lg_n01il36w(0) <= NOT n01il;
	PROCESS (clk, wire_ni0OO_PRN, wire_ni0OO_CLRN)
	BEGIN
		IF (wire_ni0OO_PRN = '0') THEN
				n0i0i <= '1';
				n0i0l <= '1';
				n0i0O <= '1';
				n0iii <= '1';
				n0iil <= '1';
				n0ili <= '1';
				n0ilO <= '1';
				n0iOi <= '1';
				n0l0i <= '1';
				n0l0O <= '1';
				ni00l <= '1';
				ni00O <= '1';
				ni01i <= '1';
				ni01O <= '1';
				ni0lO <= '1';
				ni1lO <= '1';
				ni1Oi <= '1';
				ni1Ol <= '1';
				ni1OO <= '1';
				nii1i <= '1';
		ELSIF (wire_ni0OO_CLRN = '0') THEN
				n0i0i <= '0';
				n0i0l <= '0';
				n0i0O <= '0';
				n0iii <= '0';
				n0iil <= '0';
				n0ili <= '0';
				n0ilO <= '0';
				n0iOi <= '0';
				n0l0i <= '0';
				n0l0O <= '0';
				ni00l <= '0';
				ni00O <= '0';
				ni01i <= '0';
				ni01O <= '0';
				ni0lO <= '0';
				ni1lO <= '0';
				ni1Oi <= '0';
				ni1Ol <= '0';
				ni1OO <= '0';
				nii1i <= '0';
		ELSIF (clk = '1' AND clk'event) THEN
				n0i0i <= ni1lO;
				n0i0l <= ni1Oi;
				n0i0O <= ni1Ol;
				n0iii <= ni1OO;
				n0iil <= ni01i;
				n0ili <= ni01O;
				n0ilO <= ni00l;
				n0iOi <= ni00O;
				n0l0i <= ni0lO;
				n0l0O <= nii1i;
				ni00l <= wire_niilO_dataout;
				ni00O <= wire_niiOi_dataout;
				ni01i <= wire_niiil_dataout;
				ni01O <= wire_niili_dataout;
				ni0lO <= wire_nil0i_dataout;
				ni1lO <= wire_nii0i_dataout;
				ni1Oi <= wire_nii0l_dataout;
				ni1Ol <= wire_nii0O_dataout;
				ni1OO <= wire_niiii_dataout;
				nii1i <= wire_nil0O_dataout;
		END IF;
		if (now = 0 ns) then
			n0i0i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0i0l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0i0O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0iii <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0iil <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0ili <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0ilO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0iOi <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0l0i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0l0O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni00l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni00O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni01i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni01O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni0lO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni1lO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni1Oi <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni1Ol <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni1OO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nii1i <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_ni0OO_CLRN <= (ni0Oli42 XOR ni0Oli41);
	wire_ni0OO_PRN <= ((ni0OiO44 XOR ni0OiO43) AND wire_w_lg_rst1030w(0));
	wire_n00i_dataout <= tx_data_tc(11) WHEN cascaded_8b10b_en = '1'  ELSE wire_ni0l_dataout;
	wire_n00i_w_lg_w_lg_dataout1617w1689w(0) <= wire_n00i_w_lg_dataout1617w(0) AND wire_n01O_w_lg_dataout1688w(0);
	wire_n00i_w_lg_w_lg_dataout1617w1640w(0) <= wire_n00i_w_lg_dataout1617w(0) AND wire_n01O_w_lg_dataout1639w(0);
	wire_n00i_w_lg_w_lg_dataout1617w1698w(0) <= wire_n00i_w_lg_dataout1617w(0) AND ni0l1i;
	wire_n00i_w_lg_dataout1751w(0) <= wire_n00i_dataout AND wire_n01O_w_lg_w_lg_dataout1619w1750w(0);
	wire_n00i_w_lg_dataout1746w(0) <= wire_n00i_dataout AND wire_n01O_w_lg_w_lg_dataout1619w1745w(0);
	wire_n00i_w_lg_dataout1737w(0) <= wire_n00i_dataout AND wire_n01O_w_lg_w_lg_dataout1619w1736w(0);
	wire_n00i_w_lg_dataout1734w(0) <= wire_n00i_dataout AND wire_n01O_w_lg_w_lg_dataout1619w1733w(0);
	wire_n00i_w_lg_dataout1642w(0) <= wire_n00i_dataout AND wire_n01O_w_lg_w_lg_dataout1619w1641w(0);
	wire_n00i_w_lg_dataout1633w(0) <= wire_n00i_dataout AND wire_n01O_w_lg_w_lg_dataout1619w1632w(0);
	wire_n00i_w_lg_dataout1740w(0) <= wire_n00i_dataout AND wire_n01O_w_lg_dataout1739w(0);
	wire_n00i_w_lg_dataout1645w(0) <= wire_n00i_dataout AND wire_n01O_w_lg_dataout1644w(0);
	wire_n00i_w_lg_dataout1648w(0) <= wire_n00i_dataout AND wire_n01O_w_lg_dataout1647w(0);
	wire_n00i_w_lg_dataout1617w(0) <= NOT wire_n00i_dataout;
	wire_n00i_w_lg_w_lg_w_lg_dataout1617w1689w1691w(0) <= wire_n00i_w_lg_w_lg_dataout1617w1689w(0) OR wire_n00l_w_lg_dataout1690w(0);
	wire_n00i_w_lg_w_lg_w_lg_dataout1617w1640w1643w(0) <= wire_n00i_w_lg_w_lg_dataout1617w1640w(0) OR wire_n00i_w_lg_dataout1642w(0);
	wire_n00i_w_lg_w_lg_w_lg_dataout1617w1698w1699w(0) <= wire_n00i_w_lg_w_lg_dataout1617w1698w(0) OR ni0l0O;
	wire_n00i_w_lg_w_lg_w_lg_w_lg_dataout1617w1689w1691w1693w(0) <= wire_n00i_w_lg_w_lg_w_lg_dataout1617w1689w1691w(0) OR wire_n00l_w_lg_dataout1692w(0);
	wire_n00i_w_lg_w_lg_w_lg_w_lg_dataout1617w1640w1643w1646w(0) <= wire_n00i_w_lg_w_lg_w_lg_dataout1617w1640w1643w(0) OR wire_n00i_w_lg_dataout1645w(0);
	wire_n00i_w1695w(0) <= wire_n00i_w_lg_w_lg_w_lg_w_lg_dataout1617w1689w1691w1693w(0) OR wire_n00l_w_lg_dataout1694w(0);
	wire_n00i_w1649w(0) <= wire_n00i_w_lg_w_lg_w_lg_w_lg_dataout1617w1640w1643w1646w(0) OR wire_n00i_w_lg_dataout1648w(0);
	wire_n00i_w_lg_w1695w1696w(0) <= wire_n00i_w1695w(0) OR ni0iOl;
	wire_n00l_dataout <= tx_data_tc(12) WHEN cascaded_8b10b_en = '1'  ELSE wire_ni0O_dataout;
	wire_n00l_w_lg_w_lg_w_lg_dataout1637w1638w1650w(0) <= wire_n00l_w_lg_w_lg_dataout1637w1638w(0) AND wire_n00i_w1649w(0);
	wire_n00l_w_lg_w_lg_dataout1719w1720w(0) <= wire_n00l_w_lg_dataout1719w(0) AND wire_n01O_dataout;
	wire_n00l_w_lg_w_lg_dataout1637w1700w(0) <= wire_n00l_w_lg_dataout1637w(0) AND wire_n00i_w_lg_w_lg_w_lg_dataout1617w1698w1699w(0);
	wire_n00l_w_lg_w_lg_dataout1637w1638w(0) <= wire_n00l_w_lg_dataout1637w(0) AND wire_n00i_dataout;
	wire_n00l_w_lg_w_lg_w_lg_dataout1637w1679w1680w(0) <= wire_n00l_w_lg_w_lg_dataout1637w1679w(0) AND ni0l1l;
	wire_n00l_w_lg_dataout1685w(0) <= wire_n00l_dataout AND wire_w_lg_w_lg_w_lg_ni0l1i1681w1683w1684w(0);
	wire_n00l_w_lg_dataout1618w(0) <= wire_n00l_dataout AND wire_n00i_w_lg_dataout1617w(0);
	wire_n00l_w_lg_dataout1719w(0) <= wire_n00l_dataout AND wire_n00i_dataout;
	wire_n00l_w_lg_dataout1694w(0) <= wire_n00l_dataout AND ni0l1i;
	wire_n00l_w_lg_dataout1692w(0) <= wire_n00l_dataout AND ni0lii;
	wire_n00l_w_lg_dataout1690w(0) <= wire_n00l_dataout AND ni0lil;
	wire_n00l_w_lg_dataout1637w(0) <= NOT wire_n00l_dataout;
	wire_n00l_w_lg_w_lg_dataout1637w1679w(0) <= wire_n00l_w_lg_dataout1637w(0) OR wire_nliO1l_dataout;
	wire_n00O_dataout <= tx_data_tc(13) WHEN cascaded_8b10b_en = '1'  ELSE wire_niii_dataout;
	wire_n00O_w_lg_dataout1663w(0) <= NOT wire_n00O_dataout;
	wire_n01i_dataout <= tx_data_tc(8) WHEN cascaded_8b10b_en = '1'  ELSE wire_ni1l_dataout;
	wire_n01i_w_lg_dataout1624w(0) <= NOT wire_n01i_dataout;
	wire_n01l_dataout <= tx_data_tc(9) WHEN cascaded_8b10b_en = '1'  ELSE wire_ni1O_dataout;
	wire_n01l_w_lg_w_lg_dataout1620w1666w(0) <= wire_n01l_w_lg_dataout1620w(0) AND wire_n01i_w_lg_dataout1624w(0);
	wire_n01l_w_lg_w_lg_dataout1620w1621w(0) <= wire_n01l_w_lg_dataout1620w(0) AND wire_n01i_dataout;
	wire_n01l_w_lg_dataout1625w(0) <= wire_n01l_dataout AND wire_n01i_w_lg_dataout1624w(0);
	wire_n01l_w_lg_dataout1667w(0) <= wire_n01l_dataout AND wire_n01i_dataout;
	wire_n01l_w_lg_dataout1620w(0) <= NOT wire_n01l_dataout;
	wire_n01l_w_lg_dataout1676w(0) <= wire_n01l_dataout OR wire_n01i_dataout;
	wire_n01ll_dataout <= wire_nlli1i_dataout WHEN cascaded_8b10b_en = '1'  ELSE wire_nl010O_dataout;
	wire_n01O_dataout <= tx_data_tc(10) WHEN cascaded_8b10b_en = '1'  ELSE wire_ni0i_dataout;
	wire_n01O_w_lg_w_lg_dataout1619w1750w(0) <= wire_n01O_w_lg_dataout1619w(0) AND ni0iil;
	wire_n01O_w_lg_w_lg_dataout1619w1745w(0) <= wire_n01O_w_lg_dataout1619w(0) AND ni0iiO;
	wire_n01O_w_lg_w_lg_dataout1619w1736w(0) <= wire_n01O_w_lg_dataout1619w(0) AND ni0ili;
	wire_n01O_w_lg_w_lg_dataout1619w1733w(0) <= wire_n01O_w_lg_dataout1619w(0) AND ni0ill;
	wire_n01O_w_lg_w_lg_dataout1619w1641w(0) <= wire_n01O_w_lg_dataout1619w(0) AND ni0lll;
	wire_n01O_w_lg_w_lg_dataout1619w1632w(0) <= wire_n01O_w_lg_dataout1619w(0) AND ni0llO;
	wire_n01O_w_lg_dataout1739w(0) <= wire_n01O_dataout AND wire_n01l_w_lg_w_lg_dataout1620w1666w(0);
	wire_n01O_w_lg_dataout1644w(0) <= wire_n01O_dataout AND wire_n01l_w_lg_w_lg_dataout1620w1621w(0);
	wire_n01O_w_lg_dataout1647w(0) <= wire_n01O_dataout AND wire_n01l_w_lg_dataout1625w(0);
	wire_n01O_w_lg_dataout1688w(0) <= wire_n01O_dataout AND wire_n01l_w_lg_dataout1667w(0);
	wire_n01O_w_lg_dataout1639w(0) <= wire_n01O_dataout AND ni0lll;
	wire_n01O_w_lg_dataout1619w(0) <= NOT wire_n01O_dataout;
	wire_n01O_w_lg_dataout1677w(0) <= wire_n01O_dataout OR wire_n01l_w_lg_dataout1676w(0);
	wire_n0ii_dataout <= tx_data_tc(14) WHEN cascaded_8b10b_en = '1'  ELSE wire_niil_dataout;
	wire_n0ii_w_lg_dataout1654w(0) <= wire_n0ii_dataout AND wire_niO_w_lg_dataout1653w(0);
	wire_n0ii_w_lg_dataout1616w(0) <= NOT wire_n0ii_dataout;
	wire_n0il_dataout <= tx_data_tc(15) WHEN cascaded_8b10b_en = '1'  ELSE wire_niiO_dataout;
	wire_n0il_w_lg_dataout1655w(0) <= wire_n0il_dataout AND wire_n0ii_w_lg_dataout1654w(0);
	wire_n0il_w_lg_dataout1612w(0) <= NOT wire_n0il_dataout;
	wire_n0iO_dataout <= wire_nili_dataout AND NOT(nii1Ol);
	wire_n0li_dataout <= wire_nill_dataout AND NOT(nii1Ol);
	wire_n0ll_dataout <= wire_nilO_dataout AND NOT(nii1Ol);
	wire_n0lO_dataout <= wire_niOi_dataout AND NOT(nii1Ol);
	wire_n0O_dataout <= tx_ctl_tc(0) WHEN rendec_data_sel_tx = '1'  ELSE tx_ctl_ts;
	wire_n0O0i_dataout <= ((wire_n01iO_w_lg_n01li1049w(0) AND tx_data_9_tc(0)) OR n01il) WHEN ib_force_disparity = '1'  ELSE wire_n0O0l_dataout;
	wire_n0O0l_dataout <= wire_n0O0O_dataout OR (wire_w_lg_rforce_disp1040w(0) AND tx_data_9_tc(0));
	wire_n0O0O_dataout <= n01il AND NOT((wire_w_lg_rforce_disp1036w(0) AND tx_data_9_tc(0)));
	wire_n0O1l_dataout <= wire_ni10i_dataout WHEN cascaded_8b10b_en = '1'  ELSE wire_n0O0i_dataout;
	wire_n0O1l_w_lg_dataout1848w(0) <= NOT wire_n0O1l_dataout;
	wire_n0O1O_dataout <= wire_n0OOi_dataout WHEN cascaded_8b10b_en = '1'  ELSE wire_nl010O_dataout;
	wire_n0O1O_w_lg_dataout1697w(0) <= NOT wire_n0O1O_dataout;
	wire_n0Oi_dataout <= wire_niOl_dataout OR nii1Ol;
	wire_n0Ol_dataout <= wire_niOO_dataout AND NOT(nii1Ol);
	wire_n0OO_dataout <= wire_nl1i_dataout OR nii1Ol;
	wire_n0OOi_dataout <= wire_n0OOl_dataout OR (wire_w_lg_rforce_disp1047w(0) AND tx_data_9_tc(1));
	wire_n0OOl_dataout <= wire_nl010O_dataout AND NOT((wire_w_lg_rforce_disp1043w(0) AND tx_data_9_tc(1)));
	wire_n10i_dataout <= tx_data_tc(12) AND rendec_data_sel_tx;
	wire_n10l_dataout <= tx_data_tc(13) AND rendec_data_sel_tx;
	wire_n10O_dataout <= tx_data_tc(14) AND rendec_data_sel_tx;
	wire_n11i_dataout <= tx_data_tc(9) AND rendec_data_sel_tx;
	wire_n11l_dataout <= tx_data_tc(10) AND rendec_data_sel_tx;
	wire_n11O_dataout <= tx_data_tc(11) AND rendec_data_sel_tx;
	wire_n1ii_dataout <= tx_data_tc(15) AND rendec_data_sel_tx;
	wire_n1il_dataout <= tx_data_tc(0) WHEN cascaded_8b10b_en = '1'  ELSE wire_n0iO_dataout;
	wire_n1il_w_lg_dataout1775w(0) <= NOT wire_n1il_dataout;
	wire_n1iO_dataout <= tx_data_tc(1) WHEN cascaded_8b10b_en = '1'  ELSE wire_n0li_dataout;
	wire_n1iO_w_lg_w_lg_dataout1771w1817w(0) <= wire_n1iO_w_lg_dataout1771w(0) AND wire_n1il_w_lg_dataout1775w(0);
	wire_n1iO_w_lg_w_lg_dataout1771w1772w(0) <= wire_n1iO_w_lg_dataout1771w(0) AND wire_n1il_dataout;
	wire_n1iO_w_lg_dataout1776w(0) <= wire_n1iO_dataout AND wire_n1il_w_lg_dataout1775w(0);
	wire_n1iO_w_lg_dataout1818w(0) <= wire_n1iO_dataout AND wire_n1il_dataout;
	wire_n1iO_w_lg_dataout1771w(0) <= NOT wire_n1iO_dataout;
	wire_n1iO_w_lg_dataout1827w(0) <= wire_n1iO_dataout OR wire_n1il_dataout;
	wire_n1li_dataout <= tx_data_tc(2) WHEN cascaded_8b10b_en = '1'  ELSE wire_n0ll_dataout;
	wire_n1li_w_lg_w_lg_dataout1770w1792w(0) <= wire_n1li_w_lg_dataout1770w(0) AND ni00Ol;
	wire_n1li_w_lg_w_lg_dataout1770w1783w(0) <= wire_n1li_w_lg_dataout1770w(0) AND ni00OO;
	wire_n1li_w_lg_w_lg_dataout1770w1901w(0) <= wire_n1li_w_lg_dataout1770w(0) AND ni01ll;
	wire_n1li_w_lg_w_lg_dataout1770w1896w(0) <= wire_n1li_w_lg_dataout1770w(0) AND ni01lO;
	wire_n1li_w_lg_w_lg_dataout1770w1887w(0) <= wire_n1li_w_lg_dataout1770w(0) AND ni01Oi;
	wire_n1li_w_lg_w_lg_dataout1770w1884w(0) <= wire_n1li_w_lg_dataout1770w(0) AND ni01Ol;
	wire_n1li_w_lg_dataout1890w(0) <= wire_n1li_dataout AND wire_n1iO_w_lg_w_lg_dataout1771w1817w(0);
	wire_n1li_w_lg_dataout1795w(0) <= wire_n1li_dataout AND wire_n1iO_w_lg_w_lg_dataout1771w1772w(0);
	wire_n1li_w_lg_dataout1798w(0) <= wire_n1li_dataout AND wire_n1iO_w_lg_dataout1776w(0);
	wire_n1li_w_lg_dataout1839w(0) <= wire_n1li_dataout AND wire_n1iO_w_lg_dataout1818w(0);
	wire_n1li_w_lg_dataout1790w(0) <= wire_n1li_dataout AND ni00Ol;
	wire_n1li_w_lg_dataout1770w(0) <= NOT wire_n1li_dataout;
	wire_n1li_w_lg_dataout1828w(0) <= wire_n1li_dataout OR wire_n1iO_w_lg_dataout1827w(0);
	wire_n1ll_dataout <= tx_data_tc(3) WHEN cascaded_8b10b_en = '1'  ELSE wire_n0lO_dataout;
	wire_n1ll_w_lg_w_lg_dataout1768w1840w(0) <= wire_n1ll_w_lg_dataout1768w(0) AND wire_n1li_w_lg_dataout1839w(0);
	wire_n1ll_w_lg_w_lg_dataout1768w1791w(0) <= wire_n1ll_w_lg_dataout1768w(0) AND wire_n1li_w_lg_dataout1790w(0);
	wire_n1ll_w_lg_w_lg_dataout1768w1849w(0) <= wire_n1ll_w_lg_dataout1768w(0) AND ni000i;
	wire_n1ll_w_lg_dataout1793w(0) <= wire_n1ll_dataout AND wire_n1li_w_lg_w_lg_dataout1770w1792w(0);
	wire_n1ll_w_lg_dataout1784w(0) <= wire_n1ll_dataout AND wire_n1li_w_lg_w_lg_dataout1770w1783w(0);
	wire_n1ll_w_lg_dataout1902w(0) <= wire_n1ll_dataout AND wire_n1li_w_lg_w_lg_dataout1770w1901w(0);
	wire_n1ll_w_lg_dataout1897w(0) <= wire_n1ll_dataout AND wire_n1li_w_lg_w_lg_dataout1770w1896w(0);
	wire_n1ll_w_lg_dataout1888w(0) <= wire_n1ll_dataout AND wire_n1li_w_lg_w_lg_dataout1770w1887w(0);
	wire_n1ll_w_lg_dataout1885w(0) <= wire_n1ll_dataout AND wire_n1li_w_lg_w_lg_dataout1770w1884w(0);
	wire_n1ll_w_lg_dataout1891w(0) <= wire_n1ll_dataout AND wire_n1li_w_lg_dataout1890w(0);
	wire_n1ll_w_lg_dataout1796w(0) <= wire_n1ll_dataout AND wire_n1li_w_lg_dataout1795w(0);
	wire_n1ll_w_lg_dataout1799w(0) <= wire_n1ll_dataout AND wire_n1li_w_lg_dataout1798w(0);
	wire_n1ll_w_lg_dataout1768w(0) <= NOT wire_n1ll_dataout;
	wire_n1ll_w_lg_w_lg_w_lg_dataout1768w1840w1842w(0) <= wire_n1ll_w_lg_w_lg_dataout1768w1840w(0) OR wire_n1lO_w_lg_dataout1841w(0);
	wire_n1ll_w_lg_w_lg_w_lg_dataout1768w1791w1794w(0) <= wire_n1ll_w_lg_w_lg_dataout1768w1791w(0) OR wire_n1ll_w_lg_dataout1793w(0);
	wire_n1ll_w_lg_w_lg_w_lg_dataout1768w1849w1850w(0) <= wire_n1ll_w_lg_w_lg_dataout1768w1849w(0) OR ni00iO;
	wire_n1ll_w_lg_w_lg_w_lg_w_lg_dataout1768w1840w1842w1844w(0) <= wire_n1ll_w_lg_w_lg_w_lg_dataout1768w1840w1842w(0) OR wire_n1lO_w_lg_dataout1843w(0);
	wire_n1ll_w_lg_w_lg_w_lg_w_lg_dataout1768w1791w1794w1797w(0) <= wire_n1ll_w_lg_w_lg_w_lg_dataout1768w1791w1794w(0) OR wire_n1ll_w_lg_dataout1796w(0);
	wire_n1ll_w1846w(0) <= wire_n1ll_w_lg_w_lg_w_lg_w_lg_dataout1768w1840w1842w1844w(0) OR wire_n1lO_w_lg_dataout1845w(0);
	wire_n1ll_w1800w(0) <= wire_n1ll_w_lg_w_lg_w_lg_w_lg_dataout1768w1791w1794w1797w(0) OR wire_n1ll_w_lg_dataout1799w(0);
	wire_n1ll_w_lg_w1846w1847w(0) <= wire_n1ll_w1846w(0) OR ni001l;
	wire_n1lO_dataout <= tx_data_tc(4) WHEN cascaded_8b10b_en = '1'  ELSE wire_n0Oi_dataout;
	wire_n1lO_w_lg_w_lg_w_lg_dataout1788w1789w1801w(0) <= wire_n1lO_w_lg_w_lg_dataout1788w1789w(0) AND wire_n1ll_w1800w(0);
	wire_n1lO_w_lg_w_lg_dataout1870w1871w(0) <= wire_n1lO_w_lg_dataout1870w(0) AND wire_n1li_dataout;
	wire_n1lO_w_lg_w_lg_dataout1788w1851w(0) <= wire_n1lO_w_lg_dataout1788w(0) AND wire_n1ll_w_lg_w_lg_w_lg_dataout1768w1849w1850w(0);
	wire_n1lO_w_lg_w_lg_dataout1788w1789w(0) <= wire_n1lO_w_lg_dataout1788w(0) AND wire_n1ll_dataout;
	wire_n1lO_w_lg_w_lg_w_lg_dataout1788w1830w1831w(0) <= wire_n1lO_w_lg_w_lg_dataout1788w1830w(0) AND ni000l;
	wire_n1lO_w_lg_dataout1836w(0) <= wire_n1lO_dataout AND wire_w_lg_w_lg_w_lg_ni000i1832w1834w1835w(0);
	wire_n1lO_w_lg_dataout1769w(0) <= wire_n1lO_dataout AND wire_n1ll_w_lg_dataout1768w(0);
	wire_n1lO_w_lg_dataout1870w(0) <= wire_n1lO_dataout AND wire_n1ll_dataout;
	wire_n1lO_w_lg_dataout1845w(0) <= wire_n1lO_dataout AND ni000i;
	wire_n1lO_w_lg_dataout1843w(0) <= wire_n1lO_dataout AND ni00li;
	wire_n1lO_w_lg_dataout1841w(0) <= wire_n1lO_dataout AND ni00ll;
	wire_n1lO_w_lg_dataout1788w(0) <= NOT wire_n1lO_dataout;
	wire_n1lO_w_lg_w_lg_dataout1788w1830w(0) <= wire_n1lO_w_lg_dataout1788w(0) OR wire_nl1iii_dataout;
	wire_n1Oi_dataout <= tx_data_tc(5) WHEN cascaded_8b10b_en = '1'  ELSE wire_n0Ol_dataout;
	wire_n1Oi_w_lg_dataout1814w(0) <= NOT wire_n1Oi_dataout;
	wire_n1Ol_dataout <= tx_data_tc(6) WHEN cascaded_8b10b_en = '1'  ELSE wire_n0OO_dataout;
	wire_n1Ol_w_lg_dataout1805w(0) <= wire_n1Ol_dataout AND wire_nil_w_lg_dataout1804w(0);
	wire_n1Ol_w_lg_dataout1767w(0) <= NOT wire_n1Ol_dataout;
	wire_n1OO_dataout <= tx_data_tc(7) WHEN cascaded_8b10b_en = '1'  ELSE wire_ni1i_dataout;
	wire_n1OO_w_lg_dataout1806w(0) <= wire_n1OO_dataout AND wire_n1Ol_w_lg_dataout1805w(0);
	wire_n1OO_w_lg_dataout1763w(0) <= NOT wire_n1OO_dataout;
	wire_ni0i_dataout <= wire_nl0l_dataout AND NOT(nii1Ol);
	wire_ni0l_dataout <= wire_nl0O_dataout AND NOT(nii1Ol);
	wire_ni0O_dataout <= wire_nlii_dataout AND NOT(nii1Ol);
	wire_ni10i_dataout <= wire_ni10l_dataout OR (wire_w_lg_rforce_disp1040w(0) AND tx_data_9_tc(0));
	wire_ni10l_dataout <= n01il AND NOT((wire_w_lg_rforce_disp1036w(0) AND tx_data_9_tc(0)));
	wire_ni1i_dataout <= wire_nl1l_dataout AND NOT(nii1Ol);
	wire_ni1l_dataout <= wire_nl1O_dataout AND NOT(nii1Ol);
	wire_ni1O_dataout <= wire_nl0i_dataout AND NOT(nii1Ol);
	wire_nii_dataout <= tx_ctl_tc(1) AND rendec_data_sel_tx;
	wire_nii0i_dataout <= wire_niil0i_o WHEN rtxbitslip_en = '1'  ELSE wire_niliO_o;
	wire_nii0l_dataout <= wire_niil0l_o WHEN rtxbitslip_en = '1'  ELSE wire_nilli_o;
	wire_nii0O_dataout <= wire_niil0O_o WHEN rtxbitslip_en = '1'  ELSE wire_nilll_o;
	wire_nii1l_dataout <= wire_niil1l_o WHEN rtxbitslip_en = '1'  ELSE wire_nilii_o;
	wire_nii1O_dataout <= wire_niil1O_o WHEN rtxbitslip_en = '1'  ELSE wire_nilil_o;
	wire_niii_dataout <= wire_nlil_dataout AND NOT(nii1Ol);
	wire_niiii_dataout <= wire_niilii_o WHEN rtxbitslip_en = '1'  ELSE wire_nillO_o;
	wire_niiil_dataout <= wire_niilil_o WHEN rtxbitslip_en = '1'  ELSE wire_nilOi_o;
	wire_niiiO_dataout <= wire_niiliO_o WHEN rtxbitslip_en = '1'  ELSE wire_nilOl_o;
	wire_niil_dataout <= wire_nliO_dataout AND NOT(nii1Ol);
	wire_niili_dataout <= wire_niilli_o WHEN rtxbitslip_en = '1'  ELSE wire_nilOO_o;
	wire_niill_dataout <= wire_niilll_o WHEN rtxbitslip_en = '1'  ELSE wire_niO1i_o;
	wire_niilO_dataout <= wire_niillO_o WHEN rtxbitslip_en = '1'  ELSE wire_niO1l_o;
	wire_niiO_dataout <= wire_nlli_dataout AND NOT(nii1Ol);
	wire_niiOi_dataout <= wire_niilOi_o WHEN rtxbitslip_en = '1'  ELSE wire_niO1O_o;
	wire_niiOl_dataout <= wire_niilOl_o WHEN rtxbitslip_en = '1'  ELSE wire_niO0i_o;
	wire_niiOO_dataout <= wire_niilOO_o WHEN rtxbitslip_en = '1'  ELSE wire_niO0l_o;
	wire_nil_dataout <= tx_ctl_tc(0) WHEN cascaded_8b10b_en = '1'  ELSE wire_nli_dataout;
	wire_nil_w_lg_dataout1804w(0) <= wire_nil_dataout AND wire_n1Oi_dataout;
	wire_nil00l_dataout <= wire_nilOO_o AND NOT(ni01il);
	wire_nil00O_dataout <= wire_niO1i_o AND NOT(ni01il);
	wire_nil0i_dataout <= wire_niiO0i_o WHEN rtxbitslip_en = '1'  ELSE wire_niOiO_o;
	wire_nil0l_dataout <= wire_niiO0l_o WHEN rtxbitslip_en = '1'  ELSE wire_niOli_o;
	wire_nil0O_dataout <= wire_niiO0O_o WHEN rtxbitslip_en = '1'  ELSE wire_niOll_o;
	wire_nil0OO_dataout <= wire_niOli_o AND NOT(ni01il);
	wire_nil1i_dataout <= wire_niiO1i_o WHEN rtxbitslip_en = '1'  ELSE wire_niO0O_o;
	wire_nil1l_dataout <= wire_niiO1l_o WHEN rtxbitslip_en = '1'  ELSE wire_niOii_o;
	wire_nil1O_dataout <= wire_niiO1O_o WHEN rtxbitslip_en = '1'  ELSE wire_niOil_o;
	wire_nili_dataout <= wire_nlOii_dataout OR nii1iO;
	wire_nili1i_dataout <= wire_niOll_o AND NOT(ni01il);
	wire_niliOl_dataout <= wire_niO1l_o AND ni01iO;
	wire_niliOO_dataout <= wire_niO1O_o AND ni01iO;
	wire_nill_dataout <= wire_nlOil_dataout AND NOT(nii1iO);
	wire_nill0i_dataout <= wire_niOii_o AND ni01iO;
	wire_nill0l_dataout <= wire_niOil_o AND ni01iO;
	wire_nill0O_dataout <= wire_niOiO_o AND ni01iO;
	wire_nill1i_dataout <= wire_niO0i_o AND ni01iO;
	wire_nill1l_dataout <= wire_niO0l_o AND ni01iO;
	wire_nill1O_dataout <= wire_niO0O_o AND ni01iO;
	wire_nillii_dataout <= wire_niOli_o AND ni01iO;
	wire_nillil_dataout <= wire_niOll_o AND ni01iO;
	wire_nilO_dataout <= wire_nlOiO_dataout OR nii1iO;
	wire_nilO0i_dataout <= wire_nilOO_o AND NOT(ni01li);
	wire_nilO0l_dataout <= wire_niO1i_o AND NOT(ni01li);
	wire_nilO0O_dataout <= wire_niO1l_o AND NOT(ni01li);
	wire_nilOii_dataout <= wire_niO1O_o AND NOT(ni01li);
	wire_nilOil_dataout <= wire_niO0i_o AND NOT(ni01li);
	wire_nilOiO_dataout <= wire_niO0l_o AND NOT(ni01li);
	wire_nilOli_dataout <= wire_niO0O_o AND NOT(ni01li);
	wire_nilOll_dataout <= wire_niOii_o AND NOT(ni01li);
	wire_nilOlO_dataout <= wire_niOil_o AND NOT(ni01li);
	wire_nilOOi_dataout <= wire_niOiO_o AND NOT(ni01li);
	wire_nilOOl_dataout <= wire_niOli_o AND NOT(ni01li);
	wire_nilOOO_dataout <= wire_niOll_o AND NOT(ni01li);
	wire_niO_dataout <= tx_ctl_tc(1) WHEN cascaded_8b10b_en = '1'  ELSE wire_nll_dataout;
	wire_niO_w_lg_dataout1653w(0) <= wire_niO_dataout AND wire_n00O_dataout;
	wire_niOi_dataout <= wire_nlOli_dataout AND NOT(nii1iO);
	wire_niOl_dataout <= wire_nlOll_dataout AND NOT(nii1iO);
	wire_niOlOi_dataout <= wire_n0O1l_w_lg_dataout1848w(0) WHEN ((ni00il OR ((wire_nl1iii_dataout OR ni00ll) OR ni00li)) OR ni001i) = '1'  ELSE wire_n0O1l_dataout;
	wire_niOlOi_w_lg_w_lg_dataout1755w1758w(0) <= wire_niOlOi_w_lg_dataout1755w(0) AND wire_nl00ll_w_lg_dataout1757w(0);
	wire_niOlOi_w_lg_w_lg_dataout1755w1760w(0) <= wire_niOlOi_w_lg_dataout1755w(0) AND ni0i0O;
	wire_niOlOi_w_lg_dataout1802w(0) <= wire_niOlOi_dataout AND wire_n1lO_w_lg_w_lg_w_lg_dataout1788w1789w1801w(0);
	wire_niOlOi_w_lg_dataout1755w(0) <= NOT wire_niOlOi_dataout;
	wire_niOlOi_w_lg_w_lg_w_lg_dataout1755w1758w1759w(0) <= wire_niOlOi_w_lg_w_lg_dataout1755w1758w(0) OR ni0i0l;
	wire_niOO_dataout <= wire_nlOlO_dataout AND NOT(nii1iO);
	wire_niOOOi_dataout <= wire_n1il_w_lg_dataout1775w(0) WHEN ni01OO = '1'  ELSE wire_n1il_dataout;
	wire_niOOOl_dataout <= wire_nl1i0O_w_lg_dataout1861w(0) WHEN ni01OO = '1'  ELSE wire_nl1i0O_dataout;
	wire_niOOOO_dataout <= wire_nl10OO_w_lg_dataout1860w(0) WHEN ni01OO = '1'  ELSE wire_nl10OO_dataout;
	wire_nl000i_dataout <= wire_n1OO_w_lg_dataout1763w(0) WHEN ni0i0i = '1'  ELSE wire_n1OO_dataout;
	wire_nl000l_dataout <= wire_nl01iO_w_lg_dataout1762w(0) WHEN ni0i0i = '1'  ELSE wire_nl01iO_dataout;
	wire_nl001i_dataout <= wire_n1Oi_dataout AND NOT(ni0i1O);
	wire_nl001i_w_lg_dataout1765w(0) <= NOT wire_nl001i_dataout;
	wire_nl001l_dataout <= wire_nl001i_w_lg_dataout1765w(0) WHEN ni0i0i = '1'  ELSE wire_nl001i_dataout;
	wire_nl001O_dataout <= wire_nl01Ol_w_lg_dataout1764w(0) WHEN ni0i0i = '1'  ELSE wire_nl01Ol_dataout;
	wire_nl00ll_dataout <= ni0iii WHEN r8b10b_enc_ibm_en = '1'  ELSE wire_nil_dataout;
	wire_nl00ll_w_lg_dataout1757w(0) <= wire_nl00ll_dataout AND wire_w_lg_ni0i0O1756w(0);
	wire_nl010O_dataout <= wire_niOlOi_w_lg_dataout1755w(0) WHEN (ni0i1i OR (wire_n1OO_dataout AND ni0i0O)) = '1'  ELSE wire_niOlOi_dataout;
	wire_nl01iO_dataout <= wire_nl01li_dataout OR ni0i1O;
	wire_nl01iO_w_lg_dataout1762w(0) <= NOT wire_nl01iO_dataout;
	wire_nl01li_dataout <= wire_w_lg_ni0i0O1756w(0) AND NOT(wire_n1OO_dataout);
	wire_nl01Ol_dataout <= wire_n1Ol_w_lg_dataout1767w(0) WHEN ni0i1i = '1'  ELSE wire_n1Ol_dataout;
	wire_nl01Ol_w_lg_dataout1764w(0) <= NOT wire_nl01Ol_dataout;
	wire_nl0i_dataout <= wire_n11i_dataout AND NOT(nii1iO);
	wire_nl0l_dataout <= wire_n11l_dataout AND NOT(nii1iO);
	wire_nl0O_dataout <= wire_n11O_dataout AND NOT(nii1iO);
	wire_nl10Ol_dataout <= wire_n1ll_w_lg_dataout1768w(0) WHEN ni00li = '1'  ELSE wire_n1ll_dataout;
	wire_nl10Ol_w_lg_dataout1859w(0) <= NOT wire_nl10Ol_dataout;
	wire_nl10OO_dataout <= wire_n1li_w_lg_dataout1770w(0) WHEN ((wire_n1lO_dataout AND (wire_n1ll_dataout AND (wire_n1li_w_lg_dataout1770w(0) AND wire_n1iO_w_lg_w_lg_dataout1771w1817w(0)))) OR ni00ll) = '1'  ELSE wire_n1li_dataout;
	wire_nl10OO_w_lg_dataout1860w(0) <= NOT wire_nl10OO_dataout;
	wire_nl111i_dataout <= wire_nl10Ol_w_lg_dataout1859w(0) WHEN ni01OO = '1'  ELSE wire_nl10Ol_dataout;
	wire_nl111l_dataout <= wire_w_lg_ni000O1858w(0) WHEN ni01OO = '1'  ELSE ni000O;
	wire_nl111O_dataout <= wire_w_lg_ni001O1857w(0) WHEN ni01OO = '1'  ELSE ni001O;
	wire_nl1i_dataout <= wire_nlOOi_dataout OR nii1iO;
	wire_nl1i0O_dataout <= wire_n1iO_w_lg_dataout1771w(0) WHEN ni00lO = '1'  ELSE wire_n1iO_dataout;
	wire_nl1i0O_w_lg_dataout1861w(0) <= NOT wire_nl1i0O_dataout;
	wire_nl1iii_dataout <= ni0iii WHEN r8b10b_enc_ibm_en = '1'  ELSE wire_nil_dataout;
	wire_nl1l_dataout <= wire_nlOOl_dataout OR nii1iO;
	wire_nl1O_dataout <= wire_nlOOO_dataout AND NOT(nii1iO);
	wire_nli_dataout <= wire_n0O_dataout AND NOT(nii00O);
	wire_nli0il_dataout <= wire_n01i_w_lg_dataout1624w(0) WHEN ni0ilO = '1'  ELSE wire_n01i_dataout;
	wire_nli0iO_dataout <= wire_nliO1i_w_lg_dataout1710w(0) WHEN ni0ilO = '1'  ELSE wire_nliO1i_dataout;
	wire_nli0li_dataout <= wire_nlilli_w_lg_dataout1709w(0) WHEN ni0ilO = '1'  ELSE wire_nlilli_dataout;
	wire_nli0ll_dataout <= wire_nliliO_w_lg_dataout1708w(0) WHEN ni0ilO = '1'  ELSE wire_nliliO_dataout;
	wire_nli0lO_dataout <= wire_w_lg_ni0l1O1707w(0) WHEN ni0ilO = '1'  ELSE ni0l1O;
	wire_nli0Oi_dataout <= wire_w_lg_ni0iOO1706w(0) WHEN ni0ilO = '1'  ELSE ni0iOO;
	wire_nli1il_dataout <= wire_n0O1O_w_lg_dataout1697w(0) WHEN ((ni0l0l OR ((wire_nliO1l_dataout OR ni0lil) OR ni0lii)) OR ni0iOi) = '1'  ELSE wire_n0O1O_dataout;
	wire_nli1il_w_lg_w_lg_dataout1604w1607w(0) <= wire_nli1il_w_lg_dataout1604w(0) AND wire_nlll0O_w_lg_dataout1606w(0);
	wire_nli1il_w_lg_w_lg_dataout1604w1609w(0) <= wire_nli1il_w_lg_dataout1604w(0) AND ni0O1O;
	wire_nli1il_w_lg_dataout1651w(0) <= wire_nli1il_dataout AND wire_n00l_w_lg_w_lg_w_lg_dataout1637w1638w1650w(0);
	wire_nli1il_w_lg_dataout1604w(0) <= NOT wire_nli1il_dataout;
	wire_nli1il_w_lg_w_lg_w_lg_dataout1604w1607w1608w(0) <= wire_nli1il_w_lg_w_lg_dataout1604w1607w(0) OR ni0O1l;
	wire_nlii_dataout <= wire_n10i_dataout AND NOT(nii1iO);
	wire_nlil_dataout <= wire_n10l_dataout AND NOT(nii1iO);
	wire_nliliO_dataout <= wire_n00i_w_lg_dataout1617w(0) WHEN ni0lii = '1'  ELSE wire_n00i_dataout;
	wire_nliliO_w_lg_dataout1708w(0) <= NOT wire_nliliO_dataout;
	wire_nlilli_dataout <= wire_n01O_w_lg_dataout1619w(0) WHEN ((wire_n00l_dataout AND (wire_n00i_dataout AND (wire_n01O_w_lg_dataout1619w(0) AND wire_n01l_w_lg_w_lg_dataout1620w1666w(0)))) OR ni0lil) = '1'  ELSE wire_n01O_dataout;
	wire_nlilli_w_lg_dataout1709w(0) <= NOT wire_nlilli_dataout;
	wire_nliO_dataout <= wire_n10O_dataout AND NOT(nii1iO);
	wire_nliO1i_dataout <= wire_n01l_w_lg_dataout1620w(0) WHEN ni0liO = '1'  ELSE wire_n01l_dataout;
	wire_nliO1i_w_lg_dataout1710w(0) <= NOT wire_nliO1i_dataout;
	wire_nliO1l_dataout <= ni0O0i WHEN r8b10b_enc_ibm_en = '1'  ELSE wire_niO_dataout;
	wire_nll_dataout <= wire_nii_dataout AND NOT(nii00O);
	wire_nlli_dataout <= wire_n1ii_dataout AND NOT(nii1iO);
	wire_nlli0i_dataout <= wire_nlli0l_dataout OR ni0lOO;
	wire_nlli0i_w_lg_dataout1611w(0) <= NOT wire_nlli0i_dataout;
	wire_nlli0l_dataout <= wire_w_lg_ni0O1O1605w(0) AND NOT(wire_n0il_dataout);
	wire_nlli1i_dataout <= wire_nli1il_w_lg_dataout1604w(0) WHEN (ni0lOi OR (wire_n0il_dataout AND ni0O1O)) = '1'  ELSE wire_nli1il_dataout;
	wire_nlliiO_dataout <= wire_n0ii_w_lg_dataout1616w(0) WHEN ni0lOi = '1'  ELSE wire_n0ii_dataout;
	wire_nlliiO_w_lg_dataout1613w(0) <= NOT wire_nlliiO_dataout;
	wire_nllill_dataout <= wire_n00O_dataout AND NOT(ni0lOO);
	wire_nllill_w_lg_dataout1614w(0) <= NOT wire_nllill_dataout;
	wire_nllilO_dataout <= wire_nllill_w_lg_dataout1614w(0) WHEN ni0O1i = '1'  ELSE wire_nllill_dataout;
	wire_nlliOi_dataout <= wire_nlliiO_w_lg_dataout1613w(0) WHEN ni0O1i = '1'  ELSE wire_nlliiO_dataout;
	wire_nlliOl_dataout <= wire_n0il_w_lg_dataout1612w(0) WHEN ni0O1i = '1'  ELSE wire_n0il_dataout;
	wire_nlliOO_dataout <= wire_nlli0i_w_lg_dataout1611w(0) WHEN ni0O1i = '1'  ELSE wire_nlli0i_dataout;
	wire_nlll0O_dataout <= ni0O0i WHEN r8b10b_enc_ibm_en = '1'  ELSE wire_niO_dataout;
	wire_nlll0O_w_lg_dataout1606w(0) <= wire_nlll0O_dataout AND wire_w_lg_ni0O1O1605w(0);
	wire_nlOii_dataout <= tx_data_tc(0) WHEN rendec_data_sel_tx = '1'  ELSE tx_data_ts(0);
	wire_nlOil_dataout <= tx_data_tc(1) WHEN rendec_data_sel_tx = '1'  ELSE tx_data_ts(1);
	wire_nlOiO_dataout <= tx_data_tc(2) WHEN rendec_data_sel_tx = '1'  ELSE tx_data_ts(2);
	wire_nlOli_dataout <= tx_data_tc(3) WHEN rendec_data_sel_tx = '1'  ELSE tx_data_ts(3);
	wire_nlOll_dataout <= tx_data_tc(4) WHEN rendec_data_sel_tx = '1'  ELSE tx_data_ts(4);
	wire_nlOlO_dataout <= tx_data_tc(5) WHEN rendec_data_sel_tx = '1'  ELSE tx_data_ts(5);
	wire_nlOOi_dataout <= tx_data_tc(6) WHEN rendec_data_sel_tx = '1'  ELSE tx_data_ts(6);
	wire_nlOOl_dataout <= tx_data_tc(7) WHEN rendec_data_sel_tx = '1'  ELSE tx_data_ts(7);
	wire_nlOOO_dataout <= tx_data_tc(8) AND rendec_data_sel_tx;
	wire_nili1O_i <= ( tx_boundary_sel(4 DOWNTO 0));
	nili1O :  oper_decoder
	  GENERIC MAP (
		width_i => 5,
		width_o => 32
	  )
	  PORT MAP ( 
		i => wire_nili1O_i,
		o => wire_nili1O_o
	  );
	wire_nillli_i <= ( tx_boundary_sel(3 DOWNTO 0));
	nillli :  oper_decoder
	  GENERIC MAP (
		width_i => 4,
		width_o => 16
	  )
	  PORT MAP ( 
		i => wire_nillli_i,
		o => wire_nillli_o
	  );
	wire_n010i_w_lg_o200w(0) <= NOT wire_n010i_o;
	wire_n010i_data <= ( tx_data_pg(17) & tx_data_pg(17) & tx_data_pg(17) & tx_data_pg(17) & rev_loop_data(17) & wire_nlliOi_dataout & tx_data_pg(17) & wire_nlliOi_dataout & tx_data_pg(17) & tx_data_pg(17) & tx_data_pg(17) & tx_data_pg(17) & rev_loop_data(17) & tx_data_tc(15) & tx_data_pg(17) & tx_data_tc(15));
	wire_n010i_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n010i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n010i_data,
		o => wire_n010i_o,
		sel => wire_n010i_sel
	  );
	wire_n010l_w_lg_o188w(0) <= NOT wire_n010l_o;
	wire_n010l_data <= ( tx_data_pg(18) & tx_data_pg(18) & tx_data_pg(18) & tx_data_pg(18) & rev_loop_data(18) & wire_nlliOl_dataout & tx_data_pg(18) & wire_nlliOl_dataout & tx_data_pg(18) & tx_data_pg(18) & tx_data_pg(18) & tx_data_pg(18) & rev_loop_data(18) & tx_ctl_tc(1) & tx_data_pg(18) & tx_ctl_tc(1));
	wire_n010l_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n010l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n010l_data,
		o => wire_n010l_o,
		sel => wire_n010l_sel
	  );
	wire_n010O_w_lg_o178w(0) <= NOT wire_n010O_o;
	wire_n010O_data <= ( tx_data_pg(19) & tx_data_pg(19) & tx_data_pg(19) & tx_data_pg(19) & rev_loop_data(19) & wire_nlliOO_dataout & tx_data_pg(19) & wire_nlliOO_dataout & tx_data_pg(19) & tx_data_pg(19) & tx_data_pg(19) & tx_data_pg(19) & rev_loop_data(19) & tx_data_9_tc(1) & tx_data_pg(19) & tx_data_9_tc(1));
	wire_n010O_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n010O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n010O_data,
		o => wire_n010O_o,
		sel => wire_n010O_sel
	  );
	wire_n011i_w_lg_o229w(0) <= NOT wire_n011i_o;
	wire_n011i_data <= ( tx_data_pg(14) & tx_data_pg(14) & tx_data_pg(14) & tx_data_pg(14) & rev_loop_data(14) & wire_nli0lO_dataout & tx_data_pg(14) & wire_nli0lO_dataout & tx_data_pg(14) & tx_data_pg(14) & tx_data_pg(14) & tx_data_pg(14) & rev_loop_data(14) & tx_data_tc(12) & tx_data_pg(14) & tx_data_tc(12));
	wire_n011i_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n011i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n011i_data,
		o => wire_n011i_o,
		sel => wire_n011i_sel
	  );
	wire_n011l_w_lg_o220w(0) <= NOT wire_n011l_o;
	wire_n011l_data <= ( tx_data_pg(15) & tx_data_pg(15) & tx_data_pg(15) & tx_data_pg(15) & rev_loop_data(15) & wire_nli0Oi_dataout & tx_data_pg(15) & wire_nli0Oi_dataout & tx_data_pg(15) & tx_data_pg(15) & tx_data_pg(15) & tx_data_pg(15) & rev_loop_data(15) & tx_data_tc(13) & tx_data_pg(15) & tx_data_tc(13));
	wire_n011l_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n011l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n011l_data,
		o => wire_n011l_o,
		sel => wire_n011l_sel
	  );
	wire_n011O_w_lg_o211w(0) <= NOT wire_n011O_o;
	wire_n011O_data <= ( tx_data_pg(16) & tx_data_pg(16) & tx_data_pg(16) & tx_data_pg(16) & rev_loop_data(16) & wire_nllilO_dataout & tx_data_pg(16) & wire_nllilO_dataout & tx_data_pg(16) & tx_data_pg(16) & tx_data_pg(16) & tx_data_pg(16) & rev_loop_data(16) & tx_data_tc(14) & tx_data_pg(16) & tx_data_tc(14));
	wire_n011O_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n011O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n011O_data,
		o => wire_n011O_o,
		sel => wire_n011O_sel
	  );
	wire_n1O0i_w_lg_o122w(0) <= NOT wire_n1O0i_o;
	wire_n1O0i_data <= ( tx_data_pg(2) & tx_data_pg(2) & tx_data_pg(2) & tx_data_pg(2) & rev_loop_data(2) & wire_niOOOO_dataout & tx_data_pg(2) & wire_niOOOO_dataout & tx_data_pg(2) & tx_data_pg(2) & tx_data_pg(2) & tx_data_pg(2) & rev_loop_data(2) & tx_data_tc(2) & tx_data_pg(2) & tx_data_tc(2));
	wire_n1O0i_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n1O0i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1O0i_data,
		o => wire_n1O0i_o,
		sel => wire_n1O0i_sel
	  );
	wire_n1O0l_w_lg_o133w(0) <= NOT wire_n1O0l_o;
	wire_n1O0l_data <= ( tx_data_pg(3) & tx_data_pg(3) & tx_data_pg(3) & tx_data_pg(3) & rev_loop_data(3) & wire_nl111i_dataout & tx_data_pg(3) & wire_nl111i_dataout & tx_data_pg(3) & tx_data_pg(3) & tx_data_pg(3) & tx_data_pg(3) & rev_loop_data(3) & tx_data_tc(3) & tx_data_pg(3) & tx_data_tc(3));
	wire_n1O0l_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n1O0l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1O0l_data,
		o => wire_n1O0l_o,
		sel => wire_n1O0l_sel
	  );
	wire_n1O0O_w_lg_o130w(0) <= NOT wire_n1O0O_o;
	wire_n1O0O_data <= ( tx_data_pg(4) & tx_data_pg(4) & tx_data_pg(4) & tx_data_pg(4) & rev_loop_data(4) & wire_nl111l_dataout & tx_data_pg(4) & wire_nl111l_dataout & tx_data_pg(4) & tx_data_pg(4) & tx_data_pg(4) & tx_data_pg(4) & rev_loop_data(4) & tx_data_tc(4) & tx_data_pg(4) & tx_data_tc(4));
	wire_n1O0O_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n1O0O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1O0O_data,
		o => wire_n1O0O_o,
		sel => wire_n1O0O_sel
	  );
	wire_n1O1l_w_lg_o96w(0) <= NOT wire_n1O1l_o;
	wire_n1O1l_data <= ( tx_data_pg(0) & tx_data_pg(0) & tx_data_pg(0) & tx_data_pg(0) & rev_loop_data(0) & wire_niOOOi_dataout & tx_data_pg(0) & wire_niOOOi_dataout & tx_data_pg(0) & tx_data_pg(0) & tx_data_pg(0) & tx_data_pg(0) & rev_loop_data(0) & tx_data_tc(0) & tx_data_pg(0) & tx_data_tc(0));
	wire_n1O1l_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n1O1l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1O1l_data,
		o => wire_n1O1l_o,
		sel => wire_n1O1l_sel
	  );
	wire_n1O1O_w_lg_o108w(0) <= NOT wire_n1O1O_o;
	wire_n1O1O_data <= ( tx_data_pg(1) & tx_data_pg(1) & tx_data_pg(1) & tx_data_pg(1) & rev_loop_data(1) & wire_niOOOl_dataout & tx_data_pg(1) & wire_niOOOl_dataout & tx_data_pg(1) & tx_data_pg(1) & tx_data_pg(1) & tx_data_pg(1) & rev_loop_data(1) & tx_data_tc(1) & tx_data_pg(1) & tx_data_tc(1));
	wire_n1O1O_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n1O1O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1O1O_data,
		o => wire_n1O1O_o,
		sel => wire_n1O1O_sel
	  );
	wire_n1Oii_w_lg_o119w(0) <= NOT wire_n1Oii_o;
	wire_n1Oii_data <= ( tx_data_pg(5) & tx_data_pg(5) & tx_data_pg(5) & tx_data_pg(5) & rev_loop_data(5) & wire_nl111O_dataout & tx_data_pg(5) & wire_nl111O_dataout & tx_data_pg(5) & tx_data_pg(5) & tx_data_pg(5) & tx_data_pg(5) & rev_loop_data(5) & tx_data_tc(5) & tx_data_pg(5) & tx_data_tc(5));
	wire_n1Oii_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n1Oii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1Oii_data,
		o => wire_n1Oii_o,
		sel => wire_n1Oii_sel
	  );
	wire_n1Oil_w_lg_o106w(0) <= NOT wire_n1Oil_o;
	wire_n1Oil_data <= ( tx_data_pg(6) & tx_data_pg(6) & tx_data_pg(6) & tx_data_pg(6) & rev_loop_data(6) & wire_nl001l_dataout & tx_data_pg(6) & wire_nl001l_dataout & tx_data_pg(6) & tx_data_pg(6) & tx_data_pg(6) & tx_data_pg(6) & rev_loop_data(6) & tx_data_tc(6) & tx_data_pg(6) & tx_data_tc(6));
	wire_n1Oil_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n1Oil :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1Oil_data,
		o => wire_n1Oil_o,
		sel => wire_n1Oil_sel
	  );
	wire_n1OiO_w_lg_o94w(0) <= NOT wire_n1OiO_o;
	wire_n1OiO_data <= ( tx_data_pg(7) & tx_data_pg(7) & tx_data_pg(7) & tx_data_pg(7) & rev_loop_data(7) & wire_nl001O_dataout & tx_data_pg(7) & wire_nl001O_dataout & tx_data_pg(7) & tx_data_pg(7) & tx_data_pg(7) & tx_data_pg(7) & rev_loop_data(7) & tx_data_tc(7) & tx_data_pg(7) & tx_data_tc(7));
	wire_n1OiO_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n1OiO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1OiO_data,
		o => wire_n1OiO_o,
		sel => wire_n1OiO_sel
	  );
	wire_n1Oli_w_lg_o81w(0) <= NOT wire_n1Oli_o;
	wire_n1Oli_data <= ( tx_data_pg(8) & tx_data_pg(8) & tx_data_pg(8) & tx_data_pg(8) & rev_loop_data(8) & wire_nl000i_dataout & tx_data_pg(8) & wire_nl000i_dataout & tx_data_pg(8) & tx_data_pg(8) & tx_data_pg(8) & tx_data_pg(8) & rev_loop_data(8) & tx_ctl_tc(1) & tx_data_pg(8) & tx_ctl_tc(0));
	wire_n1Oli_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n1Oli :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1Oli_data,
		o => wire_n1Oli_o,
		sel => wire_n1Oli_sel
	  );
	wire_n1Oll_w_lg_o70w(0) <= NOT wire_n1Oll_o;
	wire_n1Oll_data <= ( tx_data_pg(9) & tx_data_pg(9) & tx_data_pg(9) & tx_data_pg(9) & rev_loop_data(9) & wire_nl000l_dataout & tx_data_pg(9) & wire_nl000l_dataout & tx_data_pg(9) & tx_data_pg(9) & tx_data_pg(9) & tx_data_pg(9) & rev_loop_data(9) & tx_data_9_tc(0) & tx_data_pg(9) & tx_data_9_tc(0));
	wire_n1Oll_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n1Oll :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1Oll_data,
		o => wire_n1Oll_o,
		sel => wire_n1Oll_sel
	  );
	wire_n1OlO_w_lg_o265w(0) <= NOT wire_n1OlO_o;
	wire_n1OlO_data <= ( tx_data_pg(10) & tx_data_pg(10) & tx_data_pg(10) & tx_data_pg(10) & rev_loop_data(10) & wire_nli0il_dataout & tx_data_pg(10) & wire_nli0il_dataout & tx_data_pg(10) & tx_data_pg(10) & tx_data_pg(10) & tx_data_pg(10) & rev_loop_data(10) & tx_data_tc(8) & tx_data_pg(10) & tx_data_tc(8));
	wire_n1OlO_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n1OlO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1OlO_data,
		o => wire_n1OlO_o,
		sel => wire_n1OlO_sel
	  );
	wire_n1OOi_w_lg_o256w(0) <= NOT wire_n1OOi_o;
	wire_n1OOi_data <= ( tx_data_pg(11) & tx_data_pg(11) & tx_data_pg(11) & tx_data_pg(11) & rev_loop_data(11) & wire_nli0iO_dataout & tx_data_pg(11) & wire_nli0iO_dataout & tx_data_pg(11) & tx_data_pg(11) & tx_data_pg(11) & tx_data_pg(11) & rev_loop_data(11) & tx_data_tc(9) & tx_data_pg(11) & tx_data_tc(9));
	wire_n1OOi_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n1OOi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1OOi_data,
		o => wire_n1OOi_o,
		sel => wire_n1OOi_sel
	  );
	wire_n1OOl_w_lg_o247w(0) <= NOT wire_n1OOl_o;
	wire_n1OOl_data <= ( tx_data_pg(12) & tx_data_pg(12) & tx_data_pg(12) & tx_data_pg(12) & rev_loop_data(12) & wire_nli0li_dataout & tx_data_pg(12) & wire_nli0li_dataout & tx_data_pg(12) & tx_data_pg(12) & tx_data_pg(12) & tx_data_pg(12) & rev_loop_data(12) & tx_data_tc(10) & tx_data_pg(12) & tx_data_tc(10));
	wire_n1OOl_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n1OOl :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1OOl_data,
		o => wire_n1OOl_o,
		sel => wire_n1OOl_sel
	  );
	wire_n1OOO_w_lg_o238w(0) <= NOT wire_n1OOO_o;
	wire_n1OOO_data <= ( tx_data_pg(13) & tx_data_pg(13) & tx_data_pg(13) & tx_data_pg(13) & rev_loop_data(13) & wire_nli0ll_dataout & tx_data_pg(13) & wire_nli0ll_dataout & tx_data_pg(13) & tx_data_pg(13) & tx_data_pg(13) & tx_data_pg(13) & rev_loop_data(13) & tx_data_tc(11) & tx_data_pg(13) & tx_data_tc(11));
	wire_n1OOO_sel <= ( endec & prbs_en & rrev_loopbk & ni1li);
	n1OOO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1OOO_data,
		o => wire_n1OOO_o,
		sel => wire_n1OOO_sel
	  );
	wire_niil0i_data <= ( wire_niiOiO_o & wire_nil1Ol_o & wire_nili0O_o & wire_nillOi_o);
	wire_niil0i_sel <= ( doublewidth & dwidth);
	niil0i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niil0i_data,
		o => wire_niil0i_o,
		sel => wire_niil0i_sel
	  );
	wire_niil0l_data <= ( wire_niiOli_o & wire_nil1OO_o & wire_niliii_o & wire_nillOl_o);
	wire_niil0l_sel <= ( doublewidth & dwidth);
	niil0l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niil0l_data,
		o => wire_niil0l_o,
		sel => wire_niil0l_sel
	  );
	wire_niil0O_data <= ( wire_niiOll_o & wire_nil01i_o & wire_niliil_o & wire_nillOO_o);
	wire_niil0O_sel <= ( doublewidth & dwidth);
	niil0O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niil0O_data,
		o => wire_niil0O_o,
		sel => wire_niil0O_sel
	  );
	wire_niil1l_data <= ( wire_niiOii_o & wire_nil1lO_o & wire_nili0i_o & wire_nillll_o);
	wire_niil1l_sel <= ( doublewidth & dwidth);
	niil1l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niil1l_data,
		o => wire_niil1l_o,
		sel => wire_niil1l_sel
	  );
	wire_niil1O_data <= ( wire_niiOil_o & wire_nil1Oi_o & wire_nili0l_o & wire_nilllO_o);
	wire_niil1O_sel <= ( doublewidth & dwidth);
	niil1O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niil1O_data,
		o => wire_niil1O_o,
		sel => wire_niil1O_sel
	  );
	wire_niilii_data <= ( wire_niiOlO_o & wire_nil01l_o & wire_niliiO_o & wire_nilO1i_o);
	wire_niilii_sel <= ( doublewidth & dwidth);
	niilii :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niilii_data,
		o => wire_niilii_o,
		sel => wire_niilii_sel
	  );
	wire_niilil_data <= ( wire_niiOOi_o & wire_nil01O_o & wire_nilili_o & wire_nilO1l_o);
	wire_niilil_sel <= ( doublewidth & dwidth);
	niilil :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niilil_data,
		o => wire_niilil_o,
		sel => wire_niilil_sel
	  );
	wire_niiliO_data <= ( wire_niiOOl_o & wire_nil00i_o & wire_nilill_o & wire_nilO1O_o);
	wire_niiliO_sel <= ( doublewidth & dwidth);
	niiliO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niiliO_data,
		o => wire_niiliO_o,
		sel => wire_niiliO_sel
	  );
	wire_niilli_data <= ( wire_niiOOO_o & wire_nil00l_dataout & wire_nililO_o & wire_nilO0i_dataout);
	wire_niilli_sel <= ( doublewidth & dwidth);
	niilli :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niilli_data,
		o => wire_niilli_o,
		sel => wire_niilli_sel
	  );
	wire_niilll_data <= ( wire_nil11i_o & wire_nil00O_dataout & wire_niliOi_o & wire_nilO0l_dataout);
	wire_niilll_sel <= ( doublewidth & dwidth);
	niilll :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niilll_data,
		o => wire_niilll_o,
		sel => wire_niilll_sel
	  );
	wire_niillO_data <= ( wire_nil11l_o & wire_nil0ii_o & wire_niliOl_dataout & wire_nilO0O_dataout);
	wire_niillO_sel <= ( doublewidth & dwidth);
	niillO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niillO_data,
		o => wire_niillO_o,
		sel => wire_niillO_sel
	  );
	wire_niilOi_data <= ( wire_nil11O_o & wire_nil0il_o & wire_niliOO_dataout & wire_nilOii_dataout);
	wire_niilOi_sel <= ( doublewidth & dwidth);
	niilOi :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niilOi_data,
		o => wire_niilOi_o,
		sel => wire_niilOi_sel
	  );
	wire_niilOl_data <= ( wire_nil10i_o & wire_nil0iO_o & wire_nill1i_dataout & wire_nilOil_dataout);
	wire_niilOl_sel <= ( doublewidth & dwidth);
	niilOl :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niilOl_data,
		o => wire_niilOl_o,
		sel => wire_niilOl_sel
	  );
	wire_niilOO_data <= ( wire_nil10l_o & wire_nil0li_o & wire_nill1l_dataout & wire_nilOiO_dataout);
	wire_niilOO_sel <= ( doublewidth & dwidth);
	niilOO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niilOO_data,
		o => wire_niilOO_o,
		sel => wire_niilOO_sel
	  );
	wire_niiO0i_data <= ( wire_nil1iO_o & wire_nil0Ol_o & wire_nill0O_dataout & wire_nilOOi_dataout);
	wire_niiO0i_sel <= ( doublewidth & dwidth);
	niiO0i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niiO0i_data,
		o => wire_niiO0i_o,
		sel => wire_niiO0i_sel
	  );
	wire_niiO0l_data <= ( wire_nil1li_o & wire_nil0OO_dataout & wire_nillii_dataout & wire_nilOOl_dataout);
	wire_niiO0l_sel <= ( doublewidth & dwidth);
	niiO0l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niiO0l_data,
		o => wire_niiO0l_o,
		sel => wire_niiO0l_sel
	  );
	wire_niiO0O_data <= ( wire_nil1ll_o & wire_nili1i_dataout & wire_nillil_dataout & wire_nilOOO_dataout);
	wire_niiO0O_sel <= ( doublewidth & dwidth);
	niiO0O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niiO0O_data,
		o => wire_niiO0O_o,
		sel => wire_niiO0O_sel
	  );
	wire_niiO1i_data <= ( wire_nil10O_o & wire_nil0ll_o & wire_nill1O_dataout & wire_nilOli_dataout);
	wire_niiO1i_sel <= ( doublewidth & dwidth);
	niiO1i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niiO1i_data,
		o => wire_niiO1i_o,
		sel => wire_niiO1i_sel
	  );
	wire_niiO1l_data <= ( wire_nil1ii_o & wire_nil0lO_o & wire_nill0i_dataout & wire_nilOll_dataout);
	wire_niiO1l_sel <= ( doublewidth & dwidth);
	niiO1l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niiO1l_data,
		o => wire_niiO1l_o,
		sel => wire_niiO1l_sel
	  );
	wire_niiO1O_data <= ( wire_nil1il_o & wire_nil0Oi_o & wire_nill0l_dataout & wire_nilOlO_dataout);
	wire_niiO1O_sel <= ( doublewidth & dwidth);
	niiO1O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niiO1O_data,
		o => wire_niiO1O_o,
		sel => wire_niiO1O_sel
	  );
	wire_niiOii_data <= ( wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & niil1i & nii0Oi & nii0Ol & nii0OO & niii1i & niii1l & niii1O & niii0i & niii0l & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o);
	wire_niiOii_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	niiOii :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_niiOii_data,
		o => wire_niiOii_o,
		sel => wire_niiOii_sel
	  );
	wire_niiOil_data <= ( wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & nii0Oi & nii0Ol & nii0OO & niii1i & niii1l & niii1O & niii0i & niii0l & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o);
	wire_niiOil_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	niiOil :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_niiOil_data,
		o => wire_niiOil_o,
		sel => wire_niiOil_sel
	  );
	wire_niiOiO_data <= ( wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & nii0Ol & nii0OO & niii1i & niii1l & niii1O & niii0i & niii0l & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o);
	wire_niiOiO_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	niiOiO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_niiOiO_data,
		o => wire_niiOiO_o,
		sel => wire_niiOiO_sel
	  );
	wire_niiOli_data <= ( wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & nii0OO & niii1i & niii1l & niii1O & niii0i & niii0l & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o);
	wire_niiOli_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	niiOli :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_niiOli_data,
		o => wire_niiOli_o,
		sel => wire_niiOli_sel
	  );
	wire_niiOll_data <= ( wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & niii1i & niii1l & niii1O & niii0i & niii0l & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o);
	wire_niiOll_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	niiOll :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_niiOll_data,
		o => wire_niiOll_o,
		sel => wire_niiOll_sel
	  );
	wire_niiOlO_data <= ( wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & niii1l & niii1O & niii0i & niii0l & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o);
	wire_niiOlO_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	niiOlO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_niiOlO_data,
		o => wire_niiOlO_o,
		sel => wire_niiOlO_sel
	  );
	wire_niiOOi_data <= ( wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & niii1O & niii0i & niii0l & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o);
	wire_niiOOi_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	niiOOi :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_niiOOi_data,
		o => wire_niiOOi_o,
		sel => wire_niiOOi_sel
	  );
	wire_niiOOl_data <= ( wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & niii0i & niii0l & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o);
	wire_niiOOl_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	niiOOl :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_niiOOl_data,
		o => wire_niiOOl_o,
		sel => wire_niiOOl_sel
	  );
	wire_niiOOO_data <= ( wire_nilOO_o & wire_nilOO_o & wire_nilOO_o & wire_nilOO_o & wire_nilOO_o & wire_nilOO_o & wire_nilOO_o & wire_nilOO_o & wire_nilOO_o & wire_nilOO_o & wire_nilOO_o & wire_nilOO_o & niii0l & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_nilOO_o);
	wire_niiOOO_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	niiOOO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_niiOOO_data,
		o => wire_niiOOO_o,
		sel => wire_niiOOO_sel
	  );
	wire_nil00i_data <= ( wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o);
	wire_nil00i_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil00i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil00i_data,
		o => wire_nil00i_o,
		sel => wire_nil00i_sel
	  );
	wire_nil01i_data <= ( wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & niii1i & niii1l & niii1O & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o);
	wire_nil01i_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil01i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil01i_data,
		o => wire_nil01i_o,
		sel => wire_nil01i_sel
	  );
	wire_nil01l_data <= ( wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & niii1l & niii1O & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o);
	wire_nil01l_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil01l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil01l_data,
		o => wire_nil01l_o,
		sel => wire_nil01l_sel
	  );
	wire_nil01O_data <= ( wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & niii1O & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o);
	wire_nil01O_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil01O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil01O_data,
		o => wire_nil01O_o,
		sel => wire_nil01O_sel
	  );
	wire_nil0ii_data <= ( wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_niO1l_o);
	wire_nil0ii_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil0ii :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil0ii_data,
		o => wire_nil0ii_o,
		sel => wire_nil0ii_sel
	  );
	wire_nil0il_data <= ( wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_niO1l_o & wire_niO1O_o);
	wire_nil0il_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil0il :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil0il_data,
		o => wire_nil0il_o,
		sel => wire_nil0il_sel
	  );
	wire_nil0iO_data <= ( wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & niiiiO & niiili & niiill & niiilO & niiiOi & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_niO1l_o & wire_niO1O_o & wire_niO0i_o);
	wire_nil0iO_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil0iO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil0iO_data,
		o => wire_nil0iO_o,
		sel => wire_nil0iO_sel
	  );
	wire_nil0li_data <= ( wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & niiili & niiill & niiilO & niiiOi & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_niO1l_o & wire_niO1O_o & wire_niO0i_o & wire_niO0l_o);
	wire_nil0li_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil0li :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil0li_data,
		o => wire_nil0li_o,
		sel => wire_nil0li_sel
	  );
	wire_nil0ll_data <= ( wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & niiill & niiilO & niiiOi & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_niO1l_o & wire_niO1O_o & wire_niO0i_o & wire_niO0l_o & wire_niO0O_o);
	wire_nil0ll_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil0ll :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil0ll_data,
		o => wire_nil0ll_o,
		sel => wire_nil0ll_sel
	  );
	wire_nil0lO_data <= ( wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & niiilO & niiiOi & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_niO1l_o & wire_niO1O_o & wire_niO0i_o & wire_niO0l_o & wire_niO0O_o & wire_niOii_o);
	wire_nil0lO_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil0lO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil0lO_data,
		o => wire_nil0lO_o,
		sel => wire_nil0lO_sel
	  );
	wire_nil0Oi_data <= ( wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & niiiOi & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_niO1l_o & wire_niO1O_o & wire_niO0i_o & wire_niO0l_o & wire_niO0O_o & wire_niOii_o & wire_niOil_o);
	wire_nil0Oi_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil0Oi :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil0Oi_data,
		o => wire_nil0Oi_o,
		sel => wire_nil0Oi_sel
	  );
	wire_nil0Ol_data <= ( wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_niO1l_o & wire_niO1O_o & wire_niO0i_o & wire_niO0l_o & wire_niO0O_o & wire_niOii_o & wire_niOil_o & wire_niOiO_o);
	wire_nil0Ol_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil0Ol :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil0Ol_data,
		o => wire_nil0Ol_o,
		sel => wire_nil0Ol_sel
	  );
	wire_nil10i_data <= ( wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & wire_niO0i_o & niiiiO & niiili & niiill & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_nilOO_o & wire_niO1i_o & wire_niO1l_o & wire_niO1O_o & wire_niO0i_o);
	wire_nil10i_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil10i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil10i_data,
		o => wire_nil10i_o,
		sel => wire_nil10i_sel
	  );
	wire_nil10l_data <= ( wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & wire_niO0l_o & niiili & niiill & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_nilOO_o & wire_niO1i_o & wire_niO1l_o & wire_niO1O_o & wire_niO0i_o & wire_niO0l_o);
	wire_nil10l_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil10l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil10l_data,
		o => wire_nil10l_o,
		sel => wire_nil10l_sel
	  );
	wire_nil10O_data <= ( wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & wire_niO0O_o & niiill & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_nilOO_o & wire_niO1i_o & wire_niO1l_o & wire_niO1O_o & wire_niO0i_o & wire_niO0l_o & wire_niO0O_o);
	wire_nil10O_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil10O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil10O_data,
		o => wire_nil10O_o,
		sel => wire_nil10O_sel
	  );
	wire_nil11i_data <= ( wire_niO1i_o & wire_niO1i_o & wire_niO1i_o & wire_niO1i_o & wire_niO1i_o & wire_niO1i_o & wire_niO1i_o & wire_niO1i_o & wire_niO1i_o & wire_niO1i_o & wire_niO1i_o & wire_niO1i_o & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_nilOO_o & wire_niO1i_o);
	wire_nil11i_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil11i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil11i_data,
		o => wire_nil11i_o,
		sel => wire_nil11i_sel
	  );
	wire_nil11l_data <= ( wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & wire_niO1l_o & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_nilOO_o & wire_niO1i_o & wire_niO1l_o);
	wire_nil11l_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil11l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil11l_data,
		o => wire_nil11l_o,
		sel => wire_nil11l_sel
	  );
	wire_nil11O_data <= ( wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & wire_niO1O_o & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_nilOO_o & wire_niO1i_o & wire_niO1l_o & wire_niO1O_o);
	wire_nil11O_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil11O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil11O_data,
		o => wire_nil11O_o,
		sel => wire_nil11O_sel
	  );
	wire_nil1ii_data <= ( wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & wire_niOii_o & niiilO & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_nilOO_o & wire_niO1i_o & wire_niO1l_o & wire_niO1O_o & wire_niO0i_o & wire_niO0l_o & wire_niO0O_o & wire_niOii_o);
	wire_nil1ii_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil1ii :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil1ii_data,
		o => wire_nil1ii_o,
		sel => wire_nil1ii_sel
	  );
	wire_nil1il_data <= ( wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & wire_niOil_o & niiiOi & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_nilOO_o & wire_niO1i_o & wire_niO1l_o & wire_niO1O_o & wire_niO0i_o & wire_niO0l_o & wire_niO0O_o & wire_niOii_o & wire_niOil_o);
	wire_nil1il_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil1il :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil1il_data,
		o => wire_nil1il_o,
		sel => wire_nil1il_sel
	  );
	wire_nil1iO_data <= ( wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & wire_niOiO_o & niiiOl & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_nilOO_o & wire_niO1i_o & wire_niO1l_o & wire_niO1O_o & wire_niO0i_o & wire_niO0l_o & wire_niO0O_o & wire_niOii_o & wire_niOil_o & wire_niOiO_o);
	wire_nil1iO_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil1iO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil1iO_data,
		o => wire_nil1iO_o,
		sel => wire_nil1iO_sel
	  );
	wire_nil1li_data <= ( wire_niOli_o & wire_niOli_o & wire_niOli_o & wire_niOli_o & wire_niOli_o & wire_niOli_o & wire_niOli_o & wire_niOli_o & wire_niOli_o & wire_niOli_o & wire_niOli_o & wire_niOli_o & niiiOO & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_nilOO_o & wire_niO1i_o & wire_niO1l_o & wire_niO1O_o & wire_niO0i_o & wire_niO0l_o & wire_niO0O_o & wire_niOii_o & wire_niOil_o & wire_niOiO_o & wire_niOli_o);
	wire_nil1li_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil1li :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil1li_data,
		o => wire_nil1li_o,
		sel => wire_nil1li_sel
	  );
	wire_nil1ll_data <= ( wire_niOll_o & wire_niOll_o & wire_niOll_o & wire_niOll_o & wire_niOll_o & wire_niOll_o & wire_niOll_o & wire_niOll_o & wire_niOll_o & wire_niOll_o & wire_niOll_o & wire_niOll_o & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_nilOO_o & wire_niO1i_o & wire_niO1l_o & wire_niO1O_o & wire_niO0i_o & wire_niO0l_o & wire_niO0O_o & wire_niOii_o & wire_niOil_o & wire_niOiO_o & wire_niOli_o & wire_niOll_o);
	wire_nil1ll_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil1ll :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil1ll_data,
		o => wire_nil1ll_o,
		sel => wire_nil1ll_sel
	  );
	wire_nil1lO_data <= ( wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & niil1i & nii0Oi & nii0Ol & nii0OO & niii1i & niii1l & niii1O & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & wire_nilii_o);
	wire_nil1lO_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil1lO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil1lO_data,
		o => wire_nil1lO_o,
		sel => wire_nil1lO_sel
	  );
	wire_nil1Oi_data <= ( wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & nii0Oi & nii0Ol & nii0OO & niii1i & niii1l & niii1O & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & wire_nilii_o & wire_nilil_o);
	wire_nil1Oi_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil1Oi :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil1Oi_data,
		o => wire_nil1Oi_o,
		sel => wire_nil1Oi_sel
	  );
	wire_nil1Ol_data <= ( wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & nii0Ol & nii0OO & niii1i & niii1l & niii1O & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & wire_nilii_o & wire_nilil_o & wire_niliO_o);
	wire_nil1Ol_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil1Ol :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil1Ol_data,
		o => wire_nil1Ol_o,
		sel => wire_nil1Ol_sel
	  );
	wire_nil1OO_data <= ( wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & nii0OO & niii1i & niii1l & niii1O & niii0O & niiiii & niiiil & niiiiO & niiili & niiill & niiilO & niiiOi & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o);
	wire_nil1OO_sel <= ( tx_boundary_sel(4 DOWNTO 0));
	nil1OO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nil1OO_data,
		o => wire_nil1OO_o,
		sel => wire_nil1OO_sel
	  );
	wire_nili0i_data <= ( wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & niil1i & nii0Oi & nii0Ol & nii0OO & niii1i & niii1l & niii1O & niii0i & niii0l & wire_nilii_o);
	wire_nili0i_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	nili0i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nili0i_data,
		o => wire_nili0i_o,
		sel => wire_nili0i_sel
	  );
	wire_nili0l_data <= ( wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & nii0Oi & nii0Ol & nii0OO & niii1i & niii1l & niii1O & niii0i & niii0l & wire_nilii_o & wire_nilil_o);
	wire_nili0l_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	nili0l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nili0l_data,
		o => wire_nili0l_o,
		sel => wire_nili0l_sel
	  );
	wire_nili0O_data <= ( wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & nii0Ol & nii0OO & niii1i & niii1l & niii1O & niii0i & niii0l & wire_nilii_o & wire_nilil_o & wire_niliO_o);
	wire_nili0O_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	nili0O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nili0O_data,
		o => wire_nili0O_o,
		sel => wire_nili0O_sel
	  );
	wire_nilii_data <= ( wire_niOlO_o & wire_nl01l_o & wire_nliii_o & wire_nlllO_o);
	wire_nilii_sel <= ( doublewidth & dwidth);
	nilii :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nilii_data,
		o => wire_nilii_o,
		sel => wire_nilii_sel
	  );
	wire_niliii_data <= ( wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & nii0OO & niii1i & niii1l & niii1O & niii0i & niii0l & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o);
	wire_niliii_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	niliii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niliii_data,
		o => wire_niliii_o,
		sel => wire_niliii_sel
	  );
	wire_niliil_data <= ( wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & niii1i & niii1l & niii1O & niii0i & niii0l & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o);
	wire_niliil_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	niliil :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niliil_data,
		o => wire_niliil_o,
		sel => wire_niliil_sel
	  );
	wire_niliiO_data <= ( wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & niii1l & niii1O & niii0i & niii0l & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o);
	wire_niliiO_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	niliiO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niliiO_data,
		o => wire_niliiO_o,
		sel => wire_niliiO_sel
	  );
	wire_nilil_data <= ( wire_niOOi_o & wire_nl01O_o & wire_nliil_o & wire_nllOi_o);
	wire_nilil_sel <= ( doublewidth & dwidth);
	nilil :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nilil_data,
		o => wire_nilil_o,
		sel => wire_nilil_sel
	  );
	wire_nilili_data <= ( wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & niii1O & niii0i & niii0l & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o);
	wire_nilili_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	nilili :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nilili_data,
		o => wire_nilili_o,
		sel => wire_nilili_sel
	  );
	wire_nilill_data <= ( wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & niii0i & niii0l & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o);
	wire_nilill_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	nilill :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nilill_data,
		o => wire_nilill_o,
		sel => wire_nilill_sel
	  );
	wire_nililO_data <= ( wire_nilOO_o & wire_nilOO_o & wire_nilOO_o & wire_nilOO_o & wire_nilOO_o & wire_nilOO_o & niii0l & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_nilOO_o);
	wire_nililO_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	nililO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nililO_data,
		o => wire_nililO_o,
		sel => wire_nililO_sel
	  );
	wire_niliO_data <= ( wire_niOOl_o & wire_nl00i_o & wire_nliiO_o & wire_nllOl_o);
	wire_niliO_sel <= ( doublewidth & dwidth);
	niliO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niliO_data,
		o => wire_niliO_o,
		sel => wire_niliO_sel
	  );
	wire_niliOi_data <= ( wire_niO1i_o & wire_niO1i_o & wire_niO1i_o & wire_niO1i_o & wire_niO1i_o & wire_niO1i_o & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o & wire_nilOO_o & wire_niO1i_o);
	wire_niliOi_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	niliOi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niliOi_data,
		o => wire_niliOi_o,
		sel => wire_niliOi_sel
	  );
	wire_nilli_data <= ( wire_niOOO_o & wire_nl00l_o & wire_nlili_o & wire_nllOO_o);
	wire_nilli_sel <= ( doublewidth & dwidth);
	nilli :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nilli_data,
		o => wire_nilli_o,
		sel => wire_nilli_sel
	  );
	wire_nilll_data <= ( wire_nl11i_o & wire_nl00O_o & wire_nlill_o & wire_nlO1i_o);
	wire_nilll_sel <= ( doublewidth & dwidth);
	nilll :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nilll_data,
		o => wire_nilll_o,
		sel => wire_nilll_sel
	  );
	wire_nillll_data <= ( wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & wire_nilii_o & niil1i & nii0Oi & nii0Ol & nii0OO & niii1i & niii1l & niii1O & wire_nilii_o);
	wire_nillll_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	nillll :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nillll_data,
		o => wire_nillll_o,
		sel => wire_nillll_sel
	  );
	wire_nilllO_data <= ( wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & wire_nilil_o & nii0Oi & nii0Ol & nii0OO & niii1i & niii1l & niii1O & wire_nilii_o & wire_nilil_o);
	wire_nilllO_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	nilllO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nilllO_data,
		o => wire_nilllO_o,
		sel => wire_nilllO_sel
	  );
	wire_nillO_data <= ( wire_nl11l_o & wire_nl0ii_o & wire_nlilO_o & wire_nlO1l_o);
	wire_nillO_sel <= ( doublewidth & dwidth);
	nillO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nillO_data,
		o => wire_nillO_o,
		sel => wire_nillO_sel
	  );
	wire_nillOi_data <= ( wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & wire_niliO_o & nii0Ol & nii0OO & niii1i & niii1l & niii1O & wire_nilii_o & wire_nilil_o & wire_niliO_o);
	wire_nillOi_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	nillOi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nillOi_data,
		o => wire_nillOi_o,
		sel => wire_nillOi_sel
	  );
	wire_nillOl_data <= ( wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & wire_nilli_o & nii0OO & niii1i & niii1l & niii1O & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o);
	wire_nillOl_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	nillOl :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nillOl_data,
		o => wire_nillOl_o,
		sel => wire_nillOl_sel
	  );
	wire_nillOO_data <= ( wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & wire_nilll_o & niii1i & niii1l & niii1O & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o);
	wire_nillOO_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	nillOO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nillOO_data,
		o => wire_nillOO_o,
		sel => wire_nillOO_sel
	  );
	wire_nilO1i_data <= ( wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & wire_nillO_o & niii1l & niii1O & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o);
	wire_nilO1i_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	nilO1i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nilO1i_data,
		o => wire_nilO1i_o,
		sel => wire_nilO1i_sel
	  );
	wire_nilO1l_data <= ( wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & wire_nilOi_o & niii1O & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o);
	wire_nilO1l_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	nilO1l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nilO1l_data,
		o => wire_nilO1l_o,
		sel => wire_nilO1l_sel
	  );
	wire_nilO1O_data <= ( wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilOl_o & wire_nilii_o & wire_nilil_o & wire_niliO_o & wire_nilli_o & wire_nilll_o & wire_nillO_o & wire_nilOi_o & wire_nilOl_o);
	wire_nilO1O_sel <= ( tx_boundary_sel(3 DOWNTO 0));
	nilO1O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nilO1O_data,
		o => wire_nilO1O_o,
		sel => wire_nilO1O_sel
	  );
	wire_nilOi_data <= ( wire_nl11O_o & wire_nl0il_o & wire_nliOi_o & wire_nlO1O_o);
	wire_nilOi_sel <= ( doublewidth & dwidth);
	nilOi :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nilOi_data,
		o => wire_nilOi_o,
		sel => wire_nilOi_sel
	  );
	wire_nilOl_data <= ( wire_nl10i_o & wire_nl0iO_o & wire_nliOl_o & wire_nlO0i_o);
	wire_nilOl_sel <= ( doublewidth & dwidth);
	nilOl :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nilOl_data,
		o => wire_nilOl_o,
		sel => wire_nilOl_sel
	  );
	wire_nilOO_data <= ( wire_nl10l_o & wire_nl0li_o & wire_nliOO_o & wire_nlO0l_o);
	wire_nilOO_sel <= ( doublewidth & dwidth);
	nilOO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nilOO_data,
		o => wire_nilOO_o,
		sel => wire_nilOO_sel
	  );
	wire_niO0i_data <= ( wire_nl1iO_o & wire_nl0Ol_o & wire_nll0i_o & wire_nll0i_o);
	wire_niO0i_sel <= ( doublewidth & dwidth);
	niO0i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niO0i_data,
		o => wire_niO0i_o,
		sel => wire_niO0i_sel
	  );
	wire_niO0l_data <= ( wire_nl1li_o & wire_nl0OO_o & wire_nll0l_o & wire_nll0l_o);
	wire_niO0l_sel <= ( doublewidth & dwidth);
	niO0l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niO0l_data,
		o => wire_niO0l_o,
		sel => wire_niO0l_sel
	  );
	wire_niO0O_data <= ( wire_nl1ll_o & wire_nli1i_o & wire_nll0O_o & wire_nll0O_o);
	wire_niO0O_sel <= ( doublewidth & dwidth);
	niO0O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niO0O_data,
		o => wire_niO0O_o,
		sel => wire_niO0O_sel
	  );
	wire_niO1i_data <= ( wire_nl10O_o & wire_nl0ll_o & wire_nll1i_o & wire_nlO0O_o);
	wire_niO1i_sel <= ( doublewidth & dwidth);
	niO1i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niO1i_data,
		o => wire_niO1i_o,
		sel => wire_niO1i_sel
	  );
	wire_niO1l_data <= ( wire_nl1ii_o & wire_nl0lO_o & wire_nll1l_o & wire_nll1l_o);
	wire_niO1l_sel <= ( doublewidth & dwidth);
	niO1l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niO1l_data,
		o => wire_niO1l_o,
		sel => wire_niO1l_sel
	  );
	wire_niO1O_data <= ( wire_nl1il_o & wire_nl0Oi_o & wire_nll1O_o & wire_nll1O_o);
	wire_niO1O_sel <= ( doublewidth & dwidth);
	niO1O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niO1O_data,
		o => wire_niO1O_o,
		sel => wire_niO1O_sel
	  );
	wire_niOii_data <= ( wire_nl1lO_o & wire_nli1l_o & wire_nllii_o & wire_nllii_o);
	wire_niOii_sel <= ( doublewidth & dwidth);
	niOii :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niOii_data,
		o => wire_niOii_o,
		sel => wire_niOii_sel
	  );
	wire_niOil_data <= ( wire_nl1Oi_o & wire_nli1O_o & wire_nllil_o & wire_nllil_o);
	wire_niOil_sel <= ( doublewidth & dwidth);
	niOil :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niOil_data,
		o => wire_niOil_o,
		sel => wire_niOil_sel
	  );
	wire_niOiO_data <= ( wire_nl1Ol_o & wire_nli0i_o & wire_nlliO_o & wire_nlliO_o);
	wire_niOiO_sel <= ( doublewidth & dwidth);
	niOiO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niOiO_data,
		o => wire_niOiO_o,
		sel => wire_niOiO_sel
	  );
	wire_niOli_data <= ( wire_nl1OO_o & wire_nli0l_o & wire_nllli_o & wire_nllli_o);
	wire_niOli_sel <= ( doublewidth & dwidth);
	niOli :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niOli_data,
		o => wire_niOli_o,
		sel => wire_niOli_sel
	  );
	wire_niOll_data <= ( wire_nl01i_o & wire_nli0O_o & wire_nllll_o & wire_nllll_o);
	wire_niOll_sel <= ( doublewidth & dwidth);
	niOll :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_niOll_data,
		o => wire_niOll_o,
		sel => wire_niOll_sel
	  );
	wire_niOlO_data <= ( wire_n1Oll_w_lg_o70w & wire_n010O_w_lg_o178w & wire_n1OlO_w_lg_o265w & wire_n1O1l_w_lg_o96w & wire_n1Oll_o & wire_n010O_o & wire_n1OlO_o & wire_n1O1l_o);
	wire_niOlO_sel <= ( n0lll & n0liO & n0lii);
	niOlO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niOlO_data,
		o => wire_niOlO_o,
		sel => wire_niOlO_sel
	  );
	wire_niOOi_data <= ( wire_n1Oli_w_lg_o81w & wire_n010l_w_lg_o188w & wire_n1OOi_w_lg_o256w & wire_n1O1O_w_lg_o108w & wire_n1Oli_o & wire_n010l_o & wire_n1OOi_o & wire_n1O1O_o);
	wire_niOOi_sel <= ( n0lll & n0liO & n0lii);
	niOOi :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niOOi_data,
		o => wire_niOOi_o,
		sel => wire_niOOi_sel
	  );
	wire_niOOl_data <= ( wire_n1OiO_w_lg_o94w & wire_n010i_w_lg_o200w & wire_n1OOl_w_lg_o247w & wire_n1O0i_w_lg_o122w & wire_n1OiO_o & wire_n010i_o & wire_n1OOl_o & wire_n1O0i_o);
	wire_niOOl_sel <= ( n0lll & n0liO & n0lii);
	niOOl :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niOOl_data,
		o => wire_niOOl_o,
		sel => wire_niOOl_sel
	  );
	wire_niOOO_data <= ( wire_n1Oil_w_lg_o106w & wire_n011O_w_lg_o211w & wire_n1OOO_w_lg_o238w & wire_n1O0l_w_lg_o133w & wire_n1Oil_o & wire_n011O_o & wire_n1OOO_o & wire_n1O0l_o);
	wire_niOOO_sel <= ( n0lll & n0liO & n0lii);
	niOOO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niOOO_data,
		o => wire_niOOO_o,
		sel => wire_niOOO_sel
	  );
	wire_nl00i_data <= ( wire_n1Oii_w_lg_o119w & wire_n011l_w_lg_o220w & wire_n1OOl_w_lg_o247w & wire_n1O0i_w_lg_o122w & wire_n1Oii_o & wire_n011l_o & wire_n1OOl_o & wire_n1O0i_o);
	wire_nl00i_sel <= ( n0lll & n0liO & n0lii);
	nl00i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl00i_data,
		o => wire_nl00i_o,
		sel => wire_nl00i_sel
	  );
	wire_nl00l_data <= ( wire_n1O0O_w_lg_o130w & wire_n011i_w_lg_o229w & wire_n1OOO_w_lg_o238w & wire_n1O0l_w_lg_o133w & wire_n1O0O_o & wire_n011i_o & wire_n1OOO_o & wire_n1O0l_o);
	wire_nl00l_sel <= ( n0lll & n0liO & n0lii);
	nl00l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl00l_data,
		o => wire_nl00l_o,
		sel => wire_nl00l_sel
	  );
	wire_nl00O_data <= ( wire_n1O0l_w_lg_o133w & wire_n1OOO_w_lg_o238w & wire_n011i_w_lg_o229w & wire_n1O0O_w_lg_o130w & wire_n1O0l_o & wire_n1OOO_o & wire_n011i_o & wire_n1O0O_o);
	wire_nl00O_sel <= ( n0lll & n0liO & n0lii);
	nl00O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl00O_data,
		o => wire_nl00O_o,
		sel => wire_nl00O_sel
	  );
	wire_nl01i_data <= ( wire_n1OlO_w_lg_o265w & wire_n1O1l_w_lg_o96w & wire_n1Oll_w_lg_o70w & wire_n010O_w_lg_o178w & wire_n1OlO_o & wire_n1O1l_o & wire_n1Oll_o & wire_n010O_o);
	wire_nl01i_sel <= ( n0lll & n0liO & n0lii);
	nl01i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl01i_data,
		o => wire_nl01i_o,
		sel => wire_nl01i_sel
	  );
	wire_nl01l_data <= ( wire_n1OiO_w_lg_o94w & wire_n010i_w_lg_o200w & wire_n1OlO_w_lg_o265w & wire_n1O1l_w_lg_o96w & wire_n1OiO_o & wire_n010i_o & wire_n1OlO_o & wire_n1O1l_o);
	wire_nl01l_sel <= ( n0lll & n0liO & n0lii);
	nl01l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl01l_data,
		o => wire_nl01l_o,
		sel => wire_nl01l_sel
	  );
	wire_nl01O_data <= ( wire_n1Oil_w_lg_o106w & wire_n011O_w_lg_o211w & wire_n1OOi_w_lg_o256w & wire_n1O1O_w_lg_o108w & wire_n1Oil_o & wire_n011O_o & wire_n1OOi_o & wire_n1O1O_o);
	wire_nl01O_sel <= ( n0lll & n0liO & n0lii);
	nl01O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl01O_data,
		o => wire_nl01O_o,
		sel => wire_nl01O_sel
	  );
	wire_nl0ii_data <= ( wire_n1O0i_w_lg_o122w & wire_n1OOl_w_lg_o247w & wire_n011l_w_lg_o220w & wire_n1Oii_w_lg_o119w & wire_n1O0i_o & wire_n1OOl_o & wire_n011l_o & wire_n1Oii_o);
	wire_nl0ii_sel <= ( n0lll & n0liO & n0lii);
	nl0ii :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0ii_data,
		o => wire_nl0ii_o,
		sel => wire_nl0ii_sel
	  );
	wire_nl0il_data <= ( wire_n1O1O_w_lg_o108w & wire_n1OOi_w_lg_o256w & wire_n011O_w_lg_o211w & wire_n1Oil_w_lg_o106w & wire_n1O1O_o & wire_n1OOi_o & wire_n011O_o & wire_n1Oil_o);
	wire_nl0il_sel <= ( n0lll & n0liO & n0lii);
	nl0il :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0il_data,
		o => wire_nl0il_o,
		sel => wire_nl0il_sel
	  );
	wire_nl0iO_data <= ( wire_n1O1l_w_lg_o96w & wire_n1OlO_w_lg_o265w & wire_n010i_w_lg_o200w & wire_n1OiO_w_lg_o94w & wire_n1O1l_o & wire_n1OlO_o & wire_n010i_o & wire_n1OiO_o);
	wire_nl0iO_sel <= ( n0lll & n0liO & n0lii);
	nl0iO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0iO_data,
		o => wire_nl0iO_o,
		sel => wire_nl0iO_sel
	  );
	wire_nl0li_data <= ( wire_n1Oli_w_lg_o81w & wire_n1Oli_w_lg_o81w & wire_n1Oli_w_lg_o81w & wire_n1Oli_w_lg_o81w & wire_n1Oli_o & wire_n1Oli_o & wire_n1Oli_o & wire_n1Oli_o);
	wire_nl0li_sel <= ( n0lll & n0liO & n0lii);
	nl0li :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0li_data,
		o => wire_nl0li_o,
		sel => wire_nl0li_sel
	  );
	wire_nl0ll_data <= ( wire_n1Oll_w_lg_o70w & wire_n1Oll_w_lg_o70w & wire_n1Oll_w_lg_o70w & wire_n1Oll_w_lg_o70w & wire_n1Oll_o & wire_n1Oll_o & wire_n1Oll_o & wire_n1Oll_o);
	wire_nl0ll_sel <= ( n0lll & n0liO & n0lii);
	nl0ll :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0ll_data,
		o => wire_nl0ll_o,
		sel => wire_nl0ll_sel
	  );
	wire_nl0lO_data <= ( wire_n010i_w_lg_o200w & wire_n1OiO_w_lg_o94w & wire_n1O1l_w_lg_o96w & wire_n1OlO_w_lg_o265w & wire_n010i_o & wire_n1OiO_o & wire_n1O1l_o & wire_n1OlO_o);
	wire_nl0lO_sel <= ( n0lll & n0liO & n0lii);
	nl0lO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0lO_data,
		o => wire_nl0lO_o,
		sel => wire_nl0lO_sel
	  );
	wire_nl0Oi_data <= ( wire_n011O_w_lg_o211w & wire_n1Oil_w_lg_o106w & wire_n1O1O_w_lg_o108w & wire_n1OOi_w_lg_o256w & wire_n011O_o & wire_n1Oil_o & wire_n1O1O_o & wire_n1OOi_o);
	wire_nl0Oi_sel <= ( n0lll & n0liO & n0lii);
	nl0Oi :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0Oi_data,
		o => wire_nl0Oi_o,
		sel => wire_nl0Oi_sel
	  );
	wire_nl0Ol_data <= ( wire_n011l_w_lg_o220w & wire_n1Oii_w_lg_o119w & wire_n1O0i_w_lg_o122w & wire_n1OOl_w_lg_o247w & wire_n011l_o & wire_n1Oii_o & wire_n1O0i_o & wire_n1OOl_o);
	wire_nl0Ol_sel <= ( n0lll & n0liO & n0lii);
	nl0Ol :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0Ol_data,
		o => wire_nl0Ol_o,
		sel => wire_nl0Ol_sel
	  );
	wire_nl0OO_data <= ( wire_n011i_w_lg_o229w & wire_n1O0O_w_lg_o130w & wire_n1O0l_w_lg_o133w & wire_n1OOO_w_lg_o238w & wire_n011i_o & wire_n1O0O_o & wire_n1O0l_o & wire_n1OOO_o);
	wire_nl0OO_sel <= ( n0lll & n0liO & n0lii);
	nl0OO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0OO_data,
		o => wire_nl0OO_o,
		sel => wire_nl0OO_sel
	  );
	wire_nl10i_data <= ( wire_n1O0i_w_lg_o122w & wire_n1OOl_w_lg_o247w & wire_n010i_w_lg_o200w & wire_n1OiO_w_lg_o94w & wire_n1O0i_o & wire_n1OOl_o & wire_n010i_o & wire_n1OiO_o);
	wire_nl10i_sel <= ( n0lll & n0liO & n0lii);
	nl10i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl10i_data,
		o => wire_nl10i_o,
		sel => wire_nl10i_sel
	  );
	wire_nl10l_data <= ( wire_n1O1O_w_lg_o108w & wire_n1OOi_w_lg_o256w & wire_n010l_w_lg_o188w & wire_n1Oli_w_lg_o81w & wire_n1O1O_o & wire_n1OOi_o & wire_n010l_o & wire_n1Oli_o);
	wire_nl10l_sel <= ( n0lll & n0liO & n0lii);
	nl10l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl10l_data,
		o => wire_nl10l_o,
		sel => wire_nl10l_sel
	  );
	wire_nl10O_data <= ( wire_n1O1l_w_lg_o96w & wire_n1OlO_w_lg_o265w & wire_n010O_w_lg_o178w & wire_n1Oll_w_lg_o70w & wire_n1O1l_o & wire_n1OlO_o & wire_n010O_o & wire_n1Oll_o);
	wire_nl10O_sel <= ( n0lll & n0liO & n0lii);
	nl10O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl10O_data,
		o => wire_nl10O_o,
		sel => wire_nl10O_sel
	  );
	wire_nl11i_data <= ( wire_n1Oii_w_lg_o119w & wire_n011l_w_lg_o220w & wire_n011i_w_lg_o229w & wire_n1O0O_w_lg_o130w & wire_n1Oii_o & wire_n011l_o & wire_n011i_o & wire_n1O0O_o);
	wire_nl11i_sel <= ( n0lll & n0liO & n0lii);
	nl11i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl11i_data,
		o => wire_nl11i_o,
		sel => wire_nl11i_sel
	  );
	wire_nl11l_data <= ( wire_n1O0O_w_lg_o130w & wire_n011i_w_lg_o229w & wire_n011l_w_lg_o220w & wire_n1Oii_w_lg_o119w & wire_n1O0O_o & wire_n011i_o & wire_n011l_o & wire_n1Oii_o);
	wire_nl11l_sel <= ( n0lll & n0liO & n0lii);
	nl11l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl11l_data,
		o => wire_nl11l_o,
		sel => wire_nl11l_sel
	  );
	wire_nl11O_data <= ( wire_n1O0l_w_lg_o133w & wire_n1OOO_w_lg_o238w & wire_n011O_w_lg_o211w & wire_n1Oil_w_lg_o106w & wire_n1O0l_o & wire_n1OOO_o & wire_n011O_o & wire_n1Oil_o);
	wire_nl11O_sel <= ( n0lll & n0liO & n0lii);
	nl11O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl11O_data,
		o => wire_nl11O_o,
		sel => wire_nl11O_sel
	  );
	wire_nl1ii_data <= ( wire_n010O_w_lg_o178w & wire_n1Oll_w_lg_o70w & wire_n1O1l_w_lg_o96w & wire_n1OlO_w_lg_o265w & wire_n010O_o & wire_n1Oll_o & wire_n1O1l_o & wire_n1OlO_o);
	wire_nl1ii_sel <= ( n0lll & n0liO & n0lii);
	nl1ii :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl1ii_data,
		o => wire_nl1ii_o,
		sel => wire_nl1ii_sel
	  );
	wire_nl1il_data <= ( wire_n010l_w_lg_o188w & wire_n1Oli_w_lg_o81w & wire_n1O1O_w_lg_o108w & wire_n1OOi_w_lg_o256w & wire_n010l_o & wire_n1Oli_o & wire_n1O1O_o & wire_n1OOi_o);
	wire_nl1il_sel <= ( n0lll & n0liO & n0lii);
	nl1il :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl1il_data,
		o => wire_nl1il_o,
		sel => wire_nl1il_sel
	  );
	wire_nl1iO_data <= ( wire_n010i_w_lg_o200w & wire_n1OiO_w_lg_o94w & wire_n1O0i_w_lg_o122w & wire_n1OOl_w_lg_o247w & wire_n010i_o & wire_n1OiO_o & wire_n1O0i_o & wire_n1OOl_o);
	wire_nl1iO_sel <= ( n0lll & n0liO & n0lii);
	nl1iO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl1iO_data,
		o => wire_nl1iO_o,
		sel => wire_nl1iO_sel
	  );
	wire_nl1li_data <= ( wire_n011O_w_lg_o211w & wire_n1Oil_w_lg_o106w & wire_n1O0l_w_lg_o133w & wire_n1OOO_w_lg_o238w & wire_n011O_o & wire_n1Oil_o & wire_n1O0l_o & wire_n1OOO_o);
	wire_nl1li_sel <= ( n0lll & n0liO & n0lii);
	nl1li :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl1li_data,
		o => wire_nl1li_o,
		sel => wire_nl1li_sel
	  );
	wire_nl1ll_data <= ( wire_n011l_w_lg_o220w & wire_n1Oii_w_lg_o119w & wire_n1O0O_w_lg_o130w & wire_n011i_w_lg_o229w & wire_n011l_o & wire_n1Oii_o & wire_n1O0O_o & wire_n011i_o);
	wire_nl1ll_sel <= ( n0lll & n0liO & n0lii);
	nl1ll :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl1ll_data,
		o => wire_nl1ll_o,
		sel => wire_nl1ll_sel
	  );
	wire_nl1lO_data <= ( wire_n011i_w_lg_o229w & wire_n1O0O_w_lg_o130w & wire_n1Oii_w_lg_o119w & wire_n011l_w_lg_o220w & wire_n011i_o & wire_n1O0O_o & wire_n1Oii_o & wire_n011l_o);
	wire_nl1lO_sel <= ( n0lll & n0liO & n0lii);
	nl1lO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl1lO_data,
		o => wire_nl1lO_o,
		sel => wire_nl1lO_sel
	  );
	wire_nl1Oi_data <= ( wire_n1OOO_w_lg_o238w & wire_n1O0l_w_lg_o133w & wire_n1Oil_w_lg_o106w & wire_n011O_w_lg_o211w & wire_n1OOO_o & wire_n1O0l_o & wire_n1Oil_o & wire_n011O_o);
	wire_nl1Oi_sel <= ( n0lll & n0liO & n0lii);
	nl1Oi :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl1Oi_data,
		o => wire_nl1Oi_o,
		sel => wire_nl1Oi_sel
	  );
	wire_nl1Ol_data <= ( wire_n1OOl_w_lg_o247w & wire_n1O0i_w_lg_o122w & wire_n1OiO_w_lg_o94w & wire_n010i_w_lg_o200w & wire_n1OOl_o & wire_n1O0i_o & wire_n1OiO_o & wire_n010i_o);
	wire_nl1Ol_sel <= ( n0lll & n0liO & n0lii);
	nl1Ol :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl1Ol_data,
		o => wire_nl1Ol_o,
		sel => wire_nl1Ol_sel
	  );
	wire_nl1OO_data <= ( wire_n1OOi_w_lg_o256w & wire_n1O1O_w_lg_o108w & wire_n1Oli_w_lg_o81w & wire_n010l_w_lg_o188w & wire_n1OOi_o & wire_n1O1O_o & wire_n1Oli_o & wire_n010l_o);
	wire_nl1OO_sel <= ( n0lll & n0liO & n0lii);
	nl1OO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl1OO_data,
		o => wire_nl1OO_o,
		sel => wire_nl1OO_sel
	  );
	wire_nli0i_data <= ( wire_n1OlO_w_lg_o265w & wire_n1O1l_w_lg_o96w & wire_n1OiO_w_lg_o94w & wire_n010i_w_lg_o200w & wire_n1OlO_o & wire_n1O1l_o & wire_n1OiO_o & wire_n010i_o);
	wire_nli0i_sel <= ( n0lll & n0liO & n0lii);
	nli0i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nli0i_data,
		o => wire_nli0i_o,
		sel => wire_nli0i_sel
	  );
	wire_nli0l_data <= ( wire_n010l_w_lg_o188w & wire_n010l_w_lg_o188w & wire_n010l_w_lg_o188w & wire_n010l_w_lg_o188w & wire_n010l_o & wire_n010l_o & wire_n010l_o & wire_n010l_o);
	wire_nli0l_sel <= ( n0lll & n0liO & n0lii);
	nli0l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nli0l_data,
		o => wire_nli0l_o,
		sel => wire_nli0l_sel
	  );
	wire_nli0O_data <= ( wire_n010O_w_lg_o178w & wire_n010O_w_lg_o178w & wire_n010O_w_lg_o178w & wire_n010O_w_lg_o178w & wire_n010O_o & wire_n010O_o & wire_n010O_o & wire_n010O_o);
	wire_nli0O_sel <= ( n0lll & n0liO & n0lii);
	nli0O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nli0O_data,
		o => wire_nli0O_o,
		sel => wire_nli0O_sel
	  );
	wire_nli1i_data <= ( wire_n1OOO_w_lg_o238w & wire_n1O0l_w_lg_o133w & wire_n1O0O_w_lg_o130w & wire_n011i_w_lg_o229w & wire_n1OOO_o & wire_n1O0l_o & wire_n1O0O_o & wire_n011i_o);
	wire_nli1i_sel <= ( n0lll & n0liO & n0lii);
	nli1i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nli1i_data,
		o => wire_nli1i_o,
		sel => wire_nli1i_sel
	  );
	wire_nli1l_data <= ( wire_n1OOl_w_lg_o247w & wire_n1O0i_w_lg_o122w & wire_n1Oii_w_lg_o119w & wire_n011l_w_lg_o220w & wire_n1OOl_o & wire_n1O0i_o & wire_n1Oii_o & wire_n011l_o);
	wire_nli1l_sel <= ( n0lll & n0liO & n0lii);
	nli1l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nli1l_data,
		o => wire_nli1l_o,
		sel => wire_nli1l_sel
	  );
	wire_nli1O_data <= ( wire_n1OOi_w_lg_o256w & wire_n1O1O_w_lg_o108w & wire_n1Oil_w_lg_o106w & wire_n011O_w_lg_o211w & wire_n1OOi_o & wire_n1O1O_o & wire_n1Oil_o & wire_n011O_o);
	wire_nli1O_sel <= ( n0lll & n0liO & n0lii);
	nli1O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nli1O_data,
		o => wire_nli1O_o,
		sel => wire_nli1O_sel
	  );
	wire_nliii_data <= ( wire_n1Oll_w_lg_o70w & wire_n1O1l_w_lg_o96w & wire_n1Oll_o & wire_n1O1l_o);
	wire_nliii_sel <= ( n0lll & n0liO);
	nliii :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nliii_data,
		o => wire_nliii_o,
		sel => wire_nliii_sel
	  );
	wire_nliil_data <= ( wire_n1Oli_w_lg_o81w & wire_n1O1O_w_lg_o108w & wire_n1Oli_o & wire_n1O1O_o);
	wire_nliil_sel <= ( n0lll & n0liO);
	nliil :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nliil_data,
		o => wire_nliil_o,
		sel => wire_nliil_sel
	  );
	wire_nliiO_data <= ( wire_n1OiO_w_lg_o94w & wire_n1O0i_w_lg_o122w & wire_n1OiO_o & wire_n1O0i_o);
	wire_nliiO_sel <= ( n0lll & n0liO);
	nliiO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nliiO_data,
		o => wire_nliiO_o,
		sel => wire_nliiO_sel
	  );
	wire_nlili_data <= ( wire_n1Oil_w_lg_o106w & wire_n1O0l_w_lg_o133w & wire_n1Oil_o & wire_n1O0l_o);
	wire_nlili_sel <= ( n0lll & n0liO);
	nlili :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlili_data,
		o => wire_nlili_o,
		sel => wire_nlili_sel
	  );
	wire_nlill_data <= ( wire_n1Oii_w_lg_o119w & wire_n1O0O_w_lg_o130w & wire_n1Oii_o & wire_n1O0O_o);
	wire_nlill_sel <= ( n0lll & n0liO);
	nlill :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlill_data,
		o => wire_nlill_o,
		sel => wire_nlill_sel
	  );
	wire_nlilO_data <= ( wire_n1O0O_w_lg_o130w & wire_n1Oii_w_lg_o119w & wire_n1O0O_o & wire_n1Oii_o);
	wire_nlilO_sel <= ( n0lll & n0liO);
	nlilO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlilO_data,
		o => wire_nlilO_o,
		sel => wire_nlilO_sel
	  );
	wire_nliOi_data <= ( wire_n1O0l_w_lg_o133w & wire_n1Oil_w_lg_o106w & wire_n1O0l_o & wire_n1Oil_o);
	wire_nliOi_sel <= ( n0lll & n0liO);
	nliOi :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nliOi_data,
		o => wire_nliOi_o,
		sel => wire_nliOi_sel
	  );
	wire_nliOl_data <= ( wire_n1O0i_w_lg_o122w & wire_n1OiO_w_lg_o94w & wire_n1O0i_o & wire_n1OiO_o);
	wire_nliOl_sel <= ( n0lll & n0liO);
	nliOl :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nliOl_data,
		o => wire_nliOl_o,
		sel => wire_nliOl_sel
	  );
	wire_nliOO_data <= ( wire_n1O1O_w_lg_o108w & wire_n1Oli_w_lg_o81w & wire_n1O1O_o & wire_n1Oli_o);
	wire_nliOO_sel <= ( n0lll & n0liO);
	nliOO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nliOO_data,
		o => wire_nliOO_o,
		sel => wire_nliOO_sel
	  );
	wire_nll0i_data <= ( wire_n1OOl_w_lg_o247w & wire_n1OOl_w_lg_o247w & wire_n1OOl_o & wire_n1OOl_o);
	wire_nll0i_sel <= ( n0lll & n0liO);
	nll0i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nll0i_data,
		o => wire_nll0i_o,
		sel => wire_nll0i_sel
	  );
	wire_nll0l_data <= ( wire_n1OOO_w_lg_o238w & wire_n1OOO_w_lg_o238w & wire_n1OOO_o & wire_n1OOO_o);
	wire_nll0l_sel <= ( n0lll & n0liO);
	nll0l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nll0l_data,
		o => wire_nll0l_o,
		sel => wire_nll0l_sel
	  );
	wire_nll0O_data <= ( wire_n011i_w_lg_o229w & wire_n011i_w_lg_o229w & wire_n011i_o & wire_n011i_o);
	wire_nll0O_sel <= ( n0lll & n0liO);
	nll0O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nll0O_data,
		o => wire_nll0O_o,
		sel => wire_nll0O_sel
	  );
	wire_nll1i_data <= ( wire_n1O1l_w_lg_o96w & wire_n1Oll_w_lg_o70w & wire_n1O1l_o & wire_n1Oll_o);
	wire_nll1i_sel <= ( n0lll & n0liO);
	nll1i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nll1i_data,
		o => wire_nll1i_o,
		sel => wire_nll1i_sel
	  );
	wire_nll1l_data <= ( wire_n1OlO_w_lg_o265w & wire_n1OlO_w_lg_o265w & wire_n1OlO_o & wire_n1OlO_o);
	wire_nll1l_sel <= ( n0lll & n0liO);
	nll1l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nll1l_data,
		o => wire_nll1l_o,
		sel => wire_nll1l_sel
	  );
	wire_nll1O_data <= ( wire_n1OOi_w_lg_o256w & wire_n1OOi_w_lg_o256w & wire_n1OOi_o & wire_n1OOi_o);
	wire_nll1O_sel <= ( n0lll & n0liO);
	nll1O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nll1O_data,
		o => wire_nll1O_o,
		sel => wire_nll1O_sel
	  );
	wire_nllii_data <= ( wire_n011l_w_lg_o220w & wire_n011l_w_lg_o220w & wire_n011l_o & wire_n011l_o);
	wire_nllii_sel <= ( n0lll & n0liO);
	nllii :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nllii_data,
		o => wire_nllii_o,
		sel => wire_nllii_sel
	  );
	wire_nllil_data <= ( wire_n011O_w_lg_o211w & wire_n011O_w_lg_o211w & wire_n011O_o & wire_n011O_o);
	wire_nllil_sel <= ( n0lll & n0liO);
	nllil :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nllil_data,
		o => wire_nllil_o,
		sel => wire_nllil_sel
	  );
	wire_nlliO_data <= ( wire_ni0Oll40_w_lg_w_lg_q202w203w & wire_n010i_w_lg_o200w & wire_n010i_o & wire_ni0OlO38_w_lg_w_lg_q195w196w);
	wire_nlliO_sel <= ( n0lll & n0liO);
	nlliO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlliO_data,
		o => wire_nlliO_o,
		sel => wire_nlliO_sel
	  );
	wire_nllli_data <= ( wire_n010l_w_lg_o188w & wire_ni0OOi36_w_lg_w_lg_q187w189w & wire_n010l_o & wire_n010l_o);
	wire_nllli_sel <= ( n0lll & n0liO);
	nllli :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nllli_data,
		o => wire_nllli_o,
		sel => wire_nllli_sel
	  );
	wire_nllll_data <= ( wire_n010O_w_lg_o178w & wire_n010O_w_lg_o178w & wire_n010O_o & wire_n010O_o);
	wire_nllll_sel <= ( n0lll & n0liO);
	nllll :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nllll_data,
		o => wire_nllll_o,
		sel => wire_nllll_sel
	  );
	wire_nlllO_data <= ( wire_n1OiO_w_lg_o94w & wire_n1O1l_w_lg_o96w & wire_n1OiO_o & wire_n1O1l_o);
	wire_nlllO_sel <= ( n0lll & n0liO);
	nlllO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlllO_data,
		o => wire_nlllO_o,
		sel => wire_nlllO_sel
	  );
	wire_nllOi_data <= ( wire_n1Oil_w_lg_o106w & wire_ni0OOl34_w_lg_w_lg_q160w161w & wire_n1Oil_o & wire_n1O1O_o);
	wire_nllOi_sel <= ( n0lll & n0liO);
	nllOi :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nllOi_data,
		o => wire_nllOi_o,
		sel => wire_nllOi_sel
	  );
	wire_nllOl_data <= ( wire_n1Oii_w_lg_o119w & wire_n1O0i_w_lg_o122w & wire_n1Oii_o & wire_n1O0i_o);
	wire_nllOl_sel <= ( n0lll & n0liO);
	nllOl :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nllOl_data,
		o => wire_nllOl_o,
		sel => wire_nllOl_sel
	  );
	wire_nllOO_data <= ( wire_n1O0O_w_lg_o130w & wire_n1O0l_w_lg_o133w & wire_n1O0O_o & wire_ni0OOO32_w_lg_w_lg_q139w140w);
	wire_nllOO_sel <= ( n0lll & n0liO);
	nllOO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nllOO_data,
		o => wire_nllOO_o,
		sel => wire_nllOO_sel
	  );
	wire_nlO0i_data <= ( wire_n1O1l_w_lg_o96w & wire_n1OiO_w_lg_o94w & wire_n1O1l_o & wire_n1OiO_o);
	wire_nlO0i_sel <= ( n0lll & wire_nii10l22_w_lg_w_lg_q86w87w);
	nlO0i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlO0i_data,
		o => wire_nlO0i_o,
		sel => wire_nlO0i_sel
	  );
	wire_nlO0l_data <= ( wire_nii10O20_w_lg_w_lg_q83w84w & wire_n1Oli_w_lg_o81w & wire_n1Oli_o & wire_n1Oli_o);
	wire_nlO0l_sel <= ( wire_nii1ii18_w_lg_w_lg_q75w76w & n0liO);
	nlO0l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlO0l_data,
		o => wire_nlO0l_o,
		sel => wire_nlO0l_sel
	  );
	wire_nlO0O_data <= ( wire_n1Oll_w_lg_o70w & wire_n1Oll_w_lg_o70w & wire_nii1il16_w_lg_w_lg_q67w68w & wire_n1Oll_o);
	wire_nlO0O_sel <= ( n0lll & n0liO);
	nlO0O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlO0O_data,
		o => wire_nlO0O_o,
		sel => wire_nlO0O_sel
	  );
	wire_nlO1i_data <= ( wire_nii11i30_w_lg_w_lg_q132w134w & wire_n1O0O_w_lg_o130w & wire_n1O0l_o & wire_n1O0O_o);
	wire_nlO1i_sel <= ( n0lll & n0liO);
	nlO1i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlO1i_data,
		o => wire_nlO1i_o,
		sel => wire_nlO1i_sel
	  );
	wire_nlO1l_data <= ( wire_n1O0i_w_lg_o122w & wire_nii11l28_w_lg_w_lg_q118w120w & wire_nii11O26_w_lg_w_lg_q115w116w & wire_n1Oii_o);
	wire_nlO1l_sel <= ( n0lll & n0liO);
	nlO1l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlO1l_data,
		o => wire_nlO1l_o,
		sel => wire_nlO1l_sel
	  );
	wire_nlO1O_data <= ( wire_n1O1O_w_lg_o108w & wire_n1Oil_w_lg_o106w & wire_n1O1O_o & wire_n1Oil_o);
	wire_nlO1O_sel <= ( wire_nii10i24_w_lg_w_lg_q100w101w & n0liO);
	nlO1O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlO1O_data,
		o => wire_nlO1O_o,
		sel => wire_nlO1O_sel
	  );

 END RTL; --stratixiv_hssi_tx_digi_enc_chnl_top
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

--synthesis_resources = lut 12 mux21 13 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_tx_digi_iq_pipe_tx IS 
	 PORT 
	 ( 
		 fifo_rd_clk_raw	:	IN  STD_LOGIC;
		 fifo_select_in_centrl	:	IN  STD_LOGIC;
		 fifo_select_in_pipe_quad_down	:	IN  STD_LOGIC;
		 fifo_select_in_pipe_quad_up	:	IN  STD_LOGIC;
		 fifo_select_out_pipe	:	OUT  STD_LOGIC;
		 rd_enable_in_centrl	:	IN  STD_LOGIC;
		 rd_enable_in_pipe_quad_down	:	IN  STD_LOGIC;
		 rd_enable_in_pipe_quad_up	:	IN  STD_LOGIC;
		 rd_enable_out_pipe	:	OUT  STD_LOGIC;
		 refclk_b_raw	:	IN  STD_LOGIC;
		 rfreerun_tx	:	IN  STD_LOGIC;
		 rmaster_tx	:	IN  STD_LOGIC;
		 rmaster_up_tx	:	IN  STD_LOGIC;
		 rpipeline_bypass_tx	:	IN  STD_LOGIC;
		 soft_reset_rclk1	:	IN  STD_LOGIC;
		 soft_reset_wclk1	:	IN  STD_LOGIC;
		 tx_div2_sync_in_centrl	:	IN  STD_LOGIC;
		 tx_div2_sync_in_pipe_quad_down	:	IN  STD_LOGIC;
		 tx_div2_sync_in_pipe_quad_up	:	IN  STD_LOGIC;
		 tx_div2_sync_out_pipe	:	OUT  STD_LOGIC;
		 txrst	:	IN  STD_LOGIC;
		 wr_clk_pos_raw	:	IN  STD_LOGIC;
		 wr_enable_in_centrl	:	IN  STD_LOGIC;
		 wr_enable_in_pipe_quad_down	:	IN  STD_LOGIC;
		 wr_enable_in_pipe_quad_up	:	IN  STD_LOGIC;
		 wr_enable_out_pipe	:	OUT  STD_LOGIC
	 ); 
 END stratixiv_hssi_tx_digi_iq_pipe_tx;

 ARCHITECTURE RTL OF stratixiv_hssi_tx_digi_iq_pipe_tx IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 n0ii7	:	STD_LOGIC := '0';
	 SIGNAL	 n0ii8	:	STD_LOGIC := '0';
	 SIGNAL	 n0il5	:	STD_LOGIC := '0';
	 SIGNAL	 n0il6	:	STD_LOGIC := '0';
	 SIGNAL	 n0li3	:	STD_LOGIC := '0';
	 SIGNAL	 n0li4	:	STD_LOGIC := '0';
	 SIGNAL	 n0Oi1	:	STD_LOGIC := '0';
	 SIGNAL	 n0Oi2	:	STD_LOGIC := '0';
	 SIGNAL	n1l	:	STD_LOGIC := '0';
	 SIGNAL	wire_n1i_CLRN	:	STD_LOGIC;
	 SIGNAL	nO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl_CLRN	:	STD_LOGIC;
	 SIGNAL	ni	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlO_CLRN	:	STD_LOGIC;
	 SIGNAL	nlOO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlOl_PRN	:	STD_LOGIC;
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1O_w_lg_dataout8w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_rmaster_tx6w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_soft_reset_rclk12w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_soft_reset_wclk19w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_txrst5w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  n0ll :	STD_LOGIC;
 BEGIN

	wire_w_lg_rmaster_tx6w(0) <= NOT rmaster_tx;
	wire_w_lg_soft_reset_rclk12w(0) <= NOT soft_reset_rclk1;
	wire_w_lg_soft_reset_wclk19w(0) <= NOT soft_reset_wclk1;
	wire_w_lg_txrst5w(0) <= NOT txrst;
	fifo_select_out_pipe <= wire_nllO_dataout;
	n0ll <= '1';
	rd_enable_out_pipe <= wire_nlli_dataout;
	tx_div2_sync_out_pipe <= wire_nlOi_dataout;
	wr_enable_out_pipe <= wire_nlll_dataout;
	PROCESS (refclk_b_raw)
	BEGIN
		IF (refclk_b_raw = '1' AND refclk_b_raw'event) THEN n0ii7 <= n0ii8;
		END IF;
		if (now = 0 ns) then
			n0ii7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b_raw)
	BEGIN
		IF (refclk_b_raw = '1' AND refclk_b_raw'event) THEN n0ii8 <= n0ii7;
		END IF;
	END PROCESS;
	PROCESS (refclk_b_raw)
	BEGIN
		IF (refclk_b_raw = '1' AND refclk_b_raw'event) THEN n0il5 <= n0il6;
		END IF;
		if (now = 0 ns) then
			n0il5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b_raw)
	BEGIN
		IF (refclk_b_raw = '1' AND refclk_b_raw'event) THEN n0il6 <= n0il5;
		END IF;
	END PROCESS;
	PROCESS (refclk_b_raw)
	BEGIN
		IF (refclk_b_raw = '1' AND refclk_b_raw'event) THEN n0li3 <= n0li4;
		END IF;
		if (now = 0 ns) then
			n0li3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b_raw)
	BEGIN
		IF (refclk_b_raw = '1' AND refclk_b_raw'event) THEN n0li4 <= n0li3;
		END IF;
	END PROCESS;
	PROCESS (refclk_b_raw)
	BEGIN
		IF (refclk_b_raw = '1' AND refclk_b_raw'event) THEN n0Oi1 <= n0Oi2;
		END IF;
		if (now = 0 ns) then
			n0Oi1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk_b_raw)
	BEGIN
		IF (refclk_b_raw = '1' AND refclk_b_raw'event) THEN n0Oi2 <= n0Oi1;
		END IF;
	END PROCESS;
	PROCESS (refclk_b_raw, wire_n1O_dataout, wire_n1i_CLRN)
	BEGIN
		IF (wire_n1O_dataout = '1') THEN
				n1l <= '1';
		ELSIF (wire_n1i_CLRN = '0') THEN
				n1l <= '0';
		ELSIF (refclk_b_raw = '1' AND refclk_b_raw'event) THEN
				n1l <= wire_nli_dataout;
		END IF;
		if (now = 0 ns) then
			n1l <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_n1i_CLRN <= (n0il6 XOR n0il5);
	PROCESS (fifo_rd_clk_raw, wire_nl_CLRN)
	BEGIN
		IF (wire_nl_CLRN = '0') THEN
				nO <= '0';
		ELSIF (fifo_rd_clk_raw = '1' AND fifo_rd_clk_raw'event) THEN
				nO <= wire_n0i_dataout;
		END IF;
	END PROCESS;
	wire_nl_CLRN <= ((n0Oi2 XOR n0Oi1) AND wire_w_lg_soft_reset_rclk12w(0));
	PROCESS (refclk_b_raw, txrst, wire_nlO_CLRN)
	BEGIN
		IF (txrst = '1') THEN
				ni <= '1';
		ELSIF (wire_nlO_CLRN = '0') THEN
				ni <= '0';
		ELSIF (refclk_b_raw = '1' AND refclk_b_raw'event) THEN
				ni <= wire_nil_dataout;
		END IF;
		if (now = 0 ns) then
			ni <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nlO_CLRN <= (n0li4 XOR n0li3);
	PROCESS (wr_clk_pos_raw, wire_nlOl_PRN, soft_reset_wclk1)
	BEGIN
		IF (wire_nlOl_PRN = '0') THEN
				nlOO <= '1';
		ELSIF (soft_reset_wclk1 = '1') THEN
				nlOO <= '0';
		ELSIF (wr_clk_pos_raw = '1' AND wr_clk_pos_raw'event) THEN
				nlOO <= wire_n0O_dataout;
		END IF;
	END PROCESS;
	wire_nlOl_PRN <= (n0ii8 XOR n0ii7);
	wire_n0i_dataout <= wire_n0l_dataout WHEN wire_w_lg_rmaster_tx6w(0) = '1'  ELSE rd_enable_in_centrl;
	wire_n0l_dataout <= rd_enable_in_pipe_quad_up WHEN rmaster_up_tx = '1'  ELSE rd_enable_in_pipe_quad_down;
	wire_n0O_dataout <= wire_nii_dataout WHEN wire_w_lg_rmaster_tx6w(0) = '1'  ELSE wr_enable_in_centrl;
	wire_n1O_dataout <= txrst AND NOT(rfreerun_tx);
	wire_n1O_w_lg_dataout8w(0) <= NOT wire_n1O_dataout;
	wire_nii_dataout <= wr_enable_in_pipe_quad_up WHEN rmaster_up_tx = '1'  ELSE wr_enable_in_pipe_quad_down;
	wire_nil_dataout <= wire_niO_dataout WHEN wire_w_lg_rmaster_tx6w(0) = '1'  ELSE fifo_select_in_centrl;
	wire_niO_dataout <= fifo_select_in_pipe_quad_up WHEN rmaster_up_tx = '1'  ELSE fifo_select_in_pipe_quad_down;
	wire_nli_dataout <= wire_nll_dataout WHEN wire_w_lg_rmaster_tx6w(0) = '1'  ELSE tx_div2_sync_in_centrl;
	wire_nll_dataout <= tx_div2_sync_in_pipe_quad_up WHEN rmaster_up_tx = '1'  ELSE tx_div2_sync_in_pipe_quad_down;
	wire_nlli_dataout <= wire_n0i_dataout WHEN rpipeline_bypass_tx = '1'  ELSE nO;
	wire_nlll_dataout <= wire_n0O_dataout WHEN rpipeline_bypass_tx = '1'  ELSE nlOO;
	wire_nllO_dataout <= wire_nil_dataout WHEN rpipeline_bypass_tx = '1'  ELSE ni;
	wire_nlOi_dataout <= wire_nli_dataout WHEN rpipeline_bypass_tx = '1'  ELSE n1l;

 END RTL; --stratixiv_hssi_tx_digi_iq_pipe_tx
--synopsys translate_on
--VALID FILE


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_tx_digi IS
   PORT (
      
      -- Reset inputs
      txpcs_rst                       : IN STD_LOGIC;		-- TX PCS resets
      
      -- Scan inputs
      scan_mode                       : IN STD_LOGIC;		-- 1'b1 = scan mode active; 
      -- 1'b0 = normal mode
      -- TX PCS channel inputs/outputs
      txd                             : IN STD_LOGIC_VECTOR(43 DOWNTO 0);		-- TXD data bus from PLD
      pld_tx_clk                      : IN STD_LOGIC;		-- XGMII tx clock for this lane from PLD
      polinv_tx                       : IN STD_LOGIC;		-- TX polarity inversion dynamic control signal
      -- 8-bit tx data from 10G ethernet 
      -- tx state machine (tx_sm)
      -- 1-bit tx control from 10G ethernet tx state machine (tx_sm)
      -- Global parallel clock from TX PLL
      -- Individual TX PMA clock from TX PMA Extension
      -- Dynamic signal causes reverse loopback
      rev_loop_data                   : IN STD_LOGIC_VECTOR(19 DOWNTO 0);		-- 10 bit data from RX rate matching FIFO, reverse loopback
      wrenable_tx                     : IN STD_LOGIC;		-- TX phase comp. FIFO write enable control signal
      rddisable_tx                    : IN STD_LOGIC;		-- TX phase comp. FIFO read disable control signal
      phfifourst_tx                   : IN STD_LOGIC;		-- TX phase comp. FIFO user reset
      
      -- TX PIPE interface signals
      txdetectrxloopback              : IN STD_LOGIC;
      --input			txelecidle; 	txd[9]
      --input			txcompliance;	txd[10] and txd[32]
      powerdown                       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      
      revloopback                     : IN STD_LOGIC;
      
      -- push through TX Phase Comp FIFO
      txswing                         : IN STD_LOGIC;
      pcs_txdeemph                    : IN STD_LOGIC;
      pcs_txmargin                    : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      -- RX PIPE interface signals
      rxpolarity                      : IN STD_LOGIC;
      polinv_rx                       : IN STD_LOGIC;
      
      --PRBS-CID dynamic signal
      
      full_tx                         : OUT STD_LOGIC;		-- TX Phase comp. FIFO full flag
      empty_tx                        : OUT STD_LOGIC;		-- TX Phase comp. FIFO empty flag
      tx_data_ts                      : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
      tx_ctl_ts                       : IN STD_LOGIC;
      refclk_pma                      : IN STD_LOGIC;
      txpma_local_clk                 : IN STD_LOGIC;
      tx_clk_out                      : OUT STD_LOGIC;
      tx_data_tc                      : OUT STD_LOGIC_VECTOR(7 DOWNTO 0);		-- 8-bit tx data from tx_ctrl to XAUI TX SM
      tx_ctl_tc                       : OUT STD_LOGIC;		-- TX control/TX data bit 8 from tx_ctrl to XAUI TX SM
      pudr                            : OUT STD_LOGIC_VECTOR(19 DOWNTO 0);		-- TX PCS 20-bit code group bus to TX PMA
      rd_enable_sync                  : OUT STD_LOGIC;
      refclk_b                        : OUT STD_LOGIC;
      txlp20b                         : OUT STD_LOGIC_VECTOR(19 DOWNTO 0);		-- tx 20-bit code group bus to RX PCS for loopback
      tx_pipe_clk                     : OUT STD_LOGIC;		-- TX PIPE interface clock
      encoder_testbus                 : OUT STD_LOGIC_VECTOR(9 DOWNTO 0);		-- Test bus from 8B10B encoder
      tx_ctrl_testbus                 : OUT STD_LOGIC_VECTOR(9 DOWNTO 0);		-- Test bus from TX FIFO
      tx_pipe_soft_reset              : OUT STD_LOGIC;		-- TX PIPE soft reset from TX FIFO
      tx_pipe_electidle               : OUT STD_LOGIC;		-- TxElecIdle output from TX FIFO
      
      -- TX PIPE interface signals
      txdetectrxloopback_int          : OUT STD_LOGIC;
      --output			txelecidle; 	txd[9]
      --output			txcompliance;	txd[10] and txd[32]
      powerdown_int                   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      
      revloopback_int                 : OUT STD_LOGIC;
      
      -- push through TX Phase Comp FIFO
      phfifo_txswing                  : OUT STD_LOGIC;
      phfifo_txdeemph                 : OUT STD_LOGIC;
      phfifo_txmargin                 : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      -- RX PIPE interface signals
      rxpolarity_int                  : OUT STD_LOGIC;
      polinv_rx_int                   : OUT STD_LOGIC;
      
      -- TX PCS CRAMs
      rrev_loopbk                     : IN STD_LOGIC;		-- CRAM - Enable dynamic Reverse, PIPE mode
      rev_loopbk                      : IN STD_LOGIC;
      eidleinfersel                   : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      gray_eidleinfersel              : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      rbisten_tx                      : IN STD_LOGIC;		-- ENBIST CRAM
      rforce_disp                     : IN STD_LOGIC;		-- Acting with TXD[9, 19] forces current disparity to 1 or 0
      rib_force_disp                  : IN STD_LOGIC;		-- Disparity force CRAM in IB mode
      rforce_echar                    : IN STD_LOGIC;		-- Force /E/ char CRAM
      rforce_kchar                    : IN STD_LOGIC;		-- Force /K/ char CRAM
      rendec_tx                       : IN STD_LOGIC;		-- Enable 8B/10B encoder CRAM
      rge_xaui_tx                     : IN STD_LOGIC;		-- GIGE Idle test enable CRAM
      rdwidth_tx                      : IN STD_LOGIC;		-- TX parallel interface data width CRAM
      rtxfifo_dis                     : IN STD_LOGIC;		-- TX FIFO disable CRAM
      rcascaded_8b10b_en_tx           : IN STD_LOGIC;		-- Caascaded 8b/10b encoder enable CRAM
      rprbsen_tx                      : IN STD_LOGIC;		-- PRBS generator enable CRAM
      rprbs_sel                       : IN STD_LOGIC_VECTOR(2 DOWNTO 0);		-- PRBS selection CRAM
      rbist_sel                       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- BIST selection CRAM
      rcxpat_chnl_en                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- CRPAT or CJPAT selection CRAM
      renpolinv_tx                    : IN STD_LOGIC;		-- TX Polarity inversion enable CRAM
      rphfifopldentx                  : IN STD_LOGIC;		-- TX phase comp. FIFO PLD read/write enable CRAM
      rphfifoursttx                   : IN STD_LOGIC;		-- TX phase comp. FIFO user reset enable CRAM
      rfreerun_tx                     : IN STD_LOGIC;		-- TX_CLK out free running during TX PCS reset enable CRAM
      rtxwrclksel                     : IN STD_LOGIC;		-- TX FIFO write clock selection CRAM
      rtxrdclksel                     : IN STD_LOGIC;		-- TX FIFO read clock selection CRAM
      renbitrev_tx                    : IN STD_LOGIC;		-- TX bit reversal enable CRAM
      rensymswap_tx                   : IN STD_LOGIC;		-- TX symbol swap enable CRAM
      r8b10b_enc_ibm_en               : IN STD_LOGIC;		-- 8B10B Encoder fix enable CRAM
      rtxfifo_lowlatency_en           : IN STD_LOGIC;		-- TX FIFO low latency enable CRAM
      rpmadwidth_tx                   : IN STD_LOGIC;		-- TX PCS to TX PMA data width selection CRAM
      rpma_doublewidth_tx             : IN STD_LOGIC;		-- PCS/PMA double width (16/20) selection CRAM
      rtx_pipe_enable                 : IN STD_LOGIC;		-- TX PIPE enable CRAM
      -- CID pattern to be 0 or 1
      -- Length of CID pattern in cycles
      
      -- Common PCS CRAMs
      rindv_tx                        : IN STD_LOGIC;		-- TX SM bypassing CRAM
      rendec_data_sel_tx              : IN STD_LOGIC;		-- TX 8B10B encoder data in selection CRAM
      rtxpcsbypass_en                 : IN STD_LOGIC;		-- CRAM for enable low-latency PCS bypass mode
      rtxpcsclkpwdn                   : IN STD_LOGIC;
      rauto_speed_ena                 : IN STD_LOGIC;
      rfreq_sel                       : IN STD_LOGIC;
      gen2ngen1                       : IN STD_LOGIC;
      gen2ngen1_bundle                : IN STD_LOGIC;
      rcid_pattern_tx                 : IN STD_LOGIC;
      rcid_len_tx                     : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
      
      -- new signal inputs for bundling
      tx_div2_sync_in_centrl          : IN STD_LOGIC;
      tx_div2_sync_in_quad_up         : IN STD_LOGIC;
      tx_div2_sync_in_quad_down       : IN STD_LOGIC;
      wr_enable_in_centrl             : IN STD_LOGIC;
      wr_enable_in_quad_up            : IN STD_LOGIC;
      wr_enable_in_quad_down          : IN STD_LOGIC;
      rd_enable_in_centrl             : IN STD_LOGIC;
      rd_enable_in_quad_up            : IN STD_LOGIC;
      rd_enable_in_quad_down          : IN STD_LOGIC;
      fifo_select_in_centrl           : IN STD_LOGIC;
      fifo_select_in_quad_up          : IN STD_LOGIC;
      fifo_select_in_quad_down        : IN STD_LOGIC;
      
      dis_pc_byte                     : IN STD_LOGIC;
      reset_pc_ptrs                   : IN STD_LOGIC;
      reset_pc_ptrs_in_centrl         : IN STD_LOGIC;
      reset_pc_ptrs_in_quad_up        : IN STD_LOGIC;
      reset_pc_ptrs_in_quad_down      : IN STD_LOGIC;
      tx_div2_sync_in_pipe_quad_up    : IN STD_LOGIC;
      tx_div2_sync_in_pipe_quad_down  : IN STD_LOGIC;
      wr_enable_in_pipe_quad_up       : IN STD_LOGIC;
      wr_enable_in_pipe_quad_down     : IN STD_LOGIC;
      rd_enable_in_pipe_quad_up       : IN STD_LOGIC;
      rd_enable_in_pipe_quad_down     : IN STD_LOGIC;
      fifo_select_in_pipe_quad_up     : IN STD_LOGIC;
      fifo_select_in_pipe_quad_down   : IN STD_LOGIC;
      
      -- new MDIO inputs for bundling and auto speed
      rmaster_tx                      : IN STD_LOGIC;
      rmaster_up_tx                   : IN STD_LOGIC;
      rself_sw_en_tx                  : IN STD_LOGIC;
      rpipeline_bypass_tx             : IN STD_LOGIC;
      rphfifo_regmode_tx              : IN STD_LOGIC;
      
      -- new outputs for bundling and auto speed
      
      -- new signals in this module for bundling and auto speed
      
      --CRAM for TX bitslip 
      rtxbitslip_en                   : IN STD_LOGIC;
      tx_div2_sync_out_pipe_up        : OUT STD_LOGIC;
      fifo_select_out_pipe_up         : OUT STD_LOGIC;
      wr_enable_out_pipe_up           : OUT STD_LOGIC;
      rd_enable_out_pipe_up           : OUT STD_LOGIC;
      tx_div2_sync_out_pipe_down      : OUT STD_LOGIC;
      fifo_select_out_pipe_down       : OUT STD_LOGIC;
      wr_enable_out_pipe_down         : OUT STD_LOGIC;
      rd_enable_out_pipe_down         : OUT STD_LOGIC;
      prbs_cid_en                     : IN STD_LOGIC;
      tx_boundary_sel                 : IN STD_LOGIC_VECTOR(4 DOWNTO 0)
   );
END stratixiv_hssi_tx_digi;

ARCHITECTURE trans OF stratixiv_hssi_tx_digi IS
   COMPONENT stratixiv_hssi_tx_digi_prbs_gen
      PORT (
         tx_clk                          : IN STD_LOGIC;
         soft_reset                      : IN STD_LOGIC;
         rprbs_en_tx                     : IN STD_LOGIC;
         rpmadwidth_tx                   : IN STD_LOGIC;
         rpma_doublewidth_tx             : IN STD_LOGIC;
         rprbs_sel                       : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         cid_en                          : IN STD_LOGIC;
         rcid_len                        : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         rcid_pattern                    : IN STD_LOGIC;
         prbs_out                        : OUT STD_LOGIC_VECTOR(19 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_tx_digi_txclk_ctl
      PORT (
         pld_tx_clk                      : IN STD_LOGIC;
         refclk_pma                      : IN STD_LOGIC;
         txpma_local_clk                 : IN STD_LOGIC;
         txrst                           : IN STD_LOGIC;
         scan_mode                       : IN STD_LOGIC;
         gen2ngen1                       : IN STD_LOGIC;
         gen2ngen1_bundle                : IN STD_LOGIC;
         tx_div2_sync_centrl             : IN STD_LOGIC;
         tx_div2_sync_quad_up            : IN STD_LOGIC;
         tx_div2_sync_quad_down          : IN STD_LOGIC;
         rindv_tx                        : IN STD_LOGIC;
         rtxwrclksel                     : IN STD_LOGIC;
         rtxrdclksel                     : IN STD_LOGIC;
         rdwidth_tx                      : IN STD_LOGIC;
         rfreerun_tx                     : IN STD_LOGIC;
         rauto_speed_ena                 : IN STD_LOGIC;
         rfreq_sel                       : IN STD_LOGIC;
         rtxpcsclkpwdn                   : IN STD_LOGIC;
         rmaster_tx                      : IN STD_LOGIC;
         rmaster_up_tx                   : IN STD_LOGIC;
         rself_sw_en_tx                  : IN STD_LOGIC;
         refclk_b                        : OUT STD_LOGIC;
         wr_clk_pos                      : OUT STD_LOGIC;
         fifo_rd_clk                     : OUT STD_LOGIC;
         tx_clk_out                      : OUT STD_LOGIC;
         refclk_b_raw                    : OUT STD_LOGIC;
         wr_clk_pos_raw                  : OUT STD_LOGIC;
         fifo_rd_clk_raw                 : OUT STD_LOGIC;
         tx_div2_sync_out                : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_tx_digi_enc_chnl_top
      PORT (
         rst                             : IN STD_LOGIC;
         clk                             : IN STD_LOGIC;
         cascaded_8b10b_en               : IN STD_LOGIC;
         rendec_data_sel_tx              : IN STD_LOGIC;
         rrev_loopbk                     : IN STD_LOGIC;
         rev_loopbk                      : IN STD_LOGIC;
         dwidth                          : IN STD_LOGIC;
         doublewidth                     : IN STD_LOGIC;
         endec                           : IN STD_LOGIC;
         ge_xaui_sel                     : IN STD_LOGIC;
         rforce_disp                     : IN STD_LOGIC;
         ib_force_disparity              : IN STD_LOGIC;
         prbs_en                         : IN STD_LOGIC;
         r8b10b_enc_ibm_en               : IN STD_LOGIC;
         rev_loop_data                   : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
         tx_ctl_ts                       : IN STD_LOGIC;
         tx_ctl_tc                       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         tx_data_ts                      : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         txd_extend_tc                   : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         tx_data_tc                      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         tx_data_9_tc                    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         tx_data_pg                      : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
         k_det                           : IN STD_LOGIC;
         d21_5_eq_n                      : IN STD_LOGIC;
         d2_2_eq_n                       : IN STD_LOGIC;
         renpolinv_tx                    : IN STD_LOGIC;
         enpolinv_tx                     : IN STD_LOGIC;
         renbitrev_tx                    : IN STD_LOGIC;
         rensymswap_tx                   : IN STD_LOGIC;
         rtxbitslip_en                   : IN STD_LOGIC;
         tx_boundary_sel                 : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         pudr                            : OUT STD_LOGIC_VECTOR(19 DOWNTO 0);
         txlp20b                         : OUT STD_LOGIC_VECTOR(19 DOWNTO 0);
         tx_data_pre_en                  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         tx_data_9_pre_en                : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         tx_ctl_pre_en                   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         disp_out_3b                     : OUT STD_LOGIC_VECTOR(1 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_tx_digi_iq_pipe_tx
      PORT (
         refclk_b_raw                    : IN STD_LOGIC;
         wr_clk_pos_raw                  : IN STD_LOGIC;
         fifo_rd_clk_raw                 : IN STD_LOGIC;
         txrst                           : IN STD_LOGIC;
         soft_reset_rclk1                : IN STD_LOGIC;
         soft_reset_wclk1                : IN STD_LOGIC;
         tx_div2_sync_in_centrl          : IN STD_LOGIC;
         tx_div2_sync_in_pipe_quad_up    : IN STD_LOGIC;
         tx_div2_sync_in_pipe_quad_down  : IN STD_LOGIC;
         wr_enable_in_centrl             : IN STD_LOGIC;
         wr_enable_in_pipe_quad_up       : IN STD_LOGIC;
         wr_enable_in_pipe_quad_down     : IN STD_LOGIC;
         rd_enable_in_centrl             : IN STD_LOGIC;
         rd_enable_in_pipe_quad_up       : IN STD_LOGIC;
         rd_enable_in_pipe_quad_down     : IN STD_LOGIC;
         fifo_select_in_centrl           : IN STD_LOGIC;
         fifo_select_in_pipe_quad_up     : IN STD_LOGIC;
         fifo_select_in_pipe_quad_down   : IN STD_LOGIC;
         rmaster_tx                      : IN STD_LOGIC;
         rmaster_up_tx                   : IN STD_LOGIC;
         rpipeline_bypass_tx             : IN STD_LOGIC;
         rfreerun_tx                     : IN STD_LOGIC;
         tx_div2_sync_out_pipe           : OUT STD_LOGIC;
         fifo_select_out_pipe            : OUT STD_LOGIC;
         wr_enable_out_pipe              : OUT STD_LOGIC;
         rd_enable_out_pipe              : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_tx_digi_bist_gen
      PORT (
         tx_clk                          : IN STD_LOGIC;
         soft_reset                      : IN STD_LOGIC;
         rbisten_tx                      : IN STD_LOGIC;
         rpmadwidth_tx                   : IN STD_LOGIC;
         rpma_doublewidth_tx             : IN STD_LOGIC;
         rdwidth_tx                      : IN STD_LOGIC;
         rbist_sel                       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rcxpat_chnl_sel                 : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         bist_data_sg                    : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         bist_ctl_sg                     : OUT STD_LOGIC_VECTOR(1 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_tx_digi_tx_ctrl
      PORT (
         soft_reset                      : IN STD_LOGIC;
         fifo_wr_clk                     : IN STD_LOGIC;
         fifo_rd_clk                     : IN STD_LOGIC;
         refclk_b_in                     : IN STD_LOGIC;
         scan_mode                       : IN STD_LOGIC;
         rindv_tx                        : IN STD_LOGIC;
         p_rlpbk                         : IN STD_LOGIC;
         selftest_en                     : IN STD_LOGIC;
         rdwidth_tx                      : IN STD_LOGIC;
         txfifo_dis                      : IN STD_LOGIC;
         rtxfifo_urst_en                 : IN STD_LOGIC;
         txfifo_urst                     : IN STD_LOGIC;
         rtxfifo_lowlatency_en           : IN STD_LOGIC;
         rtxphfifopldctl_en              : IN STD_LOGIC;
         rtx_pipe_enable                 : IN STD_LOGIC;
         pld_we                          : IN STD_LOGIC;
         pld_rd_dis                      : IN STD_LOGIC;
         txd                             : IN STD_LOGIC_VECTOR(39 DOWNTO 0);
         txd_extend                      : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         rforce_disp                     : IN STD_LOGIC;
         tx_data_sg                      : IN STD_LOGIC_VECTOR(31 DOWNTO 0);
         tx_control_sg                   : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         rxd_lpbk                        : IN STD_LOGIC_VECTOR(39 DOWNTO 0);
         redund_ctl                      : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         txd_redun                       : IN STD_LOGIC_VECTOR(39 DOWNTO 0);
         rforce_kchar                    : IN STD_LOGIC;
         rforce_echar                    : IN STD_LOGIC;
         rtxpcsbypass_en                 : IN STD_LOGIC;
         txdetectrxloopback              : IN STD_LOGIC;
         powerdown                       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         revloopback                     : IN STD_LOGIC;
         txswing                         : IN STD_LOGIC;
         txdeemph                        : IN STD_LOGIC;
         txmargin                        : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rxpolarity                      : IN STD_LOGIC;
         polinv_rx                       : IN STD_LOGIC;
         eidleinfersel                   : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         reset_pc_ptrs                   : IN STD_LOGIC;
         reset_pc_ptrs_centrl            : IN STD_LOGIC;
         reset_pc_ptrs_quad_up           : IN STD_LOGIC;
         reset_pc_ptrs_quad_down         : IN STD_LOGIC;
         gen2ngen1                       : IN STD_LOGIC;
         gen2ngen1_bundle                : IN STD_LOGIC;
         dis_pc_byte                     : IN STD_LOGIC;
         wr_enable_centrl                : IN STD_LOGIC;
         wr_enable_quad_up               : IN STD_LOGIC;
         wr_enable_quad_down             : IN STD_LOGIC;
         rd_enable_centrl                : IN STD_LOGIC;
         rd_enable_quad_up               : IN STD_LOGIC;
         rd_enable_quad_down             : IN STD_LOGIC;
         fifo_select_in_centrl           : IN STD_LOGIC;
         fifo_select_in_quad_up          : IN STD_LOGIC;
         fifo_select_in_quad_down        : IN STD_LOGIC;
         rauto_speed_ena                 : IN STD_LOGIC;
         rfreq_sel                       : IN STD_LOGIC;
         rphfifo_regmode_tx              : IN STD_LOGIC;
         rmaster_tx                      : IN STD_LOGIC;
         rmaster_up_tx                   : IN STD_LOGIC;
         txd_extend_tc                   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         tx_data_tc                      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         tx_ctl_tc                       : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         tx_data_9_tc                    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         rd_enable_sync                  : OUT STD_LOGIC;
         k_det                           : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         d21_5_eq_n                      : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         d2_2_eq_n                       : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         wr_enable_out                   : OUT STD_LOGIC;
         rd_enable_out                   : OUT STD_LOGIC;
         fifo_select_out                 : OUT STD_LOGIC;
         ph_fifo_full                    : OUT STD_LOGIC;
         ph_fifo_empty                   : OUT STD_LOGIC;
         soft_reset_wclk1                : OUT STD_LOGIC;
         soft_reset_rclk1                : OUT STD_LOGIC;
         pipe_electric_idle              : OUT STD_LOGIC;
         txdetectrxloopback_int          : OUT STD_LOGIC;
         powerdown_int                   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         revloopback_int                 : OUT STD_LOGIC;
         phfifo_txswing                  : OUT STD_LOGIC;
         phfifo_txdeemph                 : OUT STD_LOGIC;
         phfifo_txmargin                 : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         rxpolarity_int                  : OUT STD_LOGIC;
         polinv_rx_int                   : OUT STD_LOGIC;
         gray_eidleinfersel              : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         wr_enable2                      : OUT STD_LOGIC;
         wptr_bin                        : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         rd_enable2                      : OUT STD_LOGIC;
         rptr_bin                        : OUT STD_LOGIC_VECTOR(2 DOWNTO 0)
      );
   END COMPONENT;
   
   SIGNAL refclk_b_raw                      : STD_LOGIC;
   SIGNAL wr_clk_pos_raw                    : STD_LOGIC;
   SIGNAL fifo_rd_clk_raw                   : STD_LOGIC;
   SIGNAL nc_new_bundle1                    : STD_LOGIC;
   SIGNAL nc_new_bundle2                    : STD_LOGIC;
   SIGNAL nc_new_bundle3                    : STD_LOGIC;
   SIGNAL fifo_select_out_testbus           : STD_LOGIC;
   -- removed
   -- txfifo_shared_sig_in_ch0
   -- txfifo_shared_sig_in_q0_ch0
   -- rphfifo_master_sel_tx
   -- txfifo_shared_sig_out
   
   -- Wiring section
   SIGNAL wr_clk_pos                        : STD_LOGIC;
   SIGNAL fifo_rd_clk                       : STD_LOGIC;
   SIGNAL soft_reset_wclk1                  : STD_LOGIC;
   SIGNAL tx_data_tc_high                   : STD_LOGIC_VECTOR(7 DOWNTO 0);		-- high 8-bit tx data from tx_ctrl
   -- low 8-bit tx data from tx_ctrl
   SIGNAL tx_ctl_tc_high                    : STD_LOGIC;		-- high tx control/tx data bit 8 from tx_ctrl
   -- low tx control/tx data bit 8 from tx_ctrl
   SIGNAL tx_ctl_pre_en                     : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL tx_data_pre_en                    : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL tx_data_9_pre_en                  : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL tx_data_sg                        : STD_LOGIC_VECTOR(15 DOWNTO 0);		-- 16-bit data sequence generated by bist_gen.
   SIGNAL tx_control_sg                     : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- 2-bit control sequence generated by selftest_gen.
   SIGNAL tx_data_9_tc                      : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- tx data bit 9 from tx_ctrl
   SIGNAL tx_data_pg                        : STD_LOGIC_VECTOR(19 DOWNTO 0);		-- 20-bit tx code group generated by prbs_gen
   SIGNAL soft_reset_int                    : STD_LOGIC;
   SIGNAL k_det                             : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL d21_5_eq_n                        : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL d2_2_eq_n                         : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL txd_extend_tc                     : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Extend txd by 2 bits. Used to force disparity. This will go to the encoder. 
   -- THis is input from the PLD Fabric
   SIGNAL disp_out_3b                       : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Disparity output from encoder for testbus
   SIGNAL wr_enable2                        : STD_LOGIC;
   SIGNAL wptr_bin                          : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rd_enable2                        : STD_LOGIC;
   SIGNAL rptr_bin                          : STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   SIGNAL tx_data_tc_temp                   : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL tx_ctl_tc_temp                    : STD_LOGIC_VECTOR(1 DOWNTO 0);
   -- X-HDL generated signals

   SIGNAL xhdl28 : STD_LOGIC_VECTOR(39 DOWNTO 0);
   SIGNAL xhdl29 : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL xhdl30 : STD_LOGIC_VECTOR(31 DOWNTO 0);
   SIGNAL xhdl31 : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL xhdl32 : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL xhdl33 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL full_tx_xhdl3                     : STD_LOGIC;
   SIGNAL empty_tx_xhdl0                    : STD_LOGIC;
   SIGNAL tx_clk_out_xhdl17                 : STD_LOGIC;
   SIGNAL tx_data_tc_xhdl19                 : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL tx_ctl_tc_xhdl18                  : STD_LOGIC;
   SIGNAL pudr_xhdl10                       : STD_LOGIC_VECTOR(19 DOWNTO 0);
   SIGNAL rd_enable_sync_xhdl13             : STD_LOGIC;
   SIGNAL refclk_b_xhdl14                   : STD_LOGIC;
   SIGNAL txlp20b_xhdl25                    : STD_LOGIC_VECTOR(19 DOWNTO 0);
   SIGNAL tx_pipe_soft_reset_xhdl23         : STD_LOGIC;
   SIGNAL tx_pipe_electidle_xhdl22          : STD_LOGIC;
   SIGNAL txdetectrxloopback_int_xhdl24     : STD_LOGIC;
   SIGNAL powerdown_int_xhdl9               : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL revloopback_int_xhdl15            : STD_LOGIC;
   SIGNAL phfifo_txswing_xhdl7              : STD_LOGIC;
   SIGNAL phfifo_txdeemph_xhdl5             : STD_LOGIC;
   SIGNAL phfifo_txmargin_xhdl6             : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rxpolarity_int_xhdl16             : STD_LOGIC;
   SIGNAL polinv_rx_int_xhdl8               : STD_LOGIC;
   SIGNAL gray_eidleinfersel_xhdl4          : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL tx_div2_sync_out_pipe_up_xhdl21   : STD_LOGIC;
   SIGNAL fifo_select_out_pipe_up_xhdl2     : STD_LOGIC;
   SIGNAL wr_enable_out_pipe_up_xhdl27      : STD_LOGIC;
   SIGNAL rd_enable_out_pipe_up_xhdl12      : STD_LOGIC;
   SIGNAL tx_div2_sync_out_pipe_down_xhdl20 : STD_LOGIC;
   SIGNAL fifo_select_out_pipe_down_xhdl1   : STD_LOGIC;
   SIGNAL wr_enable_out_pipe_down_xhdl26    : STD_LOGIC;
   SIGNAL rd_enable_out_pipe_down_xhdl11    : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   full_tx <= full_tx_xhdl3;
   empty_tx <= empty_tx_xhdl0;
   tx_clk_out <= tx_clk_out_xhdl17;
   tx_data_tc <= tx_data_tc_xhdl19;
   tx_ctl_tc <= tx_ctl_tc_xhdl18;
   pudr <= pudr_xhdl10;
   rd_enable_sync <= rd_enable_sync_xhdl13;
   refclk_b <= refclk_b_xhdl14;
   txlp20b <= txlp20b_xhdl25;
   tx_pipe_soft_reset <= tx_pipe_soft_reset_xhdl23;
   tx_pipe_electidle <= tx_pipe_electidle_xhdl22;
   txdetectrxloopback_int <= txdetectrxloopback_int_xhdl24;
   powerdown_int <= powerdown_int_xhdl9;
   revloopback_int <= revloopback_int_xhdl15;
   phfifo_txswing <= phfifo_txswing_xhdl7;
   phfifo_txdeemph <= phfifo_txdeemph_xhdl5;
   phfifo_txmargin <= phfifo_txmargin_xhdl6;
   rxpolarity_int <= rxpolarity_int_xhdl16;
   polinv_rx_int <= polinv_rx_int_xhdl8;
   gray_eidleinfersel <= gray_eidleinfersel_xhdl4;
   tx_div2_sync_out_pipe_up <= tx_div2_sync_out_pipe_up_xhdl21;
   fifo_select_out_pipe_up <= fifo_select_out_pipe_up_xhdl2;
   wr_enable_out_pipe_up <= wr_enable_out_pipe_up_xhdl27;
   rd_enable_out_pipe_up <= rd_enable_out_pipe_up_xhdl12;
   tx_div2_sync_out_pipe_down <= tx_div2_sync_out_pipe_down_xhdl20;
   fifo_select_out_pipe_down <= fifo_select_out_pipe_down_xhdl1;
   wr_enable_out_pipe_down <= wr_enable_out_pipe_down_xhdl26;
   rd_enable_out_pipe_down <= rd_enable_out_pipe_down_xhdl11;
   
   -- Gated soft reset by scan_mode signal
   --assign soft_reset_int = (scan_mode) ? 1'b0 : txpcs_rst;
   soft_reset_int <= txpcs_rst;
   
   -- TX PIPE interface clock
   --assign tx_pipe_clk = wr_clk_pos;
   tx_pipe_clk <= fifo_rd_clk;
   
   -- Encoder testbus
   encoder_testbus <= (disp_out_3b & pudr_xhdl10(7 DOWNTO 0));
   
   -- TX FIFO testbus
   tx_ctrl_testbus <= ('0' & fifo_select_out_testbus & wr_enable2 & wptr_bin & rd_enable2 & rptr_bin);
   
   -- Clock selection module
   
   
   txclk_ctl_1 : stratixiv_hssi_tx_digi_txclk_ctl
      PORT MAP (
         pld_tx_clk              => pld_tx_clk,
         refclk_pma              => refclk_pma,
         txpma_local_clk         => txpma_local_clk,
         txrst                   => txpcs_rst,
         scan_mode               => scan_mode,
         gen2ngen1               => gen2ngen1,
         gen2ngen1_bundle        => gen2ngen1_bundle,
         tx_div2_sync_centrl     => tx_div2_sync_in_centrl,
         tx_div2_sync_quad_up    => tx_div2_sync_in_quad_up,
         tx_div2_sync_quad_down  => tx_div2_sync_in_quad_down,
         rindv_tx                => rindv_tx,
         rtxwrclksel             => rtxwrclksel,
         rtxrdclksel             => rtxrdclksel,
         rdwidth_tx              => rdwidth_tx,
         rfreerun_tx             => rfreerun_tx,
         rauto_speed_ena         => rauto_speed_ena,
         rfreq_sel               => rfreq_sel,
         rtxpcsclkpwdn           => rtxpcsclkpwdn,
         rmaster_tx              => rmaster_tx,
         rmaster_up_tx           => rmaster_up_tx,
         rself_sw_en_tx          => rself_sw_en_tx,
         refclk_b                => refclk_b_xhdl14,
         wr_clk_pos              => wr_clk_pos,
         fifo_rd_clk             => fifo_rd_clk,
         tx_clk_out              => tx_clk_out_xhdl17,
         refclk_b_raw            => refclk_b_raw,
         wr_clk_pos_raw          => wr_clk_pos_raw,
         fifo_rd_clk_raw         => fifo_rd_clk_raw,
         tx_div2_sync_out        => nc_new_bundle1
      );
   
   -- TX Phase compensation FIFO module
   
   
   -- S. Park 11/29/07 - Phase FIFO bypass feature removed
   -- .txfifo_dis (rtxfifo_dis),
   xhdl28 <= (txd(42 DOWNTO 33) & txd(31 DOWNTO 22) & txd(20 DOWNTO 11) & txd(9 DOWNTO 0));
   xhdl29 <= (txd(43) & txd(32) & txd(21) & txd(10));
   xhdl30 <= ("0000000000000000" & tx_data_sg);
   xhdl31 <= ("00" & tx_control_sg);
   tx_ctrl_1 : stratixiv_hssi_tx_digi_tx_ctrl
      PORT MAP (
         soft_reset                => soft_reset_int,
         fifo_wr_clk               => wr_clk_pos,
         fifo_rd_clk               => fifo_rd_clk,
         refclk_b_in               => refclk_b_xhdl14,
         scan_mode                 => scan_mode,
         rindv_tx                  => rindv_tx,
         p_rlpbk                   => '0',
         selftest_en               => rbisten_tx,
         rdwidth_tx                => rdwidth_tx,
         txfifo_dis                => '0',
         rtxfifo_urst_en           => rphfifoursttx,
         txfifo_urst               => phfifourst_tx,
         rtxfifo_lowlatency_en     => rtxfifo_lowlatency_en,
         rtxphfifopldctl_en        => rphfifopldentx,
         rtx_pipe_enable           => rtx_pipe_enable,
         pld_we                    => wrenable_tx,
         pld_rd_dis                => rddisable_tx,
         txd                       => xhdl28,
         txd_extend                => xhdl29,
         rforce_disp               => rforce_disp,
         tx_data_sg                => xhdl30,
         tx_control_sg             => xhdl31,
         rxd_lpbk                  => "0000000000000000000000000000000000000000",
         redund_ctl                => "0000",
         txd_redun                 => "0000000000000000000000000000000000000000",
         rforce_kchar              => rforce_kchar,
         rforce_echar              => rforce_echar,
         rtxpcsbypass_en           => rtxpcsbypass_en,
         -- TX PIPE signals
         txdetectrxloopback        => txdetectrxloopback,
         powerdown                 => powerdown,
         revloopback               => revloopback,
         txswing                   => txswing,
         txdeemph                  => pcs_txdeemph,
         txmargin                  => pcs_txmargin,
         -- RX PIPE signals
         rxpolarity                => rxpolarity,
         polinv_rx                 => polinv_rx,
         eidleinfersel             => eidleinfersel,
         reset_pc_ptrs             => reset_pc_ptrs,
         reset_pc_ptrs_centrl      => reset_pc_ptrs_in_centrl,
         reset_pc_ptrs_quad_up     => reset_pc_ptrs_in_quad_up,
         reset_pc_ptrs_quad_down   => reset_pc_ptrs_in_quad_down,
         gen2ngen1                 => gen2ngen1,
         gen2ngen1_bundle          => gen2ngen1_bundle,
         dis_pc_byte               => dis_pc_byte,
         wr_enable_centrl          => wr_enable_in_centrl,
         wr_enable_quad_up         => wr_enable_in_quad_up,
         wr_enable_quad_down       => wr_enable_in_quad_down,
         rd_enable_centrl          => rd_enable_in_centrl,
         rd_enable_quad_up         => rd_enable_in_quad_up,
         rd_enable_quad_down       => rd_enable_in_quad_down,
         fifo_select_in_centrl     => fifo_select_in_centrl,
         fifo_select_in_quad_up    => fifo_select_in_quad_up,
         fifo_select_in_quad_down  => fifo_select_in_quad_down,
         rauto_speed_ena           => rauto_speed_ena,
         rfreq_sel                 => rfreq_sel,
         rphfifo_regmode_tx        => rphfifo_regmode_tx,
         rmaster_tx                => rmaster_tx,
         rmaster_up_tx             => rmaster_up_tx,
         txd_extend_tc             => txd_extend_tc,
         tx_data_tc                => tx_data_tc_temp,
         tx_ctl_tc                 => tx_ctl_tc_temp,
         tx_data_9_tc              => tx_data_9_tc,
         rd_enable_sync            => rd_enable_sync_xhdl13,
         k_det                     => k_det,
         d21_5_eq_n                => d21_5_eq_n,
         d2_2_eq_n                 => d2_2_eq_n,
         wr_enable_out             => nc_new_bundle2,
         rd_enable_out             => nc_new_bundle3,
         fifo_select_out           => fifo_select_out_testbus,
         ph_fifo_full              => full_tx_xhdl3,
         ph_fifo_empty             => empty_tx_xhdl0,
         soft_reset_wclk1          => soft_reset_wclk1,
         soft_reset_rclk1          => tx_pipe_soft_reset_xhdl23,
         pipe_electric_idle        => tx_pipe_electidle_xhdl22,
         -- TX PIPE signals
         txdetectrxloopback_int    => txdetectrxloopback_int_xhdl24,
         powerdown_int             => powerdown_int_xhdl9,
         revloopback_int           => revloopback_int_xhdl15,
         gray_eidleinfersel        => gray_eidleinfersel_xhdl4,
         
         phfifo_txswing            => phfifo_txswing_xhdl7,
         phfifo_txdeemph           => phfifo_txdeemph_xhdl5,
         phfifo_txmargin           => phfifo_txmargin_xhdl6,
         
         -- RX PIPE signals
         rxpolarity_int            => rxpolarity_int_xhdl16,
         polinv_rx_int             => polinv_rx_int_xhdl8,
         wr_enable2                => wr_enable2,
         wptr_bin                  => wptr_bin,
         rd_enable2                => rd_enable2,
         rptr_bin                  => rptr_bin
      );
   tx_data_tc_high <= tx_data_tc_temp(15 DOWNTO 8);
   tx_data_tc_xhdl19 <= tx_data_tc_temp(7 DOWNTO 0);
   tx_ctl_tc_high <= tx_ctl_tc_temp(1);
   tx_ctl_tc_xhdl18 <= tx_ctl_tc_temp(0);
   -- BIST generator module
   
   
   selftest_gen_1 : stratixiv_hssi_tx_digi_bist_gen
      PORT MAP (
         tx_clk               => wr_clk_pos,
         soft_reset           => soft_reset_wclk1,
         rbisten_tx           => rbisten_tx,
         rpmadwidth_tx        => rpmadwidth_tx,
         rpma_doublewidth_tx  => rpma_doublewidth_tx,
         rdwidth_tx           => rdwidth_tx,
         rbist_sel            => rbist_sel,
         rcxpat_chnl_sel      => rcxpat_chnl_en,
         bist_data_sg         => tx_data_sg,
         bist_ctl_sg          => tx_control_sg
      );
   
   -- PRBS generator module
   
   
   prbs_gen_1 : stratixiv_hssi_tx_digi_prbs_gen
      PORT MAP (
         tx_clk               => refclk_b_xhdl14,
         soft_reset           => soft_reset_int,
         rprbs_en_tx          => rprbsen_tx,
         rpmadwidth_tx        => rpmadwidth_tx,
         rpma_doublewidth_tx  => rpma_doublewidth_tx,
         cid_en               => prbs_cid_en,
         rcid_len             => rcid_len_tx,
         rcid_pattern         => rcid_pattern_tx,
         rprbs_sel            => rprbs_sel,
         prbs_out             => tx_data_pg
      );
   
   -- 8B-10B Encoder module
   
   
   xhdl32 <= (tx_ctl_tc_high & tx_ctl_tc_xhdl18);
   xhdl33 <= (tx_data_tc_high & tx_data_tc_xhdl19);
   enc_chnl_top_1 : stratixiv_hssi_tx_digi_enc_chnl_top
      PORT MAP (
         rst                 => soft_reset_int,
         clk                 => refclk_b_xhdl14,
         cascaded_8b10b_en   => rcascaded_8b10b_en_tx,
         rendec_data_sel_tx  => rendec_data_sel_tx,
         rrev_loopbk         => rrev_loopbk,
         rev_loopbk          => rev_loopbk,
         dwidth              => rpmadwidth_tx,
         doublewidth         => rpma_doublewidth_tx,
         endec               => rendec_tx,
         ge_xaui_sel         => rge_xaui_tx,
         rforce_disp         => rforce_disp,
         ib_force_disparity  => rib_force_disp,
         prbs_en             => rprbsen_tx,
         r8b10b_enc_ibm_en   => r8b10b_enc_ibm_en,
         rev_loop_data       => rev_loop_data,
         tx_ctl_ts           => tx_ctl_ts,
         tx_ctl_tc           => xhdl32,
         tx_data_ts          => tx_data_ts,
         txd_extend_tc       => txd_extend_tc,
         tx_data_tc          => xhdl33,
         tx_data_9_tc        => tx_data_9_tc,
         tx_data_pg          => tx_data_pg,
         k_det               => k_det(0),
         d21_5_eq_n          => d21_5_eq_n(0),
         d2_2_eq_n           => d2_2_eq_n(0),
         renpolinv_tx        => renpolinv_tx,
         enpolinv_tx         => polinv_tx,
         renbitrev_tx        => renbitrev_tx,
         rensymswap_tx       => rensymswap_tx,
         rtxbitslip_en       => rtxbitslip_en,
         tx_boundary_sel     => tx_boundary_sel,
         pudr                => pudr_xhdl10,
         txlp20b             => txlp20b_xhdl25,
         tx_data_pre_en      => tx_data_pre_en,
         tx_data_9_pre_en    => tx_data_9_pre_en,
         tx_ctl_pre_en       => tx_ctl_pre_en,
         disp_out_3b         => disp_out_3b
      );
   
   
   
   iqp_out_up : stratixiv_hssi_tx_digi_iq_pipe_tx
      PORT MAP (
         refclk_b_raw                    => refclk_b_raw,
         wr_clk_pos_raw                  => wr_clk_pos_raw,
         fifo_rd_clk_raw                 => fifo_rd_clk_raw,
         txrst                           => txpcs_rst,
         soft_reset_rclk1                => tx_pipe_soft_reset_xhdl23,
         soft_reset_wclk1                => soft_reset_wclk1,
         tx_div2_sync_in_centrl          => tx_div2_sync_in_centrl,
         tx_div2_sync_in_pipe_quad_up    => '0',
         tx_div2_sync_in_pipe_quad_down  => tx_div2_sync_in_pipe_quad_down,
         wr_enable_in_centrl             => wr_enable_in_centrl,
         wr_enable_in_pipe_quad_up       => '0',
         wr_enable_in_pipe_quad_down     => wr_enable_in_pipe_quad_down,
         rd_enable_in_centrl             => rd_enable_in_centrl,
         rd_enable_in_pipe_quad_up       => '0',
         rd_enable_in_pipe_quad_down     => rd_enable_in_pipe_quad_down,
         fifo_select_in_centrl           => fifo_select_in_centrl,
         fifo_select_in_pipe_quad_up     => '0',
         fifo_select_in_pipe_quad_down   => fifo_select_in_pipe_quad_down,
         rmaster_tx                      => rmaster_tx,
         rmaster_up_tx                   => rmaster_up_tx,
         rpipeline_bypass_tx             => rpipeline_bypass_tx,
         rfreerun_tx                     => rfreerun_tx,
         tx_div2_sync_out_pipe           => tx_div2_sync_out_pipe_up_xhdl21,
         fifo_select_out_pipe            => fifo_select_out_pipe_up_xhdl2,
         wr_enable_out_pipe              => wr_enable_out_pipe_up_xhdl27,
         rd_enable_out_pipe              => rd_enable_out_pipe_up_xhdl12
      );
   
   
   
   iqp_out_down : stratixiv_hssi_tx_digi_iq_pipe_tx
      PORT MAP (
         refclk_b_raw                    => refclk_b_raw,
         wr_clk_pos_raw                  => wr_clk_pos_raw,
         fifo_rd_clk_raw                 => fifo_rd_clk_raw,
         txrst                           => txpcs_rst,
         soft_reset_rclk1                => tx_pipe_soft_reset_xhdl23,
         soft_reset_wclk1                => soft_reset_wclk1,
         tx_div2_sync_in_centrl          => tx_div2_sync_in_centrl,
         tx_div2_sync_in_pipe_quad_up    => tx_div2_sync_in_pipe_quad_up,
         tx_div2_sync_in_pipe_quad_down  => '0',
         wr_enable_in_centrl             => wr_enable_in_centrl,
         wr_enable_in_pipe_quad_up       => wr_enable_in_pipe_quad_up,
         wr_enable_in_pipe_quad_down     => '0',
         rd_enable_in_centrl             => rd_enable_in_centrl,
         rd_enable_in_pipe_quad_up       => rd_enable_in_pipe_quad_up,
         rd_enable_in_pipe_quad_down     => '0',
         fifo_select_in_centrl           => fifo_select_in_centrl,
         fifo_select_in_pipe_quad_up     => fifo_select_in_pipe_quad_up,
         fifo_select_in_pipe_quad_down   => '0',
         rmaster_tx                      => rmaster_tx,
         rmaster_up_tx                   => rmaster_up_tx,
         rpipeline_bypass_tx             => rpipeline_bypass_tx,
         rfreerun_tx                     => rfreerun_tx,
         tx_div2_sync_out_pipe           => tx_div2_sync_out_pipe_down_xhdl20,
         fifo_select_out_pipe            => fifo_select_out_pipe_down_xhdl1,
         wr_enable_out_pipe              => wr_enable_out_pipe_down_xhdl26,
         rd_enable_out_pipe              => rd_enable_out_pipe_down_xhdl11
      );
   
END trans;




-- digi_tx--///////////////////////////////////////////////////////////////////////////////
-- hssi_module: transmitter ***************************************************//
--///////////////////////////////////////////////////////////////////////////////

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

USE IEEE.VITAL_Timing.all;
USE IEEE.VITAL_Primitives.all;
ENTITY stratixiv_hssi_tx_pcs IS
   GENERIC (

          --  generic control parameters  --
       -- VITAL
       MsgOn                   : Boolean := DefGlitchMsgOn;
       XOn                     : Boolean := DefGlitchXOn;
       MsgOnChecks             : Boolean := DefMsgOnChecks;
       XOnChecks               : Boolean := DefXOnChecks;
       InstancePath            : String := "*";
       TimingChecksOn          : Boolean := True;
          --  tipd  :interconnect path delays --
      tipd_bitslipboundaryselect               :VitalDelayArrayType01(4 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_coreclk                : VitalDelayType01 := DefpropDelay01;
      tipd_ctrlenable               :VitalDelayArrayType01(3 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_datain               :VitalDelayArrayType01(39 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_datainfull               :VitalDelayArrayType01(43 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_detectrxloop                : VitalDelayType01 := DefpropDelay01;
      tipd_digitalreset                : VitalDelayType01 := DefpropDelay01;
      tipd_dispval               :VitalDelayArrayType01(3 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_dpriodisable                : VitalDelayType01 := DefpropDelay01;
      tipd_dprioin               :VitalDelayArrayType01(149 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_enrevparallellpbk                : VitalDelayType01 := DefpropDelay01;
      tipd_forcedisp               :VitalDelayArrayType01(3 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_forcedispcompliance                : VitalDelayType01 := DefpropDelay01;
      tipd_forceelecidle                : VitalDelayType01 := DefpropDelay01;
      tipd_freezptr                : VitalDelayType01 := DefpropDelay01;
      tipd_hipdatain               :VitalDelayArrayType01(9 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_hipforceelecidle                : VitalDelayType01 := DefpropDelay01;
      tipd_hiptxdeemph                : VitalDelayType01 := DefpropDelay01;
      tipd_hiptxmargin               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_hippowerdn               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_hipdetectrxloop                : VitalDelayType01 := DefpropDelay01;
      tipd_invpol                : VitalDelayType01 := DefpropDelay01;
      tipd_iqpphfifoxnwrenable               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_iqpphfifoxnrdenable               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_iqpphfifoxnbytesel               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_iqpphfifoxnrdclk               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_localrefclk                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifobyteserdisable                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifoxnbytesel               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_phfifoxnbottomwrenable                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifoxntopwrenable                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifoptrsreset                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifoxnptrsreset               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_phfifoxnrdenable               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_phfiforddisable                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifoxntopbytesel                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifoxntoprdclk                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifox4bytesel                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifox4rdclk                : VitalDelayType01 := DefpropDelay01;
      tipd_phfiforeset                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifox4rdenable                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifowrenable                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifoxnbottombytesel                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifoxntoprdenable                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifoxnrdclk               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_phfifox4wrenable                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifoxnbottomrdenable                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifoxnbottomrdclk                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifoxnwrenable               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_pipestatetransdone                : VitalDelayType01 := DefpropDelay01;
      tipd_pipetxswing                : VitalDelayType01 := DefpropDelay01;
      tipd_pipetxmargin               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_pipetxdeemph                : VitalDelayType01 := DefpropDelay01;
      tipd_powerdn               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_prbscidenable                : VitalDelayType01 := DefpropDelay01;
      tipd_rateswitch                : VitalDelayType01 := DefpropDelay01;
      tipd_rateswitchisdone                : VitalDelayType01 := DefpropDelay01;
      tipd_rateswitchxndone                : VitalDelayType01 := DefpropDelay01;
      tipd_refclk                : VitalDelayType01 := DefpropDelay01;
      tipd_revparallelfdbk               :VitalDelayArrayType01(19 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_quadreset                : VitalDelayType01 := DefpropDelay01;
      tipd_xgmctrl                : VitalDelayType01 := DefpropDelay01;
      tipd_xgmdatain               :VitalDelayArrayType01(7 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      -- TSU-TH section
      tsetup_ctrlenable_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      tsetup_datain_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      tsetup_detectrxloop_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      tsetup_dispval_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      tsetup_forcedisp_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      tsetup_forcedispcompliance_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      tsetup_phfifowrenable_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      tsetup_forceelecidle_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      tsetup_powerdn_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      tsetup_pipetxdeemph_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      tsetup_pipetxswing_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      tsetup_pipetxmargin_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      thold_ctrlenable_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      thold_datain_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      thold_detectrxloop_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      thold_dispval_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      thold_forcedisp_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      thold_forcedispcompliance_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      thold_phfifowrenable_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      thold_forceelecidle_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      thold_powerdn_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      thold_pipetxdeemph_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      thold_pipetxswing_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      thold_pipetxmargin_coreclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      -- TCO section
      tpd_coreclk_phfifooverflow_posedge : VitalDelayType01 := DefPropDelay01;
      tpd_coreclk_phfifounderflow_posedge : VitalDelayType01 := DefPropDelay01;

      lpm_type                                 : STRING := "stratixiv_hssi_tx_pcs";
      allow_polarity_inversion                 : STRING := "false";
      auto_spd_self_switch_enable              : STRING := "false";
      bitslip_enable                           : STRING := "false";
      channel_bonding                          : STRING := "none";	-- none, x8, x4
      channel_number                           : INTEGER := 0;
      channel_width                            : INTEGER := 8;
      core_clock_0ppm                          : STRING := "false";
      datapath_low_latency_mode                : STRING := "false";	--NEW_PARAM, RTL=
      datapath_protocol                        : STRING := "basic";	--replaced by protocol_hint
      disable_ph_low_latency_mode              : STRING := "false";
      disparity_mode                           : STRING := "none";	-- legacy, new, none
      dprio_config_mode                        : STD_LOGIC_VECTOR(5 DOWNTO 0) := "000000";
      elec_idle_delay                          : INTEGER := 6;		-- new in 6.0 <3-6>
      enable_bit_reversal                      : STRING := "false";
      enable_idle_selection                    : STRING := "false";
      enable_phfifo_bypass                     : STRING := "false";
      enable_reverse_parallel_loopback         : STRING := "false";
      enable_self_test_mode                    : STRING := "false";
      enable_symbol_swap                       : STRING := "false";
      enc_8b_10b_compatibility_mode            : STRING := "true";
      enc_8b_10b_mode                          : STRING := "none";	-- cascade, normal, none
      force_echar                              : STRING := "false";
      force_kchar                              : STRING := "false";
      hip_enable                               : STRING := "false";
      iqp_bypass                               : STRING := "false";
      iqp_ph_fifo_xn_select                    : INTEGER := 9999;
      logical_channel_address                  : INTEGER := 0;		
      migrated_from_prev_family                : STRING := "false";
      ph_fifo_reg_mode                         : STRING := "false";
      ph_fifo_reset_enable                     : STRING := "false";
      ph_fifo_user_ctrl_enable                 : STRING := "false";
      ph_fifo_xn_mapping0                      : STRING := "none";
      ph_fifo_xn_mapping1                      : STRING := "none";
      ph_fifo_xn_mapping2                      : STRING := "none";
      ph_fifo_xn_select                        : INTEGER := 9999;
      pipe_auto_speed_nego_enable              : STRING := "false";	
      pipe_freq_scale_mode                     : STRING := "Data width";		
      pipe_voltage_swing_control               : STRING := "false";	--NEW_PARAM, RTL=
      prbs_all_one_detect                      : STRING := "false";
      prbs_cid_pattern                         : STRING := "false";
      prbs_cid_pattern_length                  : INTEGER := 0;
      protocol_hint                            : STRING := "basic";
      refclk_select                            : STRING := "local";	-- cmu_clk_divider
      reset_clock_output_during_digital_reset  : STRING := "false";
      self_test_mode                           : STRING := "incremental";
      use_double_data_mode                     : STRING := "false";
      use_serializer_double_data_mode          : STRING := "false";
      wr_clk_mux_select                        : STRING := "core_clk";	-- INT_CLK                  // int_clk
      use_top_quad_as_mater                    : STRING := "true";	-- NEW_PARAM todo: select top/bottom to provide phfifo pointers
      dprio_width                              : INTEGER := 150
   );
   PORT (
      bitslipboundaryselect                    : IN STD_LOGIC_VECTOR(4 DOWNTO 0) := (others => '0');		
      coreclk                                  : IN STD_LOGIC := '0';
      ctrlenable                               : IN STD_LOGIC_VECTOR(3 DOWNTO 0) := (others => '0');
      datain                                   : IN STD_LOGIC_VECTOR(39 DOWNTO 0) := (others => '0');
      datainfull                               : IN STD_LOGIC_VECTOR(43 DOWNTO 0) := (others => '0');		-- WYS_TO_CHANGE
      detectrxloop                             : IN STD_LOGIC := '0';
      digitalreset                             : IN STD_LOGIC := '0';
      dispval                                  : IN STD_LOGIC_VECTOR(3 DOWNTO 0) := (others => '0');
      dpriodisable                             : IN STD_LOGIC := '1';
      dprioin                                  : IN STD_LOGIC_VECTOR(149 DOWNTO 0) := (others => '0');
      elecidleinfersel                         : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');   
      enrevparallellpbk                        : IN STD_LOGIC := '0';
      forcedisp                                : IN STD_LOGIC_VECTOR(3 DOWNTO 0) := (others => '0');		--fix_width
      forcedispcompliance                      : IN STD_LOGIC := '0';
      forceelecidle                            : IN STD_LOGIC := '0';		
      freezptr                                 : IN STD_LOGIC := '0';
      hipdatain                                : IN STD_LOGIC_VECTOR(9 DOWNTO 0) := (others => '0');		
      hipdetectrxloop                          : IN STD_LOGIC := '0';		
      hipelecidleinfersel                      : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');		
      hipforceelecidle                         : IN STD_LOGIC := '0';		
      hippowerdn                               : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');		
      hiptxdeemph                              : IN STD_LOGIC := '0';		
      hiptxmargin                              : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');		
      invpol                                   : IN STD_LOGIC := '0';
      iqpphfifoxnbytesel                       : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');		
      iqpphfifoxnrdclk                         : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');		
      iqpphfifoxnrdenable                      : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');		
      iqpphfifoxnwrenable                      : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');		
      localrefclk                              : IN STD_LOGIC := '0';		
      phfifobyteserdisable                     : IN STD_LOGIC := '0';		
      phfifoptrsreset                          : IN STD_LOGIC := '0';		
      phfiforddisable                          : IN STD_LOGIC := '0';
      phfiforeset                              : IN STD_LOGIC := '0';
      phfifowrenable                           : IN STD_LOGIC := '1';
      phfifox4bytesel                          : IN STD_LOGIC := '0';
      phfifox4rdclk                            : IN STD_LOGIC := '0';
      phfifox4rdenable                         : IN STD_LOGIC := '0';
      phfifox4wrenable                         : IN STD_LOGIC := '0';
      phfifoxnbottombytesel                    : IN STD_LOGIC := '0';		
      phfifoxnbottomrdclk                      : IN STD_LOGIC := '0';		
      phfifoxnbottomrdenable                   : IN STD_LOGIC := '0';		
      phfifoxnbottomwrenable                   : IN STD_LOGIC := '0';		
      phfifoxnbytesel                          : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');	
      phfifoxnptrsreset                        : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');	
      phfifoxnrdclk                            : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');	
      phfifoxnrdenable                         : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');	
      phfifoxntopbytesel                       : IN STD_LOGIC := '0';		
      phfifoxntoprdclk                         : IN STD_LOGIC := '0';		
      phfifoxntoprdenable                      : IN STD_LOGIC := '0';		
      phfifoxntopwrenable                      : IN STD_LOGIC := '0';		
      phfifoxnwrenable                         : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');	
      pipestatetransdone                       : IN STD_LOGIC := '0';
      pipetxdeemph                             : IN STD_LOGIC := '0';		--NEW;  RTL=txdeemph;
      pipetxmargin                             : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');		--NEW;  RTL=txmargin[2:0]
      pipetxswing                              : IN STD_LOGIC := '0';		--NEW;  RTL=txswing
      powerdn                                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');
      prbscidenable                            : IN STD_LOGIC := '0';		
      quadreset                                : IN STD_LOGIC := '0';
      rateswitch                               : IN STD_LOGIC := '0';		--NEW,  RTL=rate
      rateswitchisdone                         : IN STD_LOGIC := '0';		
      rateswitchxndone                         : IN STD_LOGIC := '0';		
      refclk                                   : IN STD_LOGIC := '0';
      revparallelfdbk                          : IN STD_LOGIC_VECTOR(19 DOWNTO 0) := (others => '0');
      xgmctrl                                  : IN STD_LOGIC := '0';
      xgmdatain                                : IN STD_LOGIC_VECTOR(7 DOWNTO 0) := (others => '0');
      
      clkout                                   : OUT STD_LOGIC;
      coreclkout                               : OUT STD_LOGIC;		
      dataout                                  : OUT STD_LOGIC_VECTOR(19 DOWNTO 0);
      dprioout                                 : OUT STD_LOGIC_VECTOR(149 DOWNTO 0);
      forceelecidleout                         : OUT STD_LOGIC;
      grayelecidleinferselout                  : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);  
      hiptxclkout                              : OUT STD_LOGIC;		
      iqpphfifobyteselout                      : OUT STD_LOGIC;		
      iqpphfifordclkout                        : OUT STD_LOGIC;		
      iqpphfifordenableout                     : OUT STD_LOGIC;		
      iqpphfifowrenableout                     : OUT STD_LOGIC;		
      parallelfdbkout                          : OUT STD_LOGIC_VECTOR(19 DOWNTO 0);
      phfifobyteselout                         : OUT STD_LOGIC;
      phfifooverflow                           : OUT STD_LOGIC;
      phfifordclkout                           : OUT STD_LOGIC;
      phfiforddisableout                       : OUT STD_LOGIC;		
      phfifordenableout                        : OUT STD_LOGIC;
      phfiforesetout                           : OUT STD_LOGIC;		
      phfifounderflow                          : OUT STD_LOGIC;
      phfifowrenableout                        : OUT STD_LOGIC;
      pipeenrevparallellpbkout                 : OUT STD_LOGIC;     
      pipepowerdownout                         : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pipepowerstateout                        : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      rateswitchout                            : OUT STD_LOGIC;
      rdenablesync                             : OUT STD_LOGIC;
      txdetectrx                               : OUT STD_LOGIC;		
      xgmctrlenable                            : OUT STD_LOGIC;
      xgmdataout                               : OUT STD_LOGIC_VECTOR(7 DOWNTO 0)
   );
END stratixiv_hssi_tx_pcs;

ARCHITECTURE trans OF stratixiv_hssi_tx_pcs IS

  signal phfifoxnbytesel_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal phfifoxnbottomwrenable_ipd  :STD_LOGIC;
  signal dispval_ipd  :STD_LOGIC_VECTOR(3 DOWNTO 0);
  signal phfifoxntopwrenable_ipd  :STD_LOGIC;
  signal phfifoptrsreset_ipd  :STD_LOGIC;
  signal phfifoxnptrsreset_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal forcedisp_ipd  :STD_LOGIC_VECTOR(3 DOWNTO 0);
  signal hiptxmargin_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal iqpphfifoxnwrenable_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal rateswitchisdone_ipd  :STD_LOGIC;
  signal powerdn_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal phfifoxnrdenable_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal phfiforddisable_ipd  :STD_LOGIC;
  signal phfifoxntopbytesel_ipd  :STD_LOGIC;
  signal ctrlenable_ipd  :STD_LOGIC_VECTOR(3 DOWNTO 0);
  signal phfifoxntoprdclk_ipd  :STD_LOGIC;
  signal hiptxdeemph_ipd  :STD_LOGIC;
  signal freezptr_ipd  :STD_LOGIC;
  signal refclk_ipd  :STD_LOGIC;
  signal phfifox4bytesel_ipd  :STD_LOGIC;
  signal rateswitchxndone_ipd  :STD_LOGIC;
  signal forcedispcompliance_ipd  :STD_LOGIC;
  signal phfifox4rdclk_ipd  :STD_LOGIC;
  signal datainfull_ipd  :STD_LOGIC_VECTOR(43 DOWNTO 0);
  signal phfiforeset_ipd  :STD_LOGIC;
  signal coreclk_ipd  :STD_LOGIC;
  signal dprioin_ipd  :STD_LOGIC_VECTOR(149 DOWNTO 0);
  signal rateswitch_ipd  :STD_LOGIC;
  signal pipestatetransdone_ipd  :STD_LOGIC;
  signal phfifox4rdenable_ipd  :STD_LOGIC;
  signal phfifowrenable_ipd  :STD_LOGIC;
  signal datain_ipd  :STD_LOGIC_VECTOR(39 DOWNTO 0);
  signal hipforceelecidle_ipd  :STD_LOGIC;
  signal enrevparallellpbk_ipd  :STD_LOGIC;
  signal forceelecidle_ipd  :STD_LOGIC;
  signal pipetxswing_ipd  :STD_LOGIC;
  signal phfifoxnrdclk_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal pipetxmargin_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal pipetxdeemph_ipd  :STD_LOGIC;
  signal phfifox4wrenable_ipd  :STD_LOGIC;
  signal bitslipboundaryselect_ipd  :STD_LOGIC_VECTOR(4 DOWNTO 0);
  signal phfifoxnbottomrdenable_ipd  :STD_LOGIC;
  signal phfifoxnbottomrdclk_ipd  :STD_LOGIC;
  signal dpriodisable_ipd  :STD_LOGIC;
  signal phfifobyteserdisable_ipd  :STD_LOGIC;
  signal hippowerdn_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal xgmctrl_ipd  :STD_LOGIC;
  signal hipdetectrxloop_ipd  :STD_LOGIC;
  signal invpol_ipd  :STD_LOGIC;
  signal revparallelfdbk_ipd  :STD_LOGIC_VECTOR(19 DOWNTO 0);
  signal localrefclk_ipd  :STD_LOGIC;
  signal prbscidenable_ipd  :STD_LOGIC;
  signal iqpphfifoxnrdenable_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal digitalreset_ipd  :STD_LOGIC;
  signal iqpphfifoxnbytesel_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal iqpphfifoxnrdclk_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal phfifoxnwrenable_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal quadreset_ipd  :STD_LOGIC;
  signal xgmdatain_ipd  :STD_LOGIC_VECTOR(7 DOWNTO 0);
  signal phfifoxnbottombytesel_ipd  :STD_LOGIC;
  signal phfifoxntoprdenable_ipd  :STD_LOGIC;
  signal hipdatain_ipd  :STD_LOGIC_VECTOR(9 DOWNTO 0);
  signal detectrxloop_ipd  :STD_LOGIC;
   COMPONENT stratixiv_hssi_tx_pipe_interface
      PORT (
         clk                                      : IN STD_LOGIC;
         refclk_b                                 : IN STD_LOGIC;
         reset_n                                  : IN STD_LOGIC;
         refclk_b_reset_n                         : IN STD_LOGIC;
         rtx_pipe_enable                          : IN STD_LOGIC;
         rtx_elec_idle_delay                      : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rtxswing_sel_ena                         : IN STD_LOGIC;
         txdetectrxloopback                       : IN STD_LOGIC;
         txelecidle                               : IN STD_LOGIC;
         powerdown                                : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         txswing                                  : IN STD_LOGIC;
         txdeemph                                 : IN STD_LOGIC;
         txmargin                                 : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         txd_ch                                   : IN STD_LOGIC_VECTOR(43 DOWNTO 0);
         revloopback                              : IN STD_LOGIC;
         txd                                      : OUT STD_LOGIC_VECTOR(43 DOWNTO 0);
         rev_loopbk                               : OUT STD_LOGIC;
         tx_elec_idle_comp                        : IN STD_LOGIC;
         tx_elec_idle                             : OUT STD_LOGIC;
         txdetectrx                               : OUT STD_LOGIC;
         powerstate                               : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
         txswing_int                              : OUT STD_LOGIC;
         txdeemph_int                             : OUT STD_LOGIC;
         txmargin_int                             : OUT STD_LOGIC_VECTOR(2 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_tx_digi
      PORT (
         txpcs_rst                                : IN STD_LOGIC;
         scan_mode                                : IN STD_LOGIC;
         txd                                      : IN STD_LOGIC_VECTOR(43 DOWNTO 0);
         pld_tx_clk                               : IN STD_LOGIC;
         polinv_tx                                : IN STD_LOGIC;
         rev_loop_data                            : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
         wrenable_tx                              : IN STD_LOGIC;
         rddisable_tx                             : IN STD_LOGIC;
         phfifourst_tx                            : IN STD_LOGIC;
         txdetectrxloopback                       : IN STD_LOGIC;
         powerdown                                : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         revloopback                              : IN STD_LOGIC;
         txswing                                  : IN STD_LOGIC;
         pcs_txdeemph                             : IN STD_LOGIC;
         pcs_txmargin                             : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rxpolarity                               : IN STD_LOGIC;
         polinv_rx                                : IN STD_LOGIC;
         full_tx                                  : OUT STD_LOGIC;
         empty_tx                                 : OUT STD_LOGIC;
         tx_data_ts                               : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         tx_ctl_ts                                : IN STD_LOGIC;
         refclk_pma                               : IN STD_LOGIC;
         txpma_local_clk                          : IN STD_LOGIC;
         tx_clk_out                               : OUT STD_LOGIC;
         tx_data_tc                               : OUT STD_LOGIC_VECTOR(7 DOWNTO 0);
         tx_ctl_tc                                : OUT STD_LOGIC;
         pudr                                     : OUT STD_LOGIC_VECTOR(19 DOWNTO 0);
         rd_enable_sync                           : OUT STD_LOGIC;
         refclk_b                                 : OUT STD_LOGIC;
         txlp20b                                  : OUT STD_LOGIC_VECTOR(19 DOWNTO 0);
         tx_pipe_clk                              : OUT STD_LOGIC;
         encoder_testbus                          : OUT STD_LOGIC_VECTOR(9 DOWNTO 0);
         tx_ctrl_testbus                          : OUT STD_LOGIC_VECTOR(9 DOWNTO 0);
         tx_pipe_soft_reset                       : OUT STD_LOGIC;
         tx_pipe_electidle                        : OUT STD_LOGIC;
         txdetectrxloopback_int                   : OUT STD_LOGIC;
         powerdown_int                            : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         revloopback_int                          : OUT STD_LOGIC;
         phfifo_txswing                           : OUT STD_LOGIC;
         phfifo_txdeemph                          : OUT STD_LOGIC;
         phfifo_txmargin                          : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         rxpolarity_int                           : OUT STD_LOGIC;
         polinv_rx_int                            : OUT STD_LOGIC;
         rrev_loopbk                              : IN STD_LOGIC;
         rev_loopbk                               : IN STD_LOGIC;
         eidleinfersel                            : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         gray_eidleinfersel                       : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         rbisten_tx                               : IN STD_LOGIC;
         rforce_disp                              : IN STD_LOGIC;
         rib_force_disp                           : IN STD_LOGIC;
         rforce_echar                             : IN STD_LOGIC;
         rforce_kchar                             : IN STD_LOGIC;
         rendec_tx                                : IN STD_LOGIC;
         rge_xaui_tx                              : IN STD_LOGIC;
         rdwidth_tx                               : IN STD_LOGIC;
         rtxfifo_dis                              : IN STD_LOGIC;
         rcascaded_8b10b_en_tx                    : IN STD_LOGIC;
         rprbsen_tx                               : IN STD_LOGIC;
         rprbs_sel                                : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rbist_sel                                : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rcxpat_chnl_en                           : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         renpolinv_tx                             : IN STD_LOGIC;
         rphfifopldentx                           : IN STD_LOGIC;
         rphfifoursttx                            : IN STD_LOGIC;
         rfreerun_tx                              : IN STD_LOGIC;
         rtxwrclksel                              : IN STD_LOGIC;
         rtxrdclksel                              : IN STD_LOGIC;
         renbitrev_tx                             : IN STD_LOGIC;
         rensymswap_tx                            : IN STD_LOGIC;
         r8b10b_enc_ibm_en                        : IN STD_LOGIC;
         rtxfifo_lowlatency_en                    : IN STD_LOGIC;
         rpmadwidth_tx                            : IN STD_LOGIC;
         rpma_doublewidth_tx                      : IN STD_LOGIC;
         rtx_pipe_enable                          : IN STD_LOGIC;
         rindv_tx                                 : IN STD_LOGIC;
         rendec_data_sel_tx                       : IN STD_LOGIC;
         rtxpcsbypass_en                          : IN STD_LOGIC;
         rtxpcsclkpwdn                            : IN STD_LOGIC;
         rauto_speed_ena                          : IN STD_LOGIC;
         rfreq_sel                                : IN STD_LOGIC;
         gen2ngen1                                : IN STD_LOGIC;
         gen2ngen1_bundle                         : IN STD_LOGIC;
         rcid_pattern_tx                          : IN STD_LOGIC;
         rcid_len_tx                              : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         tx_div2_sync_in_centrl                   : IN STD_LOGIC;
         tx_div2_sync_in_quad_up                  : IN STD_LOGIC;
         tx_div2_sync_in_quad_down                : IN STD_LOGIC;
         wr_enable_in_centrl                      : IN STD_LOGIC;
         wr_enable_in_quad_up                     : IN STD_LOGIC;
         wr_enable_in_quad_down                   : IN STD_LOGIC;
         rd_enable_in_centrl                      : IN STD_LOGIC;
         rd_enable_in_quad_up                     : IN STD_LOGIC;
         rd_enable_in_quad_down                   : IN STD_LOGIC;
         fifo_select_in_centrl                    : IN STD_LOGIC;
         fifo_select_in_quad_up                   : IN STD_LOGIC;
         fifo_select_in_quad_down                 : IN STD_LOGIC;
         dis_pc_byte                              : IN STD_LOGIC;
         reset_pc_ptrs                            : IN STD_LOGIC;
         reset_pc_ptrs_in_centrl                  : IN STD_LOGIC;
         reset_pc_ptrs_in_quad_up                 : IN STD_LOGIC;
         reset_pc_ptrs_in_quad_down               : IN STD_LOGIC;
         tx_div2_sync_in_pipe_quad_up             : IN STD_LOGIC;
         tx_div2_sync_in_pipe_quad_down           : IN STD_LOGIC;
         wr_enable_in_pipe_quad_up                : IN STD_LOGIC;
         wr_enable_in_pipe_quad_down              : IN STD_LOGIC;
         rd_enable_in_pipe_quad_up                : IN STD_LOGIC;
         rd_enable_in_pipe_quad_down              : IN STD_LOGIC;
         fifo_select_in_pipe_quad_up              : IN STD_LOGIC;
         fifo_select_in_pipe_quad_down            : IN STD_LOGIC;
         rmaster_tx                               : IN STD_LOGIC;
         rmaster_up_tx                            : IN STD_LOGIC;
         rself_sw_en_tx                           : IN STD_LOGIC;
         rpipeline_bypass_tx                      : IN STD_LOGIC;
         rphfifo_regmode_tx                       : IN STD_LOGIC;
         rtxbitslip_en                            : IN STD_LOGIC;
         tx_div2_sync_out_pipe_up                 : OUT STD_LOGIC;
         fifo_select_out_pipe_up                  : OUT STD_LOGIC;
         wr_enable_out_pipe_up                    : OUT STD_LOGIC;
         rd_enable_out_pipe_up                    : OUT STD_LOGIC;
         tx_div2_sync_out_pipe_down               : OUT STD_LOGIC;
         fifo_select_out_pipe_down                : OUT STD_LOGIC;
         wr_enable_out_pipe_down                  : OUT STD_LOGIC;
         rd_enable_out_pipe_down                  : OUT STD_LOGIC;
         prbs_cid_en                              : IN STD_LOGIC;
         tx_boundary_sel                          : IN STD_LOGIC_VECTOR(4 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_digi_chnl_hip_spt
      PORT (
         rhip_ena                                 : IN STD_LOGIC;
         pcs_rxd_ch                               : IN STD_LOGIC_VECTOR(8 DOWNTO 0);
         pcs_rxvalid                              : IN STD_LOGIC;
         pcs_rxelecidle                           : IN STD_LOGIC;
         pcs_rxstatus_ch                          : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         pcs_phystatus                            : IN STD_LOGIC;
         txpma_local_clk                          : IN STD_LOGIC;
         txd_ch                                   : IN STD_LOGIC_VECTOR(10 DOWNTO 0);
         hip_txd_ch                               : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         txdetectrxloopback                       : IN STD_LOGIC;
         hip_txdetectrxloopback                   : IN STD_LOGIC;
         rxpolarity                               : IN STD_LOGIC;
         hip_rxpolarity                           : IN STD_LOGIC;
         powerdown_ch                             : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         hip_powerdown_ch                         : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         txdeemph                                 : IN STD_LOGIC;
         hip_txdeemph                             : IN STD_LOGIC;
         txmargin_ch                              : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         hip_txmargin_ch                          : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         eidleinfersel_ch                         : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         hip_eidleinfersel_ch                     : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rate                                     : IN STD_LOGIC;
         hip_rate                                 : IN STD_LOGIC;
         hip_txelecidle                           : IN STD_LOGIC;
         rxd_ch                                   : OUT STD_LOGIC_VECTOR(8 DOWNTO 0);
         hip_rxd_ch                               : OUT STD_LOGIC_VECTOR(8 DOWNTO 0);
         rxvalid                                  : OUT STD_LOGIC;
         hip_rxvalid                              : OUT STD_LOGIC;
         rxelecidle                               : OUT STD_LOGIC;
         hip_rxelecidle                           : OUT STD_LOGIC;
         rxstatus_ch                              : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         hip_rxstatus_ch                          : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         phystatus                                : OUT STD_LOGIC;
         hip_phystatus                            : OUT STD_LOGIC;
         hip_tx_clk                               : OUT STD_LOGIC;
         pcs_txd_ch                               : OUT STD_LOGIC_VECTOR(10 DOWNTO 0);
         pcs_txdetectrxloopback                   : OUT STD_LOGIC;
         pcs_rxpolarity                           : OUT STD_LOGIC;
         pcs_powerdown_ch                         : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         pcs_txdeemph                             : OUT STD_LOGIC;
         pcs_txmargin_ch                          : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         pcs_eidleinfersel_ch                     : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         pcs_rate                                 : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pcs_reset
      PORT (
         hard_reset                               : IN STD_LOGIC;
         clk_2_b                                  : IN STD_LOGIC;
         refclk_b_in                              : IN STD_LOGIC;
         scan_mode                                : IN STD_LOGIC;
         rxpcs_rst                                : IN STD_LOGIC;
         txpcs_rst                                : IN STD_LOGIC;
         rxrst_int                                : OUT STD_LOGIC;
         txrst_int                                : OUT STD_LOGIC
      );
   END COMPONENT;
   
   SIGNAL tmp_ctrlenable                       : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL tmp_datain                           : STD_LOGIC_VECTOR(39 DOWNTO 0);
   SIGNAL tmp_dispval                          : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL tmp_forcedisp                        : STD_LOGIC_VECTOR(3 DOWNTO 0);

   constant DPRIO_CHANNEL_INTERFACE_BIT : STD_LOGIC_VECTOR(5 DOWNTO 0) := "000100";
   
   -- new dprio model --
   -- Table1: PCS Per Channel TX Control Register 1 for Channel 0
	constant rforce_disp_TXPCS_IDX_0	: integer := 0;
	constant rrev_loopbk_TXPCS_IDX_0	: integer := 1;
	constant rtxrdclksel_TXPCS_IDX_0	: integer := 2;
	constant rtxwrclksel_TXPCS_IDX_0	: integer := 3;
	constant rfreerun_tx_TXPCS_IDX_0	: integer := 4;
	constant rtxurstpcs_TXPCS_IDX_0	: integer := 5;
	constant reserved_0_TB1_TXPCS_IDX_0	: integer := 6;
	constant rphfifoursttx_TXPCS_IDX_0	: integer := 7;
	constant rphfifopldentx_TXPCS_IDX_0	: integer := 8;
	constant rge_xaui_tx_TXPCS_IDX_0	: integer := 9;
	constant rdwidth_tx_TXPCS_IDX_0	: integer := 10;
	constant rtxfifo_lowlatency_en_TXPCS_IDX_0	: integer := 11;
	constant rib_force_disp_TXPCS_IDX_0	: integer := 12;
	constant rtxfifo_dis_TXPCS_IDX_0	: integer := 13;
	constant rforce_echar_TXPCS_IDX_0	: integer := 14;
	constant rforce_kchar_TXPCS_IDX_0	: integer := 15;
	
	-- Table2: PCS Per Channel TX Control Register 2 for Channel 0
	constant rtxpcsbypass_en_TXPCS_IDX_0	: integer := 16;
	constant rcxpat_chnl_en_TXPCS_IDX_0	: integer := 17;
	constant rcxpat_chnl_en_TXPCS_IDX_1	: integer := 18;
	constant rbist_sel_TXPCS_IDX_0	: integer := 19;
	constant rbist_sel_TXPCS_IDX_1	: integer := 20;
	constant rbisten_tx_TXPCS_IDX_0	: integer := 21;
	constant rprbs_sel_TXPCS_IDX_0	: integer := 22;
	constant rprbs_sel_TXPCS_IDX_1	: integer := 23;
	constant rprbs_sel_TXPCS_IDX_2	: integer := 24;
	constant rprbsen_tx_TXPCS_IDX_0	: integer := 25;
	constant renbitrev_tx_TXPCS_IDX_0	: integer := 26;
	constant renpolinv_tx_TXPCS_IDX_0	: integer := 27;
	constant rensymswap_tx_TXPCS_IDX_0	: integer := 28;
	constant rcascaded_8b10b_en_tx_TXPCS_IDX_0	: integer := 29;
	constant r8b10b_enc_ibm_en_TXPCS_IDX_0	: integer := 30;
	constant rendec_tx_TXPCS_IDX_0	: integer := 31;
	
	-- Table3: PCS Per Channel TX Control Register 3 for Channel 0
	constant reserved_0_TB3_TXPCS_IDX_0	: integer := 32;
	constant rcid_len_tx_TXPCS_IDX_0	: integer := 33;
	constant rcid_len_tx_TXPCS_IDX_1	: integer := 34;
	constant rcid_len_tx_TXPCS_IDX_2	: integer := 35;
	constant rcid_len_tx_TXPCS_IDX_3	: integer := 36;
	constant rcid_len_tx_TXPCS_IDX_4	: integer := 37;
	constant rcid_len_tx_TXPCS_IDX_5	: integer := 38;
	constant rcid_len_tx_TXPCS_IDX_6	: integer := 39;
	constant rcid_len_tx_TXPCS_IDX_7	: integer := 40;
	constant rcid_pattern_tx_TXPCS_IDX_0	: integer := 41;
	constant rtxpcsclkpwdn_TXPCS_IDX_0	: integer := 42;
	constant rtxswing_sel_ena_TXPCS_IDX_0	: integer := 43;
	constant rtx_elec_idle_delay_TXPCS_IDX_0	: integer := 44;
	constant rtx_elec_idle_delay_TXPCS_IDX_1	: integer := 45;
	constant rtx_elec_idle_delay_TXPCS_IDX_2	: integer := 46;
	constant rtx_pipe_enable_TXPCS_IDX_0	: integer := 47;
	
	-- Table4: PCS Per Channel TX Control Register 4 for Channel 0
	constant reserved_0_TB4_TXPCS_IDX_0	: integer := 48;
	constant reserved_0_TB4_TXPCS_IDX_1	: integer := 49;
	constant reserved_0_TB4_TXPCS_IDX_2	: integer := 50;
	constant reserved_0_TB4_TXPCS_IDX_3	: integer := 51;
	constant reserved_0_TB4_TXPCS_IDX_4	: integer := 52;
	constant reserved_0_TB4_TXPCS_IDX_5	: integer := 53;
	constant reserved_0_TB4_TXPCS_IDX_6	: integer := 54;
	constant reserved_0_TB4_TXPCS_IDX_7	: integer := 55;
	constant reserved_0_TB4_TXPCS_IDX_8	: integer := 56;
	constant reserved_0_TB4_TXPCS_IDX_9	: integer := 57;
	constant reserved_0_TB4_TXPCS_IDX_10	: integer := 58;
	constant reserved_0_TB4_TXPCS_IDX_11	: integer := 59;
	constant rtxbitslip_en_TXPCS_IDX_0	: integer := 60;
	constant rphfifo_regmode_tx_TXPCS_IDX_0	: integer := 61;
	constant rpipeline_bypass_tx_TXPCS_IDX_0	: integer := 62;
	constant rself_sw_en_tx_TXPCS_IDX_0	: integer := 63;
	
	-- Existing
	constant rauto_speed_ena_TX_IDX		: integer := 64;
	constant rendec_data_sel_tx_TX_IDX  : integer := 65;
	constant rfreq_sel_TX_IDX           : integer := 66;
	constant rhip_ena_TX_IDX            : integer := 67;
	constant rindv_tx_TX_IDX            : integer := 68;
	constant rphfifo_master_sel_tx_TX_IDX : integer := 69;
	constant rpma_doublewidth_tx_TX_IDX   : integer := 70;
	constant rpmadwidth_tx_TX_IDX         : integer := 71;
	constant rtx_cmu_sel_TX_IDX           : integer := 72;
	constant rmaster_tx_TX_IDX            : integer := 73;
	constant rmaster_up_tx_TX_IDX         : integer := 74;
	
	-- -------------------------------------------------------------------------
	-- DPRIO input CRAM  
	-- -------------------------------------------------------------------------
	-- Existing
	SIGNAL dprioin_is_lane0: STD_LOGIC;
	SIGNAL dprioin_rauto_speed_ena: STD_LOGIC;
	SIGNAL dprioin_rclkcmpinsertpad: STD_LOGIC;         -- rx only ========= pipe ===========    
	SIGNAL dprioin_rendec_data_sel_tx: STD_LOGIC;
	SIGNAL dprioin_rfreq_sel: STD_LOGIC;
	SIGNAL dprioin_rhip_ena: STD_LOGIC;
	SIGNAL dprioin_rindv_tx: STD_LOGIC;
	SIGNAL dprioin_rmaster_tx: STD_LOGIC;
	SIGNAL dprioin_rmaster_up_tx: STD_LOGIC;
	SIGNAL dprioin_rphfifo_master_sel_tx: STD_LOGIC;
	SIGNAL dprioin_rpma_doublewidth_tx: STD_LOGIC;
	SIGNAL dprioin_rpmadwidth_tx: STD_LOGIC;
	SIGNAL dprioin_rrdwidth_rx: STD_LOGIC;              	-- rx only
	SIGNAL dprioin_rrx_detect_bypass: STD_LOGIC;        	-- rx only
	SIGNAL dprioin_rrx_pipe_enable: STD_LOGIC;          	-- rx only
	SIGNAL dprioin_rtx_cmu_sel: STD_LOGIC;                 -- added in 6.1
	SIGNAL dprioin_scan_mode: STD_LOGIC;
	
	-- PCS Per Channel TX Control Register 1 for Channel 0
	SIGNAL dprioin_rforce_disp	: STD_LOGIC;
	SIGNAL dprioin_rrev_loopbk	: STD_LOGIC;
	SIGNAL dprioin_rtxrdclksel	: STD_LOGIC;
	SIGNAL dprioin_rtxwrclksel	: STD_LOGIC;
	SIGNAL dprioin_rfreerun_tx	: STD_LOGIC;
	SIGNAL dprioin_rtxurstpcs	: STD_LOGIC;
	SIGNAL dprioin_reserved_0_TB1	: STD_LOGIC;
	SIGNAL dprioin_rphfifoursttx	: STD_LOGIC;
	SIGNAL dprioin_rphfifopldentx	: STD_LOGIC;
	SIGNAL dprioin_rge_xaui_tx	: STD_LOGIC;
	SIGNAL dprioin_rdwidth_tx	: STD_LOGIC;
	SIGNAL dprioin_rtxfifo_lowlatency_en	: STD_LOGIC;
	SIGNAL dprioin_rib_force_disp	: STD_LOGIC;
	SIGNAL dprioin_rtxfifo_dis	: STD_LOGIC;
	SIGNAL dprioin_rforce_echar	: STD_LOGIC;
	SIGNAL dprioin_rforce_kchar	: STD_LOGIC;
	
	-- PCS Per Channel TX Control Register 2 for Channel 0
	SIGNAL dprioin_rtxpcsbypass_en	: STD_LOGIC;
	SIGNAL dprioin_rcxpat_chnl_en	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL dprioin_rbist_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL dprioin_rbisten_tx	: STD_LOGIC;
	SIGNAL dprioin_rprbs_sel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	SIGNAL dprioin_rprbsen_tx	: STD_LOGIC;
	SIGNAL dprioin_renbitrev_tx	: STD_LOGIC;
	SIGNAL dprioin_renpolinv_tx	: STD_LOGIC;
	SIGNAL dprioin_rensymswap_tx	: STD_LOGIC;
	SIGNAL dprioin_rcascaded_8b10b_en_tx	: STD_LOGIC;
	SIGNAL dprioin_r8b10b_enc_ibm_en	: STD_LOGIC;
	SIGNAL dprioin_rendec_tx	: STD_LOGIC;
	
	-- PCS Per Channel TX Control Register 3 for Channel 0
	SIGNAL dprioin_reserved_0_TB3	: STD_LOGIC;
	SIGNAL dprioin_rcid_len_tx	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	SIGNAL dprioin_rcid_pattern_tx	: STD_LOGIC;
	SIGNAL dprioin_rtxpcsclkpwdn	: STD_LOGIC;
	SIGNAL dprioin_rtxswing_sel_ena	: STD_LOGIC;
	SIGNAL dprioin_rtx_elec_idle_delay	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	SIGNAL dprioin_rtx_pipe_enable	: STD_LOGIC;
	
	-- PCS Per Channel TX Control Register 4 for Channel 0
	SIGNAL dprioin_reserved_0_TB4	: STD_LOGIC_VECTOR(11 DOWNTO 0);
	SIGNAL dprioin_rtxbitslip_en	: STD_LOGIC;
	SIGNAL dprioin_rphfifo_regmode_tx	: STD_LOGIC;
	SIGNAL dprioin_rpipeline_bypass_tx	: STD_LOGIC;
	SIGNAL dprioin_rself_sw_en_tx	: STD_LOGIC;
	
	-- -------------------------------------------------------------------------
	-- Initial CRAM  
	-- -------------------------------------------------------------------------
	-- Existing
    SIGNAL init_is_lane0: STD_LOGIC;
    SIGNAL init_rauto_speed_ena: STD_LOGIC;
    SIGNAL init_rclkcmpinsertpad: STD_LOGIC;             -- rx only ========= pipe ===========    
    SIGNAL init_rendec_data_sel_tx: STD_LOGIC;
    SIGNAL init_rfreq_sel: STD_LOGIC;
    SIGNAL init_rhip_ena: STD_LOGIC;
    SIGNAL init_rindv_tx: STD_LOGIC;
    SIGNAL init_rmaster_tx: STD_LOGIC;
    SIGNAL init_rmaster_up_tx: STD_LOGIC;
    SIGNAL init_rphfifo_master_sel_tx: STD_LOGIC;
    SIGNAL init_rpma_doublewidth_tx: STD_LOGIC;
    SIGNAL init_rpmadwidth_tx: STD_LOGIC;
    SIGNAL init_rrdwidth_rx: STD_LOGIC;                  -- rx only
    SIGNAL init_rrx_detect_bypass: STD_LOGIC;            -- rx only
    SIGNAL init_rrx_pipe_enable: STD_LOGIC;              -- rx only
    SIGNAL init_rtx_cmu_sel: STD_LOGIC;          		 -- added in 6.1
    SIGNAL init_scan_mode: STD_LOGIC;
   
	-- PCS Per Channel TX Control Register 1 for Channel 0
	SIGNAL init_rforce_disp	: STD_LOGIC;
	SIGNAL init_rrev_loopbk	: STD_LOGIC;
	SIGNAL init_rtxrdclksel	: STD_LOGIC;
	SIGNAL init_rtxwrclksel	: STD_LOGIC;
	SIGNAL init_rfreerun_tx	: STD_LOGIC;
	SIGNAL init_rtxurstpcs	: STD_LOGIC;
	SIGNAL init_reserved_0_TB1	: STD_LOGIC;
	SIGNAL init_rphfifoursttx	: STD_LOGIC;
	SIGNAL init_rphfifopldentx	: STD_LOGIC;
	SIGNAL init_rge_xaui_tx	: STD_LOGIC;
	SIGNAL init_rdwidth_tx	: STD_LOGIC;
	SIGNAL init_rtxfifo_lowlatency_en	: STD_LOGIC;
	SIGNAL init_rib_force_disp	: STD_LOGIC;
	SIGNAL init_rtxfifo_dis	: STD_LOGIC;
	SIGNAL init_rforce_echar	: STD_LOGIC;
	SIGNAL init_rforce_kchar	: STD_LOGIC;
	
	-- PCS Per Channel TX Control Register 2 for Channel 0
	SIGNAL init_rtxpcsbypass_en	: STD_LOGIC;
	SIGNAL init_rcxpat_chnl_en	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL init_rbist_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL init_rbisten_tx	: STD_LOGIC;
	SIGNAL init_rprbs_sel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	SIGNAL init_rprbsen_tx	: STD_LOGIC;
	SIGNAL init_renbitrev_tx	: STD_LOGIC;
	SIGNAL init_renpolinv_tx	: STD_LOGIC;
	SIGNAL init_rensymswap_tx	: STD_LOGIC;
	SIGNAL init_rcascaded_8b10b_en_tx	: STD_LOGIC;
	SIGNAL init_r8b10b_enc_ibm_en	: STD_LOGIC;
	SIGNAL init_rendec_tx	: STD_LOGIC;
	
	-- PCS Per Channel TX Control Register 3 for Channel 0
	SIGNAL init_reserved_0_TB3	: STD_LOGIC;
	SIGNAL init_rcid_len_tx	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	SIGNAL init_rcid_pattern_tx	: STD_LOGIC;
	SIGNAL init_rtxpcsclkpwdn	: STD_LOGIC;
	SIGNAL init_rtxswing_sel_ena	: STD_LOGIC;
	SIGNAL init_rtx_elec_idle_delay	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	SIGNAL init_rtx_pipe_enable	: STD_LOGIC;
	
	-- PCS Per Channel TX Control Register 4 for Channel 0
	SIGNAL init_reserved_0_TB4	: STD_LOGIC_VECTOR(11 DOWNTO 0);
	SIGNAL init_rtxbitslip_en	: STD_LOGIC;
	SIGNAL init_rphfifo_regmode_tx	: STD_LOGIC;
	SIGNAL init_rpipeline_bypass_tx	: STD_LOGIC;
	SIGNAL init_rself_sw_en_tx	: STD_LOGIC;
	
	-- -------------------------------------------------------------------------
	-- CRAM  
	-- -------------------------------------------------------------------------
	-- Existing
	SIGNAL cram_is_lane0: STD_LOGIC;
	SIGNAL cram_rauto_speed_ena: STD_LOGIC;
	SIGNAL cram_rclkcmpinsertpad: STD_LOGIC;             -- rx only ========= pipe ===========    
	SIGNAL cram_rendec_data_sel_tx: STD_LOGIC;
	SIGNAL cram_rfreq_sel: STD_LOGIC;
	SIGNAL cram_rhip_ena: STD_LOGIC;
	SIGNAL cram_rindv_tx: STD_LOGIC;
	SIGNAL cram_rmaster_tx: STD_LOGIC;
	SIGNAL cram_rmaster_up_tx: STD_LOGIC;
	SIGNAL cram_rphfifo_master_sel_tx: STD_LOGIC;
	SIGNAL cram_rpma_doublewidth_tx: STD_LOGIC;
	SIGNAL cram_rpmadwidth_tx: STD_LOGIC;
	SIGNAL cram_rrdwidth_rx: STD_LOGIC;                  -- rx only
	SIGNAL cram_rrx_detect_bypass: STD_LOGIC;            -- rx only
	SIGNAL cram_rrx_pipe_enable: STD_LOGIC;              -- rx only
	SIGNAL cram_rtx_cmu_sel: STD_LOGIC;          		  -- added in 6.1
	SIGNAL cram_scan_mode: STD_LOGIC;

	-- PCS Per Channel TX Control Register 1 for Channel 0
	SIGNAL cram_rforce_disp	: STD_LOGIC;
	SIGNAL cram_rrev_loopbk	: STD_LOGIC;
	SIGNAL cram_rtxrdclksel	: STD_LOGIC;
	SIGNAL cram_rtxwrclksel	: STD_LOGIC;
	SIGNAL cram_rfreerun_tx	: STD_LOGIC;
	SIGNAL cram_rtxurstpcs	: STD_LOGIC;
	SIGNAL cram_reserved_0_TB1	: STD_LOGIC;
	SIGNAL cram_rphfifoursttx	: STD_LOGIC;
	SIGNAL cram_rphfifopldentx	: STD_LOGIC;
	SIGNAL cram_rge_xaui_tx	: STD_LOGIC;
	SIGNAL cram_rdwidth_tx	: STD_LOGIC;
	SIGNAL cram_rtxfifo_lowlatency_en	: STD_LOGIC;
	SIGNAL cram_rib_force_disp	: STD_LOGIC;
	SIGNAL cram_rtxfifo_dis	: STD_LOGIC;
	SIGNAL cram_rforce_echar	: STD_LOGIC;
	SIGNAL cram_rforce_kchar	: STD_LOGIC;
	
	-- PCS Per Channel TX Control Register 2 for Channel 0
	SIGNAL cram_rtxpcsbypass_en	: STD_LOGIC;
	SIGNAL cram_rcxpat_chnl_en	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL cram_rbist_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL cram_rbisten_tx	: STD_LOGIC;
	SIGNAL cram_rprbs_sel	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	SIGNAL cram_rprbsen_tx	: STD_LOGIC;
	SIGNAL cram_renbitrev_tx	: STD_LOGIC;
	SIGNAL cram_renpolinv_tx	: STD_LOGIC;
	SIGNAL cram_rensymswap_tx	: STD_LOGIC;
	SIGNAL cram_rcascaded_8b10b_en_tx	: STD_LOGIC;
	SIGNAL cram_r8b10b_enc_ibm_en	: STD_LOGIC;
	SIGNAL cram_rendec_tx	: STD_LOGIC;
	
	-- PCS Per Channel TX Control Register 3 for Channel 0
	SIGNAL cram_reserved_0_TB3	: STD_LOGIC;
	SIGNAL cram_rcid_len_tx	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	SIGNAL cram_rcid_pattern_tx	: STD_LOGIC;
	SIGNAL cram_rtxpcsclkpwdn	: STD_LOGIC;
	SIGNAL cram_rtxswing_sel_ena	: STD_LOGIC;
	SIGNAL cram_rtx_elec_idle_delay	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	SIGNAL cram_rtx_pipe_enable	: STD_LOGIC;
	
	-- PCS Per Channel TX Control Register 4 for Channel 0
	SIGNAL cram_reserved_0_TB4	: STD_LOGIC_VECTOR(11 DOWNTO 0);
	SIGNAL cram_rtxbitslip_en	: STD_LOGIC;
	SIGNAL cram_rphfifo_regmode_tx	: STD_LOGIC;
	SIGNAL cram_rpipeline_bypass_tx	: STD_LOGIC;
	SIGNAL cram_rself_sw_en_tx	: STD_LOGIC;
	
	SIGNAL dpriodisable_in           : STD_LOGIC;
	
	----- new dprio end   
   
   --///////////////////////////////////////////////////////////////////////////////
   -- sub-block interface: pcs_reset     -----------------------------------------//
   --///////////////////////////////////////////////////////////////////////////////
   
   SIGNAL pr_in_hard_reset                     : STD_LOGIC;
   SIGNAL pr_in_clk_2_b                        : STD_LOGIC;
   SIGNAL pr_in_refclk_b_in                    : STD_LOGIC;
   SIGNAL pr_in_scan_mode                      : STD_LOGIC;
   SIGNAL pr_in_rxpcs_rst                      : STD_LOGIC;
   SIGNAL pr_in_txpcs_rst                      : STD_LOGIC;
   SIGNAL pr_out_txrst_int                     : STD_LOGIC;
   
   --///////////////////////////////////////////////////////////////////////////////
   -- sub-block interface: chnl_hip_spt  -----------------------------------------//
   --///////////////////////////////////////////////////////////////////////////////
   
   SIGNAL hs_in_eidleinfersel_ch               : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_in_hip_eidleinfersel_ch           : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_in_hip_powerdown_ch               : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL hs_in_hip_rate                       : STD_LOGIC;
   SIGNAL hs_in_hip_rxpolarity                 : STD_LOGIC;
   SIGNAL hs_in_hip_txd_ch                     : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL hs_in_hip_txdeemph                   : STD_LOGIC;
   SIGNAL hs_in_hip_txdetectrxloopback         : STD_LOGIC;
   SIGNAL hs_in_hip_txelecidle                 : STD_LOGIC;
   SIGNAL hs_in_hip_txmargin_ch                : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_in_pcs_phystatus                  : STD_LOGIC;
   SIGNAL hs_in_pcs_rxd_ch                     : STD_LOGIC_VECTOR(8 DOWNTO 0);
   SIGNAL hs_in_pcs_rxelecidle                 : STD_LOGIC;
   SIGNAL hs_in_pcs_rxstatus_ch                : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_in_pcs_rxvalid                    : STD_LOGIC;
   SIGNAL hs_in_powerdown_ch                   : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL hs_in_rate                           : STD_LOGIC;
   SIGNAL hs_in_rhip_ena                       : STD_LOGIC;
   SIGNAL hs_in_rxpolarity                     : STD_LOGIC;
   SIGNAL hs_in_txd_ch                         : STD_LOGIC_VECTOR(10 DOWNTO 0);
   SIGNAL hs_in_txdeemph                       : STD_LOGIC;
   SIGNAL hs_in_txdetectrxloopback             : STD_LOGIC;
   SIGNAL hs_in_txmargin_ch                    : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_in_txpma_local_clk                : STD_LOGIC;
   
   SIGNAL hs_out_hip_phystatus                 : STD_LOGIC;
   SIGNAL hs_out_hip_rxd_ch                    : STD_LOGIC_VECTOR(8 DOWNTO 0);
   SIGNAL hs_out_hip_rxelecidle                : STD_LOGIC;
   SIGNAL hs_out_hip_rxstatus_ch               : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_out_hip_rxvalid                   : STD_LOGIC;
   SIGNAL hs_out_hip_tx_clk                    : STD_LOGIC;
   SIGNAL hs_out_pcs_eidleinfersel_ch          : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_out_pcs_powerdown_ch              : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL hs_out_pcs_rate                      : STD_LOGIC;
   SIGNAL hs_out_pcs_rxpolarity                : STD_LOGIC;
   SIGNAL hs_out_pcs_txd_ch                    : STD_LOGIC_VECTOR(10 DOWNTO 0);
   SIGNAL hs_out_pcs_txdeemph                  : STD_LOGIC;
   SIGNAL hs_out_pcs_txdetectrxloopback        : STD_LOGIC;
   SIGNAL hs_out_pcs_txmargin_ch               : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_out_phystatus                     : STD_LOGIC;
   SIGNAL hs_out_rxd_ch                        : STD_LOGIC_VECTOR(8 DOWNTO 0);
   SIGNAL hs_out_rxelecidle                    : STD_LOGIC;
   SIGNAL hs_out_rxstatus_ch                   : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_out_rxvalid                       : STD_LOGIC;
   
   --///////////////////////////////////////////////////////////////////////////////
   -- sub-block interface: pipe_interface  ---------------------------------------//
   --///////////////////////////////////////////////////////////////////////////////
   
   -- inputs
   SIGNAL pi_in_pipe_tx_clk                    : STD_LOGIC;
   SIGNAL pi_in_powerdown                      : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL pi_in_refclk_b                       : STD_LOGIC;
   SIGNAL pi_in_refclk_b_reset_n               : STD_LOGIC;		
   SIGNAL pi_in_revloopback                    : STD_LOGIC;
   SIGNAL pi_in_state_transition_done          : STD_LOGIC;
   SIGNAL pi_in_tx_elec_idle_comp              : STD_LOGIC;
   SIGNAL pi_in_tx_pipe_reset_n                : STD_LOGIC;
   SIGNAL pi_in_txd_ch                         : STD_LOGIC_VECTOR(43 DOWNTO 0);
   SIGNAL pi_in_txd_ch_dprio                   : STD_LOGIC_VECTOR(43 DOWNTO 0);		
   SIGNAL pi_in_txdetectrxloopback             : STD_LOGIC;
   SIGNAL pi_in_txelecidle                     : STD_LOGIC;
   SIGNAL pi_in_txd_ch_tmp                     : STD_LOGIC_VECTOR(43 DOWNTO 0);		-- before interleaving in dwidth_single PMA
   
   -- outputs
   SIGNAL pi_out_powerstate                    : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- to top - both cmu and rx
   SIGNAL pi_out_rev_loopbk                    : STD_LOGIC;		-- to TD
   SIGNAL pi_out_tx_elec_idle                  : STD_LOGIC;		-- to tx PMA - TX sending electrical idle
   SIGNAL pi_out_txd                           : STD_LOGIC_VECTOR(43 DOWNTO 0);
   SIGNAL pi_out_txdetectrx                    : STD_LOGIC;		-- to tx PMA - RX_DET
   
   -- new input in STRATIXIV - ww26.5 =====================================
   -- from PLD
   SIGNAL pi_in_txdeemph                       : STD_LOGIC;
   SIGNAL pi_in_txmargin                       : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL pi_in_txswing                        : STD_LOGIC;
   
   -- new output in STRATIXIV - ww26.5 ====================================
   -- exposured to digi_top
   SIGNAL pi_out_txdeemph_int                  : STD_LOGIC;
   SIGNAL pi_out_txmargin_int                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL pi_out_txswing_int                   : STD_LOGIC;
   
   --///////////////////////////////////////////////////////////////////////////////
   -- sub-block interface: tx digital  -------------------------------------------//
   --///////////////////////////////////////////////////////////////////////////////
   
   -- inputs
   SIGNAL td_in_phfifourst_tx                  : STD_LOGIC;
   SIGNAL td_in_pld_tx_clk                     : STD_LOGIC;
   SIGNAL td_in_polinv_tx                      : STD_LOGIC;
   SIGNAL td_in_rddisable_tx                   : STD_LOGIC;
   SIGNAL td_in_refclk_pma                     : STD_LOGIC;
   SIGNAL td_in_rev_loop_data                  : STD_LOGIC_VECTOR(19 DOWNTO 0);
   SIGNAL td_in_rev_loopbk                     : STD_LOGIC;
   SIGNAL td_in_tx_ctl_ts                      : STD_LOGIC;
   SIGNAL td_in_tx_data_ts                     : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL td_in_txd                            : STD_LOGIC_VECTOR(43 DOWNTO 0);
   SIGNAL td_in_txfifo_shared_sig_in_ch0       : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL td_in_txfifo_shared_sig_in_q0_ch0    : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL td_in_txpcs_rst                      : STD_LOGIC;
   SIGNAL td_in_txpma_local_clk                : STD_LOGIC;
   SIGNAL td_in_wrenable_tx                    : STD_LOGIC;
   
   -- new input in STRATIXIV - ww26.5 ======================================
   
   -- freeze pointer for TX/RX phase comp FIFO during freq negotiation
   -- to tx_ctrl from rx_digi (auto_speed_neg sub-block) 
   SIGNAL td_in_freeze_ptr                     : STD_LOGIC;
   -- to tx_ctrl from TX PMA local clock divider 
   SIGNAL td_in_gen2ngen1                      : STD_LOGIC;
   -- to tx_ctrl from central clock divider 
   SIGNAL td_in_gen2ngen1_bundle               : STD_LOGIC;
   -- to tx_ctrl from PLD (RX polarity inversion dynamic control)
   --       paired with polinv_tx
   -- path: polinv_rx (pld) -> tx_digi (tx_ctrl after encoder) ->
   --    (just a simple wire in tx_ctrl so leaving it out of tx)
   --       rx_pipe (mux with rxpolarity) -> rx_digi (wordalign and decoder)
   SIGNAL td_in_polinv_rx                      : STD_LOGIC;
   -- to tx_ctrl from PLD
   -- generating powerdown_int output feeding both rx_pipe and tx_pipe
   SIGNAL td_in_powerdown                      : STD_LOGIC_VECTOR(1 DOWNTO 0);
   -- to tx_ctrl from quad pcs top
   -- generating rate_int output feeding rx_digi (auto_speed_neg)
   SIGNAL td_in_rate                           : STD_LOGIC;
   -- to tx_ctrl from quad pcs top
   -- generating revloopback_int output feeding tx_pipe
   SIGNAL td_in_revloopback                    : STD_LOGIC;
   -- to tx_ctrl from quad pcs top (no functionality change)
   -- path: rxpolarity (pld) -> tx_digi (tx_ctrl)->
   --       rx_pipe (muxing with polinv_rx) --> rx_digi
   SIGNAL td_in_rxpolarity                     : STD_LOGIC;
   -- to tx_ctrl from quad pcs top
   --    (just a simple wire in tx_ctrl so leaving it out of tx)
   -- generating txdetectrxloopback_int output feeding tx_pipe
   SIGNAL td_in_txdetectrxloopback             : STD_LOGIC;
   
   -- new output in STRATIXIV - ww26.5 ===================================
   -- to rx_digi muxed with rxpolarity_int
   SIGNAL td_out_polinv_rx_int                 : STD_LOGIC;
   -- to rx_pipe and tx_pipe
   SIGNAL td_out_powerdown_int                 : STD_LOGIC_VECTOR(1 DOWNTO 0);
   -- to tx_pipe
   SIGNAL td_out_revloopback_int               : STD_LOGIC;
   -- to rx_digi (mux with polinv_rx_int)
   SIGNAL td_out_rxpolarity_int                : STD_LOGIC;
   -- to tx_pipe
   SIGNAL td_out_txdetectrxloopback_int        : STD_LOGIC;
   
   -- outputs
   SIGNAL td_out_empty_tx                      : STD_LOGIC;
   SIGNAL td_out_encoder_testbus               : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL td_out_full_tx                       : STD_LOGIC;
   SIGNAL td_out_pudr                          : STD_LOGIC_VECTOR(19 DOWNTO 0);
   SIGNAL td_out_rd_enable_sync                : STD_LOGIC;
   SIGNAL td_out_refclk_b                      : STD_LOGIC;
   SIGNAL td_out_tx_clk_out                    : STD_LOGIC;
   SIGNAL td_out_tx_ctl_tc                     : STD_LOGIC;
   SIGNAL td_out_tx_ctrl_testbus               : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL td_out_tx_data_tc                    : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL td_out_tx_pipe_clk                   : STD_LOGIC;
   SIGNAL td_out_tx_pipe_electidle             : STD_LOGIC;
   SIGNAL td_out_tx_pipe_soft_reset            : STD_LOGIC;
   SIGNAL td_out_txfifo_shared_sig_out         : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL td_out_txlp20b                       : STD_LOGIC_VECTOR(19 DOWNTO 0);
   
   -- new ports in ww47 --------------------------------------------------
   SIGNAL td_in_prbs_cid_en                    : STD_LOGIC;		--PRBS-CID dynamic signal
   SIGNAL td_in_tx_boundary_sel                : STD_LOGIC_VECTOR(4 DOWNTO 0);
   
   -- new signal inputs for bundling
   SIGNAL td_in_tx_div2_sync_in_centrl         : STD_LOGIC;
   SIGNAL td_in_tx_div2_sync_in_quad_up        : STD_LOGIC;
   SIGNAL td_in_tx_div2_sync_in_quad_down      : STD_LOGIC;
   SIGNAL td_in_wr_enable_in_centrl            : STD_LOGIC;
   SIGNAL td_in_wr_enable_in_quad_up           : STD_LOGIC;
   SIGNAL td_in_wr_enable_in_quad_down         : STD_LOGIC;
   SIGNAL td_in_rd_enable_in_centrl            : STD_LOGIC;
   SIGNAL td_in_rd_enable_in_quad_up           : STD_LOGIC;
   SIGNAL td_in_rd_enable_in_quad_down         : STD_LOGIC;
   SIGNAL td_in_fifo_select_in_centrl          : STD_LOGIC;
   SIGNAL td_in_fifo_select_in_quad_up         : STD_LOGIC;
   SIGNAL td_in_fifo_select_in_quad_down       : STD_LOGIC;
   SIGNAL td_in_reset_pc_ptrs                  : STD_LOGIC;
   SIGNAL td_in_reset_pc_ptrs_in_centrl        : STD_LOGIC;
   SIGNAL td_in_reset_pc_ptrs_in_quad_up       : STD_LOGIC;
   SIGNAL td_in_reset_pc_ptrs_in_quad_down     : STD_LOGIC;
   
   SIGNAL td_in_tx_div2_sync_in_pipe_quad_up   : STD_LOGIC;
   SIGNAL td_in_tx_div2_sync_in_pipe_quad_down : STD_LOGIC;
   SIGNAL td_in_wr_enable_in_pipe_quad_up      : STD_LOGIC;
   SIGNAL td_in_wr_enable_in_pipe_quad_down    : STD_LOGIC;
   SIGNAL td_in_rd_enable_in_pipe_quad_up      : STD_LOGIC;
   SIGNAL td_in_rd_enable_in_pipe_quad_down    : STD_LOGIC;
   SIGNAL td_in_fifo_select_in_pipe_quad_up    : STD_LOGIC;
   SIGNAL td_in_fifo_select_in_pipe_quad_down  : STD_LOGIC;
   
   SIGNAL td_in_dis_pc_byte                    : STD_LOGIC;
   
   -- new outputs for bundling and auto speed
   SIGNAL td_out_tx_div2_sync_out_pipe         : STD_LOGIC;
   SIGNAL td_out_fifo_select_out_pipe          : STD_LOGIC;
   SIGNAL td_out_wr_enable_out_pipe            : STD_LOGIC;
   SIGNAL td_out_rd_enable_out_pipe            : STD_LOGIC;
   -- ww47 new ports end ---------------------------------------------------------
   
   -- new ports in ww12 ----------------------------------------------------------
   -- push through TX Phase Comp FIFO
   SIGNAL td_in_txswing                        : STD_LOGIC;
   SIGNAL td_in_pcs_txdeemph                   : STD_LOGIC;
   SIGNAL td_in_pcs_txmargin                   : STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- RX PIPE interface signals
   SIGNAL td_in_eidleinfersel                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- push through TX Phase Comp FIFO
   SIGNAL td_out_phfifo_txswing                : STD_LOGIC;
   SIGNAL td_out_phfifo_txdeemph               : STD_LOGIC;
   SIGNAL td_out_phfifo_txmargin               : STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- RX PIPE interface signals
   SIGNAL td_out_gray_eidleinfersel            : STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- new outputs for bundling and auto speed
   -- splitting _out_pipe into _up and _down
   SIGNAL td_out_tx_div2_sync_out_pipe_up      : STD_LOGIC;
   SIGNAL td_out_fifo_select_out_pipe_up       : STD_LOGIC;
   SIGNAL td_out_wr_enable_out_pipe_up         : STD_LOGIC;
   SIGNAL td_out_rd_enable_out_pipe_up         : STD_LOGIC;
   SIGNAL td_out_tx_div2_sync_out_pipe_down    : STD_LOGIC;
   SIGNAL td_out_fifo_select_out_pipe_down     : STD_LOGIC;
   SIGNAL td_out_wr_enable_out_pipe_down       : STD_LOGIC;
   SIGNAL td_out_rd_enable_out_pipe_down       : STD_LOGIC;
   -- ww12 new ports end ---------------------------------------------------------
   
   --///////////////////////////////////////////////////////////////////////////////
   -- Internal Variables  --------------------------------------------------------//
   --///////////////////////////////////////////////////////////////////////////////
   SIGNAL i                                    : INTEGER;
   SIGNAL j                                    : INTEGER;
   SIGNAL rxdet_fixclk_reg                     : STD_LOGIC;
   
   --///////////////////////////////////////////////////////////////////////////////
   -- Timing - INPUT BUFFERS  ----------------------------------------------------//
   --///////////////////////////////////////////////////////////////////////////////
   
   SIGNAL rxrst_int_wire                       : STD_LOGIC;
   
   --ww47 new inputs
   SIGNAL bitslipboundaryselect_in             : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL forceelecidle_in                     : STD_LOGIC;
   SIGNAL hipdatain_in                         : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL hipdetectrxloop_in                   : STD_LOGIC;
   SIGNAL hipforceelecidle_in                  : STD_LOGIC;
   SIGNAL hippowerdn_in                        : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL hiptxdeemph_in                       : STD_LOGIC;
   SIGNAL hiptxmargin_in                       : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL iqpphfifoxnbytesel_in                : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL iqpphfifoxnrdclk_in                  : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL iqpphfifoxnrdenable_in               : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL iqpphfifoxnwrenable_in               : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL phfifobyteserdisable_in              : STD_LOGIC;
   SIGNAL phfifoptrsreset_in                   : STD_LOGIC;
   SIGNAL phfifoxnbytesel_in                   : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL phfifoxnptrsreset_in                 : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL phfifoxnrdclk_in                     : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL phfifoxnrdenable_in                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL phfifoxnwrenable_in                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL prbscidenable_in                     : STD_LOGIC;
   
   -- ww12.08 inputs
   SIGNAL elecidleinfersel_in                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hipelecidleinfersel_in               : STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   --///////////////////////////////////////////////////////////////////////////////
   -- TIMING -- TCO/TSU/HOLD                                                      //
   --///////////////////////////////////////////////////////////////////////////////
   
   --///////////////////////////////////////////////////////////////////////////////
   -- dprio outputs
   --///////////////////////////////////////////////////////////////////////////////
   
   SIGNAL dprioin_in                           : STD_LOGIC_VECTOR(149 DOWNTO 0);
        
   -- PCS - disabled with mpcs_dpriodisable - enable case by case
   SIGNAL mpcs_dpriodisable                    : STD_LOGIC;
   -- X-HDL generated signals

   SIGNAL xhdl0 : STD_LOGIC_VECTOR(1 DOWNTO 0);
BEGIN
          
      ------------------------
      --  Wire Delay Block --
      ------------------------
      WireDelay : BLOCK
      BEGIN
       bits_phfifoxnbytesel : FOR i in phfifoxnbytesel'RANGE GENERATE
           VitalWireDelay (phfifoxnbytesel_ipd(i),phfifoxnbytesel(i), tipd_phfifoxnbytesel(i));
       END GENERATE;
       bits_dispval : FOR i in dispval'RANGE GENERATE
           VitalWireDelay (dispval_ipd(i),dispval(i), tipd_dispval(i));
       END GENERATE;
           VitalWireDelay (phfifoxnbottomwrenable_ipd,phfifoxnbottomwrenable, tipd_phfifoxnbottomwrenable);
           VitalWireDelay (phfifoxntopwrenable_ipd,phfifoxntopwrenable, tipd_phfifoxntopwrenable);
           VitalWireDelay (phfifoptrsreset_ipd,phfifoptrsreset, tipd_phfifoptrsreset);
       bits_phfifoxnptrsreset : FOR i in phfifoxnptrsreset'RANGE GENERATE
           VitalWireDelay (phfifoxnptrsreset_ipd(i),phfifoxnptrsreset(i), tipd_phfifoxnptrsreset(i));
       END GENERATE;
       bits_forcedisp : FOR i in forcedisp'RANGE GENERATE
           VitalWireDelay (forcedisp_ipd(i),forcedisp(i), tipd_forcedisp(i));
       END GENERATE;
       bits_hiptxmargin : FOR i in hiptxmargin'RANGE GENERATE
           VitalWireDelay (hiptxmargin_ipd(i),hiptxmargin(i), tipd_hiptxmargin(i));
       END GENERATE;
       bits_iqpphfifoxnwrenable : FOR i in iqpphfifoxnwrenable'RANGE GENERATE
           VitalWireDelay (iqpphfifoxnwrenable_ipd(i),iqpphfifoxnwrenable(i), tipd_iqpphfifoxnwrenable(i));
       END GENERATE;
           VitalWireDelay (phfiforddisable_ipd,phfiforddisable, tipd_phfiforddisable);
       bits_phfifoxnrdenable : FOR i in phfifoxnrdenable'RANGE GENERATE
           VitalWireDelay (phfifoxnrdenable_ipd(i),phfifoxnrdenable(i), tipd_phfifoxnrdenable(i));
       END GENERATE;
       bits_powerdn : FOR i in powerdn'RANGE GENERATE
           VitalWireDelay (powerdn_ipd(i),powerdn(i), tipd_powerdn(i));
       END GENERATE;
           VitalWireDelay (rateswitchisdone_ipd,rateswitchisdone, tipd_rateswitchisdone);
           VitalWireDelay (phfifoxntopbytesel_ipd,phfifoxntopbytesel, tipd_phfifoxntopbytesel);
       bits_ctrlenable : FOR i in ctrlenable'RANGE GENERATE
           VitalWireDelay (ctrlenable_ipd(i),ctrlenable(i), tipd_ctrlenable(i));
       END GENERATE;
           VitalWireDelay (phfifoxntoprdclk_ipd,phfifoxntoprdclk, tipd_phfifoxntoprdclk);
           VitalWireDelay (hiptxdeemph_ipd,hiptxdeemph, tipd_hiptxdeemph);
           VitalWireDelay (freezptr_ipd,freezptr, tipd_freezptr);
           VitalWireDelay (refclk_ipd,refclk, tipd_refclk);
           VitalWireDelay (phfifox4bytesel_ipd,phfifox4bytesel, tipd_phfifox4bytesel);
           VitalWireDelay (rateswitchxndone_ipd,rateswitchxndone, tipd_rateswitchxndone);
           VitalWireDelay (forcedispcompliance_ipd,forcedispcompliance, tipd_forcedispcompliance);
       bits_datainfull : FOR i in datainfull'RANGE GENERATE
           VitalWireDelay (datainfull_ipd(i),datainfull(i), tipd_datainfull(i));
       END GENERATE;
           VitalWireDelay (phfifox4rdclk_ipd,phfifox4rdclk, tipd_phfifox4rdclk);
           VitalWireDelay (phfiforeset_ipd,phfiforeset, tipd_phfiforeset);
       bits_dprioin : FOR i in dprioin'RANGE GENERATE
           VitalWireDelay (dprioin_ipd(i),dprioin(i), tipd_dprioin(i));
       END GENERATE;
           VitalWireDelay (coreclk_ipd,coreclk, tipd_coreclk);
           VitalWireDelay (pipestatetransdone_ipd,pipestatetransdone, tipd_pipestatetransdone);
           VitalWireDelay (rateswitch_ipd,rateswitch, tipd_rateswitch);
           VitalWireDelay (hipforceelecidle_ipd,hipforceelecidle, tipd_hipforceelecidle);
           VitalWireDelay (phfifox4rdenable_ipd,phfifox4rdenable, tipd_phfifox4rdenable);
           VitalWireDelay (phfifowrenable_ipd,phfifowrenable, tipd_phfifowrenable);
       bits_datain : FOR i in datain'RANGE GENERATE
           VitalWireDelay (datain_ipd(i),datain(i), tipd_datain(i));
       END GENERATE;
           VitalWireDelay (enrevparallellpbk_ipd,enrevparallellpbk, tipd_enrevparallellpbk);
           VitalWireDelay (forceelecidle_ipd,forceelecidle, tipd_forceelecidle);
       bits_phfifoxnrdclk : FOR i in phfifoxnrdclk'RANGE GENERATE
           VitalWireDelay (phfifoxnrdclk_ipd(i),phfifoxnrdclk(i), tipd_phfifoxnrdclk(i));
       END GENERATE;
           VitalWireDelay (pipetxswing_ipd,pipetxswing, tipd_pipetxswing);
       bits_pipetxmargin : FOR i in pipetxmargin'RANGE GENERATE
           VitalWireDelay (pipetxmargin_ipd(i),pipetxmargin(i), tipd_pipetxmargin(i));
       END GENERATE;
           VitalWireDelay (phfifox4wrenable_ipd,phfifox4wrenable, tipd_phfifox4wrenable);
           VitalWireDelay (pipetxdeemph_ipd,pipetxdeemph, tipd_pipetxdeemph);
       bits_bitslipboundaryselect : FOR i in bitslipboundaryselect'RANGE GENERATE
           VitalWireDelay (bitslipboundaryselect_ipd(i),bitslipboundaryselect(i), tipd_bitslipboundaryselect(i));
       END GENERATE;
           VitalWireDelay (phfifobyteserdisable_ipd,phfifobyteserdisable, tipd_phfifobyteserdisable);
           VitalWireDelay (dpriodisable_ipd,dpriodisable, tipd_dpriodisable);
           VitalWireDelay (phfifoxnbottomrdclk_ipd,phfifoxnbottomrdclk, tipd_phfifoxnbottomrdclk);
           VitalWireDelay (phfifoxnbottomrdenable_ipd,phfifoxnbottomrdenable, tipd_phfifoxnbottomrdenable);
       bits_hippowerdn : FOR i in hippowerdn'RANGE GENERATE
           VitalWireDelay (hippowerdn_ipd(i),hippowerdn(i), tipd_hippowerdn(i));
       END GENERATE;
           VitalWireDelay (xgmctrl_ipd,xgmctrl, tipd_xgmctrl);
           VitalWireDelay (invpol_ipd,invpol, tipd_invpol);
           VitalWireDelay (hipdetectrxloop_ipd,hipdetectrxloop, tipd_hipdetectrxloop);
           VitalWireDelay (localrefclk_ipd,localrefclk, tipd_localrefclk);
       bits_revparallelfdbk : FOR i in revparallelfdbk'RANGE GENERATE
           VitalWireDelay (revparallelfdbk_ipd(i),revparallelfdbk(i), tipd_revparallelfdbk(i));
       END GENERATE;
       bits_iqpphfifoxnrdenable : FOR i in iqpphfifoxnrdenable'RANGE GENERATE
           VitalWireDelay (iqpphfifoxnrdenable_ipd(i),iqpphfifoxnrdenable(i), tipd_iqpphfifoxnrdenable(i));
       END GENERATE;
           VitalWireDelay (prbscidenable_ipd,prbscidenable, tipd_prbscidenable);
           VitalWireDelay (digitalreset_ipd,digitalreset, tipd_digitalreset);
       bits_iqpphfifoxnbytesel : FOR i in iqpphfifoxnbytesel'RANGE GENERATE
           VitalWireDelay (iqpphfifoxnbytesel_ipd(i),iqpphfifoxnbytesel(i), tipd_iqpphfifoxnbytesel(i));
       END GENERATE;
       bits_iqpphfifoxnrdclk : FOR i in iqpphfifoxnrdclk'RANGE GENERATE
           VitalWireDelay (iqpphfifoxnrdclk_ipd(i),iqpphfifoxnrdclk(i), tipd_iqpphfifoxnrdclk(i));
       END GENERATE;
       bits_phfifoxnwrenable : FOR i in phfifoxnwrenable'RANGE GENERATE
           VitalWireDelay (phfifoxnwrenable_ipd(i),phfifoxnwrenable(i), tipd_phfifoxnwrenable(i));
       END GENERATE;
           VitalWireDelay (quadreset_ipd,quadreset, tipd_quadreset);
       bits_xgmdatain : FOR i in xgmdatain'RANGE GENERATE
           VitalWireDelay (xgmdatain_ipd(i),xgmdatain(i), tipd_xgmdatain(i));
       END GENERATE;
           VitalWireDelay (phfifoxnbottombytesel_ipd,phfifoxnbottombytesel, tipd_phfifoxnbottombytesel);
       bits_hipdatain : FOR i in hipdatain'RANGE GENERATE
           VitalWireDelay (hipdatain_ipd(i),hipdatain(i), tipd_hipdatain(i));
       END GENERATE;
           VitalWireDelay (phfifoxntoprdenable_ipd,phfifoxntoprdenable, tipd_phfifoxntoprdenable);
           VitalWireDelay (detectrxloop_ipd,detectrxloop, tipd_detectrxloop);
      END BLOCK;
       

    VITAL: PROCESS (coreclk_ipd, datain_ipd, ctrlenable_ipd, detectrxloop_ipd, dispval_ipd, forcedisp_ipd, forcedispcompliance_ipd, forceelecidle_ipd, phfifowrenable_ipd, powerdn_ipd, pipetxdeemph_ipd, pipetxswing_ipd, pipetxmargin_ipd)

    variable Tviol_coreclk_ctrlenable : std_ulogic := '0';
    variable TimingData_coreclk_ctrlenable : VitalTimingDataType := VitalTimingDataInit;

    variable Tviol_coreclk_datain : std_ulogic := '0';
    variable TimingData_coreclk_datain : VitalTimingDataType := VitalTimingDataInit;

    variable Tviol_coreclk_detectrxloop : std_ulogic := '0';
    variable TimingData_coreclk_detectrxloop : VitalTimingDataType := VitalTimingDataInit;

    variable Tviol_coreclk_dispval : std_ulogic := '0';
    variable TimingData_coreclk_dispval : VitalTimingDataType := VitalTimingDataInit;

    variable Tviol_coreclk_forcedisp : std_ulogic := '0';
    variable TimingData_coreclk_forcedisp : VitalTimingDataType := VitalTimingDataInit;

    variable Tviol_coreclk_forcedispcompliance : std_ulogic := '0';
    variable TimingData_coreclk_forcedispcompliance : VitalTimingDataType := VitalTimingDataInit;

    variable Tviol_coreclk_forceelecidle : std_ulogic := '0';
    variable TimingData_coreclk_forceelecidle : VitalTimingDataType := VitalTimingDataInit;

    variable Tviol_coreclk_phfifowrenable : std_ulogic := '0';
    variable TimingData_coreclk_phfifowrenable : VitalTimingDataType := VitalTimingDataInit;

    variable Tviol_coreclk_powerdn : std_ulogic := '0';
    variable TimingData_coreclk_powerdn : VitalTimingDataType := VitalTimingDataInit;

    variable Tviol_coreclk_pipetxdeemph : std_ulogic := '0';
    variable TimingData_coreclk_pipetxdeemph : VitalTimingDataType := VitalTimingDataInit;

    variable Tviol_coreclk_pipetxmargin : std_ulogic := '0';
    variable TimingData_coreclk_pipetxmargin : VitalTimingDataType := VitalTimingDataInit;

    variable Tviol_coreclk_pipetxswing : std_ulogic := '0';
    variable TimingData_coreclk_pipetxswing : VitalTimingDataType := VitalTimingDataInit;

    variable phfifooverflow_VitalGlitchData : VitalGlitchDataType;
    variable phfifounderflow_VitalGlitchData : VitalGlitchDataType;

    BEGIN

        ------------------------
        --  Timing Check Section
        ------------------------
        IF (TimingChecksOn) THEN
            VitalSetupHoldCheck (
                        Violation       => Tviol_coreclk_ctrlenable,
                        TimingData      => TimingData_coreclk_ctrlenable,
                        TestSignal      => ctrlenable_ipd,
                        TestSignalName  => "CTRLENABLE",
                        RefSignal       => coreclk_ipd,
                        RefSignalName   => "CORECLK",
                        SetupHigh       => tsetup_ctrlenable_coreclk_noedge_posedge,
                        SetupLow        => tsetup_ctrlenable_coreclk_noedge_posedge,
                        HoldHigh        => thold_ctrlenable_coreclk_noedge_posedge,
                        HoldLow         => thold_ctrlenable_coreclk_noedge_posedge,
                        RefTransition   => '/',
                        HeaderMsg       => InstancePath & "/STRATIXIV_HSSI_TX_PCS",
                        XOn             => XOnChecks,
                        MsgOn           => MsgOnChecks
            );

            VitalSetupHoldCheck (
                        Violation       => Tviol_coreclk_datain,
                        TimingData      => TimingData_coreclk_datain,
                        TestSignal      => datain_ipd,
                        TestSignalName  => "DATAIN",
                        RefSignal       => coreclk_ipd,
                        RefSignalName   => "CORECLK",
                        SetupHigh       => tsetup_datain_coreclk_noedge_posedge,
                        SetupLow        => tsetup_datain_coreclk_noedge_posedge,
                        HoldHigh        => thold_datain_coreclk_noedge_posedge,
                        HoldLow         => thold_datain_coreclk_noedge_posedge,
                        RefTransition   => '/',
                        HeaderMsg       => InstancePath & "/STRATIXIV_HSSI_TX_PCS",
                        XOn             => XOnChecks,
                        MsgOn           => MsgOnChecks
            );

            VitalSetupHoldCheck (
                        Violation       => Tviol_coreclk_detectrxloop,
                        TimingData      => TimingData_coreclk_detectrxloop,
                        TestSignal      => detectrxloop_ipd,
                        TestSignalName  => "DETECTRXLOOP",
                        RefSignal       => coreclk_ipd,
                        RefSignalName   => "CORECLK",
                        SetupHigh       => tsetup_detectrxloop_coreclk_noedge_posedge,
                        SetupLow        => tsetup_detectrxloop_coreclk_noedge_posedge,
                        HoldHigh        => thold_detectrxloop_coreclk_noedge_posedge,
                        HoldLow         => thold_detectrxloop_coreclk_noedge_posedge,
                        RefTransition   => '/',
                        HeaderMsg       => InstancePath & "/STRATIXIV_HSSI_TX_PCS",
                        XOn             => XOnChecks,
                        MsgOn           => MsgOnChecks
            );

            VitalSetupHoldCheck (
                        Violation       => Tviol_coreclk_dispval,
                        TimingData      => TimingData_coreclk_dispval,
                        TestSignal      => dispval_ipd,
                        TestSignalName  => "DISPVAL",
                        RefSignal       => coreclk_ipd,
                        RefSignalName   => "CORECLK",
                        SetupHigh       => tsetup_dispval_coreclk_noedge_posedge,
                        SetupLow        => tsetup_dispval_coreclk_noedge_posedge,
                        HoldHigh        => thold_dispval_coreclk_noedge_posedge,
                        HoldLow         => thold_dispval_coreclk_noedge_posedge,
                        RefTransition   => '/',
                        HeaderMsg       => InstancePath & "/STRATIXIV_HSSI_TX_PCS",
                        XOn             => XOnChecks,
                        MsgOn           => MsgOnChecks
            );

            VitalSetupHoldCheck (
                        Violation       => Tviol_coreclk_forcedisp,
                        TimingData      => TimingData_coreclk_forcedisp,
                        TestSignal      => forcedisp_ipd,
                        TestSignalName  => "FORCEDISP",
                        RefSignal       => coreclk_ipd,
                        RefSignalName   => "CORECLK",
                        SetupHigh       => tsetup_forcedisp_coreclk_noedge_posedge,
                        SetupLow        => tsetup_forcedisp_coreclk_noedge_posedge,
                        HoldHigh        => thold_forcedisp_coreclk_noedge_posedge,
                        HoldLow         => thold_forcedisp_coreclk_noedge_posedge,
                        RefTransition   => '/',
                        HeaderMsg       => InstancePath & "/STRATIXIV_HSSI_TX_PCS",
                        XOn             => XOnChecks,
                        MsgOn           => MsgOnChecks
            );

            VitalSetupHoldCheck (
                        Violation       => Tviol_coreclk_forcedispcompliance,
                        TimingData      => TimingData_coreclk_forcedispcompliance,
                        TestSignal      => forcedispcompliance_ipd,
                        TestSignalName  => "FORCEDISPCOMPLIANCE",
                        RefSignal       => coreclk_ipd,
                        RefSignalName   => "CORECLK",
                        SetupHigh       => tsetup_forcedispcompliance_coreclk_noedge_posedge,
                        SetupLow        => tsetup_forcedispcompliance_coreclk_noedge_posedge,
                        HoldHigh        => thold_forcedispcompliance_coreclk_noedge_posedge,
                        HoldLow         => thold_forcedispcompliance_coreclk_noedge_posedge,
                        RefTransition   => '/',
                        HeaderMsg       => InstancePath & "/STRATIXIV_HSSI_TX_PCS",
                        XOn             => XOnChecks,
                        MsgOn           => MsgOnChecks
            );

            VitalSetupHoldCheck (
                        Violation       => Tviol_coreclk_forceelecidle,
                        TimingData      => TimingData_coreclk_forceelecidle,
                        TestSignal      => forceelecidle_ipd,
                        TestSignalName  => "FORCEELECIDLE",
                        RefSignal       => coreclk_ipd,
                        RefSignalName   => "CORECLK",
                        SetupHigh       => tsetup_forceelecidle_coreclk_noedge_posedge,
                        SetupLow        => tsetup_forceelecidle_coreclk_noedge_posedge,
                        HoldHigh        => thold_forceelecidle_coreclk_noedge_posedge,
                        HoldLow         => thold_forceelecidle_coreclk_noedge_posedge,
                        RefTransition   => '/',
                        HeaderMsg       => InstancePath & "/STRATIXIV_HSSI_TX_PCS",
                        XOn             => XOnChecks,
                        MsgOn           => MsgOnChecks
            );

            VitalSetupHoldCheck (
                        Violation       => Tviol_coreclk_phfifowrenable,
                        TimingData      => TimingData_coreclk_phfifowrenable,
                        TestSignal      => phfifowrenable_ipd,
                        TestSignalName  => "PHFIFOWRENABLE",
                        RefSignal       => coreclk_ipd,
                        RefSignalName   => "CORECLK",
                        SetupHigh       => tsetup_phfifowrenable_coreclk_noedge_posedge,
                        SetupLow        => tsetup_phfifowrenable_coreclk_noedge_posedge,
                        HoldHigh        => thold_phfifowrenable_coreclk_noedge_posedge,
                        HoldLow         => thold_phfifowrenable_coreclk_noedge_posedge,
                        RefTransition   => '/',
                        HeaderMsg       => InstancePath & "/STRATIXIV_HSSI_TX_PCS",
                        XOn             => XOnChecks,
                        MsgOn           => MsgOnChecks
            );

            VitalSetupHoldCheck (
                        Violation       => Tviol_coreclk_powerdn,
                        TimingData      => TimingData_coreclk_powerdn,
                        TestSignal      => powerdn_ipd,
                        TestSignalName  => "POWERDN",
                        RefSignal       => coreclk_ipd,
                        RefSignalName   => "CORECLK",
                        SetupHigh       => tsetup_powerdn_coreclk_noedge_posedge,
                        SetupLow        => tsetup_powerdn_coreclk_noedge_posedge,
                        HoldHigh        => thold_powerdn_coreclk_noedge_posedge,
                        HoldLow         => thold_powerdn_coreclk_noedge_posedge,
                        RefTransition   => '/',
                        HeaderMsg       => InstancePath & "/STRATIXIV_HSSI_TX_PCS",
                        XOn             => XOnChecks,
                        MsgOn           => MsgOnChecks
            );

            VitalSetupHoldCheck (
                        Violation       => Tviol_coreclk_pipetxdeemph,
                        TimingData      => TimingData_coreclk_pipetxdeemph,
                        TestSignal      => pipetxdeemph_ipd,
                        TestSignalName  => "PIPETXDEEMPH",
                        RefSignal       => coreclk_ipd,
                        RefSignalName   => "CORECLK",
                        SetupHigh       => tsetup_pipetxdeemph_coreclk_noedge_posedge,
                        SetupLow        => tsetup_pipetxdeemph_coreclk_noedge_posedge,
                        HoldHigh        => thold_pipetxdeemph_coreclk_noedge_posedge,
                        HoldLow         => thold_pipetxdeemph_coreclk_noedge_posedge,
                        RefTransition   => '/',
                        HeaderMsg       => InstancePath & "/STRATIXIV_HSSI_TX_PCS",
                        XOn             => XOnChecks,
                        MsgOn           => MsgOnChecks
            );

            VitalSetupHoldCheck (
                        Violation       => Tviol_coreclk_pipetxmargin,
                        TimingData      => TimingData_coreclk_pipetxmargin,
                        TestSignal      => pipetxmargin_ipd,
                        TestSignalName  => "PIPETXMARGIN",
                        RefSignal       => coreclk_ipd,
                        RefSignalName   => "CORECLK",
                        SetupHigh       => tsetup_pipetxmargin_coreclk_noedge_posedge,
                        SetupLow        => tsetup_pipetxmargin_coreclk_noedge_posedge,
                        HoldHigh        => thold_pipetxmargin_coreclk_noedge_posedge,
                        HoldLow         => thold_pipetxmargin_coreclk_noedge_posedge,
                        RefTransition   => '/',
                        HeaderMsg       => InstancePath & "/STRATIXIV_HSSI_TX_PCS",
                        XOn             => XOnChecks,
                        MsgOn           => MsgOnChecks
            );

            VitalSetupHoldCheck (
                        Violation       => Tviol_coreclk_pipetxswing,
                        TimingData      => TimingData_coreclk_pipetxswing,
                        TestSignal      => pipetxswing_ipd,
                        TestSignalName  => "PIPETXSWING",
                        RefSignal       => coreclk_ipd,
                        RefSignalName   => "CORECLK",
                        SetupHigh       => tsetup_pipetxswing_coreclk_noedge_posedge,
                        SetupLow        => tsetup_pipetxswing_coreclk_noedge_posedge,
                        HoldHigh        => thold_pipetxswing_coreclk_noedge_posedge,
                        HoldLow         => thold_pipetxswing_coreclk_noedge_posedge,
                        RefTransition   => '/',
                        HeaderMsg       => InstancePath & "/STRATIXIV_HSSI_TX_PCS",
                        XOn             => XOnChecks,
                        MsgOn           => MsgOnChecks
            );

        END IF;

        ----------------------
        --  Path Delay Section
        ----------------------

        VitalPathDelay01 (
            OutSignal => phfifooverflow,
            OutSignalName => "PHFIFOOVERFLOW",
            OutTemp => td_out_full_tx,
            Paths => (1 => (coreclk_ipd'last_event, tpd_coreclk_phfifooverflow_posedge, TRUE)),
            GlitchData => phfifooverflow_VitalGlitchData,
            Mode => DefGlitchMode,
            XOn => XOn,
            MsgOn => MsgOn );

        VitalPathDelay01 (
            OutSignal => phfifounderflow,
            OutSignalName => "PHFIFOUNDERFLOW",
            OutTemp => td_out_empty_tx,
            Paths => (1 => (coreclk_ipd'last_event, tpd_coreclk_phfifounderflow_posedge, TRUE)),
            GlitchData => phfifounderflow_VitalGlitchData,
            Mode => DefGlitchMode,
            XOn => XOn,
            MsgOn => MsgOn );

    END PROCESS;
   
      ------------------------
      --  Functionality Section --
      ------------------------
   bitslipboundaryselect_in <= bitslipboundaryselect;
   forceelecidle_in <= forceelecidle;
   hipdatain_in <= hipdatain;
   hipdetectrxloop_in <= hipdetectrxloop;
   hipforceelecidle_in <= hipforceelecidle;
   hippowerdn_in <= hippowerdn;
   hiptxdeemph_in <= hiptxdeemph;
   hiptxmargin_in <= hiptxmargin;
   iqpphfifoxnbytesel_in <= iqpphfifoxnbytesel;
   iqpphfifoxnrdclk_in <= iqpphfifoxnrdclk;
   iqpphfifoxnrdenable_in <= iqpphfifoxnrdenable;
   iqpphfifoxnwrenable_in <= iqpphfifoxnwrenable;
   phfifobyteserdisable_in <= phfifobyteserdisable;
   phfifoptrsreset_in <= phfifoptrsreset;
   phfifoxnbytesel_in <= phfifoxnbytesel;
   phfifoxnptrsreset_in <= phfifoxnptrsreset;
   phfifoxnrdclk_in <= phfifoxnrdclk;
   phfifoxnrdenable_in <= phfifoxnrdenable;
   phfifoxnwrenable_in <= phfifoxnwrenable;
   prbscidenable_in <= prbscidenable;
   dprioin_in <= dprioin;
   
    PROCESS
        VARIABLE i : INTEGER := 0;
        VARIABLE txt : LINE;
        
        PROCEDURE compute_rprbs_sel (
            pma_doublewidth         : IN std_logic;   
            pma_width               : IN std_logic;   
            test_mode               : IN string; result : OUT std_logic_vector) IS
        
            VARIABLE res                    :  std_logic_vector(2 DOWNTO 0);   
            VARIABLE temp_xhdl20 : STD_LOGIC_VECTOR(1 DOWNTO 0);
        BEGIN
            temp_xhdl20 := pma_doublewidth & pma_width;
            CASE temp_xhdl20 IS
               WHEN "00" =>                                                                                          
                           IF ((test_mode = "prbs_8") OR (test_mode = "prbs8")) THEN       
                               res := "000";                                                                         
                           ELSIF (test_mode = "prbs7") THEN
                               res := "010";                     
                           ELSIF (test_mode = "prbs23") THEN
                               res := "100";
                           ELSIF (test_mode = "high frequency") THEN
                               res := "001";
                           ELSE                        
                               res := "000";     -- default
                           END IF;                                                                                   
               WHEN "01" =>                                                                                          
                           IF ((test_mode = "prbs_10") OR (test_mode = "prbs10")) THEN    
                               res := "000";                                                                         
                           ELSIF (test_mode = "high frequency") THEN
                               res := "001";
                           ELSIF (test_mode = "low frequency") THEN
                               res := "010";
                           ELSIF (test_mode = "mixed frequency") THEN
                               res := "011";
                           ELSE
                               res := "000";     -- default
                           END IF;                                                                                   
               WHEN "10" =>                                                                                          
                           IF ((test_mode = "prbs_7") OR (test_mode = "prbs7")) THEN       
                               res := "000";                                                                         
                           ELSIF (test_mode = "PRBS_23" OR test_mode = "prbs_23" OR test_mode = "prbs23")  THEN
                               res := "001";
                           ELSIF (test_mode = "high frequency")  THEN
                               res := "010";
                           ELSE
                               res := "000";     -- default
                           END IF;                                                                                   
               WHEN "11" =>                                                                                          
                           IF ((test_mode = "prbs_7") OR (test_mode = "prbs7")) THEN       
                               res := "000";                                                                         
                           ELSIF ((test_mode = "PRBS_23") OR (test_mode = "prbs_23") OR (test_mode = "prbs23")) THEN
                               res := "001";                     
                           ELSIF (test_mode = "high frequency") THEN
                               res := "010";
                           ELSIF (test_mode = "low frequency") THEN
                               res := "011";
                           ELSIF (test_mode = "mixed frequency") THEN
                               res := "100";
                           ELSE
                               res := "000";     -- default
                           END IF;                                                                                   
                WHEN OTHERS  =>
                            --WRITE(txt,string'("Invalid pma_doublewidth and pma_width selection"));   
                            --WRITELINE (OUTPUT,txt);
                
            END CASE;
            result := res;    
        END compute_rprbs_sel;
                                                                                         
        VARIABLE init_rprbs_sel_val : std_logic_vector(2 DOWNTO 0);
        VARIABLE init_rpma_doublewidth_tx_var,init_rpmadwidth_tx_var : STD_LOGIC;
      
   BEGIN
      init_r8b10b_enc_ibm_en <= mux_select((enc_8b_10b_compatibility_mode = ("true")), '1', '0');
      init_rbist_sel <= mux_select((self_test_mode = ("incremental")), "00", mux_select((self_test_mode = ("cjpat")), "01", mux_select((self_test_mode = ("crpat")), "10", "00")));
      init_rbisten_tx <= mux_select(((enable_self_test_mode = ("true")) AND (self_test_mode = ("incremental") OR self_test_mode = ("cjpat") OR self_test_mode = ("cjpat"))), '1', '0');
      init_rcascaded_8b10b_en_tx <= mux_select((enc_8b_10b_mode = ("cascaded")), '1', '0');
      init_rcxpat_chnl_en <= mux_select((channel_number = 1), "01", mux_select((channel_number = 2), "10", mux_select((channel_number = 3), "11", "00")));
      init_rdwidth_tx <= mux_select((use_double_data_mode = ("true")), '1', '0');
      init_renbitrev_tx <= mux_select((enable_bit_reversal = ("true")), '1', '0');
      init_rendec_data_sel_tx <= mux_select((protocol_hint = ("xaui")), '0', '1');
      init_rendec_tx <= mux_select((enc_8b_10b_mode /= ("none")), '1', '0');
      init_renpolinv_tx <= mux_select((allow_polarity_inversion = ("true")), '1', '0');
      init_rensymswap_tx <= mux_select((enable_symbol_swap = ("true")), '1', '0');
      init_rforce_disp <= mux_select((disparity_mode = ("new")), '1', '0');
      init_rforce_echar <= mux_select((force_echar = ("true")), '1', '0');
      init_rforce_kchar <= mux_select((force_kchar = ("true")), '1', '0');
      init_rfreerun_tx <= mux_select((reset_clock_output_during_digital_reset = ("false")), '1', '0');
      init_rge_xaui_tx <= mux_select((protocol_hint = ("gige") OR enable_idle_selection = ("true")), '1', '0');
      init_rib_force_disp <= mux_select((disparity_mode = ("legacy")), '1', '0');
      init_rindv_tx <= mux_select((channel_bonding = ("x4") OR channel_bonding = ("x8") OR protocol_hint = ("xaui")), '0', '1');
      init_rphfifo_master_sel_tx <= mux_select((channel_bonding = ("x8")), '0', '1');
      init_rphfifopldentx <= '1';
      init_rphfifoursttx <= '1';
      
            IF (use_serializer_double_data_mode = "true") THEN
                init_rpma_doublewidth_tx <= '1';
                init_rpma_doublewidth_tx_var := '1';
            ELSE
                init_rpma_doublewidth_tx <= '0';
                init_rpma_doublewidth_tx_var := '0';
            END IF;
            
            IF ((enc_8b_10b_mode = "none") AND ((channel_width = 8) OR (channel_width = 16) OR (channel_width = 32))) THEN
                init_rpmadwidth_tx <= '0';
                init_rpmadwidth_tx_var := '0';
            ELSE
                init_rpmadwidth_tx <= '1';
                init_rpmadwidth_tx_var := '1';
            END IF;
            
            compute_rprbs_sel(init_rpma_doublewidth_tx_var,init_rpmadwidth_tx_var,self_test_mode,init_rprbs_sel_val);
            init_rprbs_sel <= init_rprbs_sel_val;
      
      init_rprbsen_tx <= mux_select(((enable_self_test_mode = ("true")) AND (self_test_mode /= ("incremental")) AND (self_test_mode /= ("cjpat")) AND (self_test_mode /= ("crpat"))), '1', '0');
      init_rrev_loopbk <= mux_select((enable_reverse_parallel_loopback = ("true")), '1', '0');
      init_rtx_pipe_enable <= mux_select((protocol_hint = ("pcie") OR protocol_hint = ("pcie2")), '1', '0');
      init_rtxfifo_dis <= mux_select((enable_phfifo_bypass = ("true")), '1', '0');
      init_rtxfifo_lowlatency_en <= mux_select((disable_ph_low_latency_mode = ("false")), '1', '0');
      init_rtxpcsbypass_en <= mux_select((datapath_low_latency_mode = ("true")), '1', '0');
      init_rtxrdclksel <= mux_select((refclk_select = ("cmu_clock_divider") OR refclk_select = ("cmu clock divider")), '1', '0');
      init_rtxswing_sel_ena <= mux_select((pipe_voltage_swing_control = ("true")), '1', '0');
      init_rtxwrclksel <= mux_select((wr_clk_mux_select = ("int_clk") OR wr_clk_mux_select = ("int clk") OR wr_clk_mux_select = ("internal clock")), '1', '0');
      init_rclkcmpinsertpad <= '1';
      init_rrdwidth_rx <= '1';
      init_rrx_detect_bypass <= '1';
      init_rrx_pipe_enable <= '1';
      init_rtx_elec_idle_delay <= "011";
      init_is_lane0 <= mux_select((channel_number = 0), '1', '0');
      init_scan_mode <= '0';
      init_rauto_speed_ena <= mux_select((pipe_auto_speed_nego_enable = ("true")), '1', '0');
      init_rfreq_sel <= mux_select((alpha_tolower(pipe_freq_scale_mode) = ("data width")), '0', '1');
      init_rtxpcsclkpwdn <= '0';
      init_rcid_pattern_tx <= mux_select((prbs_cid_pattern = ("true")), '1', '0');
      init_rcid_len_tx <= int2bin(prbs_cid_pattern_length, 8);
      IF ((channel_bonding /= "x8") OR (stratixiv_tx_pcs_mph_fifo_xn_mapping(ph_fifo_xn_select,ph_fifo_xn_mapping0,ph_fifo_xn_mapping1,ph_fifo_xn_mapping2) = "central")) THEN
          init_rmaster_tx <= '1';
      ELSE
          init_rmaster_tx <= '0';
      END IF;
      -- flip
      IF (stratixiv_tx_pcs_mph_fifo_xn_mapping(ph_fifo_xn_select,ph_fifo_xn_mapping0,ph_fifo_xn_mapping1,ph_fifo_xn_mapping2) = "down") THEN
          init_rmaster_up_tx <= '1';  
      ELSE
          init_rmaster_up_tx <= '0';
      END IF;
      init_rself_sw_en_tx <= mux_select((auto_spd_self_switch_enable = ("true")), '1', '0');
      init_rpipeline_bypass_tx <= mux_select((iqp_bypass = ("true")), '1', '0');
      init_rphfifo_regmode_tx <= mux_select((ph_fifo_reg_mode = ("true")), '1', '0');
      init_rtxbitslip_en <= mux_select((bitslip_enable = ("true")), '1', '0');
      init_rhip_ena <= mux_select((hip_enable = ("true")), '1', '0');
      WAIT;
   END PROCESS;
   
-- new DPRIO model begin --
-- ---------------------------------------------------------------------------
-- Set DPRIO CRAM input from dprioin  
-- ---------------------------------------------------------------------------
dprioin_rpma_doublewidth_tx   <= dprioin_in(rpma_doublewidth_tx_TX_IDX);   
dprioin_rpmadwidth_tx         <= dprioin_in(rpmadwidth_tx_TX_IDX);        
dprioin_rendec_data_sel_tx    <= dprioin_in(rendec_data_sel_tx_TX_IDX);
dprioin_rindv_tx              <= dprioin_in(rindv_tx_TX_IDX);
dprioin_rmaster_tx            <= dprioin_in(rmaster_tx_TX_IDX);
dprioin_rmaster_up_tx         <= dprioin_in(rmaster_up_tx_TX_IDX);
dprioin_rphfifo_master_sel_tx <= init_rphfifo_master_sel_tx;    -- obsolete cram

-- Existing
dprioin_is_lane0              <= init_is_lane0;
dprioin_rauto_speed_ena       <= dprioin_in(rauto_speed_ena_TX_IDX);
dprioin_rclkcmpinsertpad      <= init_rclkcmpinsertpad;  		-- rx only <=<=<=<=<=<=<=<=<= pipe <=<=<=<=<=<=<=<=<=<=<=    
dprioin_rfreq_sel             <= dprioin_in(rfreq_sel_TX_IDX);
dprioin_rhip_ena              <= dprioin_in(rhip_ena_TX_IDX);
dprioin_rrdwidth_rx           <= init_rrdwidth_rx;              -- rx only
dprioin_rrx_detect_bypass     <= init_rrx_detect_bypass;        -- rx only
dprioin_rrx_pipe_enable       <= init_rrx_pipe_enable;          -- rx only
dprioin_rtx_cmu_sel           <= dprioin_in(rtx_cmu_sel_TX_IDX);
dprioin_scan_mode             <= init_scan_mode;

-- PCS Per Channel TX Control Register 1 for Channel 0
dprioin_rforce_disp	<= dprioin(rforce_disp_TXPCS_IDX_0);
dprioin_rrev_loopbk	<= dprioin(rrev_loopbk_TXPCS_IDX_0);
dprioin_rtxrdclksel	<= dprioin(rtxrdclksel_TXPCS_IDX_0);
dprioin_rtxwrclksel	<= dprioin(rtxwrclksel_TXPCS_IDX_0);
dprioin_rfreerun_tx	<= dprioin(rfreerun_tx_TXPCS_IDX_0);
dprioin_rtxurstpcs	<= dprioin(rtxurstpcs_TXPCS_IDX_0);
dprioin_reserved_0_TB1	<= dprioin(reserved_0_TB1_TXPCS_IDX_0);
dprioin_rphfifoursttx	<= dprioin(rphfifoursttx_TXPCS_IDX_0);
dprioin_rphfifopldentx	<= dprioin(rphfifopldentx_TXPCS_IDX_0);
dprioin_rge_xaui_tx	<= dprioin(rge_xaui_tx_TXPCS_IDX_0);
dprioin_rdwidth_tx	<= dprioin(rdwidth_tx_TXPCS_IDX_0);
dprioin_rtxfifo_lowlatency_en	<= dprioin(rtxfifo_lowlatency_en_TXPCS_IDX_0);
dprioin_rib_force_disp	<= dprioin(rib_force_disp_TXPCS_IDX_0);
dprioin_rtxfifo_dis	<= dprioin(rtxfifo_dis_TXPCS_IDX_0);
dprioin_rforce_echar	<= dprioin(rforce_echar_TXPCS_IDX_0);
dprioin_rforce_kchar	<= dprioin(rforce_kchar_TXPCS_IDX_0);

-- PCS Per Channel TX Control Register 2 for Channel 0
dprioin_rtxpcsbypass_en	<= dprioin(rtxpcsbypass_en_TXPCS_IDX_0);
dprioin_rcxpat_chnl_en	<= dprioin(rcxpat_chnl_en_TXPCS_IDX_1 DOWNTO rcxpat_chnl_en_TXPCS_IDX_0);
dprioin_rbist_sel	<= dprioin(rbist_sel_TXPCS_IDX_1 DOWNTO rbist_sel_TXPCS_IDX_0);
dprioin_rbisten_tx	<= dprioin(rbisten_tx_TXPCS_IDX_0);
dprioin_rprbs_sel	<= dprioin(rprbs_sel_TXPCS_IDX_2 DOWNTO rprbs_sel_TXPCS_IDX_0);
dprioin_rprbsen_tx	<= dprioin(rprbsen_tx_TXPCS_IDX_0);
dprioin_renbitrev_tx	<= dprioin(renbitrev_tx_TXPCS_IDX_0);
dprioin_renpolinv_tx	<= dprioin(renpolinv_tx_TXPCS_IDX_0);
dprioin_rensymswap_tx	<= dprioin(rensymswap_tx_TXPCS_IDX_0);
dprioin_rcascaded_8b10b_en_tx	<= dprioin(rcascaded_8b10b_en_tx_TXPCS_IDX_0);
dprioin_r8b10b_enc_ibm_en	<= dprioin(r8b10b_enc_ibm_en_TXPCS_IDX_0);
dprioin_rendec_tx	<= dprioin(rendec_tx_TXPCS_IDX_0);

-- PCS Per Channel TX Control Register 3 for Channel 0
dprioin_reserved_0_TB3	<= dprioin(reserved_0_TB3_TXPCS_IDX_0);
dprioin_rcid_len_tx	<= dprioin(rcid_len_tx_TXPCS_IDX_7 DOWNTO rcid_len_tx_TXPCS_IDX_0);
dprioin_rcid_pattern_tx	<= dprioin(rcid_pattern_tx_TXPCS_IDX_0);
dprioin_rtxpcsclkpwdn	<= dprioin(rtxpcsclkpwdn_TXPCS_IDX_0);
dprioin_rtxswing_sel_ena	<= dprioin(rtxswing_sel_ena_TXPCS_IDX_0);
dprioin_rtx_elec_idle_delay	<= dprioin(rtx_elec_idle_delay_TXPCS_IDX_2 DOWNTO rtx_elec_idle_delay_TXPCS_IDX_0);
dprioin_rtx_pipe_enable	<= dprioin(rtx_pipe_enable_TXPCS_IDX_0);

-- PCS Per Channel TX Control Register 4 for Channel 0
dprioin_reserved_0_TB4	<= dprioin(reserved_0_TB4_TXPCS_IDX_11 DOWNTO reserved_0_TB4_TXPCS_IDX_0);
dprioin_rtxbitslip_en	<= dprioin(rtxbitslip_en_TXPCS_IDX_0);
dprioin_rphfifo_regmode_tx	<= dprioin(rphfifo_regmode_tx_TXPCS_IDX_0);
dprioin_rpipeline_bypass_tx	<= dprioin(rpipeline_bypass_tx_TXPCS_IDX_0);
dprioin_rself_sw_en_tx	<= dprioin(rself_sw_en_tx_TXPCS_IDX_0);

-- ---------------------------------------------------------------------------
-- Set DPRIO output from initial CRAM
-- ---------------------------------------------------------------------------
-- Existing
dprioout(rpma_doublewidth_tx_TX_IDX)   <= init_rpma_doublewidth_tx;   
dprioout(rpmadwidth_tx_TX_IDX)         <= init_rpmadwidth_tx;         
dprioout(rendec_data_sel_tx_TX_IDX)    <= init_rendec_data_sel_tx;
dprioout(rindv_tx_TX_IDX)              <= init_rindv_tx;
dprioout(rmaster_tx_TX_IDX)            <= init_rmaster_tx;
dprioout(rmaster_up_tx_TX_IDX)         <= init_rmaster_up_tx;

dprioout(rauto_speed_ena_TX_IDX)       <= init_rauto_speed_ena;           
dprioout(rfreq_sel_TX_IDX)             <= init_rfreq_sel;           
dprioout(rhip_ena_TX_IDX)              <= init_rhip_ena;
dprioout(rtx_cmu_sel_TX_IDX)           <= init_rtx_cmu_sel;           

-- PCS Per Channel TX Control Register 1 for Channel 0
dprioout(rforce_disp_TXPCS_IDX_0) <= init_rforce_disp;
dprioout(rrev_loopbk_TXPCS_IDX_0) <= init_rrev_loopbk;
dprioout(rtxrdclksel_TXPCS_IDX_0) <= init_rtxrdclksel;
dprioout(rtxwrclksel_TXPCS_IDX_0) <= init_rtxwrclksel;
dprioout(rfreerun_tx_TXPCS_IDX_0) <= init_rfreerun_tx;
dprioout(rtxurstpcs_TXPCS_IDX_0) <= init_rtxurstpcs;
dprioout(reserved_0_TB1_TXPCS_IDX_0) <= init_reserved_0_TB1;
dprioout(rphfifoursttx_TXPCS_IDX_0) <= init_rphfifoursttx;
dprioout(rphfifopldentx_TXPCS_IDX_0) <= init_rphfifopldentx;
dprioout(rge_xaui_tx_TXPCS_IDX_0) <= init_rge_xaui_tx;
dprioout(rdwidth_tx_TXPCS_IDX_0) <= init_rdwidth_tx;
dprioout(rtxfifo_lowlatency_en_TXPCS_IDX_0) <= init_rtxfifo_lowlatency_en;
dprioout(rib_force_disp_TXPCS_IDX_0) <= init_rib_force_disp;
dprioout(rtxfifo_dis_TXPCS_IDX_0) <= init_rtxfifo_dis;
dprioout(rforce_echar_TXPCS_IDX_0) <= init_rforce_echar;
dprioout(rforce_kchar_TXPCS_IDX_0) <= init_rforce_kchar;

-- PCS Per Channel TX Control Register 2 for Channel 0
dprioout(rtxpcsbypass_en_TXPCS_IDX_0) <= init_rtxpcsbypass_en;
dprioout(rcxpat_chnl_en_TXPCS_IDX_1 DOWNTO rcxpat_chnl_en_TXPCS_IDX_0) <= init_rcxpat_chnl_en;
dprioout(rbist_sel_TXPCS_IDX_1 DOWNTO rbist_sel_TXPCS_IDX_0) <= init_rbist_sel;
dprioout(rbisten_tx_TXPCS_IDX_0) <= init_rbisten_tx;
dprioout(rprbs_sel_TXPCS_IDX_2 DOWNTO rprbs_sel_TXPCS_IDX_0) <= init_rprbs_sel;
dprioout(rprbsen_tx_TXPCS_IDX_0) <= init_rprbsen_tx;
dprioout(renbitrev_tx_TXPCS_IDX_0) <= init_renbitrev_tx;
dprioout(renpolinv_tx_TXPCS_IDX_0) <= init_renpolinv_tx;
dprioout(rensymswap_tx_TXPCS_IDX_0) <= init_rensymswap_tx;
dprioout(rcascaded_8b10b_en_tx_TXPCS_IDX_0) <= init_rcascaded_8b10b_en_tx;
dprioout(r8b10b_enc_ibm_en_TXPCS_IDX_0) <= init_r8b10b_enc_ibm_en;
dprioout(rendec_tx_TXPCS_IDX_0) <= init_rendec_tx;

-- PCS Per Channel TX Control Register 3 for Channel 0
dprioout(reserved_0_TB3_TXPCS_IDX_0) <= init_reserved_0_TB3;
dprioout(rcid_len_tx_TXPCS_IDX_7 DOWNTO rcid_len_tx_TXPCS_IDX_0) <= init_rcid_len_tx;
dprioout(rcid_pattern_tx_TXPCS_IDX_0) <= init_rcid_pattern_tx;
dprioout(rtxpcsclkpwdn_TXPCS_IDX_0) <= init_rtxpcsclkpwdn;
dprioout(rtxswing_sel_ena_TXPCS_IDX_0) <= init_rtxswing_sel_ena;
dprioout(rtx_elec_idle_delay_TXPCS_IDX_2 DOWNTO rtx_elec_idle_delay_TXPCS_IDX_0) <= init_rtx_elec_idle_delay;
dprioout(rtx_pipe_enable_TXPCS_IDX_0) <= init_rtx_pipe_enable;

-- PCS Per Channel TX Control Register 4 for Channel 0
dprioout(reserved_0_TB4_TXPCS_IDX_11 DOWNTO reserved_0_TB4_TXPCS_IDX_0) <= init_reserved_0_TB4;
dprioout(rtxbitslip_en_TXPCS_IDX_0) <= init_rtxbitslip_en;
dprioout(rphfifo_regmode_tx_TXPCS_IDX_0) <= init_rphfifo_regmode_tx;
dprioout(rpipeline_bypass_tx_TXPCS_IDX_0) <= init_rpipeline_bypass_tx;
dprioout(rself_sw_en_tx_TXPCS_IDX_0) <= init_rself_sw_en_tx;

-- ---------------------------------------------------------------------------
-- Set DPRIO CRAM
-- ---------------------------------------------------------------------------
dpriodisable_in <= '0' WHEN (dpriodisable = '0') ELSE '1';

cram_rpma_doublewidth_tx   <= init_rpma_doublewidth_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rpma_doublewidth_tx;
cram_rpmadwidth_tx         <= init_rpmadwidth_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rpmadwidth_tx;      
cram_rendec_data_sel_tx    <= init_rendec_data_sel_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rendec_data_sel_tx;
cram_rindv_tx              <= init_rindv_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rindv_tx;
cram_rmaster_tx            <= init_rmaster_tx WHEN (dpriodisable_in /= '0') ELSE  dprioin_rmaster_tx;
cram_rmaster_up_tx         <= init_rmaster_up_tx WHEN (dpriodisable_in /= '0') ELSE  dprioin_rmaster_up_tx;

-- Existing
cram_is_lane0              <= init_is_lane0 WHEN (dpriodisable_in /= '0') ELSE dprioin_is_lane0;
cram_rauto_speed_ena       <= init_rauto_speed_ena WHEN (dpriodisable_in /= '0') ELSE dprioin_rauto_speed_ena;
cram_rclkcmpinsertpad      <= init_rclkcmpinsertpad WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpinsertpad;           -- rx only     
cram_rfreq_sel             <= init_rfreq_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rfreq_sel;
cram_rhip_ena              <= init_rhip_ena WHEN (dpriodisable_in /= '0') ELSE  dprioin_rhip_ena;
cram_rphfifo_master_sel_tx <= init_rphfifo_master_sel_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rphfifo_master_sel_tx;
cram_rrdwidth_rx           <= init_rrdwidth_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rrdwidth_rx;                     -- rx only
cram_rrx_detect_bypass     <= init_rrx_detect_bypass WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_detect_bypass;         -- rx only
cram_rrx_pipe_enable       <= init_rrx_pipe_enable WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_pipe_enable;             -- rx only
cram_rtx_cmu_sel           <= init_rtx_cmu_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rtx_cmu_sel;
cram_scan_mode             <= init_scan_mode WHEN (dpriodisable_in /= '0') ELSE dprioin_scan_mode;

-- PCS Per Channel TX Control Register 1 for Channel 0
cram_rforce_disp <= init_rforce_disp WHEN (dpriodisable_in /= '0') ELSE dprioin_rforce_disp;
cram_rrev_loopbk <= init_rrev_loopbk WHEN (dpriodisable_in /= '0') ELSE dprioin_rrev_loopbk;
cram_rtxrdclksel <= init_rtxrdclksel WHEN (dpriodisable_in /= '0') ELSE dprioin_rtxrdclksel;
cram_rtxwrclksel <= init_rtxwrclksel WHEN (dpriodisable_in /= '0') ELSE dprioin_rtxwrclksel;
cram_rfreerun_tx <= init_rfreerun_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rfreerun_tx;
cram_rtxurstpcs <= init_rtxurstpcs WHEN (dpriodisable_in /= '0') ELSE dprioin_rtxurstpcs;
cram_reserved_0_TB1 <= init_reserved_0_TB1 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB1;
cram_rphfifoursttx <= init_rphfifoursttx WHEN (dpriodisable_in /= '0') ELSE dprioin_rphfifoursttx;
cram_rphfifopldentx <= init_rphfifopldentx WHEN (dpriodisable_in /= '0') ELSE dprioin_rphfifopldentx;
cram_rge_xaui_tx <= init_rge_xaui_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rge_xaui_tx;
cram_rdwidth_tx <= init_rdwidth_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rdwidth_tx;
cram_rtxfifo_lowlatency_en <= init_rtxfifo_lowlatency_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rtxfifo_lowlatency_en;
cram_rib_force_disp <= init_rib_force_disp WHEN (dpriodisable_in /= '0') ELSE dprioin_rib_force_disp;
cram_rtxfifo_dis <= init_rtxfifo_dis WHEN (dpriodisable_in /= '0') ELSE dprioin_rtxfifo_dis;
cram_rforce_echar <= init_rforce_echar WHEN (dpriodisable_in /= '0') ELSE dprioin_rforce_echar;
cram_rforce_kchar <= init_rforce_kchar WHEN (dpriodisable_in /= '0') ELSE dprioin_rforce_kchar;

-- PCS Per Channel TX Control Register 2 for Channel 0
cram_rtxpcsbypass_en <= init_rtxpcsbypass_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rtxpcsbypass_en;
cram_rcxpat_chnl_en <= init_rcxpat_chnl_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rcxpat_chnl_en;
cram_rbist_sel <= init_rbist_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rbist_sel;
cram_rbisten_tx <= init_rbisten_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rbisten_tx;
cram_rprbs_sel <= init_rprbs_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rprbs_sel;
cram_rprbsen_tx <= init_rprbsen_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rprbsen_tx;
cram_renbitrev_tx <= init_renbitrev_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_renbitrev_tx;
cram_renpolinv_tx <= init_renpolinv_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_renpolinv_tx;
cram_rensymswap_tx <= init_rensymswap_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rensymswap_tx;
cram_rcascaded_8b10b_en_tx <= init_rcascaded_8b10b_en_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rcascaded_8b10b_en_tx;
cram_r8b10b_enc_ibm_en <= init_r8b10b_enc_ibm_en WHEN (dpriodisable_in /= '0') ELSE dprioin_r8b10b_enc_ibm_en;
cram_rendec_tx <= init_rendec_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rendec_tx;

-- PCS Per Channel TX Control Register 3 for Channel 0
cram_reserved_0_TB3 <= init_reserved_0_TB3 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB3;
cram_rcid_len_tx <= init_rcid_len_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rcid_len_tx;
cram_rcid_pattern_tx <= init_rcid_pattern_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rcid_pattern_tx;
cram_rtxpcsclkpwdn <= init_rtxpcsclkpwdn WHEN (dpriodisable_in /= '0') ELSE dprioin_rtxpcsclkpwdn;
cram_rtxswing_sel_ena <= init_rtxswing_sel_ena WHEN (dpriodisable_in /= '0') ELSE dprioin_rtxswing_sel_ena;
cram_rtx_elec_idle_delay <= init_rtx_elec_idle_delay WHEN (dpriodisable_in /= '0') ELSE dprioin_rtx_elec_idle_delay;
cram_rtx_pipe_enable <= init_rtx_pipe_enable WHEN (dpriodisable_in /= '0') ELSE dprioin_rtx_pipe_enable;

-- PCS Per Channel TX Control Register 4 for Channel 0
cram_reserved_0_TB4 <= init_reserved_0_TB4 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB4;
cram_rtxbitslip_en <= init_rtxbitslip_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rtxbitslip_en;
cram_rphfifo_regmode_tx <= init_rphfifo_regmode_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rphfifo_regmode_tx;
cram_rpipeline_bypass_tx <= init_rpipeline_bypass_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rpipeline_bypass_tx;
cram_rself_sw_en_tx <= init_rself_sw_en_tx WHEN (dpriodisable_in /= '0') ELSE dprioin_rself_sw_en_tx;
-- new DPRIO model end --
   
   --//////////////////////////////////////////////////////////////////////////////////////////////////
   -- datain TXD mapping - datain[32/40], ctrlenable[4], forcedispacompliance, forcedisp[4], dispval[4]
   --//////////////////////////////////////////////////////////////////////////////////////////////////
   
   tmp_ctrlenable(0) <= '1' WHEN (ctrlenable_ipd(0) = '1') ELSE
                        '0';
   tmp_ctrlenable(1) <= '1' WHEN (ctrlenable_ipd(1) = '1') ELSE
                        '0';
   tmp_ctrlenable(2) <= '1' WHEN (ctrlenable_ipd(2) = '1') ELSE
                        '0';
   tmp_ctrlenable(3) <= '1' WHEN (ctrlenable_ipd(3) = '1') ELSE
                        '0';
   
   tmp_dispval(0) <= '1' WHEN (dispval_ipd(0) = '1') ELSE
                     '0';
   tmp_dispval(1) <= '1' WHEN (dispval_ipd(1) = '1') ELSE
                     '0';
   tmp_dispval(2) <= '1' WHEN (dispval_ipd(2) = '1') ELSE
                     '0';
   tmp_dispval(3) <= '1' WHEN (dispval_ipd(3) = '1') ELSE
                     '0';
   
   tmp_forcedisp(0) <= '1' WHEN (forcedisp_ipd(0) = '1') ELSE
                       '0';
   tmp_forcedisp(1) <= '1' WHEN (forcedisp_ipd(1) = '1') ELSE
                       '0';
   tmp_forcedisp(2) <= '1' WHEN (forcedisp_ipd(2) = '1') ELSE
                       '0';
   tmp_forcedisp(3) <= '1' WHEN (forcedisp_ipd(3) = '1') ELSE
                       '0';
   
   tmp_datain(0) <= '1' WHEN (datain_ipd(0) = '1') ELSE
                    '0';
   tmp_datain(1) <= '1' WHEN (datain_ipd(1) = '1') ELSE
                    '0';
   tmp_datain(2) <= '1' WHEN (datain_ipd(2) = '1') ELSE
                    '0';
   tmp_datain(3) <= '1' WHEN (datain_ipd(3) = '1') ELSE
                    '0';
   tmp_datain(4) <= '1' WHEN (datain_ipd(4) = '1') ELSE
                    '0';
   tmp_datain(5) <= '1' WHEN (datain_ipd(5) = '1') ELSE
                    '0';
   tmp_datain(6) <= '1' WHEN (datain_ipd(6) = '1') ELSE
                    '0';
   tmp_datain(7) <= '1' WHEN (datain_ipd(7) = '1') ELSE
                    '0';
   tmp_datain(8) <= '1' WHEN (datain_ipd(8) = '1') ELSE
                    '0';
   tmp_datain(9) <= '1' WHEN (datain_ipd(9) = '1') ELSE
                    '0';
   tmp_datain(10) <= '1' WHEN (datain_ipd(10) = '1') ELSE
                     '0';
   tmp_datain(11) <= '1' WHEN (datain_ipd(11) = '1') ELSE
                     '0';
   tmp_datain(12) <= '1' WHEN (datain_ipd(12) = '1') ELSE
                     '0';
   tmp_datain(13) <= '1' WHEN (datain_ipd(13) = '1') ELSE
                     '0';
   tmp_datain(14) <= '1' WHEN (datain_ipd(14) = '1') ELSE
                     '0';
   tmp_datain(15) <= '1' WHEN (datain_ipd(15) = '1') ELSE
                     '0';
   tmp_datain(16) <= '1' WHEN (datain_ipd(16) = '1') ELSE
                     '0';
   tmp_datain(17) <= '1' WHEN (datain_ipd(17) = '1') ELSE
                     '0';
   tmp_datain(18) <= '1' WHEN (datain_ipd(18) = '1') ELSE
                     '0';
   tmp_datain(19) <= '1' WHEN (datain_ipd(19) = '1') ELSE
                     '0';
   tmp_datain(20) <= '1' WHEN (datain_ipd(20) = '1') ELSE
                     '0';
   tmp_datain(21) <= '1' WHEN (datain_ipd(21) = '1') ELSE
                     '0';
   tmp_datain(22) <= '1' WHEN (datain_ipd(22) = '1') ELSE
                     '0';
   tmp_datain(23) <= '1' WHEN (datain_ipd(23) = '1') ELSE
                     '0';
   tmp_datain(24) <= '1' WHEN (datain_ipd(24) = '1') ELSE
                     '0';
   tmp_datain(25) <= '1' WHEN (datain_ipd(25) = '1') ELSE
                     '0';
   tmp_datain(26) <= '1' WHEN (datain_ipd(26) = '1') ELSE
                     '0';
   tmp_datain(27) <= '1' WHEN (datain_ipd(27) = '1') ELSE
                     '0';
   tmp_datain(28) <= '1' WHEN (datain_ipd(28) = '1') ELSE
                     '0';
   tmp_datain(29) <= '1' WHEN (datain_ipd(29) = '1') ELSE
                     '0';
   tmp_datain(30) <= '1' WHEN (datain_ipd(30) = '1') ELSE
                     '0';
   tmp_datain(31) <= '1' WHEN (datain_ipd(31) = '1') ELSE
                     '0';
   tmp_datain(32) <= '1' WHEN (datain_ipd(32) = '1') ELSE
                     '0';
   tmp_datain(33) <= '1' WHEN (datain_ipd(33) = '1') ELSE
                     '0';
   tmp_datain(34) <= '1' WHEN (datain_ipd(34) = '1') ELSE
                     '0';
   tmp_datain(35) <= '1' WHEN (datain_ipd(35) = '1') ELSE
                     '0';
   tmp_datain(36) <= '1' WHEN (datain_ipd(36) = '1') ELSE
                     '0';
   tmp_datain(37) <= '1' WHEN (datain_ipd(37) = '1') ELSE
                     '0';
   tmp_datain(38) <= '1' WHEN (datain_ipd(38) = '1') ELSE
                     '0';
   tmp_datain(39) <= '1' WHEN (datain_ipd(39) = '1') ELSE
                     '0';
   
   pi_in_txd_ch_tmp(7 DOWNTO 0) <= tmp_datain(7 DOWNTO 0);
   pi_in_txd_ch_tmp(8) <= tmp_ctrlenable(0) WHEN (cram_rendec_tx = '1') ELSE
                          tmp_datain(8) WHEN (cram_rpmadwidth_tx = '1') ELSE
                          'X';
   pi_in_txd_ch_tmp(9) <= tmp_forcedisp(0) WHEN (cram_rendec_tx = '1') ELSE
                          tmp_datain(9) WHEN (cram_rpmadwidth_tx = '1') ELSE
                          'X';
   pi_in_txd_ch_tmp(10) <= tmp_dispval(0) WHEN (cram_rendec_tx = '1') ELSE
                           'X';
   
   pi_in_txd_ch_tmp(18 DOWNTO 11) <= tmp_datain(15 DOWNTO 8) WHEN (cram_rendec_tx = '1' OR cram_rpmadwidth_tx = '0') ELSE
                                     tmp_datain(17 DOWNTO 10);
   pi_in_txd_ch_tmp(19) <= tmp_ctrlenable(1) WHEN (cram_rendec_tx = '1') ELSE
                           tmp_datain(18) WHEN (cram_rpmadwidth_tx = '1') ELSE
                           'X';
   pi_in_txd_ch_tmp(20) <= tmp_forcedisp(1) WHEN (cram_rendec_tx = '1') ELSE
                           tmp_datain(19) WHEN (cram_rpmadwidth_tx = '1') ELSE
                           'X';
   pi_in_txd_ch_tmp(21) <= tmp_dispval(1) WHEN (cram_rendec_tx = '1') ELSE
                           'X';
   
   pi_in_txd_ch_tmp(29 DOWNTO 22) <= tmp_datain(23 DOWNTO 16) WHEN (cram_rendec_tx = '1' OR cram_rpmadwidth_tx = '0') ELSE
                                     tmp_datain(27 DOWNTO 20);
   pi_in_txd_ch_tmp(30) <= tmp_ctrlenable(2) WHEN (cram_rendec_tx = '1') ELSE
                           tmp_datain(28) WHEN (cram_rpmadwidth_tx = '1') ELSE
                           'X';
   pi_in_txd_ch_tmp(31) <= tmp_forcedisp(2) WHEN (cram_rendec_tx = '1') ELSE
                           tmp_datain(29) WHEN (cram_rpmadwidth_tx = '1') ELSE
                           'X';
   pi_in_txd_ch_tmp(32) <= tmp_dispval(2) WHEN (cram_rendec_tx = '1') ELSE
                           'X';
   
   pi_in_txd_ch_tmp(40 DOWNTO 33) <= tmp_datain(31 DOWNTO 24) WHEN (cram_rendec_tx = '1' OR cram_rpmadwidth_tx = '0') ELSE
                                     tmp_datain(37 DOWNTO 30);
   pi_in_txd_ch_tmp(41) <= tmp_ctrlenable(3) WHEN (cram_rendec_tx = '1') ELSE
                           tmp_datain(38) WHEN (cram_rpmadwidth_tx = '1') ELSE
                           'X';
   pi_in_txd_ch_tmp(42) <= tmp_forcedisp(3) WHEN (cram_rendec_tx = '1') ELSE
                           tmp_datain(39) WHEN (cram_rpmadwidth_tx = '1') ELSE
                           'X';
   pi_in_txd_ch_tmp(43) <= tmp_dispval(3) WHEN (cram_rendec_tx = '1') ELSE
                           'X';
   
   --interleaving
   pi_in_txd_ch(10 DOWNTO 0) <= pi_in_txd_ch_tmp(10 DOWNTO 0);
   pi_in_txd_ch(32 DOWNTO 22) <= pi_in_txd_ch_tmp(21 DOWNTO 11) WHEN (cram_rdwidth_tx = '1' AND cram_rpma_doublewidth_tx = '0') ELSE
                                 pi_in_txd_ch_tmp(32 DOWNTO 22);
   pi_in_txd_ch(21 DOWNTO 11) <= pi_in_txd_ch_tmp(32 DOWNTO 22) WHEN (cram_rdwidth_tx = '1' AND cram_rpma_doublewidth_tx = '0') ELSE
                                 pi_in_txd_ch_tmp(21 DOWNTO 11);
   pi_in_txd_ch(43 DOWNTO 33) <= pi_in_txd_ch_tmp(43 DOWNTO 33);
   
    pi_in_txd_ch_dprio <=  datainfull WHEN ((dprio_config_mode AND DPRIO_CHANNEL_INTERFACE_BIT) = "000100") ELSE pi_in_txd_ch;
   
   --///////////////////////////////////////////////////////////////////////////////
   -- Connect Atom level output to appropriate RTL  - PORT_OUT_Table ------------ //
   --///////////////////////////////////////////////////////////////////////////////
   
   clkout <= td_out_tx_clk_out;
   dataout <= td_out_pudr;
   parallelfdbkout <= td_out_txlp20b;
   phfifooverflow <= td_out_full_tx;
   phfifounderflow <= td_out_empty_tx;
   
   pipepowerdownout <= td_out_powerdown_int;		-- powerdn_ipd;
   pipepowerstateout <= pi_out_powerstate(3 DOWNTO 0);
   rdenablesync <= td_out_rd_enable_sync;
   txdetectrx <= pi_out_txdetectrx;		-- NEW
   xgmctrlenable <= td_out_tx_ctl_tc;
   xgmdataout <= td_out_tx_data_tc;
   
   coreclkout <= coreclk_ipd;
   hiptxclkout <= hs_out_hip_tx_clk;
   iqpphfifobyteselout <= td_out_fifo_select_out_pipe;
   iqpphfifordclkout <= td_out_tx_div2_sync_out_pipe;
   iqpphfifordenableout <= td_out_rd_enable_out_pipe;
   iqpphfifowrenableout <= td_out_wr_enable_out_pipe;
   phfiforddisableout <= phfiforddisable;
   phfiforesetout <= phfiforeset;
   phfifowrenableout <= phfifowrenable;
    
   grayelecidleinferselout <= td_out_gray_eidleinfersel;
   pipeenrevparallellpbkout <= pi_out_rev_loopbk;

   -- q90 ww47 fix ---------------------------------------------------------------
   forceelecidleout     <= pi_out_tx_elec_idle;
   
   --///////////////////////////////////////////////////////////////////////////////
   -- tx sub-block instantiation: pcs_reset --------------------------------------//
   --///////////////////////////////////////////////////////////////////////////////
   
   pr_in_hard_reset <= '1' WHEN (quadreset = '1') ELSE		-- from top
                       '0';
   pr_in_clk_2_b <= '0';		-- for rx side 
   pr_in_refclk_b_in <= td_out_refclk_b;
   pr_in_scan_mode <= '0';
   pr_in_rxpcs_rst <= '0';		-- for rx side
   pr_in_txpcs_rst <= '1' WHEN (digitalreset = '1') ELSE		-- from top
                      '0';
   
   tx_pcs_reset_1 : stratixiv_hssi_pcs_reset
      PORT MAP (
         hard_reset   => pr_in_hard_reset,
         clk_2_b      => pr_in_clk_2_b,
         refclk_b_in  => pr_in_refclk_b_in,
         scan_mode    => pr_in_scan_mode,
         rxpcs_rst    => pr_in_rxpcs_rst,
         txpcs_rst    => pr_in_txpcs_rst,
         rxrst_int    => rxrst_int_wire,
         txrst_int    => pr_out_txrst_int
      );
   
   --///////////////////////////////////////////////////////////////////////////////
   -- tx sub-block instantiation: chnl_hip_support -------------------------------//
   --///////////////////////////////////////////////////////////////////////////////
   
   hs_in_eidleinfersel_ch <= elecidleinfersel_in;
   hs_in_hip_eidleinfersel_ch <= hipelecidleinfersel_in;
   hs_in_hip_powerdown_ch <= hippowerdn_in;
   hs_in_hip_rate <= 'X';
   hs_in_hip_rxpolarity <= 'X';
   hs_in_hip_txd_ch <= hipdatain_in;
   hs_in_hip_txdeemph <= hiptxdeemph_in;
   hs_in_hip_txdetectrxloopback <= hipdetectrxloop_in;
   hs_in_hip_txelecidle <= hipforceelecidle_in;
   hs_in_hip_txmargin_ch <= hiptxmargin_in;
   hs_in_pcs_phystatus <= 'X';
   hs_in_pcs_rxd_ch <= "XXXXXXXXX";
   hs_in_pcs_rxelecidle <= 'X';
   hs_in_pcs_rxstatus_ch <= "00X";
   hs_in_pcs_rxvalid <= 'X';
   hs_in_powerdown_ch <= powerdn_ipd;
   hs_in_rate <= 'X';
   hs_in_rhip_ena <= cram_rhip_ena;
   hs_in_rxpolarity <= 'X';
   hs_in_txd_ch <= pi_in_txd_ch_dprio(10 DOWNTO 0);
   hs_in_txdeemph <= pipetxdeemph_ipd;
   hs_in_txdetectrxloopback <= detectrxloop_ipd;
   hs_in_txmargin_ch <= pipetxmargin_ipd;
   hs_in_txpma_local_clk <= localrefclk;
   
   mtx_hs : stratixiv_hssi_digi_chnl_hip_spt
      PORT MAP (
         
         eidleinfersel_ch        => hs_in_eidleinfersel_ch,
         hip_eidleinfersel_ch    => hs_in_hip_eidleinfersel_ch,
         hip_powerdown_ch        => hs_in_hip_powerdown_ch,
         hip_rate                => hs_in_hip_rate,
         hip_rxpolarity          => hs_in_hip_rxpolarity,
         hip_txd_ch              => hs_in_hip_txd_ch,
         hip_txdeemph            => hs_in_hip_txdeemph,
         hip_txdetectrxloopback  => hs_in_hip_txdetectrxloopback,
         hip_txelecidle          => hs_in_hip_txelecidle,
         hip_txmargin_ch         => hs_in_hip_txmargin_ch,
         pcs_phystatus           => hs_in_pcs_phystatus,
         pcs_rxd_ch              => hs_in_pcs_rxd_ch,
         pcs_rxelecidle          => hs_in_pcs_rxelecidle,
         pcs_rxstatus_ch         => hs_in_pcs_rxstatus_ch,
         pcs_rxvalid             => hs_in_pcs_rxvalid,
         powerdown_ch            => hs_in_powerdown_ch,
         rate                    => hs_in_rate,
         rhip_ena                => hs_in_rhip_ena,
         rxpolarity              => hs_in_rxpolarity,
         txd_ch                  => hs_in_txd_ch,
         txdeemph                => hs_in_txdeemph,
         txdetectrxloopback      => hs_in_txdetectrxloopback,
         txmargin_ch             => hs_in_txmargin_ch,
         txpma_local_clk         => hs_in_txpma_local_clk,
         
         hip_phystatus           => hs_out_hip_phystatus,
         hip_rxd_ch              => hs_out_hip_rxd_ch,
         hip_rxelecidle          => hs_out_hip_rxelecidle,
         hip_rxstatus_ch         => hs_out_hip_rxstatus_ch,
         hip_rxvalid             => hs_out_hip_rxvalid,
         hip_tx_clk              => hs_out_hip_tx_clk,
         pcs_eidleinfersel_ch    => hs_out_pcs_eidleinfersel_ch,
         pcs_powerdown_ch        => hs_out_pcs_powerdown_ch,
         pcs_rate                => hs_out_pcs_rate,
         pcs_rxpolarity          => hs_out_pcs_rxpolarity,
         pcs_txd_ch              => hs_out_pcs_txd_ch,
         pcs_txdeemph            => hs_out_pcs_txdeemph,
         pcs_txdetectrxloopback  => hs_out_pcs_txdetectrxloopback,
         pcs_txmargin_ch         => hs_out_pcs_txmargin_ch,
         phystatus               => hs_out_phystatus,
         rxd_ch                  => hs_out_rxd_ch,
         rxelecidle              => hs_out_rxelecidle,
         rxstatus_ch             => hs_out_rxstatus_ch,
         rxvalid                 => hs_out_rxvalid
      );
   
   --///////////////////////////////////////////////////////////////////////////////
   -- tx sub-block instantiation: pipe_interface ---------------------------------//
   --///////////////////////////////////////////////////////////////////////////////
   
   pi_in_pipe_tx_clk <= '0' WHEN (cram_rtx_pipe_enable = '0') ELSE
                        td_out_tx_pipe_clk;
   pi_in_powerdown <= td_out_powerdown_int;		-- powerdn_ipd;            
   pi_in_refclk_b <= '0' WHEN (cram_rtx_pipe_enable = '0') ELSE
                     td_out_refclk_b;
   pi_in_refclk_b_reset_n <= NOT(pr_out_txrst_int);
   pi_in_revloopback <= td_out_revloopback_int;		-- (enrevparallellpbk_ipd === 1'b1) ? 1'b1 : 1'b0; 
   pi_in_tx_elec_idle_comp <= td_out_tx_pipe_electidle;
   pi_in_tx_pipe_reset_n <= NOT(td_out_tx_pipe_soft_reset);
   pi_in_txdetectrxloopback <= td_out_txdetectrxloopback_int;		-- (detectrxloop_ipd === 1'b1) ? 1'b1 : 1'b0;
   pi_in_txelecidle <= forceelecidle_ipd;
   pi_in_state_transition_done <= pipestatetransdone;
   
   -- new interfaces in STRATIXIV
   pi_in_txdeemph <= td_out_phfifo_txdeemph;
   pi_in_txmargin <= td_out_phfifo_txmargin;
   pi_in_txswing  <= td_out_phfifo_txswing;
   
   tx_pipe_interface_inst : stratixiv_hssi_tx_pipe_interface
      PORT MAP (
         clk                  => pi_in_pipe_tx_clk,
         refclk_b             => pi_in_refclk_b,
         refclk_b_reset_n     => pi_in_refclk_b_reset_n,
         reset_n              => pi_in_tx_pipe_reset_n,
         rtx_pipe_enable      => cram_rtx_pipe_enable,
         rtx_elec_idle_delay  => cram_rtx_elec_idle_delay,
         txdetectrxloopback   => pi_in_txdetectrxloopback,
         txelecidle           => pi_in_txelecidle,
         powerdown            => pi_in_powerdown,
         txd_ch               => pi_in_txd_ch_dprio,
         revloopback          => pi_in_revloopback,
         txd                  => pi_out_txd,
         rev_loopbk           => pi_out_rev_loopbk,
         tx_elec_idle_comp    => pi_in_tx_elec_idle_comp,
         tx_elec_idle         => pi_out_tx_elec_idle,
         txdetectrx           => pi_out_txdetectrx,
         powerstate           => pi_out_powerstate,
         
         -- new interfaces in STRATIXIV - ww26.5
         rtxswing_sel_ena     => cram_rtxswing_sel_ena,
         txdeemph             => pi_in_txdeemph,
         txmargin             => pi_in_txmargin,
         txswing              => pi_in_txswing,
         txdeemph_int         => pi_out_txdeemph_int,
         txmargin_int         => pi_out_txmargin_int,
         txswing_int          => pi_out_txswing_int
      );
   
   --///////////////////////////////////////////////////////////////////////////////
   -- tx sub-block instantiation: tx_digi ----------------------------------------//
   --///////////////////////////////////////////////////////////////////////////////
   
   td_in_phfifourst_tx <= '1' WHEN (phfiforeset = '1') ELSE
                          '0';
   td_in_pld_tx_clk <= coreclk;		-- coreclk_ipd;
   td_in_polinv_tx <= '1' WHEN (invpol_ipd = '1') ELSE
                      '0';
   td_in_rddisable_tx <= '1' WHEN (phfiforddisable = '1') ELSE		-- enable by default
                         '0';
   td_in_refclk_pma <= refclk_ipd;
   td_in_rev_loop_data <= revparallelfdbk;
   td_in_rev_loopbk <= pi_out_rev_loopbk;
   td_in_tx_data_ts <= xgmdatain;
   td_in_tx_ctl_ts <= xgmctrl;
   td_in_txd <= (pi_in_txd_ch_dprio(43 DOWNTO 11) & hs_out_pcs_txd_ch);		--pi_in_txd_ch_dprio; // pi_out_txd - 44 bit
   td_in_txpcs_rst <= pr_out_txrst_int;
   td_in_txpma_local_clk <= localrefclk;
   td_in_wrenable_tx <= '0' WHEN (phfifowrenable_ipd = '0') ELSE		-- enable by default 
                        '1';
   
   td_in_gen2ngen1 <= '1' WHEN (rateswitchisdone = '1') ELSE		--from tx_pma local clk divider
                      '0';
   td_in_gen2ngen1_bundle <= '1' WHEN (rateswitchxndone = '1') ELSE		--from central clk divider
                             '0';
   td_in_polinv_rx <= '0';		-- leaving it out of tx as it is a simple wire in tx_ctrl 
   td_in_powerdown <= hs_out_pcs_powerdown_ch;		-- powerdn_ipd;	
   td_in_revloopback <= '1' WHEN (enrevparallellpbk_ipd = '1') ELSE
                        '0';
   td_in_rxpolarity <= '0';		--// leaving it out of tx as it is a simple wire in tx_ctrl
   td_in_txdetectrxloopback <= hs_out_pcs_txdetectrxloopback;		-- (detectrxloop_ipd === 1'b1) ? 1'b1 : 1'b0;
   
   td_in_prbs_cid_en <= prbscidenable_in;
   td_in_tx_boundary_sel <= bitslipboundaryselect_in;
   
   -- new signal inputs for bundling
   -- temporary disabled by forcing rindv_tx = 1'b0 todo
   td_in_tx_div2_sync_in_centrl <= phfifoxnrdclk_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   td_in_tx_div2_sync_in_quad_up <= phfifoxnrdclk_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   td_in_tx_div2_sync_in_quad_down <= phfifoxnrdclk_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   td_in_wr_enable_in_centrl <= phfifoxnwrenable_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   td_in_wr_enable_in_quad_up <= phfifoxnwrenable_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   td_in_wr_enable_in_quad_down <= phfifoxnwrenable_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   td_in_rd_enable_in_centrl <= phfifoxnrdenable_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   td_in_rd_enable_in_quad_up <= phfifoxnrdenable_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   td_in_rd_enable_in_quad_down <= phfifoxnrdenable_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   td_in_fifo_select_in_centrl <= phfifoxnbytesel_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   td_in_fifo_select_in_quad_up <= phfifoxnbytesel_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   td_in_fifo_select_in_quad_down <= phfifoxnbytesel_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   td_in_reset_pc_ptrs <= phfifoptrsreset_in;		-- from rx
   td_in_reset_pc_ptrs_in_centrl <= phfifoxnptrsreset_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   td_in_reset_pc_ptrs_in_quad_up <= phfifoxnptrsreset_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   td_in_reset_pc_ptrs_in_quad_down <= phfifoxnptrsreset_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   
   td_in_tx_div2_sync_in_pipe_quad_up <= iqpphfifoxnrdclk_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   td_in_tx_div2_sync_in_pipe_quad_down <= iqpphfifoxnrdclk_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   td_in_wr_enable_in_pipe_quad_up <= iqpphfifoxnwrenable_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   td_in_wr_enable_in_pipe_quad_down <= iqpphfifoxnwrenable_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   td_in_rd_enable_in_pipe_quad_up <= iqpphfifoxnrdenable_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   td_in_rd_enable_in_pipe_quad_down <= iqpphfifoxnrdenable_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   td_in_fifo_select_in_pipe_quad_up <= iqpphfifoxnbytesel_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   td_in_fifo_select_in_pipe_quad_down <= iqpphfifoxnbytesel_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   
   td_in_dis_pc_byte <= phfifobyteserdisable_in;		-- from rx
   
   -- push through TX Phase Comp FIFO
   td_in_txswing      <= pipetxswing_ipd; 		    --ww12_new conne
   td_in_pcs_txdeemph <= hs_out_pcs_txdeemph; 		--ww12_new conne
   td_in_pcs_txmargin <= hs_out_pcs_txmargin_ch;	--ww12_new conne
   
   -- RX PIPE interface signals
   td_in_eidleinfersel <= hs_out_pcs_eidleinfersel_ch;
   
   td_out_tx_div2_sync_out_pipe <= td_out_tx_div2_sync_out_pipe_up WHEN (cram_rmaster_up_tx = '0') ELSE
                                   td_out_tx_div2_sync_out_pipe_down;
   td_out_fifo_select_out_pipe <= td_out_fifo_select_out_pipe_up WHEN (cram_rmaster_up_tx = '0') ELSE
                                  td_out_fifo_select_out_pipe_down;
   td_out_wr_enable_out_pipe <= td_out_wr_enable_out_pipe_up WHEN (cram_rmaster_up_tx = '0') ELSE
                                td_out_wr_enable_out_pipe_down;
   td_out_rd_enable_out_pipe <= td_out_rd_enable_out_pipe_up WHEN (cram_rmaster_up_tx = '0') ELSE
                                td_out_rd_enable_out_pipe_down;
   
   digi_tx_1 : stratixiv_hssi_tx_digi
      PORT MAP (
         empty_tx                        => td_out_empty_tx,
         encoder_testbus                 => td_out_encoder_testbus,
         full_tx                         => td_out_full_tx,
         phfifourst_tx                   => td_in_phfifourst_tx,
         pld_tx_clk                      => td_in_pld_tx_clk,
         polinv_tx                       => td_in_polinv_tx,
         pudr                            => td_out_pudr,
         r8b10b_enc_ibm_en               => cram_r8b10b_enc_ibm_en,
         rbist_sel                       => cram_rbist_sel,
         rbisten_tx                      => cram_rbisten_tx,
         rcascaded_8b10b_en_tx           => cram_rcascaded_8b10b_en_tx,
         rcxpat_chnl_en                  => cram_rcxpat_chnl_en,
         rd_enable_sync                  => td_out_rd_enable_sync,
         rddisable_tx                    => td_in_rddisable_tx,
         rdwidth_tx                      => cram_rdwidth_tx,
         refclk_b                        => td_out_refclk_b,
         refclk_pma                      => td_in_refclk_pma,
         renbitrev_tx                    => cram_renbitrev_tx,
         rendec_data_sel_tx              => cram_rendec_data_sel_tx,
         rendec_tx                       => cram_rendec_tx,
         renpolinv_tx                    => cram_renpolinv_tx,
         rensymswap_tx                   => cram_rensymswap_tx,
         rev_loop_data                   => td_in_rev_loop_data,
         rev_loopbk                      => td_in_rev_loopbk,
         rforce_disp                     => cram_rforce_disp,
         rforce_echar                    => cram_rforce_echar,
         rforce_kchar                    => cram_rforce_kchar,
         rfreerun_tx                     => cram_rfreerun_tx,
         rge_xaui_tx                     => cram_rge_xaui_tx,
         rib_force_disp                  => cram_rib_force_disp,
         rindv_tx                        => cram_rindv_tx,
         rphfifopldentx                  => cram_rphfifopldentx,
         rphfifoursttx                   => cram_rphfifoursttx,
         rpma_doublewidth_tx             => cram_rpma_doublewidth_tx,
         rpmadwidth_tx                   => cram_rpmadwidth_tx,
         rprbs_sel                       => cram_rprbs_sel,
         rprbsen_tx                      => cram_rprbsen_tx,
         rrev_loopbk                     => cram_rrev_loopbk,
         rtx_pipe_enable                 => cram_rtx_pipe_enable,
         rtxfifo_dis                     => cram_rtxfifo_dis,
         rtxfifo_lowlatency_en           => cram_rtxfifo_lowlatency_en,
         rtxrdclksel                     => cram_rtxrdclksel,
         rtxwrclksel                     => cram_rtxwrclksel,
         scan_mode                       => cram_scan_mode,
         tx_clk_out                      => td_out_tx_clk_out,
         tx_ctl_tc                       => td_out_tx_ctl_tc,
         tx_ctl_ts                       => td_in_tx_ctl_ts,
         tx_ctrl_testbus                 => td_out_tx_ctrl_testbus,
         tx_data_tc                      => td_out_tx_data_tc,
         tx_data_ts                      => td_in_tx_data_ts,
         tx_pipe_clk                     => td_out_tx_pipe_clk,
         tx_pipe_electidle               => td_out_tx_pipe_electidle,
         tx_pipe_soft_reset              => td_out_tx_pipe_soft_reset,
         txd                             => td_in_txd,
         txlp20b                         => td_out_txlp20b,
         txpcs_rst                       => td_in_txpcs_rst,
         txpma_local_clk                 => td_in_txpma_local_clk,
         wrenable_tx                     => td_in_wrenable_tx,
         
         gen2ngen1                       => td_in_gen2ngen1,
         gen2ngen1_bundle                => td_in_gen2ngen1_bundle,
         polinv_rx                       => td_in_polinv_rx,
         powerdown                       => td_in_powerdown,
         revloopback                     => td_in_revloopback,
         rxpolarity                      => td_in_rxpolarity,
         txdetectrxloopback              => td_in_txdetectrxloopback,
         
         rauto_speed_ena                 => cram_rauto_speed_ena,
         rfreq_sel                       => cram_rfreq_sel,
         rtxpcsbypass_en                 => cram_rtxpcsbypass_en,
         rtxpcsclkpwdn                   => cram_rtxpcsclkpwdn,
         
         polinv_rx_int                   => td_out_polinv_rx_int,
         powerdown_int                   => td_out_powerdown_int,
         revloopback_int                 => td_out_revloopback_int,
         rxpolarity_int                  => td_out_rxpolarity_int,
         txdetectrxloopback_int          => td_out_txdetectrxloopback_int,
         
         prbs_cid_en                     => td_in_prbs_cid_en,
         tx_boundary_sel                 => td_in_tx_boundary_sel,
         rcid_pattern_tx                 => cram_rcid_pattern_tx,
         rcid_len_tx                     => cram_rcid_len_tx,
         
         tx_div2_sync_in_centrl          => td_in_tx_div2_sync_in_centrl,
         tx_div2_sync_in_quad_up         => td_in_tx_div2_sync_in_quad_up,
         tx_div2_sync_in_quad_down       => td_in_tx_div2_sync_in_quad_down,
         wr_enable_in_centrl             => td_in_wr_enable_in_centrl,
         wr_enable_in_quad_up            => td_in_wr_enable_in_quad_up,
         wr_enable_in_quad_down          => td_in_wr_enable_in_quad_down,
         rd_enable_in_centrl             => td_in_rd_enable_in_centrl,
         rd_enable_in_quad_up            => td_in_rd_enable_in_quad_up,
         rd_enable_in_quad_down          => td_in_rd_enable_in_quad_down,
         fifo_select_in_centrl           => td_in_fifo_select_in_centrl,
         fifo_select_in_quad_up          => td_in_fifo_select_in_quad_up,
         fifo_select_in_quad_down        => td_in_fifo_select_in_quad_down,
         reset_pc_ptrs                   => td_in_reset_pc_ptrs,
         reset_pc_ptrs_in_centrl         => td_in_reset_pc_ptrs_in_centrl,
         reset_pc_ptrs_in_quad_up        => td_in_reset_pc_ptrs_in_quad_up,
         reset_pc_ptrs_in_quad_down      => td_in_reset_pc_ptrs_in_quad_down,
         tx_div2_sync_in_pipe_quad_up    => td_in_tx_div2_sync_in_pipe_quad_up,
         tx_div2_sync_in_pipe_quad_down  => td_in_tx_div2_sync_in_pipe_quad_down,
         wr_enable_in_pipe_quad_up       => td_in_wr_enable_in_pipe_quad_up,
         wr_enable_in_pipe_quad_down     => td_in_wr_enable_in_pipe_quad_down,
         rd_enable_in_pipe_quad_up       => td_in_rd_enable_in_pipe_quad_up,
         rd_enable_in_pipe_quad_down     => td_in_rd_enable_in_pipe_quad_down,
         fifo_select_in_pipe_quad_up     => td_in_fifo_select_in_pipe_quad_up,
         fifo_select_in_pipe_quad_down   => td_in_fifo_select_in_pipe_quad_down,
         
         dis_pc_byte                     => td_in_dis_pc_byte,
         
         rmaster_tx                      => cram_rmaster_tx,
         rmaster_up_tx                   => cram_rmaster_up_tx,
         rself_sw_en_tx                  => cram_rself_sw_en_tx,
         rpipeline_bypass_tx             => cram_rpipeline_bypass_tx,
         rphfifo_regmode_tx              => cram_rphfifo_regmode_tx,
         
         tx_div2_sync_out_pipe_up        => td_out_tx_div2_sync_out_pipe_up,
         fifo_select_out_pipe_up         => td_out_fifo_select_out_pipe_up,
         wr_enable_out_pipe_up           => td_out_wr_enable_out_pipe_up,
         rd_enable_out_pipe_up           => td_out_rd_enable_out_pipe_up,
         tx_div2_sync_out_pipe_down      => td_out_tx_div2_sync_out_pipe_down,
         fifo_select_out_pipe_down       => td_out_fifo_select_out_pipe_down,
         wr_enable_out_pipe_down         => td_out_wr_enable_out_pipe_down,
         rd_enable_out_pipe_down         => td_out_rd_enable_out_pipe_down,
         
         txswing                         => td_in_txswing,
         pcs_txdeemph                    => td_in_pcs_txdeemph,
         pcs_txmargin                    => td_in_pcs_txmargin,
         eidleinfersel                   => td_in_eidleinfersel,
         
         phfifo_txswing                  => td_out_phfifo_txswing,
         phfifo_txdeemph                 => td_out_phfifo_txdeemph,
         phfifo_txmargin                 => td_out_phfifo_txmargin,
         gray_eidleinfersel              => td_out_gray_eidleinfersel,
         
         rtxbitslip_en                   => cram_rtxbitslip_en
      );
   
END trans;

-- stratixiigx_hssi_transmitter 


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_rx_digis_ram8x70_syn IS
   GENERIC (
      
      read_access_time   : INTEGER := 0;
      write_access_time  : INTEGER := 0;
      ram_width          : INTEGER := 70
   );
   PORT (
      rst_l              : IN STD_LOGIC;
      clk                : IN STD_LOGIC;
      fifo_wr            : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
      data_in            : IN STD_LOGIC_VECTOR(69 DOWNTO 0);
      fifo_re            : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
      data_out           : OUT STD_LOGIC_VECTOR(69 DOWNTO 0)
   );
END stratixiv_hssi_rx_digis_ram8x70_syn;

ARCHITECTURE trans OF stratixiv_hssi_rx_digis_ram8x70_syn IS
   
   SIGNAL data_out_i    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_0 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_1 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_2 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_3 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_4 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_5 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_6 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_7 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_0 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_1 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_2 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_3 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_4 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_5 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_6 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_7 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   
   SIGNAL data_reg_0    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_1    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_2    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_3    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_4    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_5    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_6    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_7    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   
   SIGNAL we            : STD_LOGIC;
   SIGNAL re_l          : STD_LOGIC;
BEGIN
   
   we <= '1';
   re_l <= '0';
   
   --assignment
   data_reg_0 <= data_in WHEN (fifo_wr(0) = '1') ELSE
                 ram_array_q_0;
   data_reg_1 <= data_in WHEN (fifo_wr(1) = '1') ELSE
                 ram_array_q_1;
   data_reg_2 <= data_in WHEN (fifo_wr(2) = '1') ELSE
                 ram_array_q_2;
   data_reg_3 <= data_in WHEN (fifo_wr(3) = '1') ELSE
                 ram_array_q_3;
   data_reg_4 <= data_in WHEN (fifo_wr(4) = '1') ELSE
                 ram_array_q_4;
   data_reg_5 <= data_in WHEN (fifo_wr(5) = '1') ELSE
                 ram_array_q_5;
   data_reg_6 <= data_in WHEN (fifo_wr(6) = '1') ELSE
                 ram_array_q_6;
   data_reg_7 <= data_in WHEN (fifo_wr(7) = '1') ELSE
                 ram_array_q_7;
   
   data_out <= "0000000000000000000000000000000000000000000000000000000000000000000000" WHEN (re_l = '1') ELSE
               data_out_i;
   
   PROCESS (ram_array_q_0, ram_array_q_1, ram_array_q_2, ram_array_q_3, ram_array_q_4, ram_array_q_5, ram_array_q_6, ram_array_q_7, fifo_re)
VARIABLE  txt : LINE;
   BEGIN
      CASE fifo_re IS		-- synopsys parallel_case full_case
         WHEN "00000001" =>
            data_out_i <= ram_array_q_0;
         WHEN "00000010" =>
            data_out_i <= ram_array_q_1;
         WHEN "00000100" =>
            data_out_i <= ram_array_q_2;
         WHEN "00001000" =>
            data_out_i <= ram_array_q_3;
         WHEN "00010000" =>
            data_out_i <= ram_array_q_4;
         WHEN "00100000" =>
            data_out_i <= ram_array_q_5;
         WHEN "01000000" =>
            data_out_i <= ram_array_q_6;
         WHEN "10000000" =>
            data_out_i <= ram_array_q_7;
         WHEN OTHERS =>
            data_out_i <= ram_array_q_0;
      END CASE;
   END PROCESS;
   
   PROCESS (clk, rst_l)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rst_l)) = '1') THEN
         ram_array_q_0 <=  TRANSPORT "0000100000000000000000000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_1 <=  TRANSPORT "0000100000000000000000000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_2 <=  TRANSPORT "0000100000000000000000000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_3 <=  TRANSPORT "0000100000000000000000000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_4 <=  TRANSPORT "0000100000000000000000000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_5 <=  TRANSPORT "0000100000000000000000000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_6 <=  TRANSPORT "0000100000000000000000000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_7 <=  TRANSPORT "0000100000000000000000000000000000000000000000000000000000000000000000" AFTER (write_access_time)*1 ps;
      ELSIF (clk'EVENT AND clk = '1') THEN
         ram_array_q_0 <=  TRANSPORT ram_array_d_0 AFTER (write_access_time)*1 ps;
         ram_array_q_1 <=  TRANSPORT ram_array_d_1 AFTER (write_access_time)*1 ps;
         ram_array_q_2 <=  TRANSPORT ram_array_d_2 AFTER (write_access_time)*1 ps;
         ram_array_q_3 <=  TRANSPORT ram_array_d_3 AFTER (write_access_time)*1 ps;
         ram_array_q_4 <=  TRANSPORT ram_array_d_4 AFTER (write_access_time)*1 ps;
         ram_array_q_5 <=  TRANSPORT ram_array_d_5 AFTER (write_access_time)*1 ps;
         ram_array_q_6 <=  TRANSPORT ram_array_d_6 AFTER (write_access_time)*1 ps;
         ram_array_q_7 <=  TRANSPORT ram_array_d_7 AFTER (write_access_time)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (we, data_reg_0, data_reg_1, data_reg_2, data_reg_3, data_reg_4, data_reg_5, data_reg_6, data_reg_7, ram_array_q_0, ram_array_q_1, ram_array_q_2, ram_array_q_3, ram_array_q_4, ram_array_q_5, ram_array_q_6, ram_array_q_7)
VARIABLE  txt : LINE;
   BEGIN
      IF (we = '1') THEN
         ram_array_d_0 <= data_reg_0;
         ram_array_d_1 <= data_reg_1;
         ram_array_d_2 <= data_reg_2;
         ram_array_d_3 <= data_reg_3;
         ram_array_d_4 <= data_reg_4;
         ram_array_d_5 <= data_reg_5;
         ram_array_d_6 <= data_reg_6;
         ram_array_d_7 <= data_reg_7;
      ELSE
         ram_array_d_0 <= ram_array_q_0;
         ram_array_d_1 <= ram_array_q_1;
         ram_array_d_2 <= ram_array_q_2;
         ram_array_d_3 <= ram_array_q_3;
         ram_array_d_4 <= ram_array_q_4;
         ram_array_d_5 <= ram_array_q_5;
         ram_array_d_6 <= ram_array_q_6;
         ram_array_d_7 <= ram_array_q_7;
      END IF;
   END PROCESS;
   
END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_rx_digis_ph_fifo IS
   PORT (
      -- inputs
      -- outputs
      
      -- =======
      -- inputs 
      -- =======
      rst_wclk                 : IN STD_LOGIC;
      rst_rclk                 : IN STD_LOGIC;
      wr_clk                   : IN STD_LOGIC;		-- Write Clock
      rd_clk                   : IN STD_LOGIC;		-- Read Clock
      en                       : IN STD_LOGIC;		-- Disable FIFO or bypass - only for Altera internal debug
      lowlatency_en            : IN STD_LOGIC;		-- low latency enable
      we                       : IN STD_LOGIC;		-- PLD dynamic write pointer enable  
      re                       : IN STD_LOGIC;		-- PLD dynamic read pointer enable  
      din                      : IN STD_LOGIC_VECTOR(69 DOWNTO 0);		-- 10-bit code-group bus from deskew module.
      
      rphfifo_regmode_rx       : IN STD_LOGIC;
      rindv_rx                 : IN STD_LOGIC;
      rauto_speed_ena          : IN STD_LOGIC;
      reset_pc_ptrs            : IN STD_LOGIC;
      reset_pc_ptrs_centrl     : IN STD_LOGIC;
      reset_pc_ptrs_quad_up    : IN STD_LOGIC;
      reset_pc_ptrs_quad_down  : IN STD_LOGIC;
      rmaster_rx               : IN STD_LOGIC;
      rmaster_up_rx            : IN STD_LOGIC;
      
      -- =======
      -- outputs 
      -- =======
      -- Indicates overflow (rd_clk)
      -- FIFO empty (rd_clk)
      data_out                 : OUT STD_LOGIC_VECTOR(69 DOWNTO 0);		-- output data (rd_clk synchronous if not FIFO bypass)
      ph_fifo_full             : OUT STD_LOGIC;
      ph_fifo_empty            : OUT STD_LOGIC;
      wptr_bin                 : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);		-- test bus
      rptr_bin                 : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      pcs_wrapback_in          : IN STD_LOGIC_VECTOR(69 DOWNTO 0);
      rpcs_wrapback_en         : IN STD_LOGIC;
      scan_mode                : IN STD_LOGIC
   );
END stratixiv_hssi_rx_digis_ph_fifo;

ARCHITECTURE trans OF stratixiv_hssi_rx_digis_ph_fifo IS
   COMPONENT stratixiv_hssi_rx_digis_ram8x70_syn IS
      GENERIC (    
      read_access_time   : INTEGER := 0;
      write_access_time  : INTEGER := 0;
      ram_width          : INTEGER := 70
   );
      PORT (
         rst_l                    : IN STD_LOGIC;
         clk                      : IN STD_LOGIC;
         fifo_wr                  : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         data_in                  : IN STD_LOGIC_VECTOR(69 DOWNTO 0);
         fifo_re                  : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         data_out                 : OUT STD_LOGIC_VECTOR(69 DOWNTO 0)
      );
   END COMPONENT;
   
   
   -- ===================
   -- signal declaration
   -- ===================
   SIGNAL wptr                   : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL rptr                   : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL wptr_gray              : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL wptr_gray0             : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL wptr0                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL wptr1                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL wptr1_onehot           : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL rptr0_pre              : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL rptr0                  : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL rptr1                  : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL first_rd               : STD_LOGIC;
   SIGNAL ram_data_out           : STD_LOGIC_VECTOR(69 DOWNTO 0);
   SIGNAL ram_data_out_pre       : STD_LOGIC_VECTOR(69 DOWNTO 0);
   -- test bus
   -- test bus
   
   SIGNAL ph_fifo_empty_pre      : STD_LOGIC;
   
   SIGNAL rst_n                  : STD_LOGIC;		-- Invert rst for new FIFO     
   
   SIGNAL fifo_cnt               : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL fifo_cnt_pre           : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rptr1_bin              : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL wptr1_bin_rclk         : STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   SIGNAL reset_ptrs_local       : STD_LOGIC;
   
   SIGNAL reset_ptrs_local_sync1 : STD_LOGIC;
   SIGNAL reset_ptrs_local_sync2 : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL ph_fifo_full_xhdl0     : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   ph_fifo_full <= ph_fifo_full_xhdl0;
   
   -- =============
   -- functionality
   -- =============
   rst_n <= NOT(rst_wclk);
   
   -- bypass
   data_out(69 DOWNTO 0) <= ram_data_out WHEN (en = '1') ELSE
                            din;
   
   reset_ptrs_local <= rauto_speed_ena AND reset_pc_ptrs WHEN (rindv_rx = '1') ELSE
                       reset_pc_ptrs_centrl WHEN (rmaster_rx = '1') ELSE
                       reset_pc_ptrs_quad_up WHEN (rmaster_up_rx = '1') ELSE
                       reset_pc_ptrs_quad_down;
   
   -- write pointer
   PROCESS (rst_wclk, wr_clk)
   BEGIN
      IF (rst_wclk = '1') THEN
         wptr <=  TRANSPORT "00000001" AFTER 1 ps;
      ELSIF (wr_clk'EVENT AND wr_clk = '1') THEN
         IF (rphfifo_regmode_rx = '1') THEN
            wptr <=  TRANSPORT "00000001" AFTER 1 ps;
         ELSIF (reset_ptrs_local = '1') THEN
            wptr <=  TRANSPORT "00000001" AFTER 1 ps;
         ELSE
            IF (we = '1') THEN
               wptr <=  TRANSPORT (wptr(6 DOWNTO 0) & wptr(7)) AFTER 1 ps;
            END IF;
         END IF;
      END IF;
   END PROCESS;
   
   --newly added fifo_cnt and fifo_cnt_pre logic for full/empty flag use
   -- manually translated
   PROCESS(fifo_cnt_pre, rst_rclk, rptr1_bin, wptr1_bin_rclk)
   BEGIN
       IF (rptr1_bin = wptr1_bin_rclk) THEN
           IF (rst_rclk /= '1') THEN
               IF (fifo_cnt_pre = "0111" OR fifo_cnt_pre = "0110" OR fifo_cnt_pre = "1000") THEN
                   fifo_cnt <= "1000";
               ELSE
                   fifo_cnt <= "0000";
               END IF;    
           ELSE
               fifo_cnt <= "0000";
           END IF;
       ELSE
           IF (wptr1_bin_rclk > rptr1_bin) THEN
               fifo_cnt <= ('0' & (wptr1_bin_rclk - rptr1_bin));
           ELSE
               fifo_cnt <= ("1000" - ('0' & (rptr1_bin - wptr1_bin_rclk)));
           END IF;     
       END IF;
   END PROCESS;
   
   -- incorrect translation
   --fifo_cnt <= "1000" WHEN (fifo_cnt_pre = "0111" OR fifo_cnt_pre = "0110" OR fifo_cnt_pre = "1000") ELSE
   --            "0000" WHEN (rst_rclk /= '1') ELSE
   --            "0000" WHEN (rptr1_bin = wptr1_bin_rclk) ELSE
   --            ('0' & (wptr1_bin_rclk - rptr1_bin)) WHEN (wptr1_bin_rclk > rptr1_bin) ELSE
   --            ("1000" - ('0' & (rptr1_bin - wptr1_bin_rclk)));
   
   PROCESS (rst_rclk, rd_clk)
   BEGIN
      IF (rst_rclk = '1') THEN
         reset_ptrs_local_sync1 <=  TRANSPORT '0' AFTER 1 ps;
         reset_ptrs_local_sync2 <=  TRANSPORT '0' AFTER 1 ps;		-- if (rst_rclk == 1'b1)
      ELSIF (rd_clk'EVENT AND rd_clk = '1') THEN
         IF (rphfifo_regmode_rx = '1') THEN
            reset_ptrs_local_sync1 <=  TRANSPORT '0' AFTER 1 ps;
            reset_ptrs_local_sync2 <=  TRANSPORT '0' AFTER 1 ps;
         ELSE
            reset_ptrs_local_sync1 <=  TRANSPORT reset_ptrs_local AFTER 1 ps;
            reset_ptrs_local_sync2 <=  TRANSPORT reset_ptrs_local_sync1 AFTER 1 ps;
         END IF;
      END IF;
   END PROCESS;
   -- always @ (posedge rst_rclk or posedge rd_clk)

    --ECO for S4GX to fix metastability issue
    -- replace the 1st FF with new flop w/o reset
    -- replace the 2nd FF with an enhanced flop
    PROCESS (rd_clk)
    BEGIN
        IF (rd_clk'EVENT AND rd_clk = '1') THEN
            IF (reset_ptrs_local_sync2 = '1' OR rphfifo_regmode_rx = '1') THEN
                wptr0 <=  TRANSPORT "001" AFTER 1 ps;
            ELSE
                wptr0 <=  TRANSPORT wptr_gray AFTER 1 ps;
            END IF;
        END IF;
    END PROCESS;     -- always @ (posedge rst_rclk or posedge rd_clk)
   
    PROCESS(rst_rclk, rd_clk)
    BEGIN
        IF (rst_rclk = '1') THEN
            wptr1 <=  TRANSPORT "001" AFTER 1 ps;
        ELSIF (rd_clk'EVENT AND rd_clk = '1') THEN
            IF ((reset_ptrs_local_sync2 OR rphfifo_regmode_rx) = '1') THEN
                wptr1 <=  TRANSPORT "001" AFTER 1 ps;
            ELSE
                wptr1 <=  TRANSPORT wptr0 AFTER 1 ps;
            END IF;
        END IF;
   END PROCESS; -- always @ (posedge rst_rclk or posedge rd_clk)
         
   -- read pointer
   -- full & empty
   PROCESS (rst_rclk, rd_clk)
   BEGIN
      IF (rst_rclk = '1') THEN
         --wptr0 <=  TRANSPORT "001" AFTER 1 ps;
         --wptr1 <=  TRANSPORT "001" AFTER 1 ps;
         rptr <=  TRANSPORT "00100000" AFTER 1 ps;
         rptr0_pre <=  TRANSPORT "00010000" AFTER 1 ps;
         rptr0 <=  TRANSPORT "00010000" AFTER 1 ps;
         rptr1 <=  TRANSPORT "00010000" AFTER 1 ps;
         ph_fifo_full_xhdl0 <=  TRANSPORT '0' AFTER 1 ps;
         ph_fifo_empty <=  TRANSPORT '0' AFTER 1 ps;
         ph_fifo_empty_pre <=  TRANSPORT '0' AFTER 1 ps;
         first_rd <=  TRANSPORT '1' AFTER 1 ps;		-- fifo_cnt previous value
         fifo_cnt_pre <=  TRANSPORT "0000" AFTER 1 ps;		-- if (rst_rclk == 1'b1)
      ELSIF (rd_clk'EVENT AND rd_clk = '1') THEN
         IF ((reset_ptrs_local_sync2 OR rphfifo_regmode_rx) = '1') THEN
            --wptr0 <=  TRANSPORT "001" AFTER 1 ps;
            --wptr1 <=  TRANSPORT "001" AFTER 1 ps;
            rptr <=  TRANSPORT "00100000" AFTER 1 ps;
            rptr0_pre <=  TRANSPORT "00010000" AFTER 1 ps;
            rptr0 <=  TRANSPORT "00010000" AFTER 1 ps;
            rptr1 <=  TRANSPORT "00010000" AFTER 1 ps;
            ph_fifo_full_xhdl0 <=  TRANSPORT '0' AFTER 1 ps;
            ph_fifo_empty <=  TRANSPORT '0' AFTER 1 ps;
            ph_fifo_empty_pre <=  TRANSPORT '0' AFTER 1 ps;
            first_rd <=  TRANSPORT '1' AFTER 1 ps;		-- fifo_cnt previous value
            fifo_cnt_pre <=  TRANSPORT "0000" AFTER 1 ps;		-- if (reset_ptrs_local_sync2)
         ELSE
            ph_fifo_empty <=  TRANSPORT ph_fifo_empty_pre AFTER 1 ps;
            
            fifo_cnt_pre <=  TRANSPORT fifo_cnt AFTER 1 ps;
            
            --wptr0 <=  TRANSPORT wptr_gray AFTER 1 ps;
            --wptr1 <=  TRANSPORT wptr0 AFTER 1 ps;
            
            rptr0_pre <=  TRANSPORT rptr AFTER 1 ps;
            rptr0 <=  TRANSPORT rptr0_pre AFTER 1 ps;
            
            rptr1 <=  TRANSPORT rptr0 AFTER 1 ps;
            IF (first_rd = '1' AND re = '1') THEN
               
               -- advance by 2 on first read in low-latency mode
               first_rd <=  TRANSPORT '0' AFTER 1 ps;
            END IF;
            IF (re = '1') THEN
               IF (first_rd = '1' AND lowlatency_en = '1') THEN
                  rptr <=  TRANSPORT (rptr(5 DOWNTO 0) & rptr(7 DOWNTO 6)) AFTER 1 ps;
               ELSE
                  
                  -- full condition
                  --$if ({wptr1_onehot[6:0],wptr1_onehot[7]} == rptr1)
                  --new full flag requirement
                  rptr <=  TRANSPORT (rptr(6 DOWNTO 0) & rptr(7)) AFTER 1 ps;
               END IF;
            END IF;
            IF ( ((rptr1(6 DOWNTO 0) & rptr1(7)) = wptr1_onehot) AND (fifo_cnt_pre = "0111" OR fifo_cnt_pre = "1000") AND ((NOT ph_fifo_empty_pre) = '1') ) THEN
               --else if (ph_fifo_full == 1'b1 && ({rptr1[6:0],rptr1[7]} != wptr1_onehot)) //become sticky until reset
               --ph_fifo_full <= #1 1'b0;
               
               -- empty condition
               --$if ({rptr1[6:0],rptr1[7]} == wptr1_onehot)
               --new empty flag requirement
               ph_fifo_full_xhdl0 <=  TRANSPORT '1' AFTER 1 ps;
            END IF;
            IF (fifo_cnt = "0000" AND ((NOT(ph_fifo_full_xhdl0))) = '1') THEN
               --else if (ph_fifo_empty_pre == 1'b1 && (rptr1 != wptr1_onehot)) // become sticky until reset
               --ph_fifo_empty_pre <= #1 1'b0;
               ph_fifo_empty_pre <=  TRANSPORT '1' AFTER 1 ps;		-- else: !if(rst_rclk == 1'b1)
            END IF;
         END IF;
      END IF;
   END PROCESS;
   
   -- always @ (posedge rst_rclk or posedge rd_clk)
   
   
   
   ram8x70_syn_1 : stratixiv_hssi_rx_digis_ram8x70_syn
      PORT MAP (
         rst_l     => rst_n,
         clk       => wr_clk,
         fifo_wr   => wptr,
         data_in   => din,
         fifo_re   => rptr,
         data_out  => ram_data_out_pre
      );
   
   PROCESS (rst_rclk, rd_clk)
   BEGIN
      IF (rst_rclk = '1') THEN
         ram_data_out <=  TRANSPORT "0000000000000000000000000000000000000000000000000000000000000000000000" AFTER 1 ps;
      ELSIF (rd_clk'EVENT AND rd_clk = '1') THEN
         IF (rphfifo_regmode_rx = '1') THEN
            ram_data_out <=  TRANSPORT din AFTER 1 ps;
         ELSE
            ram_data_out <=  TRANSPORT ram_data_out_pre AFTER 1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   -- always @ (posedge rst_rclk or posedge rd_clk)
   
   PROCESS (wptr)
   BEGIN
      CASE wptr IS
         WHEN "00000001" =>
            wptr_bin <= "000";
         WHEN "00000010" =>
            wptr_bin <= "001";
         WHEN "00000100" =>
            wptr_bin <= "010";
         WHEN "00001000" =>
            wptr_bin <= "011";
         WHEN "00010000" =>
            wptr_bin <= "100";
         WHEN "00100000" =>
            wptr_bin <= "101";
         WHEN "01000000" =>
            wptr_bin <= "110";
         WHEN "10000000" =>
            wptr_bin <= "111";
         WHEN OTHERS =>		-- case(wptr)
            wptr_bin <= "111";
      END CASE;
   END PROCESS;
   
   -- always@ (wptr)
   
   PROCESS (rptr)
   BEGIN
      CASE rptr IS
         WHEN "00000001" =>
            rptr_bin <= "000";
         WHEN "00000010" =>
            rptr_bin <= "001";
         WHEN "00000100" =>
            rptr_bin <= "010";
         WHEN "00001000" =>
            rptr_bin <= "011";
         WHEN "00010000" =>
            rptr_bin <= "100";
         WHEN "00100000" =>
            rptr_bin <= "101";
         WHEN "01000000" =>
            rptr_bin <= "110";
         WHEN "10000000" =>
            rptr_bin <= "111";
         WHEN OTHERS =>		-- case(rptr)
            rptr_bin <= "111";
      END CASE;
   END PROCESS;
   
   -- always@ (rptr)
   
   PROCESS (rptr1)
   BEGIN
      CASE rptr1 IS
         WHEN "00000001" =>
            rptr1_bin <= "000";
         WHEN "00000010" =>
            rptr1_bin <= "001";
         WHEN "00000100" =>
            rptr1_bin <= "010";
         WHEN "00001000" =>
            rptr1_bin <= "011";
         WHEN "00010000" =>
            rptr1_bin <= "100";
         WHEN "00100000" =>
            rptr1_bin <= "101";
         WHEN "01000000" =>
            rptr1_bin <= "110";
         WHEN "10000000" =>
            rptr1_bin <= "111";
         WHEN OTHERS =>		-- case(rptr1)
            rptr1_bin <= "111";
      END CASE;
   END PROCESS;
   
   -- always@ (rptr1)
   
   PROCESS (rst_wclk, wr_clk)
   BEGIN
      IF (rst_wclk = '1') THEN
         wptr_gray <=  TRANSPORT "000" AFTER 1 ps;
      ELSIF (wr_clk'EVENT AND wr_clk = '1') THEN
         wptr_gray <=  TRANSPORT wptr_gray0 AFTER 1 ps;
      END IF;
   END PROCESS;
   
   
   PROCESS (wptr)
   BEGIN
      CASE wptr IS
         WHEN "00000001" =>
            wptr_gray0 <= "000";
         WHEN "00000010" =>
            wptr_gray0 <= "001";
         WHEN "00000100" =>
            wptr_gray0 <= "011";
         WHEN "00001000" =>
            wptr_gray0 <= "010";
         WHEN "00010000" =>
            wptr_gray0 <= "110";
         WHEN "00100000" =>
            wptr_gray0 <= "111";
         WHEN "01000000" =>
            wptr_gray0 <= "101";
         WHEN "10000000" =>
            wptr_gray0 <= "100";
         WHEN OTHERS =>		-- case(wptr)
            wptr_gray0 <= "000";
      END CASE;
   END PROCESS;
   
   -- always@ (wptr)
   
   PROCESS (wptr1)
   BEGIN
      CASE wptr1 IS
         WHEN "000" =>
            wptr1_onehot <= "00000001";
         WHEN "001" =>
            wptr1_onehot <= "00000010";
         WHEN "011" =>
            wptr1_onehot <= "00000100";
         WHEN "010" =>
            wptr1_onehot <= "00001000";
         WHEN "110" =>
            wptr1_onehot <= "00010000";
         WHEN "111" =>
            wptr1_onehot <= "00100000";
         WHEN "101" =>
            wptr1_onehot <= "01000000";
         WHEN "100" =>
            wptr1_onehot <= "10000000";
         WHEN OTHERS =>		-- case(wptr1)
            wptr1_onehot <= "10000000";
      END CASE;
   END PROCESS;
   
   -- always@ (wptr1)
   
   PROCESS (wptr1)
   BEGIN
      CASE wptr1 IS
         WHEN "000" =>
            wptr1_bin_rclk <= "000";
         WHEN "001" =>
            wptr1_bin_rclk <= "001";
         WHEN "011" =>
            wptr1_bin_rclk <= "010";
         WHEN "010" =>
            wptr1_bin_rclk <= "011";
         WHEN "110" =>
            wptr1_bin_rclk <= "100";
         WHEN "111" =>
            wptr1_bin_rclk <= "101";
         WHEN "101" =>
            wptr1_bin_rclk <= "110";
         WHEN "100" =>
            wptr1_bin_rclk <= "111";
         WHEN OTHERS =>		-- case(wptr1)
            wptr1_bin_rclk <= "000";
      END CASE;
   END PROCESS;
   
   
END trans;


-- always@ (wptr1)

-- ph_fifo_rx

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_rx_digis_ram16x14_syn IS
   GENERIC (
      
      read_access_time   : INTEGER := 0;
      write_access_time  : INTEGER := 0;
      ram_width          : INTEGER := 14
   );
   PORT (
      clk                : IN STD_LOGIC;
      rst_l              : IN STD_LOGIC;
      addr_wr            : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      addr_rd1           : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      addr_rd2           : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      data_in            : IN STD_LOGIC_VECTOR(13 DOWNTO 0);
      we                 : IN STD_LOGIC;
      re_l               : IN STD_LOGIC;
      data_out1          : OUT STD_LOGIC_VECTOR(13 DOWNTO 0);
      data_out2          : OUT STD_LOGIC_VECTOR(13 DOWNTO 0)
   );
END stratixiv_hssi_rx_digis_ram16x14_syn;

ARCHITECTURE trans OF stratixiv_hssi_rx_digis_ram16x14_syn IS
   
   SIGNAL data_out1_i    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_out2_i    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_0  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_1  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_2  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_3  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_4  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_5  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_6  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_7  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_8  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_9  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_10 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_11 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_12 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_13 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_14 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_15 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_0  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_1  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_2  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_3  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_4  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_5  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_6  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_7  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_8  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_9  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_10 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_11 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_12 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_13 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_14 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_15 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_0     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_1     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_2     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_3     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_4     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_5     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_6     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_7     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_8     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_9     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_10    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_11    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_12    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_13    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_14    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_15    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
BEGIN
   
   --assignment
   data_reg_0 <= data_in WHEN (addr_wr(0) = '1') ELSE
                 ram_array_q_0;
   data_reg_1 <= data_in WHEN (addr_wr(1) = '1') ELSE
                 ram_array_q_1;
   data_reg_2 <= data_in WHEN (addr_wr(2) = '1') ELSE
                 ram_array_q_2;
   data_reg_3 <= data_in WHEN (addr_wr(3) = '1') ELSE
                 ram_array_q_3;
   data_reg_4 <= data_in WHEN (addr_wr(4) = '1') ELSE
                 ram_array_q_4;
   data_reg_5 <= data_in WHEN (addr_wr(5) = '1') ELSE
                 ram_array_q_5;
   data_reg_6 <= data_in WHEN (addr_wr(6) = '1') ELSE
                 ram_array_q_6;
   data_reg_7 <= data_in WHEN (addr_wr(7) = '1') ELSE
                 ram_array_q_7;
   data_reg_8 <= data_in WHEN (addr_wr(8) = '1') ELSE
                 ram_array_q_8;
   data_reg_9 <= data_in WHEN (addr_wr(9) = '1') ELSE
                 ram_array_q_9;
   data_reg_10 <= data_in WHEN (addr_wr(10) = '1') ELSE
                  ram_array_q_10;
   data_reg_11 <= data_in WHEN (addr_wr(11) = '1') ELSE
                  ram_array_q_11;
   data_reg_12 <= data_in WHEN (addr_wr(12) = '1') ELSE
                  ram_array_q_12;
   data_reg_13 <= data_in WHEN (addr_wr(13) = '1') ELSE
                  ram_array_q_13;
   data_reg_14 <= data_in WHEN (addr_wr(14) = '1') ELSE
                  ram_array_q_14;
   data_reg_15 <= data_in WHEN (addr_wr(15) = '1') ELSE
                  ram_array_q_15;
   
   data_out1 <= "00000000000000" WHEN (re_l = '1') ELSE
                data_out1_i;
   data_out2 <= "00000000000000" WHEN (re_l = '1') ELSE
                data_out2_i;
   
   PROCESS (ram_array_q_0, ram_array_q_1, ram_array_q_2, ram_array_q_3, ram_array_q_4, ram_array_q_5, ram_array_q_6, ram_array_q_7, ram_array_q_8, ram_array_q_9, ram_array_q_10, ram_array_q_11, ram_array_q_12, ram_array_q_13, ram_array_q_14, ram_array_q_15, addr_rd1, addr_rd2)
VARIABLE  txt : LINE;
   BEGIN
      CASE addr_rd1 IS		-- synopsys parallel_case full_case
         WHEN "0000000000000001" =>
            data_out1_i <= ram_array_q_0;
         WHEN "0000000000000010" =>
            data_out1_i <= ram_array_q_1;
         WHEN "0000000000000100" =>
            data_out1_i <= ram_array_q_2;
         WHEN "0000000000001000" =>
            data_out1_i <= ram_array_q_3;
         WHEN "0000000000010000" =>
            data_out1_i <= ram_array_q_4;
         WHEN "0000000000100000" =>
            data_out1_i <= ram_array_q_5;
         WHEN "0000000001000000" =>
            data_out1_i <= ram_array_q_6;
         WHEN "0000000010000000" =>
            data_out1_i <= ram_array_q_7;
         WHEN "0000000100000000" =>
            data_out1_i <= ram_array_q_8;
         WHEN "0000001000000000" =>
            data_out1_i <= ram_array_q_9;
         WHEN "0000010000000000" =>
            data_out1_i <= ram_array_q_10;
         WHEN "0000100000000000" =>
            data_out1_i <= ram_array_q_11;
         WHEN "0001000000000000" =>
            data_out1_i <= ram_array_q_12;
         WHEN "0010000000000000" =>
            data_out1_i <= ram_array_q_13;
         WHEN "0100000000000000" =>
            data_out1_i <= ram_array_q_14;
         WHEN "1000000000000000" =>
            data_out1_i <= ram_array_q_15;
         WHEN OTHERS =>
            NULL;
      END CASE;
      
      CASE addr_rd2 IS		-- synopsys parallel_case full_case
         WHEN "0000000000000001" =>
            data_out2_i <= ram_array_q_0;
         WHEN "0000000000000010" =>
            data_out2_i <= ram_array_q_1;
         WHEN "0000000000000100" =>
            data_out2_i <= ram_array_q_2;
         WHEN "0000000000001000" =>
            data_out2_i <= ram_array_q_3;
         WHEN "0000000000010000" =>
            data_out2_i <= ram_array_q_4;
         WHEN "0000000000100000" =>
            data_out2_i <= ram_array_q_5;
         WHEN "0000000001000000" =>
            data_out2_i <= ram_array_q_6;
         WHEN "0000000010000000" =>
            data_out2_i <= ram_array_q_7;
         WHEN "0000000100000000" =>
            data_out2_i <= ram_array_q_8;
         WHEN "0000001000000000" =>
            data_out2_i <= ram_array_q_9;
         WHEN "0000010000000000" =>
            data_out2_i <= ram_array_q_10;
         WHEN "0000100000000000" =>
            data_out2_i <= ram_array_q_11;
         WHEN "0001000000000000" =>
            data_out2_i <= ram_array_q_12;
         WHEN "0010000000000000" =>
            data_out2_i <= ram_array_q_13;
         WHEN "0100000000000000" =>
            data_out2_i <= ram_array_q_14;
         WHEN "1000000000000000" =>
            data_out2_i <= ram_array_q_15;
         WHEN OTHERS =>
            NULL;
      END CASE;
   END PROCESS;
   
   PROCESS (clk, rst_l)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rst_l)) = '1') THEN
         ram_array_q_0 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
         ram_array_q_1 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
         ram_array_q_2 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
         ram_array_q_3 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
         ram_array_q_4 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
         ram_array_q_5 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
         ram_array_q_6 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
         ram_array_q_7 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
         ram_array_q_8 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
         ram_array_q_9 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
         ram_array_q_10 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
         ram_array_q_11 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
         ram_array_q_12 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
         ram_array_q_13 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
         ram_array_q_14 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
         ram_array_q_15 <=  TRANSPORT "00000000000000" AFTER (write_access_time)*1* 1 ps;
      ELSIF (clk'EVENT AND clk = '1') THEN
         ram_array_q_0 <=  TRANSPORT ram_array_d_0 AFTER (write_access_time)*1* 1 ps;
         ram_array_q_1 <=  TRANSPORT ram_array_d_1 AFTER (write_access_time)*1* 1 ps;
         ram_array_q_2 <=  TRANSPORT ram_array_d_2 AFTER (write_access_time)*1* 1 ps;
         ram_array_q_3 <=  TRANSPORT ram_array_d_3 AFTER (write_access_time)*1* 1 ps;
         ram_array_q_4 <=  TRANSPORT ram_array_d_4 AFTER (write_access_time)*1* 1 ps;
         ram_array_q_5 <=  TRANSPORT ram_array_d_5 AFTER (write_access_time)*1* 1 ps;
         ram_array_q_6 <=  TRANSPORT ram_array_d_6 AFTER (write_access_time)*1* 1 ps;
         ram_array_q_7 <=  TRANSPORT ram_array_d_7 AFTER (write_access_time)*1* 1 ps;
         ram_array_q_8 <=  TRANSPORT ram_array_d_8 AFTER (write_access_time)*1* 1 ps;
         ram_array_q_9 <=  TRANSPORT ram_array_d_9 AFTER (write_access_time)*1* 1 ps;
         ram_array_q_10 <=  TRANSPORT ram_array_d_10 AFTER (write_access_time)*1* 1 ps;
         ram_array_q_11 <=  TRANSPORT ram_array_d_11 AFTER (write_access_time)*1* 1 ps;
         ram_array_q_12 <=  TRANSPORT ram_array_d_12 AFTER (write_access_time)*1* 1 ps;
         ram_array_q_13 <=  TRANSPORT ram_array_d_13 AFTER (write_access_time)*1* 1 ps;
         ram_array_q_14 <=  TRANSPORT ram_array_d_14 AFTER (write_access_time)*1* 1 ps;
         ram_array_q_15 <=  TRANSPORT ram_array_d_15 AFTER (write_access_time)*1* 1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (we, data_reg_0, data_reg_1, data_reg_2, data_reg_3, data_reg_4, data_reg_5, data_reg_6, data_reg_7, data_reg_8, data_reg_9, data_reg_10, data_reg_11, data_reg_12, data_reg_13, data_reg_14, data_reg_15, ram_array_q_0, ram_array_q_1, ram_array_q_2, ram_array_q_3, ram_array_q_4, ram_array_q_5, ram_array_q_6, ram_array_q_7, ram_array_q_8, ram_array_q_9, ram_array_q_10, ram_array_q_11, ram_array_q_12, ram_array_q_13, ram_array_q_14, ram_array_q_15)
VARIABLE  txt : LINE;
   BEGIN
      IF (we = '1') THEN
         ram_array_d_0 <=  TRANSPORT data_reg_0 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_1 <=  TRANSPORT data_reg_1 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_2 <=  TRANSPORT data_reg_2 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_3 <=  TRANSPORT data_reg_3 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_4 <=  TRANSPORT data_reg_4 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_5 <=  TRANSPORT data_reg_5 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_6 <=  TRANSPORT data_reg_6 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_7 <=  TRANSPORT data_reg_7 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_8 <=  TRANSPORT data_reg_8 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_9 <=  TRANSPORT data_reg_9 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_10 <=  TRANSPORT data_reg_10 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_11 <=  TRANSPORT data_reg_11 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_12 <=  TRANSPORT data_reg_12 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_13 <=  TRANSPORT data_reg_13 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_14 <=  TRANSPORT data_reg_14 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_15 <=  TRANSPORT data_reg_15 AFTER (write_access_time)*1* 1 ps;
      ELSE
         ram_array_d_0 <=  TRANSPORT ram_array_q_0 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_1 <=  TRANSPORT ram_array_q_1 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_2 <=  TRANSPORT ram_array_q_2 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_3 <=  TRANSPORT ram_array_q_3 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_4 <=  TRANSPORT ram_array_q_4 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_5 <=  TRANSPORT ram_array_q_5 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_6 <=  TRANSPORT ram_array_q_6 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_7 <=  TRANSPORT ram_array_q_7 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_8 <=  TRANSPORT ram_array_q_8 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_9 <=  TRANSPORT ram_array_q_9 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_10 <=  TRANSPORT ram_array_q_10 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_11 <=  TRANSPORT ram_array_q_11 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_12 <=  TRANSPORT ram_array_q_12 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_13 <=  TRANSPORT ram_array_q_13 AFTER (write_access_time)*1* 1 ps;
         ram_array_d_14 <=  TRANSPORT ram_array_q_14 AFTER (write_access_time)*1* 1 ps;
         
         ram_array_d_15 <=  TRANSPORT ram_array_q_15 AFTER (write_access_time)*1* 1 ps;
      END IF;
   END PROCESS;
   
END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_rx_digis_ram20x16_syn IS
   GENERIC (
      
      read_access_time   : INTEGER := 0;
      write_access_time  : INTEGER := 0;
      ram_width          : INTEGER := 16
   );
   PORT (
      data_in            : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      clk                : IN STD_LOGIC;
      fifo_wr            : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
      rst_l              : IN STD_LOGIC;
      fifo_re1           : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
      fifo_re2           : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
      data_out1          : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      data_out2          : OUT STD_LOGIC_VECTOR(15 DOWNTO 0)
   );
END stratixiv_hssi_rx_digis_ram20x16_syn;

ARCHITECTURE trans OF stratixiv_hssi_rx_digis_ram20x16_syn IS
   
   SIGNAL data_out1_i    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_out2_i    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_0  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_1  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_2  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_3  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_4  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_5  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_6  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_7  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_8  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_9  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_10 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_11 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_12 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_13 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_14 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_15 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_16 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_17 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_18 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_d_19 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_0  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_1  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_2  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_3  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_4  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_5  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_6  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_7  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_8  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_9  : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_10 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_11 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_12 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_13 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_14 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_15 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_16 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_17 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_18 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL ram_array_q_19 : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_0     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_1     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_2     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_3     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_4     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_5     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_6     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_7     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_8     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_9     : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_10    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_11    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_12    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_13    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_14    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_15    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_16    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_17    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_18    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   SIGNAL data_reg_19    : STD_LOGIC_VECTOR(ram_width - 1 DOWNTO 0);
   
   SIGNAL we             : STD_LOGIC;
   SIGNAL re_l           : STD_LOGIC;
BEGIN
   
   we <= '1';
   re_l <= '0';
   
   --assignment
   data_reg_0 <= data_in WHEN (fifo_wr(0) = '1') ELSE
                 ram_array_q_0;
   data_reg_1 <= data_in WHEN (fifo_wr(1) = '1') ELSE
                 ram_array_q_1;
   data_reg_2 <= data_in WHEN (fifo_wr(2) = '1') ELSE
                 ram_array_q_2;
   data_reg_3 <= data_in WHEN (fifo_wr(3) = '1') ELSE
                 ram_array_q_3;
   data_reg_4 <= data_in WHEN (fifo_wr(4) = '1') ELSE
                 ram_array_q_4;
   data_reg_5 <= data_in WHEN (fifo_wr(5) = '1') ELSE
                 ram_array_q_5;
   data_reg_6 <= data_in WHEN (fifo_wr(6) = '1') ELSE
                 ram_array_q_6;
   data_reg_7 <= data_in WHEN (fifo_wr(7) = '1') ELSE
                 ram_array_q_7;
   data_reg_8 <= data_in WHEN (fifo_wr(8) = '1') ELSE
                 ram_array_q_8;
   data_reg_9 <= data_in WHEN (fifo_wr(9) = '1') ELSE
                 ram_array_q_9;
   data_reg_10 <= data_in WHEN (fifo_wr(10) = '1') ELSE
                  ram_array_q_10;
   data_reg_11 <= data_in WHEN (fifo_wr(11) = '1') ELSE
                  ram_array_q_11;
   data_reg_12 <= data_in WHEN (fifo_wr(12) = '1') ELSE
                  ram_array_q_12;
   data_reg_13 <= data_in WHEN (fifo_wr(13) = '1') ELSE
                  ram_array_q_13;
   data_reg_14 <= data_in WHEN (fifo_wr(14) = '1') ELSE
                  ram_array_q_14;
   data_reg_15 <= data_in WHEN (fifo_wr(15) = '1') ELSE
                  ram_array_q_15;
   data_reg_16 <= data_in WHEN (fifo_wr(16) = '1') ELSE
                  ram_array_q_16;
   data_reg_17 <= data_in WHEN (fifo_wr(17) = '1') ELSE
                  ram_array_q_17;
   data_reg_18 <= data_in WHEN (fifo_wr(18) = '1') ELSE
                  ram_array_q_18;
   data_reg_19 <= data_in WHEN (fifo_wr(19) = '1') ELSE
                  ram_array_q_19;
   
   -- 03/22/05 VC: LEDA fix: Remove delay on combinatorial statement
   --                        and changed 15'b0 to 16'd0
   --assign #read_access_time data_out1 = re_l ? 15'b0 : data_out1_i;
   --assign #read_access_time data_out2 = re_l ? 15'b0 : data_out2_i;
   data_out1 <= "0000000000000000" WHEN (re_l = '1') ELSE
                data_out1_i;
   data_out2 <= "0000000000000000" WHEN (re_l = '1') ELSE
                data_out2_i;
   
   PROCESS (ram_array_q_0, ram_array_q_1, ram_array_q_2, ram_array_q_3, ram_array_q_4, ram_array_q_5, ram_array_q_6, ram_array_q_7, ram_array_q_8, ram_array_q_9, ram_array_q_10, ram_array_q_11, ram_array_q_12, ram_array_q_13, ram_array_q_14, ram_array_q_15, ram_array_q_16, ram_array_q_17, ram_array_q_18, ram_array_q_19, fifo_re1, fifo_re2)
VARIABLE  txt : LINE;
   BEGIN
      -- 03/22/05 VC: Removed full case statement because
      --              not all cases are listed
      --    case ( fifo_re1 )  // synopsys parallel_case full_case
      CASE fifo_re1 IS		-- synopsys parallel_case
         WHEN "00000000000000000001" =>
            data_out1_i <= ram_array_q_0;
         WHEN "00000000000000000010" =>
            data_out1_i <= ram_array_q_1;
         WHEN "00000000000000000100" =>
            data_out1_i <= ram_array_q_2;
         WHEN "00000000000000001000" =>
            data_out1_i <= ram_array_q_3;
         WHEN "00000000000000010000" =>
            data_out1_i <= ram_array_q_4;
         WHEN "00000000000000100000" =>
            data_out1_i <= ram_array_q_5;
         WHEN "00000000000001000000" =>
            data_out1_i <= ram_array_q_6;
         WHEN "00000000000010000000" =>
            data_out1_i <= ram_array_q_7;
         WHEN "00000000000100000000" =>
            data_out1_i <= ram_array_q_8;
         WHEN "00000000001000000000" =>
            data_out1_i <= ram_array_q_9;
         WHEN "00000000010000000000" =>
            data_out1_i <= ram_array_q_10;
         WHEN "00000000100000000000" =>
            data_out1_i <= ram_array_q_11;
         WHEN "00000001000000000000" =>
            data_out1_i <= ram_array_q_12;
         WHEN "00000010000000000000" =>
            data_out1_i <= ram_array_q_13;
         WHEN "00000100000000000000" =>
            data_out1_i <= ram_array_q_14;
         WHEN "00001000000000000000" =>
            data_out1_i <= ram_array_q_15;
         WHEN "00010000000000000000" =>
            data_out1_i <= ram_array_q_16;
         WHEN "00100000000000000000" =>
            data_out1_i <= ram_array_q_17;
         WHEN "01000000000000000000" =>
            data_out1_i <= ram_array_q_18;
         -- 03/22/05 VC: LEDA fix: Added default clause to case statement
         WHEN "10000000000000000000" =>
            data_out1_i <= ram_array_q_19;
         WHEN OTHERS =>
            data_out1_i <= ram_array_q_0;
      END CASE;
      
      -- 03/22/05 VC: Removed full case statement because
      --              not all cases are listed
      --    case ( fifo_re2 )  // synopsys parallel_case full_case
      CASE fifo_re2 IS		-- synopsys parallel_case
         WHEN "00000000000000000001" =>
            data_out2_i <= ram_array_q_0;
         WHEN "00000000000000000010" =>
            data_out2_i <= ram_array_q_1;
         WHEN "00000000000000000100" =>
            data_out2_i <= ram_array_q_2;
         WHEN "00000000000000001000" =>
            data_out2_i <= ram_array_q_3;
         WHEN "00000000000000010000" =>
            data_out2_i <= ram_array_q_4;
         WHEN "00000000000000100000" =>
            data_out2_i <= ram_array_q_5;
         WHEN "00000000000001000000" =>
            data_out2_i <= ram_array_q_6;
         WHEN "00000000000010000000" =>
            data_out2_i <= ram_array_q_7;
         WHEN "00000000000100000000" =>
            data_out2_i <= ram_array_q_8;
         WHEN "00000000001000000000" =>
            data_out2_i <= ram_array_q_9;
         WHEN "00000000010000000000" =>
            data_out2_i <= ram_array_q_10;
         WHEN "00000000100000000000" =>
            data_out2_i <= ram_array_q_11;
         WHEN "00000001000000000000" =>
            data_out2_i <= ram_array_q_12;
         WHEN "00000010000000000000" =>
            data_out2_i <= ram_array_q_13;
         WHEN "00000100000000000000" =>
            data_out2_i <= ram_array_q_14;
         WHEN "00001000000000000000" =>
            data_out2_i <= ram_array_q_15;
         WHEN "00010000000000000000" =>
            data_out2_i <= ram_array_q_16;
         WHEN "00100000000000000000" =>
            data_out2_i <= ram_array_q_17;
         WHEN "01000000000000000000" =>
            data_out2_i <= ram_array_q_18;
         -- 03/22/05 VC: LEDA fix: Added default clause to case statement
         WHEN "10000000000000000000" =>
            data_out2_i <= ram_array_q_19;
         WHEN OTHERS =>
            data_out2_i <= ram_array_q_0;
      END CASE;
   END PROCESS;
   
   -- 03/22/05 VC: LEDA fix: Change 0 to 16'd0
   PROCESS (clk, rst_l)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rst_l)) = '1') THEN
         ram_array_q_0 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_1 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_2 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_3 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_4 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_5 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_6 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_7 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_8 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_9 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_10 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_11 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_12 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_13 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_14 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_15 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_16 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_17 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_18 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
         ram_array_q_19 <=  TRANSPORT "0000000000000000" AFTER (write_access_time)*1 ps;
      ELSIF (clk'EVENT AND clk = '1') THEN
         ram_array_q_0 <=  TRANSPORT ram_array_d_0 AFTER (write_access_time)*1 ps;
         ram_array_q_1 <=  TRANSPORT ram_array_d_1 AFTER (write_access_time)*1 ps;
         ram_array_q_2 <=  TRANSPORT ram_array_d_2 AFTER (write_access_time)*1 ps;
         ram_array_q_3 <=  TRANSPORT ram_array_d_3 AFTER (write_access_time)*1 ps;
         ram_array_q_4 <=  TRANSPORT ram_array_d_4 AFTER (write_access_time)*1 ps;
         ram_array_q_5 <=  TRANSPORT ram_array_d_5 AFTER (write_access_time)*1 ps;
         ram_array_q_6 <=  TRANSPORT ram_array_d_6 AFTER (write_access_time)*1 ps;
         ram_array_q_7 <=  TRANSPORT ram_array_d_7 AFTER (write_access_time)*1 ps;
         ram_array_q_8 <=  TRANSPORT ram_array_d_8 AFTER (write_access_time)*1 ps;
         ram_array_q_9 <=  TRANSPORT ram_array_d_9 AFTER (write_access_time)*1 ps;
         ram_array_q_10 <=  TRANSPORT ram_array_d_10 AFTER (write_access_time)*1 ps;
         ram_array_q_11 <=  TRANSPORT ram_array_d_11 AFTER (write_access_time)*1 ps;
         ram_array_q_12 <=  TRANSPORT ram_array_d_12 AFTER (write_access_time)*1 ps;
         ram_array_q_13 <=  TRANSPORT ram_array_d_13 AFTER (write_access_time)*1 ps;
         ram_array_q_14 <=  TRANSPORT ram_array_d_14 AFTER (write_access_time)*1 ps;
         ram_array_q_15 <=  TRANSPORT ram_array_d_15 AFTER (write_access_time)*1 ps;
         ram_array_q_16 <=  TRANSPORT ram_array_d_16 AFTER (write_access_time)*1 ps;
         ram_array_q_17 <=  TRANSPORT ram_array_d_17 AFTER (write_access_time)*1 ps;
         ram_array_q_18 <=  TRANSPORT ram_array_d_18 AFTER (write_access_time)*1 ps;
         ram_array_q_19 <=  TRANSPORT ram_array_d_19 AFTER (write_access_time)*1 ps;
      END IF;
   END PROCESS;
   
   PROCESS (we, data_reg_0, data_reg_1, data_reg_2, data_reg_3, data_reg_4, data_reg_5, data_reg_6, data_reg_7, data_reg_8, data_reg_9, data_reg_10, data_reg_11, data_reg_12, data_reg_13, data_reg_14, data_reg_15, data_reg_16, data_reg_17, data_reg_18, data_reg_19, ram_array_q_0, ram_array_q_1, ram_array_q_2, ram_array_q_3, ram_array_q_4, ram_array_q_5, ram_array_q_6, ram_array_q_7, ram_array_q_8, ram_array_q_9, ram_array_q_10, ram_array_q_11, ram_array_q_12, ram_array_q_13, ram_array_q_14, ram_array_q_15, ram_array_q_16, ram_array_q_17, ram_array_q_18, ram_array_q_19)
VARIABLE  txt : LINE;
   BEGIN
      IF (we = '1') THEN
         ram_array_d_0 <= data_reg_0;
         ram_array_d_1 <= data_reg_1;
         ram_array_d_2 <= data_reg_2;
         ram_array_d_3 <= data_reg_3;
         ram_array_d_4 <= data_reg_4;
         ram_array_d_5 <= data_reg_5;
         ram_array_d_6 <= data_reg_6;
         ram_array_d_7 <= data_reg_7;
         ram_array_d_8 <= data_reg_8;
         ram_array_d_9 <= data_reg_9;
         ram_array_d_10 <= data_reg_10;
         ram_array_d_11 <= data_reg_11;
         ram_array_d_12 <= data_reg_12;
         ram_array_d_13 <= data_reg_13;
         ram_array_d_14 <= data_reg_14;
         ram_array_d_15 <= data_reg_15;
         ram_array_d_16 <= data_reg_16;
         ram_array_d_17 <= data_reg_17;
         ram_array_d_18 <= data_reg_18;
         ram_array_d_19 <= data_reg_19;
      ELSE
         ram_array_d_0 <= ram_array_q_0;
         ram_array_d_1 <= ram_array_q_1;
         ram_array_d_2 <= ram_array_q_2;
         ram_array_d_3 <= ram_array_q_3;
         ram_array_d_4 <= ram_array_q_4;
         ram_array_d_5 <= ram_array_q_5;
         ram_array_d_6 <= ram_array_q_6;
         ram_array_d_7 <= ram_array_q_7;
         ram_array_d_8 <= ram_array_q_8;
         ram_array_d_9 <= ram_array_q_9;
         ram_array_d_10 <= ram_array_q_10;
         ram_array_d_11 <= ram_array_q_11;
         ram_array_d_12 <= ram_array_q_12;
         ram_array_d_13 <= ram_array_q_13;
         ram_array_d_14 <= ram_array_q_14;
         ram_array_d_15 <= ram_array_q_15;
         ram_array_d_16 <= ram_array_q_16;
         ram_array_d_17 <= ram_array_q_17;
         ram_array_d_18 <= ram_array_q_18;
         ram_array_d_19 <= ram_array_q_19;
      END IF;
   END PROCESS;
   
END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_rx_digis_rxclk_gating IS
    PORT (
        
        select_n                : IN STD_LOGIC;
        clk1                    : IN STD_LOGIC;
        clk2                    : IN STD_LOGIC;
        clk1out_n               : OUT STD_LOGIC;
        clk2out_n               : OUT STD_LOGIC
    );
END stratixiv_hssi_rx_digis_rxclk_gating;

ARCHITECTURE trans OF stratixiv_hssi_rx_digis_rxclk_gating IS
BEGIN
    
    clk1out_n <= NOT((select_n OR clk1));
    clk2out_n <= NOT((NOT(select_n) OR clk2));
    
END ARCHITECTURE trans;



-- rxclk_gating

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_rx_digi_rxclk_ctl IS
   PORT (
      
      -- Clock Inputs
      pld_rx_clk              : IN STD_LOGIC;		-- PLD clock from PLD clock trees
      rcvd_clk_pma            : IN STD_LOGIC;		-- local recovered clock
      rcvd_clk0_pma           : IN STD_LOGIC;		-- channel zero recovered clock
      tx_pma_clk              : IN STD_LOGIC;		-- local TX PMA clock
      refclk_pma              : IN STD_LOGIC;		-- Quad based clk from TXPLL
      fref                    : IN STD_LOGIC;
      clklow                  : IN STD_LOGIC;
      
      -- Control Inputs
      scan_mode               : IN STD_LOGIC;		-- Scan mode enable signal
      -- This is the soft_reset for the RX_PCS
      
      -- New Control Inputs
      gen2ngen1               : IN STD_LOGIC;		-- from PMA for PCIexp Gen1/Gen2 datawidth scaling
      gen2ngen1_bundle        : IN STD_LOGIC;		-- from PMA for PCIexp Gen1/Gen2 datawidth scaling in x4 and x8 
      rx_div2_sync_centrl     : IN STD_LOGIC;		-- divided clock from the central channel (x2, x4 mode)
      rx_div2_sync_quad_up    : IN STD_LOGIC;		-- divided clock from quad above (> x4 mode)
      rx_div2_sync_quad_down  : IN STD_LOGIC;		-- divided clock from quad below (> x4 mode)
      
      -- MDIO Inputs
      rrcvd_clk_sel           : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rclk_1_sel              : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rclk_2_sel              : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rrx_rd_clk_sel          : IN STD_LOGIC;		-- Select clock for rx ph comp fifo read side
      rxrst                   : IN STD_LOGIC;
      rindv_rx                : IN STD_LOGIC;		-- Select between XAUI mode or indiv  channel mode
      rdwidth_rx              : IN STD_LOGIC;		-- divide by 1 or 2 before feeding to FIFO write clock
      rfreerun_rx             : IN STD_LOGIC;		-- Select whether divider is permamently enabled (free -running) or divider should be enabled / reset by RX PCS reset
      
      -- New MDIO Inputs
      rauto_speed_ena         : IN STD_LOGIC;		-- auto speed negotiation enable
      rfreq_sel               : IN STD_LOGIC;		-- freq scaling or data width scaling
      rrxpcsclkpwdn           : IN STD_LOGIC;		-- RX clocking power down enable
      rmaster_rx              : IN STD_LOGIC;		-- New bundle mode MDIO, selects master quad
      rmaster_up_rx           : IN STD_LOGIC;		-- New bundle mode MDIO, selects master quad
      rself_sw_en_rx          : IN STD_LOGIC;		-- enables self-switch to have correct /2 clock in all quads in bundle mode
      
      -- Removed Inputs
      --    input          rphfifo_master_sel_rx;  // RX Phase comp. FIFO rx_div2_sync selection CRAM
      --    input          rx_div2_sync_in_ch0;    // Connect from channel zero rx_div2_sync_out
      --    input          rx_div2_sync_in_q0_ch0; // Connect from channel zero rx_div2_sync_out of Master Quad
      
      -- Clock Outputs with CTS
      fref_muxed              : OUT STD_LOGIC;
      clklow_muxed            : OUT STD_LOGIC;
      rcvd_clk                : OUT STD_LOGIC;
      clk_1_b                 : OUT STD_LOGIC;
      clk_2_b                 : OUT STD_LOGIC;
      rx_wr_clk               : OUT STD_LOGIC;		-- drives the rx ph comp fifo write clock tree
      rx_rd_clk               : OUT STD_LOGIC;		-- drives the rx ph comp fifo read clock tree
      
      -- Clock Outputs to PLD, no CTS
      rx_clk                  : OUT STD_LOGIC;		-- drives the PLD clock tree in x1 mode, logically same as rx_wr_clk
      rcvd_clk_pma_b          : OUT STD_LOGIC;		-- debug output clock to PLD
      
      -- New Clock Outputs with CTS
      clk_2_b_raw             : OUT STD_LOGIC;		-- same as clk_2_b, but with no clock gating
      rx_wr_clk_raw           : OUT STD_LOGIC;		-- same as rx_wr_clk, but with no clock gating
      rx_rd_clk_raw           : OUT STD_LOGIC;		-- same as rx_rd_clk, but with no clock gating
      
      -- Control Outputs
      rx_div2_sync_out        : OUT STD_LOGIC		-- inverted /2 clock.  not used w/new bundling scheme. (left for safety)
   );
END stratixiv_hssi_rx_digi_rxclk_ctl;

ARCHITECTURE trans OF stratixiv_hssi_rx_digi_rxclk_ctl IS
   COMPONENT stratixiv_hssi_rx_digis_rxclk_gating
        PORT (
            select_n                : IN STD_LOGIC;
            clk1                    : IN STD_LOGIC;
            clk2                    : IN STD_LOGIC;
            clk1out_n               : OUT STD_LOGIC;
            clk2out_n               : OUT STD_LOGIC
        );
    END COMPONENT;
      
   SIGNAL rx_clk_2_by2           : STD_LOGIC := '1';
   SIGNAL gen2ngen1_local_sync   : STD_LOGIC;
   SIGNAL counter                : STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   SIGNAL rx_div2_sync           : STD_LOGIC;
   SIGNAL rx_rst_n               : STD_LOGIC;
   SIGNAL rrcvd_clk_sel_int      : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rclk_1_sel_int         : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rclk_2_sel_int         : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dynamic_div2ndiv1      : STD_LOGIC;
   SIGNAL gen2ngen1_local        : STD_LOGIC;
   SIGNAL rrxpcsclkpwdn_nscan    : STD_LOGIC;
   SIGNAL rx_div2_this_quad      : STD_LOGIC;
   SIGNAL rx_div2_this_channel   : STD_LOGIC;
   SIGNAL rx_div2_other_quad     : STD_LOGIC;
   SIGNAL force_master           : STD_LOGIC;
    
    SIGNAL select_div1_n          : STD_LOGIC;
    SIGNAL clk1out_n              : STD_LOGIC;
    SIGNAL clk2out_n              : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL rx_wr_clk_xhdl3        : STD_LOGIC;
   SIGNAL clk_2_b_raw_xhdl0      : STD_LOGIC;
   SIGNAL rx_wr_clk_raw_xhdl4    : STD_LOGIC;
   SIGNAL rx_rd_clk_raw_xhdl2    : STD_LOGIC;
   SIGNAL rx_div2_sync_out_xhdl1 : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   rx_wr_clk <= rx_wr_clk_xhdl3;
   clk_2_b_raw <= clk_2_b_raw_xhdl0;
   rx_wr_clk_raw <= rx_wr_clk_raw_xhdl4;
   rx_rd_clk_raw <= rx_rd_clk_raw_xhdl2;
   rx_div2_sync_out <= rx_div2_sync_out_xhdl1;
   
   
   -- Old bundle logic:
   -- Select between the local synchronization signal or the global synchronization signal
   --assign rx_div2_sync = rindv_rx ? rx_div2_sync_out : rx_div2_sync_in;
   -- assign 	  rx_div2_sync = (rphfifo_master_sel_rx == 1'b0) ? rx_div2_sync_in_q0_ch0 :
   -- 				 (rindv_rx == 1'b0) ? rx_div2_sync_in_ch0 : 
   -- 				 (rauto_speed_ena & ~rfreq_sel) ? (rx_div2_sync_out | ~gen2ngen1_local_sync) : rx_div2_sync_out;
   
   PROCESS (rxrst, clk_2_b_raw_xhdl0)
VARIABLE  txt : LINE;
   BEGIN
      IF (rxrst = '1') THEN
         counter <=  TRANSPORT "00" AFTER 1* 1 ps;
      ELSIF (clk_2_b_raw_xhdl0'EVENT AND clk_2_b_raw_xhdl0 = '1') THEN
         IF (((rauto_speed_ena AND NOT(rfreq_sel) AND rself_sw_en_rx) AND NOT(force_master)) = '1') THEN
            counter <=  TRANSPORT counter + "01" AFTER 1* 1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   force_master <= '1' WHEN ((counter = "11") AND ((rauto_speed_ena AND NOT(rfreq_sel) AND rself_sw_en_rx) = '1')) ELSE
                   '0';
   
   rx_div2_sync <= rx_div2_this_quad WHEN ((rmaster_rx OR force_master) = '1') ELSE
                   rx_div2_other_quad;
   rx_div2_this_quad <= rx_div2_this_channel WHEN ((rindv_rx OR force_master) = '1') ELSE
                        rx_div2_sync_centrl;
   rx_div2_this_channel <= (rx_div2_sync_out_xhdl1 OR NOT(gen2ngen1_local_sync)) WHEN ((rauto_speed_ena AND NOT(rfreq_sel)) = '1') ELSE
                           rx_div2_sync_out_xhdl1;
   rx_div2_other_quad <= rx_div2_sync_quad_up WHEN (rmaster_up_rx = '1') ELSE
                         rx_div2_sync_quad_down;
   
   gen2ngen1_local <= gen2ngen1_bundle WHEN (rindv_rx = '0') ELSE
                      gen2ngen1;
   
   PROCESS (rxrst, clk_2_b_raw_xhdl0)
VARIABLE  txt : LINE;
   BEGIN
      IF (rxrst = '1') THEN
         gen2ngen1_local_sync <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (clk_2_b_raw_xhdl0'EVENT AND clk_2_b_raw_xhdl0 = '1') THEN
         gen2ngen1_local_sync <=  TRANSPORT gen2ngen1_local AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   dynamic_div2ndiv1 <= rdwidth_rx OR (gen2ngen1_local_sync AND rauto_speed_ena AND NOT(rfreq_sel));
   
   -- Reset for Divide-by-2 FF and synchronization FF's for clock gating
   rx_rst_n <= '1' WHEN (rfreerun_rx = '1') ELSE
               NOT(rxrst);
   
   rrxpcsclkpwdn_nscan <= rrxpcsclkpwdn AND NOT(scan_mode);
   
   -- clocks are assigned below in the order in which they appear in the out flowing data path
   -- RCVD_CLK selection
   rrcvd_clk_sel_int <= "01" WHEN (scan_mode = '1') ELSE
                        rrcvd_clk_sel;
   rcvd_clk <= '1' WHEN (rrxpcsclkpwdn_nscan = '1') ELSE
               rcvd_clk_pma WHEN (rrcvd_clk_sel_int = "00") ELSE
               refclk_pma WHEN (rrcvd_clk_sel_int = "01") ELSE
               tx_pma_clk WHEN (rrcvd_clk_sel_int = "10") ELSE
               rcvd_clk_pma WHEN (rrcvd_clk_sel_int = "11") ELSE
               rcvd_clk_pma;
   
   -- CLK_1 seleciton
   rclk_1_sel_int <= "01" WHEN (scan_mode = '1') ELSE
                     rclk_1_sel;
   clk_1_b <= '1' WHEN (rrxpcsclkpwdn_nscan = '1') ELSE
              rcvd_clk_pma WHEN (rclk_1_sel_int = "00") ELSE
              refclk_pma WHEN (rclk_1_sel_int = "01") ELSE
              tx_pma_clk WHEN (rclk_1_sel_int = "10") ELSE
              rcvd_clk0_pma WHEN (rclk_1_sel_int = "11") ELSE
              rcvd_clk_pma;
   
   -- CLK_2 selection
   rclk_2_sel_int <= "10" WHEN (scan_mode = '1') ELSE
                     rclk_2_sel;
   clk_2_b_raw_xhdl0 <= rcvd_clk_pma WHEN (rclk_2_sel_int = "00") ELSE
                        tx_pma_clk WHEN (rclk_2_sel_int = "01") ELSE
                        refclk_pma WHEN (rclk_2_sel_int = "10") ELSE
                        rcvd_clk_pma;
   --change made for S3GX to remove pld_rx_clk from mux input 
   --(rclk_2_sel_int == 2'b10) ? refclk_pma : 
   --(rclk_2_sel_int == 2'b11) ? pld_rx_clk : rcvd_clk_pma;
   
   clk_2_b <= '1' WHEN (rrxpcsclkpwdn_nscan = '1') ELSE
              clk_2_b_raw_xhdl0;
   
   -- This register is used to generate divided by two clock. Div by 2 clock starts off high after reset
   -- No #1 on this FF as it generates a clock
   PROCESS (rx_rst_n, clk_2_b_raw_xhdl0)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rx_rst_n)) = '1') THEN
         rx_clk_2_by2 <= '1';
      ELSIF (clk_2_b_raw_xhdl0'EVENT AND clk_2_b_raw_xhdl0 = '1') THEN
         rx_clk_2_by2 <= rx_div2_sync;
      END IF;
   END PROCESS;
   
   rx_div2_sync_out_xhdl1 <= NOT(rx_clk_2_by2);
   
   -- RX FIFO write clock: could be fast or divided by 2
   -- old code:
   -- assign rx_wr_clk = ((rdwidth_rx == 1'b0) || scan_mode) ? clk_2_b_raw : rx_clk_2_by2;
   
    select_div1_n <= NOT((scan_mode OR NOT(dynamic_div2ndiv1)));
        
    rxclk_gating : stratixiv_hssi_rx_digis_rxclk_gating
        PORT MAP (
            select_n   => select_div1_n,
            clk1       => clk_2_b_raw_xhdl0,
            clk2       => rx_clk_2_by2,
            clk1out_n  => clk1out_n,
            clk2out_n  => clk2out_n
        );
    
    rx_wr_clk_raw_xhdl4 <= NOT((clk1out_n OR clk2out_n));
   
   
   rx_wr_clk_xhdl3 <= '1' WHEN (rrxpcsclkpwdn_nscan = '1') ELSE
                      rx_wr_clk_raw_xhdl4;
   
   -- RX FIFO read clock
   rx_rd_clk_raw_xhdl2 <= rx_wr_clk_raw_xhdl4 WHEN ((scan_mode OR int2bit((rrx_rd_clk_sel = '0'))) = '1') ELSE
                          pld_rx_clk;
   rx_rd_clk <= '1' WHEN (rrxpcsclkpwdn_nscan = '1') ELSE
                rx_rd_clk_raw_xhdl2;
   
   -- RX clock out
   rx_clk <= rx_wr_clk_xhdl3;		-- drives PLD clock tree
   
   -- Recovered clock for debugging
   rcvd_clk_pma_b <= rcvd_clk_pma;		-- Goes out to PLD as debug clock. This clock may or may not be routed out to PLD fabric. TBD
   
   fref_muxed <= refclk_pma WHEN (scan_mode = '1') ELSE
                 '1' WHEN (rrxpcsclkpwdn = '1') ELSE
                 fref;
   clklow_muxed <= refclk_pma WHEN (scan_mode = '1') ELSE
                   '1' WHEN (rrxpcsclkpwdn = '1') ELSE
                   clklow;
   
END trans;




-- rxclk_ctl
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 74 mux21 44 oper_add 1 oper_decoder 1 oper_mux 4 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_rx_digi_auto_speed_neg IS 
	 PORT 
	 ( 
		 config_sel	:	OUT  STD_LOGIC;
		 config_sel_centrl	:	IN  STD_LOGIC;
		 config_sel_quad_down	:	IN  STD_LOGIC;
		 config_sel_quad_up	:	IN  STD_LOGIC;
		 cs	:	OUT  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 dis_pc_byte	:	OUT  STD_LOGIC;
		 gen2ngen1	:	IN  STD_LOGIC;
		 pcie_switch	:	OUT  STD_LOGIC;
		 rate	:	IN  STD_LOGIC;
		 rauto_deassert_pc_rst_cnt	:	IN  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 rauto_pc_en_cnt	:	IN  STD_LOGIC_VECTOR (4 DOWNTO 0);
		 rauto_speed_ena	:	IN  STD_LOGIC;
		 refclk	:	IN  STD_LOGIC;
		 reset_pc_ptrs	:	OUT  STD_LOGIC;
		 rindv_rx	:	IN  STD_LOGIC;
		 rmaster_rx	:	IN  STD_LOGIC;
		 rmaster_up_rx	:	IN  STD_LOGIC;
		 rphfifo_regmode_rx	:	IN  STD_LOGIC;
		 rpma_done_count	:	IN  STD_LOGIC_VECTOR (17 DOWNTO 0);
		 rwait_for_phfifo_cnt	:	IN  STD_LOGIC_VECTOR (5 DOWNTO 0);
		 rxpcs_rst_int	:	IN  STD_LOGIC;
		 singleorbundle	:	IN  STD_LOGIC;
		 speed_change	:	OUT  STD_LOGIC
	 ); 
 END stratixiv_hssi_rx_digi_auto_speed_neg;

 ARCHITECTURE RTL OF stratixiv_hssi_rx_digi_auto_speed_neg IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 n000l43	:	STD_LOGIC := '0';
	 SIGNAL	 n000l44	:	STD_LOGIC := '0';
	 SIGNAL	 n00ii41	:	STD_LOGIC := '0';
	 SIGNAL	 n00ii42	:	STD_LOGIC := '0';
	 SIGNAL	 n00il39	:	STD_LOGIC := '0';
	 SIGNAL	 n00il40	:	STD_LOGIC := '0';
	 SIGNAL	 n00ll37	:	STD_LOGIC := '0';
	 SIGNAL	 n00ll38	:	STD_LOGIC := '0';
	 SIGNAL	 n00Ol35	:	STD_LOGIC := '0';
	 SIGNAL	 n00Ol36	:	STD_LOGIC := '0';
	 SIGNAL	 n0i0i31	:	STD_LOGIC := '0';
	 SIGNAL	 n0i0i32	:	STD_LOGIC := '0';
	 SIGNAL	 n0i0O29	:	STD_LOGIC := '0';
	 SIGNAL	 n0i0O30	:	STD_LOGIC := '0';
	 SIGNAL	 n0i1i33	:	STD_LOGIC := '0';
	 SIGNAL	 n0i1i34	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0i1i34_w_lg_q150w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0iil27	:	STD_LOGIC := '0';
	 SIGNAL	 n0iil28	:	STD_LOGIC := '0';
	 SIGNAL	 n0ili25	:	STD_LOGIC := '0';
	 SIGNAL	 n0ili26	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0ili26_w_lg_q120w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0ilO23	:	STD_LOGIC := '0';
	 SIGNAL	 n0ilO24	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0ilO24_w_lg_w_lg_q114w115w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0ilO24_w_lg_q114w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0iOl21	:	STD_LOGIC := '0';
	 SIGNAL	 n0iOl22	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0iOl22_w_lg_w_lg_q106w107w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0iOl22_w_lg_q106w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0l0i17	:	STD_LOGIC := '0';
	 SIGNAL	 n0l0i18	:	STD_LOGIC := '0';
	 SIGNAL	 n0l0O15	:	STD_LOGIC := '0';
	 SIGNAL	 n0l0O16	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0l0O16_w_lg_q83w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0l1i19	:	STD_LOGIC := '0';
	 SIGNAL	 n0l1i20	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0l1i20_w_lg_w_lg_q95w96w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l1i20_w_lg_q95w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0lli13	:	STD_LOGIC := '0';
	 SIGNAL	 n0lli14	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0lli14_w_lg_q74w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0lOO11	:	STD_LOGIC := '0';
	 SIGNAL	 n0lOO12	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0lOO12_w_lg_w_lg_q29w30w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lOO12_w_lg_q29w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O0i3	:	STD_LOGIC := '0';
	 SIGNAL	 n0O0i4	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O0i4_w_lg_w_lg_q9w10w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O0i4_w_lg_q9w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O0l1	:	STD_LOGIC := '0';
	 SIGNAL	 n0O0l2	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O0l2_w_lg_w_lg_q1w2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O0l2_w_lg_q1w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O1i10	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O1i10_w_lg_w_lg_q21w22w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O1i10_w_lg_q21w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O1i9	:	STD_LOGIC := '0';
	 SIGNAL	 n0O1l7	:	STD_LOGIC := '0';
	 SIGNAL	 n0O1l8	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O1l8_w_lg_w_lg_q17w18w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O1l8_w_lg_q17w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O1O5	:	STD_LOGIC := '0';
	 SIGNAL	 n0O1O6	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O1O6_w_lg_w_lg_q14w15w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O1O6_w_lg_q14w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n11l	:	STD_LOGIC := '0';
	 SIGNAL	wire_n11i_PRN	:	STD_LOGIC;
	 SIGNAL	wire_n11i_ENA	:	STD_LOGIC;
	 SIGNAL	n00i	:	STD_LOGIC := '0';
	 SIGNAL	n00l	:	STD_LOGIC := '0';
	 SIGNAL	n00O	:	STD_LOGIC := '0';
	 SIGNAL	n01i	:	STD_LOGIC := '0';
	 SIGNAL	n01l	:	STD_LOGIC := '0';
	 SIGNAL	n01O	:	STD_LOGIC := '0';
	 SIGNAL	n0ii	:	STD_LOGIC := '0';
	 SIGNAL	n0il	:	STD_LOGIC := '0';
	 SIGNAL	n0iO	:	STD_LOGIC := '0';
	 SIGNAL	n0li	:	STD_LOGIC := '0';
	 SIGNAL	n0ll	:	STD_LOGIC := '0';
	 SIGNAL	n0lO	:	STD_LOGIC := '0';
	 SIGNAL	n0Oi	:	STD_LOGIC := '0';
	 SIGNAL	n0Ol	:	STD_LOGIC := '0';
	 SIGNAL	n0OO	:	STD_LOGIC := '0';
	 SIGNAL	n10i	:	STD_LOGIC := '0';
	 SIGNAL	n10l	:	STD_LOGIC := '0';
	 SIGNAL	n11O	:	STD_LOGIC := '0';
	 SIGNAL	n1il	:	STD_LOGIC := '0';
	 SIGNAL	n1iO	:	STD_LOGIC := '0';
	 SIGNAL	n1li	:	STD_LOGIC := '0';
	 SIGNAL	n1Ol	:	STD_LOGIC := '0';
	 SIGNAL	n1OO	:	STD_LOGIC := '0';
	 SIGNAL	ni1i	:	STD_LOGIC := '0';
	 SIGNAL	ni1O	:	STD_LOGIC := '0';
	 SIGNAL	nll0i	:	STD_LOGIC := '0';
	 SIGNAL	nlOOi	:	STD_LOGIC := '0';
	 SIGNAL	nlOOl	:	STD_LOGIC := '0';
	 SIGNAL	nlOOO	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni1l_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_ni1l_w_lg_w118w121w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w118w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_w_lg_w_lg_w_lg_w_lg_n1OO93w97w98w102w110w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_w_lg_w_lg_w_lg_n1OO93w97w98w102w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_w_lg_w_lg_n01l104w108w109w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_w_lg_w_lg_n01O112w116w117w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_w_lg_w_lg_n1OO93w97w98w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_w_lg_n01i100w101w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_w_lg_n01l104w108w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_w_lg_n01O112w116w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_w_lg_n1OO93w97w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_n01i100w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_n01l104w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_n01O112w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_n1OO93w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_n1OO129w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nO_a	:	STD_LOGIC_VECTOR (18 DOWNTO 0);
	 SIGNAL  wire_nO_b	:	STD_LOGIC_VECTOR (18 DOWNTO 0);
	 SIGNAL  wire_gnd	:	STD_LOGIC;
	 SIGNAL  wire_nO_o	:	STD_LOGIC_VECTOR (18 DOWNTO 0);
	 SIGNAL  wire_nllii_i	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllii_o	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nliOO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nliOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nliOO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll1i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nll1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nll1i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll1l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nll1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nll1l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll1O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nll1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nll1O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_gen2ngen1148w151w152w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_gen2ngen181w84w85w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_gen2ngen172w75w76w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_gen2ngen1122w123w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_gen2ngen1148w151w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_gen2ngen181w84w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_gen2ngen172w75w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_gen2ngen177w156w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_gen2ngen177w89w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_gen2ngen177w78w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_gen2ngen1122w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_gen2ngen1148w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_gen2ngen181w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_gen2ngen172w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_gen2ngen177w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n001l355w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n00lO160w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rphfifo_regmode_rx196w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rxpcs_rst_int180w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  n000i :	STD_LOGIC;
	 SIGNAL  n001l :	STD_LOGIC;
	 SIGNAL  n001O :	STD_LOGIC;
	 SIGNAL  n00li :	STD_LOGIC;
	 SIGNAL  n00lO :	STD_LOGIC;
	 SIGNAL  n00Oi :	STD_LOGIC;
	 SIGNAL  n0i1O :	STD_LOGIC;
	 SIGNAL  n0l1O :	STD_LOGIC;
	 SIGNAL  n0lil :	STD_LOGIC;
	 SIGNAL  n0liO :	STD_LOGIC;
	 SIGNAL  n0llO :	STD_LOGIC;
	 SIGNAL  wire_w_rauto_deassert_pc_rst_cnt_range92w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rauto_deassert_pc_rst_cnt_range99w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rauto_deassert_pc_rst_cnt_range103w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rauto_deassert_pc_rst_cnt_range111w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_gnd <= '0';
	wire_w_lg_w_lg_w_lg_gen2ngen1148w151w152w(0) <= wire_w_lg_w_lg_gen2ngen1148w151w(0) AND n1Ol;
	wire_w_lg_w_lg_w_lg_gen2ngen181w84w85w(0) <= wire_w_lg_w_lg_gen2ngen181w84w(0) AND n1Ol;
	wire_w_lg_w_lg_w_lg_gen2ngen172w75w76w(0) <= wire_w_lg_w_lg_gen2ngen172w75w(0) AND n1Ol;
	wire_w_lg_w_lg_gen2ngen1122w123w(0) <= wire_w_lg_gen2ngen1122w(0) AND n1Ol;
	wire_w_lg_w_lg_gen2ngen1148w151w(0) <= wire_w_lg_gen2ngen1148w(0) AND wire_n0i1i34_w_lg_q150w(0);
	wire_w_lg_w_lg_gen2ngen181w84w(0) <= wire_w_lg_gen2ngen181w(0) AND wire_n0l0O16_w_lg_q83w(0);
	wire_w_lg_w_lg_gen2ngen172w75w(0) <= wire_w_lg_gen2ngen172w(0) AND wire_n0lli14_w_lg_q74w(0);
	wire_w_lg_w_lg_gen2ngen177w156w(0) <= wire_w_lg_gen2ngen177w(0) AND n00Oi;
	wire_w_lg_w_lg_gen2ngen177w89w(0) <= wire_w_lg_gen2ngen177w(0) AND n0l1O;
	wire_w_lg_w_lg_gen2ngen177w78w(0) <= wire_w_lg_gen2ngen177w(0) AND n0liO;
	wire_w_lg_gen2ngen1122w(0) <= gen2ngen1 AND wire_ni1l_w_lg_w118w121w(0);
	wire_w_lg_gen2ngen1148w(0) <= gen2ngen1 AND n0i1O;
	wire_w_lg_gen2ngen181w(0) <= gen2ngen1 AND n0lil;
	wire_w_lg_gen2ngen172w(0) <= gen2ngen1 AND n0llO;
	wire_w_lg_gen2ngen177w(0) <= NOT gen2ngen1;
	wire_w_lg_n001l355w(0) <= NOT n001l;
	wire_w_lg_n00lO160w(0) <= NOT n00lO;
	wire_w_lg_rphfifo_regmode_rx196w(0) <= NOT rphfifo_regmode_rx;
	wire_w_lg_rxpcs_rst_int180w(0) <= NOT rxpcs_rst_int;
	config_sel <= n11l;
	cs <= ( nlOOO & nlOOl & nlOOi & nll0i);
	dis_pc_byte <= n001O;
	n000i <= ((((n1il XOR n10l) XOR (NOT (n000l44 XOR n000l43))) AND rauto_speed_ena) AND singleorbundle);
	n001l <= (((((((wire_nllii_o(15) OR wire_nllii_o(14)) OR wire_nllii_o(13)) OR wire_nllii_o(12)) OR wire_nllii_o(11)) OR wire_nllii_o(10)) OR wire_nllii_o(1)) OR wire_nllii_o(0));
	n001O <= (((((wire_nllii_o(7) OR wire_nllii_o(6)) OR wire_nllii_o(5)) OR wire_nllii_o(4)) OR wire_nllii_o(2)) OR wire_nllii_o(3));
	n00li <= '1';
	n00lO <= (((wire_nllii_o(7) OR wire_nllii_o(5)) OR wire_nllii_o(1)) OR wire_nllii_o(9));
	n00Oi <= ((((((((((((((((((NOT (n1Ol XOR rpma_done_count(0))) AND (NOT (n1OO XOR rpma_done_count(1)))) AND (NOT (n01i XOR rpma_done_count(2)))) AND (NOT (n01l XOR rpma_done_count(3)))) AND (NOT (n01O XOR rpma_done_count(4)))) AND (NOT (n00i XOR rpma_done_count(5)))) AND (NOT (n00l XOR rpma_done_count(6)))) AND (NOT (n00O XOR rpma_done_count(7)))) AND (NOT (n0ii XOR rpma_done_count(8)))) AND (NOT (n0il XOR rpma_done_count(9)))) AND (NOT (n0iO XOR rpma_done_count(10)))) AND (NOT (n0li XOR rpma_done_count(11)))) AND (NOT (n0ll XOR rpma_done_count(12)))) AND (NOT (n0lO XOR rpma_done_count(13)))) AND (NOT (n0Oi XOR rpma_done_count(14)))) AND (NOT (n0Ol XOR rpma_done_count(15)))) AND (NOT (n0OO XOR rpma_done_count(16)))) AND (NOT (ni1i XOR rpma_done_count(17))));
	n0i1O <= ((((((((((((((((((NOT (n1OO XOR rpma_done_count(0))) AND (NOT (n01i XOR rpma_done_count(1)))) AND (NOT (n01l XOR rpma_done_count(2)))) AND (NOT (n01O XOR rpma_done_count(3)))) AND (NOT (n00i XOR rpma_done_count(4)))) AND (NOT (n00l XOR rpma_done_count(5)))) AND (NOT (n00O XOR rpma_done_count(6)))) AND (NOT (n0ii XOR rpma_done_count(7)))) AND (NOT (n0il XOR rpma_done_count(8)))) AND (NOT (n0iO XOR rpma_done_count(9)))) AND (NOT (n0li XOR rpma_done_count(10)))) AND (NOT (n0ll XOR rpma_done_count(11)))) AND (NOT (n0lO XOR rpma_done_count(12)))) AND (NOT (n0Oi XOR rpma_done_count(13)))) AND (NOT (n0Ol XOR rpma_done_count(14)))) AND (NOT (n0OO XOR rpma_done_count(15)))) AND (NOT (ni1i XOR rpma_done_count(16)))) AND (NOT (ni1O XOR rpma_done_count(17))));
	n0l1O <= (((((NOT (n1Ol XOR rauto_pc_en_cnt(0))) AND (NOT (n1OO XOR rauto_pc_en_cnt(1)))) AND (NOT (n01i XOR rauto_pc_en_cnt(2)))) AND (NOT (n01l XOR rauto_pc_en_cnt(3)))) AND (NOT (n01O XOR rauto_pc_en_cnt(4))));
	n0lil <= (((((NOT (n1OO XOR rauto_pc_en_cnt(0))) AND (NOT (n01i XOR rauto_pc_en_cnt(1)))) AND (NOT (n01l XOR rauto_pc_en_cnt(2)))) AND (NOT (n01O XOR rauto_pc_en_cnt(3)))) AND (NOT (n00i XOR rauto_pc_en_cnt(4))));
	n0liO <= ((((((NOT (n1Ol XOR rwait_for_phfifo_cnt(0))) AND (NOT (n1OO XOR rwait_for_phfifo_cnt(1)))) AND (NOT (n01i XOR rwait_for_phfifo_cnt(2)))) AND (NOT (n01l XOR rwait_for_phfifo_cnt(3)))) AND (NOT (n01O XOR rwait_for_phfifo_cnt(4)))) AND (NOT (n00i XOR rwait_for_phfifo_cnt(5))));
	n0llO <= ((((((NOT (n1OO XOR rwait_for_phfifo_cnt(0))) AND (NOT (n01i XOR rwait_for_phfifo_cnt(1)))) AND (NOT (n01l XOR rwait_for_phfifo_cnt(2)))) AND (NOT (n01O XOR rwait_for_phfifo_cnt(3)))) AND (NOT (n00i XOR rwait_for_phfifo_cnt(4)))) AND (NOT (n00l XOR rwait_for_phfifo_cnt(5))));
	pcie_switch <= wire_n1ll_dataout;
	reset_pc_ptrs <= (((wire_nllii_o(5) OR wire_nllii_o(4)) OR wire_nllii_o(2)) OR wire_nllii_o(3));
	speed_change <= wire_w_lg_n001l355w(0);
	wire_w_rauto_deassert_pc_rst_cnt_range92w(0) <= rauto_deassert_pc_rst_cnt(0);
	wire_w_rauto_deassert_pc_rst_cnt_range99w(0) <= rauto_deassert_pc_rst_cnt(1);
	wire_w_rauto_deassert_pc_rst_cnt_range103w(0) <= rauto_deassert_pc_rst_cnt(2);
	wire_w_rauto_deassert_pc_rst_cnt_range111w(0) <= rauto_deassert_pc_rst_cnt(3);
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n000l43 <= n000l44;
		END IF;
		if (now = 0 ns) then
			n000l43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n000l44 <= n000l43;
		END IF;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n00ii41 <= n00ii42;
		END IF;
		if (now = 0 ns) then
			n00ii41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n00ii42 <= n00ii41;
		END IF;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n00il39 <= n00il40;
		END IF;
		if (now = 0 ns) then
			n00il39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n00il40 <= n00il39;
		END IF;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n00ll37 <= n00ll38;
		END IF;
		if (now = 0 ns) then
			n00ll37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n00ll38 <= n00ll37;
		END IF;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n00Ol35 <= n00Ol36;
		END IF;
		if (now = 0 ns) then
			n00Ol35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n00Ol36 <= n00Ol35;
		END IF;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0i0i31 <= n0i0i32;
		END IF;
		if (now = 0 ns) then
			n0i0i31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0i0i32 <= n0i0i31;
		END IF;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0i0O29 <= n0i0O30;
		END IF;
		if (now = 0 ns) then
			n0i0O29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0i0O30 <= n0i0O29;
		END IF;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0i1i33 <= n0i1i34;
		END IF;
		if (now = 0 ns) then
			n0i1i33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0i1i34 <= n0i1i33;
		END IF;
	END PROCESS;
	wire_n0i1i34_w_lg_q150w(0) <= n0i1i34 XOR n0i1i33;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0iil27 <= n0iil28;
		END IF;
		if (now = 0 ns) then
			n0iil27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0iil28 <= n0iil27;
		END IF;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0ili25 <= n0ili26;
		END IF;
		if (now = 0 ns) then
			n0ili25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0ili26 <= n0ili25;
		END IF;
	END PROCESS;
	wire_n0ili26_w_lg_q120w(0) <= n0ili26 XOR n0ili25;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0ilO23 <= n0ilO24;
		END IF;
		if (now = 0 ns) then
			n0ilO23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0ilO24 <= n0ilO23;
		END IF;
	END PROCESS;
	wire_n0ilO24_w_lg_w_lg_q114w115w(0) <= NOT wire_n0ilO24_w_lg_q114w(0);
	wire_n0ilO24_w_lg_q114w(0) <= n0ilO24 XOR n0ilO23;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0iOl21 <= n0iOl22;
		END IF;
		if (now = 0 ns) then
			n0iOl21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0iOl22 <= n0iOl21;
		END IF;
	END PROCESS;
	wire_n0iOl22_w_lg_w_lg_q106w107w(0) <= NOT wire_n0iOl22_w_lg_q106w(0);
	wire_n0iOl22_w_lg_q106w(0) <= n0iOl22 XOR n0iOl21;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0l0i17 <= n0l0i18;
		END IF;
		if (now = 0 ns) then
			n0l0i17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0l0i18 <= n0l0i17;
		END IF;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0l0O15 <= n0l0O16;
		END IF;
		if (now = 0 ns) then
			n0l0O15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0l0O16 <= n0l0O15;
		END IF;
	END PROCESS;
	wire_n0l0O16_w_lg_q83w(0) <= n0l0O16 XOR n0l0O15;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0l1i19 <= n0l1i20;
		END IF;
		if (now = 0 ns) then
			n0l1i19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0l1i20 <= n0l1i19;
		END IF;
	END PROCESS;
	wire_n0l1i20_w_lg_w_lg_q95w96w(0) <= NOT wire_n0l1i20_w_lg_q95w(0);
	wire_n0l1i20_w_lg_q95w(0) <= n0l1i20 XOR n0l1i19;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0lli13 <= n0lli14;
		END IF;
		if (now = 0 ns) then
			n0lli13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0lli14 <= n0lli13;
		END IF;
	END PROCESS;
	wire_n0lli14_w_lg_q74w(0) <= n0lli14 XOR n0lli13;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0lOO11 <= n0lOO12;
		END IF;
		if (now = 0 ns) then
			n0lOO11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0lOO12 <= n0lOO11;
		END IF;
	END PROCESS;
	wire_n0lOO12_w_lg_w_lg_q29w30w(0) <= wire_n0lOO12_w_lg_q29w(0) AND ni1i;
	wire_n0lOO12_w_lg_q29w(0) <= n0lOO12 XOR n0lOO11;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0O0i3 <= n0O0i4;
		END IF;
		if (now = 0 ns) then
			n0O0i3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0O0i4 <= n0O0i3;
		END IF;
	END PROCESS;
	wire_n0O0i4_w_lg_w_lg_q9w10w(0) <= wire_n0O0i4_w_lg_q9w(0) AND n00i;
	wire_n0O0i4_w_lg_q9w(0) <= n0O0i4 XOR n0O0i3;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0O0l1 <= n0O0l2;
		END IF;
		if (now = 0 ns) then
			n0O0l1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0O0l2 <= n0O0l1;
		END IF;
	END PROCESS;
	wire_n0O0l2_w_lg_w_lg_q1w2w(0) <= wire_n0O0l2_w_lg_q1w(0) AND n1Ol;
	wire_n0O0l2_w_lg_q1w(0) <= n0O0l2 XOR n0O0l1;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0O1i10 <= n0O1i9;
		END IF;
	END PROCESS;
	wire_n0O1i10_w_lg_w_lg_q21w22w(0) <= wire_n0O1i10_w_lg_q21w(0) AND n0li;
	wire_n0O1i10_w_lg_q21w(0) <= n0O1i10 XOR n0O1i9;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0O1i9 <= n0O1i10;
		END IF;
		if (now = 0 ns) then
			n0O1i9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0O1l7 <= n0O1l8;
		END IF;
		if (now = 0 ns) then
			n0O1l7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0O1l8 <= n0O1l7;
		END IF;
	END PROCESS;
	wire_n0O1l8_w_lg_w_lg_q17w18w(0) <= wire_n0O1l8_w_lg_q17w(0) AND n0il;
	wire_n0O1l8_w_lg_q17w(0) <= n0O1l8 XOR n0O1l7;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0O1O5 <= n0O1O6;
		END IF;
		if (now = 0 ns) then
			n0O1O5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (refclk)
	BEGIN
		IF (refclk = '1' AND refclk'event) THEN n0O1O6 <= n0O1O5;
		END IF;
	END PROCESS;
	wire_n0O1O6_w_lg_w_lg_q14w15w(0) <= wire_n0O1O6_w_lg_q14w(0) AND n0ii;
	wire_n0O1O6_w_lg_q14w(0) <= n0O1O6 XOR n0O1O5;
	PROCESS (refclk, wire_n11i_PRN, rxpcs_rst_int)
	BEGIN
		IF (wire_n11i_PRN = '0') THEN
				n11l <= '1';
		ELSIF (rxpcs_rst_int = '1') THEN
				n11l <= '0';
		ELSIF (refclk = '1' AND refclk'event) THEN
			IF (wire_nllii_o(3) = '1') THEN
				n11l <= n1il;
			END IF;
		END IF;
	END PROCESS;
	wire_n11i_ENA <= wire_nllii_o(3);
	wire_n11i_PRN <= (n00ii42 XOR n00ii41);
	PROCESS (refclk, wire_ni1l_CLRN)
	BEGIN
		IF (wire_ni1l_CLRN = '0') THEN
				n00i <= '0';
				n00l <= '0';
				n00O <= '0';
				n01i <= '0';
				n01l <= '0';
				n01O <= '0';
				n0ii <= '0';
				n0il <= '0';
				n0iO <= '0';
				n0li <= '0';
				n0ll <= '0';
				n0lO <= '0';
				n0Oi <= '0';
				n0Ol <= '0';
				n0OO <= '0';
				n10i <= '0';
				n10l <= '0';
				n11O <= '0';
				n1il <= '0';
				n1iO <= '0';
				n1li <= '0';
				n1Ol <= '0';
				n1OO <= '0';
				ni1i <= '0';
				ni1O <= '0';
				nll0i <= '0';
				nlOOi <= '0';
				nlOOl <= '0';
				nlOOO <= '0';
		ELSIF (refclk = '1' AND refclk'event) THEN
				n00i <= wire_nili_dataout;
				n00l <= wire_nill_dataout;
				n00O <= wire_nilO_dataout;
				n01i <= wire_niii_dataout;
				n01l <= wire_niil_dataout;
				n01O <= wire_niiO_dataout;
				n0ii <= wire_niOi_dataout;
				n0il <= wire_niOl_dataout;
				n0iO <= wire_niOO_dataout;
				n0li <= wire_nl1i_dataout;
				n0ll <= wire_nl1l_dataout;
				n0lO <= wire_nl1O_dataout;
				n0Oi <= wire_nl0i_dataout;
				n0Ol <= wire_nl0l_dataout;
				n0OO <= wire_nl0O_dataout;
				n10i <= gen2ngen1;
				n10l <= n1il;
				n11O <= ((n10i XOR gen2ngen1) XOR (NOT (n00il40 XOR n00il39)));
				n1il <= n1iO;
				n1iO <= rate;
				n1li <= wire_ni0i_dataout;
				n1Ol <= wire_ni0l_dataout;
				n1OO <= wire_ni0O_dataout;
				ni1i <= wire_nlii_dataout;
				ni1O <= wire_nlil_dataout;
				nll0i <= wire_nliOO_o;
				nlOOi <= wire_nll1i_o;
				nlOOl <= wire_nll1l_o;
				nlOOO <= wire_nll1O_o;
		END IF;
	END PROCESS;
	wire_ni1l_CLRN <= ((n00ll38 XOR n00ll37) AND wire_w_lg_rxpcs_rst_int180w(0));
	wire_ni1l_w_lg_w118w121w(0) <= wire_ni1l_w118w(0) AND wire_n0ili26_w_lg_q120w(0);
	wire_ni1l_w118w(0) <= wire_ni1l_w_lg_w_lg_w_lg_w_lg_w_lg_n1OO93w97w98w102w110w(0) AND wire_ni1l_w_lg_w_lg_w_lg_n01O112w116w117w(0);
	wire_ni1l_w_lg_w_lg_w_lg_w_lg_w_lg_n1OO93w97w98w102w110w(0) <= wire_ni1l_w_lg_w_lg_w_lg_w_lg_n1OO93w97w98w102w(0) AND wire_ni1l_w_lg_w_lg_w_lg_n01l104w108w109w(0);
	wire_ni1l_w_lg_w_lg_w_lg_w_lg_n1OO93w97w98w102w(0) <= wire_ni1l_w_lg_w_lg_w_lg_n1OO93w97w98w(0) AND wire_ni1l_w_lg_w_lg_n01i100w101w(0);
	wire_ni1l_w_lg_w_lg_w_lg_n01l104w108w109w(0) <= NOT wire_ni1l_w_lg_w_lg_n01l104w108w(0);
	wire_ni1l_w_lg_w_lg_w_lg_n01O112w116w117w(0) <= NOT wire_ni1l_w_lg_w_lg_n01O112w116w(0);
	wire_ni1l_w_lg_w_lg_w_lg_n1OO93w97w98w(0) <= NOT wire_ni1l_w_lg_w_lg_n1OO93w97w(0);
	wire_ni1l_w_lg_w_lg_n01i100w101w(0) <= NOT wire_ni1l_w_lg_n01i100w(0);
	wire_ni1l_w_lg_w_lg_n01l104w108w(0) <= wire_ni1l_w_lg_n01l104w(0) XOR wire_n0iOl22_w_lg_w_lg_q106w107w(0);
	wire_ni1l_w_lg_w_lg_n01O112w116w(0) <= wire_ni1l_w_lg_n01O112w(0) XOR wire_n0ilO24_w_lg_w_lg_q114w115w(0);
	wire_ni1l_w_lg_w_lg_n1OO93w97w(0) <= wire_ni1l_w_lg_n1OO93w(0) XOR wire_n0l1i20_w_lg_w_lg_q95w96w(0);
	wire_ni1l_w_lg_n01i100w(0) <= n01i XOR wire_w_rauto_deassert_pc_rst_cnt_range99w(0);
	wire_ni1l_w_lg_n01l104w(0) <= n01l XOR wire_w_rauto_deassert_pc_rst_cnt_range103w(0);
	wire_ni1l_w_lg_n01O112w(0) <= n01O XOR wire_w_rauto_deassert_pc_rst_cnt_range111w(0);
	wire_ni1l_w_lg_n1OO93w(0) <= n1OO XOR wire_w_rauto_deassert_pc_rst_cnt_range92w(0);
	wire_ni1l_w_lg_n1OO129w(0) <= n1OO XOR wire_w_rauto_deassert_pc_rst_cnt_range99w(0);
	wire_n1ll_dataout <= wire_n1Oi_dataout WHEN rmaster_rx = '1'  ELSE wire_n1lO_dataout;
	wire_n1lO_dataout <= config_sel_quad_up WHEN rmaster_up_rx = '1'  ELSE config_sel_quad_down;
	wire_n1Oi_dataout <= n11l WHEN rindv_rx = '1'  ELSE config_sel_centrl;
	wire_ni0i_dataout <= wire_nliO_dataout AND NOT(wire_w_lg_n00lO160w(0));
	wire_ni0l_dataout <= wire_nO_o(0) AND NOT(wire_w_lg_n00lO160w(0));
	wire_ni0O_dataout <= wire_nO_o(1) AND NOT(wire_w_lg_n00lO160w(0));
	wire_niii_dataout <= wire_nO_o(2) AND NOT(wire_w_lg_n00lO160w(0));
	wire_niil_dataout <= wire_nO_o(3) AND NOT(wire_w_lg_n00lO160w(0));
	wire_niiO_dataout <= wire_nO_o(4) AND NOT(wire_w_lg_n00lO160w(0));
	wire_nili_dataout <= wire_nO_o(5) AND NOT(wire_w_lg_n00lO160w(0));
	wire_nill_dataout <= wire_nO_o(6) AND NOT(wire_w_lg_n00lO160w(0));
	wire_nilO_dataout <= wire_nO_o(7) AND NOT(wire_w_lg_n00lO160w(0));
	wire_niOi_dataout <= wire_nO_o(8) AND NOT(wire_w_lg_n00lO160w(0));
	wire_niOl_dataout <= wire_nO_o(9) AND NOT(wire_w_lg_n00lO160w(0));
	wire_niOO_dataout <= wire_nO_o(10) AND NOT(wire_w_lg_n00lO160w(0));
	wire_nl0i_dataout <= wire_nO_o(14) AND NOT(wire_w_lg_n00lO160w(0));
	wire_nl0l_dataout <= wire_nO_o(15) AND NOT(wire_w_lg_n00lO160w(0));
	wire_nl0O_dataout <= wire_nO_o(16) AND NOT(wire_w_lg_n00lO160w(0));
	wire_nl1i_dataout <= wire_nO_o(11) AND NOT(wire_w_lg_n00lO160w(0));
	wire_nl1l_dataout <= wire_nO_o(12) AND NOT(wire_w_lg_n00lO160w(0));
	wire_nl1O_dataout <= wire_nO_o(13) AND NOT(wire_w_lg_n00lO160w(0));
	wire_nlii_dataout <= wire_nO_o(17) AND NOT(wire_w_lg_n00lO160w(0));
	wire_nlil_dataout <= wire_nO_o(18) AND NOT(wire_w_lg_n00lO160w(0));
	wire_nliO_dataout <= wire_nlli_dataout OR n1li;
	wire_nlli_dataout <= ((wire_w_lg_w_lg_w_lg_gen2ngen1148w151w152w(0) AND (n00Ol36 XOR n00Ol35)) OR wire_w_lg_w_lg_gen2ngen177w156w(0)) WHEN wire_nllii_o(5) = '1'  ELSE wire_nlll_dataout;
	wire_nlll_dataout <= ((wire_w_lg_w_lg_gen2ngen1122w123w(0) AND (n0iil28 XOR n0iil27)) OR (wire_w_lg_gen2ngen177w(0) AND (((((NOT (n1Ol XOR rauto_deassert_pc_rst_cnt(0))) AND (NOT (wire_ni1l_w_lg_n1OO129w(0) XOR (NOT (n0i0O30 XOR n0i0O29))))) AND (NOT (n01i XOR rauto_deassert_pc_rst_cnt(2)))) AND (NOT (n01l XOR rauto_deassert_pc_rst_cnt(3)))) AND (n0i0i32 XOR n0i0i31)))) WHEN wire_nllii_o(7) = '1'  ELSE wire_nllO_dataout;
	wire_nllli_dataout <= nll0i AND NOT(n1li);
	wire_nllll_dataout <= nlOOi OR n1li;
	wire_nlllO_dataout <= nlOOl AND NOT(n1li);
	wire_nllO_dataout <= ((wire_w_lg_w_lg_w_lg_gen2ngen181w84w85w(0) AND (n0l0i18 XOR n0l0i17)) OR wire_w_lg_w_lg_gen2ngen177w89w(0)) WHEN wire_nllii_o(9) = '1'  ELSE wire_nlOi_dataout;
	wire_nllOi_dataout <= nlOOO OR n1li;
	wire_nllOl_dataout <= nlOOi AND NOT(n1li);
	wire_nllOO_dataout <= wire_w_lg_rphfifo_regmode_rx196w(0) WHEN n1li = '1'  ELSE nlOOl;
	wire_nlO0i_dataout <= nlOOl OR n11O;
	wire_nlO0l_dataout <= nlOOO AND NOT(n11O);
	wire_nlO0O_dataout <= nlOOO AND NOT(n1li);
	wire_nlO1i_dataout <= rphfifo_regmode_rx WHEN n1li = '1'  ELSE nlOOO;
	wire_nlO1l_dataout <= nll0i OR n11O;
	wire_nlO1O_dataout <= nlOOi AND NOT(n11O);
	wire_nlOi_dataout <= (wire_w_lg_w_lg_w_lg_gen2ngen172w75w76w(0) OR wire_w_lg_w_lg_gen2ngen177w78w(0)) WHEN wire_nllii_o(1) = '1'  ELSE n1li;
	wire_nlOii_dataout <= nll0i OR n000i;
	wire_nlOil_dataout <= rphfifo_regmode_rx WHEN n000i = '1'  ELSE nlOOi;
	wire_nlOiO_dataout <= nlOOl AND NOT(n000i);
	wire_nlOli_dataout <= nlOOO AND NOT(n000i);
	wire_nO_a <= ( ni1O & wire_n0lOO12_w_lg_w_lg_q29w30w & n0OO & n0Ol & n0Oi & n0lO & n0ll & wire_n0O1i10_w_lg_w_lg_q21w22w & n0iO & wire_n0O1l8_w_lg_w_lg_q17w18w & wire_n0O1O6_w_lg_w_lg_q14w15w & n00O & n00l & wire_n0O0i4_w_lg_w_lg_q9w10w & n01O & n01l & n01i & n1OO & wire_n0O0l2_w_lg_w_lg_q1w2w);
	wire_nO_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	nO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 19,
		width_b => 19,
		width_o => 19
	  )
	  PORT MAP ( 
		a => wire_nO_a,
		b => wire_nO_b,
		cin => wire_gnd,
		o => wire_nO_o
	  );
	wire_nllii_i <= ( nlOOO & nlOOl & nlOOi & nll0i);
	nllii :  oper_decoder
	  GENERIC MAP (
		width_i => 4,
		width_o => 16
	  )
	  PORT MAP ( 
		i => wire_nllii_i,
		o => wire_nllii_o
	  );
	wire_nliOO_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & wire_nllli_dataout & "1" & wire_nllli_dataout & "1" & wire_nllli_dataout & wire_nlO1l_dataout & "0" & "1" & wire_nllli_dataout & wire_nlOii_dataout);
	wire_nliOO_sel <= ( nlOOO & nlOOl & nlOOi & nll0i);
	nliOO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nliOO_data,
		o => wire_nliOO_o,
		sel => wire_nliOO_sel
	  );
	wire_nll1i_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & wire_nllll_dataout & "0" & wire_nllOl_dataout & "1" & wire_nllll_dataout & wire_nlO1O_dataout & "0" & "1" & wire_nllll_dataout & wire_nlOil_dataout);
	wire_nll1i_sel <= ( nlOOO & nlOOl & nlOOi & nll0i);
	nll1i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nll1i_data,
		o => wire_nll1i_o,
		sel => wire_nll1i_sel
	  );
	wire_nll1l_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & wire_nlllO_dataout & "0" & wire_nlllO_dataout & "1" & wire_nllOO_dataout & wire_nlO0i_dataout & "1" & "0" & wire_nlllO_dataout & wire_nlOiO_dataout);
	wire_nll1l_sel <= ( nlOOO & nlOOl & nlOOi & nll0i);
	nll1l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nll1l_data,
		o => wire_nll1l_o,
		sel => wire_nll1l_sel
	  );
	wire_nll1O_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & wire_nllOi_dataout & "1" & wire_nllOi_dataout & "0" & wire_nlO1i_dataout & wire_nlO0l_dataout & "0" & "0" & wire_nlO0O_dataout & wire_nlOli_dataout);
	wire_nll1O_sel <= ( nlOOO & nlOOl & nlOOi & nll0i);
	nll1O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nll1O_data,
		o => wire_nll1O_o,
		sel => wire_nll1O_sel
	  );

 END RTL; --stratixiv_hssi_rx_digi_auto_speed_neg
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 149 mux21 612 oper_add 8 oper_decoder 4 oper_mux 37 oper_selector 4 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_rx_digi_bist_ver IS 
	 PORT 
	 ( 
		 bistdone	:	OUT  STD_LOGIC;
		 bisterr	:	OUT  STD_LOGIC;
		 clk_2	:	IN  STD_LOGIC;
		 cur_state	:	OUT  STD_LOGIC_VECTOR (4 DOWNTO 0);
		 err_ctl	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 err_data	:	OUT  STD_LOGIC_VECTOR (15 DOWNTO 0);
		 prbs_done	:	IN  STD_LOGIC;
		 prbs_err	:	IN  STD_LOGIC;
		 rbist_clr_rx	:	IN  STD_LOGIC;
		 rbist_sel	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rbisten_rx	:	IN  STD_LOGIC;
		 rcxpat_chnl_sel	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rdwidth_rx	:	IN  STD_LOGIC;
		 rpma_doublewidth_rx	:	IN  STD_LOGIC;
		 rpmadwidth_rx	:	IN  STD_LOGIC;
		 rxc	:	IN  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 rxd	:	IN  STD_LOGIC_VECTOR (63 DOWNTO 0);
		 selftest_done	:	OUT  STD_LOGIC;
		 selftest_err	:	OUT  STD_LOGIC;
		 soft_reset	:	IN  STD_LOGIC;
		 sync_status	:	IN  STD_LOGIC
	 ); 
 END stratixiv_hssi_rx_digi_bist_ver;

 ARCHITECTURE RTL OF stratixiv_hssi_rx_digi_bist_ver IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 n0li1O47	:	STD_LOGIC := '0';
	 SIGNAL	 n0li1O48	:	STD_LOGIC := '0';
	 SIGNAL	 n0lOOi45	:	STD_LOGIC := '0';
	 SIGNAL	 n0lOOi46	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0lOOi46_w_lg_w_lg_q339w340w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lOOi46_w_lg_q339w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0lOOl43	:	STD_LOGIC := '0';
	 SIGNAL	 n0lOOl44	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0lOOl44_w_lg_w_lg_q314w315w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lOOl44_w_lg_q314w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0lOOO41	:	STD_LOGIC := '0';
	 SIGNAL	 n0lOOO42	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0lOOO42_w_lg_w_lg_q309w310w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lOOO42_w_lg_q309w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O10i33	:	STD_LOGIC := '0';
	 SIGNAL	 n0O10i34	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O10i34_w_lg_w_lg_q186w187w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O10i34_w_lg_q186w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O10l31	:	STD_LOGIC := '0';
	 SIGNAL	 n0O10l32	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O10l32_w_lg_w_lg_q177w178w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O10l32_w_lg_q177w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O10O29	:	STD_LOGIC := '0';
	 SIGNAL	 n0O10O30	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O10O30_w_lg_w_lg_q174w175w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O10O30_w_lg_q174w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O11i39	:	STD_LOGIC := '0';
	 SIGNAL	 n0O11i40	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O11i40_w_lg_w_lg_q303w304w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O11i40_w_lg_q303w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O11l37	:	STD_LOGIC := '0';
	 SIGNAL	 n0O11l38	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O11l38_w_lg_w_lg_q237w238w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O11l38_w_lg_q237w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O11O35	:	STD_LOGIC := '0';
	 SIGNAL	 n0O11O36	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O11O36_w_lg_w_lg_q191w192w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O11O36_w_lg_q191w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O1ii27	:	STD_LOGIC := '0';
	 SIGNAL	 n0O1ii28	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O1ii28_w_lg_w_lg_q159w160w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O1ii28_w_lg_q159w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O1Ol25	:	STD_LOGIC := '0';
	 SIGNAL	 n0O1Ol26	:	STD_LOGIC := '0';
	 SIGNAL	 n0Oi0O21	:	STD_LOGIC := '0';
	 SIGNAL	 n0Oi0O22	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0Oi0O22_w_lg_w_lg_q116w117w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0Oi0O22_w_lg_q116w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0Oi1O23	:	STD_LOGIC := '0';
	 SIGNAL	 n0Oi1O24	:	STD_LOGIC := '0';
	 SIGNAL	 n0OiOi19	:	STD_LOGIC := '0';
	 SIGNAL	 n0OiOi20	:	STD_LOGIC := '0';
	 SIGNAL	 n0OiOO17	:	STD_LOGIC := '0';
	 SIGNAL	 n0OiOO18	:	STD_LOGIC := '0';
	 SIGNAL	 n0Ol0i11	:	STD_LOGIC := '0';
	 SIGNAL	 n0Ol0i12	:	STD_LOGIC := '0';
	 SIGNAL	 n0Ol0O10	:	STD_LOGIC := '0';
	 SIGNAL	 n0Ol0O9	:	STD_LOGIC := '0';
	 SIGNAL	 n0Ol1i15	:	STD_LOGIC := '0';
	 SIGNAL	 n0Ol1i16	:	STD_LOGIC := '0';
	 SIGNAL	 n0Ol1l13	:	STD_LOGIC := '0';
	 SIGNAL	 n0Ol1l14	:	STD_LOGIC := '0';
	 SIGNAL	 n0Olil7	:	STD_LOGIC := '0';
	 SIGNAL	 n0Olil8	:	STD_LOGIC := '0';
	 SIGNAL	 n0OlOO5	:	STD_LOGIC := '0';
	 SIGNAL	 n0OlOO6	:	STD_LOGIC := '0';
	 SIGNAL	 n0OO0i1	:	STD_LOGIC := '0';
	 SIGNAL	 n0OO0i2	:	STD_LOGIC := '0';
	 SIGNAL	 n0OO1l3	:	STD_LOGIC := '0';
	 SIGNAL	 n0OO1l4	:	STD_LOGIC := '0';
	 SIGNAL	ni00i	:	STD_LOGIC := '0';
	 SIGNAL	ni01l	:	STD_LOGIC := '0';
	 SIGNAL	ni1lOl	:	STD_LOGIC := '0';
	 SIGNAL	niiilO	:	STD_LOGIC := '0';
	 SIGNAL	niiiOi	:	STD_LOGIC := '0';
	 SIGNAL	niiiOl	:	STD_LOGIC := '0';
	 SIGNAL	niiiOO	:	STD_LOGIC := '0';
	 SIGNAL	niil0i	:	STD_LOGIC := '0';
	 SIGNAL	niil0l	:	STD_LOGIC := '0';
	 SIGNAL	niil0O	:	STD_LOGIC := '0';
	 SIGNAL	niil1i	:	STD_LOGIC := '0';
	 SIGNAL	niil1l	:	STD_LOGIC := '0';
	 SIGNAL	niil1O	:	STD_LOGIC := '0';
	 SIGNAL	niilii	:	STD_LOGIC := '0';
	 SIGNAL	niilil	:	STD_LOGIC := '0';
	 SIGNAL	niiliO	:	STD_LOGIC := '0';
	 SIGNAL	niilli	:	STD_LOGIC := '0';
	 SIGNAL	niilll	:	STD_LOGIC := '0';
	 SIGNAL	niillO	:	STD_LOGIC := '0';
	 SIGNAL	niilOi	:	STD_LOGIC := '0';
	 SIGNAL	niilOl	:	STD_LOGIC := '0';
	 SIGNAL	niiO1i	:	STD_LOGIC := '0';
	 SIGNAL	niiO1l	:	STD_LOGIC := '0';
	 SIGNAL	nll00O	:	STD_LOGIC := '0';
	 SIGNAL	nll0ii	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni01O_CLRN	:	STD_LOGIC;
	 SIGNAL	n11Oi	:	STD_LOGIC := '0';
	 SIGNAL	ni00l	:	STD_LOGIC := '0';
	 SIGNAL	ni00O	:	STD_LOGIC := '0';
	 SIGNAL	ni01i	:	STD_LOGIC := '0';
	 SIGNAL	ni0ii	:	STD_LOGIC := '0';
	 SIGNAL	ni0il	:	STD_LOGIC := '0';
	 SIGNAL	ni0iO	:	STD_LOGIC := '0';
	 SIGNAL	ni0li	:	STD_LOGIC := '0';
	 SIGNAL	ni0ll	:	STD_LOGIC := '0';
	 SIGNAL	ni0lO	:	STD_LOGIC := '0';
	 SIGNAL	ni0Oi	:	STD_LOGIC := '0';
	 SIGNAL	ni0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nii1i	:	STD_LOGIC := '0';
	 SIGNAL	niilOO	:	STD_LOGIC := '0';
	 SIGNAL	niiO0l	:	STD_LOGIC := '0';
	 SIGNAL	niiO0O	:	STD_LOGIC := '0';
	 SIGNAL	niiOii	:	STD_LOGIC := '0';
	 SIGNAL	niiOil	:	STD_LOGIC := '0';
	 SIGNAL	niiOiO	:	STD_LOGIC := '0';
	 SIGNAL	niiOli	:	STD_LOGIC := '0';
	 SIGNAL	niiOll	:	STD_LOGIC := '0';
	 SIGNAL	niiOlO	:	STD_LOGIC := '0';
	 SIGNAL	niiOOi	:	STD_LOGIC := '0';
	 SIGNAL	niiOOl	:	STD_LOGIC := '0';
	 SIGNAL	niiOOO	:	STD_LOGIC := '0';
	 SIGNAL	nil00i	:	STD_LOGIC := '0';
	 SIGNAL	nil00l	:	STD_LOGIC := '0';
	 SIGNAL	nil00O	:	STD_LOGIC := '0';
	 SIGNAL	nil01i	:	STD_LOGIC := '0';
	 SIGNAL	nil01l	:	STD_LOGIC := '0';
	 SIGNAL	nil01O	:	STD_LOGIC := '0';
	 SIGNAL	nil10i	:	STD_LOGIC := '0';
	 SIGNAL	nil10l	:	STD_LOGIC := '0';
	 SIGNAL	nil10O	:	STD_LOGIC := '0';
	 SIGNAL	nil11i	:	STD_LOGIC := '0';
	 SIGNAL	nil11l	:	STD_LOGIC := '0';
	 SIGNAL	nil11O	:	STD_LOGIC := '0';
	 SIGNAL	nil1ii	:	STD_LOGIC := '0';
	 SIGNAL	nil1il	:	STD_LOGIC := '0';
	 SIGNAL	nil1iO	:	STD_LOGIC := '0';
	 SIGNAL	nil1li	:	STD_LOGIC := '0';
	 SIGNAL	nil1ll	:	STD_LOGIC := '0';
	 SIGNAL	nil1lO	:	STD_LOGIC := '0';
	 SIGNAL	nil1Oi	:	STD_LOGIC := '0';
	 SIGNAL	nil1Ol	:	STD_LOGIC := '0';
	 SIGNAL	nil1OO	:	STD_LOGIC := '0';
	 SIGNAL	nl1Oll	:	STD_LOGIC := '0';
	 SIGNAL	nll00l	:	STD_LOGIC := '0';
	 SIGNAL	nll0il	:	STD_LOGIC := '0';
	 SIGNAL	nll0iO	:	STD_LOGIC := '0';
	 SIGNAL	nll0li	:	STD_LOGIC := '0';
	 SIGNAL	nll0ll	:	STD_LOGIC := '0';
	 SIGNAL	nll0lO	:	STD_LOGIC := '0';
	 SIGNAL	nll0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nll0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nll0OO	:	STD_LOGIC := '0';
	 SIGNAL	nlli0i	:	STD_LOGIC := '0';
	 SIGNAL	nlli0l	:	STD_LOGIC := '0';
	 SIGNAL	nlli0O	:	STD_LOGIC := '0';
	 SIGNAL	nlli1i	:	STD_LOGIC := '0';
	 SIGNAL	nlli1l	:	STD_LOGIC := '0';
	 SIGNAL	nlli1O	:	STD_LOGIC := '0';
	 SIGNAL	nlliii	:	STD_LOGIC := '0';
	 SIGNAL	nlliil	:	STD_LOGIC := '0';
	 SIGNAL	nlliiO	:	STD_LOGIC := '0';
	 SIGNAL	nllili	:	STD_LOGIC := '0';
	 SIGNAL	nllill	:	STD_LOGIC := '0';
	 SIGNAL	nllilO	:	STD_LOGIC := '0';
	 SIGNAL	nlliOi	:	STD_LOGIC := '0';
	 SIGNAL	nlliOl	:	STD_LOGIC := '0';
	 SIGNAL	nlliOO	:	STD_LOGIC := '0';
	 SIGNAL	nlll0i	:	STD_LOGIC := '0';
	 SIGNAL	nlll1i	:	STD_LOGIC := '0';
	 SIGNAL	nlll1l	:	STD_LOGIC := '0';
	 SIGNAL	nlll1O	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni0OO_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_ni0OO_PRN	:	STD_LOGIC;
	 SIGNAL  wire_ni0OO_w_lg_w_lg_w_lg_w1242w1243w1244w1245w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_w1251w1252w1253w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_w1242w1243w1244w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w1251w1252w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w1242w1243w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w1251w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w1242w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_w_lg_w_lg_nlliOO1247w1248w1249w1250w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_w_lg_w_lg_nlli0O990w992w993w994w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_w_lg_w_lg_nlliOO1222w1238w1240w1241w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_w_lg_ni0li837w838w839w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_w_lg_nil1Oi2312w2314w2315w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_w_lg_nlli0O995w996w997w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_w_lg_nlliOO1247w1248w1249w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_w_lg_nlli0O990w992w993w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_w_lg_nlliOO1222w1224w1225w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_w_lg_nlliOO1222w1238w1240w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_ni0li837w838w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_nil1Oi2312w2314w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_nlli0O995w996w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_nlliOO1247w1248w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_nll0Ol1343w1344w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_nlli0O990w992w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_nlliOO1222w1224w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_w_lg_nlliOO1222w1238w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_ni0li837w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nil1Oi2312w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nll0Ol1352w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nlli0O995w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nlliOO1247w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_ni00O840w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nil10l2331w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nil10O2322w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nil1ii2320w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nil1il2318w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nil1iO2316w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nil1li2325w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nil1ll2313w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nil1lO2311w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nll0ll1347w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nll0lO1345w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nll0Oi1351w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nll0Ol1343w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nlli0l991w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nlli0O990w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nlli1l1296w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nlli1O1273w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nlliii1236w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nlliil1234w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nlliiO1232w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nllili1230w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nllill1228w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nllilO1226w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nlliOi1239w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nlliOl1223w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0OO_w_lg_nlliOO1222w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	niiO0i	:	STD_LOGIC := '0';
	 SIGNAL	wire_niiO1O_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_n000i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni_w_lg_dataout403w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_dataout153w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni000i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni000l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni000O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni001i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni001O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nililO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl_w_lg_dataout1094w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_dataout1013w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl000l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlii_w_lg_dataout2015w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlil_w_lg_dataout720w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliO_w_lg_dataout718w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nliO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlli_w_lg_dataout716w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlll_w_lg_dataout679w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllO_w_lg_dataout713w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nllO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOi_w_lg_dataout678w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOl_w_lg_dataout710w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOO_w_lg_w_lg_w2466w2467w2468w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_w2481w2482w2483w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w2466w2467w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w2481w2482w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w2410w2411w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w2433w2434w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w2452w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w2466w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w2481w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w2410w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w2433w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout2333w2449w2450w2451w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout2333w2334w2335w2465w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout2333w2334w2335w2336w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout709w711w2408w2409w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout709w2430w2431w2432w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_w_lg_dataout2333w2449w2450w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_w_lg_dataout2333w2334w2335w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_w_lg_dataout709w711w2408w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_w_lg_dataout709w2430w2431w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_dataout2333w2449w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_dataout2333w2334w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_dataout709w711w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_dataout709w2430w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_dataout2333w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_dataout709w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nO_w_lg_dataout1517w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiOl_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niiOl_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_gnd	:	STD_LOGIC;
	 SIGNAL  wire_niiOl_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niO0Ol_a	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_niO0Ol_b	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_niO0Ol_o	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_niO0OO_a	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_niO0OO_b	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_niO0OO_o	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_niOi1i_a	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_niOi1i_b	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_niOi1i_o	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_nllO0i_a	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nllO0i_b	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nllO0i_o	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nllOil_a	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllOil_b	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllOil_o	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO00O_a	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_nlO00O_b	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_nlO00O_o	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_nlO11l_a	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO11l_b	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO11l_o	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n11li_i	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n11li_o	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_ni1iii_i	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni1iii_o	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nii0Ol_i	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nii0Ol_o	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nl1OiO_i	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1OiO_o	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n100i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n100i_o	:	STD_LOGIC;
	 SIGNAL  wire_n100i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n100l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n100l_o	:	STD_LOGIC;
	 SIGNAL  wire_n100l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n101i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n101i_o	:	STD_LOGIC;
	 SIGNAL  wire_n101i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n101l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n101l_o	:	STD_LOGIC;
	 SIGNAL  wire_n101l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n101O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n101O_o	:	STD_LOGIC;
	 SIGNAL  wire_n101O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n11Ol_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n11Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_n11Ol_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n11OO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n11OO_o	:	STD_LOGIC;
	 SIGNAL  wire_n11OO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_ni1iil_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni1iil_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1iil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni1iiO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni1iiO_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1iiO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni1ili_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni1ili_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1ili_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni1ill_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni1ill_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1ill_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni1ilO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni1ilO_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1ilO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni1iOi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni1iOi_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1iOi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni1iOl_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni1iOl_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1iOl_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni1iOO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni1iOO_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1iOO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nii0iO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nii0iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nii0iO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nii0li_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nii0li_o	:	STD_LOGIC;
	 SIGNAL  wire_nii0li_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nii0lO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nii0lO_o	:	STD_LOGIC;
	 SIGNAL  wire_nii0lO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nii0OO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nii0OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nii0OO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niii0i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niii0i_o	:	STD_LOGIC;
	 SIGNAL  wire_niii0i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niii0l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niii0l_o	:	STD_LOGIC;
	 SIGNAL  wire_niii0l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niii0O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niii0O_o	:	STD_LOGIC;
	 SIGNAL  wire_niii0O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niii1i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niii1i_o	:	STD_LOGIC;
	 SIGNAL  wire_niii1i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niii1l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niii1l_o	:	STD_LOGIC;
	 SIGNAL  wire_niii1l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niii1O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niii1O_o	:	STD_LOGIC;
	 SIGNAL  wire_niii1O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niiiii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niiiii_o	:	STD_LOGIC;
	 SIGNAL  wire_niiiii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niiiil_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niiiil_o	:	STD_LOGIC;
	 SIGNAL  wire_niiiil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niiiiO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niiiiO_o	:	STD_LOGIC;
	 SIGNAL  wire_niiiiO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niiili_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niiili_o	:	STD_LOGIC;
	 SIGNAL  wire_niiili_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niiill_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niiill_o	:	STD_LOGIC;
	 SIGNAL  wire_niiill_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl010i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nl010i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl010i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl010l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nl010l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl010l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl010O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nl010O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl010O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl011i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nl011i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl011i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl011l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nl011l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl011l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl011O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nl011O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl011O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl01ii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nl01ii_o	:	STD_LOGIC;
	 SIGNAL  wire_nl01ii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n11ii_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n11ii_o	:	STD_LOGIC;
	 SIGNAL  wire_n11ii_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n11il_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n11il_o	:	STD_LOGIC;
	 SIGNAL  wire_n11il_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n11ll_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n11ll_o	:	STD_LOGIC;
	 SIGNAL  wire_n11ll_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_ni1i0l_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_ni1i0l_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1i0l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rpmadwidth_rx15w16w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n0OlOi124w2004w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_n0OiiO114w118w119w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0lOli979w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0OilO112w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rpmadwidth_rx15w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rbist_sel_range1w9w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rcxpat_chnl_sel_range842w847w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rxc_range111w980w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rxc_range111w113w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rxc_range111w2011w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rxc_range111w2008w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rxd_range651w668w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iO0l2052w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iO1O2054w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iOii2050w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iOil2133w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iOiO2048w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iOli2046w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iOll2044w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iOlO2047w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iOOi2042w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iOOO2040w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l01l2021w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l01O2020w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0il2014w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0iO2013w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l10i2036w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l10l2126w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l10O2034w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l11l2038w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l1ii2032w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l1il2030w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l1iO2033w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l1li2028w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l1lO2026w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l1Ol2024w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l1OO2023w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0li0l1011w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0li0O1010w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0liii1009w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0liil1008w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0lili1006w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0lill1005w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0lilO1004w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0liOi1003w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0liOl1002w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0liOO1001w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ll0i999w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ll1O1000w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0llil989w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0lliO988w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0llll987w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0lllO986w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0llOl985w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0llOO984w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O00i136w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O00l135w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O00O134w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O01i139w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O01l138w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O01O137w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O0ii133w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O0il132w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O0iO131w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O0li130w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O0ll129w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O0lO128w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O0Oi127w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O0Ol126w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O1iO151w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O1li150w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O1ll149w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O1lO148w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0Oi1i125w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0OlOi124w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rbist_clr_rx108w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rpma_doublewidth_rx14w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_soft_reset105w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rbist_sel_range3w4w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rcxpat_chnl_sel_range844w845w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rxd_range652w667w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n0OiiO114w118w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0OiiO114w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  n0iO0i :	STD_LOGIC;
	 SIGNAL  n0iO0l :	STD_LOGIC;
	 SIGNAL  n0iO0O :	STD_LOGIC;
	 SIGNAL  n0iO1i :	STD_LOGIC;
	 SIGNAL  n0iO1l :	STD_LOGIC;
	 SIGNAL  n0iO1O :	STD_LOGIC;
	 SIGNAL  n0iOii :	STD_LOGIC;
	 SIGNAL  n0iOil :	STD_LOGIC;
	 SIGNAL  n0iOiO :	STD_LOGIC;
	 SIGNAL  n0iOli :	STD_LOGIC;
	 SIGNAL  n0iOll :	STD_LOGIC;
	 SIGNAL  n0iOlO :	STD_LOGIC;
	 SIGNAL  n0iOOi :	STD_LOGIC;
	 SIGNAL  n0iOOl :	STD_LOGIC;
	 SIGNAL  n0iOOO :	STD_LOGIC;
	 SIGNAL  n0l00i :	STD_LOGIC;
	 SIGNAL  n0l00l :	STD_LOGIC;
	 SIGNAL  n0l00O :	STD_LOGIC;
	 SIGNAL  n0l01i :	STD_LOGIC;
	 SIGNAL  n0l01l :	STD_LOGIC;
	 SIGNAL  n0l01O :	STD_LOGIC;
	 SIGNAL  n0l0ii :	STD_LOGIC;
	 SIGNAL  n0l0il :	STD_LOGIC;
	 SIGNAL  n0l0iO :	STD_LOGIC;
	 SIGNAL  n0l0li :	STD_LOGIC;
	 SIGNAL  n0l0ll :	STD_LOGIC;
	 SIGNAL  n0l0lO :	STD_LOGIC;
	 SIGNAL  n0l0Oi :	STD_LOGIC;
	 SIGNAL  n0l0Ol :	STD_LOGIC;
	 SIGNAL  n0l0OO :	STD_LOGIC;
	 SIGNAL  n0l10i :	STD_LOGIC;
	 SIGNAL  n0l10l :	STD_LOGIC;
	 SIGNAL  n0l10O :	STD_LOGIC;
	 SIGNAL  n0l11i :	STD_LOGIC;
	 SIGNAL  n0l11l :	STD_LOGIC;
	 SIGNAL  n0l11O :	STD_LOGIC;
	 SIGNAL  n0l1ii :	STD_LOGIC;
	 SIGNAL  n0l1il :	STD_LOGIC;
	 SIGNAL  n0l1iO :	STD_LOGIC;
	 SIGNAL  n0l1li :	STD_LOGIC;
	 SIGNAL  n0l1ll :	STD_LOGIC;
	 SIGNAL  n0l1lO :	STD_LOGIC;
	 SIGNAL  n0l1Oi :	STD_LOGIC;
	 SIGNAL  n0l1Ol :	STD_LOGIC;
	 SIGNAL  n0l1OO :	STD_LOGIC;
	 SIGNAL  n0li0i :	STD_LOGIC;
	 SIGNAL  n0li0l :	STD_LOGIC;
	 SIGNAL  n0li0O :	STD_LOGIC;
	 SIGNAL  n0li1i :	STD_LOGIC;
	 SIGNAL  n0li1l :	STD_LOGIC;
	 SIGNAL  n0liii :	STD_LOGIC;
	 SIGNAL  n0liil :	STD_LOGIC;
	 SIGNAL  n0liiO :	STD_LOGIC;
	 SIGNAL  n0lili :	STD_LOGIC;
	 SIGNAL  n0lill :	STD_LOGIC;
	 SIGNAL  n0lilO :	STD_LOGIC;
	 SIGNAL  n0liOi :	STD_LOGIC;
	 SIGNAL  n0liOl :	STD_LOGIC;
	 SIGNAL  n0liOO :	STD_LOGIC;
	 SIGNAL  n0ll0i :	STD_LOGIC;
	 SIGNAL  n0ll0l :	STD_LOGIC;
	 SIGNAL  n0ll0O :	STD_LOGIC;
	 SIGNAL  n0ll1i :	STD_LOGIC;
	 SIGNAL  n0ll1l :	STD_LOGIC;
	 SIGNAL  n0ll1O :	STD_LOGIC;
	 SIGNAL  n0llii :	STD_LOGIC;
	 SIGNAL  n0llil :	STD_LOGIC;
	 SIGNAL  n0lliO :	STD_LOGIC;
	 SIGNAL  n0llli :	STD_LOGIC;
	 SIGNAL  n0llll :	STD_LOGIC;
	 SIGNAL  n0lllO :	STD_LOGIC;
	 SIGNAL  n0llOi :	STD_LOGIC;
	 SIGNAL  n0llOl :	STD_LOGIC;
	 SIGNAL  n0llOO :	STD_LOGIC;
	 SIGNAL  n0lO0i :	STD_LOGIC;
	 SIGNAL  n0lO0l :	STD_LOGIC;
	 SIGNAL  n0lO0O :	STD_LOGIC;
	 SIGNAL  n0lO1i :	STD_LOGIC;
	 SIGNAL  n0lO1l :	STD_LOGIC;
	 SIGNAL  n0lO1O :	STD_LOGIC;
	 SIGNAL  n0lOii :	STD_LOGIC;
	 SIGNAL  n0lOil :	STD_LOGIC;
	 SIGNAL  n0lOiO :	STD_LOGIC;
	 SIGNAL  n0lOli :	STD_LOGIC;
	 SIGNAL  n0lOll :	STD_LOGIC;
	 SIGNAL  n0lOlO :	STD_LOGIC;
	 SIGNAL  n0O00i :	STD_LOGIC;
	 SIGNAL  n0O00l :	STD_LOGIC;
	 SIGNAL  n0O00O :	STD_LOGIC;
	 SIGNAL  n0O01i :	STD_LOGIC;
	 SIGNAL  n0O01l :	STD_LOGIC;
	 SIGNAL  n0O01O :	STD_LOGIC;
	 SIGNAL  n0O0ii :	STD_LOGIC;
	 SIGNAL  n0O0il :	STD_LOGIC;
	 SIGNAL  n0O0iO :	STD_LOGIC;
	 SIGNAL  n0O0li :	STD_LOGIC;
	 SIGNAL  n0O0ll :	STD_LOGIC;
	 SIGNAL  n0O0lO :	STD_LOGIC;
	 SIGNAL  n0O0Oi :	STD_LOGIC;
	 SIGNAL  n0O0Ol :	STD_LOGIC;
	 SIGNAL  n0O0OO :	STD_LOGIC;
	 SIGNAL  n0O1il :	STD_LOGIC;
	 SIGNAL  n0O1iO :	STD_LOGIC;
	 SIGNAL  n0O1li :	STD_LOGIC;
	 SIGNAL  n0O1ll :	STD_LOGIC;
	 SIGNAL  n0O1lO :	STD_LOGIC;
	 SIGNAL  n0O1Oi :	STD_LOGIC;
	 SIGNAL  n0Oi0l :	STD_LOGIC;
	 SIGNAL  n0Oi1i :	STD_LOGIC;
	 SIGNAL  n0Oi1l :	STD_LOGIC;
	 SIGNAL  n0Oiil :	STD_LOGIC;
	 SIGNAL  n0OiiO :	STD_LOGIC;
	 SIGNAL  n0Oili :	STD_LOGIC;
	 SIGNAL  n0Oill :	STD_LOGIC;
	 SIGNAL  n0OilO :	STD_LOGIC;
	 SIGNAL  n0OiOl :	STD_LOGIC;
	 SIGNAL  n0Olli :	STD_LOGIC;
	 SIGNAL  n0Olll :	STD_LOGIC;
	 SIGNAL  n0OllO :	STD_LOGIC;
	 SIGNAL  n0OlOi :	STD_LOGIC;
	 SIGNAL  n0OlOl :	STD_LOGIC;
	 SIGNAL  wire_w_rbist_sel_range1w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rbist_sel_range3w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rcxpat_chnl_sel_range842w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rcxpat_chnl_sel_range844w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rxc_range111w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rxd_range651w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rxd_range652w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_gnd <= '0';
	wire_w_lg_w_lg_rpmadwidth_rx15w16w(0) <= wire_w_lg_rpmadwidth_rx15w(0) AND rdwidth_rx;
	wire_w_lg_w_lg_n0OlOi124w2004w(0) <= wire_w_lg_n0OlOi124w(0) AND n0li1i;
	wire_w_lg_w_lg_w_lg_n0OiiO114w118w119w(0) <= wire_w_lg_w_lg_n0OiiO114w118w(0) AND n0Oi0l;
	wire_w_lg_n0lOli979w(0) <= n0lOli AND n0lOiO;
	wire_w_lg_n0OilO112w(0) <= n0OilO AND n0Oill;
	wire_w_lg_rpmadwidth_rx15w(0) <= rpmadwidth_rx AND wire_w_lg_rpma_doublewidth_rx14w(0);
	wire_w_lg_w_rbist_sel_range1w9w(0) <= wire_w_rbist_sel_range1w(0) AND wire_w_lg_w_rbist_sel_range3w4w(0);
	wire_w_lg_w_rcxpat_chnl_sel_range842w847w(0) <= wire_w_rcxpat_chnl_sel_range842w(0) AND wire_w_lg_w_rcxpat_chnl_sel_range844w845w(0);
	wire_w_lg_w_rxc_range111w980w(0) <= wire_w_rxc_range111w(0) AND wire_w_lg_n0lOli979w(0);
	wire_w_lg_w_rxc_range111w113w(0) <= wire_w_rxc_range111w(0) AND wire_w_lg_n0OilO112w(0);
	wire_w_lg_w_rxc_range111w2011w(0) <= wire_w_rxc_range111w(0) AND n0l0li;
	wire_w_lg_w_rxc_range111w2008w(0) <= wire_w_rxc_range111w(0) AND n0l0lO;
	wire_w_lg_w_rxd_range651w668w(0) <= wire_w_rxd_range651w(0) AND wire_w_lg_w_rxd_range652w667w(0);
	wire_w_lg_n0iO0l2052w(0) <= NOT n0iO0l;
	wire_w_lg_n0iO1O2054w(0) <= NOT n0iO1O;
	wire_w_lg_n0iOii2050w(0) <= NOT n0iOii;
	wire_w_lg_n0iOil2133w(0) <= NOT n0iOil;
	wire_w_lg_n0iOiO2048w(0) <= NOT n0iOiO;
	wire_w_lg_n0iOli2046w(0) <= NOT n0iOli;
	wire_w_lg_n0iOll2044w(0) <= NOT n0iOll;
	wire_w_lg_n0iOlO2047w(0) <= NOT n0iOlO;
	wire_w_lg_n0iOOi2042w(0) <= NOT n0iOOi;
	wire_w_lg_n0iOOO2040w(0) <= NOT n0iOOO;
	wire_w_lg_n0l01l2021w(0) <= NOT n0l01l;
	wire_w_lg_n0l01O2020w(0) <= NOT n0l01O;
	wire_w_lg_n0l0il2014w(0) <= NOT n0l0il;
	wire_w_lg_n0l0iO2013w(0) <= NOT n0l0iO;
	wire_w_lg_n0l10i2036w(0) <= NOT n0l10i;
	wire_w_lg_n0l10l2126w(0) <= NOT n0l10l;
	wire_w_lg_n0l10O2034w(0) <= NOT n0l10O;
	wire_w_lg_n0l11l2038w(0) <= NOT n0l11l;
	wire_w_lg_n0l1ii2032w(0) <= NOT n0l1ii;
	wire_w_lg_n0l1il2030w(0) <= NOT n0l1il;
	wire_w_lg_n0l1iO2033w(0) <= NOT n0l1iO;
	wire_w_lg_n0l1li2028w(0) <= NOT n0l1li;
	wire_w_lg_n0l1lO2026w(0) <= NOT n0l1lO;
	wire_w_lg_n0l1Ol2024w(0) <= NOT n0l1Ol;
	wire_w_lg_n0l1OO2023w(0) <= NOT n0l1OO;
	wire_w_lg_n0li0l1011w(0) <= NOT n0li0l;
	wire_w_lg_n0li0O1010w(0) <= NOT n0li0O;
	wire_w_lg_n0liii1009w(0) <= NOT n0liii;
	wire_w_lg_n0liil1008w(0) <= NOT n0liil;
	wire_w_lg_n0lili1006w(0) <= NOT n0lili;
	wire_w_lg_n0lill1005w(0) <= NOT n0lill;
	wire_w_lg_n0lilO1004w(0) <= NOT n0lilO;
	wire_w_lg_n0liOi1003w(0) <= NOT n0liOi;
	wire_w_lg_n0liOl1002w(0) <= NOT n0liOl;
	wire_w_lg_n0liOO1001w(0) <= NOT n0liOO;
	wire_w_lg_n0ll0i999w(0) <= NOT n0ll0i;
	wire_w_lg_n0ll1O1000w(0) <= NOT n0ll1O;
	wire_w_lg_n0llil989w(0) <= NOT n0llil;
	wire_w_lg_n0lliO988w(0) <= NOT n0lliO;
	wire_w_lg_n0llll987w(0) <= NOT n0llll;
	wire_w_lg_n0lllO986w(0) <= NOT n0lllO;
	wire_w_lg_n0llOl985w(0) <= NOT n0llOl;
	wire_w_lg_n0llOO984w(0) <= NOT n0llOO;
	wire_w_lg_n0O00i136w(0) <= NOT n0O00i;
	wire_w_lg_n0O00l135w(0) <= NOT n0O00l;
	wire_w_lg_n0O00O134w(0) <= NOT n0O00O;
	wire_w_lg_n0O01i139w(0) <= NOT n0O01i;
	wire_w_lg_n0O01l138w(0) <= NOT n0O01l;
	wire_w_lg_n0O01O137w(0) <= NOT n0O01O;
	wire_w_lg_n0O0ii133w(0) <= NOT n0O0ii;
	wire_w_lg_n0O0il132w(0) <= NOT n0O0il;
	wire_w_lg_n0O0iO131w(0) <= NOT n0O0iO;
	wire_w_lg_n0O0li130w(0) <= NOT n0O0li;
	wire_w_lg_n0O0ll129w(0) <= NOT n0O0ll;
	wire_w_lg_n0O0lO128w(0) <= NOT n0O0lO;
	wire_w_lg_n0O0Oi127w(0) <= NOT n0O0Oi;
	wire_w_lg_n0O0Ol126w(0) <= NOT n0O0Ol;
	wire_w_lg_n0O1iO151w(0) <= NOT n0O1iO;
	wire_w_lg_n0O1li150w(0) <= NOT n0O1li;
	wire_w_lg_n0O1ll149w(0) <= NOT n0O1ll;
	wire_w_lg_n0O1lO148w(0) <= NOT n0O1lO;
	wire_w_lg_n0Oi1i125w(0) <= NOT n0Oi1i;
	wire_w_lg_n0OlOi124w(0) <= NOT n0OlOi;
	wire_w_lg_rbist_clr_rx108w(0) <= NOT rbist_clr_rx;
	wire_w_lg_rpma_doublewidth_rx14w(0) <= NOT rpma_doublewidth_rx;
	wire_w_lg_soft_reset105w(0) <= NOT soft_reset;
	wire_w_lg_w_rbist_sel_range3w4w(0) <= NOT wire_w_rbist_sel_range3w(0);
	wire_w_lg_w_rcxpat_chnl_sel_range844w845w(0) <= NOT wire_w_rcxpat_chnl_sel_range844w(0);
	wire_w_lg_w_rxd_range652w667w(0) <= NOT wire_w_rxd_range652w(0);
	wire_w_lg_w_lg_n0OiiO114w118w(0) <= wire_w_lg_n0OiiO114w(0) OR wire_n0Oi0O22_w_lg_w_lg_q116w117w(0);
	wire_w_lg_n0OiiO114w(0) <= n0OiiO OR n0Oiil;
	bistdone <= ((wire_nl1l_dataout OR prbs_done) OR (NOT (n0Ol0O10 XOR n0Ol0O9)));
	bisterr <= ((wire_nl1i_dataout OR prbs_err) OR (NOT (n0Olil8 XOR n0Olil7)));
	cur_state <= ( wire_n1OO_dataout & wire_n1Ol_dataout & wire_n1Oi_dataout & wire_n1lO_dataout & wire_n1ll_dataout);
	err_ctl <= ( wire_niOO_dataout & wire_niOl_dataout);
	err_data <= ( wire_niOi_dataout & wire_nilO_dataout & wire_nill_dataout & wire_nili_dataout & wire_niiO_dataout & wire_niil_dataout & wire_niii_dataout & wire_ni0O_dataout & wire_ni0l_dataout & wire_ni0i_dataout & wire_ni1O_dataout & wire_ni1l_dataout & wire_ni1i_dataout & wire_n0OO_dataout & wire_n0Ol_dataout & wire_n0Oi_dataout);
	n0iO0i <= (wire_w_lg_n0iO0l2052w(0) OR wire_w_lg_n0l1Ol2024w(0));
	n0iO0l <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND (NOT rxd(0))) AND rxd(1)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7));
	n0iO0O <= (wire_w_lg_n0iOii2050w(0) OR wire_w_lg_n0l01l2021w(0));
	n0iO1i <= (((((((((((((wire_ni1iii_o(15) OR wire_ni1iii_o(14)) OR wire_ni1iii_o(13)) OR wire_ni1iii_o(12)) OR wire_ni1iii_o(11)) OR wire_ni1iii_o(10)) OR wire_ni1iii_o(9)) OR wire_ni1iii_o(8)) OR wire_ni1iii_o(7)) OR wire_ni1iii_o(6)) OR wire_ni1iii_o(5)) OR wire_ni1iii_o(4)) OR wire_ni1iii_o(3)) OR wire_ni1iii_o(0));
	n0iO1l <= (wire_w_lg_n0iO1O2054w(0) OR wire_w_lg_n0l1Ol2024w(0));
	n0iO1O <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND rxd(0)) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7));
	n0iOii <= ((((((((wire_nlOO_w_lg_w_lg_w2481w2482w2483w(0) AND (NOT rxd(0))) AND rxd(1)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7));
	n0iOil <= (wire_w_lg_n0iOiO2048w(0) OR wire_w_lg_n0l1Ol2024w(0));
	n0iOiO <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND rxd(0)) AND rxd(1)) AND rxd(2)) AND (NOT rxd(3))) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7));
	n0iOli <= (wire_w_lg_n0iOll2044w(0) OR wire_w_lg_n0l1Ol2024w(0));
	n0iOll <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND (NOT rxd(0))) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7));
	n0iOlO <= (wire_w_lg_n0iOOi2042w(0) OR wire_w_lg_n0l01l2021w(0));
	n0iOOi <= ((((((((wire_nlOO_w_lg_w_lg_w2466w2467w2468w(0) AND (NOT rxd(0))) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7));
	n0iOOl <= (wire_w_lg_n0iOOO2040w(0) OR wire_w_lg_n0l1Ol2024w(0));
	n0iOOO <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND (NOT rxd(0))) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND (NOT rxd(5))) AND rxd(6)) AND rxd(7));
	n0l00i <= (((((((nil1lO AND nil1ll) AND nil1li) AND nil1iO) AND nil1il) AND nil1ii) AND nil10O) AND nil10l);
	n0l00l <= (n0OlOi AND n0l00O);
	n0l00O <= (((((((niiOll AND niiOli) AND niiOiO) AND niiOil) AND niiOii) AND niiO0O) AND niiO0l) AND niiO0i);
	n0l01i <= (wire_w_lg_n0l01O2020w(0) OR wire_w_lg_n0l01l2021w(0));
	n0l01l <= (wire_nlii_dataout AND rxc(0));
	n0l01O <= ((((((((((wire_nlOO_w_lg_w2410w2411w(0) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND (NOT rxd(0))) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND (NOT rxd(5))) AND (NOT rxd(6))) AND (NOT rxd(7)));
	n0l0ii <= (wire_w_lg_n0l0il2014w(0) OR (NOT (wire_nlii_w_lg_dataout2015w(0) AND (NOT rxc(0)))));
	n0l0il <= ((((((((((((((((NOT (rxd(0) XOR wire_niOi1l_dataout)) AND (NOT (rxd(1) XOR wire_niOi1O_dataout))) AND (NOT (rxd(2) XOR wire_niOi0i_dataout))) AND (NOT (rxd(3) XOR wire_niOi0l_dataout))) AND (NOT (rxd(4) XOR wire_niOi0O_dataout))) AND (NOT (rxd(5) XOR wire_niOiii_dataout))) AND (NOT (rxd(6) XOR wire_niOiil_dataout))) AND (NOT (rxd(7) XOR wire_niOiiO_dataout))) AND (NOT (wire_nlil_dataout XOR wire_niOili_dataout))) AND (NOT (wire_nliO_dataout XOR wire_niOill_dataout))) AND (NOT (wire_nlli_dataout XOR wire_niOilO_dataout))) AND (NOT (wire_nlll_dataout XOR wire_niOiOi_dataout))) AND (NOT (wire_nllO_dataout XOR wire_niOiOl_dataout))) AND (NOT (wire_nlOi_dataout XOR wire_niOiOO_dataout))) AND (NOT (wire_nlOl_dataout XOR wire_niOl1i_dataout))) AND (NOT (wire_nlOO_dataout XOR wire_niOl1l_dataout)));
	n0l0iO <= (wire_w_lg_n0OlOi124w(0) AND wire_w_lg_w_rxc_range111w2011w(0));
	n0l0li <= (((((((rxd(0) AND rxd(1)) AND (NOT rxd(2))) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7));
	n0l0ll <= (n0OlOi AND ((wire_nlii_dataout AND n0l0Oi) AND wire_w_lg_w_rxc_range111w2008w(0)));
	n0l0lO <= ((((((((NOT rxd(0)) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND (NOT rxd(6))) AND rxd(7));
	n0l0Oi <= (((wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout2333w2334w2335w2336w(0) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_dataout) AND wire_nlil_dataout);
	n0l0Ol <= (wire_w_lg_w_lg_n0OlOi124w2004w(0) OR (n0OlOi AND n0l0OO));
	n0l0OO <= ((((((wire_ni0OO_w_lg_w_lg_nil1Oi2312w2314w(0) AND wire_ni0OO_w_lg_nil1li2325w(0)) AND wire_ni0OO_w_lg_nil1iO2316w(0)) AND wire_ni0OO_w_lg_nil1il2318w(0)) AND wire_ni0OO_w_lg_nil1ii2320w(0)) AND wire_ni0OO_w_lg_nil10O2322w(0)) AND wire_ni0OO_w_lg_nil10l2331w(0));
	n0l10i <= ((((((((((wire_nlOO_w2452w(0) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND (NOT rxd(0))) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND (NOT rxd(5))) AND (NOT rxd(6))) AND rxd(7));
	n0l10l <= (wire_w_lg_n0l10O2034w(0) OR wire_w_lg_n0l1Ol2024w(0));
	n0l10O <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND (NOT rxd(0))) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND (NOT rxd(7)));
	n0l11i <= (wire_w_lg_n0l11l2038w(0) OR wire_w_lg_n0l1Ol2024w(0));
	n0l11l <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND (NOT rxd(0))) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND (NOT rxd(5))) AND (NOT rxd(6))) AND rxd(7));
	n0l11O <= (wire_w_lg_n0l10i2036w(0) OR wire_w_lg_n0l01l2021w(0));
	n0l1ii <= (wire_w_lg_n0l1il2030w(0) OR wire_w_lg_n0l1Ol2024w(0));
	n0l1il <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND (NOT rxd(0))) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND (NOT rxd(5))) AND rxd(6)) AND (NOT rxd(7)));
	n0l1iO <= (wire_w_lg_n0l1li2028w(0) OR wire_w_lg_n0l01l2021w(0));
	n0l1li <= ((((((((((wire_nlOO_w_lg_w2433w2434w(0) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND (NOT rxd(0))) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND (NOT rxd(5))) AND rxd(6)) AND (NOT rxd(7)));
	n0l1ll <= (wire_w_lg_n0l1lO2026w(0) OR wire_w_lg_n0l1Ol2024w(0));
	n0l1lO <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND (NOT rxd(0))) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND (NOT rxd(6))) AND (NOT rxd(7)));
	n0l1Oi <= (wire_w_lg_n0l1OO2023w(0) OR wire_w_lg_n0l1Ol2024w(0));
	n0l1Ol <= (wire_nlii_w_lg_dataout2015w(0) AND rxc(0));
	n0l1OO <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND (NOT rxd(0))) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND (NOT rxd(5))) AND (NOT rxd(6))) AND (NOT rxd(7)));
	n0li0i <= ((NOT rxc(0)) OR wire_w_lg_n0li0l1011w(0));
	n0li0l <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND rxd(0)) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7));
	n0li0O <= (((((((((((((((wire_nlOl_w_lg_dataout710w(0) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND rxd(0)) AND rxd(1)) AND (NOT rxd(2))) AND rxd(3)) AND (NOT rxd(4))) AND rxd(5)) AND (NOT rxd(6))) AND rxd(7)) AND (NOT (n0OlOi XOR wire_nlli_dataout))) AND (NOT (n0OlOi XOR wire_nlll_dataout))) AND (NOT (n0OlOi XOR wire_nllO_dataout))) AND (NOT (n0OlOi XOR wire_nlOi_dataout))) AND (NOT (n0OlOi XOR wire_nlOO_dataout)));
	n0li1i <= (((((wire_ni0OO_w_lg_w_lg_w_lg_nil1Oi2312w2314w2315w(0) AND wire_ni0OO_w_lg_nil1iO2316w(0)) AND wire_ni0OO_w_lg_nil1il2318w(0)) AND wire_ni0OO_w_lg_nil1ii2320w(0)) AND wire_ni0OO_w_lg_nil10O2322w(0)) AND nil10l);
	n0li1l <= (wire_nO_dataout AND rxd(10));
	n0liii <= (((((((((((((((wire_nlOl_w_lg_dataout710w(0) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND (NOT rxd(0))) AND rxd(1)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND (NOT rxd(5))) AND (NOT rxd(6))) AND (NOT rxd(7))) AND (NOT (n0OlOi XOR wire_nlli_dataout))) AND (NOT (n0OlOi XOR wire_nlll_dataout))) AND (NOT (n0OlOi XOR wire_nllO_dataout))) AND (NOT (n0OlOi XOR wire_nlOi_dataout))) AND (NOT (n0OlOi XOR wire_nlOO_dataout)));
	n0liil <= (((((((((((((((wire_nlOl_w_lg_dataout710w(0) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND rxd(0)) AND rxd(1)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND (NOT rxd(5))) AND (NOT rxd(6))) AND rxd(7)) AND (NOT (n0OlOi XOR wire_nlli_dataout))) AND (NOT (n0OlOi XOR wire_nlll_dataout))) AND (NOT (n0OlOi XOR wire_nllO_dataout))) AND (NOT (n0OlOi XOR wire_nlOi_dataout))) AND (NOT (n0OlOi XOR wire_nlOO_dataout)));
	n0liiO <= (wire_w_lg_n0lili1006w(0) OR (NOT (wire_nlii_dataout AND (NOT rxc(0)))));
	n0lili <= (((((((((((((((wire_nliO_w_lg_dataout718w(0) AND rxd(0)) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND (NOT rxd(6))) AND rxd(7)) AND (NOT (n0OlOi XOR wire_nlil_dataout))) AND (NOT (n0OlOi XOR wire_nlli_dataout))) AND (NOT (n0OlOi XOR wire_nlll_dataout))) AND (NOT (n0OlOi XOR wire_nllO_dataout))) AND (NOT (n0OlOi XOR wire_nlOi_dataout))) AND (NOT (n0OlOi XOR wire_nlOl_dataout))) AND (NOT (n0OlOi XOR wire_nlOO_dataout)));
	n0lill <= (((((((((((((((wire_nlOl_w_lg_dataout710w(0) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND rxd(0)) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND (NOT rxd(3))) AND rxd(4)) AND rxd(5)) AND (NOT rxd(6))) AND rxd(7)) AND (NOT (n0OlOi XOR wire_nlil_dataout))) AND (NOT (n0OlOi XOR wire_nlli_dataout))) AND (NOT (n0OlOi XOR wire_nllO_dataout))) AND (NOT (n0OlOi XOR wire_nlOi_dataout))) AND (NOT (n0OlOi XOR wire_nlOO_dataout)));
	n0lilO <= ((((wire_ni0OO_w_lg_w_lg_nll0Ol1343w1344w(0) AND wire_ni0OO_w_lg_nll0lO1345w(0)) AND wire_ni0OO_w_lg_nll0ll1347w(0)) AND nll0li) AND nll0iO);
	n0liOi <= ((((wire_ni0OO_w_lg_nll0Ol1352w(0) AND wire_ni0OO_w_lg_nll0lO1345w(0)) AND nll0ll) AND nll0li) AND nll0iO);
	n0liOl <= (((((((((((((((wire_nlOl_w_lg_dataout710w(0) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND rxd(5)) AND rxd(7)) AND (NOT (wire_w_lg_n0OlOi124w(0) XOR rxd(0)))) AND (NOT (wire_w_lg_n0OlOi124w(0) XOR rxd(1)))) AND (NOT (n0OlOi XOR rxd(2)))) AND (NOT (wire_w_lg_n0OlOi124w(0) XOR rxd(3)))) AND (NOT (n0OlOi XOR rxd(4)))) AND (NOT (n0OlOi XOR rxd(6)))) AND (NOT (n0OlOi XOR wire_nlil_dataout))) AND (NOT (n0OlOi XOR wire_nliO_dataout))) AND (NOT (n0OlOi XOR wire_nlll_dataout))) AND (NOT (n0OlOi XOR wire_nlOi_dataout))) AND (NOT (n0OlOi XOR wire_nlOO_dataout)));
	n0liOO <= (((((((((((((((wire_nlll_w_lg_dataout679w(0) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND rxd(0)) AND rxd(1)) AND (NOT rxd(2))) AND rxd(3)) AND (NOT rxd(4))) AND rxd(5)) AND rxd(6)) AND rxd(7)) AND (NOT (n0OlOi XOR wire_nlli_dataout))) AND (NOT (n0OlOi XOR wire_nllO_dataout))) AND (NOT (n0OlOi XOR wire_nlOi_dataout))) AND (NOT (n0OlOi XOR wire_nlOl_dataout))) AND (NOT (n0OlOi XOR wire_nlOO_dataout)));
	n0ll0i <= (wire_ni0OO_w_lg_w_lg_w_lg_nlli0O990w992w993w(0) AND wire_ni0OO_w_lg_nlli1O1273w(0));
	n0ll0l <= (((wire_ni0OO_w_lg_nlli0O990w(0) AND nlli0l) AND nlli0i) AND nlli1O);
	n0ll0O <= (((nlli0O AND nlli0l) AND nlli0i) AND nlli1O);
	n0ll1i <= ((wire_ni0OO_w_lg_nlli1l1296w(0) AND nlli1i) AND nll0OO);
	n0ll1l <= ((nlli1l AND nlli1i) AND nll0OO);
	n0ll1O <= (((((((((((((((wire_nllO_w_lg_dataout713w(0) AND wire_nlli_w_lg_dataout716w(0)) AND (NOT rxd(0))) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND (NOT rxd(3))) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7)) AND (NOT (n0OlOi XOR wire_nlil_dataout))) AND (NOT (n0OlOi XOR wire_nliO_dataout))) AND (NOT (n0OlOi XOR wire_nlll_dataout))) AND (NOT (n0OlOi XOR wire_nlOi_dataout))) AND (NOT (n0OlOi XOR wire_nlOl_dataout))) AND (NOT (n0OlOi XOR wire_nlOO_dataout)));
	n0llii <= (wire_ni0OO_w_lg_w_lg_w_lg_w_lg_nlli0O990w992w993w994w(0) OR wire_ni0OO_w_lg_w_lg_w_lg_nlli0O995w996w997w(0));
	n0llil <= (((((((((((((((wire_nlOO_w_lg_dataout709w(0) AND wire_nlil_w_lg_dataout720w(0)) AND (NOT rxd(0))) AND rxd(1)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND (NOT rxd(7))) AND (NOT (n0OlOi XOR wire_nliO_dataout))) AND (NOT (n0OlOi XOR wire_nlli_dataout))) AND (NOT (n0OlOi XOR wire_nlll_dataout))) AND (NOT (n0OlOi XOR wire_nllO_dataout))) AND (NOT (n0OlOi XOR wire_nlOi_dataout))) AND (NOT (n0OlOi XOR wire_nlOl_dataout)));
	n0lliO <= (wire_ni0OO_w_lg_w_lg_w1251w1252w1253w(0) AND nlliii);
	n0llli <= ((((((wire_ni0OO_w_lg_w_lg_w_lg_nlliOO1222w1224w1225w(0) AND wire_ni0OO_w_lg_nllilO1226w(0)) AND wire_ni0OO_w_lg_nllill1228w(0)) AND wire_ni0OO_w_lg_nllili1230w(0)) AND wire_ni0OO_w_lg_nlliiO1232w(0)) AND wire_ni0OO_w_lg_nlliil1234w(0)) AND nlliii);
	n0llll <= (wire_ni0OO_w_lg_w_lg_w_lg_w1242w1243w1244w1245w(0) AND nlliii);
	n0lllO <= (wire_ni0OO_w_lg_w_lg_w1251w1252w1253w(0) AND wire_ni0OO_w_lg_nlliii1236w(0));
	n0llOi <= ((((((wire_ni0OO_w_lg_w_lg_w_lg_nlliOO1222w1224w1225w(0) AND wire_ni0OO_w_lg_nllilO1226w(0)) AND wire_ni0OO_w_lg_nllill1228w(0)) AND wire_ni0OO_w_lg_nllili1230w(0)) AND wire_ni0OO_w_lg_nlliiO1232w(0)) AND wire_ni0OO_w_lg_nlliil1234w(0)) AND wire_ni0OO_w_lg_nlliii1236w(0));
	n0llOl <= (wire_ni0OO_w_lg_w_lg_w_lg_w1242w1243w1244w1245w(0) AND wire_ni0OO_w_lg_nlliii1236w(0));
	n0llOO <= (((((((((((((((wire_nlOO_w_lg_dataout709w(0) AND wire_nlil_w_lg_dataout720w(0)) AND rxd(0)) AND rxd(1)) AND (NOT rxd(2))) AND rxd(3)) AND (NOT rxd(4))) AND (NOT rxd(5))) AND (NOT rxd(6))) AND (NOT rxd(7))) AND (NOT (n0OlOi XOR wire_nliO_dataout))) AND (NOT (n0OlOi XOR wire_nlli_dataout))) AND (NOT (n0OlOi XOR wire_nlll_dataout))) AND (NOT (n0OlOi XOR wire_nllO_dataout))) AND (NOT (n0OlOi XOR wire_nlOi_dataout))) AND (NOT (n0OlOi XOR wire_nlOl_dataout)));
	n0lO0i <= (rcxpat_chnl_sel(0) AND rcxpat_chnl_sel(1));
	n0lO0l <= (n0lOii AND n0lO0O);
	n0lO0O <= ((((((wire_w_lg_w_rxd_range651w668w(0) AND rxd(2)) AND (NOT rxd(3))) AND rxd(4)) AND (NOT rxd(5))) AND rxd(6)) AND (NOT rxd(7)));
	n0lO1i <= ((NOT rcxpat_chnl_sel(0)) AND rcxpat_chnl_sel(1));
	n0lO1l <= wire_w_lg_w_rcxpat_chnl_sel_range842w847w(0);
	n0lO1O <= (n0lO0O AND n0lO0i);
	n0lOii <= (n0lO1l OR n0lO1i);
	n0lOil <= wire_w_lg_w_rxc_range111w980w(0);
	n0lOiO <= ((NOT rcxpat_chnl_sel(0)) AND wire_w_lg_w_rcxpat_chnl_sel_range844w845w(0));
	n0lOli <= (((((((rxd(0) AND rxd(1)) AND (NOT rxd(2))) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7));
	n0lOll <= (((((((((((((((((((((((((((((wire_n11li_o(31) OR wire_n11li_o(30)) OR wire_n11li_o(29)) OR wire_n11li_o(28)) OR wire_n11li_o(27)) OR wire_n11li_o(26)) OR wire_n11li_o(25)) OR wire_n11li_o(24)) OR wire_n11li_o(23)) OR wire_n11li_o(22)) OR wire_n11li_o(21)) OR wire_n11li_o(20)) OR wire_n11li_o(19)) OR wire_n11li_o(18)) OR wire_n11li_o(17)) OR wire_n11li_o(16)) OR wire_n11li_o(13)) OR wire_n11li_o(12)) OR wire_n11li_o(11)) OR wire_n11li_o(10)) OR wire_n11li_o(9)) OR wire_n11li_o(8)) OR wire_n11li_o(7)) OR wire_n11li_o(6)) OR wire_n11li_o(5)) OR wire_n11li_o(4)) OR wire_n11li_o(3)) OR wire_n11li_o(2)) OR wire_n11li_o(1)) OR wire_n11li_o(0));
	n0lOlO <= ((((((((((((((((((((((((((wire_n11li_o(31) OR wire_n11li_o(30)) OR wire_n11li_o(29)) OR wire_n11li_o(28)) OR wire_n11li_o(27)) OR wire_n11li_o(26)) OR wire_n11li_o(25)) OR wire_n11li_o(24)) OR wire_n11li_o(23)) OR wire_n11li_o(22)) OR wire_n11li_o(21)) OR wire_n11li_o(15)) OR wire_n11li_o(14)) OR wire_n11li_o(13)) OR wire_n11li_o(12)) OR wire_n11li_o(11)) OR wire_n11li_o(10)) OR wire_n11li_o(9)) OR wire_n11li_o(8)) OR wire_n11li_o(7)) OR wire_n11li_o(6)) OR wire_n11li_o(5)) OR wire_n11li_o(4)) OR wire_n11li_o(3)) OR wire_n11li_o(2)) OR wire_n11li_o(1)) OR wire_n11li_o(0));
	n0O00i <= (wire_ni0OO_w_lg_w_lg_w_lg_ni0li837w838w839w(0) AND wire_ni0OO_w_lg_ni00O840w(0));
	n0O00l <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND rxd(0)) AND rxd(1)) AND (NOT rxd(2))) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7));
	n0O00O <= (((((((((((((((wire_nlli_w_lg_dataout716w(0) AND (NOT rxd(0))) AND rxd(1)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND (NOT rxd(5))) AND rxd(6)) AND (NOT rxd(7))) AND (NOT (n0OlOi XOR wire_nlil_dataout))) AND (NOT (n0OlOi XOR wire_nliO_dataout))) AND (NOT (n0OlOi XOR wire_nlll_dataout))) AND (NOT (n0OlOi XOR wire_nllO_dataout))) AND (NOT (n0OlOi XOR wire_nlOi_dataout))) AND (NOT (n0OlOi XOR wire_nlOl_dataout))) AND (NOT (n0OlOi XOR wire_nlOO_dataout)));
	n0O01i <= (((((((((((((((wire_nliO_w_lg_dataout718w(0) AND (NOT rxd(0))) AND wire_w_lg_w_rxd_range652w667w(0)) AND (NOT rxd(2))) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7)) AND (NOT (n0OlOi XOR wire_nlil_dataout))) AND (NOT (n0OlOi XOR wire_nlli_dataout))) AND (NOT (n0OlOi XOR wire_nlll_dataout))) AND (NOT (n0OlOi XOR wire_nllO_dataout))) AND (NOT (n0OlOi XOR wire_nlOi_dataout))) AND (NOT (n0OlOi XOR wire_nlOl_dataout))) AND (NOT (n0OlOi XOR wire_nlOO_dataout)));
	n0O01l <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND rxd(0)) AND wire_w_lg_w_rxd_range652w667w(0)) AND (NOT rxd(2))) AND rxd(3)) AND rxd(4)) AND (NOT rxd(5))) AND rxd(6)) AND (NOT rxd(7)));
	n0O01O <= (((((((((((((((wire_nlOO_w_lg_dataout709w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND rxd(0)) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND (NOT rxd(3))) AND rxd(4)) AND rxd(5)) AND (NOT rxd(6))) AND (NOT rxd(7))) AND (NOT (n0OlOi XOR wire_nlil_dataout))) AND (NOT (n0OlOi XOR wire_nlll_dataout))) AND (NOT (n0OlOi XOR wire_nllO_dataout))) AND (NOT (n0OlOi XOR wire_nlOl_dataout)));
	n0O0ii <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND (NOT rxd(0))) AND wire_w_lg_w_rxd_range652w667w(0)) AND rxd(2)) AND (NOT rxd(3))) AND rxd(4)) AND (NOT rxd(5))) AND (NOT rxd(6))) AND (NOT rxd(7)));
	n0O0il <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND rxd(0)) AND rxd(1)) AND (NOT rxd(2))) AND (NOT rxd(3))) AND rxd(4)) AND rxd(5)) AND (NOT rxd(6))) AND rxd(7)) AND (NOT (n0OlOi XOR wire_nlli_dataout))) AND (NOT (n0OlOi XOR wire_nllO_dataout)));
	n0O0iO <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND rxd(0)) AND rxd(1)) AND rxd(2)) AND rxd(3)) AND (NOT rxd(4))) AND (NOT rxd(5))) AND (NOT rxd(6))) AND rxd(7));
	n0O0li <= (((((((((((((((wire_nlOl_w_lg_dataout710w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND rxd(0)) AND rxd(1)) AND (NOT rxd(2))) AND rxd(3)) AND (NOT rxd(4))) AND rxd(5)) AND rxd(6)) AND (NOT rxd(7))) AND (NOT (n0OlOi XOR wire_nlil_dataout))) AND (NOT (n0OlOi XOR wire_nliO_dataout))) AND (NOT (n0OlOi XOR wire_nlli_dataout))) AND (NOT (n0OlOi XOR wire_nlll_dataout))) AND (NOT (n0OlOi XOR wire_nlOO_dataout)));
	n0O0ll <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND rxd(0)) AND rxd(1)) AND rxd(2)) AND (NOT rxd(3))) AND (NOT rxd(4))) AND (NOT rxd(5))) AND rxd(6)) AND (NOT rxd(7)));
	n0O0lO <= (((((((((((((((wire_nlOO_w_lg_dataout709w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND rxd(0)) AND rxd(1)) AND (NOT rxd(2))) AND (NOT rxd(3))) AND (NOT rxd(4))) AND rxd(5)) AND (NOT rxd(6))) AND (NOT rxd(7))) AND (NOT (n0OlOi XOR wire_nlil_dataout))) AND (NOT (n0OlOi XOR wire_nliO_dataout))) AND (NOT (n0OlOi XOR wire_nlli_dataout))) AND (NOT (n0OlOi XOR wire_nlOl_dataout)));
	n0O0Oi <= ((((((((((((((wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_w_lg_dataout678w(0)) AND wire_nllO_w_lg_dataout713w(0)) AND wire_nlll_w_lg_dataout679w(0)) AND wire_nlli_w_lg_dataout716w(0)) AND wire_nliO_w_lg_dataout718w(0)) AND wire_nlil_w_lg_dataout720w(0)) AND rxd(0)) AND rxd(1)) AND rxd(2)) AND (NOT rxd(3))) AND rxd(4)) AND (NOT rxd(5))) AND rxd(6)) AND rxd(7));
	n0O0Ol <= (((((((((((((((wire_nlOi_w_lg_dataout678w(0) AND wire_nlll_w_lg_dataout679w(0)) AND (NOT rxd(0))) AND rxd(1)) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND (NOT rxd(6))) AND rxd(7)) AND (NOT (n0OlOi XOR wire_nlil_dataout))) AND (NOT (n0OlOi XOR wire_nliO_dataout))) AND (NOT (n0OlOi XOR wire_nlli_dataout))) AND (NOT (n0OlOi XOR wire_nllO_dataout))) AND (NOT (n0OlOi XOR wire_nlOl_dataout))) AND (NOT (n0OlOi XOR wire_nlOO_dataout)));
	n0O0OO <= (n0Oi0l AND n0Oi1i);
	n0O1il <= ((NOT rxc(0)) OR wire_w_lg_n0O1iO151w(0));
	n0O1iO <= ((((((wire_w_lg_w_rxd_range651w668w(0) AND rxd(2)) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7));
	n0O1li <= ((((((wire_w_lg_w_rxd_range651w668w(0) AND (NOT rxd(2))) AND rxd(3)) AND rxd(4)) AND (NOT rxd(5))) AND rxd(6)) AND (NOT rxd(7)));
	n0O1ll <= ((((((wire_w_lg_w_rxd_range651w668w(0) AND rxd(2)) AND (NOT rxd(3))) AND (NOT rxd(4))) AND (NOT rxd(5))) AND (NOT rxd(6))) AND (NOT rxd(7)));
	n0O1lO <= ((((((wire_w_lg_w_rxd_range651w668w(0) AND (NOT rxd(2))) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND (NOT rxd(7)));
	n0O1Oi <= ((wire_w_lg_n0O01i139w(0) OR (NOT (wire_nlii_dataout AND (NOT rxc(0))))) OR (NOT (n0O1Ol26 XOR n0O1Ol25)));
	n0Oi0l <= ((((((wire_w_lg_w_rxd_range651w668w(0) AND rxd(2)) AND (NOT rxd(3))) AND rxd(4)) AND (NOT rxd(5))) AND rxd(6)) AND (NOT rxd(7)));
	n0Oi1i <= (rcxpat_chnl_sel(0) AND rcxpat_chnl_sel(1));
	n0Oi1l <= (wire_w_lg_w_lg_w_lg_n0OiiO114w118w119w(0) AND (n0Oi1O24 XOR n0Oi1O23));
	n0Oiil <= ((NOT rcxpat_chnl_sel(0)) AND rcxpat_chnl_sel(1));
	n0OiiO <= wire_w_lg_w_rcxpat_chnl_sel_range842w847w(0);
	n0Oili <= wire_w_lg_w_rxc_range111w113w(0);
	n0Oill <= ((NOT rcxpat_chnl_sel(0)) AND wire_w_lg_w_rcxpat_chnl_sel_range844w845w(0));
	n0OilO <= (((((((rxd(0) AND rxd(1)) AND (NOT rxd(2))) AND rxd(3)) AND rxd(4)) AND rxd(5)) AND rxd(6)) AND rxd(7));
	n0OiOl <= '1';
	n0Olli <= (((NOT rbist_sel(0)) AND wire_w_lg_w_rbist_sel_range3w4w(0)) AND (n0Ol0i12 XOR n0Ol0i11));
	n0Olll <= wire_w_lg_w_rbist_sel_range1w9w(0);
	n0OllO <= (((NOT rbist_sel(0)) AND rbist_sel(1)) AND (n0Ol1l14 XOR n0Ol1l13));
	n0OlOi <= (n0OlOl OR (rpmadwidth_rx AND rpma_doublewidth_rx));
	n0OlOl <= (wire_w_lg_w_lg_rpmadwidth_rx15w16w(0) AND (n0OlOO6 XOR n0OlOO5));
	selftest_done <= wire_nl1l_dataout;
	selftest_err <= wire_nl1i_dataout;
	wire_w_rbist_sel_range1w(0) <= rbist_sel(0);
	wire_w_rbist_sel_range3w(0) <= rbist_sel(1);
	wire_w_rcxpat_chnl_sel_range842w(0) <= rcxpat_chnl_sel(0);
	wire_w_rcxpat_chnl_sel_range844w(0) <= rcxpat_chnl_sel(1);
	wire_w_rxc_range111w(0) <= rxc(0);
	wire_w_rxd_range651w(0) <= rxd(0);
	wire_w_rxd_range652w(0) <= rxd(1);
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0li1O47 <= n0li1O48;
		END IF;
		if (now = 0 ns) then
			n0li1O47 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0li1O48 <= n0li1O47;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0lOOi45 <= n0lOOi46;
		END IF;
		if (now = 0 ns) then
			n0lOOi45 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0lOOi46 <= n0lOOi45;
		END IF;
	END PROCESS;
	wire_n0lOOi46_w_lg_w_lg_q339w340w(0) <= wire_n0lOOi46_w_lg_q339w(0) AND ni0lO;
	wire_n0lOOi46_w_lg_q339w(0) <= n0lOOi46 XOR n0lOOi45;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0lOOl43 <= n0lOOl44;
		END IF;
		if (now = 0 ns) then
			n0lOOl43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0lOOl44 <= n0lOOl43;
		END IF;
	END PROCESS;
	wire_n0lOOl44_w_lg_w_lg_q314w315w(0) <= wire_n0lOOl44_w_lg_q314w(0) AND wire_n10li_dataout;
	wire_n0lOOl44_w_lg_q314w(0) <= n0lOOl44 XOR n0lOOl43;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0lOOO41 <= n0lOOO42;
		END IF;
		if (now = 0 ns) then
			n0lOOO41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0lOOO42 <= n0lOOO41;
		END IF;
	END PROCESS;
	wire_n0lOOO42_w_lg_w_lg_q309w310w(0) <= wire_n0lOOO42_w_lg_q309w(0) AND wire_n1ill_dataout;
	wire_n0lOOO42_w_lg_q309w(0) <= n0lOOO42 XOR n0lOOO41;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O10i33 <= n0O10i34;
		END IF;
		if (now = 0 ns) then
			n0O10i33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O10i34 <= n0O10i33;
		END IF;
	END PROCESS;
	wire_n0O10i34_w_lg_w_lg_q186w187w(0) <= wire_n0O10i34_w_lg_q186w(0) AND wire_n1iOO_dataout;
	wire_n0O10i34_w_lg_q186w(0) <= n0O10i34 XOR n0O10i33;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O10l31 <= n0O10l32;
		END IF;
		if (now = 0 ns) then
			n0O10l31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O10l32 <= n0O10l31;
		END IF;
	END PROCESS;
	wire_n0O10l32_w_lg_w_lg_q177w178w(0) <= wire_n0O10l32_w_lg_q177w(0) AND wire_w_lg_n0O0il132w(0);
	wire_n0O10l32_w_lg_q177w(0) <= n0O10l32 XOR n0O10l31;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O10O29 <= n0O10O30;
		END IF;
		if (now = 0 ns) then
			n0O10O29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O10O30 <= n0O10O29;
		END IF;
	END PROCESS;
	wire_n0O10O30_w_lg_w_lg_q174w175w(0) <= wire_n0O10O30_w_lg_q174w(0) AND wire_w_lg_n0O0iO131w(0);
	wire_n0O10O30_w_lg_q174w(0) <= n0O10O30 XOR n0O10O29;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O11i39 <= n0O11i40;
		END IF;
		if (now = 0 ns) then
			n0O11i39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O11i40 <= n0O11i39;
		END IF;
	END PROCESS;
	wire_n0O11i40_w_lg_w_lg_q303w304w(0) <= wire_n0O11i40_w_lg_q303w(0) AND wire_n00il_dataout;
	wire_n0O11i40_w_lg_q303w(0) <= n0O11i40 XOR n0O11i39;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O11l37 <= n0O11l38;
		END IF;
		if (now = 0 ns) then
			n0O11l37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O11l38 <= n0O11l37;
		END IF;
	END PROCESS;
	wire_n0O11l38_w_lg_w_lg_q237w238w(0) <= wire_n0O11l38_w_lg_q237w(0) AND n0O0ii;
	wire_n0O11l38_w_lg_q237w(0) <= n0O11l38 XOR n0O11l37;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O11O35 <= n0O11O36;
		END IF;
		if (now = 0 ns) then
			n0O11O35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O11O36 <= n0O11O35;
		END IF;
	END PROCESS;
	wire_n0O11O36_w_lg_w_lg_q191w192w(0) <= wire_n0O11O36_w_lg_q191w(0) AND wire_n1i1i_dataout;
	wire_n0O11O36_w_lg_q191w(0) <= n0O11O36 XOR n0O11O35;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O1ii27 <= n0O1ii28;
		END IF;
		if (now = 0 ns) then
			n0O1ii27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O1ii28 <= n0O1ii27;
		END IF;
	END PROCESS;
	wire_n0O1ii28_w_lg_w_lg_q159w160w(0) <= wire_n0O1ii28_w_lg_q159w(0) AND nii1i;
	wire_n0O1ii28_w_lg_q159w(0) <= n0O1ii28 XOR n0O1ii27;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O1Ol25 <= n0O1Ol26;
		END IF;
		if (now = 0 ns) then
			n0O1Ol25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O1Ol26 <= n0O1Ol25;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Oi0O21 <= n0Oi0O22;
		END IF;
		if (now = 0 ns) then
			n0Oi0O21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Oi0O22 <= n0Oi0O21;
		END IF;
	END PROCESS;
	wire_n0Oi0O22_w_lg_w_lg_q116w117w(0) <= NOT wire_n0Oi0O22_w_lg_q116w(0);
	wire_n0Oi0O22_w_lg_q116w(0) <= n0Oi0O22 XOR n0Oi0O21;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Oi1O23 <= n0Oi1O24;
		END IF;
		if (now = 0 ns) then
			n0Oi1O23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Oi1O24 <= n0Oi1O23;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OiOi19 <= n0OiOi20;
		END IF;
		if (now = 0 ns) then
			n0OiOi19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OiOi20 <= n0OiOi19;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OiOO17 <= n0OiOO18;
		END IF;
		if (now = 0 ns) then
			n0OiOO17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OiOO18 <= n0OiOO17;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Ol0i11 <= n0Ol0i12;
		END IF;
		if (now = 0 ns) then
			n0Ol0i11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Ol0i12 <= n0Ol0i11;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Ol0O10 <= n0Ol0O9;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Ol0O9 <= n0Ol0O10;
		END IF;
		if (now = 0 ns) then
			n0Ol0O9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Ol1i15 <= n0Ol1i16;
		END IF;
		if (now = 0 ns) then
			n0Ol1i15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Ol1i16 <= n0Ol1i15;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Ol1l13 <= n0Ol1l14;
		END IF;
		if (now = 0 ns) then
			n0Ol1l13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Ol1l14 <= n0Ol1l13;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Olil7 <= n0Olil8;
		END IF;
		if (now = 0 ns) then
			n0Olil7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Olil8 <= n0Olil7;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OlOO5 <= n0OlOO6;
		END IF;
		if (now = 0 ns) then
			n0OlOO5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OlOO6 <= n0OlOO5;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OO0i1 <= n0OO0i2;
		END IF;
		if (now = 0 ns) then
			n0OO0i1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OO0i2 <= n0OO0i1;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OO1l3 <= n0OO1l4;
		END IF;
		if (now = 0 ns) then
			n0OO1l3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OO1l4 <= n0OO1l3;
		END IF;
	END PROCESS;
	PROCESS (clk_2, wire_ni01O_CLRN)
	BEGIN
		IF (wire_ni01O_CLRN = '0') THEN
				ni00i <= '0';
				ni01l <= '0';
				ni1lOl <= '0';
				niiilO <= '0';
				niiiOi <= '0';
				niiiOl <= '0';
				niiiOO <= '0';
				niil0i <= '0';
				niil0l <= '0';
				niil0O <= '0';
				niil1i <= '0';
				niil1l <= '0';
				niil1O <= '0';
				niilii <= '0';
				niilil <= '0';
				niiliO <= '0';
				niilli <= '0';
				niilll <= '0';
				niillO <= '0';
				niilOi <= '0';
				niilOl <= '0';
				niiO1i <= '0';
				niiO1l <= '0';
				nll00O <= '0';
				nll0ii <= '0';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
				ni00i <= wire_nii1O_dataout;
				ni01l <= wire_nii1l_dataout;
				ni1lOl <= wire_nil0ii_dataout;
				niiilO <= wire_nil0il_dataout;
				niiiOi <= wire_nil0iO_dataout;
				niiiOl <= wire_nil0li_dataout;
				niiiOO <= wire_nil0ll_dataout;
				niil0i <= wire_nil0OO_dataout;
				niil0l <= wire_nili1i_dataout;
				niil0O <= wire_nili1l_dataout;
				niil1i <= wire_nil0lO_dataout;
				niil1l <= wire_nil0Oi_dataout;
				niil1O <= wire_nil0Ol_dataout;
				niilii <= wire_nili1O_dataout;
				niilil <= wire_nili0i_dataout;
				niiliO <= wire_nili0l_dataout;
				niilli <= wire_nili0O_dataout;
				niilll <= wire_niliii_dataout;
				niillO <= wire_niliil_dataout;
				niilOi <= wire_niliiO_dataout;
				niilOl <= wire_nilili_dataout;
				niiO1i <= wire_nilill_dataout;
				niiO1l <= wire_nililO_dataout;
				nll00O <= wire_nlll0l_dataout;
				nll0ii <= wire_nlll0O_dataout;
		END IF;
	END PROCESS;
	wire_ni01O_CLRN <= ((n0OiOi20 XOR n0OiOi19) AND wire_w_lg_soft_reset105w(0));
	PROCESS (clk_2, wire_ni0OO_PRN, wire_ni0OO_CLRN)
	BEGIN
		IF (wire_ni0OO_PRN = '0') THEN
				n11Oi <= '1';
				ni00l <= '1';
				ni00O <= '1';
				ni01i <= '1';
				ni0ii <= '1';
				ni0il <= '1';
				ni0iO <= '1';
				ni0li <= '1';
				ni0ll <= '1';
				ni0lO <= '1';
				ni0Oi <= '1';
				ni0Ol <= '1';
				nii1i <= '1';
				niilOO <= '1';
				niiO0l <= '1';
				niiO0O <= '1';
				niiOii <= '1';
				niiOil <= '1';
				niiOiO <= '1';
				niiOli <= '1';
				niiOll <= '1';
				niiOlO <= '1';
				niiOOi <= '1';
				niiOOl <= '1';
				niiOOO <= '1';
				nil00i <= '1';
				nil00l <= '1';
				nil00O <= '1';
				nil01i <= '1';
				nil01l <= '1';
				nil01O <= '1';
				nil10i <= '1';
				nil10l <= '1';
				nil10O <= '1';
				nil11i <= '1';
				nil11l <= '1';
				nil11O <= '1';
				nil1ii <= '1';
				nil1il <= '1';
				nil1iO <= '1';
				nil1li <= '1';
				nil1ll <= '1';
				nil1lO <= '1';
				nil1Oi <= '1';
				nil1Ol <= '1';
				nil1OO <= '1';
				nl1Oll <= '1';
				nll00l <= '1';
				nll0il <= '1';
				nll0iO <= '1';
				nll0li <= '1';
				nll0ll <= '1';
				nll0lO <= '1';
				nll0Oi <= '1';
				nll0Ol <= '1';
				nll0OO <= '1';
				nlli0i <= '1';
				nlli0l <= '1';
				nlli0O <= '1';
				nlli1i <= '1';
				nlli1l <= '1';
				nlli1O <= '1';
				nlliii <= '1';
				nlliil <= '1';
				nlliiO <= '1';
				nllili <= '1';
				nllill <= '1';
				nllilO <= '1';
				nlliOi <= '1';
				nlliOl <= '1';
				nlliOO <= '1';
				nlll0i <= '1';
				nlll1i <= '1';
				nlll1l <= '1';
				nlll1O <= '1';
		ELSIF (wire_ni0OO_CLRN = '0') THEN
				n11Oi <= '0';
				ni00l <= '0';
				ni00O <= '0';
				ni01i <= '0';
				ni0ii <= '0';
				ni0il <= '0';
				ni0iO <= '0';
				ni0li <= '0';
				ni0ll <= '0';
				ni0lO <= '0';
				ni0Oi <= '0';
				ni0Ol <= '0';
				nii1i <= '0';
				niilOO <= '0';
				niiO0l <= '0';
				niiO0O <= '0';
				niiOii <= '0';
				niiOil <= '0';
				niiOiO <= '0';
				niiOli <= '0';
				niiOll <= '0';
				niiOlO <= '0';
				niiOOi <= '0';
				niiOOl <= '0';
				niiOOO <= '0';
				nil00i <= '0';
				nil00l <= '0';
				nil00O <= '0';
				nil01i <= '0';
				nil01l <= '0';
				nil01O <= '0';
				nil10i <= '0';
				nil10l <= '0';
				nil10O <= '0';
				nil11i <= '0';
				nil11l <= '0';
				nil11O <= '0';
				nil1ii <= '0';
				nil1il <= '0';
				nil1iO <= '0';
				nil1li <= '0';
				nil1ll <= '0';
				nil1lO <= '0';
				nil1Oi <= '0';
				nil1Ol <= '0';
				nil1OO <= '0';
				nl1Oll <= '0';
				nll00l <= '0';
				nll0il <= '0';
				nll0iO <= '0';
				nll0li <= '0';
				nll0ll <= '0';
				nll0lO <= '0';
				nll0Oi <= '0';
				nll0Ol <= '0';
				nll0OO <= '0';
				nlli0i <= '0';
				nlli0l <= '0';
				nlli0O <= '0';
				nlli1i <= '0';
				nlli1l <= '0';
				nlli1O <= '0';
				nlliii <= '0';
				nlliil <= '0';
				nlliiO <= '0';
				nllili <= '0';
				nllill <= '0';
				nllilO <= '0';
				nlliOi <= '0';
				nlliOl <= '0';
				nlliOO <= '0';
				nlll0i <= '0';
				nlll1i <= '0';
				nlll1l <= '0';
				nlll1O <= '0';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
			IF (rbist_clr_rx = '0') THEN
				n11Oi <= ni01i;
				ni00l <= wire_n11ll_o;
				ni00O <= wire_nii0i_dataout;
				ni01i <= sync_status;
				ni0ii <= wire_nii0l_dataout;
				ni0il <= wire_nii0O_dataout;
				ni0iO <= wire_niiii_dataout;
				ni0li <= wire_niiil_dataout;
				ni0ll <= wire_n101i_o;
				ni0lO <= wire_n101l_o;
				ni0Oi <= wire_n101O_o;
				ni0Ol <= wire_n100i_o;
				nii1i <= wire_n100l_o;
				niilOO <= wire_ni1iiO_o;
				niiO0l <= wire_niO1Oi_dataout;
				niiO0O <= wire_niO1Ol_dataout;
				niiOii <= wire_niO1OO_dataout;
				niiOil <= wire_niO01i_dataout;
				niiOiO <= wire_niO01l_dataout;
				niiOli <= wire_niO01O_dataout;
				niiOll <= wire_niO00i_dataout;
				niiOlO <= wire_niO10i_dataout;
				niiOOi <= wire_niO10l_dataout;
				niiOOl <= wire_niO10O_dataout;
				niiOOO <= wire_niO1ii_dataout;
				nil00i <= wire_ni1iOi_o;
				nil00l <= wire_ni1iOl_o;
				nil00O <= wire_ni1iOO_o;
				nil01i <= nil00l;
				nil01l <= nil00O;
				nil01O <= wire_ni1ilO_o;
				nil10i <= wire_niO1ll_dataout;
				nil10l <= wire_niO00l_dataout;
				nil10O <= wire_niO00O_dataout;
				nil11i <= wire_niO1il_dataout;
				nil11l <= wire_niO1iO_dataout;
				nil11O <= wire_niO1li_dataout;
				nil1ii <= wire_niO0ii_dataout;
				nil1il <= wire_niO0il_dataout;
				nil1iO <= wire_niO0iO_dataout;
				nil1li <= wire_niO0li_dataout;
				nil1ll <= wire_niO0ll_dataout;
				nil1lO <= wire_niO0lO_dataout;
				nil1Oi <= wire_niO0Oi_dataout;
				nil1Ol <= nil01O;
				nil1OO <= nil00i;
				nl1Oll <= nll00l;
				nll00l <= sync_status;
				nll0il <= wire_nl011i_o;
				nll0iO <= wire_nlllii_dataout;
				nll0li <= wire_nlllil_dataout;
				nll0ll <= wire_nllliO_dataout;
				nll0lO <= wire_nlllli_dataout;
				nll0Oi <= wire_nlllll_dataout;
				nll0Ol <= wire_nllllO_dataout;
				nll0OO <= wire_nllO0l_dataout;
				nlli0i <= wire_nllOli_dataout;
				nlli0l <= wire_nllOll_dataout;
				nlli0O <= wire_nllOlO_dataout;
				nlli1i <= wire_nllO0O_dataout;
				nlli1l <= wire_nllOii_dataout;
				nlli1O <= wire_nllOiO_dataout;
				nlliii <= wire_nlO11O_dataout;
				nlliil <= wire_nlO10i_dataout;
				nlliiO <= wire_nlO10l_dataout;
				nllili <= wire_nlO10O_dataout;
				nllill <= wire_nlO1ii_dataout;
				nllilO <= wire_nlO1il_dataout;
				nlliOi <= wire_nlO1iO_dataout;
				nlliOl <= wire_nlO1li_dataout;
				nlliOO <= wire_nlO1ll_dataout;
				nlll0i <= wire_nl01ii_o;
				nlll1i <= wire_nl010i_o;
				nlll1l <= wire_nl010l_o;
				nlll1O <= wire_nl010O_o;
			END IF;
		END IF;
	END PROCESS;
	wire_ni0OO_CLRN <= ((n0Ol1i16 XOR n0Ol1i15) AND wire_w_lg_soft_reset105w(0));
	wire_ni0OO_PRN <= (n0OiOO18 XOR n0OiOO17);
	wire_ni0OO_w_lg_w_lg_w_lg_w1242w1243w1244w1245w(0) <= wire_ni0OO_w_lg_w_lg_w1242w1243w1244w(0) AND nlliil;
	wire_ni0OO_w_lg_w_lg_w1251w1252w1253w(0) <= wire_ni0OO_w_lg_w1251w1252w(0) AND nlliil;
	wire_ni0OO_w_lg_w_lg_w1242w1243w1244w(0) <= wire_ni0OO_w_lg_w1242w1243w(0) AND wire_ni0OO_w_lg_nlliiO1232w(0);
	wire_ni0OO_w_lg_w1251w1252w(0) <= wire_ni0OO_w1251w(0) AND nlliiO;
	wire_ni0OO_w_lg_w1242w1243w(0) <= wire_ni0OO_w1242w(0) AND wire_ni0OO_w_lg_nllili1230w(0);
	wire_ni0OO_w1251w(0) <= wire_ni0OO_w_lg_w_lg_w_lg_w_lg_nlliOO1247w1248w1249w1250w(0) AND wire_ni0OO_w_lg_nllili1230w(0);
	wire_ni0OO_w1242w(0) <= wire_ni0OO_w_lg_w_lg_w_lg_w_lg_nlliOO1222w1238w1240w1241w(0) AND wire_ni0OO_w_lg_nllill1228w(0);
	wire_ni0OO_w_lg_w_lg_w_lg_w_lg_nlliOO1247w1248w1249w1250w(0) <= wire_ni0OO_w_lg_w_lg_w_lg_nlliOO1247w1248w1249w(0) AND wire_ni0OO_w_lg_nllill1228w(0);
	wire_ni0OO_w_lg_w_lg_w_lg_w_lg_nlli0O990w992w993w994w(0) <= wire_ni0OO_w_lg_w_lg_w_lg_nlli0O990w992w993w(0) AND nlli1O;
	wire_ni0OO_w_lg_w_lg_w_lg_w_lg_nlliOO1222w1238w1240w1241w(0) <= wire_ni0OO_w_lg_w_lg_w_lg_nlliOO1222w1238w1240w(0) AND wire_ni0OO_w_lg_nllilO1226w(0);
	wire_ni0OO_w_lg_w_lg_w_lg_ni0li837w838w839w(0) <= wire_ni0OO_w_lg_w_lg_ni0li837w838w(0) AND ni0ii;
	wire_ni0OO_w_lg_w_lg_w_lg_nil1Oi2312w2314w2315w(0) <= wire_ni0OO_w_lg_w_lg_nil1Oi2312w2314w(0) AND nil1li;
	wire_ni0OO_w_lg_w_lg_w_lg_nlli0O995w996w997w(0) <= wire_ni0OO_w_lg_w_lg_nlli0O995w996w(0) AND nlli1O;
	wire_ni0OO_w_lg_w_lg_w_lg_nlliOO1247w1248w1249w(0) <= wire_ni0OO_w_lg_w_lg_nlliOO1247w1248w(0) AND wire_ni0OO_w_lg_nllilO1226w(0);
	wire_ni0OO_w_lg_w_lg_w_lg_nlli0O990w992w993w(0) <= wire_ni0OO_w_lg_w_lg_nlli0O990w992w(0) AND nlli0i;
	wire_ni0OO_w_lg_w_lg_w_lg_nlliOO1222w1224w1225w(0) <= wire_ni0OO_w_lg_w_lg_nlliOO1222w1224w(0) AND nlliOi;
	wire_ni0OO_w_lg_w_lg_w_lg_nlliOO1222w1238w1240w(0) <= wire_ni0OO_w_lg_w_lg_nlliOO1222w1238w(0) AND wire_ni0OO_w_lg_nlliOi1239w(0);
	wire_ni0OO_w_lg_w_lg_ni0li837w838w(0) <= wire_ni0OO_w_lg_ni0li837w(0) AND ni0il;
	wire_ni0OO_w_lg_w_lg_nil1Oi2312w2314w(0) <= wire_ni0OO_w_lg_nil1Oi2312w(0) AND wire_ni0OO_w_lg_nil1ll2313w(0);
	wire_ni0OO_w_lg_w_lg_nlli0O995w996w(0) <= wire_ni0OO_w_lg_nlli0O995w(0) AND nlli0i;
	wire_ni0OO_w_lg_w_lg_nlliOO1247w1248w(0) <= wire_ni0OO_w_lg_nlliOO1247w(0) AND wire_ni0OO_w_lg_nlliOi1239w(0);
	wire_ni0OO_w_lg_w_lg_nll0Ol1343w1344w(0) <= wire_ni0OO_w_lg_nll0Ol1343w(0) AND nll0Oi;
	wire_ni0OO_w_lg_w_lg_nlli0O990w992w(0) <= wire_ni0OO_w_lg_nlli0O990w(0) AND wire_ni0OO_w_lg_nlli0l991w(0);
	wire_ni0OO_w_lg_w_lg_nlliOO1222w1224w(0) <= wire_ni0OO_w_lg_nlliOO1222w(0) AND wire_ni0OO_w_lg_nlliOl1223w(0);
	wire_ni0OO_w_lg_w_lg_nlliOO1222w1238w(0) <= wire_ni0OO_w_lg_nlliOO1222w(0) AND nlliOl;
	wire_ni0OO_w_lg_ni0li837w(0) <= ni0li AND ni0iO;
	wire_ni0OO_w_lg_nil1Oi2312w(0) <= nil1Oi AND wire_ni0OO_w_lg_nil1lO2311w(0);
	wire_ni0OO_w_lg_nll0Ol1352w(0) <= nll0Ol AND wire_ni0OO_w_lg_nll0Oi1351w(0);
	wire_ni0OO_w_lg_nlli0O995w(0) <= nlli0O AND wire_ni0OO_w_lg_nlli0l991w(0);
	wire_ni0OO_w_lg_nlliOO1247w(0) <= nlliOO AND wire_ni0OO_w_lg_nlliOl1223w(0);
	wire_ni0OO_w_lg_ni00O840w(0) <= NOT ni00O;
	wire_ni0OO_w_lg_nil10l2331w(0) <= NOT nil10l;
	wire_ni0OO_w_lg_nil10O2322w(0) <= NOT nil10O;
	wire_ni0OO_w_lg_nil1ii2320w(0) <= NOT nil1ii;
	wire_ni0OO_w_lg_nil1il2318w(0) <= NOT nil1il;
	wire_ni0OO_w_lg_nil1iO2316w(0) <= NOT nil1iO;
	wire_ni0OO_w_lg_nil1li2325w(0) <= NOT nil1li;
	wire_ni0OO_w_lg_nil1ll2313w(0) <= NOT nil1ll;
	wire_ni0OO_w_lg_nil1lO2311w(0) <= NOT nil1lO;
	wire_ni0OO_w_lg_nll0ll1347w(0) <= NOT nll0ll;
	wire_ni0OO_w_lg_nll0lO1345w(0) <= NOT nll0lO;
	wire_ni0OO_w_lg_nll0Oi1351w(0) <= NOT nll0Oi;
	wire_ni0OO_w_lg_nll0Ol1343w(0) <= NOT nll0Ol;
	wire_ni0OO_w_lg_nlli0l991w(0) <= NOT nlli0l;
	wire_ni0OO_w_lg_nlli0O990w(0) <= NOT nlli0O;
	wire_ni0OO_w_lg_nlli1l1296w(0) <= NOT nlli1l;
	wire_ni0OO_w_lg_nlli1O1273w(0) <= NOT nlli1O;
	wire_ni0OO_w_lg_nlliii1236w(0) <= NOT nlliii;
	wire_ni0OO_w_lg_nlliil1234w(0) <= NOT nlliil;
	wire_ni0OO_w_lg_nlliiO1232w(0) <= NOT nlliiO;
	wire_ni0OO_w_lg_nllili1230w(0) <= NOT nllili;
	wire_ni0OO_w_lg_nllill1228w(0) <= NOT nllill;
	wire_ni0OO_w_lg_nllilO1226w(0) <= NOT nllilO;
	wire_ni0OO_w_lg_nlliOi1239w(0) <= NOT nlliOi;
	wire_ni0OO_w_lg_nlliOl1223w(0) <= NOT nlliOl;
	wire_ni0OO_w_lg_nlliOO1222w(0) <= NOT nlliOO;
	PROCESS (clk_2, soft_reset, wire_niiO1O_CLRN)
	BEGIN
		IF (soft_reset = '1') THEN
				niiO0i <= '1';
		ELSIF (wire_niiO1O_CLRN = '0') THEN
				niiO0i <= '0';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
			IF (rbist_clr_rx = '0') THEN
				niiO0i <= wire_niO1lO_dataout;
			END IF;
		END IF;
		if (now = 0 ns) then
			niiO0i <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_niiO1O_CLRN <= (n0li1O48 XOR n0li1O47);
	wire_n000i_dataout <= ni01l OR wire_w_lg_n0O01O137w(0);
	wire_n000l_dataout <= ni00i OR wire_w_lg_n0O01O137w(0);
	wire_n000O_dataout <= wire_n00lO_dataout OR wire_w_lg_n0O01O137w(0);
	wire_n001i_dataout <= nii1i OR n0Oi1i;
	wire_n001l_dataout <= wire_n00ll_dataout AND NOT(wire_w_lg_n0O01O137w(0));
	wire_n001O_dataout <= wire_n0i1l_dataout AND NOT(wire_w_lg_n0O01O137w(0));
	wire_n00i_dataout <= nlll0i WHEN n0Olll = '1'  ELSE wire_n0iO_dataout;
	wire_n00ii_dataout <= wire_n00Oi_dataout AND NOT(wire_w_lg_n0O01O137w(0));
	wire_n00il_dataout <= wire_n00Ol_dataout OR wire_w_lg_n0O01O137w(0);
	wire_n00iO_dataout <= wire_n00OO_dataout AND NOT(wire_w_lg_n0O01O137w(0));
	wire_n00l_dataout <= wire_n0li_dataout AND NOT(n0Olll);
	wire_n00li_dataout <= wire_n0i1i_dataout OR wire_w_lg_n0O01O137w(0);
	wire_n00ll_dataout <= wire_w_lg_n0O00i136w(0) AND n0OlOi;
	wire_n00lO_dataout <= wire_n1Oii_dataout OR NOT(n0OlOi);
	wire_n00O_dataout <= ni0ll AND n0OllO;
	wire_n00Oi_dataout <= wire_n1Oil_dataout OR NOT(n0OlOi);
	wire_n00Ol_dataout <= wire_n1OiO_dataout OR NOT(n0OlOi);
	wire_n00OO_dataout <= wire_n1Oli_dataout OR NOT(n0OlOi);
	wire_n010i_dataout <= wire_n01iO_dataout AND NOT(n0OiiO);
	wire_n010l_dataout <= wire_n01li_dataout AND NOT(n0OiiO);
	wire_n010O_dataout <= wire_n01ll_dataout OR n0OiiO;
	wire_n011i_dataout <= wire_n010O_dataout OR n0Oill;
	wire_n011l_dataout <= wire_n01ii_dataout OR n0OiiO;
	wire_n011O_dataout <= wire_n01il_dataout AND NOT(n0OiiO);
	wire_n01i_dataout <= nlll1i WHEN n0Olll = '1'  ELSE wire_n00O_dataout;
	wire_n01ii_dataout <= wire_n01lO_dataout AND NOT(n0Oiil);
	wire_n01il_dataout <= wire_n01Oi_dataout OR n0Oiil;
	wire_n01iO_dataout <= wire_n01Ol_dataout AND NOT(n0Oiil);
	wire_n01l_dataout <= nlll1l WHEN n0Olll = '1'  ELSE wire_n0ii_dataout;
	wire_n01li_dataout <= wire_n01OO_dataout AND NOT(n0Oiil);
	wire_n01ll_dataout <= wire_n001i_dataout OR n0Oiil;
	wire_n01lO_dataout <= ni0ll OR n0Oi1i;
	wire_n01O_dataout <= nlll1O WHEN n0Olll = '1'  ELSE wire_n0il_dataout;
	wire_n01Oi_dataout <= ni0lO OR n0Oi1i;
	wire_n01Ol_dataout <= ni0Oi AND NOT(n0Oi1i);
	wire_n01OO_dataout <= ni0Ol AND NOT(n0Oi1i);
	wire_n0i_dataout <= rxd(33) WHEN n0OlOl = '1'  ELSE rxd(17);
	wire_n0i0i_dataout <= ni00i OR wire_w_lg_n0O00l135w(0);
	wire_n0i0l_dataout <= ni01l OR wire_w_lg_n0O00O134w(0);
	wire_n0i0O_dataout <= ni00i OR wire_w_lg_n0O00O134w(0);
	wire_n0i1i_dataout <= wire_n1Oll_dataout AND n0OlOi;
	wire_n0i1l_dataout <= n0O00i AND n0OlOi;
	wire_n0i1O_dataout <= ni01l OR wire_w_lg_n0O00l135w(0);
	wire_n0ii_dataout <= ni0lO AND n0OllO;
	wire_n0iii_dataout <= wire_w_lg_n0OlOi124w(0) OR wire_w_lg_n0O00O134w(0);
	wire_n0iil_dataout <= n0OlOi AND NOT(wire_w_lg_n0O00O134w(0));
	wire_n0iiO_dataout <= ni01l OR wire_w_lg_n0O0ii133w(0);
	wire_n0il_dataout <= ni0Oi AND n0OllO;
	wire_n0ili_dataout <= ni00i OR wire_w_lg_n0O0ii133w(0);
	wire_n0ill_dataout <= ni01l OR wire_w_lg_n0O0il132w(0);
	wire_n0ilO_dataout <= ni00i OR wire_w_lg_n0O0il132w(0);
	wire_n0iO_dataout <= ni0Ol AND n0OllO;
	wire_n0iOi_dataout <= wire_w_lg_n0OlOi124w(0) OR wire_w_lg_n0O0il132w(0);
	wire_n0iOl_dataout <= wire_w_lg_n0OlOi124w(0) AND NOT(wire_w_lg_n0O0il132w(0));
	wire_n0iOO_dataout <= n0OlOi OR wire_w_lg_n0O0il132w(0);
	wire_n0l_dataout <= rxd(34) WHEN n0OlOl = '1'  ELSE rxd(18);
	wire_n0l0i_dataout <= ni00i OR wire_w_lg_n0O0li130w(0);
	wire_n0l0l_dataout <= wire_w_lg_n0OlOi124w(0) OR wire_w_lg_n0O0li130w(0);
	wire_n0l0O_dataout <= n0OlOi AND NOT(wire_w_lg_n0O0li130w(0));
	wire_n0l1i_dataout <= ni01l OR wire_w_lg_n0O0iO131w(0);
	wire_n0l1l_dataout <= ni00i OR wire_w_lg_n0O0iO131w(0);
	wire_n0l1O_dataout <= ni01l OR wire_w_lg_n0O0li130w(0);
	wire_n0li_dataout <= nii1i AND n0OllO;
	wire_n0lii_dataout <= ni01l OR wire_w_lg_n0O0ll129w(0);
	wire_n0lil_dataout <= ni00i OR wire_w_lg_n0O0ll129w(0);
	wire_n0liO_dataout <= ni01l OR wire_w_lg_n0O0lO128w(0);
	wire_n0lli_dataout <= ni00i OR wire_w_lg_n0O0lO128w(0);
	wire_n0lll_dataout <= wire_w_lg_n0OlOi124w(0) AND NOT(wire_w_lg_n0O0lO128w(0));
	wire_n0llO_dataout <= wire_w_lg_n0OlOi124w(0) OR wire_w_lg_n0O0lO128w(0);
	wire_n0lOi_dataout <= n0OlOi AND NOT(wire_w_lg_n0O0lO128w(0));
	wire_n0lOl_dataout <= ni01l OR wire_w_lg_n0O0Oi127w(0);
	wire_n0lOO_dataout <= ni00i OR wire_w_lg_n0O0Oi127w(0);
	wire_n0O_dataout <= rxd(35) WHEN n0OlOl = '1'  ELSE rxd(19);
	wire_n0O0i_dataout <= n0OlOi AND NOT(wire_w_lg_n0O0Ol126w(0));
	wire_n0O0l_dataout <= ni0ll AND NOT(wire_w_lg_n0Oi1i125w(0));
	wire_n0O0O_dataout <= ni0lO AND NOT(wire_w_lg_n0Oi1i125w(0));
	wire_n0O1i_dataout <= ni01l OR wire_w_lg_n0O0Ol126w(0);
	wire_n0O1l_dataout <= ni00i OR wire_w_lg_n0O0Ol126w(0);
	wire_n0O1O_dataout <= wire_w_lg_n0OlOi124w(0) OR wire_w_lg_n0O0Ol126w(0);
	wire_n0Oi_dataout <= ni1lOl AND n0Olli;
	wire_n0Oii_dataout <= ni0Oi OR wire_w_lg_n0Oi1i125w(0);
	wire_n0Oil_dataout <= ni0Ol AND NOT(wire_w_lg_n0Oi1i125w(0));
	wire_n0OiO_dataout <= nii1i AND NOT(wire_w_lg_n0Oi1i125w(0));
	wire_n0Ol_dataout <= niiilO AND n0Olli;
	wire_n0Oli_dataout <= wire_n0OOO_dataout AND NOT(n0Oili);
	wire_n0Oll_dataout <= wire_w_lg_n0OlOi124w(0) WHEN n0Oili = '1'  ELSE wire_ni11i_dataout;
	wire_n0OlO_dataout <= n0OlOi WHEN n0Oili = '1'  ELSE wire_ni11l_dataout;
	wire_n0OO_dataout <= niiiOi AND n0Olli;
	wire_n0OOi_dataout <= wire_ni11O_dataout AND NOT(n0Oili);
	wire_n0OOl_dataout <= wire_ni10i_dataout AND NOT(n0Oili);
	wire_n0OOO_dataout <= wire_ni10l_dataout AND NOT(n0Oi1l);
	wire_n100O_dataout <= ni00i AND NOT(wire_ni_w_lg_dataout153w(0));
	wire_n10ii_dataout <= ni01l AND NOT(wire_ni_w_lg_dataout153w(0));
	wire_n10il_dataout <= ni0ll AND NOT(wire_ni_w_lg_dataout153w(0));
	wire_n10iO_dataout <= ni0lO AND NOT(wire_ni_w_lg_dataout153w(0));
	wire_n10li_dataout <= ni0Oi AND NOT(wire_ni_w_lg_dataout153w(0));
	wire_n10ll_dataout <= ni0Ol AND NOT(wire_ni_w_lg_dataout153w(0));
	wire_n10lO_dataout <= nii1i AND NOT(wire_ni_w_lg_dataout153w(0));
	wire_n10Oi_dataout <= ni00l OR NOT(n0O1il);
	wire_n10Ol_dataout <= wire_n1i1l_dataout OR n0O1il;
	wire_n10OO_dataout <= ni00i OR n0O1il;
	wire_n1i0i_dataout <= ni00l OR NOT(wire_w_lg_n0O1li150w(0));
	wire_n1i0l_dataout <= wire_n1i1l_dataout OR wire_w_lg_n0O1li150w(0);
	wire_n1i0O_dataout <= ni00i OR wire_w_lg_n0O1li150w(0);
	wire_n1i1i_dataout <= ni00l OR n0O1il;
	wire_n1i1l_dataout <= ni01l OR ni00l;
	wire_n1iii_dataout <= ni00l OR wire_w_lg_n0O1li150w(0);
	wire_n1iil_dataout <= ni00l OR NOT(wire_w_lg_n0O1ll149w(0));
	wire_n1iiO_dataout <= wire_n1i1l_dataout OR wire_w_lg_n0O1ll149w(0);
	wire_n1ili_dataout <= ni00i OR wire_w_lg_n0O1ll149w(0);
	wire_n1ill_dataout <= ni00l OR wire_w_lg_n0O1ll149w(0);
	wire_n1ilO_dataout <= ni00l OR NOT(wire_w_lg_n0O1lO148w(0));
	wire_n1iOi_dataout <= wire_n1i1l_dataout OR wire_w_lg_n0O1lO148w(0);
	wire_n1iOl_dataout <= ni00i OR wire_w_lg_n0O1lO148w(0);
	wire_n1iOO_dataout <= ni00l OR wire_w_lg_n0O1lO148w(0);
	wire_n1l_dataout <= rxc(2) WHEN n0OlOl = '1'  ELSE rxc(1);
	wire_n1l0i_dataout <= wire_w_lg_n0O01i139w(0) OR n0OlOi;
	wire_n1l0l_dataout <= wire_n1lll_dataout OR NOT(n0OlOi);
	wire_n1l0O_dataout <= ni01l OR wire_w_lg_n0O01i139w(0);
	wire_n1l1i_dataout <= wire_n1lil_dataout WHEN n0OlOi = '1'  ELSE ni00l;
	wire_n1l1l_dataout <= wire_n1liO_dataout WHEN n0OlOi = '1'  ELSE wire_n1l0O_dataout;
	wire_n1l1O_dataout <= wire_n1lli_dataout WHEN n0OlOi = '1'  ELSE wire_n1lii_dataout;
	wire_n1lii_dataout <= ni00i OR wire_w_lg_n0O01i139w(0);
	wire_n1lil_dataout <= ni00l OR NOT(n0O1Oi);
	wire_n1liO_dataout <= wire_n1i1l_dataout OR n0O1Oi;
	wire_n1ll_dataout <= nil01O WHEN n0Olli = '1'  ELSE wire_n01i_dataout;
	wire_n1lli_dataout <= ni00i OR n0O1Oi;
	wire_n1lll_dataout <= ni00l OR n0O1Oi;
	wire_n1lO_dataout <= nil00i WHEN n0Olli = '1'  ELSE wire_n01l_dataout;
	wire_n1lOi_dataout <= wire_w_lg_n0O00i136w(0) AND NOT(wire_w_lg_n0O01l138w(0));
	wire_n1lOl_dataout <= n0O00i AND NOT(wire_w_lg_n0O01l138w(0));
	wire_n1lOO_dataout <= ni01l OR wire_w_lg_n0O01l138w(0);
	wire_n1O_dataout <= rxd(32) WHEN n0OlOl = '1'  ELSE rxd(16);
	wire_n1O0i_dataout <= wire_n1OiO_dataout OR wire_w_lg_n0O01l138w(0);
	wire_n1O0l_dataout <= wire_n1Oli_dataout AND NOT(wire_w_lg_n0O01l138w(0));
	wire_n1O0O_dataout <= wire_n1Oll_dataout OR wire_w_lg_n0O01l138w(0);
	wire_n1O1i_dataout <= ni00i OR wire_w_lg_n0O01l138w(0);
	wire_n1O1l_dataout <= wire_n1Oii_dataout OR wire_w_lg_n0O01l138w(0);
	wire_n1O1O_dataout <= wire_n1Oil_dataout AND NOT(wire_w_lg_n0O01l138w(0));
	wire_n1Oi_dataout <= nil00l WHEN n0Olli = '1'  ELSE wire_n01O_dataout;
	wire_n1Oii_dataout <= wire_n1OlO_dataout AND n0O00i;
	wire_n1Oil_dataout <= wire_n1OOi_dataout AND n0O00i;
	wire_n1OiO_dataout <= wire_n1OOl_dataout OR NOT(n0O00i);
	wire_n1Ol_dataout <= nil00O WHEN n0Olli = '1'  ELSE wire_n00i_dataout;
	wire_n1Oli_dataout <= wire_n1OOO_dataout AND n0O00i;
	wire_n1Oll_dataout <= wire_n011i_dataout AND n0O00i;
	wire_n1OlO_dataout <= wire_n011l_dataout AND NOT(n0Oill);
	wire_n1OO_dataout <= wire_n00l_dataout AND NOT(n0Olli);
	wire_n1OOi_dataout <= wire_n011O_dataout AND NOT(n0Oill);
	wire_n1OOl_dataout <= wire_n010i_dataout AND NOT(n0Oill);
	wire_n1OOO_dataout <= wire_n010l_dataout AND NOT(n0Oill);
	wire_ni_dataout <= rbisten_rx AND (((NOT rbist_sel(0)) AND rbist_sel(1)) AND (n0OO1l4 XOR n0OO1l3));
	wire_ni_w_lg_dataout403w(0) <= wire_ni_dataout AND n11Oi;
	wire_ni_w_lg_dataout153w(0) <= NOT wire_ni_dataout;
	wire_ni000i_dataout <= n0l11O WHEN n0OlOi = '1'  ELSE n0l11i;
	wire_ni000l_dataout <= niiO1i OR n0l11i;
	wire_ni000O_dataout <= niiO1l OR n0l11i;
	wire_ni001i_dataout <= wire_ni00il_dataout WHEN n0OlOi = '1'  ELSE wire_ni000l_dataout;
	wire_ni001l_dataout <= wire_ni00iO_dataout WHEN n0OlOi = '1'  ELSE wire_ni000O_dataout;
	wire_ni001O_dataout <= n0l11i OR n0OlOi;
	wire_ni00il_dataout <= niiO1i OR n0l11O;
	wire_ni00iO_dataout <= niiO1l OR n0l11O;
	wire_ni00ll_dataout <= niiO1i OR n0l10l;
	wire_ni00lO_dataout <= niiO1l OR n0l10l;
	wire_ni00Ol_dataout <= wire_ni0iii_dataout WHEN n0OlOi = '1'  ELSE wire_ni0i0i_dataout;
	wire_ni00OO_dataout <= wire_ni0iil_dataout WHEN n0OlOi = '1'  ELSE wire_ni0i0l_dataout;
	wire_ni010i_dataout <= n0iOli OR n0OlOi;
	wire_ni010l_dataout <= wire_w_lg_n0iOlO2047w(0) WHEN n0OlOi = '1'  ELSE wire_w_lg_n0iOli2046w(0);
	wire_ni010O_dataout <= n0iOlO WHEN n0OlOi = '1'  ELSE n0iOli;
	wire_ni011l_dataout <= wire_ni01li_dataout WHEN n0OlOi = '1'  ELSE wire_ni01ii_dataout;
	wire_ni011O_dataout <= wire_ni01ll_dataout WHEN n0OlOi = '1'  ELSE wire_ni01il_dataout;
	wire_ni01ii_dataout <= niiO1i OR n0iOli;
	wire_ni01il_dataout <= niiO1l OR n0iOli;
	wire_ni01li_dataout <= niiO1i OR n0iOlO;
	wire_ni01ll_dataout <= niiO1l OR n0iOlO;
	wire_ni01Oi_dataout <= niiO1i OR n0iOOl;
	wire_ni01Ol_dataout <= niiO1l OR n0iOOl;
	wire_ni0i_dataout <= niil1l AND n0Olli;
	wire_ni0i0i_dataout <= niiO1i OR n0l1ii;
	wire_ni0i0l_dataout <= niiO1l OR n0l1ii;
	wire_ni0i1i_dataout <= n0l1ii OR n0OlOi;
	wire_ni0i1l_dataout <= wire_w_lg_n0l1iO2033w(0) WHEN n0OlOi = '1'  ELSE wire_w_lg_n0l1ii2032w(0);
	wire_ni0i1O_dataout <= n0l1iO WHEN n0OlOi = '1'  ELSE n0l1ii;
	wire_ni0iii_dataout <= niiO1i OR n0l1iO;
	wire_ni0iil_dataout <= niiO1l OR n0l1iO;
	wire_ni0ili_dataout <= niiO1i OR n0l1ll;
	wire_ni0ill_dataout <= niiO1l OR n0l1ll;
	wire_ni0iOi_dataout <= wire_ni0l0l_dataout WHEN n0OlOi = '1'  ELSE wire_ni0l1l_dataout;
	wire_ni0iOl_dataout <= wire_ni0l0O_dataout WHEN n0OlOi = '1'  ELSE wire_ni0l1O_dataout;
	wire_ni0iOO_dataout <= n0l1Oi OR n0OlOi;
	wire_ni0l_dataout <= niil1O AND n0Olli;
	wire_ni0l0l_dataout <= niiO1i OR n0l01i;
	wire_ni0l0O_dataout <= niiO1l OR n0l01i;
	wire_ni0l1i_dataout <= n0l01i WHEN n0OlOi = '1'  ELSE n0l1Oi;
	wire_ni0l1l_dataout <= niiO1i OR n0l1Oi;
	wire_ni0l1O_dataout <= niiO1l OR n0l1Oi;
	wire_ni0lil_dataout <= niiO1i OR n0l0ii;
	wire_ni0liO_dataout <= niiO1l OR n0l0ii;
	wire_ni0lli_dataout <= wire_ni0lOl_dataout OR n0l0ii;
	wire_ni0lll_dataout <= wire_ni0lOO_dataout AND NOT(n0l0ii);
	wire_ni0llO_dataout <= wire_ni0O1i_dataout OR n0l0ii;
	wire_ni0lOi_dataout <= wire_ni0O1l_dataout OR n0l0ii;
	wire_ni0lOl_dataout <= wire_ni0O1O_dataout OR n0l00l;
	wire_ni0lOO_dataout <= wire_ni0O0i_dataout OR n0l00l;
	wire_ni0O_dataout <= niil0i AND n0Olli;
	wire_ni0O0i_dataout <= nil00i OR n0l00i;
	wire_ni0O0l_dataout <= nil00l AND NOT(n0l00i);
	wire_ni0O0O_dataout <= nil00O AND NOT(n0l00i);
	wire_ni0O1i_dataout <= wire_ni0O0l_dataout AND NOT(n0l00l);
	wire_ni0O1l_dataout <= wire_ni0O0O_dataout AND NOT(n0l00l);
	wire_ni0O1O_dataout <= nil01O OR n0l00i;
	wire_ni0OiO_dataout <= wire_nii11i_dataout OR n0l0Ol;
	wire_ni0Oli_dataout <= niiO1i OR n0l0Ol;
	wire_ni0Oll_dataout <= niiO1l OR n0l0Ol;
	wire_ni0OlO_dataout <= wire_nii11l_dataout OR n0l0Ol;
	wire_ni0OOi_dataout <= wire_nii11O_dataout AND NOT(n0l0Ol);
	wire_ni0OOl_dataout <= wire_nii10i_dataout OR n0l0Ol;
	wire_ni0OOO_dataout <= wire_nii10l_dataout OR n0l0Ol;
	wire_ni10i_dataout <= wire_ni1iO_dataout AND NOT(n0Oi1l);
	wire_ni10l_dataout <= wire_w_lg_n0OlOi124w(0) WHEN n0O0OO = '1'  ELSE ni0ll;
	wire_ni10O_dataout <= wire_w_lg_n0OlOi124w(0) WHEN n0O0OO = '1'  ELSE ni0lO;
	wire_ni11i_dataout <= wire_w_lg_n0OlOi124w(0) WHEN n0Oi1l = '1'  ELSE wire_ni10O_dataout;
	wire_ni11l_dataout <= n0OlOi WHEN n0Oi1l = '1'  ELSE wire_ni1ii_dataout;
	wire_ni11O_dataout <= wire_ni1il_dataout AND NOT(n0Oi1l);
	wire_ni1i_dataout <= niiiOl AND n0Olli;
	wire_ni1ii_dataout <= n0OlOi WHEN n0O0OO = '1'  ELSE ni0Oi;
	wire_ni1il_dataout <= ni0Ol AND NOT(n0O0OO);
	wire_ni1iO_dataout <= nii1i AND NOT(n0O0OO);
	wire_ni1l_dataout <= niiiOO AND n0Olli;
	wire_ni1l0i_dataout <= nil01O AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_ni1l0l_dataout <= nil00i AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_ni1l0O_dataout <= nil00l AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_ni1l1i_dataout <= niilOO AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_ni1l1l_dataout <= niiO1i AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_ni1l1O_dataout <= niiO1l AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_ni1lii_dataout <= nil00O AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_ni1lil_dataout <= niilOO OR NOT(n0iO1l);
	wire_ni1liO_dataout <= niiO1i OR n0iO1l;
	wire_ni1lli_dataout <= wire_ni1llO_dataout OR n0iO1l;
	wire_ni1lll_dataout <= niilOO OR n0iO1l;
	wire_ni1llO_dataout <= niiO1l OR niilOO;
	wire_ni1lOO_dataout <= wire_ni1OiO_dataout WHEN n0OlOi = '1'  ELSE niilOO;
	wire_ni1O_dataout <= niil1i AND n0Olli;
	wire_ni1O0i_dataout <= n0iO0i OR n0OlOi;
	wire_ni1O0l_dataout <= wire_ni1OlO_dataout OR NOT(n0OlOi);
	wire_ni1O0O_dataout <= niiO1i OR n0iO0i;
	wire_ni1O1i_dataout <= n0iO0O WHEN n0OlOi = '1'  ELSE n0iO0i;
	wire_ni1O1l_dataout <= wire_ni1Oli_dataout WHEN n0OlOi = '1'  ELSE wire_ni1O0O_dataout;
	wire_ni1O1O_dataout <= wire_ni1Oll_dataout WHEN n0OlOi = '1'  ELSE wire_ni1Oii_dataout;
	wire_ni1Oii_dataout <= niiO1l OR n0iO0i;
	wire_ni1OiO_dataout <= niilOO OR NOT(n0iO0O);
	wire_ni1Oli_dataout <= niiO1i OR n0iO0O;
	wire_ni1Oll_dataout <= wire_ni1llO_dataout OR n0iO0O;
	wire_ni1OlO_dataout <= niilOO OR n0iO0O;
	wire_ni1OOl_dataout <= niiO1i OR n0iOil;
	wire_ni1OOO_dataout <= niiO1l OR n0iOil;
	wire_nii_dataout <= rxd(36) WHEN n0OlOl = '1'  ELSE rxd(20);
	wire_nii00i_dataout <= nil01O OR n0li1l;
	wire_nii00l_dataout <= nil00i AND NOT(n0li1l);
	wire_nii00O_dataout <= nil00l AND NOT(n0li1l);
	wire_nii0i_dataout <= wire_niiOl_o(0) WHEN wire_n11ii_o = '1'  ELSE wire_niiiO_dataout;
	wire_nii0ii_dataout <= nil00O AND NOT(n0li1l);
	wire_nii0l_dataout <= wire_niiOl_o(1) WHEN wire_n11ii_o = '1'  ELSE wire_niili_dataout;
	wire_nii0ll_dataout <= wire_niOi0i_dataout OR NOT(wire_nii0Ol_o(2));
	wire_nii0O_dataout <= wire_niiOl_o(2) WHEN wire_n11ii_o = '1'  ELSE wire_niill_dataout;
	wire_nii0Oi_dataout <= wire_niOi0O_dataout OR NOT(wire_nii0Ol_o(2));
	wire_nii10i_dataout <= wire_nii1il_dataout AND NOT(n0l0ll);
	wire_nii10l_dataout <= wire_nii1iO_dataout AND NOT(n0l0ll);
	wire_nii10O_dataout <= nil01O AND NOT(n0l0iO);
	wire_nii11i_dataout <= wire_w_lg_n0l0iO2013w(0) AND NOT(n0l0ll);
	wire_nii11l_dataout <= wire_nii10O_dataout AND NOT(n0l0ll);
	wire_nii11O_dataout <= wire_nii1ii_dataout OR n0l0ll;
	wire_nii1ii_dataout <= nil00i OR n0l0iO;
	wire_nii1il_dataout <= nil00l AND NOT(n0l0iO);
	wire_nii1iO_dataout <= nil00O AND NOT(n0l0iO);
	wire_nii1l_dataout <= wire_n11OO_o AND NOT(rbist_clr_rx);
	wire_nii1O_dataout <= wire_n11Ol_o AND NOT(rbist_clr_rx);
	wire_niii_dataout <= niil0l AND n0Olli;
	wire_niiii_dataout <= wire_niiOl_o(3) WHEN wire_n11ii_o = '1'  ELSE wire_niilO_dataout;
	wire_niiil_dataout <= wire_niiOl_o(4) WHEN wire_n11ii_o = '1'  ELSE wire_niiOi_dataout;
	wire_niiiO_dataout <= ni00O AND NOT(wire_n11il_o);
	wire_niil_dataout <= niil0O AND n0Olli;
	wire_niili_dataout <= ni0ii AND NOT(wire_n11il_o);
	wire_niill_dataout <= ni0il AND NOT(wire_n11il_o);
	wire_niilO_dataout <= ni0iO AND NOT(wire_n11il_o);
	wire_niiO_dataout <= niilii AND n0Olli;
	wire_niiOi_dataout <= ni0li AND NOT(wire_n11il_o);
	wire_nil_dataout <= rxd(37) WHEN n0OlOl = '1'  ELSE rxd(21);
	wire_nil0ii_dataout <= wire_niliOi_dataout AND NOT(rbist_clr_rx);
	wire_nil0il_dataout <= wire_niliOl_dataout AND NOT(rbist_clr_rx);
	wire_nil0iO_dataout <= wire_niliOO_dataout AND NOT(rbist_clr_rx);
	wire_nil0li_dataout <= wire_nill1i_dataout AND NOT(rbist_clr_rx);
	wire_nil0ll_dataout <= wire_nill1l_dataout AND NOT(rbist_clr_rx);
	wire_nil0lO_dataout <= wire_nill1O_dataout AND NOT(rbist_clr_rx);
	wire_nil0Oi_dataout <= wire_nill0i_dataout AND NOT(rbist_clr_rx);
	wire_nil0Ol_dataout <= wire_nill0l_dataout AND NOT(rbist_clr_rx);
	wire_nil0OO_dataout <= wire_nill0O_dataout AND NOT(rbist_clr_rx);
	wire_nili_dataout <= niilil AND n0Olli;
	wire_nili0i_dataout <= wire_nillli_dataout AND NOT(rbist_clr_rx);
	wire_nili0l_dataout <= wire_nillll_dataout AND NOT(rbist_clr_rx);
	wire_nili0O_dataout <= wire_nilllO_dataout AND NOT(rbist_clr_rx);
	wire_nili1i_dataout <= wire_nillii_dataout AND NOT(rbist_clr_rx);
	wire_nili1l_dataout <= wire_nillil_dataout AND NOT(rbist_clr_rx);
	wire_nili1O_dataout <= wire_nilliO_dataout AND NOT(rbist_clr_rx);
	wire_niliii_dataout <= wire_nillOi_dataout AND NOT(rbist_clr_rx);
	wire_niliil_dataout <= wire_nillOl_dataout AND NOT(rbist_clr_rx);
	wire_niliiO_dataout <= wire_nillOO_dataout AND NOT(rbist_clr_rx);
	wire_nilili_dataout <= wire_ni1iil_o AND NOT(rbist_clr_rx);
	wire_nilill_dataout <= wire_ni1ili_o AND NOT(rbist_clr_rx);
	wire_nililO_dataout <= wire_ni1ill_o AND NOT(rbist_clr_rx);
	wire_niliOi_dataout <= wire_nilO1i_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_niliOl_dataout <= wire_nilO1l_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_niliOO_dataout <= wire_nilO1O_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nill_dataout <= niiliO AND n0Olli;
	wire_nill0i_dataout <= wire_nilOii_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nill0l_dataout <= wire_nilOil_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nill0O_dataout <= wire_nilOiO_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nill1i_dataout <= wire_nilO0i_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nill1l_dataout <= wire_nilO0l_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nill1O_dataout <= wire_nilO0O_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nillii_dataout <= wire_nilOli_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nillil_dataout <= wire_nilOll_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nilliO_dataout <= wire_nilOlO_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nillli_dataout <= wire_nilOOi_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nillll_dataout <= wire_nilOOl_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nilllO_dataout <= wire_nilOOO_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nillOi_dataout <= wire_niO11i_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nillOl_dataout <= wire_niO11l_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nillOO_dataout <= wire_niO11O_dataout AND NOT(wire_nO_w_lg_dataout1517w(0));
	wire_nilO_dataout <= niilli AND n0Olli;
	wire_nilO0i_dataout <= wire_nii0lO_o WHEN niilOl = '1'  ELSE niiiOl;
	wire_nilO0l_dataout <= wire_nii0Oi_dataout WHEN niilOl = '1'  ELSE niiiOO;
	wire_nilO0O_dataout <= wire_nii0OO_o WHEN niilOl = '1'  ELSE niil1i;
	wire_nilO1i_dataout <= wire_nii0iO_o WHEN niilOl = '1'  ELSE ni1lOl;
	wire_nilO1l_dataout <= wire_nii0li_o WHEN niilOl = '1'  ELSE niiilO;
	wire_nilO1O_dataout <= wire_nii0ll_dataout WHEN niilOl = '1'  ELSE niiiOi;
	wire_nilOii_dataout <= wire_niii1i_o WHEN niilOl = '1'  ELSE niil1l;
	wire_nilOil_dataout <= wire_niii1l_o WHEN niilOl = '1'  ELSE niil1O;
	wire_nilOiO_dataout <= wire_niii1O_o WHEN niilOl = '1'  ELSE niil0i;
	wire_nilOli_dataout <= wire_niii0i_o WHEN niilOl = '1'  ELSE niil0l;
	wire_nilOll_dataout <= wire_niii0l_o WHEN niilOl = '1'  ELSE niil0O;
	wire_nilOlO_dataout <= wire_niii0O_o WHEN niilOl = '1'  ELSE niilii;
	wire_nilOOi_dataout <= wire_niiiii_o WHEN niilOl = '1'  ELSE niilil;
	wire_nilOOl_dataout <= wire_niiiil_o WHEN niilOl = '1'  ELSE niiliO;
	wire_nilOOO_dataout <= wire_niiiiO_o WHEN niilOl = '1'  ELSE niilli;
	wire_niO_dataout <= rxd(38) WHEN n0OlOl = '1'  ELSE rxd(22);
	wire_niO00i_dataout <= wire_niO0OO_o(6) AND wire_ni1i0l_o;
	wire_niO00l_dataout <= wire_niOi1i_o(0) AND wire_ni1i0l_o;
	wire_niO00O_dataout <= wire_niOi1i_o(1) AND wire_ni1i0l_o;
	wire_niO01i_dataout <= wire_niO0OO_o(3) AND wire_ni1i0l_o;
	wire_niO01l_dataout <= wire_niO0OO_o(4) AND wire_ni1i0l_o;
	wire_niO01O_dataout <= wire_niO0OO_o(5) AND wire_ni1i0l_o;
	wire_niO0ii_dataout <= wire_niOi1i_o(2) AND wire_ni1i0l_o;
	wire_niO0il_dataout <= wire_niOi1i_o(3) AND wire_ni1i0l_o;
	wire_niO0iO_dataout <= wire_niOi1i_o(4) AND wire_ni1i0l_o;
	wire_niO0li_dataout <= wire_niOi1i_o(5) AND wire_ni1i0l_o;
	wire_niO0ll_dataout <= wire_niOi1i_o(6) AND wire_ni1i0l_o;
	wire_niO0lO_dataout <= wire_niOi1i_o(7) AND wire_ni1i0l_o;
	wire_niO0Oi_dataout <= wire_niOi1i_o(8) AND wire_ni1i0l_o;
	wire_niO10i_dataout <= niiOlO AND wire_ni1i0l_o;
	wire_niO10l_dataout <= wire_niO0Ol_o(0) AND wire_ni1i0l_o;
	wire_niO10O_dataout <= wire_niO0Ol_o(1) AND wire_ni1i0l_o;
	wire_niO11i_dataout <= wire_niiili_o WHEN niilOl = '1'  ELSE niilll;
	wire_niO11l_dataout <= (NOT wire_nii0Ol_o(2)) WHEN niilOl = '1'  ELSE niillO;
	wire_niO11O_dataout <= wire_niiill_o WHEN niilOl = '1'  ELSE niilOi;
	wire_niO1ii_dataout <= wire_niO0Ol_o(2) AND wire_ni1i0l_o;
	wire_niO1il_dataout <= wire_niO0Ol_o(3) AND wire_ni1i0l_o;
	wire_niO1iO_dataout <= wire_niO0Ol_o(4) AND wire_ni1i0l_o;
	wire_niO1li_dataout <= wire_niO0Ol_o(5) AND wire_ni1i0l_o;
	wire_niO1ll_dataout <= wire_niO0Ol_o(6) AND wire_ni1i0l_o;
	wire_niO1lO_dataout <= niiO0i OR NOT(wire_ni1i0l_o);
	wire_niO1Oi_dataout <= wire_niO0OO_o(0) AND wire_ni1i0l_o;
	wire_niO1Ol_dataout <= wire_niO0OO_o(1) AND wire_ni1i0l_o;
	wire_niO1OO_dataout <= wire_niO0OO_o(2) AND wire_ni1i0l_o;
	wire_niOi_dataout <= niilll AND n0Olli;
	wire_niOi0i_dataout <= niiOOl WHEN n0OlOi = '1'  ELSE nil1ii;
	wire_niOi0l_dataout <= niiOOO WHEN n0OlOi = '1'  ELSE nil1il;
	wire_niOi0O_dataout <= nil11i WHEN n0OlOi = '1'  ELSE nil1iO;
	wire_niOi1l_dataout <= niiOlO WHEN n0OlOi = '1'  ELSE nil10l;
	wire_niOi1O_dataout <= niiOOi WHEN n0OlOi = '1'  ELSE nil10O;
	wire_niOiii_dataout <= nil11l WHEN n0OlOi = '1'  ELSE nil1li;
	wire_niOiil_dataout <= nil11O WHEN n0OlOi = '1'  ELSE nil1ll;
	wire_niOiiO_dataout <= nil10i WHEN n0OlOi = '1'  ELSE nil1lO;
	wire_niOili_dataout <= niiO0i AND n0OlOi;
	wire_niOill_dataout <= niiO0l AND n0OlOi;
	wire_niOilO_dataout <= niiO0O AND n0OlOi;
	wire_niOiOi_dataout <= niiOii AND n0OlOi;
	wire_niOiOl_dataout <= niiOil AND n0OlOi;
	wire_niOiOO_dataout <= niiOiO AND n0OlOi;
	wire_niOl_dataout <= niillO AND n0Olli;
	wire_niOl1i_dataout <= niiOli AND n0OlOi;
	wire_niOl1l_dataout <= niiOll AND n0OlOi;
	wire_niOO_dataout <= niilOi AND n0Olli;
	wire_nl_dataout <= rbisten_rx AND wire_w_lg_w_rbist_sel_range1w9w(0);
	wire_nl_w_lg_dataout1094w(0) <= wire_nl_dataout AND nl1Oll;
	wire_nl_w_lg_dataout1013w(0) <= NOT wire_nl_dataout;
	wire_nl000l_dataout <= nll0il OR NOT(wire_w_lg_n0li0O1010w(0));
	wire_nl000O_dataout <= wire_nl001O_dataout OR wire_w_lg_n0li0O1010w(0);
	wire_nl001i_dataout <= nll0ii OR n0li0i;
	wire_nl001l_dataout <= nll0il OR n0li0i;
	wire_nl001O_dataout <= nll00O OR nll0il;
	wire_nl00ii_dataout <= nll0ii OR wire_w_lg_n0li0O1010w(0);
	wire_nl00il_dataout <= nll0il OR wire_w_lg_n0li0O1010w(0);
	wire_nl00iO_dataout <= nll0il OR NOT(wire_w_lg_n0liii1009w(0));
	wire_nl00li_dataout <= wire_nl001O_dataout OR wire_w_lg_n0liii1009w(0);
	wire_nl00ll_dataout <= nll0ii OR wire_w_lg_n0liii1009w(0);
	wire_nl00lO_dataout <= nll0il OR wire_w_lg_n0liii1009w(0);
	wire_nl00Oi_dataout <= nll0il OR NOT(wire_w_lg_n0liil1008w(0));
	wire_nl00Ol_dataout <= wire_nl001O_dataout OR wire_w_lg_n0liil1008w(0);
	wire_nl00OO_dataout <= nll0ii OR wire_w_lg_n0liil1008w(0);
	wire_nl01il_dataout <= nll0ii AND NOT(wire_nl_w_lg_dataout1013w(0));
	wire_nl01iO_dataout <= nll00O AND NOT(wire_nl_w_lg_dataout1013w(0));
	wire_nl01li_dataout <= nlll1i AND NOT(wire_nl_w_lg_dataout1013w(0));
	wire_nl01ll_dataout <= nlll1l AND NOT(wire_nl_w_lg_dataout1013w(0));
	wire_nl01lO_dataout <= nlll1O AND NOT(wire_nl_w_lg_dataout1013w(0));
	wire_nl01Oi_dataout <= nlll0i AND NOT(wire_nl_w_lg_dataout1013w(0));
	wire_nl01Ol_dataout <= nll0il OR NOT(n0li0i);
	wire_nl01OO_dataout <= wire_nl001O_dataout OR n0li0i;
	wire_nl0i_dataout <= nll00O WHEN n0Olll = '1'  ELSE wire_nl0O_dataout;
	wire_nl0i0i_dataout <= wire_nl0ill_dataout WHEN n0OlOi = '1'  ELSE wire_nl0iil_dataout;
	wire_nl0i0l_dataout <= wire_w_lg_n0lili1006w(0) OR n0OlOi;
	wire_nl0i0O_dataout <= wire_nl0ilO_dataout OR NOT(n0OlOi);
	wire_nl0i1i_dataout <= nll0il OR wire_w_lg_n0liil1008w(0);
	wire_nl0i1l_dataout <= wire_nl0iiO_dataout WHEN n0OlOi = '1'  ELSE nll0il;
	wire_nl0i1O_dataout <= wire_nl0ili_dataout WHEN n0OlOi = '1'  ELSE wire_nl0iii_dataout;
	wire_nl0iii_dataout <= nll00O OR wire_w_lg_n0lili1006w(0);
	wire_nl0iil_dataout <= nll0ii OR wire_w_lg_n0lili1006w(0);
	wire_nl0iiO_dataout <= nll0il OR NOT(n0liiO);
	wire_nl0ili_dataout <= wire_nl001O_dataout OR n0liiO;
	wire_nl0ill_dataout <= nll0ii OR n0liiO;
	wire_nl0ilO_dataout <= nll0il OR n0liiO;
	wire_nl0iOl_dataout <= wire_nl0l0O_dataout AND NOT(wire_w_lg_n0lill1005w(0));
	wire_nl0iOO_dataout <= wire_nl0l0l_dataout AND NOT(wire_w_lg_n0lill1005w(0));
	wire_nl0l_dataout <= ni00i AND n0OllO;
	wire_nl0l0i_dataout <= wire_nl0l0O_dataout OR wire_w_lg_n0lill1005w(0);
	wire_nl0l0l_dataout <= n0lilO WHEN n0OlOi = '1'  ELSE n0liOi;
	wire_nl0l0O_dataout <= wire_w_lg_n0lilO1004w(0) WHEN n0OlOi = '1'  ELSE wire_w_lg_n0liOi1003w(0);
	wire_nl0l1i_dataout <= nll00O OR wire_w_lg_n0lill1005w(0);
	wire_nl0l1l_dataout <= nll0ii OR wire_w_lg_n0lill1005w(0);
	wire_nl0l1O_dataout <= wire_nl0l0l_dataout OR wire_w_lg_n0lill1005w(0);
	wire_nl0lii_dataout <= nll00O OR wire_w_lg_n0liOl1002w(0);
	wire_nl0lil_dataout <= nll0ii OR wire_w_lg_n0liOl1002w(0);
	wire_nl0liO_dataout <= n0OlOi AND NOT(wire_w_lg_n0liOO1001w(0));
	wire_nl0lli_dataout <= nll00O OR wire_w_lg_n0liOO1001w(0);
	wire_nl0lll_dataout <= nll0ii OR wire_w_lg_n0liOO1001w(0);
	wire_nl0llO_dataout <= wire_nl0O1i_dataout OR wire_w_lg_n0liOO1001w(0);
	wire_nl0lOi_dataout <= wire_nl0O1l_dataout OR wire_w_lg_n0liOO1001w(0);
	wire_nl0lOl_dataout <= wire_nl0O1O_dataout OR wire_w_lg_n0liOO1001w(0);
	wire_nl0lOO_dataout <= wire_nl0O0i_dataout OR wire_w_lg_n0liOO1001w(0);
	wire_nl0O_dataout <= ni01l AND n0OllO;
	wire_nl0O0i_dataout <= wire_nl0Oil_dataout AND n0OlOi;
	wire_nl0O0l_dataout <= wire_nl0OiO_dataout OR n0ll1i;
	wire_nl0O0O_dataout <= wire_nl0Oli_dataout AND NOT(n0ll1i);
	wire_nl0O1i_dataout <= wire_nl0O0l_dataout AND n0OlOi;
	wire_nl0O1l_dataout <= wire_nl0O0O_dataout OR NOT(n0OlOi);
	wire_nl0O1O_dataout <= wire_nl0Oii_dataout OR NOT(n0OlOi);
	wire_nl0Oii_dataout <= wire_nl0Oll_dataout OR n0ll1i;
	wire_nl0Oil_dataout <= wire_nl0OlO_dataout AND NOT(n0ll1i);
	wire_nl0OiO_dataout <= wire_nl0OOi_dataout OR NOT(n0ll1l);
	wire_nl0Oli_dataout <= wire_nl0OOl_dataout OR NOT(n0ll1l);
	wire_nl0Oll_dataout <= wire_nl0OOO_dataout OR NOT(n0ll1l);
	wire_nl0OlO_dataout <= wire_nli11i_dataout AND n0ll1l;
	wire_nl0OOi_dataout <= wire_nli11l_dataout AND NOT(n0lOiO);
	wire_nl0OOl_dataout <= wire_nli11O_dataout OR n0lOiO;
	wire_nl0OOO_dataout <= wire_nli10i_dataout AND NOT(n0lOiO);
	wire_nl1i_dataout <= niiO1i WHEN n0Olli = '1'  ELSE wire_nl1O_dataout;
	wire_nl1l_dataout <= niiO1l WHEN n0Olli = '1'  ELSE wire_nl0i_dataout;
	wire_nl1O_dataout <= nll0ii WHEN n0Olll = '1'  ELSE wire_nl0l_dataout;
	wire_nl1Oii_dataout <= wire_nliill_dataout AND wire_nl1OiO_o(5);
	wire_nl1Oil_dataout <= n0llil AND wire_nl1OiO_o(5);
	wire_nl1Oli_dataout <= wire_nli1Ol_dataout AND wire_nl1OiO_o(6);
	wire_nl1OlO_dataout <= wire_nli1OO_dataout AND wire_nl1OiO_o(6);
	wire_nl1OOi_dataout <= wire_nl0liO_dataout AND wire_nl1OiO_o(7);
	wire_nl1OOl_dataout <= wire_nl0iOl_dataout AND wire_nl1OiO_o(8);
	wire_nl1OOO_dataout <= wire_nl0iOO_dataout AND wire_nl1OiO_o(8);
	wire_nli_dataout <= rxd(39) WHEN n0OlOl = '1'  ELSE rxd(23);
	wire_nli00i_dataout <= wire_nli0li_dataout OR wire_w_lg_n0ll1O1000w(0);
	wire_nli00l_dataout <= wire_nli0ll_dataout OR wire_w_lg_n0ll1O1000w(0);
	wire_nli00O_dataout <= wire_nli0lO_dataout OR wire_w_lg_n0ll1O1000w(0);
	wire_nli01i_dataout <= nll00O OR wire_w_lg_n0ll1O1000w(0);
	wire_nli01l_dataout <= nll0ii OR wire_w_lg_n0ll1O1000w(0);
	wire_nli01O_dataout <= wire_nli0iO_dataout OR wire_w_lg_n0ll1O1000w(0);
	wire_nli0ii_dataout <= wire_w_lg_n0ll0i999w(0) OR NOT(n0OlOi);
	wire_nli0il_dataout <= n0ll0i AND n0OlOi;
	wire_nli0iO_dataout <= n0ll0i WHEN n0OlOi = '1'  ELSE wire_nli0Oi_dataout;
	wire_nli0li_dataout <= wire_w_lg_n0ll0i999w(0) WHEN n0OlOi = '1'  ELSE wire_nli0Ol_dataout;
	wire_nli0ll_dataout <= wire_w_lg_n0ll0i999w(0) WHEN n0OlOi = '1'  ELSE wire_nli0OO_dataout;
	wire_nli0lO_dataout <= n0ll0i WHEN n0OlOi = '1'  ELSE wire_nlii1i_dataout;
	wire_nli0Oi_dataout <= wire_nlii1l_dataout OR n0llii;
	wire_nli0Ol_dataout <= wire_nlii1O_dataout AND NOT(n0llii);
	wire_nli0OO_dataout <= wire_nlii0i_dataout AND NOT(n0llii);
	wire_nli10i_dataout <= wire_nli1il_dataout AND NOT(n0lO1l);
	wire_nli10l_dataout <= wire_nli1iO_dataout OR n0lO1l;
	wire_nli10O_dataout <= wire_nli1li_dataout AND NOT(n0lO1i);
	wire_nli11i_dataout <= wire_nli10l_dataout OR n0lOiO;
	wire_nli11l_dataout <= wire_nli10O_dataout OR n0lO1l;
	wire_nli11O_dataout <= wire_nli1ii_dataout OR n0lO1l;
	wire_nli1ii_dataout <= wire_nli1ll_dataout AND NOT(n0lO1i);
	wire_nli1il_dataout <= wire_nli1lO_dataout OR n0lO1i;
	wire_nli1iO_dataout <= wire_nli1Oi_dataout OR n0lO1i;
	wire_nli1li_dataout <= nlll1i OR n0lO0i;
	wire_nli1ll_dataout <= nlll1l AND NOT(n0lO0i);
	wire_nli1lO_dataout <= nlll1O OR n0lO0i;
	wire_nli1Oi_dataout <= nlll0i OR n0lO0i;
	wire_nli1Ol_dataout <= wire_nli0ii_dataout AND NOT(wire_w_lg_n0ll1O1000w(0));
	wire_nli1OO_dataout <= wire_nli0il_dataout AND NOT(wire_w_lg_n0ll1O1000w(0));
	wire_nlii_dataout <= wire_n1l_dataout AND n0OlOi;
	wire_nlii_w_lg_dataout2015w(0) <= NOT wire_nlii_dataout;
	wire_nlii0i_dataout <= wire_nliiil_dataout OR n0ll0l;
	wire_nlii0l_dataout <= wire_nliiiO_dataout AND NOT(n0ll0l);
	wire_nlii0O_dataout <= wire_nl0OOi_dataout OR NOT(n0ll0O);
	wire_nlii1i_dataout <= wire_nlii0l_dataout OR n0llii;
	wire_nlii1l_dataout <= wire_nlii0O_dataout OR n0ll0l;
	wire_nlii1O_dataout <= wire_nliiii_dataout AND NOT(n0ll0l);
	wire_nliiii_dataout <= wire_nl0OOl_dataout OR NOT(n0ll0O);
	wire_nliiil_dataout <= wire_nl0OOO_dataout OR NOT(n0ll0O);
	wire_nliiiO_dataout <= wire_nli11i_dataout AND n0ll0O;
	wire_nliill_dataout <= wire_nlil1i_dataout AND NOT(wire_w_lg_n0llil989w(0));
	wire_nliilO_dataout <= nll00O OR wire_w_lg_n0llil989w(0);
	wire_nliiOi_dataout <= nll0ii OR wire_w_lg_n0llil989w(0);
	wire_nliiOl_dataout <= wire_nlil1l_dataout OR wire_w_lg_n0llil989w(0);
	wire_nliiOO_dataout <= wire_nlil1O_dataout OR wire_w_lg_n0llil989w(0);
	wire_nlil_dataout <= wire_n1O_dataout AND n0OlOi;
	wire_nlil_w_lg_dataout720w(0) <= NOT wire_nlil_dataout;
	wire_nlil0i_dataout <= wire_nlilli_dataout WHEN n0OlOi = '1'  ELSE wire_nlilii_dataout;
	wire_nlil0l_dataout <= wire_nlilll_dataout WHEN n0OlOi = '1'  ELSE wire_nlilil_dataout;
	wire_nlil0O_dataout <= wire_nlillO_dataout WHEN n0OlOi = '1'  ELSE wire_nliliO_dataout;
	wire_nlil1i_dataout <= wire_nlilOi_dataout WHEN n0lOiO = '1'  ELSE wire_nlil0i_dataout;
	wire_nlil1l_dataout <= wire_nlilOl_dataout WHEN n0lOiO = '1'  ELSE wire_nlil0l_dataout;
	wire_nlil1O_dataout <= wire_nlilOO_dataout WHEN n0lOiO = '1'  ELSE wire_nlil0O_dataout;
	wire_nlilii_dataout <= n0lliO AND NOT(n0llll);
	wire_nlilil_dataout <= wire_w_lg_n0lliO988w(0) AND NOT(n0llll);
	wire_nliliO_dataout <= n0lliO OR n0llll;
	wire_nlilli_dataout <= n0llll AND NOT(n0llli);
	wire_nlilll_dataout <= wire_w_lg_n0llll987w(0) AND NOT(n0llli);
	wire_nlillO_dataout <= n0llll OR n0llli;
	wire_nlilOi_dataout <= wire_nliO0i_dataout WHEN n0OlOi = '1'  ELSE wire_nliO1i_dataout;
	wire_nlilOl_dataout <= wire_nliO0l_dataout WHEN n0OlOi = '1'  ELSE wire_nliO1l_dataout;
	wire_nlilOO_dataout <= wire_nliO0O_dataout WHEN n0OlOi = '1'  ELSE wire_nliO1O_dataout;
	wire_nliO_dataout <= wire_n0i_dataout AND n0OlOi;
	wire_nliO_w_lg_dataout718w(0) <= NOT wire_nliO_dataout;
	wire_nliO0i_dataout <= n0llOl AND NOT(n0llOi);
	wire_nliO0l_dataout <= wire_w_lg_n0llOl985w(0) AND NOT(n0llOi);
	wire_nliO0O_dataout <= n0llOl OR n0llOi;
	wire_nliO1i_dataout <= n0lllO AND NOT(n0llOl);
	wire_nliO1l_dataout <= wire_w_lg_n0lllO986w(0) AND NOT(n0llOl);
	wire_nliO1O_dataout <= n0lllO OR n0llOl;
	wire_nliOii_dataout <= nll00O OR wire_w_lg_n0llOO984w(0);
	wire_nliOil_dataout <= nll0ii OR wire_w_lg_n0llOO984w(0);
	wire_nliOiO_dataout <= wire_nliOOi_dataout AND NOT(n0lOiO);
	wire_nliOli_dataout <= wire_nliOOl_dataout AND NOT(n0lOiO);
	wire_nliOll_dataout <= wire_nliOOO_dataout OR n0lOiO;
	wire_nliOlO_dataout <= wire_nll11i_dataout AND NOT(n0lOiO);
	wire_nliOOi_dataout <= nlll1i OR n0lOii;
	wire_nliOOl_dataout <= nlll1l AND NOT(n0lOii);
	wire_nliOOO_dataout <= nlll1O OR n0lOii;
	wire_nll10i_dataout <= wire_w_lg_n0OlOi124w(0) WHEN n0lOil = '1'  ELSE wire_nll1il_dataout;
	wire_nll10l_dataout <= n0OlOi WHEN n0lOil = '1'  ELSE wire_nll1iO_dataout;
	wire_nll10O_dataout <= wire_nll1li_dataout AND NOT(n0lOil);
	wire_nll11i_dataout <= nlll0i AND NOT(n0lOii);
	wire_nll11O_dataout <= wire_nll1ii_dataout AND NOT(n0lOil);
	wire_nll1ii_dataout <= n0OlOi WHEN n0lO0l = '1'  ELSE wire_nll1ll_dataout;
	wire_nll1il_dataout <= wire_w_lg_n0OlOi124w(0) WHEN n0lO0l = '1'  ELSE wire_nll1lO_dataout;
	wire_nll1iO_dataout <= n0OlOi WHEN n0lO0l = '1'  ELSE wire_nll1Oi_dataout;
	wire_nll1li_dataout <= wire_nll1Ol_dataout AND NOT(n0lO0l);
	wire_nll1ll_dataout <= nlll1i OR n0lO1O;
	wire_nll1lO_dataout <= wire_w_lg_n0OlOi124w(0) WHEN n0lO1O = '1'  ELSE nlll1l;
	wire_nll1Oi_dataout <= n0OlOi WHEN n0lO1O = '1'  ELSE nlll1O;
	wire_nll1Ol_dataout <= nlll0i AND NOT(n0lO1O);
	wire_nlli_dataout <= wire_n0l_dataout AND n0OlOi;
	wire_nlli_w_lg_dataout716w(0) <= NOT wire_nlli_dataout;
	wire_nlll_dataout <= wire_n0O_dataout AND n0OlOi;
	wire_nlll_w_lg_dataout679w(0) <= NOT wire_nlll_dataout;
	wire_nlll0l_dataout <= wire_nl011O_o AND NOT(rbist_clr_rx);
	wire_nlll0O_dataout <= wire_nl011l_o AND NOT(rbist_clr_rx);
	wire_nlllii_dataout <= wire_nllO0i_o(0) WHEN wire_nl1OOl_dataout = '1'  ELSE wire_nlllOi_dataout;
	wire_nlllil_dataout <= wire_nllO0i_o(1) WHEN wire_nl1OOl_dataout = '1'  ELSE wire_nlllOl_dataout;
	wire_nllliO_dataout <= wire_nllO0i_o(2) WHEN wire_nl1OOl_dataout = '1'  ELSE wire_nlllOO_dataout;
	wire_nlllli_dataout <= wire_nllO0i_o(3) WHEN wire_nl1OOl_dataout = '1'  ELSE wire_nllO1i_dataout;
	wire_nlllll_dataout <= wire_nllO0i_o(4) WHEN wire_nl1OOl_dataout = '1'  ELSE wire_nllO1l_dataout;
	wire_nllllO_dataout <= wire_nllO0i_o(5) WHEN wire_nl1OOl_dataout = '1'  ELSE wire_nllO1O_dataout;
	wire_nlllOi_dataout <= nll0iO AND NOT(wire_nl1OOO_dataout);
	wire_nlllOl_dataout <= nll0li AND NOT(wire_nl1OOO_dataout);
	wire_nlllOO_dataout <= nll0ll AND NOT(wire_nl1OOO_dataout);
	wire_nllO_dataout <= wire_nii_dataout AND n0OlOi;
	wire_nllO_w_lg_dataout713w(0) <= NOT wire_nllO_dataout;
	wire_nllO0l_dataout <= wire_nllOil_o(0) WHEN wire_nl1OOi_dataout = '1'  ELSE nll0OO;
	wire_nllO0O_dataout <= wire_nllOil_o(1) WHEN wire_nl1OOi_dataout = '1'  ELSE nlli1i;
	wire_nllO1i_dataout <= nll0lO AND NOT(wire_nl1OOO_dataout);
	wire_nllO1l_dataout <= nll0Oi AND NOT(wire_nl1OOO_dataout);
	wire_nllO1O_dataout <= nll0Ol AND NOT(wire_nl1OOO_dataout);
	wire_nllOii_dataout <= wire_nllOil_o(2) WHEN wire_nl1OOi_dataout = '1'  ELSE nlli1l;
	wire_nllOiO_dataout <= wire_nllOOi_dataout AND NOT(wire_nl1OlO_dataout);
	wire_nllOli_dataout <= wire_nllOOl_dataout AND NOT(wire_nl1OlO_dataout);
	wire_nllOll_dataout <= wire_nllOOO_dataout AND NOT(wire_nl1OlO_dataout);
	wire_nllOlO_dataout <= wire_nlO11i_dataout AND NOT(wire_nl1OlO_dataout);
	wire_nllOOi_dataout <= wire_nlO11l_o(0) WHEN wire_nl1Oli_dataout = '1'  ELSE nlli1O;
	wire_nllOOl_dataout <= wire_nlO11l_o(1) WHEN wire_nl1Oli_dataout = '1'  ELSE nlli0i;
	wire_nllOOO_dataout <= wire_nlO11l_o(2) WHEN wire_nl1Oli_dataout = '1'  ELSE nlli0l;
	wire_nlO00i_dataout <= wire_nlO00O_o(7) WHEN wire_nl1Oil_dataout = '1'  ELSE nlliOl;
	wire_nlO00l_dataout <= wire_nlO00O_o(8) WHEN wire_nl1Oil_dataout = '1'  ELSE nlliOO;
	wire_nlO01i_dataout <= wire_nlO00O_o(4) WHEN wire_nl1Oil_dataout = '1'  ELSE nllill;
	wire_nlO01l_dataout <= wire_nlO00O_o(5) WHEN wire_nl1Oil_dataout = '1'  ELSE nllilO;
	wire_nlO01O_dataout <= wire_nlO00O_o(6) WHEN wire_nl1Oil_dataout = '1'  ELSE nlliOi;
	wire_nlO10i_dataout <= wire_nlO1Oi_dataout AND NOT(wire_nl1Oii_dataout);
	wire_nlO10l_dataout <= wire_nlO1Ol_dataout AND NOT(wire_nl1Oii_dataout);
	wire_nlO10O_dataout <= wire_nlO1OO_dataout AND NOT(wire_nl1Oii_dataout);
	wire_nlO11i_dataout <= wire_nlO11l_o(3) WHEN wire_nl1Oli_dataout = '1'  ELSE nlli0O;
	wire_nlO11O_dataout <= wire_nlO1lO_dataout AND NOT(wire_nl1Oii_dataout);
	wire_nlO1ii_dataout <= wire_nlO01i_dataout AND NOT(wire_nl1Oii_dataout);
	wire_nlO1il_dataout <= wire_nlO01l_dataout AND NOT(wire_nl1Oii_dataout);
	wire_nlO1iO_dataout <= wire_nlO01O_dataout AND NOT(wire_nl1Oii_dataout);
	wire_nlO1li_dataout <= wire_nlO00i_dataout AND NOT(wire_nl1Oii_dataout);
	wire_nlO1ll_dataout <= wire_nlO00l_dataout AND NOT(wire_nl1Oii_dataout);
	wire_nlO1lO_dataout <= wire_nlO00O_o(0) WHEN wire_nl1Oil_dataout = '1'  ELSE nlliii;
	wire_nlO1Oi_dataout <= wire_nlO00O_o(1) WHEN wire_nl1Oil_dataout = '1'  ELSE nlliil;
	wire_nlO1Ol_dataout <= wire_nlO00O_o(2) WHEN wire_nl1Oil_dataout = '1'  ELSE nlliiO;
	wire_nlO1OO_dataout <= wire_nlO00O_o(3) WHEN wire_nl1Oil_dataout = '1'  ELSE nllili;
	wire_nlOi_dataout <= wire_nil_dataout AND n0OlOi;
	wire_nlOi_w_lg_dataout678w(0) <= NOT wire_nlOi_dataout;
	wire_nlOl_dataout <= wire_niO_dataout AND n0OlOi;
	wire_nlOl_w_lg_dataout710w(0) <= NOT wire_nlOl_dataout;
	wire_nlOO_dataout <= wire_nli_dataout AND n0OlOi;
	wire_nlOO_w_lg_w_lg_w2466w2467w2468w(0) <= wire_nlOO_w_lg_w2466w2467w(0) AND wire_nlil_dataout;
	wire_nlOO_w_lg_w_lg_w2481w2482w2483w(0) <= wire_nlOO_w_lg_w2481w2482w(0) AND wire_nlil_dataout;
	wire_nlOO_w_lg_w2466w2467w(0) <= wire_nlOO_w2466w(0) AND wire_nliO_dataout;
	wire_nlOO_w_lg_w2481w2482w(0) <= wire_nlOO_w2481w(0) AND wire_nliO_w_lg_dataout718w(0);
	wire_nlOO_w_lg_w2410w2411w(0) <= wire_nlOO_w2410w(0) AND wire_nlli_dataout;
	wire_nlOO_w_lg_w2433w2434w(0) <= wire_nlOO_w2433w(0) AND wire_nlli_dataout;
	wire_nlOO_w2452w(0) <= wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout2333w2449w2450w2451w(0) AND wire_nlli_dataout;
	wire_nlOO_w2466w(0) <= wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout2333w2334w2335w2465w(0) AND wire_nlli_dataout;
	wire_nlOO_w2481w(0) <= wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout2333w2334w2335w2336w(0) AND wire_nlli_dataout;
	wire_nlOO_w2410w(0) <= wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout709w711w2408w2409w(0) AND wire_nlll_dataout;
	wire_nlOO_w2433w(0) <= wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout709w2430w2431w2432w(0) AND wire_nlll_dataout;
	wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout2333w2449w2450w2451w(0) <= wire_nlOO_w_lg_w_lg_w_lg_dataout2333w2449w2450w(0) AND wire_nlll_dataout;
	wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout2333w2334w2335w2465w(0) <= wire_nlOO_w_lg_w_lg_w_lg_dataout2333w2334w2335w(0) AND wire_nlll_w_lg_dataout679w(0);
	wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout2333w2334w2335w2336w(0) <= wire_nlOO_w_lg_w_lg_w_lg_dataout2333w2334w2335w(0) AND wire_nlll_dataout;
	wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout709w711w2408w2409w(0) <= wire_nlOO_w_lg_w_lg_w_lg_dataout709w711w2408w(0) AND wire_nllO_dataout;
	wire_nlOO_w_lg_w_lg_w_lg_w_lg_dataout709w2430w2431w2432w(0) <= wire_nlOO_w_lg_w_lg_w_lg_dataout709w2430w2431w(0) AND wire_nllO_dataout;
	wire_nlOO_w_lg_w_lg_w_lg_dataout2333w2449w2450w(0) <= wire_nlOO_w_lg_w_lg_dataout2333w2449w(0) AND wire_nllO_dataout;
	wire_nlOO_w_lg_w_lg_w_lg_dataout2333w2334w2335w(0) <= wire_nlOO_w_lg_w_lg_dataout2333w2334w(0) AND wire_nllO_dataout;
	wire_nlOO_w_lg_w_lg_w_lg_dataout709w711w2408w(0) <= wire_nlOO_w_lg_w_lg_dataout709w711w(0) AND wire_nlOi_dataout;
	wire_nlOO_w_lg_w_lg_w_lg_dataout709w2430w2431w(0) <= wire_nlOO_w_lg_w_lg_dataout709w2430w(0) AND wire_nlOi_dataout;
	wire_nlOO_w_lg_w_lg_dataout2333w2449w(0) <= wire_nlOO_w_lg_dataout2333w(0) AND wire_nlOi_w_lg_dataout678w(0);
	wire_nlOO_w_lg_w_lg_dataout2333w2334w(0) <= wire_nlOO_w_lg_dataout2333w(0) AND wire_nlOi_dataout;
	wire_nlOO_w_lg_w_lg_dataout709w711w(0) <= wire_nlOO_w_lg_dataout709w(0) AND wire_nlOl_w_lg_dataout710w(0);
	wire_nlOO_w_lg_w_lg_dataout709w2430w(0) <= wire_nlOO_w_lg_dataout709w(0) AND wire_nlOl_dataout;
	wire_nlOO_w_lg_dataout2333w(0) <= wire_nlOO_dataout AND wire_nlOl_dataout;
	wire_nlOO_w_lg_dataout709w(0) <= NOT wire_nlOO_dataout;
	wire_nO_dataout <= rbisten_rx AND (((NOT rbist_sel(0)) AND wire_w_lg_w_rbist_sel_range3w4w(0)) AND (n0OO0i2 XOR n0OO0i1));
	wire_nO_w_lg_dataout1517w(0) <= NOT wire_nO_dataout;
	wire_niiOl_a <= ( ni0li & ni0iO & ni0il & ni0ii & ni00O);
	wire_niiOl_b <= ( "0" & "0" & "0" & "0" & "1");
	niiOl :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_niiOl_a,
		b => wire_niiOl_b,
		cin => wire_gnd,
		o => wire_niiOl_o
	  );
	wire_niO0Ol_a <= ( nil10i & nil11O & nil11l & nil11i & niiOOO & niiOOl & niiOOi);
	wire_niO0Ol_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "1");
	niO0Ol :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 7,
		width_b => 7,
		width_o => 7
	  )
	  PORT MAP ( 
		a => wire_niO0Ol_a,
		b => wire_niO0Ol_b,
		cin => wire_gnd,
		o => wire_niO0Ol_o
	  );
	wire_niO0OO_a <= ( niiOll & niiOli & niiOiO & niiOil & niiOii & niiO0O & niiO0l);
	wire_niO0OO_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "1");
	niO0OO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 7,
		width_b => 7,
		width_o => 7
	  )
	  PORT MAP ( 
		a => wire_niO0OO_a,
		b => wire_niO0OO_b,
		cin => wire_gnd,
		o => wire_niO0OO_o
	  );
	wire_niOi1i_a <= ( nil1Oi & nil1lO & nil1ll & nil1li & nil1iO & nil1il & nil1ii & nil10O & nil10l);
	wire_niOi1i_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	niOi1i :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 9,
		width_b => 9,
		width_o => 9
	  )
	  PORT MAP ( 
		a => wire_niOi1i_a,
		b => wire_niOi1i_b,
		cin => wire_gnd,
		o => wire_niOi1i_o
	  );
	wire_nllO0i_a <= ( nll0Ol & nll0Oi & nll0lO & nll0ll & nll0li & nll0iO);
	wire_nllO0i_b <= ( "0" & "0" & "0" & "0" & "0" & "1");
	nllO0i :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 6,
		width_b => 6,
		width_o => 6
	  )
	  PORT MAP ( 
		a => wire_nllO0i_a,
		b => wire_nllO0i_b,
		cin => wire_gnd,
		o => wire_nllO0i_o
	  );
	wire_nllOil_a <= ( nlli1l & nlli1i & nll0OO);
	wire_nllOil_b <= ( "0" & "0" & "1");
	nllOil :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 3,
		width_b => 3,
		width_o => 3
	  )
	  PORT MAP ( 
		a => wire_nllOil_a,
		b => wire_nllOil_b,
		cin => wire_gnd,
		o => wire_nllOil_o
	  );
	wire_nlO00O_a <= ( nlliOO & nlliOl & nlliOi & nllilO & nllill & nllili & nlliiO & nlliil & nlliii);
	wire_nlO00O_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	nlO00O :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 9,
		width_b => 9,
		width_o => 9
	  )
	  PORT MAP ( 
		a => wire_nlO00O_a,
		b => wire_nlO00O_b,
		cin => wire_gnd,
		o => wire_nlO00O_o
	  );
	wire_nlO11l_a <= ( nlli0O & nlli0l & nlli0i & nlli1O);
	wire_nlO11l_b <= ( "0" & "0" & "0" & "1");
	nlO11l :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 4,
		width_b => 4,
		width_o => 4
	  )
	  PORT MAP ( 
		a => wire_nlO11l_a,
		b => wire_nlO11l_b,
		cin => wire_gnd,
		o => wire_nlO11l_o
	  );
	wire_n11li_i <= ( nii1i & ni0Ol & ni0Oi & ni0lO & ni0ll);
	n11li :  oper_decoder
	  GENERIC MAP (
		width_i => 5,
		width_o => 32
	  )
	  PORT MAP ( 
		i => wire_n11li_i,
		o => wire_n11li_o
	  );
	wire_ni1iii_i <= ( nil00O & nil00l & nil00i & nil01O);
	ni1iii :  oper_decoder
	  GENERIC MAP (
		width_i => 4,
		width_o => 16
	  )
	  PORT MAP ( 
		i => wire_ni1iii_i,
		o => wire_ni1iii_o
	  );
	wire_nii0Ol_i <= ( nil01l & nil01i & nil1OO & nil1Ol);
	nii0Ol :  oper_decoder
	  GENERIC MAP (
		width_i => 4,
		width_o => 16
	  )
	  PORT MAP ( 
		i => wire_nii0Ol_i,
		o => wire_nii0Ol_o
	  );
	wire_nl1OiO_i <= ( nlll0i & nlll1O & nlll1l & nlll1i);
	nl1OiO :  oper_decoder
	  GENERIC MAP (
		width_i => 4,
		width_o => 16
	  )
	  PORT MAP ( 
		i => wire_nl1OiO_i,
		o => wire_nl1OiO_o
	  );
	wire_n100i_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_n10ll_dataout & "0" & "0" & "0" & "0" & "0" & wire_n1O0l_dataout & wire_n00iO_dataout & n0O00l & n0O00O & wire_n0O11l38_w_lg_w_lg_q237w238w & n0O0il & n0O0iO & n0O0li & n0O0ll & wire_n0lOi_dataout & "0" & "0" & "0" & wire_n0Oil_dataout & wire_n0OOi_dataout & "0");
	wire_n100i_sel <= ( nii1i & ni0Ol & ni0Oi & ni0lO & ni0ll);
	n100i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n100i_data,
		o => wire_n100i_o,
		sel => wire_n100i_sel
	  );
	wire_n100l_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_n10lO_dataout & wire_n0O11O36_w_lg_w_lg_q191w192w & wire_n1iii_dataout & wire_n1ill_dataout & wire_n0O10i34_w_lg_w_lg_q186w187w & wire_n1l0l_dataout & wire_n1O0O_dataout & wire_n00li_dataout & wire_w_lg_n0O00l135w & wire_w_lg_n0O00O134w & wire_w_lg_n0O0ii133w & wire_n0O10l32_w_lg_w_lg_q177w178w & wire_n0O10O30_w_lg_w_lg_q174w175w & wire_w_lg_n0O0li130w & wire_w_lg_n0O0ll129w & wire_w_lg_n0O0lO128w & wire_w_lg_n0O0Oi127w & wire_w_lg_n0O0Ol126w & "0" & wire_n0OiO_dataout & wire_n0OOl_dataout & "0");
	wire_n100l_sel <= ( wire_n0O1ii28_w_lg_w_lg_q159w160w & ni0Ol & ni0Oi & ni0lO & ni0ll);
	n100l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n100l_data,
		o => wire_n100l_o,
		sel => wire_n100l_sel
	  );
	wire_n101i_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_n10il_dataout & "1" & "1" & "1" & "1" & wire_n1l0i_dataout & wire_n1O1l_dataout & wire_n000O_dataout & wire_w_lg_n0O00l135w & wire_n0iii_dataout & wire_w_lg_n0O0ii133w & wire_n0iOi_dataout & wire_w_lg_n0O0iO131w & wire_n0l0l_dataout & wire_w_lg_n0O0ll129w & wire_n0llO_dataout & wire_w_lg_n0O0Oi127w & wire_n0O1O_dataout & "0" & wire_n0O0l_dataout & wire_n0Oli_dataout & wire_ni_w_lg_dataout403w);
	wire_n101i_sel <= ( nii1i & ni0Ol & ni0Oi & ni0lO & ni0ll);
	n101i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n101i_data,
		o => wire_n101i_o,
		sel => wire_n101i_sel
	  );
	wire_n101l_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_n10iO_dataout & "0" & "0" & "0" & "0" & "0" & wire_n1O1O_dataout & wire_n00ii_dataout & n0O00l & wire_n0iil_dataout & "0" & wire_n0iOl_dataout & n0O0iO & wire_n0l0O_dataout & "0" & wire_n0lll_dataout & n0O0Oi & wire_n0O0i_dataout & "0" & wire_n0O0O_dataout & wire_n0Oll_dataout & "0");
	wire_n101l_sel <= ( nii1i & ni0Ol & ni0Oi & wire_n0lOOi46_w_lg_w_lg_q339w340w & ni0ll);
	n101l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n101l_data,
		o => wire_n101l_o,
		sel => wire_n101l_sel
	  );
	wire_n101O_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_n0lOOl44_w_lg_w_lg_q314w315w & wire_n1i1i_dataout & wire_n1iii_dataout & wire_n0lOOO42_w_lg_w_lg_q309w310w & wire_n1iOO_dataout & wire_n1l0l_dataout & wire_n1O0i_dataout & wire_n0O11i40_w_lg_w_lg_q303w304w & "1" & "1" & "1" & wire_n0iOO_dataout & wire_w_lg_n0O0iO131w & wire_w_lg_n0O0li130w & wire_w_lg_n0O0ll129w & wire_n0llO_dataout & "1" & "1" & "1" & wire_n0Oii_dataout & wire_n0OlO_dataout & "0");
	wire_n101O_sel <= ( nii1i & ni0Ol & ni0Oi & ni0lO & ni0ll);
	n101O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n101O_data,
		o => wire_n101O_o,
		sel => wire_n101O_sel
	  );
	wire_n11Ol_data <= ( ni00i & ni00i & ni00i & ni00i & ni00i & ni00i & ni00i & ni00i & ni00i & ni00i & wire_n100O_dataout & wire_n10OO_dataout & wire_n1i0O_dataout & wire_n1ili_dataout & wire_n1iOl_dataout & wire_n1l1O_dataout & wire_n1O1i_dataout & wire_n000l_dataout & wire_n0i0i_dataout & wire_n0i0O_dataout & wire_n0ili_dataout & wire_n0ilO_dataout & wire_n0l1l_dataout & wire_n0l0i_dataout & wire_n0lil_dataout & wire_n0lli_dataout & wire_n0lOO_dataout & wire_n0O1l_dataout & ni00i & ni00i & ni00i & ni00i);
	wire_n11Ol_sel <= ( nii1i & ni0Ol & ni0Oi & ni0lO & ni0ll);
	n11Ol :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n11Ol_data,
		o => wire_n11Ol_o,
		sel => wire_n11Ol_sel
	  );
	wire_n11OO_data <= ( ni01l & ni01l & ni01l & ni01l & ni01l & ni01l & ni01l & ni01l & ni01l & ni01l & wire_n10ii_dataout & wire_n10Ol_dataout & wire_n1i0l_dataout & wire_n1iiO_dataout & wire_n1iOi_dataout & wire_n1l1l_dataout & wire_n1lOO_dataout & wire_n000i_dataout & wire_n0i1O_dataout & wire_n0i0l_dataout & wire_n0iiO_dataout & wire_n0ill_dataout & wire_n0l1i_dataout & wire_n0l1O_dataout & wire_n0lii_dataout & wire_n0liO_dataout & wire_n0lOl_dataout & wire_n0O1i_dataout & ni01l & ni01l & ni01l & ni01l);
	wire_n11OO_sel <= ( nii1i & ni0Ol & ni0Oi & ni0lO & ni0ll);
	n11OO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n11OO_data,
		o => wire_n11OO_o,
		sel => wire_n11OO_sel
	  );
	wire_ni1iil_data <= ( "0" & "0" & "0" & n0iO1l & wire_ni1O1i_dataout & n0iOil & wire_ni010O_dataout & n0iOOl & wire_ni000i_dataout & "0" & wire_ni0i1O_dataout & n0l1ll & wire_ni0l1i_dataout & n0l0ii & n0l0Ol & "0");
	wire_ni1iil_sel <= ( nil00O & nil00l & nil00i & nil01O);
	ni1iil :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni1iil_data,
		o => wire_ni1iil_o,
		sel => wire_ni1iil_sel
	  );
	wire_ni1iiO_data <= ( niilOO & niilOO & wire_ni1l1i_dataout & wire_ni1lil_dataout & wire_ni1lOO_dataout & niilOO & niilOO & niilOO & niilOO & niilOO & niilOO & niilOO & niilOO & niilOO & niilOO & niilOO);
	wire_ni1iiO_sel <= ( nil00O & nil00l & nil00i & nil01O);
	ni1iiO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni1iiO_data,
		o => wire_ni1iiO_o,
		sel => wire_ni1iiO_sel
	  );
	wire_ni1ili_data <= ( niiO1i & niiO1i & wire_ni1l1l_dataout & wire_ni1liO_dataout & wire_ni1O1l_dataout & wire_ni1OOl_dataout & wire_ni011l_dataout & wire_ni01Oi_dataout & wire_ni001i_dataout & wire_ni00ll_dataout & wire_ni00Ol_dataout & wire_ni0ili_dataout & wire_ni0iOi_dataout & wire_ni0lil_dataout & wire_ni0Oli_dataout & niiO1i);
	wire_ni1ili_sel <= ( nil00O & nil00l & nil00i & nil01O);
	ni1ili :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni1ili_data,
		o => wire_ni1ili_o,
		sel => wire_ni1ili_sel
	  );
	wire_ni1ill_data <= ( niiO1l & niiO1l & wire_ni1l1O_dataout & wire_ni1lli_dataout & wire_ni1O1O_dataout & wire_ni1OOO_dataout & wire_ni011O_dataout & wire_ni01Ol_dataout & wire_ni001l_dataout & wire_ni00lO_dataout & wire_ni00OO_dataout & wire_ni0ill_dataout & wire_ni0iOl_dataout & wire_ni0liO_dataout & wire_ni0Oll_dataout & niiO1l);
	wire_ni1ill_sel <= ( nil00O & nil00l & nil00i & nil01O);
	ni1ill :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni1ill_data,
		o => wire_ni1ill_o,
		sel => wire_ni1ill_sel
	  );
	wire_ni1ilO_data <= ( "0" & "0" & wire_ni1l0i_dataout & "1" & wire_ni1O0i_dataout & "1" & wire_ni010i_dataout & "1" & wire_ni001O_dataout & "1" & wire_ni0i1i_dataout & "1" & wire_ni0iOO_dataout & wire_ni0lli_dataout & wire_ni0OlO_dataout & wire_nii00i_dataout);
	wire_ni1ilO_sel <= ( nil00O & nil00l & nil00i & nil01O);
	ni1ilO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni1ilO_data,
		o => wire_ni1ilO_o,
		sel => wire_ni1ilO_sel
	  );
	wire_ni1iOi_data <= ( "0" & "0" & wire_ni1l0l_dataout & "0" & "0" & wire_w_lg_n0iOil2133w & wire_ni010l_dataout & "0" & "0" & wire_w_lg_n0l10l2126w & wire_ni0i1l_dataout & "0" & "0" & wire_ni0lll_dataout & wire_ni0OOi_dataout & wire_nii00l_dataout);
	wire_ni1iOi_sel <= ( nil00O & nil00l & nil00i & nil01O);
	ni1iOi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni1iOi_data,
		o => wire_ni1iOi_o,
		sel => wire_ni1iOi_sel
	  );
	wire_ni1iOl_data <= ( "0" & "0" & wire_ni1l0O_dataout & wire_ni1lll_dataout & wire_ni1O0l_dataout & n0iOil & wire_ni010O_dataout & n0iOOl & wire_ni000i_dataout & "1" & "1" & "1" & "1" & wire_ni0llO_dataout & wire_ni0OOl_dataout & wire_nii00O_dataout);
	wire_ni1iOl_sel <= ( nil00O & nil00l & nil00i & nil01O);
	ni1iOl :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni1iOl_data,
		o => wire_ni1iOl_o,
		sel => wire_ni1iOl_sel
	  );
	wire_ni1iOO_data <= ( "0" & "0" & wire_ni1lii_dataout & wire_ni1lll_dataout & wire_ni1O0l_dataout & "1" & "1" & "1" & "1" & n0l10l & wire_ni0i1O_dataout & n0l1ll & wire_ni0l1i_dataout & wire_ni0lOi_dataout & wire_ni0OOO_dataout & wire_nii0ii_dataout);
	wire_ni1iOO_sel <= ( nil00O & nil00l & nil00i & nil01O);
	ni1iOO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni1iOO_data,
		o => wire_ni1iOO_o,
		sel => wire_ni1iOO_sel
	  );
	wire_nii0iO_data <= ( "1" & "1" & "1" & "1" & "0" & "1" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_niOi1l_dataout & "1" & "1");
	wire_nii0iO_sel <= ( nil01l & nil01i & nil1OO & nil1Ol);
	nii0iO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nii0iO_data,
		o => wire_nii0iO_o,
		sel => wire_nii0iO_sel
	  );
	wire_nii0li_data <= ( "1" & "1" & "1" & "0" & "1" & "1" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_niOi1O_dataout & "1" & "1");
	wire_nii0li_sel <= ( nil01l & nil01i & nil1OO & nil1Ol);
	nii0li :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nii0li_data,
		o => wire_nii0li_o,
		sel => wire_nii0li_sel
	  );
	wire_nii0lO_data <= ( "1" & "1" & "1" & "1" & "1" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_niOi0l_dataout & "1" & "1");
	wire_nii0lO_sel <= ( nil01l & nil01i & nil1OO & nil1Ol);
	nii0lO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nii0lO_data,
		o => wire_nii0lO_o,
		sel => wire_nii0lO_sel
	  );
	wire_nii0OO_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "0" & "1" & "0" & "1" & "0" & wire_niOiii_dataout & "1" & "1");
	wire_nii0OO_sel <= ( nil01l & nil01i & nil1OO & nil1Ol);
	nii0OO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nii0OO_data,
		o => wire_nii0OO_o,
		sel => wire_nii0OO_sel
	  );
	wire_niii0i_data <= ( n0OlOi & n0OlOi & n0OlOi & "0" & "0" & "0" & n0OlOi & "0" & "0" & "0" & "0" & "0" & "0" & wire_niOill_dataout & n0OlOi & n0OlOi);
	wire_niii0i_sel <= ( nil01l & nil01i & nil1OO & nil1Ol);
	niii0i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niii0i_data,
		o => wire_niii0i_o,
		sel => wire_niii0i_sel
	  );
	wire_niii0l_data <= ( n0OlOi & n0OlOi & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & wire_niOilO_dataout & n0OlOi & n0OlOi);
	wire_niii0l_sel <= ( nil01l & nil01i & nil1OO & nil1Ol);
	niii0l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niii0l_data,
		o => wire_niii0l_o,
		sel => wire_niii0l_sel
	  );
	wire_niii0O_data <= ( n0OlOi & n0OlOi & n0OlOi & "0" & n0OlOi & "0" & "0" & "0" & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & wire_niOiOi_dataout & n0OlOi & n0OlOi);
	wire_niii0O_sel <= ( nil01l & nil01i & nil1OO & nil1Ol);
	niii0O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niii0O_data,
		o => wire_niii0O_o,
		sel => wire_niii0O_sel
	  );
	wire_niii1i_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "1" & "1" & "0" & "0" & wire_niOiil_dataout & "1" & "1");
	wire_niii1i_sel <= ( nil01l & nil01i & nil1OO & nil1Ol);
	niii1i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niii1i_data,
		o => wire_niii1i_o,
		sel => wire_niii1i_sel
	  );
	wire_niii1l_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "0" & "0" & "0" & wire_niOiiO_dataout & "1" & "1");
	wire_niii1l_sel <= ( nil01l & nil01i & nil1OO & nil1Ol);
	niii1l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niii1l_data,
		o => wire_niii1l_o,
		sel => wire_niii1l_sel
	  );
	wire_niii1O_data <= ( n0OlOi & n0OlOi & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & "0" & "0" & "0" & "0" & "0" & wire_niOili_dataout & n0OlOi & n0OlOi);
	wire_niii1O_sel <= ( nil01l & nil01i & nil1OO & nil1Ol);
	niii1O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niii1O_data,
		o => wire_niii1O_o,
		sel => wire_niii1O_sel
	  );
	wire_niiiii_data <= ( n0OlOi & n0OlOi & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & wire_niOiOl_dataout & n0OlOi & n0OlOi);
	wire_niiiii_sel <= ( nil01l & nil01i & nil1OO & nil1Ol);
	niiiii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niiiii_data,
		o => wire_niiiii_o,
		sel => wire_niiiii_sel
	  );
	wire_niiiil_data <= ( n0OlOi & n0OlOi & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & "0" & "0" & n0OlOi & "0" & n0OlOi & wire_niOiOO_dataout & n0OlOi & n0OlOi);
	wire_niiiil_sel <= ( nil01l & nil01i & nil1OO & nil1Ol);
	niiiil :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niiiil_data,
		o => wire_niiiil_o,
		sel => wire_niiiil_sel
	  );
	wire_niiiiO_data <= ( n0OlOi & n0OlOi & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & "0" & wire_niOl1i_dataout & n0OlOi & n0OlOi);
	wire_niiiiO_sel <= ( nil01l & nil01i & nil1OO & nil1Ol);
	niiiiO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niiiiO_data,
		o => wire_niiiiO_o,
		sel => wire_niiiiO_sel
	  );
	wire_niiili_data <= ( n0OlOi & n0OlOi & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & "0" & "0" & "0" & wire_niOl1l_dataout & n0OlOi & n0OlOi);
	wire_niiili_sel <= ( nil01l & nil01i & nil1OO & nil1Ol);
	niiili :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niiili_data,
		o => wire_niiili_o,
		sel => wire_niiili_sel
	  );
	wire_niiill_data <= ( n0OlOi & n0OlOi & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & "0" & n0OlOi & n0OlOi);
	wire_niiill_sel <= ( nil01l & nil01i & nil1OO & nil1Ol);
	niiill :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niiill_data,
		o => wire_niiill_o,
		sel => wire_niiill_sel
	  );
	wire_nl010i_data <= ( wire_nl01li_dataout & "1" & "1" & "1" & "1" & wire_nl0i0l_dataout & wire_w_lg_n0liOl1002w & wire_nl0l1O_dataout & wire_nl0llO_dataout & wire_nli01O_dataout & wire_nliiOl_dataout & "1" & "1" & wire_nliOiO_dataout & wire_nll11O_dataout & wire_nl_w_lg_dataout1094w);
	wire_nl010i_sel <= ( nlll0i & nlll1O & nlll1l & nlll1i);
	nl010i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nl010i_data,
		o => wire_nl010i_o,
		sel => wire_nl010i_sel
	  );
	wire_nl010l_data <= ( wire_nl01ll_dataout & wire_nl001l_dataout & wire_nl00il_dataout & wire_nl00lO_dataout & wire_nl0i1i_dataout & wire_nl0i0O_dataout & wire_w_lg_n0liOl1002w & wire_nl0l1O_dataout & wire_nl0lOi_dataout & wire_nli00i_dataout & wire_nliiOO_dataout & wire_w_lg_n0llOO984w & "0" & wire_nliOli_dataout & wire_nll10i_dataout & "0");
	wire_nl010l_sel <= ( nlll0i & nlll1O & nlll1l & nlll1i);
	nl010l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nl010l_data,
		o => wire_nl010l_o,
		sel => wire_nl010l_sel
	  );
	wire_nl010O_data <= ( wire_nl01lO_dataout & wire_nl001l_dataout & wire_nl00il_dataout & wire_nl00lO_dataout & wire_nl0i1i_dataout & wire_nl0i0O_dataout & wire_w_lg_n0liOl1002w & wire_nl0l1O_dataout & wire_nl0lOl_dataout & wire_nli00l_dataout & "1" & "1" & "1" & wire_nliOll_dataout & wire_nll10l_dataout & "0");
	wire_nl010O_sel <= ( nlll0i & nlll1O & nlll1l & nlll1i);
	nl010O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nl010O_data,
		o => wire_nl010O_o,
		sel => wire_nl010O_sel
	  );
	wire_nl011i_data <= ( nll0il & wire_nl01Ol_dataout & wire_nl000l_dataout & wire_nl00iO_dataout & wire_nl00Oi_dataout & wire_nl0i1l_dataout & nll0il & nll0il & nll0il & nll0il & nll0il & nll0il & nll0il & nll0il & nll0il & nll0il);
	wire_nl011i_sel <= ( nlll0i & nlll1O & nlll1l & nlll1i);
	nl011i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nl011i_data,
		o => wire_nl011i_o,
		sel => wire_nl011i_sel
	  );
	wire_nl011l_data <= ( wire_nl01il_dataout & wire_nl001i_dataout & wire_nl00ii_dataout & wire_nl00ll_dataout & wire_nl00OO_dataout & wire_nl0i0i_dataout & wire_nl0lil_dataout & wire_nl0l1l_dataout & wire_nl0lll_dataout & wire_nli01l_dataout & wire_nliiOi_dataout & wire_nliOil_dataout & nll0ii & nll0ii & nll0ii & nll0ii);
	wire_nl011l_sel <= ( nlll0i & nlll1O & nlll1l & nlll1i);
	nl011l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nl011l_data,
		o => wire_nl011l_o,
		sel => wire_nl011l_sel
	  );
	wire_nl011O_data <= ( wire_nl01iO_dataout & wire_nl01OO_dataout & wire_nl000O_dataout & wire_nl00li_dataout & wire_nl00Ol_dataout & wire_nl0i1O_dataout & wire_nl0lii_dataout & wire_nl0l1i_dataout & wire_nl0lli_dataout & wire_nli01i_dataout & wire_nliilO_dataout & wire_nliOii_dataout & nll00O & nll00O & nll00O & nll00O);
	wire_nl011O_sel <= ( nlll0i & nlll1O & nlll1l & nlll1i);
	nl011O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nl011O_data,
		o => wire_nl011O_o,
		sel => wire_nl011O_sel
	  );
	wire_nl01ii_data <= ( wire_nl01Oi_dataout & wire_nl001l_dataout & wire_nl00il_dataout & wire_nl00lO_dataout & wire_nl0i1i_dataout & wire_nl0i0O_dataout & "1" & wire_nl0l0i_dataout & wire_nl0lOO_dataout & wire_nli00O_dataout & wire_w_lg_n0llil989w & wire_w_lg_n0llOO984w & "0" & wire_nliOlO_dataout & wire_nll10O_dataout & "0");
	wire_nl01ii_sel <= ( nlll0i & nlll1O & nlll1l & nlll1i);
	nl01ii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nl01ii_data,
		o => wire_nl01ii_o,
		sel => wire_nl01ii_sel
	  );
	wire_n11ii_data <= ( "0" & wire_n1lOi_dataout & wire_n001l_dataout);
	wire_n11ii_sel <= ( n0lOll & wire_n11li_o(15 DOWNTO 14));
	n11ii :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n11ii_data,
		o => wire_n11ii_o,
		sel => wire_n11ii_sel
	  );
	wire_n11il_data <= ( "0" & wire_n1lOl_dataout & wire_n001O_dataout);
	wire_n11il_sel <= ( n0lOll & wire_n11li_o(15 DOWNTO 14));
	n11il :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n11il_data,
		o => wire_n11il_o,
		sel => wire_n11il_sel
	  );
	wire_n11ll_data <= ( ni00l & wire_n10Oi_dataout & wire_n1i0i_dataout & wire_n1iil_dataout & wire_n1ilO_dataout & wire_n1l1i_dataout);
	wire_n11ll_sel <= ( n0lOlO & wire_n11li_o(20 DOWNTO 16));
	n11ll :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_n11ll_data,
		o => wire_n11ll_o,
		sel => wire_n11ll_sel
	  );
	wire_ni1i0l_data <= ( "0" & "1" & wire_ni0OiO_dataout);
	wire_ni1i0l_sel <= ( n0iO1i & wire_ni1iii_o(2 DOWNTO 1));
	ni1i0l :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_ni1i0l_data,
		o => wire_ni1i0l_o,
		sel => wire_ni1i0l_sel
	  );

 END RTL; --stratixiv_hssi_rx_digi_bist_ver
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 98 mux21 49 oper_add 3 oper_selector 7 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_rx_digi_cdr_ctrl IS 
	 PORT 
	 ( 
		 adata	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 adata_valid	:	IN  STD_LOGIC;
		 early_eios	:	OUT  STD_LOGIC;
		 eidle_exit	:	OUT  STD_LOGIC;
		 eiosdetect_int	:	OUT  STD_LOGIC;
		 gen2ngen1	:	IN  STD_LOGIC;
		 gen2ngen1_bundle	:	IN  STD_LOGIC;
		 inferred_rxvalid	:	OUT  STD_LOGIC;
		 ltr	:	OUT  STD_LOGIC;
		 pipe_loopbk	:	IN  STD_LOGIC;
		 pld_ltr	:	IN  STD_LOGIC;
		 rcdr_ctrl_en	:	IN  STD_LOGIC;
		 rcid_en	:	IN  STD_LOGIC;
		 rcvd_clk	:	IN  STD_LOGIC;
		 rindv_rx	:	IN  STD_LOGIC;
		 rmask_count	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 rrxvalid_mask	:	IN  STD_LOGIC;
		 rwait_count	:	IN  STD_LOGIC_VECTOR (7 DOWNTO 0);
		 rxpcs_reset_int	:	IN  STD_LOGIC;
		 sigdet	:	IN  STD_LOGIC
	 ); 
 END stratixiv_hssi_rx_digi_cdr_ctrl;

 ARCHITECTURE RTL OF stratixiv_hssi_rx_digi_cdr_ctrl IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 n0l0O43	:	STD_LOGIC := '0';
	 SIGNAL	 n0l0O44	:	STD_LOGIC := '0';
	 SIGNAL	 n0l1i45	:	STD_LOGIC := '0';
	 SIGNAL	 n0l1i46	:	STD_LOGIC := '0';
	 SIGNAL	 n0lli41	:	STD_LOGIC := '0';
	 SIGNAL	 n0lli42	:	STD_LOGIC := '0';
	 SIGNAL	 n0lOO39	:	STD_LOGIC := '0';
	 SIGNAL	 n0lOO40	:	STD_LOGIC := '0';
	 SIGNAL	 n0O0i35	:	STD_LOGIC := '0';
	 SIGNAL	 n0O0i36	:	STD_LOGIC := '0';
	 SIGNAL	 n0O0l33	:	STD_LOGIC := '0';
	 SIGNAL	 n0O0l34	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O0l34_w_lg_w_lg_q200w201w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O0l34_w_lg_q200w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O0O31	:	STD_LOGIC := '0';
	 SIGNAL	 n0O0O32	:	STD_LOGIC := '0';
	 SIGNAL	 n0O1l37	:	STD_LOGIC := '0';
	 SIGNAL	 n0O1l38	:	STD_LOGIC := '0';
	 SIGNAL	 n0OiO29	:	STD_LOGIC := '0';
	 SIGNAL	 n0OiO30	:	STD_LOGIC := '0';
	 SIGNAL	 n0Oll27	:	STD_LOGIC := '0';
	 SIGNAL	 n0Oll28	:	STD_LOGIC := '0';
	 SIGNAL	 n0OOi25	:	STD_LOGIC := '0';
	 SIGNAL	 n0OOi26	:	STD_LOGIC := '0';
	 SIGNAL	 n0OOO23	:	STD_LOGIC := '0';
	 SIGNAL	 n0OOO24	:	STD_LOGIC := '0';
	 SIGNAL	 ni01i3	:	STD_LOGIC := '0';
	 SIGNAL	 ni01i4	:	STD_LOGIC := '0';
	 SIGNAL  wire_ni01i4_w_lg_w_lg_q4w5w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni01i4_w_lg_q4w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 ni01O1	:	STD_LOGIC := '0';
	 SIGNAL	 ni01O2	:	STD_LOGIC := '0';
	 SIGNAL	 ni10i19	:	STD_LOGIC := '0';
	 SIGNAL	 ni10i20	:	STD_LOGIC := '0';
	 SIGNAL  wire_ni10i20_w_lg_w_lg_q111w112w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni10i20_w_lg_q111w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 ni10l17	:	STD_LOGIC := '0';
	 SIGNAL	 ni10l18	:	STD_LOGIC := '0';
	 SIGNAL	 ni11O21	:	STD_LOGIC := '0';
	 SIGNAL	 ni11O22	:	STD_LOGIC := '0';
	 SIGNAL  wire_ni11O22_w_lg_w_lg_q114w115w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni11O22_w_lg_q114w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 ni1ii15	:	STD_LOGIC := '0';
	 SIGNAL	 ni1ii16	:	STD_LOGIC := '0';
	 SIGNAL	 ni1iO13	:	STD_LOGIC := '0';
	 SIGNAL	 ni1iO14	:	STD_LOGIC := '0';
	 SIGNAL	 ni1lO11	:	STD_LOGIC := '0';
	 SIGNAL	 ni1lO12	:	STD_LOGIC := '0';
	 SIGNAL  wire_ni1lO12_w_lg_w_lg_q22w23w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1lO12_w_lg_q22w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 ni1Oi10	:	STD_LOGIC := '0';
	 SIGNAL  wire_ni1Oi10_w_lg_w_lg_q18w19w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1Oi10_w_lg_q18w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 ni1Oi9	:	STD_LOGIC := '0';
	 SIGNAL	 ni1Ol7	:	STD_LOGIC := '0';
	 SIGNAL	 ni1Ol8	:	STD_LOGIC := '0';
	 SIGNAL  wire_ni1Ol8_w_lg_w_lg_q15w16w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1Ol8_w_lg_q15w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 ni1OO5	:	STD_LOGIC := '0';
	 SIGNAL	 ni1OO6	:	STD_LOGIC := '0';
	 SIGNAL  wire_ni1OO6_w_lg_w_lg_q10w11w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1OO6_w_lg_q10w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n10O	:	STD_LOGIC := '0';
	 SIGNAL	n11O	:	STD_LOGIC := '0';
	 SIGNAL	n1ii	:	STD_LOGIC := '0';
	 SIGNAL	n1il	:	STD_LOGIC := '0';
	 SIGNAL	n1iO	:	STD_LOGIC := '0';
	 SIGNAL	n1li	:	STD_LOGIC := '0';
	 SIGNAL	n1ll	:	STD_LOGIC := '0';
	 SIGNAL	n1lO	:	STD_LOGIC := '0';
	 SIGNAL	n1Oi	:	STD_LOGIC := '0';
	 SIGNAL	n1Ol	:	STD_LOGIC := '0';
	 SIGNAL	n1OO	:	STD_LOGIC := '0';
	 SIGNAL	ni0li	:	STD_LOGIC := '0';
	 SIGNAL	ni0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nii0i	:	STD_LOGIC := '0';
	 SIGNAL	nii0O	:	STD_LOGIC := '0';
	 SIGNAL	niili	:	STD_LOGIC := '0';
	 SIGNAL	niOOO	:	STD_LOGIC := '0';
	 SIGNAL	nl	:	STD_LOGIC := '0';
	 SIGNAL	nl0il	:	STD_LOGIC := '0';
	 SIGNAL	nl0iO	:	STD_LOGIC := '0';
	 SIGNAL	nl0li	:	STD_LOGIC := '0';
	 SIGNAL	nl0ll	:	STD_LOGIC := '0';
	 SIGNAL	nl0lO	:	STD_LOGIC := '0';
	 SIGNAL	nl0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nl0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nl0OO	:	STD_LOGIC := '0';
	 SIGNAL	nl10O	:	STD_LOGIC := '0';
	 SIGNAL	nl11i	:	STD_LOGIC := '0';
	 SIGNAL	nl11l	:	STD_LOGIC := '0';
	 SIGNAL	nl11O	:	STD_LOGIC := '0';
	 SIGNAL	nl1ii	:	STD_LOGIC := '0';
	 SIGNAL	nl1il	:	STD_LOGIC := '0';
	 SIGNAL	nl1iO	:	STD_LOGIC := '0';
	 SIGNAL	nl1li	:	STD_LOGIC := '0';
	 SIGNAL	nl1ll	:	STD_LOGIC := '0';
	 SIGNAL	nli0O	:	STD_LOGIC := '0';
	 SIGNAL	nli1i	:	STD_LOGIC := '0';
	 SIGNAL	nll0l	:	STD_LOGIC := '0';
	 SIGNAL	nll0O	:	STD_LOGIC := '0';
	 SIGNAL	nll1l	:	STD_LOGIC := '0';
	 SIGNAL	nllii	:	STD_LOGIC := '0';
	 SIGNAL	nllil	:	STD_LOGIC := '0';
	 SIGNAL	nlliO	:	STD_LOGIC := '0';
	 SIGNAL	nllli	:	STD_LOGIC := '0';
	 SIGNAL	nllll	:	STD_LOGIC := '0';
	 SIGNAL	nlllO	:	STD_LOGIC := '0';
	 SIGNAL	nlO	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_ni_w_lg_w_lg_nl1li346w347w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nl0iO227w228w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nl1li346w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_n10O250w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_niili224w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_niOOO47w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nl0iO227w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nl11i139w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nl1ii348w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nl1ll241w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nlO226w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nl11O285w286w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nl11O285w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nilil	:	STD_LOGIC := '0';
	 SIGNAL	wire_nilii_PRN	:	STD_LOGIC;
	 SIGNAL	wire_nilii_ENA	:	STD_LOGIC;
	 SIGNAL	niiii	:	STD_LOGIC := '0';
	 SIGNAL	niiil	:	STD_LOGIC := '0';
	 SIGNAL	niiiO	:	STD_LOGIC := '0';
	 SIGNAL	nl10l	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl10i_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nl10i_w_lg_w_lg_w_lg_nl10l321w322w323w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl10i_w_lg_w_lg_nl10l334w335w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl10i_w_lg_w_lg_nl10l321w322w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl10i_w_lg_nl10l334w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl10i_w_lg_nl10l321w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0ll_a	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_n0ll_b	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_gnd	:	STD_LOGIC;
	 SIGNAL  wire_n0ll_o	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nl0ii_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0ii_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0ii_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nlO0O_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO0O_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO0O_o	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_niill_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niill_o	:	STD_LOGIC;
	 SIGNAL  wire_niill_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niiOi_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niiOi_o	:	STD_LOGIC;
	 SIGNAL  wire_niiOi_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niiOO_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_niiOO_o	:	STD_LOGIC;
	 SIGNAL  wire_niiOO_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nil1i_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nil1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nil1i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nil1O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nil1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nil1O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niliO_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_niliO_o	:	STD_LOGIC;
	 SIGNAL  wire_niliO_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nilli_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nilli_o	:	STD_LOGIC;
	 SIGNAL  wire_nilli_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_w_lg_rcid_en196w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0i274w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0l248w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l1l337w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0lOi236w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0Oil195w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rxpcs_reset_int2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0llO262w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rmask_count_range68w69w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rmask_count_range84w85w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rmask_count_range92w93w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rwait_count_range147w148w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rwait_count_range158w159w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rwait_count_range170w171w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rwait_count_range186w187w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  n0ilO :	STD_LOGIC;
	 SIGNAL  n0iOi :	STD_LOGIC;
	 SIGNAL  n0iOl :	STD_LOGIC;
	 SIGNAL  n0iOO :	STD_LOGIC;
	 SIGNAL  n0l0i :	STD_LOGIC;
	 SIGNAL  n0l0l :	STD_LOGIC;
	 SIGNAL  n0l1l :	STD_LOGIC;
	 SIGNAL  n0l1O :	STD_LOGIC;
	 SIGNAL  n0lil :	STD_LOGIC;
	 SIGNAL  n0liO :	STD_LOGIC;
	 SIGNAL  n0llO :	STD_LOGIC;
	 SIGNAL  n0lOi :	STD_LOGIC;
	 SIGNAL  n0lOl :	STD_LOGIC;
	 SIGNAL  n0Oil :	STD_LOGIC;
	 SIGNAL  ni01l :	STD_LOGIC;
	 SIGNAL  ni11l :	STD_LOGIC;
	 SIGNAL  ni1ll :	STD_LOGIC;
	 SIGNAL  wire_w_rmask_count_range68w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rmask_count_range84w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rmask_count_range92w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rwait_count_range147w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rwait_count_range158w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rwait_count_range170w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rwait_count_range186w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_gnd <= '0';
	wire_w_lg_rcid_en196w(0) <= rcid_en AND wire_w_lg_n0Oil195w(0);
	wire_w_lg_n0l0i274w(0) <= NOT n0l0i;
	wire_w_lg_n0l0l248w(0) <= NOT n0l0l;
	wire_w_lg_n0l1l337w(0) <= NOT n0l1l;
	wire_w_lg_n0lOi236w(0) <= NOT n0lOi;
	wire_w_lg_n0Oil195w(0) <= NOT n0Oil;
	wire_w_lg_rxpcs_reset_int2w(0) <= NOT rxpcs_reset_int;
	wire_w_lg_n0llO262w(0) <= n0llO OR n0lOi;
	wire_w_lg_w_rmask_count_range68w69w(0) <= wire_w_rmask_count_range68w(0) XOR n1iO;
	wire_w_lg_w_rmask_count_range84w85w(0) <= wire_w_rmask_count_range84w(0) XOR n1lO;
	wire_w_lg_w_rmask_count_range92w93w(0) <= wire_w_rmask_count_range92w(0) XOR n1Oi;
	wire_w_lg_w_rwait_count_range147w148w(0) <= wire_w_rwait_count_range147w(0) XOR nll1l;
	wire_w_lg_w_rwait_count_range158w159w(0) <= wire_w_rwait_count_range158w(0) XOR nllii;
	wire_w_lg_w_rwait_count_range170w171w(0) <= wire_w_rwait_count_range170w(0) XOR nlliO;
	wire_w_lg_w_rwait_count_range186w187w(0) <= wire_w_rwait_count_range186w(0) XOR nlllO;
	early_eios <= wire_nli1O_dataout;
	eidle_exit <= niOOO;
	eiosdetect_int <= nii0i;
	inferred_rxvalid <= wire_nli1l_dataout;
	ltr <= wire_nliii_dataout;
	n0ilO <= (((((((((adata(0) AND adata(1)) AND (NOT adata(2))) AND (NOT adata(3))) AND (NOT adata(4))) AND (NOT adata(5))) AND (NOT adata(6))) AND adata(7)) AND (NOT adata(8))) AND adata(9));
	n0iOi <= ((((((((((NOT adata(0)) AND (NOT adata(1))) AND adata(2)) AND adata(3)) AND adata(4)) AND adata(5)) AND adata(6)) AND (NOT adata(7))) AND adata(8)) AND (NOT adata(9)));
	n0iOl <= (((((((((adata(0) AND adata(1)) AND (NOT adata(2))) AND (NOT adata(3))) AND (NOT adata(4))) AND (NOT adata(5))) AND adata(6)) AND adata(7)) AND (NOT adata(8))) AND (NOT adata(9)));
	n0iOO <= ((((((((((NOT adata(0)) AND (NOT adata(1))) AND adata(2)) AND adata(3)) AND adata(4)) AND adata(5)) AND (NOT adata(6))) AND (NOT adata(7))) AND adata(8)) AND adata(9));
	n0l0i <= (nl0iO AND nll0l);
	n0l0l <= ((wire_nii1i_dataout AND n0Oil) AND (n0l0O44 XOR n0l0O43));
	n0l1l <= ((wire_ni_w_lg_w_lg_nl1li346w347w(0) AND wire_ni_w_lg_nl1ii348w(0)) AND nl10O);
	n0l1O <= (((nl11l OR nl11i) OR niOOO) OR niili);
	n0lil <= (n0liO OR (wire_nii1i_dataout AND wire_ni_w_lg_nl1ll241w(0)));
	n0liO <= ((wire_ni_w_lg_nlO226w(0) AND wire_ni_w_lg_nl0iO227w(0)) AND (n0lli42 XOR n0lli41));
	n0llO <= (wire_nii1i_dataout AND ni0li);
	n0lOi <= (wire_nii1i_dataout AND ni0Oi);
	n0lOl <= ((wire_ni_w_lg_nlO226w(0) AND (wire_ni_w_lg_w_lg_nl0iO227w228w(0) AND (n0O1l38 XOR n0O1l37))) AND (n0lOO40 XOR n0lOO39));
	n0Oil <= (nlO AND nl1ll);
	ni01l <= '1';
	ni11l <= ((((((((NOT (wire_w_lg_w_rwait_count_range147w148w(0) XOR (NOT (n0OOO24 XOR n0OOO23)))) AND (NOT (rwait_count(1) XOR nll0O))) AND (NOT (wire_w_lg_w_rwait_count_range158w159w(0) XOR (NOT (n0OOi26 XOR n0OOi25))))) AND (NOT (rwait_count(3) XOR nllil))) AND (NOT (wire_w_lg_w_rwait_count_range170w171w(0) XOR (NOT (n0Oll28 XOR n0Oll27))))) AND (NOT (rwait_count(5) XOR nllli))) AND (NOT (rwait_count(6) XOR nllll))) AND (NOT (wire_w_lg_w_rwait_count_range186w187w(0) XOR (NOT (n0OiO30 XOR n0OiO29)))));
	ni1ll <= ((((((((((NOT (rmask_count(0) XOR n11O)) AND (NOT (rmask_count(1) XOR n1ii))) AND (NOT (rmask_count(2) XOR n1il))) AND (NOT (wire_w_lg_w_rmask_count_range68w69w(0) XOR (NOT (ni1iO14 XOR ni1iO13))))) AND (NOT (rmask_count(4) XOR n1li))) AND (NOT (rmask_count(5) XOR n1ll))) AND (NOT (wire_w_lg_w_rmask_count_range84w85w(0) XOR (NOT (ni1ii16 XOR ni1ii15))))) AND (NOT (wire_w_lg_w_rmask_count_range92w93w(0) XOR (NOT (ni10l18 XOR ni10l17))))) AND (NOT (rmask_count(8) XOR n1Ol))) AND (NOT (rmask_count(9) XOR n1OO)));
	wire_w_rmask_count_range68w(0) <= rmask_count(3);
	wire_w_rmask_count_range84w(0) <= rmask_count(6);
	wire_w_rmask_count_range92w(0) <= rmask_count(7);
	wire_w_rwait_count_range147w(0) <= rwait_count(0);
	wire_w_rwait_count_range158w(0) <= rwait_count(2);
	wire_w_rwait_count_range170w(0) <= rwait_count(4);
	wire_w_rwait_count_range186w(0) <= rwait_count(7);
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0l0O43 <= n0l0O44;
		END IF;
		if (now = 0 ns) then
			n0l0O43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0l0O44 <= n0l0O43;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0l1i45 <= n0l1i46;
		END IF;
		if (now = 0 ns) then
			n0l1i45 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0l1i46 <= n0l1i45;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0lli41 <= n0lli42;
		END IF;
		if (now = 0 ns) then
			n0lli41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0lli42 <= n0lli41;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0lOO39 <= n0lOO40;
		END IF;
		if (now = 0 ns) then
			n0lOO39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0lOO40 <= n0lOO39;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0O0i35 <= n0O0i36;
		END IF;
		if (now = 0 ns) then
			n0O0i35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0O0i36 <= n0O0i35;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0O0l33 <= n0O0l34;
		END IF;
		if (now = 0 ns) then
			n0O0l33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0O0l34 <= n0O0l33;
		END IF;
	END PROCESS;
	wire_n0O0l34_w_lg_w_lg_q200w201w(0) <= wire_n0O0l34_w_lg_q200w(0) AND nl10O;
	wire_n0O0l34_w_lg_q200w(0) <= n0O0l34 XOR n0O0l33;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0O0O31 <= n0O0O32;
		END IF;
		if (now = 0 ns) then
			n0O0O31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0O0O32 <= n0O0O31;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0O1l37 <= n0O1l38;
		END IF;
		if (now = 0 ns) then
			n0O1l37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0O1l38 <= n0O1l37;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0OiO29 <= n0OiO30;
		END IF;
		if (now = 0 ns) then
			n0OiO29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0OiO30 <= n0OiO29;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0Oll27 <= n0Oll28;
		END IF;
		if (now = 0 ns) then
			n0Oll27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0Oll28 <= n0Oll27;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0OOi25 <= n0OOi26;
		END IF;
		if (now = 0 ns) then
			n0OOi25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0OOi26 <= n0OOi25;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0OOO23 <= n0OOO24;
		END IF;
		if (now = 0 ns) then
			n0OOO23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN n0OOO24 <= n0OOO23;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni01i3 <= ni01i4;
		END IF;
		if (now = 0 ns) then
			ni01i3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni01i4 <= ni01i3;
		END IF;
	END PROCESS;
	wire_ni01i4_w_lg_w_lg_q4w5w(0) <= wire_ni01i4_w_lg_q4w(0) AND n11O;
	wire_ni01i4_w_lg_q4w(0) <= ni01i4 XOR ni01i3;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni01O1 <= ni01O2;
		END IF;
		if (now = 0 ns) then
			ni01O1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni01O2 <= ni01O1;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni10i19 <= ni10i20;
		END IF;
		if (now = 0 ns) then
			ni10i19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni10i20 <= ni10i19;
		END IF;
	END PROCESS;
	wire_ni10i20_w_lg_w_lg_q111w112w(0) <= wire_ni10i20_w_lg_q111w(0) AND nllii;
	wire_ni10i20_w_lg_q111w(0) <= ni10i20 XOR ni10i19;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni10l17 <= ni10l18;
		END IF;
		if (now = 0 ns) then
			ni10l17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni10l18 <= ni10l17;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni11O21 <= ni11O22;
		END IF;
		if (now = 0 ns) then
			ni11O21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni11O22 <= ni11O21;
		END IF;
	END PROCESS;
	wire_ni11O22_w_lg_w_lg_q114w115w(0) <= wire_ni11O22_w_lg_q114w(0) AND nllil;
	wire_ni11O22_w_lg_q114w(0) <= ni11O22 XOR ni11O21;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni1ii15 <= ni1ii16;
		END IF;
		if (now = 0 ns) then
			ni1ii15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni1ii16 <= ni1ii15;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni1iO13 <= ni1iO14;
		END IF;
		if (now = 0 ns) then
			ni1iO13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni1iO14 <= ni1iO13;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni1lO11 <= ni1lO12;
		END IF;
		if (now = 0 ns) then
			ni1lO11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni1lO12 <= ni1lO11;
		END IF;
	END PROCESS;
	wire_ni1lO12_w_lg_w_lg_q22w23w(0) <= wire_ni1lO12_w_lg_q22w(0) AND n1OO;
	wire_ni1lO12_w_lg_q22w(0) <= ni1lO12 XOR ni1lO11;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni1Oi10 <= ni1Oi9;
		END IF;
	END PROCESS;
	wire_ni1Oi10_w_lg_w_lg_q18w19w(0) <= wire_ni1Oi10_w_lg_q18w(0) AND n1Oi;
	wire_ni1Oi10_w_lg_q18w(0) <= ni1Oi10 XOR ni1Oi9;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni1Oi9 <= ni1Oi10;
		END IF;
		if (now = 0 ns) then
			ni1Oi9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni1Ol7 <= ni1Ol8;
		END IF;
		if (now = 0 ns) then
			ni1Ol7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni1Ol8 <= ni1Ol7;
		END IF;
	END PROCESS;
	wire_ni1Ol8_w_lg_w_lg_q15w16w(0) <= wire_ni1Ol8_w_lg_q15w(0) AND n1lO;
	wire_ni1Ol8_w_lg_q15w(0) <= ni1Ol8 XOR ni1Ol7;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni1OO5 <= ni1OO6;
		END IF;
		if (now = 0 ns) then
			ni1OO5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN ni1OO6 <= ni1OO5;
		END IF;
	END PROCESS;
	wire_ni1OO6_w_lg_w_lg_q10w11w(0) <= wire_ni1OO6_w_lg_q10w(0) AND n1iO;
	wire_ni1OO6_w_lg_q10w(0) <= ni1OO6 XOR ni1OO5;
	PROCESS (rcvd_clk, wire_ni_CLRN)
	BEGIN
		IF (wire_ni_CLRN = '0') THEN
				n10O <= '0';
				n11O <= '0';
				n1ii <= '0';
				n1il <= '0';
				n1iO <= '0';
				n1li <= '0';
				n1ll <= '0';
				n1lO <= '0';
				n1Oi <= '0';
				n1Ol <= '0';
				n1OO <= '0';
				ni0li <= '0';
				ni0Oi <= '0';
				nii0i <= '0';
				nii0O <= '0';
				niili <= '0';
				niOOO <= '0';
				nl <= '0';
				nl0il <= '0';
				nl0iO <= '0';
				nl0li <= '0';
				nl0ll <= '0';
				nl0lO <= '0';
				nl0Oi <= '0';
				nl0Ol <= '0';
				nl0OO <= '0';
				nl10O <= '0';
				nl11i <= '0';
				nl11l <= '0';
				nl11O <= '0';
				nl1ii <= '0';
				nl1il <= '0';
				nl1iO <= '0';
				nl1li <= '0';
				nl1ll <= '0';
				nli0O <= '0';
				nli1i <= '0';
				nll0l <= '0';
				nll0O <= '0';
				nll1l <= '0';
				nllii <= '0';
				nllil <= '0';
				nlliO <= '0';
				nllli <= '0';
				nllll <= '0';
				nlllO <= '0';
				nlO <= '0';
		ELSIF (rcvd_clk = '1' AND rcvd_clk'event) THEN
				n10O <= wire_n10i_dataout;
				n11O <= wire_n01i_dataout;
				n1ii <= wire_n01l_dataout;
				n1il <= wire_n01O_dataout;
				n1iO <= wire_n00i_dataout;
				n1li <= wire_n00l_dataout;
				n1ll <= wire_n00O_dataout;
				n1lO <= wire_n0ii_dataout;
				n1Oi <= wire_n0il_dataout;
				n1Ol <= wire_n0iO_dataout;
				n1OO <= wire_n0li_dataout;
				ni0li <= wire_ni0ll_dataout;
				ni0Oi <= ni0li;
				nii0i <= nii0O;
				nii0O <= wire_nil0l_dataout;
				niili <= wire_niill_o;
				niOOO <= wire_niiOi_o;
				nl <= wire_nO_dataout;
				nl0il <= pipe_loopbk;
				nl0iO <= nl0li;
				nl0li <= nl0ll;
				nl0ll <= nl0lO;
				nl0lO <= nl0Oi;
				nl0Oi <= nl0Ol;
				nl0Ol <= nl0OO;
				nl0OO <= sigdet;
				nl10O <= wire_nl1lO_dataout;
				nl11i <= wire_niiOO_o;
				nl11l <= wire_nil1i_o;
				nl11O <= wire_nil1l_dataout;
				nl1ii <= wire_nl1Oi_dataout;
				nl1il <= wire_nl1Ol_dataout;
				nl1iO <= wire_nl1OO_dataout;
				nl1li <= wire_nl01i_dataout;
				nl1ll <= nl0il;
				nli0O <= wire_niliO_o;
				nli1i <= wire_nilli_o;
				nll0l <= wire_nll1O_dataout;
				nll0O <= wire_nllOl_dataout;
				nll1l <= wire_nllOi_dataout;
				nllii <= wire_nllOO_dataout;
				nllil <= wire_nlO1i_dataout;
				nlliO <= wire_nlO1l_dataout;
				nllli <= wire_nlO1O_dataout;
				nllll <= wire_nlO0i_dataout;
				nlllO <= wire_nlO0l_dataout;
				nlO <= nl;
		END IF;
	END PROCESS;
	wire_ni_CLRN <= ((ni01O2 XOR ni01O1) AND wire_w_lg_rxpcs_reset_int2w(0));
	wire_ni_w_lg_w_lg_nl1li346w347w(0) <= wire_ni_w_lg_nl1li346w(0) AND nl1il;
	wire_ni_w_lg_w_lg_nl0iO227w228w(0) <= wire_ni_w_lg_nl0iO227w(0) AND nilil;
	wire_ni_w_lg_nl1li346w(0) <= nl1li AND nl1iO;
	wire_ni_w_lg_n10O250w(0) <= NOT n10O;
	wire_ni_w_lg_niili224w(0) <= NOT niili;
	wire_ni_w_lg_niOOO47w(0) <= NOT niOOO;
	wire_ni_w_lg_nl0iO227w(0) <= NOT nl0iO;
	wire_ni_w_lg_nl11i139w(0) <= NOT nl11i;
	wire_ni_w_lg_nl1ii348w(0) <= NOT nl1ii;
	wire_ni_w_lg_nl1ll241w(0) <= NOT nl1ll;
	wire_ni_w_lg_nlO226w(0) <= NOT nlO;
	wire_ni_w_lg_w_lg_nl11O285w286w(0) <= wire_ni_w_lg_nl11O285w(0) OR niili;
	wire_ni_w_lg_nl11O285w(0) <= nl11O OR nl11i;
	PROCESS (rcvd_clk, wire_nilii_PRN, rxpcs_reset_int)
	BEGIN
		IF (wire_nilii_PRN = '0') THEN
				nilil <= '1';
		ELSIF (rxpcs_reset_int = '1') THEN
				nilil <= '0';
		ELSIF (rcvd_clk = '1' AND rcvd_clk'event) THEN
			IF (wire_nilii_ENA = '1') THEN
				nilil <= ni01l;
			END IF;
		END IF;
	END PROCESS;
	wire_nilii_ENA <= (nl0li AND wire_ni_w_lg_nl0iO227w(0));
	wire_nilii_PRN <= (n0l1i46 XOR n0l1i45);
	PROCESS (rcvd_clk, rxpcs_reset_int, wire_nl10i_CLRN)
	BEGIN
		IF (rxpcs_reset_int = '1') THEN
				niiii <= '1';
				niiil <= '1';
				niiiO <= '1';
				nl10l <= '1';
		ELSIF (wire_nl10i_CLRN = '0') THEN
				niiii <= '0';
				niiil <= '0';
				niiiO <= '0';
				nl10l <= '0';
		ELSIF (rcvd_clk = '1' AND rcvd_clk'event) THEN
				niiii <= niiil;
				niiil <= niiiO;
				niiiO <= (NOT (nl11i OR niOOO));
				nl10l <= wire_nil1O_o;
		END IF;
		if (now = 0 ns) then
			niiii <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			niiil <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			niiiO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl10l <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nl10i_CLRN <= (n0O0i36 XOR n0O0i35);
	wire_nl10i_w_lg_w_lg_w_lg_nl10l321w322w323w(0) <= wire_nl10i_w_lg_w_lg_nl10l321w322w(0) OR niili;
	wire_nl10i_w_lg_w_lg_nl10l334w335w(0) <= wire_nl10i_w_lg_nl10l334w(0) OR niOOO;
	wire_nl10i_w_lg_w_lg_nl10l321w322w(0) <= wire_nl10i_w_lg_nl10l321w(0) OR nl11l;
	wire_nl10i_w_lg_nl10l334w(0) <= nl10l OR nl11i;
	wire_nl10i_w_lg_nl10l321w(0) <= nl10l OR nl11O;
	wire_n00i_dataout <= wire_n0ll_o(3) AND NOT(wire_ni_w_lg_niOOO47w(0));
	wire_n00l_dataout <= wire_n0ll_o(4) AND NOT(wire_ni_w_lg_niOOO47w(0));
	wire_n00O_dataout <= wire_n0ll_o(5) AND NOT(wire_ni_w_lg_niOOO47w(0));
	wire_n01i_dataout <= wire_n0ll_o(0) AND NOT(wire_ni_w_lg_niOOO47w(0));
	wire_n01l_dataout <= wire_n0ll_o(1) AND NOT(wire_ni_w_lg_niOOO47w(0));
	wire_n01O_dataout <= wire_n0ll_o(2) AND NOT(wire_ni_w_lg_niOOO47w(0));
	wire_n0ii_dataout <= wire_n0ll_o(6) AND NOT(wire_ni_w_lg_niOOO47w(0));
	wire_n0il_dataout <= wire_n0ll_o(7) AND NOT(wire_ni_w_lg_niOOO47w(0));
	wire_n0iO_dataout <= wire_n0ll_o(8) AND NOT(wire_ni_w_lg_niOOO47w(0));
	wire_n0li_dataout <= wire_n0ll_o(9) AND NOT(wire_ni_w_lg_niOOO47w(0));
	wire_n10i_dataout <= wire_n10l_dataout AND NOT(wire_ni_w_lg_niOOO47w(0));
	wire_n10l_dataout <= n10O OR ni1ll;
	wire_ni0ll_dataout <= adata_valid AND (n0iOi OR n0ilO);
	wire_nii1i_dataout <= adata_valid AND (n0iOO OR n0iOl);
	wire_nil0l_dataout <= wire_nii1i_dataout AND (nl11O OR nl11l);
	wire_nil1l_dataout <= wire_niOil_dataout AND nl10l;
	wire_nilOi_dataout <= wire_ni_w_lg_n10O250w(0) AND NOT(n0liO);
	wire_nilOl_dataout <= n10O AND NOT(n0liO);
	wire_niO1i_dataout <= wire_w_lg_n0l0l248w(0) AND NOT(n0lil);
	wire_niO1l_dataout <= n0l0l AND NOT(n0lil);
	wire_niOii_dataout <= wire_niOli_dataout AND NOT(n0lOl);
	wire_niOil_dataout <= n0llO AND NOT(n0lOl);
	wire_niOiO_dataout <= wire_niOll_dataout AND NOT(n0lOl);
	wire_niOli_dataout <= n0lOi AND NOT(n0llO);
	wire_niOll_dataout <= wire_w_lg_n0lOi236w(0) AND NOT(n0llO);
	wire_nl00i_dataout <= wire_nl0ii_o(2) WHEN niili = '1'  ELSE nl1il;
	wire_nl00l_dataout <= wire_nl0ii_o(3) WHEN niili = '1'  ELSE nl1iO;
	wire_nl00O_dataout <= wire_nl0ii_o(4) WHEN niili = '1'  ELSE nl1li;
	wire_nl01i_dataout <= wire_nl00O_dataout AND NOT(wire_ni_w_lg_niili224w(0));
	wire_nl01l_dataout <= wire_nl0ii_o(0) WHEN niili = '1'  ELSE nl10O;
	wire_nl01O_dataout <= wire_nl0ii_o(1) WHEN niili = '1'  ELSE nl1ii;
	wire_nl1lO_dataout <= wire_nl01l_dataout AND NOT(wire_ni_w_lg_niili224w(0));
	wire_nl1Oi_dataout <= wire_nl01O_dataout AND NOT(wire_ni_w_lg_niili224w(0));
	wire_nl1Ol_dataout <= wire_nl00i_dataout AND NOT(wire_ni_w_lg_niili224w(0));
	wire_nl1OO_dataout <= wire_nl00l_dataout AND NOT(wire_ni_w_lg_niili224w(0));
	wire_nli1l_dataout <= niiii OR NOT(rrxvalid_mask);
	wire_nli1O_dataout <= nli1i AND (wire_w_lg_rcid_en196w(0) AND (n0O0O32 XOR n0O0O31));
	wire_nliii_dataout <= nli0O WHEN rcdr_ctrl_en = '1'  ELSE pld_ltr;
	wire_nll0i_dataout <= nll0l OR ni11l;
	wire_nll1O_dataout <= wire_nll0i_dataout AND NOT(wire_ni_w_lg_nl11i139w(0));
	wire_nllOi_dataout <= wire_nlO0O_o(0) AND NOT(wire_ni_w_lg_nl11i139w(0));
	wire_nllOl_dataout <= wire_nlO0O_o(1) AND NOT(wire_ni_w_lg_nl11i139w(0));
	wire_nllOO_dataout <= wire_nlO0O_o(2) AND NOT(wire_ni_w_lg_nl11i139w(0));
	wire_nlO0i_dataout <= wire_nlO0O_o(6) AND NOT(wire_ni_w_lg_nl11i139w(0));
	wire_nlO0l_dataout <= wire_nlO0O_o(7) AND NOT(wire_ni_w_lg_nl11i139w(0));
	wire_nlO1i_dataout <= wire_nlO0O_o(3) AND NOT(wire_ni_w_lg_nl11i139w(0));
	wire_nlO1l_dataout <= wire_nlO0O_o(4) AND NOT(wire_ni_w_lg_nl11i139w(0));
	wire_nlO1O_dataout <= wire_nlO0O_o(5) AND NOT(wire_ni_w_lg_nl11i139w(0));
	wire_nO_dataout <= gen2ngen1 WHEN rindv_rx = '1'  ELSE gen2ngen1_bundle;
	wire_n0ll_a <= ( wire_ni1lO12_w_lg_w_lg_q22w23w & n1Ol & wire_ni1Oi10_w_lg_w_lg_q18w19w & wire_ni1Ol8_w_lg_w_lg_q15w16w & n1ll & n1li & wire_ni1OO6_w_lg_w_lg_q10w11w & n1il & n1ii & wire_ni01i4_w_lg_w_lg_q4w5w);
	wire_n0ll_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	n0ll :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 10,
		width_b => 10,
		width_o => 10
	  )
	  PORT MAP ( 
		a => wire_n0ll_a,
		b => wire_n0ll_b,
		cin => wire_gnd,
		o => wire_n0ll_o
	  );
	wire_nl0ii_a <= ( nl1li & nl1iO & nl1il & nl1ii & wire_n0O0l34_w_lg_w_lg_q200w201w);
	wire_nl0ii_b <= ( "0" & "0" & "0" & "0" & "1");
	nl0ii :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_nl0ii_a,
		b => wire_nl0ii_b,
		cin => wire_gnd,
		o => wire_nl0ii_o
	  );
	wire_nlO0O_a <= ( nlllO & nllll & nllli & nlliO & wire_ni11O22_w_lg_w_lg_q114w115w & wire_ni10i20_w_lg_w_lg_q111w112w & nll0O & nll1l);
	wire_nlO0O_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	nlO0O :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8,
		width_o => 8
	  )
	  PORT MAP ( 
		a => wire_nlO0O_a,
		b => wire_nlO0O_b,
		cin => wire_gnd,
		o => wire_nlO0O_o
	  );
	wire_niill_data <= ( "0" & wire_niO1l_dataout & wire_niO1l_dataout & wire_w_lg_n0l1l337w);
	wire_niill_sel <= ( wire_nl10i_w_lg_w_lg_nl10l334w335w & nl11O & nl11l & niili);
	niill :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niill_data,
		o => wire_niill_o,
		sel => wire_niill_sel
	  );
	wire_niiOi_data <= ( "0" & n0l0i & wire_nilOi_dataout);
	wire_niiOi_sel <= ( wire_nl10i_w_lg_w_lg_w_lg_nl10l321w322w323w & nl11i & niOOO);
	niiOi :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niiOi_data,
		o => wire_niiOi_o,
		sel => wire_niiOi_sel
	  );
	wire_niiOO_data <= ( n0lOl & n0lil & n0lil & wire_w_lg_n0l0i274w & n0liO & n0l1l);
	wire_niiOO_sel <= ( nl10l & nl11O & nl11l & nl11i & niOOO & niili);
	niiOO :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_niiOO_data,
		o => wire_niiOO_o,
		sel => wire_niiOO_sel
	  );
	wire_nil1i_data <= ( wire_niOii_dataout & wire_niO1i_dataout & "0");
	wire_nil1i_sel <= ( nl10l & nl11O & n0l1O);
	nil1i :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nil1i_data,
		o => wire_nil1i_o,
		sel => wire_nil1i_sel
	  );
	wire_nil1O_data <= ( wire_niOiO_dataout & "0" & wire_niO1i_dataout & wire_nilOl_dataout);
	wire_nil1O_sel <= ( nl10l & wire_ni_w_lg_w_lg_nl11O285w286w & nl11l & niOOO);
	nil1O :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nil1O_data,
		o => wire_nil1O_o,
		sel => wire_nil1O_sel
	  );
	wire_niliO_data <= ( n0lOl & n0lil & n0lil & wire_w_lg_n0l0i274w & n0liO & n0l1l);
	wire_niliO_sel <= ( nl10l & nl11O & nl11l & nl11i & niOOO & niili);
	niliO :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_niliO_data,
		o => wire_niliO_o,
		sel => wire_niliO_sel
	  );
	wire_nilli_data <= ( wire_w_lg_n0llO262w & wire_niO1i_dataout & "0");
	wire_nilli_sel <= ( nl10l & nl11O & n0l1O);
	nilli :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nilli_data,
		o => wire_nilli_o,
		sel => wire_nilli_sel
	  );

 END RTL; --stratixiv_hssi_rx_digi_cdr_ctrl
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 529 mux21 1169 oper_add 22 oper_decoder 15 oper_less_than 18 oper_mux 4 stratixiv_hssi_rx_digis_ram20x16_syn 2 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_rx_digi_comp_chnl_top IS 
	 PORT 
	 ( 
		 align_status	:	IN  STD_LOGIC;
		 align_status_sync	:	OUT  STD_LOGIC;
		 align_status_sync_0	:	IN  STD_LOGIC;
		 align_status_sync_2	:	IN  STD_LOGIC;
		 audi	:	IN  STD_LOGIC_VECTOR (13 DOWNTO 0);
		 audi_pre	:	IN  STD_LOGIC_VECTOR (13 DOWNTO 0);
		 cg_comp_rd_d_ch0	:	IN  STD_LOGIC;
		 cg_comp_rd_d_ch1	:	IN  STD_LOGIC;
		 cg_comp_rd_d_ch2	:	IN  STD_LOGIC;
		 cg_comp_rd_d_ch3	:	IN  STD_LOGIC;
		 cg_comp_rd_d_out	:	OUT  STD_LOGIC;
		 cg_comp_wr_ch0	:	IN  STD_LOGIC;
		 cg_comp_wr_ch1	:	IN  STD_LOGIC;
		 cg_comp_wr_ch2	:	IN  STD_LOGIC;
		 cg_comp_wr_ch3	:	IN  STD_LOGIC;
		 cg_comp_wr_out	:	OUT  STD_LOGIC;
		 clk_1	:	IN  STD_LOGIC;
		 clk_2	:	IN  STD_LOGIC;
		 cmpfifourst	:	IN  STD_LOGIC;
		 comp_curr_st	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 cudi	:	OUT  STD_LOGIC_VECTOR (31 DOWNTO 0);
		 cudi_valid	:	OUT  STD_LOGIC;
		 del_cond_met_0	:	IN  STD_LOGIC;
		 del_cond_met_out	:	OUT  STD_LOGIC;
		 dskwclksel	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 fifo_cnt	:	OUT  STD_LOGIC_VECTOR (4 DOWNTO 0);
		 fifo_ovr_0	:	IN  STD_LOGIC;
		 fifo_ovr_out	:	OUT  STD_LOGIC;
		 fifo_rd_in_comp_0	:	IN  STD_LOGIC;
		 fifo_rd_in_comp_2	:	IN  STD_LOGIC;
		 fifo_rd_out_comp	:	OUT  STD_LOGIC;
		 gen2ngen1	:	IN  STD_LOGIC;
		 gen2ngen1_bundle	:	IN  STD_LOGIC;
		 hard_reset	:	IN  STD_LOGIC;
		 inferred_rxvalid	:	IN  STD_LOGIC;
		 insert_incomplete_0	:	IN  STD_LOGIC;
		 insert_incomplete_out	:	OUT  STD_LOGIC;
		 is_lane0	:	IN  STD_LOGIC;
		 latency_comp_0	:	IN  STD_LOGIC;
		 latency_comp_out	:	OUT  STD_LOGIC;
		 rauto_speed_ena	:	IN  STD_LOGIC;
		 rclkcmpinsertpad	:	IN  STD_LOGIC;
		 rclkcmpsq1n	:	IN  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 rclkcmpsq1p	:	IN  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 rclkcmpsqmd	:	IN  STD_LOGIC;
		 rcmpfifourst	:	IN  STD_LOGIC;
		 rdel_threshold	:	IN  STD_LOGIC_VECTOR (4 DOWNTO 0);
		 rdenable	:	IN  STD_LOGIC;
		 rdfifo_almost_empty	:	OUT  STD_LOGIC;
		 rdfifo_almost_full	:	OUT  STD_LOGIC;
		 rdfifo_empty	:	OUT  STD_LOGIC;
		 rdfifo_full	:	OUT  STD_LOGIC;
		 rdwidth_rx	:	IN  STD_LOGIC;
		 rempty_threshold	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 rev_loop_data	:	OUT  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 rfreq_sel	:	IN  STD_LOGIC;
		 rfull_threshold	:	IN  STD_LOGIC_VECTOR (4 DOWNTO 0);
		 rgenericfifo	:	IN  STD_LOGIC;
		 rindv_rx	:	IN  STD_LOGIC;
		 rins_threshold	:	IN  STD_LOGIC_VECTOR (4 DOWNTO 0);
		 rmatchen	:	IN  STD_LOGIC;
		 rrx_pipe_enable	:	IN  STD_LOGIC;
		 rskpsetbased	:	IN  STD_LOGIC;
		 rstart_threshold	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 rtruebac2bac	:	IN  STD_LOGIC;
		 rwa_6g_en	:	IN  STD_LOGIC;
		 scan_mode	:	IN  STD_LOGIC;
		 skpos_det	:	OUT  STD_LOGIC;
		 soft_reset	:	IN  STD_LOGIC;
		 sudi	:	IN  STD_LOGIC_VECTOR (27 DOWNTO 0);
		 sudi_pre	:	IN  STD_LOGIC_VECTOR (13 DOWNTO 0);
		 sync_status	:	IN  STD_LOGIC;
		 wrenable	:	IN  STD_LOGIC
	 ); 
 END stratixiv_hssi_rx_digi_comp_chnl_top;

 ARCHITECTURE RTL OF stratixiv_hssi_rx_digi_comp_chnl_top IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 nli0O0O61	:	STD_LOGIC := '0';
	 SIGNAL	 nli0O0O62	:	STD_LOGIC := '0';
	 SIGNAL	 nliil1i59	:	STD_LOGIC := '0';
	 SIGNAL	 nliil1i60	:	STD_LOGIC := '0';
	 SIGNAL	 nliil1l57	:	STD_LOGIC := '0';
	 SIGNAL	 nliil1l58	:	STD_LOGIC := '0';
	 SIGNAL	 nliiOOi55	:	STD_LOGIC := '0';
	 SIGNAL	 nliiOOi56	:	STD_LOGIC := '0';
	 SIGNAL	 nliiOOl53	:	STD_LOGIC := '0';
	 SIGNAL	 nliiOOl54	:	STD_LOGIC := '0';
	 SIGNAL	 nliiOOO51	:	STD_LOGIC := '0';
	 SIGNAL	 nliiOOO52	:	STD_LOGIC := '0';
	 SIGNAL	 nlil01l49	:	STD_LOGIC := '0';
	 SIGNAL	 nlil01l50	:	STD_LOGIC := '0';
	 SIGNAL	 nlil0li47	:	STD_LOGIC := '0';
	 SIGNAL	 nlil0li48	:	STD_LOGIC := '0';
	 SIGNAL	 nlil0Ol45	:	STD_LOGIC := '0';
	 SIGNAL	 nlil0Ol46	:	STD_LOGIC := '0';
	 SIGNAL	 nlili0l43	:	STD_LOGIC := '0';
	 SIGNAL	 nlili0l44	:	STD_LOGIC := '0';
	 SIGNAL	 nlilill41	:	STD_LOGIC := '0';
	 SIGNAL	 nlilill42	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlilill42_w_lg_w_lg_q405w406w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlilill42_w_lg_q405w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlililO39	:	STD_LOGIC := '0';
	 SIGNAL	 nlililO40	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlililO40_w_lg_w_lg_q396w397w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlililO40_w_lg_q396w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nliliOi37	:	STD_LOGIC := '0';
	 SIGNAL	 nliliOi38	:	STD_LOGIC := '0';
	 SIGNAL  wire_nliliOi38_w_lg_w_lg_q369w370w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliliOi38_w_lg_q369w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nliliOl35	:	STD_LOGIC := '0';
	 SIGNAL	 nliliOl36	:	STD_LOGIC := '0';
	 SIGNAL  wire_nliliOl36_w_lg_w_lg_q332w333w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliliOl36_w_lg_q332w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nliliOO33	:	STD_LOGIC := '0';
	 SIGNAL	 nliliOO34	:	STD_LOGIC := '0';
	 SIGNAL  wire_nliliOO34_w_lg_w_lg_q166w167w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliliOO34_w_lg_q166w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlill0l25	:	STD_LOGIC := '0';
	 SIGNAL	 nlill0l26	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlill0l26_w_lg_w_lg_q124w125w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlill0l26_w_lg_q124w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlill1i31	:	STD_LOGIC := '0';
	 SIGNAL	 nlill1i32	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlill1i32_w_lg_w_lg_q155w156w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlill1i32_w_lg_q155w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlill1l29	:	STD_LOGIC := '0';
	 SIGNAL	 nlill1l30	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlill1l30_w_lg_w_lg_q152w153w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlill1l30_w_lg_q152w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlill1O27	:	STD_LOGIC := '0';
	 SIGNAL	 nlill1O28	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlill1O28_w_lg_q140w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlilliO23	:	STD_LOGIC := '0';
	 SIGNAL	 nlilliO24	:	STD_LOGIC := '0';
	 SIGNAL	 nlillll21	:	STD_LOGIC := '0';
	 SIGNAL	 nlillll22	:	STD_LOGIC := '0';
	 SIGNAL	 nlilO0O15	:	STD_LOGIC := '0';
	 SIGNAL	 nlilO0O16	:	STD_LOGIC := '0';
	 SIGNAL	 nlilO1i19	:	STD_LOGIC := '0';
	 SIGNAL	 nlilO1i20	:	STD_LOGIC := '0';
	 SIGNAL	 nlilO1O17	:	STD_LOGIC := '0';
	 SIGNAL	 nlilO1O18	:	STD_LOGIC := '0';
	 SIGNAL	 nlilOli13	:	STD_LOGIC := '0';
	 SIGNAL	 nlilOli14	:	STD_LOGIC := '0';
	 SIGNAL	 nlilOlO11	:	STD_LOGIC := '0';
	 SIGNAL	 nlilOlO12	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlilOlO12_w_lg_q17w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlilOOl10	:	STD_LOGIC := '0';
	 SIGNAL	 nlilOOl9	:	STD_LOGIC := '0';
	 SIGNAL	 nlilOOO7	:	STD_LOGIC := '0';
	 SIGNAL	 nlilOOO8	:	STD_LOGIC := '0';
	 SIGNAL	 nliO10i3	:	STD_LOGIC := '0';
	 SIGNAL	 nliO10i4	:	STD_LOGIC := '0';
	 SIGNAL	 nliO11l5	:	STD_LOGIC := '0';
	 SIGNAL	 nliO11l6	:	STD_LOGIC := '0';
	 SIGNAL	 nliO1iO1	:	STD_LOGIC := '0';
	 SIGNAL	 nliO1iO2	:	STD_LOGIC := '0';
	 SIGNAL	n0111i	:	STD_LOGIC := '0';
	 SIGNAL	n0111l	:	STD_LOGIC := '0';
	 SIGNAL	n1000i	:	STD_LOGIC := '0';
	 SIGNAL	n1000l	:	STD_LOGIC := '0';
	 SIGNAL	n1000O	:	STD_LOGIC := '0';
	 SIGNAL	n1001i	:	STD_LOGIC := '0';
	 SIGNAL	n1001l	:	STD_LOGIC := '0';
	 SIGNAL	n1001O	:	STD_LOGIC := '0';
	 SIGNAL	n100ii	:	STD_LOGIC := '0';
	 SIGNAL	n100il	:	STD_LOGIC := '0';
	 SIGNAL	n100li	:	STD_LOGIC := '0';
	 SIGNAL	n100ll	:	STD_LOGIC := '0';
	 SIGNAL	n100lO	:	STD_LOGIC := '0';
	 SIGNAL	n100Oi	:	STD_LOGIC := '0';
	 SIGNAL	n100Ol	:	STD_LOGIC := '0';
	 SIGNAL	n100OO	:	STD_LOGIC := '0';
	 SIGNAL	n101Ol	:	STD_LOGIC := '0';
	 SIGNAL	n101OO	:	STD_LOGIC := '0';
	 SIGNAL	n10i0i	:	STD_LOGIC := '0';
	 SIGNAL	n10i0l	:	STD_LOGIC := '0';
	 SIGNAL	n10i0O	:	STD_LOGIC := '0';
	 SIGNAL	n10i1i	:	STD_LOGIC := '0';
	 SIGNAL	n10i1l	:	STD_LOGIC := '0';
	 SIGNAL	n10i1O	:	STD_LOGIC := '0';
	 SIGNAL	n10iii	:	STD_LOGIC := '0';
	 SIGNAL	n10iil	:	STD_LOGIC := '0';
	 SIGNAL	n10iiO	:	STD_LOGIC := '0';
	 SIGNAL	n10ili	:	STD_LOGIC := '0';
	 SIGNAL	n10ill	:	STD_LOGIC := '0';
	 SIGNAL	n10ilO	:	STD_LOGIC := '0';
	 SIGNAL	n10iOl	:	STD_LOGIC := '0';
	 SIGNAL	n10iOO	:	STD_LOGIC := '0';
	 SIGNAL	n10l0i	:	STD_LOGIC := '0';
	 SIGNAL	n10l0l	:	STD_LOGIC := '0';
	 SIGNAL	n10l0O	:	STD_LOGIC := '0';
	 SIGNAL	n10l1i	:	STD_LOGIC := '0';
	 SIGNAL	n10l1l	:	STD_LOGIC := '0';
	 SIGNAL	n10l1O	:	STD_LOGIC := '0';
	 SIGNAL	n10lii	:	STD_LOGIC := '0';
	 SIGNAL	n10lil	:	STD_LOGIC := '0';
	 SIGNAL	n10liO	:	STD_LOGIC := '0';
	 SIGNAL	n10lli	:	STD_LOGIC := '0';
	 SIGNAL	n10lll	:	STD_LOGIC := '0';
	 SIGNAL	n10llO	:	STD_LOGIC := '0';
	 SIGNAL	n10lOi	:	STD_LOGIC := '0';
	 SIGNAL	n10lOl	:	STD_LOGIC := '0';
	 SIGNAL	n10lOO	:	STD_LOGIC := '0';
	 SIGNAL	n10O1i	:	STD_LOGIC := '0';
	 SIGNAL	n10O1l	:	STD_LOGIC := '0';
	 SIGNAL	n10O1O	:	STD_LOGIC := '0';
	 SIGNAL	n110iO	:	STD_LOGIC := '0';
	 SIGNAL	n110li	:	STD_LOGIC := '0';
	 SIGNAL	n110ll	:	STD_LOGIC := '0';
	 SIGNAL	n110lO	:	STD_LOGIC := '0';
	 SIGNAL	n11iil	:	STD_LOGIC := '0';
	 SIGNAL	n11iiO	:	STD_LOGIC := '0';
	 SIGNAL	n11ili	:	STD_LOGIC := '0';
	 SIGNAL	n11ill	:	STD_LOGIC := '0';
	 SIGNAL	n11ilO	:	STD_LOGIC := '0';
	 SIGNAL	n11iOi	:	STD_LOGIC := '0';
	 SIGNAL	n11iOl	:	STD_LOGIC := '0';
	 SIGNAL	n11iOO	:	STD_LOGIC := '0';
	 SIGNAL	n11O0i	:	STD_LOGIC := '0';
	 SIGNAL	n11O0l	:	STD_LOGIC := '0';
	 SIGNAL	n11O0O	:	STD_LOGIC := '0';
	 SIGNAL	n11O1i	:	STD_LOGIC := '0';
	 SIGNAL	n11O1l	:	STD_LOGIC := '0';
	 SIGNAL	n11O1O	:	STD_LOGIC := '0';
	 SIGNAL	n1l	:	STD_LOGIC := '0';
	 SIGNAL	n1liil	:	STD_LOGIC := '0';
	 SIGNAL	n1liiO	:	STD_LOGIC := '0';
	 SIGNAL	n1lili	:	STD_LOGIC := '0';
	 SIGNAL	n1ll1i	:	STD_LOGIC := '0';
	 SIGNAL	n1ll1l	:	STD_LOGIC := '0';
	 SIGNAL	n1O00i	:	STD_LOGIC := '0';
	 SIGNAL	n1O00l	:	STD_LOGIC := '0';
	 SIGNAL	n1O01l	:	STD_LOGIC := '0';
	 SIGNAL	n1O01O	:	STD_LOGIC := '0';
	 SIGNAL	ni0OOi	:	STD_LOGIC := '0';
	 SIGNAL	ni0OOl	:	STD_LOGIC := '0';
	 SIGNAL	ni0OOO	:	STD_LOGIC := '0';
	 SIGNAL	nii00i	:	STD_LOGIC := '0';
	 SIGNAL	nii00l	:	STD_LOGIC := '0';
	 SIGNAL	nii00O	:	STD_LOGIC := '0';
	 SIGNAL	nii01i	:	STD_LOGIC := '0';
	 SIGNAL	nii01l	:	STD_LOGIC := '0';
	 SIGNAL	nii01O	:	STD_LOGIC := '0';
	 SIGNAL	nii0ii	:	STD_LOGIC := '0';
	 SIGNAL	nii0il	:	STD_LOGIC := '0';
	 SIGNAL	nii0iO	:	STD_LOGIC := '0';
	 SIGNAL	nii0ll	:	STD_LOGIC := '0';
	 SIGNAL	nii0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nii0OO	:	STD_LOGIC := '0';
	 SIGNAL	nii10i	:	STD_LOGIC := '0';
	 SIGNAL	nii10l	:	STD_LOGIC := '0';
	 SIGNAL	nii10O	:	STD_LOGIC := '0';
	 SIGNAL	nii11i	:	STD_LOGIC := '0';
	 SIGNAL	nii11l	:	STD_LOGIC := '0';
	 SIGNAL	nii11O	:	STD_LOGIC := '0';
	 SIGNAL	nii1ii	:	STD_LOGIC := '0';
	 SIGNAL	nii1il	:	STD_LOGIC := '0';
	 SIGNAL	nii1iO	:	STD_LOGIC := '0';
	 SIGNAL	nii1li	:	STD_LOGIC := '0';
	 SIGNAL	nii1ll	:	STD_LOGIC := '0';
	 SIGNAL	nii1lO	:	STD_LOGIC := '0';
	 SIGNAL	nii1Oi	:	STD_LOGIC := '0';
	 SIGNAL	nii1Ol	:	STD_LOGIC := '0';
	 SIGNAL	nii1OO	:	STD_LOGIC := '0';
	 SIGNAL	niii1i	:	STD_LOGIC := '0';
	 SIGNAL	niOlOl	:	STD_LOGIC := '0';
	 SIGNAL	niOlOO	:	STD_LOGIC := '0';
	 SIGNAL	niOO0i	:	STD_LOGIC := '0';
	 SIGNAL	niOO0l	:	STD_LOGIC := '0';
	 SIGNAL	niOO0O	:	STD_LOGIC := '0';
	 SIGNAL	niOO1i	:	STD_LOGIC := '0';
	 SIGNAL	niOO1l	:	STD_LOGIC := '0';
	 SIGNAL	niOO1O	:	STD_LOGIC := '0';
	 SIGNAL	niOOii	:	STD_LOGIC := '0';
	 SIGNAL	niOOil	:	STD_LOGIC := '0';
	 SIGNAL	niOOli	:	STD_LOGIC := '0';
	 SIGNAL	niOOll	:	STD_LOGIC := '0';
	 SIGNAL	niOOlO	:	STD_LOGIC := '0';
	 SIGNAL	niOOOi	:	STD_LOGIC := '0';
	 SIGNAL	niOOOl	:	STD_LOGIC := '0';
	 SIGNAL	niOOOO	:	STD_LOGIC := '0';
	 SIGNAL	nl100i	:	STD_LOGIC := '0';
	 SIGNAL	nl100l	:	STD_LOGIC := '0';
	 SIGNAL	nl100O	:	STD_LOGIC := '0';
	 SIGNAL	nl101i	:	STD_LOGIC := '0';
	 SIGNAL	nl101l	:	STD_LOGIC := '0';
	 SIGNAL	nl101O	:	STD_LOGIC := '0';
	 SIGNAL	nl10ii	:	STD_LOGIC := '0';
	 SIGNAL	nl10il	:	STD_LOGIC := '0';
	 SIGNAL	nl10iO	:	STD_LOGIC := '0';
	 SIGNAL	nl10li	:	STD_LOGIC := '0';
	 SIGNAL	nl10ll	:	STD_LOGIC := '0';
	 SIGNAL	nl10lO	:	STD_LOGIC := '0';
	 SIGNAL	nl10Oi	:	STD_LOGIC := '0';
	 SIGNAL	nl10Ol	:	STD_LOGIC := '0';
	 SIGNAL	nl10OO	:	STD_LOGIC := '0';
	 SIGNAL	nl110i	:	STD_LOGIC := '0';
	 SIGNAL	nl110l	:	STD_LOGIC := '0';
	 SIGNAL	nl110O	:	STD_LOGIC := '0';
	 SIGNAL	nl111i	:	STD_LOGIC := '0';
	 SIGNAL	nl111l	:	STD_LOGIC := '0';
	 SIGNAL	nl111O	:	STD_LOGIC := '0';
	 SIGNAL	nl11ii	:	STD_LOGIC := '0';
	 SIGNAL	nl11il	:	STD_LOGIC := '0';
	 SIGNAL	nl11iO	:	STD_LOGIC := '0';
	 SIGNAL	nl11li	:	STD_LOGIC := '0';
	 SIGNAL	nl11ll	:	STD_LOGIC := '0';
	 SIGNAL	nl11lO	:	STD_LOGIC := '0';
	 SIGNAL	nl11OO	:	STD_LOGIC := '0';
	 SIGNAL	nl1i0i	:	STD_LOGIC := '0';
	 SIGNAL	nl1i1i	:	STD_LOGIC := '0';
	 SIGNAL	nl1i1l	:	STD_LOGIC := '0';
	 SIGNAL	nl1i1O	:	STD_LOGIC := '0';
	 SIGNAL	nli0il	:	STD_LOGIC := '0';
	 SIGNAL	nli0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nli0OO	:	STD_LOGIC := '0';
	 SIGNAL	nli1ll	:	STD_LOGIC := '0';
	 SIGNAL	nli1lO	:	STD_LOGIC := '0';
	 SIGNAL	nli1Oi	:	STD_LOGIC := '0';
	 SIGNAL	nli1Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlii0i	:	STD_LOGIC := '0';
	 SIGNAL	nlii0l	:	STD_LOGIC := '0';
	 SIGNAL	nlii0O	:	STD_LOGIC := '0';
	 SIGNAL	nlii1i	:	STD_LOGIC := '0';
	 SIGNAL	nlii1l	:	STD_LOGIC := '0';
	 SIGNAL	nliilO	:	STD_LOGIC := '0';
	 SIGNAL	nliiOi	:	STD_LOGIC := '0';
	 SIGNAL	nlil0i	:	STD_LOGIC := '0';
	 SIGNAL	nlil0l	:	STD_LOGIC := '0';
	 SIGNAL	nlil0O	:	STD_LOGIC := '0';
	 SIGNAL	nlil1O	:	STD_LOGIC := '0';
	 SIGNAL	nlilOl	:	STD_LOGIC := '0';
	 SIGNAL	nliO01l	:	STD_LOGIC := '0';
	 SIGNAL	nliO01O	:	STD_LOGIC := '0';
	 SIGNAL	nliO1i	:	STD_LOGIC := '0';
	 SIGNAL	nlll	:	STD_LOGIC := '0';
	 SIGNAL	nlO00OO	:	STD_LOGIC := '0';
	 SIGNAL	nlOi1iO	:	STD_LOGIC := '0';
	 SIGNAL	nlOiO0i	:	STD_LOGIC := '0';
	 SIGNAL	nlOiO0l	:	STD_LOGIC := '0';
	 SIGNAL	nlOiO0O	:	STD_LOGIC := '0';
	 SIGNAL	nlOiO1O	:	STD_LOGIC := '0';
	 SIGNAL	nlOiOii	:	STD_LOGIC := '0';
	 SIGNAL	nlOl0OO	:	STD_LOGIC := '0';
	 SIGNAL	nlOli0i	:	STD_LOGIC := '0';
	 SIGNAL	nlOli0l	:	STD_LOGIC := '0';
	 SIGNAL	nlOli0O	:	STD_LOGIC := '0';
	 SIGNAL	nlOli1i	:	STD_LOGIC := '0';
	 SIGNAL	nlOli1l	:	STD_LOGIC := '0';
	 SIGNAL	nlOli1O	:	STD_LOGIC := '0';
	 SIGNAL	nlOliii	:	STD_LOGIC := '0';
	 SIGNAL	nlOliil	:	STD_LOGIC := '0';
	 SIGNAL	nlOliiO	:	STD_LOGIC := '0';
	 SIGNAL	nlOlili	:	STD_LOGIC := '0';
	 SIGNAL	nlOlilO	:	STD_LOGIC := '0';
	 SIGNAL	nlOliOO	:	STD_LOGIC := '0';
	 SIGNAL	nlOll1i	:	STD_LOGIC := '0';
	 SIGNAL	nlOll1l	:	STD_LOGIC := '0';
	 SIGNAL	wire_n1i_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_n1i_PRN	:	STD_LOGIC;
	 SIGNAL  wire_n1i_w_lg_w_lg_w_lg_w1365w1366w1367w1368w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_w_lg_w1399w1400w1401w1402w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_w1365w1366w1367w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_w1399w1400w1401w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w1365w1366w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w1399w1400w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w1365w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w1399w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_w_lg_w_lg_nii0il1341w1342w1344w1345w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_w_lg_w_lg_nii1ii1375w1376w1378w1379w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_w_lg_w_lg_nii0il1358w1360w1362w1363w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_w_lg_w_lg_nii1ii1392w1394w1396w1397w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_w_lg_nii0il1341w1342w1344w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_w_lg_nii1ii1375w1376w1378w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_w_lg_nii0il1358w1360w1362w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_w_lg_nii1ii1392w1394w1396w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_nii0il1341w1342w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_nii1ii1375w1376w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_nii0il1358w1360w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_nii1ii1392w1394w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_nlilOl458w459w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n100ii3075w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n1liil2154w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii0il1341w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii1ii1375w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_niOOii1336w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nlii0O548w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n1000l3076w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n1000O3074w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n110iO2148w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n110li2131w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n110ll2149w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n110lO3093w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n11iil3091w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n11iiO3089w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n11ili3087w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n11ill3085w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n11ilO3083w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n11iOi3081w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n11iOl3080w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n11iOO1967w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n11O0i2092w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n11O0l2091w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n11O1i1951w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n11O1l2086w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_n11O1O2094w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_ni0OOl1384w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_ni0OOO1382w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii00i1364w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii00l1343w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii00O1361w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii01i1348w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii01O1346w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii0ii1359w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii0il1358w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii10i1377w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii10l1395w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii10O1393w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii11l1380w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii11O1398w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii1ii1392w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nii1OO1350w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_niOO0l1337w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_niOO0O1335w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nli0il643w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nlil0i484w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nlil0l722w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nlilOl458w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_nlOi1iO2142w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n0l0iO	:	STD_LOGIC := '0';
	 SIGNAL	ni11ll	:	STD_LOGIC := '0';
	 SIGNAL	ni11lO	:	STD_LOGIC := '0';
	 SIGNAL	ni11Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlliiOO	:	STD_LOGIC := '0';
	 SIGNAL	nllil1i	:	STD_LOGIC := '0';
	 SIGNAL	nllil1l	:	STD_LOGIC := '0';
	 SIGNAL	nlllO0l	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni11Oi_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_ni11Oi_PRN	:	STD_LOGIC;
	 SIGNAL	n0111O	:	STD_LOGIC := '0';
	 SIGNAL	n0l00l	:	STD_LOGIC := '0';
	 SIGNAL	n0l00O	:	STD_LOGIC := '0';
	 SIGNAL	n0l0ii	:	STD_LOGIC := '0';
	 SIGNAL	n0l0il	:	STD_LOGIC := '0';
	 SIGNAL	n0l0li	:	STD_LOGIC := '0';
	 SIGNAL	n0l0ll	:	STD_LOGIC := '0';
	 SIGNAL	n0l0lO	:	STD_LOGIC := '0';
	 SIGNAL	n0l0Oi	:	STD_LOGIC := '0';
	 SIGNAL	n0l0Ol	:	STD_LOGIC := '0';
	 SIGNAL	n0l0OO	:	STD_LOGIC := '0';
	 SIGNAL	n0li0i	:	STD_LOGIC := '0';
	 SIGNAL	n0li0l	:	STD_LOGIC := '0';
	 SIGNAL	n0li0O	:	STD_LOGIC := '0';
	 SIGNAL	n0li1i	:	STD_LOGIC := '0';
	 SIGNAL	n0li1l	:	STD_LOGIC := '0';
	 SIGNAL	n0li1O	:	STD_LOGIC := '0';
	 SIGNAL	n0liii	:	STD_LOGIC := '0';
	 SIGNAL	n0liil	:	STD_LOGIC := '0';
	 SIGNAL	n0liiO	:	STD_LOGIC := '0';
	 SIGNAL	n0lili	:	STD_LOGIC := '0';
	 SIGNAL	n0lill	:	STD_LOGIC := '0';
	 SIGNAL	n0lilO	:	STD_LOGIC := '0';
	 SIGNAL	n0liOi	:	STD_LOGIC := '0';
	 SIGNAL	n0liOl	:	STD_LOGIC := '0';
	 SIGNAL	n0O0ll	:	STD_LOGIC := '0';
	 SIGNAL	n0O0lO	:	STD_LOGIC := '0';
	 SIGNAL	n0O0Oi	:	STD_LOGIC := '0';
	 SIGNAL	n0O0Ol	:	STD_LOGIC := '0';
	 SIGNAL	n0O0OO	:	STD_LOGIC := '0';
	 SIGNAL	n0Oiil	:	STD_LOGIC := '0';
	 SIGNAL	n0OiOl	:	STD_LOGIC := '0';
	 SIGNAL	n0OiOO	:	STD_LOGIC := '0';
	 SIGNAL	n0Ol0i	:	STD_LOGIC := '0';
	 SIGNAL	n0Ol0l	:	STD_LOGIC := '0';
	 SIGNAL	n0Ol0O	:	STD_LOGIC := '0';
	 SIGNAL	n0Ol1l	:	STD_LOGIC := '0';
	 SIGNAL	n0Ol1O	:	STD_LOGIC := '0';
	 SIGNAL	n0OO1O	:	STD_LOGIC := '0';
	 SIGNAL	n0OOli	:	STD_LOGIC := '0';
	 SIGNAL	n0OOll	:	STD_LOGIC := '0';
	 SIGNAL	n1O	:	STD_LOGIC := '0';
	 SIGNAL	ni000i	:	STD_LOGIC := '0';
	 SIGNAL	ni000l	:	STD_LOGIC := '0';
	 SIGNAL	ni00il	:	STD_LOGIC := '0';
	 SIGNAL	ni00iO	:	STD_LOGIC := '0';
	 SIGNAL	ni00Oi	:	STD_LOGIC := '0';
	 SIGNAL	ni101i	:	STD_LOGIC := '0';
	 SIGNAL	ni101l	:	STD_LOGIC := '0';
	 SIGNAL	ni110i	:	STD_LOGIC := '0';
	 SIGNAL	ni110l	:	STD_LOGIC := '0';
	 SIGNAL	ni111i	:	STD_LOGIC := '0';
	 SIGNAL	ni111l	:	STD_LOGIC := '0';
	 SIGNAL	ni111O	:	STD_LOGIC := '0';
	 SIGNAL	ni11OO	:	STD_LOGIC := '0';
	 SIGNAL	ni1i0i	:	STD_LOGIC := '0';
	 SIGNAL	ni1i0l	:	STD_LOGIC := '0';
	 SIGNAL	ni1i0O	:	STD_LOGIC := '0';
	 SIGNAL	ni1i1l	:	STD_LOGIC := '0';
	 SIGNAL	ni1i1O	:	STD_LOGIC := '0';
	 SIGNAL	ni1llO	:	STD_LOGIC := '0';
	 SIGNAL	ni1O0i	:	STD_LOGIC := '0';
	 SIGNAL	ni1O0l	:	STD_LOGIC := '0';
	 SIGNAL	ni1O0O	:	STD_LOGIC := '0';
	 SIGNAL	ni1O1l	:	STD_LOGIC := '0';
	 SIGNAL	ni1O1O	:	STD_LOGIC := '0';
	 SIGNAL	nil	:	STD_LOGIC := '0';
	 SIGNAL	nliO00i	:	STD_LOGIC := '0';
	 SIGNAL	nliO1l	:	STD_LOGIC := '0';
	 SIGNAL	nlli00O	:	STD_LOGIC := '0';
	 SIGNAL	nlli0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nlli0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlli1ii	:	STD_LOGIC := '0';
	 SIGNAL	nlli1il	:	STD_LOGIC := '0';
	 SIGNAL	nlli1iO	:	STD_LOGIC := '0';
	 SIGNAL	nlli1li	:	STD_LOGIC := '0';
	 SIGNAL	nlli1ll	:	STD_LOGIC := '0';
	 SIGNAL	nllii0l	:	STD_LOGIC := '0';
	 SIGNAL	nllii0O	:	STD_LOGIC := '0';
	 SIGNAL	nllii1O	:	STD_LOGIC := '0';
	 SIGNAL	nlliiii	:	STD_LOGIC := '0';
	 SIGNAL	nlliiil	:	STD_LOGIC := '0';
	 SIGNAL	nlliiiO	:	STD_LOGIC := '0';
	 SIGNAL	nlliiO	:	STD_LOGIC := '0';
	 SIGNAL	nllil0i	:	STD_LOGIC := '0';
	 SIGNAL	nllil0l	:	STD_LOGIC := '0';
	 SIGNAL	nllil1O	:	STD_LOGIC := '0';
	 SIGNAL	nllili	:	STD_LOGIC := '0';
	 SIGNAL	nllill	:	STD_LOGIC := '0';
	 SIGNAL	nllilO	:	STD_LOGIC := '0';
	 SIGNAL	nlliOi	:	STD_LOGIC := '0';
	 SIGNAL	nlliOl	:	STD_LOGIC := '0';
	 SIGNAL	nlliOO	:	STD_LOGIC := '0';
	 SIGNAL	nlll0i	:	STD_LOGIC := '0';
	 SIGNAL	nlll0l	:	STD_LOGIC := '0';
	 SIGNAL	nlll0O	:	STD_LOGIC := '0';
	 SIGNAL	nlll10l	:	STD_LOGIC := '0';
	 SIGNAL	nlll10O	:	STD_LOGIC := '0';
	 SIGNAL	nlll1i	:	STD_LOGIC := '0';
	 SIGNAL	nlll1ii	:	STD_LOGIC := '0';
	 SIGNAL	nlll1il	:	STD_LOGIC := '0';
	 SIGNAL	nlll1iO	:	STD_LOGIC := '0';
	 SIGNAL	nlll1l	:	STD_LOGIC := '0';
	 SIGNAL	nlll1li	:	STD_LOGIC := '0';
	 SIGNAL	nlll1O	:	STD_LOGIC := '0';
	 SIGNAL	nlllii	:	STD_LOGIC := '0';
	 SIGNAL	nlllil	:	STD_LOGIC := '0';
	 SIGNAL	nllliO	:	STD_LOGIC := '0';
	 SIGNAL	nllll0O	:	STD_LOGIC := '0';
	 SIGNAL	nlllli	:	STD_LOGIC := '0';
	 SIGNAL	nllllii	:	STD_LOGIC := '0';
	 SIGNAL	nlllliO	:	STD_LOGIC := '0';
	 SIGNAL	nlllll	:	STD_LOGIC := '0';
	 SIGNAL	nllllli	:	STD_LOGIC := '0';
	 SIGNAL	nllllO	:	STD_LOGIC := '0';
	 SIGNAL	nlllO0i	:	STD_LOGIC := '0';
	 SIGNAL	nlllO0O	:	STD_LOGIC := '0';
	 SIGNAL	nlllO1i	:	STD_LOGIC := '0';
	 SIGNAL	nlllO1l	:	STD_LOGIC := '0';
	 SIGNAL	nlllO1O	:	STD_LOGIC := '0';
	 SIGNAL	nlllOi	:	STD_LOGIC := '0';
	 SIGNAL	nlllOii	:	STD_LOGIC := '0';
	 SIGNAL	nlllOil	:	STD_LOGIC := '0';
	 SIGNAL	nlllOiO	:	STD_LOGIC := '0';
	 SIGNAL	nlllOl	:	STD_LOGIC := '0';
	 SIGNAL	nlllOli	:	STD_LOGIC := '0';
	 SIGNAL	nlllOll	:	STD_LOGIC := '0';
	 SIGNAL	nlllOlO	:	STD_LOGIC := '0';
	 SIGNAL	nlllOO	:	STD_LOGIC := '0';
	 SIGNAL	nlllOOi	:	STD_LOGIC := '0';
	 SIGNAL	nlllOOl	:	STD_LOGIC := '0';
	 SIGNAL	nlllOOO	:	STD_LOGIC := '0';
	 SIGNAL	nllO0i	:	STD_LOGIC := '0';
	 SIGNAL	nllO0l	:	STD_LOGIC := '0';
	 SIGNAL	nllO10i	:	STD_LOGIC := '0';
	 SIGNAL	nllO10l	:	STD_LOGIC := '0';
	 SIGNAL	nllO10O	:	STD_LOGIC := '0';
	 SIGNAL	nllO11i	:	STD_LOGIC := '0';
	 SIGNAL	nllO11l	:	STD_LOGIC := '0';
	 SIGNAL	nllO11O	:	STD_LOGIC := '0';
	 SIGNAL	nllO1i	:	STD_LOGIC := '0';
	 SIGNAL	nllO1ii	:	STD_LOGIC := '0';
	 SIGNAL	nllO1il	:	STD_LOGIC := '0';
	 SIGNAL	nllO1iO	:	STD_LOGIC := '0';
	 SIGNAL	nllO1l	:	STD_LOGIC := '0';
	 SIGNAL	nllO1li	:	STD_LOGIC := '0';
	 SIGNAL	nllO1O	:	STD_LOGIC := '0';
	 SIGNAL	nllOOi	:	STD_LOGIC := '0';
	 SIGNAL	nllOOl	:	STD_LOGIC := '0';
	 SIGNAL	nlO00ii	:	STD_LOGIC := '0';
	 SIGNAL	nlO00li	:	STD_LOGIC := '0';
	 SIGNAL	nlO00ll	:	STD_LOGIC := '0';
	 SIGNAL	nlO00lO	:	STD_LOGIC := '0';
	 SIGNAL	nlO00Oi	:	STD_LOGIC := '0';
	 SIGNAL	nlO00Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlO011i	:	STD_LOGIC := '0';
	 SIGNAL	nlO011l	:	STD_LOGIC := '0';
	 SIGNAL	nlO01l	:	STD_LOGIC := '0';
	 SIGNAL	nlO01O	:	STD_LOGIC := '0';
	 SIGNAL	nlO10li	:	STD_LOGIC := '0';
	 SIGNAL	nlO10ll	:	STD_LOGIC := '0';
	 SIGNAL	nlO10lO	:	STD_LOGIC := '0';
	 SIGNAL	nlO10Oi	:	STD_LOGIC := '0';
	 SIGNAL	nlO1i0O	:	STD_LOGIC := '0';
	 SIGNAL	nlO1Oii	:	STD_LOGIC := '0';
	 SIGNAL	nlO1OiO	:	STD_LOGIC := '0';
	 SIGNAL	nlO1OOi	:	STD_LOGIC := '0';
	 SIGNAL	nlO1OOl	:	STD_LOGIC := '0';
	 SIGNAL	nlO1OOO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nii_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nii_w_lg_nlllO0i3156w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_n0l00l858w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_n0l00O860w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_n0l0ii862w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_n0l0il864w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_n0O0ll856w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_n0O0OO843w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_n0Oiil755w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_n0Ol0O974w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_ni1i0i1700w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_ni1i0l1699w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_ni1i0O967w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_ni1llO1648w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_ni1O0i1642w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_ni1O0l1641w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_ni1O1l1646w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_ni1O1O1644w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlli0Oi2548w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlli0Ol2560w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlll10l3171w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlll10O3169w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlll1ii3167w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlll1il3165w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlll1iO3164w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlll1li2465w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nllllli2296w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlllO0i2304w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlllO1i2298w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlllO1l2300w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlllO1O2302w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlO011i3144w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlO10Oi2283w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlO1Oii2347w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlO1OOO3145w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_w_lg_nllllii47w48w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nllllii47w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlO00ll2360w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlO00lO2361w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_nlO00Oi2362w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	ni00Ol	:	STD_LOGIC := '0';
	 SIGNAL	ni0liO	:	STD_LOGIC := '0';
	 SIGNAL	ni0lli	:	STD_LOGIC := '0';
	 SIGNAL	ni0lll	:	STD_LOGIC := '0';
	 SIGNAL	ni0llO	:	STD_LOGIC := '0';
	 SIGNAL	ni0lOi	:	STD_LOGIC := '0';
	 SIGNAL	ni0lOl	:	STD_LOGIC := '0';
	 SIGNAL	ni0lOO	:	STD_LOGIC := '0';
	 SIGNAL	ni0O0i	:	STD_LOGIC := '0';
	 SIGNAL	ni0O0l	:	STD_LOGIC := '0';
	 SIGNAL	ni0O0O	:	STD_LOGIC := '0';
	 SIGNAL	ni0O1i	:	STD_LOGIC := '0';
	 SIGNAL	ni0O1l	:	STD_LOGIC := '0';
	 SIGNAL	ni0O1O	:	STD_LOGIC := '0';
	 SIGNAL	ni0Oii	:	STD_LOGIC := '0';
	 SIGNAL	ni0Oil	:	STD_LOGIC := '0';
	 SIGNAL	ni0OiO	:	STD_LOGIC := '0';
	 SIGNAL	ni0Oli	:	STD_LOGIC := '0';
	 SIGNAL	ni0Oll	:	STD_LOGIC := '0';
	 SIGNAL	ni0OlO	:	STD_LOGIC := '0';
	 SIGNAL	nii0li	:	STD_LOGIC := '0';
	 SIGNAL	nii0Oi	:	STD_LOGIC := '0';
	 SIGNAL	wire_nii0lO_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nii0lO_w_lg_nii0Oi640w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n0Oi1i	:	STD_LOGIC := '0';
	 SIGNAL	n0Oi1l	:	STD_LOGIC := '0';
	 SIGNAL	niiOlO	:	STD_LOGIC := '0';
	 SIGNAL	niiOOi	:	STD_LOGIC := '0';
	 SIGNAL	niiOOO	:	STD_LOGIC := '0';
	 SIGNAL	nlli10i	:	STD_LOGIC := '0';
	 SIGNAL	nlli10l	:	STD_LOGIC := '0';
	 SIGNAL	nlli10O	:	STD_LOGIC := '0';
	 SIGNAL	nlO10Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlO10OO	:	STD_LOGIC := '0';
	 SIGNAL	wire_niiOOl_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_niiOOl_PRN	:	STD_LOGIC;
	 SIGNAL	nl0l	:	STD_LOGIC := '0';
	 SIGNAL	nO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl_CLRN	:	STD_LOGIC;
	 SIGNAL	n100iO	:	STD_LOGIC := '0';
	 SIGNAL	n10iOi	:	STD_LOGIC := '0';
	 SIGNAL	niOOiO	:	STD_LOGIC := '0';
	 SIGNAL	nl11Ol	:	STD_LOGIC := '0';
	 SIGNAL	n0l00i	:	STD_LOGIC := '0';
	 SIGNAL	n0l01l	:	STD_LOGIC := '0';
	 SIGNAL	n0l01O	:	STD_LOGIC := '0';
	 SIGNAL	n1O00O	:	STD_LOGIC := '0';
	 SIGNAL	n1O0ii	:	STD_LOGIC := '0';
	 SIGNAL	nli01l	:	STD_LOGIC := '0';
	 SIGNAL	nli1OO	:	STD_LOGIC := '0';
	 SIGNAL	nlli11i	:	STD_LOGIC := '0';
	 SIGNAL	nlli11l	:	STD_LOGIC := '0';
	 SIGNAL	nlli11O	:	STD_LOGIC := '0';
	 SIGNAL	wire_nli01i_PRN	:	STD_LOGIC;
	 SIGNAL	nl0O	:	STD_LOGIC := '0';
	 SIGNAL	nlli	:	STD_LOGIC := '0';
	 SIGNAL	nlOiOil	:	STD_LOGIC := '0';
	 SIGNAL	nlOiOli	:	STD_LOGIC := '0';
	 SIGNAL	nlOiOll	:	STD_LOGIC := '0';
	 SIGNAL	nlOiOlO	:	STD_LOGIC := '0';
	 SIGNAL	nlOiOOi	:	STD_LOGIC := '0';
	 SIGNAL	nlOiOOl	:	STD_LOGIC := '0';
	 SIGNAL	nlOiOOO	:	STD_LOGIC := '0';
	 SIGNAL	nlOl00i	:	STD_LOGIC := '0';
	 SIGNAL	nlOl00l	:	STD_LOGIC := '0';
	 SIGNAL	nlOl00O	:	STD_LOGIC := '0';
	 SIGNAL	nlOl01i	:	STD_LOGIC := '0';
	 SIGNAL	nlOl01l	:	STD_LOGIC := '0';
	 SIGNAL	nlOl01O	:	STD_LOGIC := '0';
	 SIGNAL	nlOl0ii	:	STD_LOGIC := '0';
	 SIGNAL	nlOl0il	:	STD_LOGIC := '0';
	 SIGNAL	nlOl0iO	:	STD_LOGIC := '0';
	 SIGNAL	nlOl0li	:	STD_LOGIC := '0';
	 SIGNAL	nlOl0ll	:	STD_LOGIC := '0';
	 SIGNAL	nlOl0lO	:	STD_LOGIC := '0';
	 SIGNAL	nlOl0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nlOl0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlOl10i	:	STD_LOGIC := '0';
	 SIGNAL	nlOl10l	:	STD_LOGIC := '0';
	 SIGNAL	nlOl10O	:	STD_LOGIC := '0';
	 SIGNAL	nlOl11i	:	STD_LOGIC := '0';
	 SIGNAL	nlOl11l	:	STD_LOGIC := '0';
	 SIGNAL	nlOl11O	:	STD_LOGIC := '0';
	 SIGNAL	nlOl1ii	:	STD_LOGIC := '0';
	 SIGNAL	nlOl1il	:	STD_LOGIC := '0';
	 SIGNAL	nlOl1iO	:	STD_LOGIC := '0';
	 SIGNAL	nlOl1li	:	STD_LOGIC := '0';
	 SIGNAL	nlOl1ll	:	STD_LOGIC := '0';
	 SIGNAL	nlOl1lO	:	STD_LOGIC := '0';
	 SIGNAL	nlOl1Oi	:	STD_LOGIC := '0';
	 SIGNAL	nlOl1Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlOl1OO	:	STD_LOGIC := '0';
	 SIGNAL	nlOlill	:	STD_LOGIC := '0';
	 SIGNAL	nlOliOl	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlOliOi_PRN	:	STD_LOGIC;
	 SIGNAL  wire_nlOliOi_w_lg_nlOliOl2139w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0110i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0110l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0liOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oi0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oi0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oi0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Olii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Olil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Olli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Olll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1100i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1100l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1100O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1101i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1110i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1110l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1111i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1111l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1111O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1illi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1illl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1illO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1ll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1O1ll_w_lg_dataout1963w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1O1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1Oi1O_w_lg_dataout2151w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1Oiil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1Oiil_w_lg_dataout1964w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1Oiil_w_lg_dataout2152w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1Oiil_w_lg_dataout1939w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1OiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Olii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Olli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1Olli_w_lg_dataout2356w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1Olll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1Olll_w_lg_dataout2357w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1OlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni000O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni100i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni100l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni100O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni101O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nililO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl00O_w_lg_dataout123w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl00Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl0i_w_lg_dataout4w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl0i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl0ii_w_lg_w_lg_dataout138w141w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0ii_w_lg_dataout138w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl0iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOlO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliOlO_w_lg_dataout544w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliOOi_w_lg_dataout733w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOOi_w_lg_dataout924w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nliOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllli0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllli0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllli0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllli1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllli1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllli1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO001i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO00il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0Oil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO0Oil_w_lg_w_lg_dataout2541w2543w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0Oil_w_lg_dataout2541w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlO0OiO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO0OiO_w_lg_w_lg_w_lg_dataout2540w2544w2545w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0OiO_w_lg_w_lg_dataout2540w2544w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0OiO_w_lg_dataout2540w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlO0Oli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO0Oli_w_lg_w_lg_dataout2226w2227w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0Oli_w_lg_w_lg_dataout2226w2232w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0Oli_w_lg_dataout2226w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlO0Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0OlO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO0OlO_w_lg_dataout2225w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlO100i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO100l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO100O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO110i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO110l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO111i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO111l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO111O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi10l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOi10l_w_lg_dataout2551w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlOi10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi11i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOi11i_w_lg_dataout1990w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlOi11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0O0li_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0O0li_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_gnd	:	STD_LOGIC;
	 SIGNAL  wire_n0O0li_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0OOOO_w_lg_w_o_range1678w1682w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0OOOO_w_lg_w_lg_w_o_range1679w1680w1681w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0OOOO_w_lg_w_o_range1679w1680w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0OOOO_a	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_n0OOOO_b	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_n0OOOO_o	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_n0OOOO_w_o_range1679w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0OOOO_w_o_range1678w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1010i_a	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n1010i_b	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n1010i_o	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n1l0lO_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1l0lO_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1l0lO_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1O1OO_w_lg_w_o_range3053w3057w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O1OO_w_lg_w_lg_w_o_range3054w3055w3056w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O1OO_w_lg_w_o_range3054w3055w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O1OO_a	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_n1O1OO_b	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_n1O1OO_o	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_n1O1OO_w_o_range3054w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O1OO_w_o_range3053w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni01ii_a	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_ni01ii_b	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_ni01ii_o	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_ni01il_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_ni01il_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_ni01il_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_ni1lii_a	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_ni1lii_b	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_ni1lii_o	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_ni1lil_w_lg_w_o_range869w870w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1lil_w_lg_w_o_range872w873w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1lil_w_lg_w_o_range875w876w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1lil_w_lg_w_o_range878w879w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1lil_w_lg_w_o_range881w882w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1lil_a	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_ni1lil_b	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_ni1lil_o	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_ni1lil_w_o_range869w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1lil_w_o_range872w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1lil_w_o_range875w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1lil_w_o_range878w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1lil_w_o_range881w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1liO_a	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_ni1liO_b	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_ni1liO_o	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nl0OOi_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0OOi_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0OOi_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nli1iO_w_lg_w_o_range1314w1318w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1iO_w_lg_w_lg_w_o_range1315w1316w1317w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1iO_w_lg_w_o_range1315w1316w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1iO_a	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nli1iO_b	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nli1iO_o	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nli1iO_w_o_range1315w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1iO_w_o_range1314w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllliii_a	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nllliii_b	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nllliii_o	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nllliil_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllliil_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllliil_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllliOl_a	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllliOl_b	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllliOl_o	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllll1i_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllll1i_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllll1i_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nlO000i_w_lg_w_o_range2309w2310w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO000i_w_lg_w_o_range2312w2313w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO000i_w_lg_w_o_range2315w2316w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO000i_w_lg_w_o_range2318w2319w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO000i_w_lg_w_o_range2321w2322w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO000i_a	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nlO000i_b	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nlO000i_o	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nlO000i_w_o_range2309w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO000i_w_o_range2312w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO000i_w_o_range2315w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO000i_w_o_range2318w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO000i_w_o_range2321w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO000l_a	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nlO000l_b	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nlO000l_o	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nlO001O_a	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nlO001O_b	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nlO001O_o	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nlO0lli_w_lg_w_o_range3109w3113w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0lli_w_lg_w_lg_w_o_range3110w3111w3112w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0lli_w_lg_w_o_range3110w3111w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0lli_a	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nlO0lli_b	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nlO0lli_o	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_nlO0lli_w_o_range3110w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0lli_w_o_range3109w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO101i_a	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nlO101i_b	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nlO101i_o	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nlO10iO_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nlO10iO_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nlO10iO_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n011iO_i	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n011iO_o	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n011ll_i	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n011ll_o	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n011Oi_i	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n011Oi_o	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n0OO1l_i	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0OO1l_o	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n1l00O_i	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1l00O_o	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n1l01l_i	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1l01l_o	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1l1OO_i	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1l1OO_o	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1OliO_i	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n1OliO_o	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl0O1i_i	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl0O1i_o	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nl0O1O_i	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl0O1O_o	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nl0Oii_i	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0Oii_o	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nliO01i_i	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nliO01i_o	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nliO1lO_i	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nliO1lO_o	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nliO1Ol_i	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nliO1Ol_o	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlli01O_i	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nlli01O_o	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n11iii_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n11iii_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n11iii_o	:	STD_LOGIC;
	 SIGNAL  wire_n1O01i_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1O01i_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_vcc	:	STD_LOGIC;
	 SIGNAL  wire_n1O01i_o	:	STD_LOGIC;
	 SIGNAL  wire_n1O10l_a	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n1O10l_b	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n1O10l_o	:	STD_LOGIC;
	 SIGNAL  wire_n1O11l_a	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n1O11l_b	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n1O11l_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OllO_w_lg_o2370w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1OllO_w_lg_o2547w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1OllO_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1OllO_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1OllO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OlOi_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1OlOi_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1OlOi_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OOlO_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1OOlO_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1OOlO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OOOi_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1OOOi_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1OOOi_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1i1i_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_ni1i1i_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_ni1i1i_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1lli_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_ni1lli_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_ni1lli_o	:	STD_LOGIC;
	 SIGNAL  wire_nli1li_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nli1li_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nli1li_o	:	STD_LOGIC;
	 SIGNAL  wire_nlilOi_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nlilOi_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nlilOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nlli0iO_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nlli0iO_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nlli0iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nllOii_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllOii_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllOii_o	:	STD_LOGIC;
	 SIGNAL  wire_nllOil_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllOil_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllOil_o	:	STD_LOGIC;
	 SIGNAL  wire_nllOiO_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllOiO_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllOiO_o	:	STD_LOGIC;
	 SIGNAL  wire_nllOli_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllOli_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllOli_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO000O_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nlO000O_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nlO000O_o	:	STD_LOGIC;
	 SIGNAL  wire_nllOOO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllOOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nllOOO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlO11i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO11i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO11i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlO11l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO11l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO11l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlO11O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO11O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO11O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllOll_data_in	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nllOll_data_out1	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nllOll_data_out2	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nllOll_fifo_re1	:	STD_LOGIC_VECTOR (19 DOWNTO 0);
	 SIGNAL  wire_nllOll_fifo_re2	:	STD_LOGIC_VECTOR (19 DOWNTO 0);
	 SIGNAL  wire_nllOll_fifo_wr	:	STD_LOGIC_VECTOR (19 DOWNTO 0);
	 SIGNAL  wire_nllOll_rst_l	:	STD_LOGIC;
	 SIGNAL  wire_nllOlO_data_in	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nllOlO_data_out1	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nllOlO_data_out2	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nllOlO_fifo_re1	:	STD_LOGIC_VECTOR (19 DOWNTO 0);
	 SIGNAL  wire_nllOlO_fifo_re2	:	STD_LOGIC_VECTOR (19 DOWNTO 0);
	 SIGNAL  wire_nllOlO_fifo_wr	:	STD_LOGIC_VECTOR (19 DOWNTO 0);
	 SIGNAL  wire_nllOlO_rst_l	:	STD_LOGIC;
	 SIGNAL  wire_w1975w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_rauto_speed_ena7w18w19w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_rclkcmpsqmd1966w1970w1971w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_rskpsetbased1945w1946w1947w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_rclkcmpsqmd1941w1942w1943w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_rclkcmpsqmd1941w1960w1961w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rauto_speed_ena7w18w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rclkcmpsqmd1966w1970w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rskpsetbased1945w1946w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlii1li1993w1994w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nliliil440w441w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlillii120w2153w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rclkcmpsqmd1941w1942w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rclkcmpsqmd1941w1960w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rgenericfifo32w2464w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rgenericfifo32w754w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rrx_pipe_enable1940w1944w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rrx_pipe_enable1940w2367w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rskpsetbased1866w1962w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rskpsetbased1866w2358w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rtruebac2bac1950w1968w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rtruebac2bac1950w2365w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_dskwclksel_range33w34w35w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_rskpsetbased2364w2368w2369w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_cg_comp_rd_d_ch01956w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_cg_comp_rd_d_ch21957w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_cg_comp_rd_d_ch31958w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_cg_comp_wr_ch02351w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_cg_comp_wr_ch22352w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_cg_comp_wr_ch32353w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nli0O1i2546w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlii0Oi1973w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlii0Ol1972w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliiOii734w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliiOli735w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlillil2355w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rauto_speed_ena7w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rclkcmpsqmd1966w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rgenericfifo756w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rgenericfifo2466w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rmatchen2150w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rrx_pipe_enable2542w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rskpsetbased1945w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rskpsetbased2366w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rskpsetbased2364w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rtruebac2bac2363w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_hard_reset25w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_is_lane01987w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nli0iii2509w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nli0l0i2528w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nli0l0l2557w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nli0l1O2424w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nli0liO2281w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nli0lli2279w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nli0lll2277w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nli0llO2275w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nli0Oli2135w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nli0OlO3183w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlii1li1993w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlii1Oi2147w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliii0i2234w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliil0O841w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliilii839w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliilil837w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliiliO835w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliilli968w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliilll798w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliilOO744w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliiO0O726w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlil00O1789w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlil0iO547w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliliii460w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliliil440w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlill0O122w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlillii120w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlilO0l1955w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliO1il2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rclkcmpinsertpad655w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rclkcmpsqmd1941w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rfreq_sel6w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rgenericfifo32w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rmatchen438w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rrx_pipe_enable1940w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rskpsetbased1866w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rtruebac2bac1950w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_dskwclksel_range33w34w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w1975w1976w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_rauto_speed_ena7w18w19w20w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_rskpsetbased1866w2358w2359w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_dskwclksel_range33w34w35w36w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlii0Ol1972w1974w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rskpsetbased2364w2368w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlilO0l1955w2350w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_nlilO0l1955w2350w2354w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlii1Oi1977w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlii1Ol1978w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rtruebac2bac1969w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  nli00ll :	STD_LOGIC;
	 SIGNAL  nli00lO :	STD_LOGIC;
	 SIGNAL  nli00Oi :	STD_LOGIC;
	 SIGNAL  nli00Ol :	STD_LOGIC;
	 SIGNAL  nli00OO :	STD_LOGIC;
	 SIGNAL  nli0i0i :	STD_LOGIC;
	 SIGNAL  nli0i0l :	STD_LOGIC;
	 SIGNAL  nli0i0O :	STD_LOGIC;
	 SIGNAL  nli0i1i :	STD_LOGIC;
	 SIGNAL  nli0i1l :	STD_LOGIC;
	 SIGNAL  nli0i1O :	STD_LOGIC;
	 SIGNAL  nli0iii :	STD_LOGIC;
	 SIGNAL  nli0iil :	STD_LOGIC;
	 SIGNAL  nli0iiO :	STD_LOGIC;
	 SIGNAL  nli0ili :	STD_LOGIC;
	 SIGNAL  nli0ill :	STD_LOGIC;
	 SIGNAL  nli0ilO :	STD_LOGIC;
	 SIGNAL  nli0iOi :	STD_LOGIC;
	 SIGNAL  nli0iOl :	STD_LOGIC;
	 SIGNAL  nli0iOO :	STD_LOGIC;
	 SIGNAL  nli0l0i :	STD_LOGIC;
	 SIGNAL  nli0l0l :	STD_LOGIC;
	 SIGNAL  nli0l0O :	STD_LOGIC;
	 SIGNAL  nli0l1i :	STD_LOGIC;
	 SIGNAL  nli0l1l :	STD_LOGIC;
	 SIGNAL  nli0l1O :	STD_LOGIC;
	 SIGNAL  nli0lii :	STD_LOGIC;
	 SIGNAL  nli0lil :	STD_LOGIC;
	 SIGNAL  nli0liO :	STD_LOGIC;
	 SIGNAL  nli0lli :	STD_LOGIC;
	 SIGNAL  nli0lll :	STD_LOGIC;
	 SIGNAL  nli0llO :	STD_LOGIC;
	 SIGNAL  nli0lOi :	STD_LOGIC;
	 SIGNAL  nli0lOl :	STD_LOGIC;
	 SIGNAL  nli0lOO :	STD_LOGIC;
	 SIGNAL  nli0O0i :	STD_LOGIC;
	 SIGNAL  nli0O0l :	STD_LOGIC;
	 SIGNAL  nli0O1i :	STD_LOGIC;
	 SIGNAL  nli0O1l :	STD_LOGIC;
	 SIGNAL  nli0O1O :	STD_LOGIC;
	 SIGNAL  nli0Oii :	STD_LOGIC;
	 SIGNAL  nli0Oil :	STD_LOGIC;
	 SIGNAL  nli0OiO :	STD_LOGIC;
	 SIGNAL  nli0Oli :	STD_LOGIC;
	 SIGNAL  nli0Oll :	STD_LOGIC;
	 SIGNAL  nli0OlO :	STD_LOGIC;
	 SIGNAL  nli0OOi :	STD_LOGIC;
	 SIGNAL  nli0OOl :	STD_LOGIC;
	 SIGNAL  nli0OOO :	STD_LOGIC;
	 SIGNAL  nlii00i :	STD_LOGIC;
	 SIGNAL  nlii00l :	STD_LOGIC;
	 SIGNAL  nlii00O :	STD_LOGIC;
	 SIGNAL  nlii01i :	STD_LOGIC;
	 SIGNAL  nlii01l :	STD_LOGIC;
	 SIGNAL  nlii01O :	STD_LOGIC;
	 SIGNAL  nlii0ii :	STD_LOGIC;
	 SIGNAL  nlii0il :	STD_LOGIC;
	 SIGNAL  nlii0iO :	STD_LOGIC;
	 SIGNAL  nlii0li :	STD_LOGIC;
	 SIGNAL  nlii0ll :	STD_LOGIC;
	 SIGNAL  nlii0lO :	STD_LOGIC;
	 SIGNAL  nlii0Oi :	STD_LOGIC;
	 SIGNAL  nlii0Ol :	STD_LOGIC;
	 SIGNAL  nlii0OO :	STD_LOGIC;
	 SIGNAL  nlii10i :	STD_LOGIC;
	 SIGNAL  nlii10l :	STD_LOGIC;
	 SIGNAL  nlii10O :	STD_LOGIC;
	 SIGNAL  nlii11i :	STD_LOGIC;
	 SIGNAL  nlii11l :	STD_LOGIC;
	 SIGNAL  nlii11O :	STD_LOGIC;
	 SIGNAL  nlii1ii :	STD_LOGIC;
	 SIGNAL  nlii1il :	STD_LOGIC;
	 SIGNAL  nlii1iO :	STD_LOGIC;
	 SIGNAL  nlii1li :	STD_LOGIC;
	 SIGNAL  nlii1ll :	STD_LOGIC;
	 SIGNAL  nlii1lO :	STD_LOGIC;
	 SIGNAL  nlii1Oi :	STD_LOGIC;
	 SIGNAL  nlii1Ol :	STD_LOGIC;
	 SIGNAL  nlii1OO :	STD_LOGIC;
	 SIGNAL  nliii0i :	STD_LOGIC;
	 SIGNAL  nliii0l :	STD_LOGIC;
	 SIGNAL  nliii0O :	STD_LOGIC;
	 SIGNAL  nliii1i :	STD_LOGIC;
	 SIGNAL  nliii1l :	STD_LOGIC;
	 SIGNAL  nliii1O :	STD_LOGIC;
	 SIGNAL  nliiiii :	STD_LOGIC;
	 SIGNAL  nliiiil :	STD_LOGIC;
	 SIGNAL  nliiiiO :	STD_LOGIC;
	 SIGNAL  nliiili :	STD_LOGIC;
	 SIGNAL  nliiill :	STD_LOGIC;
	 SIGNAL  nliiilO :	STD_LOGIC;
	 SIGNAL  nliiiOi :	STD_LOGIC;
	 SIGNAL  nliiiOl :	STD_LOGIC;
	 SIGNAL  nliiiOO :	STD_LOGIC;
	 SIGNAL  nliil0i :	STD_LOGIC;
	 SIGNAL  nliil0l :	STD_LOGIC;
	 SIGNAL  nliil0O :	STD_LOGIC;
	 SIGNAL  nliil1O :	STD_LOGIC;
	 SIGNAL  nliilii :	STD_LOGIC;
	 SIGNAL  nliilil :	STD_LOGIC;
	 SIGNAL  nliiliO :	STD_LOGIC;
	 SIGNAL  nliilli :	STD_LOGIC;
	 SIGNAL  nliilll :	STD_LOGIC;
	 SIGNAL  nliillO :	STD_LOGIC;
	 SIGNAL  nliilOi :	STD_LOGIC;
	 SIGNAL  nliilOl :	STD_LOGIC;
	 SIGNAL  nliilOO :	STD_LOGIC;
	 SIGNAL  nliiO0i :	STD_LOGIC;
	 SIGNAL  nliiO0l :	STD_LOGIC;
	 SIGNAL  nliiO0O :	STD_LOGIC;
	 SIGNAL  nliiO1i :	STD_LOGIC;
	 SIGNAL  nliiO1l :	STD_LOGIC;
	 SIGNAL  nliiO1O :	STD_LOGIC;
	 SIGNAL  nliiOii :	STD_LOGIC;
	 SIGNAL  nliiOil :	STD_LOGIC;
	 SIGNAL  nliiOiO :	STD_LOGIC;
	 SIGNAL  nliiOli :	STD_LOGIC;
	 SIGNAL  nliiOll :	STD_LOGIC;
	 SIGNAL  nliiOlO :	STD_LOGIC;
	 SIGNAL  nlil00i :	STD_LOGIC;
	 SIGNAL  nlil00l :	STD_LOGIC;
	 SIGNAL  nlil00O :	STD_LOGIC;
	 SIGNAL  nlil01i :	STD_LOGIC;
	 SIGNAL  nlil01O :	STD_LOGIC;
	 SIGNAL  nlil0ii :	STD_LOGIC;
	 SIGNAL  nlil0il :	STD_LOGIC;
	 SIGNAL  nlil0iO :	STD_LOGIC;
	 SIGNAL  nlil0lO :	STD_LOGIC;
	 SIGNAL  nlil0Oi :	STD_LOGIC;
	 SIGNAL  nlil10i :	STD_LOGIC;
	 SIGNAL  nlil10l :	STD_LOGIC;
	 SIGNAL  nlil10O :	STD_LOGIC;
	 SIGNAL  nlil11i :	STD_LOGIC;
	 SIGNAL  nlil11l :	STD_LOGIC;
	 SIGNAL  nlil11O :	STD_LOGIC;
	 SIGNAL  nlil1ii :	STD_LOGIC;
	 SIGNAL  nlil1il :	STD_LOGIC;
	 SIGNAL  nlil1iO :	STD_LOGIC;
	 SIGNAL  nlil1li :	STD_LOGIC;
	 SIGNAL  nlil1ll :	STD_LOGIC;
	 SIGNAL  nlil1lO :	STD_LOGIC;
	 SIGNAL  nlil1Oi :	STD_LOGIC;
	 SIGNAL  nlil1Ol :	STD_LOGIC;
	 SIGNAL  nlil1OO :	STD_LOGIC;
	 SIGNAL  nlili0i :	STD_LOGIC;
	 SIGNAL  nlili1i :	STD_LOGIC;
	 SIGNAL  nlili1l :	STD_LOGIC;
	 SIGNAL  nlili1O :	STD_LOGIC;
	 SIGNAL  nliliii :	STD_LOGIC;
	 SIGNAL  nliliil :	STD_LOGIC;
	 SIGNAL  nliliiO :	STD_LOGIC;
	 SIGNAL  nlilili :	STD_LOGIC;
	 SIGNAL  nlill0O :	STD_LOGIC;
	 SIGNAL  nlillii :	STD_LOGIC;
	 SIGNAL  nlillil :	STD_LOGIC;
	 SIGNAL  nlillOi :	STD_LOGIC;
	 SIGNAL  nlillOl :	STD_LOGIC;
	 SIGNAL  nlillOO :	STD_LOGIC;
	 SIGNAL  nlilO0l :	STD_LOGIC;
	 SIGNAL  nlilOil :	STD_LOGIC;
	 SIGNAL  nlilOiO :	STD_LOGIC;
	 SIGNAL  nliO10l :	STD_LOGIC;
	 SIGNAL  nliO11i :	STD_LOGIC;
	 SIGNAL  nliO1il :	STD_LOGIC;
	 SIGNAL  wire_w_dskwclksel_range33w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rdel_threshold_range361w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 COMPONENT  stratixiv_hssi_rx_digis_ram20x16_syn
	 GENERIC 
	 (
		ram_width	:	NATURAL;
		read_access_time	:	NATURAL;
		write_access_time	:	NATURAL
	 );
	 PORT
	 ( 
		clk	:	IN STD_LOGIC;
		data_in	:	IN STD_LOGIC_VECTOR(15 DOWNTO 0);
		data_out1	:	OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
		data_out2	:	OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
		fifo_re1	:	IN STD_LOGIC_VECTOR(19 DOWNTO 0);
		fifo_re2	:	IN STD_LOGIC_VECTOR(19 DOWNTO 0);
		fifo_wr	:	IN STD_LOGIC_VECTOR(19 DOWNTO 0);
		rst_l	:	IN STD_LOGIC
	 ); 
	 END COMPONENT;
 BEGIN

	wire_gnd <= '0';
	wire_vcc <= '1';
	wire_w1975w(0) <= wire_w_lg_w_lg_w_lg_rclkcmpsqmd1966w1970w1971w(0) AND wire_w_lg_w_lg_nlii0Ol1972w1974w(0);
	wire_w_lg_w_lg_w_lg_rauto_speed_ena7w18w19w(0) <= wire_w_lg_w_lg_rauto_speed_ena7w18w(0) AND nlll;
	wire_w_lg_w_lg_w_lg_rclkcmpsqmd1966w1970w1971w(0) <= wire_w_lg_w_lg_rclkcmpsqmd1966w1970w(0) AND n1liil;
	wire_w_lg_w_lg_w_lg_rskpsetbased1945w1946w1947w(0) <= wire_w_lg_w_lg_rskpsetbased1945w1946w(0) AND wire_n1O10l_o;
	wire_w_lg_w_lg_w_lg_rclkcmpsqmd1941w1942w1943w(0) <= wire_w_lg_w_lg_rclkcmpsqmd1941w1942w(0) AND nlii1OO;
	wire_w_lg_w_lg_w_lg_rclkcmpsqmd1941w1960w1961w(0) <= wire_w_lg_w_lg_rclkcmpsqmd1941w1960w(0) AND nlii1OO;
	wire_w_lg_w_lg_rauto_speed_ena7w18w(0) <= wire_w_lg_rauto_speed_ena7w(0) AND wire_nlilOlO12_w_lg_q17w(0);
	wire_w_lg_w_lg_rclkcmpsqmd1966w1970w(0) <= wire_w_lg_rclkcmpsqmd1966w(0) AND wire_w_lg_rtruebac2bac1969w(0);
	wire_w_lg_w_lg_rskpsetbased1945w1946w(0) <= wire_w_lg_rskpsetbased1945w(0) AND n1liil;
	wire_w_lg_w_lg_nlii1li1993w1994w(0) <= wire_w_lg_nlii1li1993w(0) AND wire_n1li1O_dataout;
	wire_w_lg_w_lg_nliliil440w441w(0) <= wire_w_lg_nliliil440w(0) AND nliliii;
	wire_w_lg_w_lg_nlillii120w2153w(0) <= wire_w_lg_nlillii120w(0) AND wire_n1Oiil_w_lg_dataout2152w(0);
	wire_w_lg_w_lg_rclkcmpsqmd1941w1942w(0) <= wire_w_lg_rclkcmpsqmd1941w(0) AND wire_w_lg_nlillii120w(0);
	wire_w_lg_w_lg_rclkcmpsqmd1941w1960w(0) <= wire_w_lg_rclkcmpsqmd1941w(0) AND wire_n1O1lO_dataout;
	wire_w_lg_w_lg_rgenericfifo32w2464w(0) <= wire_w_lg_rgenericfifo32w(0) AND nli0l1O;
	wire_w_lg_w_lg_rgenericfifo32w754w(0) <= wire_w_lg_rgenericfifo32w(0) AND nliilOO;
	wire_w_lg_w_lg_rrx_pipe_enable1940w1944w(0) <= wire_w_lg_rrx_pipe_enable1940w(0) AND wire_w_lg_w_lg_w_lg_rclkcmpsqmd1941w1942w1943w(0);
	wire_w_lg_w_lg_rrx_pipe_enable1940w2367w(0) <= wire_w_lg_rrx_pipe_enable1940w(0) AND wire_w_lg_rskpsetbased2366w(0);
	wire_w_lg_w_lg_rskpsetbased1866w1962w(0) <= wire_w_lg_rskpsetbased1866w(0) AND wire_w_lg_w_lg_w_lg_rclkcmpsqmd1941w1960w1961w(0);
	wire_w_lg_w_lg_rskpsetbased1866w2358w(0) <= wire_w_lg_rskpsetbased1866w(0) AND wire_n1Olll_w_lg_dataout2357w(0);
	wire_w_lg_w_lg_rtruebac2bac1950w1968w(0) <= wire_w_lg_rtruebac2bac1950w(0) AND wire_n1i_w_lg_n11iOO1967w(0);
	wire_w_lg_w_lg_rtruebac2bac1950w2365w(0) <= wire_w_lg_rtruebac2bac1950w(0) AND nlO00Oi;
	wire_w_lg_w_lg_w_dskwclksel_range33w34w35w(0) <= wire_w_lg_w_dskwclksel_range33w34w(0) AND rmatchen;
	wire_w_lg_w_lg_w_lg_rskpsetbased2364w2368w2369w(0) <= wire_w_lg_w_lg_rskpsetbased2364w2368w(0) AND nlO01O;
	wire_w_lg_cg_comp_rd_d_ch01956w(0) <= cg_comp_rd_d_ch0 AND cg_comp_rd_d_ch1;
	wire_w_lg_cg_comp_rd_d_ch21957w(0) <= cg_comp_rd_d_ch2 AND wire_w_lg_cg_comp_rd_d_ch01956w(0);
	wire_w_lg_cg_comp_rd_d_ch31958w(0) <= cg_comp_rd_d_ch3 AND wire_w_lg_cg_comp_rd_d_ch21957w(0);
	wire_w_lg_cg_comp_wr_ch02351w(0) <= cg_comp_wr_ch0 AND cg_comp_wr_ch1;
	wire_w_lg_cg_comp_wr_ch22352w(0) <= cg_comp_wr_ch2 AND wire_w_lg_cg_comp_wr_ch02351w(0);
	wire_w_lg_cg_comp_wr_ch32353w(0) <= cg_comp_wr_ch3 AND wire_w_lg_cg_comp_wr_ch22352w(0);
	wire_w_lg_nli0O1i2546w(0) <= nli0O1i AND wire_nlO0OiO_w_lg_w_lg_w_lg_dataout2540w2544w2545w(0);
	wire_w_lg_nlii0Oi1973w(0) <= nlii0Oi AND nlii1ll;
	wire_w_lg_nlii0Ol1972w(0) <= nlii0Ol AND nlii1lO;
	wire_w_lg_nliiOii734w(0) <= nliiOii AND wire_nliOOi_w_lg_dataout733w(0);
	wire_w_lg_nliiOli735w(0) <= nliiOli AND wire_w_lg_nliiOii734w(0);
	wire_w_lg_nlillil2355w(0) <= nlillil AND wire_w_lg_w_lg_w_lg_nlilO0l1955w2350w2354w(0);
	wire_w_lg_rauto_speed_ena7w(0) <= rauto_speed_ena AND wire_w_lg_rfreq_sel6w(0);
	wire_w_lg_rclkcmpsqmd1966w(0) <= rclkcmpsqmd AND wire_w_lg_nlillii120w(0);
	wire_w_lg_rgenericfifo756w(0) <= rgenericfifo AND wire_nii_w_lg_n0Oiil755w(0);
	wire_w_lg_rgenericfifo2466w(0) <= rgenericfifo AND wire_nii_w_lg_nlll1li2465w(0);
	wire_w_lg_rmatchen2150w(0) <= rmatchen AND rrx_pipe_enable;
	wire_w_lg_rrx_pipe_enable2542w(0) <= rrx_pipe_enable AND nlii0OO;
	wire_w_lg_rskpsetbased1945w(0) <= rskpsetbased AND wire_w_lg_w_lg_rrx_pipe_enable1940w1944w(0);
	wire_w_lg_rskpsetbased2366w(0) <= rskpsetbased AND wire_w_lg_w_lg_rtruebac2bac1950w2365w(0);
	wire_w_lg_rskpsetbased2364w(0) <= rskpsetbased AND wire_w_lg_rtruebac2bac2363w(0);
	wire_w_lg_rtruebac2bac2363w(0) <= rtruebac2bac AND wire_nii_w_lg_nlO00Oi2362w(0);
	wire_w_lg_hard_reset25w(0) <= NOT hard_reset;
	wire_w_lg_is_lane01987w(0) <= NOT is_lane0;
	wire_w_lg_nli0iii2509w(0) <= NOT nli0iii;
	wire_w_lg_nli0l0i2528w(0) <= NOT nli0l0i;
	wire_w_lg_nli0l0l2557w(0) <= NOT nli0l0l;
	wire_w_lg_nli0l1O2424w(0) <= NOT nli0l1O;
	wire_w_lg_nli0liO2281w(0) <= NOT nli0liO;
	wire_w_lg_nli0lli2279w(0) <= NOT nli0lli;
	wire_w_lg_nli0lll2277w(0) <= NOT nli0lll;
	wire_w_lg_nli0llO2275w(0) <= NOT nli0llO;
	wire_w_lg_nli0Oli2135w(0) <= NOT nli0Oli;
	wire_w_lg_nli0OlO3183w(0) <= NOT nli0OlO;
	wire_w_lg_nlii1li1993w(0) <= NOT nlii1li;
	wire_w_lg_nlii1Oi2147w(0) <= NOT nlii1Oi;
	wire_w_lg_nliii0i2234w(0) <= NOT nliii0i;
	wire_w_lg_nliil0O841w(0) <= NOT nliil0O;
	wire_w_lg_nliilii839w(0) <= NOT nliilii;
	wire_w_lg_nliilil837w(0) <= NOT nliilil;
	wire_w_lg_nliiliO835w(0) <= NOT nliiliO;
	wire_w_lg_nliilli968w(0) <= NOT nliilli;
	wire_w_lg_nliilll798w(0) <= NOT nliilll;
	wire_w_lg_nliilOO744w(0) <= NOT nliilOO;
	wire_w_lg_nliiO0O726w(0) <= NOT nliiO0O;
	wire_w_lg_nlil00O1789w(0) <= NOT nlil00O;
	wire_w_lg_nlil0iO547w(0) <= NOT nlil0iO;
	wire_w_lg_nliliii460w(0) <= NOT nliliii;
	wire_w_lg_nliliil440w(0) <= NOT nliliil;
	wire_w_lg_nlill0O122w(0) <= NOT nlill0O;
	wire_w_lg_nlillii120w(0) <= NOT nlillii;
	wire_w_lg_nlilO0l1955w(0) <= NOT nlilO0l;
	wire_w_lg_nliO1il2w(0) <= NOT nliO1il;
	wire_w_lg_rclkcmpinsertpad655w(0) <= NOT rclkcmpinsertpad;
	wire_w_lg_rclkcmpsqmd1941w(0) <= NOT rclkcmpsqmd;
	wire_w_lg_rfreq_sel6w(0) <= NOT rfreq_sel;
	wire_w_lg_rgenericfifo32w(0) <= NOT rgenericfifo;
	wire_w_lg_rmatchen438w(0) <= NOT rmatchen;
	wire_w_lg_rrx_pipe_enable1940w(0) <= NOT rrx_pipe_enable;
	wire_w_lg_rskpsetbased1866w(0) <= NOT rskpsetbased;
	wire_w_lg_rtruebac2bac1950w(0) <= NOT rtruebac2bac;
	wire_w_lg_w_dskwclksel_range33w34w(0) <= NOT wire_w_dskwclksel_range33w(0);
	wire_w_lg_w1975w1976w(0) <= wire_w1975w(0) OR n11O1l;
	wire_w_lg_w_lg_w_lg_w_lg_rauto_speed_ena7w18w19w20w(0) <= wire_w_lg_w_lg_w_lg_rauto_speed_ena7w18w19w(0) OR rdwidth_rx;
	wire_w_lg_w_lg_w_lg_rskpsetbased1866w2358w2359w(0) <= wire_w_lg_w_lg_rskpsetbased1866w2358w(0) OR nlO1i0O;
	wire_w_lg_w_lg_w_lg_w_dskwclksel_range33w34w35w36w(0) <= wire_w_lg_w_lg_w_dskwclksel_range33w34w35w(0) OR nlilO0l;
	wire_w_lg_w_lg_nlii0Ol1972w1974w(0) <= wire_w_lg_nlii0Ol1972w(0) OR wire_w_lg_nlii0Oi1973w(0);
	wire_w_lg_w_lg_rskpsetbased2364w2368w(0) <= wire_w_lg_rskpsetbased2364w(0) OR wire_w_lg_w_lg_rrx_pipe_enable1940w2367w(0);
	wire_w_lg_w_lg_nlilO0l1955w2350w(0) <= wire_w_lg_nlilO0l1955w(0) OR nliii0i;
	wire_w_lg_w_lg_w_lg_nlilO0l1955w2350w2354w(0) <= wire_w_lg_w_lg_nlilO0l1955w2350w(0) OR wire_w_lg_cg_comp_wr_ch32353w(0);
	wire_w_lg_nlii1Oi1977w(0) <= nlii1Oi OR nlO00OO;
	wire_w_lg_nlii1Ol1978w(0) <= nlii1Ol OR wire_w_lg_nlii1Oi1977w(0);
	wire_w_lg_rtruebac2bac1969w(0) <= rtruebac2bac OR wire_w_lg_w_lg_rtruebac2bac1950w1968w(0);
	align_status_sync <= nlOiO0O;
	cg_comp_rd_d_out <= wire_n1Oiil_dataout;
	cg_comp_wr_out <= nlillil;
	comp_curr_st <= ( nlO01l & nllOOl);
	cudi <= ( wire_niOi_dataout & wire_nilO_dataout & wire_nill_dataout & wire_nili_dataout & wire_niiO_dataout & wire_niil_dataout & wire_niii_dataout & wire_ni0O_dataout & wire_ni0l_dataout & wire_ni0i_dataout & wire_ni1O_dataout & wire_ni1l_dataout & wire_ni1i_dataout & wire_n0OO_dataout & wire_n0Ol_dataout & wire_n0Oi_dataout & wire_n0lO_dataout & wire_n0ll_dataout & wire_n0li_dataout & wire_n0iO_dataout & wire_n0il_dataout & wire_n0ii_dataout & wire_n00O_dataout & wire_n00l_dataout & wire_n00i_dataout & wire_n01O_dataout & wire_n01l_dataout & wire_n01i_dataout & wire_n1OO_dataout & wire_n1Ol_dataout & wire_n1Oi_dataout & wire_n1lO_dataout);
	cudi_valid <= wire_niiOi_dataout;
	del_cond_met_out <= wire_n1OllO_o;
	fifo_cnt <= ( wire_nl1O_dataout & wire_nl1l_dataout & wire_nl1i_dataout & wire_niOO_dataout & wire_niOl_dataout);
	fifo_ovr_out <= nlO01O;
	fifo_rd_out_comp <= n1lili;
	insert_incomplete_out <= n1liil;
	latency_comp_out <= wire_w_lg_nlillii120w(0);
	nli00ll <= (nlO10lO XOR nlO10li);
	nli00lO <= (((((((((wire_nlli01O_o(18) OR wire_nlli01O_o(17)) OR wire_nlli01O_o(14)) OR wire_nlli01O_o(13)) OR wire_nlli01O_o(10)) OR wire_nlli01O_o(9)) OR wire_nlli01O_o(6)) OR wire_nlli01O_o(5)) OR wire_nlli01O_o(2)) OR wire_nlli01O_o(1));
	nli00Oi <= ((((((((((wire_nlli01O_o(20) OR wire_nlli01O_o(19)) OR wire_nlli01O_o(12)) OR wire_nlli01O_o(11)) OR wire_nlli01O_o(4)) OR wire_nlli01O_o(3)) OR wire_nlli01O_o(18)) OR wire_nlli01O_o(13)) OR wire_nlli01O_o(10)) OR wire_nlli01O_o(5)) OR wire_nlli01O_o(2));
	nli00Ol <= ((((((((wire_nlli01O_o(20) OR wire_nlli01O_o(11)) OR wire_nlli01O_o(8)) OR wire_nlli01O_o(7)) OR wire_nlli01O_o(4)) OR wire_nlli01O_o(10)) OR wire_nlli01O_o(9)) OR wire_nlli01O_o(6)) OR wire_nlli01O_o(5));
	nli00OO <= ((((((((((((wire_nlli01O_o(20) OR wire_nlli01O_o(19)) OR wire_nlli01O_o(16)) OR wire_nlli01O_o(15)) OR wire_nlli01O_o(12)) OR wire_nlli01O_o(11)) OR wire_nlli01O_o(8)) OR wire_nlli01O_o(18)) OR wire_nlli01O_o(17)) OR wire_nlli01O_o(14)) OR wire_nlli01O_o(13)) OR wire_nlli01O_o(10)) OR wire_nlli01O_o(9));
	nli0i0i <= (wire_n1OlOi_o OR nllil1i);
	nli0i0l <= (wire_n1OllO_o OR nllil1O);
	nli0i0O <= ((((nlll1iO OR nlll1il) OR nlll1ii) OR nlll10O) OR nlll10l);
	nli0i1i <= ((((wire_nlli01O_o(20) OR wire_nlli01O_o(19)) OR wire_nlli01O_o(16)) OR wire_nlli01O_o(18)) OR wire_nlli01O_o(17));
	nli0i1l <= (nli0l0i OR nlli0Oi);
	nli0i1O <= ((((wire_nlO0lli_w_lg_w_o_range3109w3113w(0) AND (NOT (wire_nlO0lli_o(2) XOR nllii0l))) AND (NOT (wire_nlO0lli_o(3) XOR nllii0O))) AND (NOT (wire_nlO0lli_o(4) XOR nlliiii))) AND (NOT (wire_nlO0lli_o(5) XOR nlliiil)));
	nli0iii <= ((((wire_nii_w_lg_nlll1iO3164w(0) AND wire_nii_w_lg_nlll1il3165w(0)) AND wire_nii_w_lg_nlll1ii3167w(0)) AND wire_nii_w_lg_nlll10O3169w(0)) AND wire_nii_w_lg_nlll10l3171w(0));
	nli0iil <= ((wire_w_lg_rclkcmpsqmd1941w(0) AND (wire_w_lg_w_lg_rgenericfifo32w2464w(0) OR wire_w_lg_rgenericfifo2466w(0))) AND nli0ill);
	nli0iiO <= (nli0l1i AND nli0ill);
	nli0ili <= ((rclkcmpsqmd AND (nli0l1O AND (nlillOl OR nllil0l))) AND nli0ill);
	nli0ill <= (wire_w_lg_rskpsetbased1866w(0) OR wire_w_lg_nli0l0i2528w(0));
	nli0ilO <= ((rskpsetbased OR (wire_w_lg_rskpsetbased1866w(0) AND wire_w_lg_nli0l1O2424w(0))) AND nli0l0i);
	nli0iOi <= ((wire_w_lg_rgenericfifo32w(0) AND wire_w_lg_nli0l1O2424w(0)) OR (rgenericfifo AND nlll1li));
	nli0iOl <= ((((wire_nii_w_lg_nlllO0i2304w(0) AND wire_nii_w_lg_nlllO1O2302w(0)) AND wire_nii_w_lg_nlllO1l2300w(0)) AND wire_nii_w_lg_nlllO1i2298w(0)) AND wire_nii_w_lg_nllllli2296w(0));
	nli0iOO <= (wire_w_lg_rgenericfifo32w(0) AND nli0l1i);
	nli0l0i <= ((wire_w_lg_nli0l0l2557w(0) AND (nli0O1O AND nli0i1O)) AND wire_nii_w_lg_nlli0Ol2560w(0));
	nli0l0l <= (wire_w_lg_w_lg_w_lg_rskpsetbased1866w2358w2359w(0) OR wire_n1OllO_w_lg_o2370w(0));
	nli0l0O <= ((((wire_nii_w_lg_nlO011i3144w(0) AND wire_nii_w_lg_nlO1OOO3145w(0)) AND (NOT (rstart_threshold(0) XOR nlO1OiO))) AND (NOT (rstart_threshold(1) XOR nlO1OOi))) AND (NOT (rstart_threshold(2) XOR nlO1OOl)));
	nli0l1i <= (rclkcmpsqmd AND nli0l1O);
	nli0l1l <= (((wire_nii_w_lg_nlllO0i3156w(0) AND wire_nii_w_lg_nlllO1l2300w(0)) AND nlllO1i) AND nllllli);
	nli0l1O <= (nli0l0l OR (rskpsetbased AND nli0l0i));
	nli0lii <= (wire_w_lg_rgenericfifo32w(0) AND wire_nlOi10l_w_lg_dataout2551w(0));
	nli0lil <= (((((NOT (nllllli XOR nli0llO)) AND (NOT (nlllO1i XOR nli0lll))) AND (NOT (nlllO1l XOR nli0lli))) AND (NOT (nlllO1O XOR nli0liO))) AND (NOT (nlO10Oi XOR nlllO0i)));
	nli0liO <= (wire_nii_w_lg_nlO10Oi2283w(0) AND nlO10lO);
	nli0lli <= (wire_nii_w_lg_nlO10Oi2283w(0) AND (nlO10lO XOR nlO10ll));
	nli0lll <= (nlO10Oi XOR (nlO10ll XOR nli00ll));
	nli0llO <= (nlO10Oi XOR (nli00ll XOR (nlO10ll XOR nllO1li)));
	nli0lOi <= ((((((((((NOT (rclkcmpsq1n(0) XOR wire_nlO0lOi_dataout)) AND (NOT (rclkcmpsq1n(1) XOR wire_nlO0lOl_dataout))) AND (NOT (rclkcmpsq1n(2) XOR wire_nlO0lOO_dataout))) AND (NOT (rclkcmpsq1n(3) XOR wire_nlO0O1i_dataout))) AND (NOT (rclkcmpsq1n(4) XOR wire_nlO0O1l_dataout))) AND (NOT (rclkcmpsq1n(5) XOR wire_nlO0O1O_dataout))) AND (NOT (rclkcmpsq1n(6) XOR wire_nlO0O0i_dataout))) AND (NOT (rclkcmpsq1n(7) XOR wire_nlO0O0l_dataout))) AND (NOT (rclkcmpsq1n(8) XOR wire_nlO0O0O_dataout))) AND (NOT (rclkcmpsq1n(9) XOR wire_nlO0Oii_dataout)));
	nli0lOl <= ((((((((((NOT (rclkcmpsq1p(0) XOR wire_nlO0lOi_dataout)) AND (NOT (rclkcmpsq1p(1) XOR wire_nlO0lOl_dataout))) AND (NOT (rclkcmpsq1p(2) XOR wire_nlO0lOO_dataout))) AND (NOT (rclkcmpsq1p(3) XOR wire_nlO0O1i_dataout))) AND (NOT (rclkcmpsq1p(4) XOR wire_nlO0O1l_dataout))) AND (NOT (rclkcmpsq1p(5) XOR wire_nlO0O1O_dataout))) AND (NOT (rclkcmpsq1p(6) XOR wire_nlO0O0i_dataout))) AND (NOT (rclkcmpsq1p(7) XOR wire_nlO0O0l_dataout))) AND (NOT (rclkcmpsq1p(8) XOR wire_nlO0O0O_dataout))) AND (NOT (rclkcmpsq1p(9) XOR wire_nlO0Oii_dataout)));
	nli0lOO <= (nlii0OO AND (wire_w_lg_rclkcmpsqmd1941w(0) OR nlO00ii));
	nli0O0i <= (wire_w_lg_rmatchen438w(0) OR rgenericfifo);
	nli0O0l <= (rmatchen OR rgenericfifo);
	nli0O1i <= (wire_nlO0OlO_w_lg_dataout2225w(0) AND wire_nlO0Oli_w_lg_w_lg_dataout2226w2232w(0));
	nli0O1l <= ((((wire_nlO0lli_w_lg_w_o_range3109w3113w(0) AND (NOT (wire_nlO0lli_o(2) XOR nllii0l))) AND (NOT (wire_nlO0lli_o(3) XOR nllii0O))) AND (NOT (wire_nlO0lli_o(4) XOR nlliiii))) AND (NOT (wire_nlO0lli_o(5) XOR nlliiil)));
	nli0O1O <= (((((NOT (rfull_threshold(0) XOR nlO1OiO)) AND (NOT (rfull_threshold(1) XOR nlO1OOi))) AND (NOT (rfull_threshold(2) XOR nlO1OOl))) AND (NOT (rfull_threshold(3) XOR nlO1OOO))) AND (NOT (rfull_threshold(4) XOR nlO011i)));
	nli0Oii <= (rgenericfifo AND wire_n1i_w_lg_nlOi1iO2142w(0));
	nli0Oil <= ((wire_w_lg_rgenericfifo32w(0) AND wire_w_lg_nlii1li1993w(0)) OR nlOi1iO);
	nli0OiO <= (n110ll OR n110iO);
	nli0Oli <= (wire_n1i_w_lg_n110iO2148w(0) AND (wire_n1i_w_lg_n110ll2149w(0) AND wire_n1i_w_lg_n1liil2154w(0)));
	nli0Oll <= (((((((wire_n1i_w_lg_n11iOl3080w(0) AND wire_n1i_w_lg_n11iOi3081w(0)) AND wire_n1i_w_lg_n11ilO3083w(0)) AND wire_n1i_w_lg_n11ill3085w(0)) AND wire_n1i_w_lg_n11ili3087w(0)) AND wire_n1i_w_lg_n11iiO3089w(0)) AND wire_n1i_w_lg_n11iil3091w(0)) AND wire_n1i_w_lg_n110lO3093w(0));
	nli0OlO <= (rgenericfifo OR wire_nlOi11i_dataout);
	nli0OOi <= (wire_n1O11l_o AND (wire_n1Oiil_dataout AND (NOT ((wire_n1i_w_lg_n11O0l2091w(0) AND wire_n1i_w_lg_n11O0i2092w(0)) AND wire_n1i_w_lg_n11O1O2094w(0)))));
	nli0OOl <= (wire_n1O11l_o AND nlii1Ol);
	nli0OOO <= (wire_n1Oiil_dataout AND wire_n1Oi1O_dataout);
	nlii00i <= ((((wire_nliO1lO_o(13) OR wire_nliO1lO_o(7)) OR wire_nliO1lO_o(4)) OR wire_nliO1lO_o(2)) OR wire_nliO1lO_o(1));
	nlii00l <= (((((((((wire_nliO01i_o(26) OR wire_nliO01i_o(25)) OR wire_nliO01i_o(11)) OR wire_nliO01i_o(8)) OR wire_nliO01i_o(7)) OR wire_nliO01i_o(4)) OR wire_nliO01i_o(14)) OR wire_nliO01i_o(13)) OR wire_nliO01i_o(2)) OR wire_nliO01i_o(1));
	nlii00O <= (wire_w_lg_rgenericfifo32w(0) AND wire_nlOi11i_w_lg_dataout1990w(0));
	nlii01i <= ((((wire_n1O1OO_w_lg_w_o_range3053w3057w(0) AND (NOT (wire_n1O1OO_o(2) XOR nlii00i))) AND (NOT (wire_n1O1OO_o(3) XOR nlii01O))) AND (NOT (wire_n1O1OO_o(4) XOR wire_nliO1Ol_o(1)))) AND (NOT (wire_n1O1OO_o(5) XOR nlii01l)));
	nlii01l <= ((((wire_nliO01i_o(30) OR wire_nliO01i_o(27)) OR wire_nliO01i_o(26)) OR wire_nliO01i_o(25)) OR wire_nliO01i_o(24));
	nlii01O <= ((((((((wire_nliO01i_o(30) OR wire_nliO01i_o(11)) OR wire_nliO01i_o(10)) OR wire_nliO01i_o(9)) OR wire_nliO01i_o(8)) OR wire_nliO01i_o(7)) OR wire_nliO01i_o(6)) OR wire_nliO01i_o(5)) OR wire_nliO01i_o(4));
	nlii0ii <= ((((((((((NOT (rclkcmpsq1n(0) XOR nlOl01O)) AND (NOT (rclkcmpsq1n(1) XOR nlOl00i))) AND (NOT (rclkcmpsq1n(2) XOR nlOl00l))) AND (NOT (rclkcmpsq1n(3) XOR nlOl00O))) AND (NOT (rclkcmpsq1n(4) XOR nlOl0ii))) AND (NOT (rclkcmpsq1n(5) XOR nlOl0il))) AND (NOT (rclkcmpsq1n(6) XOR nlOl0iO))) AND (NOT (rclkcmpsq1n(7) XOR nlOl0li))) AND (NOT (rclkcmpsq1n(8) XOR nlOl0ll))) AND (NOT (rclkcmpsq1n(9) XOR nlOl0lO)));
	nlii0il <= ((((((((((NOT (rclkcmpsq1p(0) XOR nlOl01O)) AND (NOT (rclkcmpsq1p(1) XOR nlOl00i))) AND (NOT (rclkcmpsq1p(2) XOR nlOl00l))) AND (NOT (rclkcmpsq1p(3) XOR nlOl00O))) AND (NOT (rclkcmpsq1p(4) XOR nlOl0ii))) AND (NOT (rclkcmpsq1p(5) XOR nlOl0il))) AND (NOT (rclkcmpsq1p(6) XOR nlOl0iO))) AND (NOT (rclkcmpsq1p(7) XOR nlOl0li))) AND (NOT (rclkcmpsq1p(8) XOR nlOl0ll))) AND (NOT (rclkcmpsq1p(9) XOR nlOl0lO)));
	nlii0iO <= ((((((((((NOT (rclkcmpsq1n(0) XOR nlOl10O)) AND (NOT (rclkcmpsq1n(1) XOR nlOl1ii))) AND (NOT (rclkcmpsq1n(2) XOR nlOl1il))) AND (NOT (rclkcmpsq1n(3) XOR nlOl1iO))) AND (NOT (rclkcmpsq1n(4) XOR nlOl1li))) AND (NOT (rclkcmpsq1n(5) XOR nlOl1ll))) AND (NOT (rclkcmpsq1n(6) XOR nlOl1lO))) AND (NOT (rclkcmpsq1n(7) XOR nlOl1Oi))) AND (NOT (rclkcmpsq1n(8) XOR nlOl1Ol))) AND (NOT (rclkcmpsq1n(9) XOR nlOl1OO)));
	nlii0li <= ((((((((((NOT (rclkcmpsq1p(0) XOR nlOl10O)) AND (NOT (rclkcmpsq1p(1) XOR nlOl1ii))) AND (NOT (rclkcmpsq1p(2) XOR nlOl1il))) AND (NOT (rclkcmpsq1p(3) XOR nlOl1iO))) AND (NOT (rclkcmpsq1p(4) XOR nlOl1li))) AND (NOT (rclkcmpsq1p(5) XOR nlOl1ll))) AND (NOT (rclkcmpsq1p(6) XOR nlOl1lO))) AND (NOT (rclkcmpsq1p(7) XOR nlOl1Oi))) AND (NOT (rclkcmpsq1p(8) XOR nlOl1Ol))) AND (NOT (rclkcmpsq1p(9) XOR nlOl1OO)));
	nlii0ll <= ((((((((((NOT (wire_n1OiOi_dataout XOR nlOl01O)) AND (NOT (wire_n1OiOl_dataout XOR nlOl00i))) AND (NOT (wire_n1OiOO_dataout XOR nlOl00l))) AND (NOT (wire_n1Ol1i_dataout XOR nlOl00O))) AND (NOT (wire_n1Ol1l_dataout XOR nlOl0ii))) AND (NOT (wire_n1Ol1O_dataout XOR nlOl0il))) AND (NOT (wire_n1Ol0i_dataout XOR nlOl0iO))) AND (NOT (wire_n1Ol0l_dataout XOR nlOl0li))) AND (NOT (wire_n1Ol0O_dataout XOR nlOl0ll))) AND (NOT (wire_n1Olii_dataout XOR nlOl0lO)));
	nlii0lO <= ((((((((((NOT (wire_n1OlOl_dataout XOR nlOl01O)) AND (NOT (wire_n1OlOO_dataout XOR nlOl00i))) AND (NOT (wire_n1OO1i_dataout XOR nlOl00l))) AND (NOT (wire_n1OO1l_dataout XOR nlOl00O))) AND (NOT (wire_n1OO1O_dataout XOR nlOl0ii))) AND (NOT (wire_n1OO0i_dataout XOR nlOl0il))) AND (NOT (wire_n1OO0l_dataout XOR nlOl0iO))) AND (NOT (wire_n1OO0O_dataout XOR nlOl0li))) AND (NOT (wire_n1OOii_dataout XOR nlOl0ll))) AND (NOT (wire_n1OOil_dataout XOR nlOl0lO)));
	nlii0Oi <= ((((((((((NOT (wire_n1OiOi_dataout XOR nlOl10O)) AND (NOT (wire_n1OiOl_dataout XOR nlOl1ii))) AND (NOT (wire_n1OiOO_dataout XOR nlOl1il))) AND (NOT (wire_n1Ol1i_dataout XOR nlOl1iO))) AND (NOT (wire_n1Ol1l_dataout XOR nlOl1li))) AND (NOT (wire_n1Ol1O_dataout XOR nlOl1ll))) AND (NOT (wire_n1Ol0i_dataout XOR nlOl1lO))) AND (NOT (wire_n1Ol0l_dataout XOR nlOl1Oi))) AND (NOT (wire_n1Ol0O_dataout XOR nlOl1Ol))) AND (NOT (wire_n1Olii_dataout XOR nlOl1OO)));
	nlii0Ol <= ((((((((((NOT (wire_n1OlOl_dataout XOR nlOl10O)) AND (NOT (wire_n1OlOO_dataout XOR nlOl1ii))) AND (NOT (wire_n1OO1i_dataout XOR nlOl1il))) AND (NOT (wire_n1OO1l_dataout XOR nlOl1iO))) AND (NOT (wire_n1OO1O_dataout XOR nlOl1li))) AND (NOT (wire_n1OO0i_dataout XOR nlOl1ll))) AND (NOT (wire_n1OO0l_dataout XOR nlOl1lO))) AND (NOT (wire_n1OO0O_dataout XOR nlOl1Oi))) AND (NOT (wire_n1OOii_dataout XOR nlOl1Ol))) AND (NOT (wire_n1OOil_dataout XOR nlOl1OO)));
	nlii0OO <= (nliii1l OR nliii1i);
	nlii10i <= (((wire_n1i_w_lg_n100ii3075w(0) AND wire_n1i_w_lg_n1000l3076w(0)) AND n1000i) AND n1001O);
	nlii10l <= ((wire_w_lg_rgenericfifo32w(0) AND wire_w_lg_w_lg_nlii1li1993w1994w(0)) OR nlii1iO);
	nlii10O <= (dskwclksel(0) AND nlii1il);
	nlii11i <= ((((wire_n1l1OO_o(8) OR wire_n1l1OO_o(6)) OR wire_n1l1OO_o(4)) OR wire_n1l1OO_o(2)) OR wire_n1l1OO_o(0));
	nlii11l <= (((((((wire_n1l00O_o(10) OR wire_n1l00O_o(9)) OR wire_n1l00O_o(8)) OR wire_n1l00O_o(7)) OR wire_n1l00O_o(6)) OR wire_n1l00O_o(5)) OR wire_n1l00O_o(4)) OR wire_n1l00O_o(3));
	nlii11O <= (((((((((wire_n1l00O_o(16) OR wire_n1l00O_o(15)) OR wire_n1l00O_o(14)) OR wire_n1l00O_o(13)) OR wire_n1l00O_o(12)) OR wire_n1l00O_o(11)) OR wire_n1l00O_o(10)) OR wire_n1l00O_o(9)) OR wire_n1l00O_o(8)) OR wire_n1l00O_o(7));
	nlii1ii <= ((NOT dskwclksel(0)) AND nlii1il);
	nlii1il <= (wire_w_lg_is_lane01987w(0) AND nlilO0l);
	nlii1iO <= (rgenericfifo AND nlOi1iO);
	nlii1li <= (((wire_w_lg_nlilO0l1955w(0) OR wire_w_lg_cg_comp_rd_d_ch31958w(0)) AND wire_n1Oiil_w_lg_dataout1964w(0)) OR (wire_w_lg_w1975w1976w(0) OR wire_w_lg_nlii1Ol1978w(0)));
	nlii1ll <= ((((((((((NOT (rclkcmpsq1n(0) XOR nlOiOil)) AND (NOT (rclkcmpsq1n(1) XOR nlOiOli))) AND (NOT (rclkcmpsq1n(2) XOR nlOiOll))) AND (NOT (rclkcmpsq1n(3) XOR nlOiOlO))) AND (NOT (rclkcmpsq1n(4) XOR nlOiOOi))) AND (NOT (rclkcmpsq1n(5) XOR nlOiOOl))) AND (NOT (rclkcmpsq1n(6) XOR nlOiOOO))) AND (NOT (rclkcmpsq1n(7) XOR nlOl11i))) AND (NOT (rclkcmpsq1n(8) XOR nlOl11l))) AND (NOT (rclkcmpsq1n(9) XOR nlOl11O)));
	nlii1lO <= ((((((((((NOT (rclkcmpsq1p(0) XOR nlOiOil)) AND (NOT (rclkcmpsq1p(1) XOR nlOiOli))) AND (NOT (rclkcmpsq1p(2) XOR nlOiOll))) AND (NOT (rclkcmpsq1p(3) XOR nlOiOlO))) AND (NOT (rclkcmpsq1p(4) XOR nlOiOOi))) AND (NOT (rclkcmpsq1p(5) XOR nlOiOOl))) AND (NOT (rclkcmpsq1p(6) XOR nlOiOOO))) AND (NOT (rclkcmpsq1p(7) XOR nlOl11i))) AND (NOT (rclkcmpsq1p(8) XOR nlOl11l))) AND (NOT (rclkcmpsq1p(9) XOR nlOl11O)));
	nlii1Oi <= (rskpsetbased AND n110ll);
	nlii1Ol <= ((wire_n1Oiil_w_lg_dataout1939w(0) AND wire_w_lg_w_lg_w_lg_rskpsetbased1945w1946w1947w(0)) AND wire_n1O11l_o);
	nlii1OO <= (rtruebac2bac OR (wire_w_lg_rtruebac2bac1950w(0) AND wire_n1i_w_lg_n11O1i1951w(0)));
	nliii0i <= (rskpsetbased OR rclkcmpsqmd);
	nliii0l <= (n0O0Ol XOR n0O0lO);
	nliii0O <= ((((n0O0ll AND n0l0il) AND wire_nii_w_lg_n0l0ii862w(0)) AND wire_nii_w_lg_n0l00O860w(0)) AND n0l00l);
	nliii1i <= ((((((((((NOT (wire_n1OiOi_dataout XOR wire_nlO0lOi_dataout)) AND (NOT (wire_n1OiOl_dataout XOR wire_nlO0lOl_dataout))) AND (NOT (wire_n1OiOO_dataout XOR wire_nlO0lOO_dataout))) AND (NOT (wire_n1Ol1i_dataout XOR wire_nlO0O1i_dataout))) AND (NOT (wire_n1Ol1l_dataout XOR wire_nlO0O1l_dataout))) AND (NOT (wire_n1Ol1O_dataout XOR wire_nlO0O1O_dataout))) AND (NOT (wire_n1Ol0i_dataout XOR wire_nlO0O0i_dataout))) AND (NOT (wire_n1Ol0l_dataout XOR wire_nlO0O0l_dataout))) AND (NOT (wire_n1Ol0O_dataout XOR wire_nlO0O0O_dataout))) AND (NOT (wire_n1Olii_dataout XOR wire_nlO0Oii_dataout)));
	nliii1l <= ((((((((((NOT (wire_n1OlOl_dataout XOR wire_nlO0lOi_dataout)) AND (NOT (wire_n1OlOO_dataout XOR wire_nlO0lOl_dataout))) AND (NOT (wire_n1OO1i_dataout XOR wire_nlO0lOO_dataout))) AND (NOT (wire_n1OO1l_dataout XOR wire_nlO0O1i_dataout))) AND (NOT (wire_n1OO1O_dataout XOR wire_nlO0O1l_dataout))) AND (NOT (wire_n1OO0i_dataout XOR wire_nlO0O1O_dataout))) AND (NOT (wire_n1OO0l_dataout XOR wire_nlO0O0i_dataout))) AND (NOT (wire_n1OO0O_dataout XOR wire_nlO0O0l_dataout))) AND (NOT (wire_n1OOii_dataout XOR wire_nlO0O0O_dataout))) AND (NOT (wire_n1OOil_dataout XOR wire_nlO0Oii_dataout)));
	nliii1O <= (wire_n1OliO_o(3) OR wire_n1OliO_o(0));
	nliiiii <= (((((((((wire_n0OO1l_o(18) OR wire_n0OO1l_o(17)) OR wire_n0OO1l_o(14)) OR wire_n0OO1l_o(13)) OR wire_n0OO1l_o(10)) OR wire_n0OO1l_o(9)) OR wire_n0OO1l_o(6)) OR wire_n0OO1l_o(5)) OR wire_n0OO1l_o(2)) OR wire_n0OO1l_o(1));
	nliiiil <= ((((((((((wire_n0OO1l_o(20) OR wire_n0OO1l_o(19)) OR wire_n0OO1l_o(18)) OR wire_n0OO1l_o(13)) OR wire_n0OO1l_o(12)) OR wire_n0OO1l_o(11)) OR wire_n0OO1l_o(10)) OR wire_n0OO1l_o(5)) OR wire_n0OO1l_o(4)) OR wire_n0OO1l_o(3)) OR wire_n0OO1l_o(2));
	nliiiiO <= ((((((((wire_n0OO1l_o(20) OR wire_n0OO1l_o(11)) OR wire_n0OO1l_o(10)) OR wire_n0OO1l_o(9)) OR wire_n0OO1l_o(8)) OR wire_n0OO1l_o(7)) OR wire_n0OO1l_o(6)) OR wire_n0OO1l_o(5)) OR wire_n0OO1l_o(4));
	nliiili <= ((((((((((((wire_n0OO1l_o(20) OR wire_n0OO1l_o(19)) OR wire_n0OO1l_o(18)) OR wire_n0OO1l_o(17)) OR wire_n0OO1l_o(16)) OR wire_n0OO1l_o(15)) OR wire_n0OO1l_o(14)) OR wire_n0OO1l_o(13)) OR wire_n0OO1l_o(12)) OR wire_n0OO1l_o(11)) OR wire_n0OO1l_o(10)) OR wire_n0OO1l_o(9)) OR wire_n0OO1l_o(8));
	nliiill <= ((((wire_n0OO1l_o(20) OR wire_n0OO1l_o(19)) OR wire_n0OO1l_o(18)) OR wire_n0OO1l_o(17)) OR wire_n0OO1l_o(16));
	nliiilO <= ((((wire_nii_w_lg_ni1i0l1699w(0) AND wire_nii_w_lg_ni1i0i1700w(0)) AND (NOT (rstart_threshold(0) XOR ni101l))) AND (NOT (rstart_threshold(1) XOR ni1i1l))) AND (NOT (rstart_threshold(2) XOR ni1i1O)));
	nliiiOi <= (nliiO0O OR n0OOli);
	nliiiOl <= ((((wire_n0OOOO_w_lg_w_o_range1678w1682w(0) AND (NOT (ni111i XOR wire_n0OOOO_o(2)))) AND (NOT (ni111l XOR wire_n0OOOO_o(3)))) AND (NOT (ni111O XOR wire_n0OOOO_o(4)))) AND (NOT (ni110i XOR wire_n0OOOO_o(5))));
	nliiiOO <= (((((NOT (rfull_threshold(0) XOR ni101l)) AND (NOT (rfull_threshold(1) XOR ni1i1l))) AND (NOT (rfull_threshold(2) XOR ni1i1O))) AND (NOT (rfull_threshold(3) XOR ni1i0i))) AND (NOT (rfull_threshold(4) XOR ni1i0l)));
	nliil0i <= (wire_nllOiO_o OR ni11OO);
	nliil0l <= (((((NOT (n0O0ll XOR nliiliO)) AND (NOT (n0l00l XOR nliilil))) AND (NOT (n0l00O XOR nliilii))) AND (NOT (n0l0ii XOR nliil0O))) AND (NOT (n0O0OO XOR n0l0il)));
	nliil0O <= (wire_nii_w_lg_n0O0OO843w(0) AND n0O0Ol);
	nliil1O <= (wire_nllOli_o OR ni11lO);
	nliilii <= (wire_nii_w_lg_n0O0OO843w(0) AND (n0O0Ol XOR n0O0Oi));
	nliilil <= (n0O0OO XOR (n0O0Oi XOR nliii0l));
	nliiliO <= (n0O0OO XOR (nliii0l XOR (n0O0Oi XOR n0liOl)));
	nliilli <= (wire_nllOiO_o AND ((ni00Oi OR ni00iO) AND nlO01O));
	nliilll <= ((((wire_nii_w_lg_ni1O0l1641w(0) AND wire_nii_w_lg_ni1O0i1642w(0)) AND wire_nii_w_lg_ni1O1O1644w(0)) AND wire_nii_w_lg_ni1O1l1646w(0)) AND wire_nii_w_lg_ni1llO1648w(0));
	nliillO <= ((wire_w_lg_w_lg_rgenericfifo32w754w(0) OR wire_w_lg_rgenericfifo756w(0)) AND wire_w_lg_nliiO0O726w(0));
	nliilOi <= ((((ni1O0l OR ni1O0i) OR ni1O1O) OR ni1O1l) OR ni1llO);
	nliilOl <= ((wire_w_lg_rgenericfifo32w(0) AND wire_w_lg_nliilOO744w(0)) OR (rgenericfifo AND n0Oiil));
	nliilOO <= (nliilli OR nliiO0O);
	nliiO0i <= ((((((((((NOT (sudi(14) XOR rclkcmpsq1n(0))) AND (NOT (sudi(15) XOR rclkcmpsq1n(1)))) AND (NOT (sudi(16) XOR rclkcmpsq1n(2)))) AND (NOT (sudi(17) XOR rclkcmpsq1n(3)))) AND (NOT (sudi(18) XOR rclkcmpsq1n(4)))) AND (NOT (sudi(19) XOR rclkcmpsq1n(5)))) AND (NOT (sudi(20) XOR rclkcmpsq1n(6)))) AND (NOT (sudi(21) XOR rclkcmpsq1n(7)))) AND (NOT (sudi(22) XOR rclkcmpsq1n(8)))) AND (NOT (sudi(23) XOR rclkcmpsq1n(9))));
	nliiO0l <= ((((((((((NOT (sudi(14) XOR rclkcmpsq1p(0))) AND (NOT (sudi(15) XOR rclkcmpsq1p(1)))) AND (NOT (sudi(16) XOR rclkcmpsq1p(2)))) AND (NOT (sudi(17) XOR rclkcmpsq1p(3)))) AND (NOT (sudi(18) XOR rclkcmpsq1p(4)))) AND (NOT (sudi(19) XOR rclkcmpsq1p(5)))) AND (NOT (sudi(20) XOR rclkcmpsq1p(6)))) AND (NOT (sudi(21) XOR rclkcmpsq1p(7)))) AND (NOT (sudi(22) XOR rclkcmpsq1p(8)))) AND (NOT (sudi(23) XOR rclkcmpsq1p(9))));
	nliiO0O <= (wire_nii_w_lg_ni1i0O967w(0) AND (wire_w_lg_nliilli968w(0) AND (nliiiOO AND nliiiOl)));
	nliiO1i <= (wire_w_lg_rgenericfifo32w(0) AND wire_nliOOi_w_lg_dataout924w(0));
	nliiO1l <= ((((((((((NOT (sudi(0) XOR rclkcmpsq1n(0))) AND (NOT (sudi(1) XOR rclkcmpsq1n(1)))) AND (NOT (sudi(2) XOR rclkcmpsq1n(2)))) AND (NOT (sudi(3) XOR rclkcmpsq1n(3)))) AND (NOT (sudi(4) XOR rclkcmpsq1n(4)))) AND (NOT (sudi(5) XOR rclkcmpsq1n(5)))) AND (NOT (sudi(6) XOR rclkcmpsq1n(6)))) AND (NOT (sudi(7) XOR rclkcmpsq1n(7)))) AND (NOT (sudi(8) XOR rclkcmpsq1n(8)))) AND (NOT (sudi(9) XOR rclkcmpsq1n(9))));
	nliiO1O <= ((((((((((NOT (sudi(0) XOR rclkcmpsq1p(0))) AND (NOT (sudi(1) XOR rclkcmpsq1p(1)))) AND (NOT (sudi(2) XOR rclkcmpsq1p(2)))) AND (NOT (sudi(3) XOR rclkcmpsq1p(3)))) AND (NOT (sudi(4) XOR rclkcmpsq1p(4)))) AND (NOT (sudi(5) XOR rclkcmpsq1p(5)))) AND (NOT (sudi(6) XOR rclkcmpsq1p(6)))) AND (NOT (sudi(7) XOR rclkcmpsq1p(7)))) AND (NOT (sudi(8) XOR rclkcmpsq1p(8)))) AND (NOT (sudi(9) XOR rclkcmpsq1p(9))));
	nliiOii <= (nliiOiO OR nliiOil);
	nliiOil <= ((((((((((NOT (sudi(14) XOR rclkcmpsq1n(10))) AND (NOT (sudi(15) XOR rclkcmpsq1n(11)))) AND (NOT (sudi(16) XOR rclkcmpsq1n(12)))) AND (NOT (sudi(17) XOR rclkcmpsq1n(13)))) AND (NOT (sudi(18) XOR rclkcmpsq1n(14)))) AND (NOT (sudi(19) XOR rclkcmpsq1n(15)))) AND (NOT (sudi(20) XOR rclkcmpsq1n(16)))) AND (NOT (sudi(21) XOR rclkcmpsq1n(17)))) AND (NOT (sudi(22) XOR rclkcmpsq1n(18)))) AND (NOT (sudi(23) XOR rclkcmpsq1n(19))));
	nliiOiO <= ((((((((((NOT (sudi(14) XOR rclkcmpsq1p(10))) AND (NOT (sudi(15) XOR rclkcmpsq1p(11)))) AND (NOT (sudi(16) XOR rclkcmpsq1p(12)))) AND (NOT (sudi(17) XOR rclkcmpsq1p(13)))) AND (NOT (sudi(18) XOR rclkcmpsq1p(14)))) AND (NOT (sudi(19) XOR rclkcmpsq1p(15)))) AND (NOT (sudi(20) XOR rclkcmpsq1p(16)))) AND (NOT (sudi(21) XOR rclkcmpsq1p(17)))) AND (NOT (sudi(22) XOR rclkcmpsq1p(18)))) AND (NOT (sudi(23) XOR rclkcmpsq1p(19))));
	nliiOli <= (nliiOlO OR nliiOll);
	nliiOll <= ((((((((((NOT (sudi(0) XOR rclkcmpsq1n(10))) AND (NOT (sudi(1) XOR rclkcmpsq1n(11)))) AND (NOT (sudi(2) XOR rclkcmpsq1n(12)))) AND (NOT (sudi(3) XOR rclkcmpsq1n(13)))) AND (NOT (sudi(4) XOR rclkcmpsq1n(14)))) AND (NOT (sudi(5) XOR rclkcmpsq1n(15)))) AND (NOT (sudi(6) XOR rclkcmpsq1n(16)))) AND (NOT (sudi(7) XOR rclkcmpsq1n(17)))) AND (NOT (sudi(8) XOR rclkcmpsq1n(18)))) AND (NOT (sudi(9) XOR rclkcmpsq1n(19))));
	nliiOlO <= ((((((((((NOT (sudi(0) XOR rclkcmpsq1p(10))) AND (NOT (sudi(1) XOR rclkcmpsq1p(11)))) AND (NOT (sudi(2) XOR rclkcmpsq1p(12)))) AND (NOT (sudi(3) XOR rclkcmpsq1p(13)))) AND (NOT (sudi(4) XOR rclkcmpsq1p(14)))) AND (NOT (sudi(5) XOR rclkcmpsq1p(15)))) AND (NOT (sudi(6) XOR rclkcmpsq1p(16)))) AND (NOT (sudi(7) XOR rclkcmpsq1p(17)))) AND (NOT (sudi(8) XOR rclkcmpsq1p(18)))) AND (NOT (sudi(9) XOR rclkcmpsq1p(19))));
	nlil00i <= (nlil0l OR nlil1O);
	nlil00l <= (wire_w_lg_rgenericfifo32w(0) AND wire_nliOlO_w_lg_dataout544w(0));
	nlil00O <= (rgenericfifo OR wire_nliOlO_dataout);
	nlil01i <= (((((((((wire_n011Oi_o(26) OR wire_n011Oi_o(25)) OR wire_n011Oi_o(11)) OR wire_n011Oi_o(8)) OR wire_n011Oi_o(7)) OR wire_n011Oi_o(4)) OR wire_n011Oi_o(14)) OR wire_n011Oi_o(13)) OR wire_n011Oi_o(2)) OR wire_n011Oi_o(1));
	nlil01O <= (rgenericfifo AND nli0il);
	nlil0ii <= ((((((((((NOT (rclkcmpsq1n(0) XOR wire_nllOlO_data_out2(0))) AND (NOT (rclkcmpsq1n(1) XOR wire_nllOlO_data_out2(1)))) AND (NOT (rclkcmpsq1n(2) XOR wire_nllOlO_data_out2(2)))) AND (NOT (rclkcmpsq1n(3) XOR wire_nllOlO_data_out2(3)))) AND (NOT (rclkcmpsq1n(4) XOR wire_nllOlO_data_out2(4)))) AND (NOT (rclkcmpsq1n(5) XOR wire_nllOlO_data_out2(5)))) AND (NOT (rclkcmpsq1n(6) XOR wire_nllOlO_data_out2(6)))) AND (NOT (rclkcmpsq1n(7) XOR wire_nllOlO_data_out2(7)))) AND (NOT (rclkcmpsq1n(8) XOR wire_nllOlO_data_out2(8)))) AND (NOT (rclkcmpsq1n(9) XOR wire_nllOlO_data_out2(9))));
	nlil0il <= ((((((((((NOT (rclkcmpsq1p(0) XOR wire_nllOlO_data_out2(0))) AND (NOT (rclkcmpsq1p(1) XOR wire_nllOlO_data_out2(1)))) AND (NOT (rclkcmpsq1p(2) XOR wire_nllOlO_data_out2(2)))) AND (NOT (rclkcmpsq1p(3) XOR wire_nllOlO_data_out2(3)))) AND (NOT (rclkcmpsq1p(4) XOR wire_nllOlO_data_out2(4)))) AND (NOT (rclkcmpsq1p(5) XOR wire_nllOlO_data_out2(5)))) AND (NOT (rclkcmpsq1p(6) XOR wire_nllOlO_data_out2(6)))) AND (NOT (rclkcmpsq1p(7) XOR wire_nllOlO_data_out2(7)))) AND (NOT (rclkcmpsq1p(8) XOR wire_nllOlO_data_out2(8)))) AND (NOT (rclkcmpsq1p(9) XOR wire_nllOlO_data_out2(9))));
	nlil0iO <= (nlil0l OR nliliii);
	nlil0lO <= ((((((((((NOT (rclkcmpsq1n(10) XOR wire_nllOll_data_out2(0))) AND (NOT (rclkcmpsq1n(11) XOR wire_nllOll_data_out2(1)))) AND (NOT (rclkcmpsq1n(12) XOR wire_nllOll_data_out2(2)))) AND (NOT (rclkcmpsq1n(13) XOR wire_nllOll_data_out2(3)))) AND (NOT (rclkcmpsq1n(14) XOR wire_nllOll_data_out2(4)))) AND (NOT (rclkcmpsq1n(15) XOR wire_nllOll_data_out2(5)))) AND (NOT (rclkcmpsq1n(16) XOR wire_nllOll_data_out2(6)))) AND (NOT (rclkcmpsq1n(17) XOR wire_nllOll_data_out2(7)))) AND (NOT (rclkcmpsq1n(18) XOR wire_nllOll_data_out2(8)))) AND (NOT (rclkcmpsq1n(19) XOR wire_nllOll_data_out2(9))));
	nlil0Oi <= ((((((((((NOT (rclkcmpsq1p(10) XOR wire_nllOll_data_out2(0))) AND (NOT (rclkcmpsq1p(11) XOR wire_nllOll_data_out2(1)))) AND (NOT (rclkcmpsq1p(12) XOR wire_nllOll_data_out2(2)))) AND (NOT (rclkcmpsq1p(13) XOR wire_nllOll_data_out2(3)))) AND (NOT (rclkcmpsq1p(14) XOR wire_nllOll_data_out2(4)))) AND (NOT (rclkcmpsq1p(15) XOR wire_nllOll_data_out2(5)))) AND (NOT (rclkcmpsq1p(16) XOR wire_nllOll_data_out2(6)))) AND (NOT (rclkcmpsq1p(17) XOR wire_nllOll_data_out2(7)))) AND (NOT (rclkcmpsq1p(18) XOR wire_nllOll_data_out2(8)))) AND (NOT (rclkcmpsq1p(19) XOR wire_nllOll_data_out2(9))));
	nlil10i <= (((((wire_n1i_w_lg_w_lg_w_lg_w_lg_nii0il1341w1342w1344w1345w(0) AND wire_n1i_w_lg_nii01O1346w(0)) AND wire_n1i_w_lg_nii01i1348w(0)) AND wire_n1i_w_lg_nii1OO1350w(0)) AND (NOT (wire_w_lg_rclkcmpinsertpad655w(0) XOR nii1Ol))) AND (NOT (rclkcmpinsertpad XOR nii01l)));
	nlil10l <= (rgenericfifo AND wire_n1i_w_lg_nli0il643w(0));
	nlil10O <= (nli0il OR (wire_w_lg_rgenericfifo32w(0) AND wire_w_lg_nlil0iO547w(0)));
	nlil11i <= ((wire_n1i_w_lg_w_lg_w_lg_w1399w1400w1401w1402w(0) AND (NOT (rclkcmpinsertpad XOR ni0OOi))) AND (NOT (wire_w_lg_rclkcmpinsertpad655w(0) XOR nii11i)));
	nlil11l <= (((((wire_n1i_w_lg_w_lg_w_lg_w_lg_nii1ii1375w1376w1378w1379w(0) AND wire_n1i_w_lg_nii11l1380w(0)) AND wire_n1i_w_lg_ni0OOO1382w(0)) AND wire_n1i_w_lg_ni0OOl1384w(0)) AND (NOT (wire_w_lg_rclkcmpinsertpad655w(0) XOR ni0OOi))) AND (NOT (rclkcmpinsertpad XOR nii11i)));
	nlil11O <= ((wire_n1i_w_lg_w_lg_w_lg_w1365w1366w1367w1368w(0) AND (NOT (rclkcmpinsertpad XOR nii1Ol))) AND (NOT (wire_w_lg_rclkcmpinsertpad655w(0) XOR nii01l)));
	nlil1ii <= ((((wire_nl0O1i_o(8) OR wire_nl0O1i_o(6)) OR wire_nl0O1i_o(4)) OR wire_nl0O1i_o(2)) OR wire_nl0O1i_o(0));
	nlil1il <= (((((((wire_nl0Oii_o(10) OR wire_nl0Oii_o(9)) OR wire_nl0Oii_o(8)) OR wire_nl0Oii_o(7)) OR wire_nl0Oii_o(6)) OR wire_nl0Oii_o(5)) OR wire_nl0Oii_o(4)) OR wire_nl0Oii_o(3));
	nlil1iO <= (((((((((wire_nl0Oii_o(16) OR wire_nl0Oii_o(15)) OR wire_nl0Oii_o(14)) OR wire_nl0Oii_o(13)) OR wire_nl0Oii_o(12)) OR wire_nl0Oii_o(11)) OR wire_nl0Oii_o(10)) OR wire_nl0Oii_o(9)) OR wire_nl0Oii_o(8)) OR wire_nl0Oii_o(7));
	nlil1li <= (((wire_n1i_w_lg_niOOii1336w(0) AND wire_n1i_w_lg_niOO0l1337w(0)) AND niOO0i) AND niOO1O);
	nlil1ll <= ((wire_w_lg_rgenericfifo32w(0) AND wire_n1i_w_lg_nlii0O548w(0)) OR nlil01O);
	nlil1lO <= ((((wire_nli1iO_w_lg_w_o_range1314w1318w(0) AND (NOT (wire_nli1iO_o(2) XOR nlil1OO))) AND (NOT (wire_nli1iO_o(3) XOR nlil1Ol))) AND (NOT (wire_nli1iO_o(4) XOR wire_n011ll_o(1)))) AND (NOT (wire_nli1iO_o(5) XOR nlil1Oi)));
	nlil1Oi <= ((((wire_n011Oi_o(30) OR wire_n011Oi_o(27)) OR wire_n011Oi_o(26)) OR wire_n011Oi_o(25)) OR wire_n011Oi_o(24));
	nlil1Ol <= ((((((((wire_n011Oi_o(30) OR wire_n011Oi_o(11)) OR wire_n011Oi_o(10)) OR wire_n011Oi_o(9)) OR wire_n011Oi_o(8)) OR wire_n011Oi_o(7)) OR wire_n011Oi_o(6)) OR wire_n011Oi_o(5)) OR wire_n011Oi_o(4));
	nlil1OO <= ((((wire_n011iO_o(13) OR wire_n011iO_o(7)) OR wire_n011iO_o(4)) OR wire_n011iO_o(2)) OR wire_n011iO_o(1));
	nlili0i <= ((((((((((NOT (rclkcmpsq1p(10) XOR ni0O1O)) AND (NOT (rclkcmpsq1p(11) XOR ni0O0i))) AND (NOT (rclkcmpsq1p(12) XOR ni0O0l))) AND (NOT (rclkcmpsq1p(13) XOR ni0O0O))) AND (NOT (rclkcmpsq1p(14) XOR ni0Oii))) AND (NOT (rclkcmpsq1p(15) XOR ni0Oil))) AND (NOT (rclkcmpsq1p(16) XOR ni0OiO))) AND (NOT (rclkcmpsq1p(17) XOR ni0Oli))) AND (NOT (rclkcmpsq1p(18) XOR ni0Oll))) AND (NOT (rclkcmpsq1p(19) XOR ni0OlO)));
	nlili1i <= ((((((((((NOT (rclkcmpsq1n(0) XOR ni00Ol)) AND (NOT (rclkcmpsq1n(1) XOR ni0liO))) AND (NOT (rclkcmpsq1n(2) XOR ni0lli))) AND (NOT (rclkcmpsq1n(3) XOR ni0lll))) AND (NOT (rclkcmpsq1n(4) XOR ni0llO))) AND (NOT (rclkcmpsq1n(5) XOR ni0lOi))) AND (NOT (rclkcmpsq1n(6) XOR ni0lOl))) AND (NOT (rclkcmpsq1n(7) XOR ni0lOO))) AND (NOT (rclkcmpsq1n(8) XOR ni0O1i))) AND (NOT (rclkcmpsq1n(9) XOR ni0O1l)));
	nlili1l <= ((((((((((NOT (rclkcmpsq1p(0) XOR ni00Ol)) AND (NOT (rclkcmpsq1p(1) XOR ni0liO))) AND (NOT (rclkcmpsq1p(2) XOR ni0lli))) AND (NOT (rclkcmpsq1p(3) XOR ni0lll))) AND (NOT (rclkcmpsq1p(4) XOR ni0llO))) AND (NOT (rclkcmpsq1p(5) XOR ni0lOi))) AND (NOT (rclkcmpsq1p(6) XOR ni0lOl))) AND (NOT (rclkcmpsq1p(7) XOR ni0lOO))) AND (NOT (rclkcmpsq1p(8) XOR ni0O1i))) AND (NOT (rclkcmpsq1p(9) XOR ni0O1l)));
	nlili1O <= ((((((((((NOT (rclkcmpsq1n(10) XOR ni0O1O)) AND (NOT (rclkcmpsq1n(11) XOR ni0O0i))) AND (NOT (rclkcmpsq1n(12) XOR ni0O0l))) AND (NOT (rclkcmpsq1n(13) XOR ni0O0O))) AND (NOT (rclkcmpsq1n(14) XOR ni0Oii))) AND (NOT (rclkcmpsq1n(15) XOR ni0Oil))) AND (NOT (rclkcmpsq1n(16) XOR ni0OiO))) AND (NOT (rclkcmpsq1n(17) XOR ni0Oli))) AND (NOT (rclkcmpsq1n(18) XOR ni0Oll))) AND (NOT (rclkcmpsq1n(19) XOR ni0OlO)));
	nliliii <= (nliO1i AND (nlii0i AND wire_w_lg_nliliil440w(0)));
	nliliil <= (wire_nli1li_o OR (nlilOl AND nlil1lO));
	nliliiO <= (wire_w_lg_rmatchen438w(0) OR rgenericfifo);
	nlilili <= (rmatchen OR rgenericfifo);
	nlill0O <= (wire_n1li_dataout OR wire_n1iO_dataout);
	nlillii <= (wire_n1O01i_o OR (n11O1i AND nlii01i));
	nlillil <= ((wire_nlO0OlO_w_lg_dataout2225w(0) AND wire_nlO0Oli_w_lg_w_lg_dataout2226w2227w(0)) AND (NOT (nli0O1O AND nli0O1l)));
	nlillOi <= (wire_n1OllO_w_lg_o2547w(0) AND (wire_w_lg_nli0l0i2528w(0) AND wire_nii_w_lg_nlli0Oi2548w(0)));
	nlillOl <= (((wire_w_lg_rrx_pipe_enable1940w(0) AND nli0ill) AND nli0iOi) AND nli0i0O);
	nlillOO <= ((nliilOl AND wire_w_lg_nliiO0O726w(0)) AND nliilOi);
	nlilO0l <= (dskwclksel(1) AND rmatchen);
	nlilOil <= '0';
	nlilOiO <= (wire_w_lg_w_lg_w_lg_w_lg_rauto_speed_ena7w18w19w20w(0) OR (NOT (nlilOli14 XOR nlilOli13)));
	nliO10l <= '1';
	nliO11i <= (((wire_w_lg_rauto_speed_ena7w(0) AND (nliO11l6 XOR nliO11l5)) AND n1O) OR rdwidth_rx);
	nliO1il <= (wire_nlil_dataout OR soft_reset);
	rdfifo_almost_empty <= wire_nll_dataout;
	rdfifo_almost_full <= wire_ni_dataout;
	rdfifo_empty <= wire_nli_dataout;
	rdfifo_full <= wire_nlO_dataout;
	rev_loop_data <= ( wire_niO1O_dataout & wire_niO1l_dataout & wire_niO1i_dataout & wire_nilOO_dataout & wire_nilOl_dataout & wire_nilOi_dataout & wire_nillO_dataout & wire_nilll_dataout & wire_nilli_dataout & wire_niliO_dataout & wire_nilil_dataout & wire_nilii_dataout & wire_nil0O_dataout & wire_nil0l_dataout & wire_nil0i_dataout & wire_nil1O_dataout & wire_nil1l_dataout & wire_nil1i_dataout & wire_niiOO_dataout & wire_niiOl_dataout);
	skpos_det <= nlillil;
	wire_w_dskwclksel_range33w(0) <= dskwclksel(1);
	wire_w_rdel_threshold_range361w(0) <= rdel_threshold(3);
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nli0O0O61 <= nli0O0O62;
		END IF;
		if (now = 0 ns) then
			nli0O0O61 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nli0O0O62 <= nli0O0O61;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliil1i59 <= nliil1i60;
		END IF;
		if (now = 0 ns) then
			nliil1i59 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliil1i60 <= nliil1i59;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliil1l57 <= nliil1l58;
		END IF;
		if (now = 0 ns) then
			nliil1l57 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliil1l58 <= nliil1l57;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliiOOi55 <= nliiOOi56;
		END IF;
		if (now = 0 ns) then
			nliiOOi55 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliiOOi56 <= nliiOOi55;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliiOOl53 <= nliiOOl54;
		END IF;
		if (now = 0 ns) then
			nliiOOl53 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliiOOl54 <= nliiOOl53;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliiOOO51 <= nliiOOO52;
		END IF;
		if (now = 0 ns) then
			nliiOOO51 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliiOOO52 <= nliiOOO51;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlil01l49 <= nlil01l50;
		END IF;
		if (now = 0 ns) then
			nlil01l49 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlil01l50 <= nlil01l49;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlil0li47 <= nlil0li48;
		END IF;
		if (now = 0 ns) then
			nlil0li47 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlil0li48 <= nlil0li47;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlil0Ol45 <= nlil0Ol46;
		END IF;
		if (now = 0 ns) then
			nlil0Ol45 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlil0Ol46 <= nlil0Ol45;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlili0l43 <= nlili0l44;
		END IF;
		if (now = 0 ns) then
			nlili0l43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlili0l44 <= nlili0l43;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilill41 <= nlilill42;
		END IF;
		if (now = 0 ns) then
			nlilill41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilill42 <= nlilill41;
		END IF;
	END PROCESS;
	wire_nlilill42_w_lg_w_lg_q405w406w(0) <= wire_nlilill42_w_lg_q405w(0) AND wire_w_rdel_threshold_range361w(0);
	wire_nlilill42_w_lg_q405w(0) <= nlilill42 XOR nlilill41;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlililO39 <= nlililO40;
		END IF;
		if (now = 0 ns) then
			nlililO39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlililO40 <= nlililO39;
		END IF;
	END PROCESS;
	wire_nlililO40_w_lg_w_lg_q396w397w(0) <= wire_nlililO40_w_lg_q396w(0) AND ni1i0l;
	wire_nlililO40_w_lg_q396w(0) <= nlililO40 XOR nlililO39;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliliOi37 <= nliliOi38;
		END IF;
		if (now = 0 ns) then
			nliliOi37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliliOi38 <= nliliOi37;
		END IF;
	END PROCESS;
	wire_nliliOi38_w_lg_w_lg_q369w370w(0) <= wire_nliliOi38_w_lg_q369w(0) AND ni1i1l;
	wire_nliliOi38_w_lg_q369w(0) <= nliliOi38 XOR nliliOi37;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliliOl35 <= nliliOl36;
		END IF;
		if (now = 0 ns) then
			nliliOl35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliliOl36 <= nliliOl35;
		END IF;
	END PROCESS;
	wire_nliliOl36_w_lg_w_lg_q332w333w(0) <= wire_nliliOl36_w_lg_q332w(0) AND ni1i1O;
	wire_nliliOl36_w_lg_q332w(0) <= nliliOl36 XOR nliliOl35;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliliOO33 <= nliliOO34;
		END IF;
		if (now = 0 ns) then
			nliliOO33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliliOO34 <= nliliOO33;
		END IF;
	END PROCESS;
	wire_nliliOO34_w_lg_w_lg_q166w167w(0) <= wire_nliliOO34_w_lg_q166w(0) AND wire_nlO1iO_dataout;
	wire_nliliOO34_w_lg_q166w(0) <= nliliOO34 XOR nliliOO33;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlill0l25 <= nlill0l26;
		END IF;
		if (now = 0 ns) then
			nlill0l25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlill0l26 <= nlill0l25;
		END IF;
	END PROCESS;
	wire_nlill0l26_w_lg_w_lg_q124w125w(0) <= wire_nlill0l26_w_lg_q124w(0) AND nllOOl;
	wire_nlill0l26_w_lg_q124w(0) <= nlill0l26 XOR nlill0l25;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlill1i31 <= nlill1i32;
		END IF;
		if (now = 0 ns) then
			nlill1i31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlill1i32 <= nlill1i31;
		END IF;
	END PROCESS;
	wire_nlill1i32_w_lg_w_lg_q155w156w(0) <= wire_nlill1i32_w_lg_q155w(0) AND wire_nlO10l_dataout;
	wire_nlill1i32_w_lg_q155w(0) <= nlill1i32 XOR nlill1i31;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlill1l29 <= nlill1l30;
		END IF;
		if (now = 0 ns) then
			nlill1l29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlill1l30 <= nlill1l29;
		END IF;
	END PROCESS;
	wire_nlill1l30_w_lg_w_lg_q152w153w(0) <= wire_nlill1l30_w_lg_q152w(0) AND nllOOi;
	wire_nlill1l30_w_lg_q152w(0) <= nlill1l30 XOR nlill1l29;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlill1O27 <= nlill1O28;
		END IF;
		if (now = 0 ns) then
			nlill1O27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlill1O28 <= nlill1O27;
		END IF;
	END PROCESS;
	wire_nlill1O28_w_lg_q140w(0) <= nlill1O28 XOR nlill1O27;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilliO23 <= nlilliO24;
		END IF;
		if (now = 0 ns) then
			nlilliO23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilliO24 <= nlilliO23;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlillll21 <= nlillll22;
		END IF;
		if (now = 0 ns) then
			nlillll21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlillll22 <= nlillll21;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilO0O15 <= nlilO0O16;
		END IF;
		if (now = 0 ns) then
			nlilO0O15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilO0O16 <= nlilO0O15;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilO1i19 <= nlilO1i20;
		END IF;
		if (now = 0 ns) then
			nlilO1i19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilO1i20 <= nlilO1i19;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilO1O17 <= nlilO1O18;
		END IF;
		if (now = 0 ns) then
			nlilO1O17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilO1O18 <= nlilO1O17;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilOli13 <= nlilOli14;
		END IF;
		if (now = 0 ns) then
			nlilOli13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilOli14 <= nlilOli13;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilOlO11 <= nlilOlO12;
		END IF;
		if (now = 0 ns) then
			nlilOlO11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilOlO12 <= nlilOlO11;
		END IF;
	END PROCESS;
	wire_nlilOlO12_w_lg_q17w(0) <= nlilOlO12 XOR nlilOlO11;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilOOl10 <= nlilOOl9;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilOOl9 <= nlilOOl10;
		END IF;
		if (now = 0 ns) then
			nlilOOl9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilOOO7 <= nlilOOO8;
		END IF;
		if (now = 0 ns) then
			nlilOOO7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nlilOOO8 <= nlilOOO7;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliO10i3 <= nliO10i4;
		END IF;
		if (now = 0 ns) then
			nliO10i3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliO10i4 <= nliO10i3;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliO11l5 <= nliO11l6;
		END IF;
		if (now = 0 ns) then
			nliO11l5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliO11l6 <= nliO11l5;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliO1iO1 <= nliO1iO2;
		END IF;
		if (now = 0 ns) then
			nliO1iO1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN nliO1iO2 <= nliO1iO1;
		END IF;
	END PROCESS;
	PROCESS (clk_2, wire_n1i_PRN, wire_n1i_CLRN)
	BEGIN
		IF (wire_n1i_PRN = '0') THEN
				n0111i <= '1';
				n0111l <= '1';
				n1000i <= '1';
				n1000l <= '1';
				n1000O <= '1';
				n1001i <= '1';
				n1001l <= '1';
				n1001O <= '1';
				n100ii <= '1';
				n100il <= '1';
				n100li <= '1';
				n100ll <= '1';
				n100lO <= '1';
				n100Oi <= '1';
				n100Ol <= '1';
				n100OO <= '1';
				n101Ol <= '1';
				n101OO <= '1';
				n10i0i <= '1';
				n10i0l <= '1';
				n10i0O <= '1';
				n10i1i <= '1';
				n10i1l <= '1';
				n10i1O <= '1';
				n10iii <= '1';
				n10iil <= '1';
				n10iiO <= '1';
				n10ili <= '1';
				n10ill <= '1';
				n10ilO <= '1';
				n10iOl <= '1';
				n10iOO <= '1';
				n10l0i <= '1';
				n10l0l <= '1';
				n10l0O <= '1';
				n10l1i <= '1';
				n10l1l <= '1';
				n10l1O <= '1';
				n10lii <= '1';
				n10lil <= '1';
				n10liO <= '1';
				n10lli <= '1';
				n10lll <= '1';
				n10llO <= '1';
				n10lOi <= '1';
				n10lOl <= '1';
				n10lOO <= '1';
				n10O1i <= '1';
				n10O1l <= '1';
				n10O1O <= '1';
				n110iO <= '1';
				n110li <= '1';
				n110ll <= '1';
				n110lO <= '1';
				n11iil <= '1';
				n11iiO <= '1';
				n11ili <= '1';
				n11ill <= '1';
				n11ilO <= '1';
				n11iOi <= '1';
				n11iOl <= '1';
				n11iOO <= '1';
				n11O0i <= '1';
				n11O0l <= '1';
				n11O0O <= '1';
				n11O1i <= '1';
				n11O1l <= '1';
				n11O1O <= '1';
				n1l <= '1';
				n1liil <= '1';
				n1liiO <= '1';
				n1lili <= '1';
				n1ll1i <= '1';
				n1ll1l <= '1';
				n1O00i <= '1';
				n1O00l <= '1';
				n1O01l <= '1';
				n1O01O <= '1';
				ni0OOi <= '1';
				ni0OOl <= '1';
				ni0OOO <= '1';
				nii00i <= '1';
				nii00l <= '1';
				nii00O <= '1';
				nii01i <= '1';
				nii01l <= '1';
				nii01O <= '1';
				nii0ii <= '1';
				nii0il <= '1';
				nii0iO <= '1';
				nii0ll <= '1';
				nii0Ol <= '1';
				nii0OO <= '1';
				nii10i <= '1';
				nii10l <= '1';
				nii10O <= '1';
				nii11i <= '1';
				nii11l <= '1';
				nii11O <= '1';
				nii1ii <= '1';
				nii1il <= '1';
				nii1iO <= '1';
				nii1li <= '1';
				nii1ll <= '1';
				nii1lO <= '1';
				nii1Oi <= '1';
				nii1Ol <= '1';
				nii1OO <= '1';
				niii1i <= '1';
				niOlOl <= '1';
				niOlOO <= '1';
				niOO0i <= '1';
				niOO0l <= '1';
				niOO0O <= '1';
				niOO1i <= '1';
				niOO1l <= '1';
				niOO1O <= '1';
				niOOii <= '1';
				niOOil <= '1';
				niOOli <= '1';
				niOOll <= '1';
				niOOlO <= '1';
				niOOOi <= '1';
				niOOOl <= '1';
				niOOOO <= '1';
				nl100i <= '1';
				nl100l <= '1';
				nl100O <= '1';
				nl101i <= '1';
				nl101l <= '1';
				nl101O <= '1';
				nl10ii <= '1';
				nl10il <= '1';
				nl10iO <= '1';
				nl10li <= '1';
				nl10ll <= '1';
				nl10lO <= '1';
				nl10Oi <= '1';
				nl10Ol <= '1';
				nl10OO <= '1';
				nl110i <= '1';
				nl110l <= '1';
				nl110O <= '1';
				nl111i <= '1';
				nl111l <= '1';
				nl111O <= '1';
				nl11ii <= '1';
				nl11il <= '1';
				nl11iO <= '1';
				nl11li <= '1';
				nl11ll <= '1';
				nl11lO <= '1';
				nl11OO <= '1';
				nl1i0i <= '1';
				nl1i1i <= '1';
				nl1i1l <= '1';
				nl1i1O <= '1';
				nli0il <= '1';
				nli0Ol <= '1';
				nli0OO <= '1';
				nli1ll <= '1';
				nli1lO <= '1';
				nli1Oi <= '1';
				nli1Ol <= '1';
				nlii0i <= '1';
				nlii0l <= '1';
				nlii0O <= '1';
				nlii1i <= '1';
				nlii1l <= '1';
				nliilO <= '1';
				nliiOi <= '1';
				nlil0i <= '1';
				nlil0l <= '1';
				nlil0O <= '1';
				nlil1O <= '1';
				nlilOl <= '1';
				nliO01l <= '1';
				nliO01O <= '1';
				nliO1i <= '1';
				nlll <= '1';
				nlO00OO <= '1';
				nlOi1iO <= '1';
				nlOiO0i <= '1';
				nlOiO0l <= '1';
				nlOiO0O <= '1';
				nlOiO1O <= '1';
				nlOiOii <= '1';
				nlOl0OO <= '1';
				nlOli0i <= '1';
				nlOli0l <= '1';
				nlOli0O <= '1';
				nlOli1i <= '1';
				nlOli1l <= '1';
				nlOli1O <= '1';
				nlOliii <= '1';
				nlOliil <= '1';
				nlOliiO <= '1';
				nlOlili <= '1';
				nlOlilO <= '1';
				nlOliOO <= '1';
				nlOll1i <= '1';
				nlOll1l <= '1';
		ELSIF (wire_n1i_CLRN = '0') THEN
				n0111i <= '0';
				n0111l <= '0';
				n1000i <= '0';
				n1000l <= '0';
				n1000O <= '0';
				n1001i <= '0';
				n1001l <= '0';
				n1001O <= '0';
				n100ii <= '0';
				n100il <= '0';
				n100li <= '0';
				n100ll <= '0';
				n100lO <= '0';
				n100Oi <= '0';
				n100Ol <= '0';
				n100OO <= '0';
				n101Ol <= '0';
				n101OO <= '0';
				n10i0i <= '0';
				n10i0l <= '0';
				n10i0O <= '0';
				n10i1i <= '0';
				n10i1l <= '0';
				n10i1O <= '0';
				n10iii <= '0';
				n10iil <= '0';
				n10iiO <= '0';
				n10ili <= '0';
				n10ill <= '0';
				n10ilO <= '0';
				n10iOl <= '0';
				n10iOO <= '0';
				n10l0i <= '0';
				n10l0l <= '0';
				n10l0O <= '0';
				n10l1i <= '0';
				n10l1l <= '0';
				n10l1O <= '0';
				n10lii <= '0';
				n10lil <= '0';
				n10liO <= '0';
				n10lli <= '0';
				n10lll <= '0';
				n10llO <= '0';
				n10lOi <= '0';
				n10lOl <= '0';
				n10lOO <= '0';
				n10O1i <= '0';
				n10O1l <= '0';
				n10O1O <= '0';
				n110iO <= '0';
				n110li <= '0';
				n110ll <= '0';
				n110lO <= '0';
				n11iil <= '0';
				n11iiO <= '0';
				n11ili <= '0';
				n11ill <= '0';
				n11ilO <= '0';
				n11iOi <= '0';
				n11iOl <= '0';
				n11iOO <= '0';
				n11O0i <= '0';
				n11O0l <= '0';
				n11O0O <= '0';
				n11O1i <= '0';
				n11O1l <= '0';
				n11O1O <= '0';
				n1l <= '0';
				n1liil <= '0';
				n1liiO <= '0';
				n1lili <= '0';
				n1ll1i <= '0';
				n1ll1l <= '0';
				n1O00i <= '0';
				n1O00l <= '0';
				n1O01l <= '0';
				n1O01O <= '0';
				ni0OOi <= '0';
				ni0OOl <= '0';
				ni0OOO <= '0';
				nii00i <= '0';
				nii00l <= '0';
				nii00O <= '0';
				nii01i <= '0';
				nii01l <= '0';
				nii01O <= '0';
				nii0ii <= '0';
				nii0il <= '0';
				nii0iO <= '0';
				nii0ll <= '0';
				nii0Ol <= '0';
				nii0OO <= '0';
				nii10i <= '0';
				nii10l <= '0';
				nii10O <= '0';
				nii11i <= '0';
				nii11l <= '0';
				nii11O <= '0';
				nii1ii <= '0';
				nii1il <= '0';
				nii1iO <= '0';
				nii1li <= '0';
				nii1ll <= '0';
				nii1lO <= '0';
				nii1Oi <= '0';
				nii1Ol <= '0';
				nii1OO <= '0';
				niii1i <= '0';
				niOlOl <= '0';
				niOlOO <= '0';
				niOO0i <= '0';
				niOO0l <= '0';
				niOO0O <= '0';
				niOO1i <= '0';
				niOO1l <= '0';
				niOO1O <= '0';
				niOOii <= '0';
				niOOil <= '0';
				niOOli <= '0';
				niOOll <= '0';
				niOOlO <= '0';
				niOOOi <= '0';
				niOOOl <= '0';
				niOOOO <= '0';
				nl100i <= '0';
				nl100l <= '0';
				nl100O <= '0';
				nl101i <= '0';
				nl101l <= '0';
				nl101O <= '0';
				nl10ii <= '0';
				nl10il <= '0';
				nl10iO <= '0';
				nl10li <= '0';
				nl10ll <= '0';
				nl10lO <= '0';
				nl10Oi <= '0';
				nl10Ol <= '0';
				nl10OO <= '0';
				nl110i <= '0';
				nl110l <= '0';
				nl110O <= '0';
				nl111i <= '0';
				nl111l <= '0';
				nl111O <= '0';
				nl11ii <= '0';
				nl11il <= '0';
				nl11iO <= '0';
				nl11li <= '0';
				nl11ll <= '0';
				nl11lO <= '0';
				nl11OO <= '0';
				nl1i0i <= '0';
				nl1i1i <= '0';
				nl1i1l <= '0';
				nl1i1O <= '0';
				nli0il <= '0';
				nli0Ol <= '0';
				nli0OO <= '0';
				nli1ll <= '0';
				nli1lO <= '0';
				nli1Oi <= '0';
				nli1Ol <= '0';
				nlii0i <= '0';
				nlii0l <= '0';
				nlii0O <= '0';
				nlii1i <= '0';
				nlii1l <= '0';
				nliilO <= '0';
				nliiOi <= '0';
				nlil0i <= '0';
				nlil0l <= '0';
				nlil0O <= '0';
				nlil1O <= '0';
				nlilOl <= '0';
				nliO01l <= '0';
				nliO01O <= '0';
				nliO1i <= '0';
				nlll <= '0';
				nlO00OO <= '0';
				nlOi1iO <= '0';
				nlOiO0i <= '0';
				nlOiO0l <= '0';
				nlOiO0O <= '0';
				nlOiO1O <= '0';
				nlOiOii <= '0';
				nlOl0OO <= '0';
				nlOli0i <= '0';
				nlOli0l <= '0';
				nlOli0O <= '0';
				nlOli1i <= '0';
				nlOli1l <= '0';
				nlOli1O <= '0';
				nlOliii <= '0';
				nlOliil <= '0';
				nlOliiO <= '0';
				nlOlili <= '0';
				nlOlilO <= '0';
				nlOliOO <= '0';
				nlOll1i <= '0';
				nlOll1l <= '0';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
				n0111i <= wire_n0110i_dataout;
				n0111l <= wire_n0110l_dataout;
				n1000i <= wire_n10Oli_dataout;
				n1000l <= wire_n10Oll_dataout;
				n1000O <= wire_n10OlO_dataout;
				n1001i <= wire_n10Oii_dataout;
				n1001l <= wire_n10Oil_dataout;
				n1001O <= wire_n10OiO_dataout;
				n100ii <= wire_n10OOi_dataout;
				n100il <= wire_n10OOl_dataout;
				n100li <= wire_n1i11i_dataout;
				n100ll <= wire_n1i11l_dataout;
				n100lO <= wire_n1i11O_dataout;
				n100Oi <= wire_n1i10i_dataout;
				n100Ol <= wire_n1i10l_dataout;
				n100OO <= wire_n1i10O_dataout;
				n101Ol <= wire_n10O0l_dataout;
				n101OO <= wire_n10O0O_dataout;
				n10i0i <= wire_n1i1li_dataout;
				n10i0l <= wire_n1i1ll_dataout;
				n10i0O <= wire_n1i1lO_dataout;
				n10i1i <= wire_n1i1ii_dataout;
				n10i1l <= wire_n1i1il_dataout;
				n10i1O <= wire_n1i1iO_dataout;
				n10iii <= wire_n1i1Oi_dataout;
				n10iil <= wire_n1i1Ol_dataout;
				n10iiO <= wire_n1i1OO_dataout;
				n10ili <= wire_n1i01i_dataout;
				n10ill <= wire_n1i01l_dataout;
				n10ilO <= wire_n1i01O_dataout;
				n10iOl <= wire_n1i00l_dataout;
				n10iOO <= wire_n1i00O_dataout;
				n10l0i <= wire_n1i0li_dataout;
				n10l0l <= wire_n1i0ll_dataout;
				n10l0O <= wire_n1i0lO_dataout;
				n10l1i <= wire_n1i0ii_dataout;
				n10l1l <= wire_n1i0il_dataout;
				n10l1O <= wire_n1i0iO_dataout;
				n10lii <= wire_n1i0Oi_dataout;
				n10lil <= wire_n1i0Ol_dataout;
				n10liO <= wire_n1i0OO_dataout;
				n10lli <= wire_n1ii1i_dataout;
				n10lll <= wire_n1ii1l_dataout;
				n10llO <= wire_n1ii1O_dataout;
				n10lOi <= wire_n1ii0i_dataout;
				n10lOl <= wire_n1ii0l_dataout;
				n10lOO <= wire_n1ii0O_dataout;
				n10O1i <= wire_n1iiii_dataout;
				n10O1l <= wire_n1iiil_dataout;
				n10O1O <= wire_n1lill_dataout;
				n110iO <= n110ll;
				n110li <= wire_n110Oi_dataout;
				n110ll <= wire_n110Ol_dataout;
				n110lO <= wire_n11l1i_dataout;
				n11iil <= wire_n11l1l_dataout;
				n11iiO <= wire_n11l1O_dataout;
				n11ili <= wire_n11l0i_dataout;
				n11ill <= wire_n11l0l_dataout;
				n11ilO <= wire_n11l0O_dataout;
				n11iOi <= wire_n11lii_dataout;
				n11iOl <= wire_n11lil_dataout;
				n11iOO <= wire_n101iO_dataout;
				n11O0i <= wire_n11Oil_dataout;
				n11O0l <= wire_n11OiO_dataout;
				n11O0O <= wire_n10O0i_dataout;
				n11O1i <= wire_n101ll_dataout;
				n11O1l <= wire_n101li_dataout;
				n11O1O <= wire_n11Oii_dataout;
				n1l <= wire_niO_dataout;
				n1liil <= wire_n1lilO_dataout;
				n1liiO <= wire_n1liOi_dataout;
				n1lili <= n1ll1i;
				n1ll1i <= (wire_w_lg_rgenericfifo32w(0) AND nlO1Oii);
				n1ll1l <= wire_n1O0il_dataout;
				n1O00i <= wire_n1O0ll_dataout;
				n1O00l <= wire_n1O0lO_dataout;
				n1O01l <= wire_n1O0iO_dataout;
				n1O01O <= wire_n1O0li_dataout;
				ni0OOi <= wire_niii1l_dataout;
				ni0OOl <= wire_niii1O_dataout;
				ni0OOO <= wire_niii0i_dataout;
				nii00i <= wire_niilil_dataout;
				nii00l <= wire_niiliO_dataout;
				nii00O <= wire_niilli_dataout;
				nii01i <= wire_niil0l_dataout;
				nii01l <= wire_niil0O_dataout;
				nii01O <= wire_niilii_dataout;
				nii0ii <= wire_niilll_dataout;
				nii0il <= wire_niillO_dataout;
				nii0iO <= wire_niilOi_dataout;
				nii0ll <= wire_niilOl_dataout;
				nii0Ol <= wire_niilOO_dataout;
				nii0OO <= wire_niiO1i_dataout;
				nii10i <= wire_niiiil_dataout;
				nii10l <= wire_niiiiO_dataout;
				nii10O <= wire_niiili_dataout;
				nii11i <= wire_niii0l_dataout;
				nii11l <= wire_niii0O_dataout;
				nii11O <= wire_niiiii_dataout;
				nii1ii <= wire_niiill_dataout;
				nii1il <= wire_niiilO_dataout;
				nii1iO <= wire_niiiOi_dataout;
				nii1li <= wire_niiiOl_dataout;
				nii1ll <= wire_niiiOO_dataout;
				nii1lO <= wire_niil1i_dataout;
				nii1Oi <= wire_niil1l_dataout;
				nii1Ol <= wire_niil1O_dataout;
				nii1OO <= wire_niil0i_dataout;
				niii1i <= wire_nl1i0l_dataout;
				niOlOl <= wire_nl1i0O_dataout;
				niOlOO <= wire_nl1iii_dataout;
				niOO0i <= wire_nl1ill_dataout;
				niOO0l <= wire_nl1ilO_dataout;
				niOO0O <= wire_nl1iOi_dataout;
				niOO1i <= wire_nl1iil_dataout;
				niOO1l <= wire_nl1iiO_dataout;
				niOO1O <= wire_nl1ili_dataout;
				niOOii <= wire_nl1iOl_dataout;
				niOOil <= wire_nl1iOO_dataout;
				niOOli <= wire_nl1l1l_dataout;
				niOOll <= wire_nl1l1O_dataout;
				niOOlO <= wire_nl1l0i_dataout;
				niOOOi <= wire_nl1l0l_dataout;
				niOOOl <= wire_nl1l0O_dataout;
				niOOOO <= wire_nl1lii_dataout;
				nl100i <= wire_nl1Oli_dataout;
				nl100l <= wire_nl1Oll_dataout;
				nl100O <= wire_nl1OlO_dataout;
				nl101i <= wire_nl1Oii_dataout;
				nl101l <= wire_nl1Oil_dataout;
				nl101O <= wire_nl1OiO_dataout;
				nl10ii <= wire_nl1OOi_dataout;
				nl10il <= wire_nl1OOl_dataout;
				nl10iO <= wire_nl1OOO_dataout;
				nl10li <= wire_nl011i_dataout;
				nl10ll <= wire_nl011l_dataout;
				nl10lO <= wire_nl011O_dataout;
				nl10Oi <= wire_nl010i_dataout;
				nl10Ol <= wire_nl010l_dataout;
				nl10OO <= wire_nl010O_dataout;
				nl110i <= wire_nl1lll_dataout;
				nl110l <= wire_nl1llO_dataout;
				nl110O <= wire_nl1lOi_dataout;
				nl111i <= wire_nl1lil_dataout;
				nl111l <= wire_nl1liO_dataout;
				nl111O <= wire_nl1lli_dataout;
				nl11ii <= wire_nl1lOl_dataout;
				nl11il <= wire_nl1lOO_dataout;
				nl11iO <= wire_nl1O1i_dataout;
				nl11li <= wire_nl1O1l_dataout;
				nl11ll <= wire_nl1O1O_dataout;
				nl11lO <= wire_nl1O0i_dataout;
				nl11OO <= wire_nl1O0O_dataout;
				nl1i0i <= wire_nli01O_dataout;
				nl1i1i <= wire_nl01ii_dataout;
				nl1i1l <= wire_nl01il_dataout;
				nl1i1O <= wire_nl01iO_dataout;
				nli0il <= nli0Ol;
				nli0Ol <= (rgenericfifo AND rdenable);
				nli0OO <= nlii1i;
				nli1ll <= wire_nli00i_dataout;
				nli1lO <= wire_nli00l_dataout;
				nli1Oi <= wire_nli00O_dataout;
				nli1Ol <= wire_nli0ii_dataout;
				nlii0i <= wire_nliiil_dataout;
				nlii0l <= wire_nliiiO_dataout;
				nlii0O <= nliilO;
				nlii1i <= sync_status;
				nlii1l <= wire_nliiii_dataout;
				nliilO <= (wire_w_lg_rgenericfifo32w(0) AND n0Ol0O);
				nliiOi <= nlil1O;
				nlil0i <= wire_nlilii_dataout;
				nlil0l <= wire_nlilil_dataout;
				nlil0O <= wire_nlilOO_dataout;
				nlil1O <= nlil0l;
				nlilOl <= wire_nliO0i_dataout;
				nliO01l <= wire_nliO00l_dataout;
				nliO01O <= wire_nliO00O_dataout;
				nliO1i <= wire_nliO1O_dataout;
				nlll <= n1l;
				nlO00OO <= wire_nlOi1li_dataout;
				nlOi1iO <= nlOiO1O;
				nlOiO0i <= nlOiO0l;
				nlOiO0l <= sync_status;
				nlOiO0O <= nlOiOii;
				nlOiO1O <= (rgenericfifo AND rdenable);
				nlOiOii <= align_status;
				nlOl0OO <= wire_nlOll1O_dataout;
				nlOli0i <= wire_nlOllii_dataout;
				nlOli0l <= wire_nlOllil_dataout;
				nlOli0O <= wire_nlOlliO_dataout;
				nlOli1i <= wire_nlOll0i_dataout;
				nlOli1l <= wire_nlOll0l_dataout;
				nlOli1O <= wire_nlOll0O_dataout;
				nlOliii <= wire_nlOllli_dataout;
				nlOliil <= wire_nlOllll_dataout;
				nlOliiO <= wire_nlOlllO_dataout;
				nlOlili <= wire_nlOllOi_dataout;
				nlOlilO <= wire_nlOllOl_dataout;
				nlOliOO <= wire_nlOllOO_dataout;
				nlOll1i <= wire_nlOlO1i_dataout;
				nlOll1l <= n110iO;
		END IF;
	END PROCESS;
	wire_n1i_CLRN <= ((nlilOOO8 XOR nlilOOO7) AND wire_w_lg_nliO1il2w(0));
	wire_n1i_PRN <= (nlilOOl10 XOR nlilOOl9);
	wire_n1i_w_lg_w_lg_w_lg_w1365w1366w1367w1368w(0) <= wire_n1i_w_lg_w_lg_w1365w1366w1367w(0) AND nii1OO;
	wire_n1i_w_lg_w_lg_w_lg_w1399w1400w1401w1402w(0) <= wire_n1i_w_lg_w_lg_w1399w1400w1401w(0) AND ni0OOl;
	wire_n1i_w_lg_w_lg_w1365w1366w1367w(0) <= wire_n1i_w_lg_w1365w1366w(0) AND nii01i;
	wire_n1i_w_lg_w_lg_w1399w1400w1401w(0) <= wire_n1i_w_lg_w1399w1400w(0) AND ni0OOO;
	wire_n1i_w_lg_w1365w1366w(0) <= wire_n1i_w1365w(0) AND nii01O;
	wire_n1i_w_lg_w1399w1400w(0) <= wire_n1i_w1399w(0) AND nii11l;
	wire_n1i_w1365w(0) <= wire_n1i_w_lg_w_lg_w_lg_w_lg_nii0il1358w1360w1362w1363w(0) AND wire_n1i_w_lg_nii00i1364w(0);
	wire_n1i_w1399w(0) <= wire_n1i_w_lg_w_lg_w_lg_w_lg_nii1ii1392w1394w1396w1397w(0) AND wire_n1i_w_lg_nii11O1398w(0);
	wire_n1i_w_lg_w_lg_w_lg_w_lg_nii0il1341w1342w1344w1345w(0) <= wire_n1i_w_lg_w_lg_w_lg_nii0il1341w1342w1344w(0) AND nii00i;
	wire_n1i_w_lg_w_lg_w_lg_w_lg_nii1ii1375w1376w1378w1379w(0) <= wire_n1i_w_lg_w_lg_w_lg_nii1ii1375w1376w1378w(0) AND nii11O;
	wire_n1i_w_lg_w_lg_w_lg_w_lg_nii0il1358w1360w1362w1363w(0) <= wire_n1i_w_lg_w_lg_w_lg_nii0il1358w1360w1362w(0) AND nii00l;
	wire_n1i_w_lg_w_lg_w_lg_w_lg_nii1ii1392w1394w1396w1397w(0) <= wire_n1i_w_lg_w_lg_w_lg_nii1ii1392w1394w1396w(0) AND nii10i;
	wire_n1i_w_lg_w_lg_w_lg_nii0il1341w1342w1344w(0) <= wire_n1i_w_lg_w_lg_nii0il1341w1342w(0) AND wire_n1i_w_lg_nii00l1343w(0);
	wire_n1i_w_lg_w_lg_w_lg_nii1ii1375w1376w1378w(0) <= wire_n1i_w_lg_w_lg_nii1ii1375w1376w(0) AND wire_n1i_w_lg_nii10i1377w(0);
	wire_n1i_w_lg_w_lg_w_lg_nii0il1358w1360w1362w(0) <= wire_n1i_w_lg_w_lg_nii0il1358w1360w(0) AND wire_n1i_w_lg_nii00O1361w(0);
	wire_n1i_w_lg_w_lg_w_lg_nii1ii1392w1394w1396w(0) <= wire_n1i_w_lg_w_lg_nii1ii1392w1394w(0) AND wire_n1i_w_lg_nii10l1395w(0);
	wire_n1i_w_lg_w_lg_nii0il1341w1342w(0) <= wire_n1i_w_lg_nii0il1341w(0) AND nii00O;
	wire_n1i_w_lg_w_lg_nii1ii1375w1376w(0) <= wire_n1i_w_lg_nii1ii1375w(0) AND nii10l;
	wire_n1i_w_lg_w_lg_nii0il1358w1360w(0) <= wire_n1i_w_lg_nii0il1358w(0) AND wire_n1i_w_lg_nii0ii1359w(0);
	wire_n1i_w_lg_w_lg_nii1ii1392w1394w(0) <= wire_n1i_w_lg_nii1ii1392w(0) AND wire_n1i_w_lg_nii10O1393w(0);
	wire_n1i_w_lg_w_lg_nlilOl458w459w(0) <= wire_n1i_w_lg_nlilOl458w(0) AND nlil0O;
	wire_n1i_w_lg_n100ii3075w(0) <= n100ii AND wire_n1i_w_lg_n1000O3074w(0);
	wire_n1i_w_lg_n1liil2154w(0) <= n1liil AND wire_w_lg_w_lg_nlillii120w2153w(0);
	wire_n1i_w_lg_nii0il1341w(0) <= nii0il AND nii0ii;
	wire_n1i_w_lg_nii1ii1375w(0) <= nii1ii AND nii10O;
	wire_n1i_w_lg_niOOii1336w(0) <= niOOii AND wire_n1i_w_lg_niOO0O1335w(0);
	wire_n1i_w_lg_nlii0O548w(0) <= nlii0O AND wire_w_lg_nlil0iO547w(0);
	wire_n1i_w_lg_n1000l3076w(0) <= NOT n1000l;
	wire_n1i_w_lg_n1000O3074w(0) <= NOT n1000O;
	wire_n1i_w_lg_n110iO2148w(0) <= NOT n110iO;
	wire_n1i_w_lg_n110li2131w(0) <= NOT n110li;
	wire_n1i_w_lg_n110ll2149w(0) <= NOT n110ll;
	wire_n1i_w_lg_n110lO3093w(0) <= NOT n110lO;
	wire_n1i_w_lg_n11iil3091w(0) <= NOT n11iil;
	wire_n1i_w_lg_n11iiO3089w(0) <= NOT n11iiO;
	wire_n1i_w_lg_n11ili3087w(0) <= NOT n11ili;
	wire_n1i_w_lg_n11ill3085w(0) <= NOT n11ill;
	wire_n1i_w_lg_n11ilO3083w(0) <= NOT n11ilO;
	wire_n1i_w_lg_n11iOi3081w(0) <= NOT n11iOi;
	wire_n1i_w_lg_n11iOl3080w(0) <= NOT n11iOl;
	wire_n1i_w_lg_n11iOO1967w(0) <= NOT n11iOO;
	wire_n1i_w_lg_n11O0i2092w(0) <= NOT n11O0i;
	wire_n1i_w_lg_n11O0l2091w(0) <= NOT n11O0l;
	wire_n1i_w_lg_n11O1i1951w(0) <= NOT n11O1i;
	wire_n1i_w_lg_n11O1l2086w(0) <= NOT n11O1l;
	wire_n1i_w_lg_n11O1O2094w(0) <= NOT n11O1O;
	wire_n1i_w_lg_ni0OOl1384w(0) <= NOT ni0OOl;
	wire_n1i_w_lg_ni0OOO1382w(0) <= NOT ni0OOO;
	wire_n1i_w_lg_nii00i1364w(0) <= NOT nii00i;
	wire_n1i_w_lg_nii00l1343w(0) <= NOT nii00l;
	wire_n1i_w_lg_nii00O1361w(0) <= NOT nii00O;
	wire_n1i_w_lg_nii01i1348w(0) <= NOT nii01i;
	wire_n1i_w_lg_nii01O1346w(0) <= NOT nii01O;
	wire_n1i_w_lg_nii0ii1359w(0) <= NOT nii0ii;
	wire_n1i_w_lg_nii0il1358w(0) <= NOT nii0il;
	wire_n1i_w_lg_nii10i1377w(0) <= NOT nii10i;
	wire_n1i_w_lg_nii10l1395w(0) <= NOT nii10l;
	wire_n1i_w_lg_nii10O1393w(0) <= NOT nii10O;
	wire_n1i_w_lg_nii11l1380w(0) <= NOT nii11l;
	wire_n1i_w_lg_nii11O1398w(0) <= NOT nii11O;
	wire_n1i_w_lg_nii1ii1392w(0) <= NOT nii1ii;
	wire_n1i_w_lg_nii1OO1350w(0) <= NOT nii1OO;
	wire_n1i_w_lg_niOO0l1337w(0) <= NOT niOO0l;
	wire_n1i_w_lg_niOO0O1335w(0) <= NOT niOO0O;
	wire_n1i_w_lg_nli0il643w(0) <= NOT nli0il;
	wire_n1i_w_lg_nlil0i484w(0) <= NOT nlil0i;
	wire_n1i_w_lg_nlil0l722w(0) <= NOT nlil0l;
	wire_n1i_w_lg_nlilOl458w(0) <= NOT nlilOl;
	wire_n1i_w_lg_nlOi1iO2142w(0) <= NOT nlOi1iO;
	PROCESS (clk_1, wire_ni11Oi_PRN, wire_ni11Oi_CLRN)
	BEGIN
		IF (wire_ni11Oi_PRN = '0') THEN
				n0l0iO <= '1';
				ni11ll <= '1';
				ni11lO <= '1';
				ni11Ol <= '1';
				nlliiOO <= '1';
				nllil1i <= '1';
				nllil1l <= '1';
				nlllO0l <= '1';
		ELSIF (wire_ni11Oi_CLRN = '0') THEN
				n0l0iO <= '0';
				ni11ll <= '0';
				ni11lO <= '0';
				ni11Ol <= '0';
				nlliiOO <= '0';
				nllil1i <= '0';
				nllil1l <= '0';
				nlllO0l <= '0';
		ELSIF (clk_1 = '1' AND clk_1'event) THEN
				n0l0iO <= wire_n0ll0l_dataout;
				ni11ll <= wire_ni100i_dataout;
				ni11lO <= wire_ni100l_dataout;
				ni11Ol <= wire_ni100O_dataout;
				nlliiOO <= wire_nllilii_dataout;
				nllil1i <= wire_nllilil_dataout;
				nllil1l <= wire_nlliliO_dataout;
				nlllO0l <= wire_nllO01i_dataout;
		END IF;
		if (now = 0 ns) then
			n0l0iO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni11ll <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni11lO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni11Ol <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlliiOO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nllil1i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nllil1l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlllO0l <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_ni11Oi_CLRN <= (nliil1l58 XOR nliil1l57);
	wire_ni11Oi_PRN <= ((nliil1i60 XOR nliil1i59) AND wire_nl0i_w_lg_dataout4w(0));
	PROCESS (clk_1, wire_nii_CLRN)
	BEGIN
		IF (wire_nii_CLRN = '0') THEN
				n0111O <= '0';
				n0l00l <= '0';
				n0l00O <= '0';
				n0l0ii <= '0';
				n0l0il <= '0';
				n0l0li <= '0';
				n0l0ll <= '0';
				n0l0lO <= '0';
				n0l0Oi <= '0';
				n0l0Ol <= '0';
				n0l0OO <= '0';
				n0li0i <= '0';
				n0li0l <= '0';
				n0li0O <= '0';
				n0li1i <= '0';
				n0li1l <= '0';
				n0li1O <= '0';
				n0liii <= '0';
				n0liil <= '0';
				n0liiO <= '0';
				n0lili <= '0';
				n0lill <= '0';
				n0lilO <= '0';
				n0liOi <= '0';
				n0liOl <= '0';
				n0O0ll <= '0';
				n0O0lO <= '0';
				n0O0Oi <= '0';
				n0O0Ol <= '0';
				n0O0OO <= '0';
				n0Oiil <= '0';
				n0OiOl <= '0';
				n0OiOO <= '0';
				n0Ol0i <= '0';
				n0Ol0l <= '0';
				n0Ol0O <= '0';
				n0Ol1l <= '0';
				n0Ol1O <= '0';
				n0OO1O <= '0';
				n0OOli <= '0';
				n0OOll <= '0';
				n1O <= '0';
				ni000i <= '0';
				ni000l <= '0';
				ni00il <= '0';
				ni00iO <= '0';
				ni00Oi <= '0';
				ni101i <= '0';
				ni101l <= '0';
				ni110i <= '0';
				ni110l <= '0';
				ni111i <= '0';
				ni111l <= '0';
				ni111O <= '0';
				ni11OO <= '0';
				ni1i0i <= '0';
				ni1i0l <= '0';
				ni1i0O <= '0';
				ni1i1l <= '0';
				ni1i1O <= '0';
				ni1llO <= '0';
				ni1O0i <= '0';
				ni1O0l <= '0';
				ni1O0O <= '0';
				ni1O1l <= '0';
				ni1O1O <= '0';
				nil <= '0';
				nliO00i <= '0';
				nliO1l <= '0';
				nlli00O <= '0';
				nlli0Oi <= '0';
				nlli0Ol <= '0';
				nlli1ii <= '0';
				nlli1il <= '0';
				nlli1iO <= '0';
				nlli1li <= '0';
				nlli1ll <= '0';
				nllii0l <= '0';
				nllii0O <= '0';
				nllii1O <= '0';
				nlliiii <= '0';
				nlliiil <= '0';
				nlliiiO <= '0';
				nlliiO <= '0';
				nllil0i <= '0';
				nllil0l <= '0';
				nllil1O <= '0';
				nllili <= '0';
				nllill <= '0';
				nllilO <= '0';
				nlliOi <= '0';
				nlliOl <= '0';
				nlliOO <= '0';
				nlll0i <= '0';
				nlll0l <= '0';
				nlll0O <= '0';
				nlll10l <= '0';
				nlll10O <= '0';
				nlll1i <= '0';
				nlll1ii <= '0';
				nlll1il <= '0';
				nlll1iO <= '0';
				nlll1l <= '0';
				nlll1li <= '0';
				nlll1O <= '0';
				nlllii <= '0';
				nlllil <= '0';
				nllliO <= '0';
				nllll0O <= '0';
				nlllli <= '0';
				nllllii <= '0';
				nlllliO <= '0';
				nlllll <= '0';
				nllllli <= '0';
				nllllO <= '0';
				nlllO0i <= '0';
				nlllO0O <= '0';
				nlllO1i <= '0';
				nlllO1l <= '0';
				nlllO1O <= '0';
				nlllOi <= '0';
				nlllOii <= '0';
				nlllOil <= '0';
				nlllOiO <= '0';
				nlllOl <= '0';
				nlllOli <= '0';
				nlllOll <= '0';
				nlllOlO <= '0';
				nlllOO <= '0';
				nlllOOi <= '0';
				nlllOOl <= '0';
				nlllOOO <= '0';
				nllO0i <= '0';
				nllO0l <= '0';
				nllO10i <= '0';
				nllO10l <= '0';
				nllO10O <= '0';
				nllO11i <= '0';
				nllO11l <= '0';
				nllO11O <= '0';
				nllO1i <= '0';
				nllO1ii <= '0';
				nllO1il <= '0';
				nllO1iO <= '0';
				nllO1l <= '0';
				nllO1li <= '0';
				nllO1O <= '0';
				nllOOi <= '0';
				nllOOl <= '0';
				nlO00ii <= '0';
				nlO00li <= '0';
				nlO00ll <= '0';
				nlO00lO <= '0';
				nlO00Oi <= '0';
				nlO00Ol <= '0';
				nlO011i <= '0';
				nlO011l <= '0';
				nlO01l <= '0';
				nlO01O <= '0';
				nlO10li <= '0';
				nlO10ll <= '0';
				nlO10lO <= '0';
				nlO10Oi <= '0';
				nlO1i0O <= '0';
				nlO1Oii <= '0';
				nlO1OiO <= '0';
				nlO1OOi <= '0';
				nlO1OOl <= '0';
				nlO1OOO <= '0';
		ELSIF (clk_1 = '1' AND clk_1'event) THEN
				n0111O <= wire_n0110O_dataout;
				n0l00l <= wire_n0ll1i_dataout;
				n0l00O <= wire_n0ll1l_dataout;
				n0l0ii <= wire_n0ll1O_dataout;
				n0l0il <= wire_n0ll0i_dataout;
				n0l0li <= wire_n0ll0O_dataout;
				n0l0ll <= wire_n0llii_dataout;
				n0l0lO <= wire_n0llil_dataout;
				n0l0Oi <= wire_n0lliO_dataout;
				n0l0Ol <= wire_n0llli_dataout;
				n0l0OO <= wire_n0llll_dataout;
				n0li0i <= wire_n0llOO_dataout;
				n0li0l <= wire_n0lO1i_dataout;
				n0li0O <= wire_n0lO1l_dataout;
				n0li1i <= wire_n0lllO_dataout;
				n0li1l <= wire_n0llOi_dataout;
				n0li1O <= wire_n0llOl_dataout;
				n0liii <= wire_n0lO1O_dataout;
				n0liil <= wire_n0lO0i_dataout;
				n0liiO <= wire_n0lO0l_dataout;
				n0lili <= wire_n0lO0O_dataout;
				n0lill <= wire_n0lOii_dataout;
				n0lilO <= wire_n0lOil_dataout;
				n0liOi <= wire_n0lOiO_dataout;
				n0liOl <= wire_n0Oi1O_dataout;
				n0O0ll <= wire_n0liOO_dataout;
				n0O0lO <= wire_n0Oi0i_dataout;
				n0O0Oi <= wire_n0Oi0l_dataout;
				n0O0Ol <= wire_n0Oi0O_dataout;
				n0O0OO <= wire_n0Oiii_dataout;
				n0Oiil <= n0OiOl;
				n0OiOl <= (rgenericfifo AND wrenable);
				n0OiOO <= wire_n0Olii_dataout;
				n0Ol0i <= wire_n0Olli_dataout;
				n0Ol0l <= wire_n0Olll_dataout;
				n0Ol0O <= wire_n0OO0i_dataout;
				n0Ol1l <= wire_n0Olil_dataout;
				n0Ol1O <= wire_n0OliO_dataout;
				n0OO1O <= n0OOli;
				n0OOli <= nliiO0O;
				n0OOll <= wire_ni110O_dataout;
				n1O <= nil;
				ni000i <= wire_ni00ii_dataout;
				ni000l <= wire_ni00li_dataout;
				ni00il <= wire_ni00ll_dataout;
				ni00iO <= wire_ni00OO_dataout;
				ni00Oi <= wire_ni0iiO_dataout;
				ni101i <= wire_ni10il_dataout;
				ni101l <= wire_ni1iii_dataout;
				ni110i <= wire_ni11li_dataout;
				ni110l <= wire_ni101O_dataout;
				ni111i <= wire_ni11ii_dataout;
				ni111l <= wire_ni11il_dataout;
				ni111O <= wire_ni11iO_dataout;
				ni11OO <= wire_ni10ii_dataout;
				ni1i0i <= wire_ni1ili_dataout;
				ni1i0l <= wire_ni1ill_dataout;
				ni1i0O <= wire_ni1lOi_dataout;
				ni1i1l <= wire_ni1iil_dataout;
				ni1i1O <= wire_ni1iiO_dataout;
				ni1llO <= wire_ni1Oii_dataout;
				ni1O0i <= wire_ni1Oli_dataout;
				ni1O0l <= wire_ni1Oll_dataout;
				ni1O0O <= wire_ni000O_dataout;
				ni1O1l <= wire_ni1Oil_dataout;
				ni1O1O <= wire_ni1OiO_dataout;
				nil <= wire_niO_dataout;
				nliO00i <= wire_nliO0ii_dataout;
				nliO1l <= sudi(0);
				nlli00O <= wire_nlli1lO_dataout;
				nlli0Oi <= nli0l0i;
				nlli0Ol <= wire_nllii0i_dataout;
				nlli1ii <= wire_nlli1Oi_dataout;
				nlli1il <= wire_nlli1Ol_dataout;
				nlli1iO <= wire_nlli1OO_dataout;
				nlli1li <= wire_nlli01i_dataout;
				nlli1ll <= nlli0Oi;
				nllii0l <= wire_nlliill_dataout;
				nllii0O <= wire_nlliilO_dataout;
				nllii1O <= wire_nlliili_dataout;
				nlliiii <= wire_nlliiOi_dataout;
				nlliiil <= wire_nlliiOl_dataout;
				nlliiiO <= wire_nllil0O_dataout;
				nlliiO <= sudi(1);
				nllil0i <= wire_nllilll_dataout;
				nllil0l <= wire_nlll1ll_dataout;
				nllil1O <= wire_nllilli_dataout;
				nllili <= sudi(2);
				nllill <= sudi(3);
				nllilO <= sudi(4);
				nlliOi <= sudi(5);
				nlliOl <= sudi(6);
				nlliOO <= sudi(7);
				nlll0i <= sudi(11);
				nlll0l <= sudi(12);
				nlll0O <= sudi(13);
				nlll10l <= wire_nlll1lO_dataout;
				nlll10O <= wire_nlll1Oi_dataout;
				nlll1i <= sudi(8);
				nlll1ii <= wire_nlll1Ol_dataout;
				nlll1il <= wire_nlll1OO_dataout;
				nlll1iO <= wire_nlll01i_dataout;
				nlll1l <= sudi(9);
				nlll1li <= nllll0O;
				nlll1O <= sudi(10);
				nlllii <= sudi(14);
				nlllil <= sudi(15);
				nllliO <= sudi(16);
				nllll0O <= (rgenericfifo AND wrenable);
				nlllli <= sudi(17);
				nllllii <= wire_nllllll_dataout;
				nlllliO <= wire_nlllllO_dataout;
				nlllll <= sudi(18);
				nllllli <= wire_nllO1ll_dataout;
				nllllO <= sudi(19);
				nlllO0i <= wire_nllO1OO_dataout;
				nlllO0O <= wire_nllO01l_dataout;
				nlllO1i <= wire_nllO1lO_dataout;
				nlllO1l <= wire_nllO1Oi_dataout;
				nlllO1O <= wire_nllO1Ol_dataout;
				nlllOi <= sudi(20);
				nlllOii <= wire_nllO01O_dataout;
				nlllOil <= wire_nllO00i_dataout;
				nlllOiO <= wire_nllO00l_dataout;
				nlllOl <= sudi(21);
				nlllOli <= wire_nllO00O_dataout;
				nlllOll <= wire_nllO0ii_dataout;
				nlllOlO <= wire_nllO0il_dataout;
				nlllOO <= sudi(22);
				nlllOOi <= wire_nllO0iO_dataout;
				nlllOOl <= wire_nllO0li_dataout;
				nlllOOO <= wire_nllO0ll_dataout;
				nllO0i <= sudi(26);
				nllO0l <= sudi(27);
				nllO10i <= wire_nllO0OO_dataout;
				nllO10l <= wire_nllOi1i_dataout;
				nllO10O <= wire_nllOi1l_dataout;
				nllO11i <= wire_nllO0lO_dataout;
				nllO11l <= wire_nllO0Oi_dataout;
				nllO11O <= wire_nllO0Ol_dataout;
				nllO1i <= sudi(23);
				nllO1ii <= wire_nllOi1O_dataout;
				nllO1il <= wire_nllOi0i_dataout;
				nllO1iO <= wire_nllOi0l_dataout;
				nllO1l <= sudi(24);
				nllO1li <= wire_nlO1i1i_dataout;
				nllO1O <= sudi(25);
				nllOOi <= wire_nlO11i_o;
				nllOOl <= wire_nlO11l_o;
				nlO00ii <= (rclkcmpsqmd AND (wire_nlOi10l_dataout AND (((nlillil OR nlO00Oi) OR nlO00lO) OR nlO00ll)));
				nlO00li <= wire_nlO0i1i_dataout;
				nlO00ll <= wire_nlO0i1O_dataout;
				nlO00lO <= wire_nlO0i0l_dataout;
				nlO00Oi <= wire_nlO0iiO_dataout;
				nlO00Ol <= wire_nlO0l1O_dataout;
				nlO011i <= wire_nlO01ii_dataout;
				nlO011l <= wire_nlO00il_dataout;
				nlO01l <= wire_nlO11O_o;
				nlO01O <= wire_nllOOO_o;
				nlO10li <= wire_nlO1i1l_dataout;
				nlO10ll <= wire_nlO1i1O_dataout;
				nlO10lO <= wire_nlO1i0i_dataout;
				nlO10Oi <= wire_nlO1i0l_dataout;
				nlO1i0O <= wire_nlO1Oil_dataout;
				nlO1Oii <= wire_nlO1Oli_dataout;
				nlO1OiO <= wire_nlO011O_dataout;
				nlO1OOi <= wire_nlO010i_dataout;
				nlO1OOl <= wire_nlO010l_dataout;
				nlO1OOO <= wire_nlO010O_dataout;
		END IF;
	END PROCESS;
	wire_nii_CLRN <= ((nliO10i4 XOR nliO10i3) AND wire_nl0i_w_lg_dataout4w(0));
	wire_nii_w_lg_nlllO0i3156w(0) <= nlllO0i AND wire_nii_w_lg_nlllO1O2302w(0);
	wire_nii_w_lg_n0l00l858w(0) <= NOT n0l00l;
	wire_nii_w_lg_n0l00O860w(0) <= NOT n0l00O;
	wire_nii_w_lg_n0l0ii862w(0) <= NOT n0l0ii;
	wire_nii_w_lg_n0l0il864w(0) <= NOT n0l0il;
	wire_nii_w_lg_n0O0ll856w(0) <= NOT n0O0ll;
	wire_nii_w_lg_n0O0OO843w(0) <= NOT n0O0OO;
	wire_nii_w_lg_n0Oiil755w(0) <= NOT n0Oiil;
	wire_nii_w_lg_n0Ol0O974w(0) <= NOT n0Ol0O;
	wire_nii_w_lg_ni1i0i1700w(0) <= NOT ni1i0i;
	wire_nii_w_lg_ni1i0l1699w(0) <= NOT ni1i0l;
	wire_nii_w_lg_ni1i0O967w(0) <= NOT ni1i0O;
	wire_nii_w_lg_ni1llO1648w(0) <= NOT ni1llO;
	wire_nii_w_lg_ni1O0i1642w(0) <= NOT ni1O0i;
	wire_nii_w_lg_ni1O0l1641w(0) <= NOT ni1O0l;
	wire_nii_w_lg_ni1O1l1646w(0) <= NOT ni1O1l;
	wire_nii_w_lg_ni1O1O1644w(0) <= NOT ni1O1O;
	wire_nii_w_lg_nlli0Oi2548w(0) <= NOT nlli0Oi;
	wire_nii_w_lg_nlli0Ol2560w(0) <= NOT nlli0Ol;
	wire_nii_w_lg_nlll10l3171w(0) <= NOT nlll10l;
	wire_nii_w_lg_nlll10O3169w(0) <= NOT nlll10O;
	wire_nii_w_lg_nlll1ii3167w(0) <= NOT nlll1ii;
	wire_nii_w_lg_nlll1il3165w(0) <= NOT nlll1il;
	wire_nii_w_lg_nlll1iO3164w(0) <= NOT nlll1iO;
	wire_nii_w_lg_nlll1li2465w(0) <= NOT nlll1li;
	wire_nii_w_lg_nllllli2296w(0) <= NOT nllllli;
	wire_nii_w_lg_nlllO0i2304w(0) <= NOT nlllO0i;
	wire_nii_w_lg_nlllO1i2298w(0) <= NOT nlllO1i;
	wire_nii_w_lg_nlllO1l2300w(0) <= NOT nlllO1l;
	wire_nii_w_lg_nlllO1O2302w(0) <= NOT nlllO1O;
	wire_nii_w_lg_nlO011i3144w(0) <= NOT nlO011i;
	wire_nii_w_lg_nlO10Oi2283w(0) <= NOT nlO10Oi;
	wire_nii_w_lg_nlO1Oii2347w(0) <= NOT nlO1Oii;
	wire_nii_w_lg_nlO1OOO3145w(0) <= NOT nlO1OOO;
	wire_nii_w_lg_w_lg_nllllii47w48w(0) <= wire_nii_w_lg_nllllii47w(0) OR nlillOi;
	wire_nii_w_lg_nllllii47w(0) <= nllllii OR nlillOl;
	wire_nii_w_lg_nlO00ll2360w(0) <= nlO00ll OR nlO00li;
	wire_nii_w_lg_nlO00lO2361w(0) <= nlO00lO OR wire_nii_w_lg_nlO00ll2360w(0);
	wire_nii_w_lg_nlO00Oi2362w(0) <= nlO00Oi OR wire_nii_w_lg_nlO00lO2361w(0);
	PROCESS (clk_2, wire_nii0lO_CLRN)
	BEGIN
		IF (wire_nii0lO_CLRN = '0') THEN
				ni00Ol <= '0';
				ni0liO <= '0';
				ni0lli <= '0';
				ni0lll <= '0';
				ni0llO <= '0';
				ni0lOi <= '0';
				ni0lOl <= '0';
				ni0lOO <= '0';
				ni0O0i <= '0';
				ni0O0l <= '0';
				ni0O0O <= '0';
				ni0O1i <= '0';
				ni0O1l <= '0';
				ni0O1O <= '0';
				ni0Oii <= '0';
				ni0Oil <= '0';
				ni0OiO <= '0';
				ni0Oli <= '0';
				ni0Oll <= '0';
				ni0OlO <= '0';
				nii0li <= '0';
				nii0Oi <= '0';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
			IF (nlil0l = '0') THEN
				ni00Ol <= wire_niiO1l_dataout;
				ni0liO <= wire_niiO1O_dataout;
				ni0lli <= wire_niiO0i_dataout;
				ni0lll <= wire_niiO0l_dataout;
				ni0llO <= wire_niiO0O_dataout;
				ni0lOi <= wire_niiOii_dataout;
				ni0lOl <= wire_niiOil_dataout;
				ni0lOO <= wire_niiOiO_dataout;
				ni0O0i <= wire_nil11l_dataout;
				ni0O0l <= wire_nil11O_dataout;
				ni0O0O <= wire_nil10i_dataout;
				ni0O1i <= wire_niiOli_dataout;
				ni0O1l <= wire_niiOll_dataout;
				ni0O1O <= wire_nil11i_dataout;
				ni0Oii <= wire_nil10l_dataout;
				ni0Oil <= wire_nil10O_dataout;
				ni0OiO <= wire_nil1ii_dataout;
				ni0Oli <= wire_nil1il_dataout;
				ni0Oll <= wire_nil1iO_dataout;
				ni0OlO <= wire_nil1li_dataout;
				nii0li <= wire_niliil_dataout;
				nii0Oi <= wire_nilili_dataout;
			END IF;
		END IF;
	END PROCESS;
	wire_nii0lO_CLRN <= ((nliiOOi56 XOR nliiOOi55) AND wire_w_lg_nliO1il2w(0));
	wire_nii0lO_w_lg_nii0Oi640w(0) <= NOT nii0Oi;
	PROCESS (clk_1, wire_niiOOl_PRN, wire_niiOOl_CLRN)
	BEGIN
		IF (wire_niiOOl_PRN = '0') THEN
				n0Oi1i <= '1';
				n0Oi1l <= '1';
				niiOlO <= '1';
				niiOOi <= '1';
				niiOOO <= '1';
				nlli10i <= '1';
				nlli10l <= '1';
				nlli10O <= '1';
				nlO10Ol <= '1';
				nlO10OO <= '1';
		ELSIF (wire_niiOOl_CLRN = '0') THEN
				n0Oi1i <= '0';
				n0Oi1l <= '0';
				niiOlO <= '0';
				niiOOi <= '0';
				niiOOO <= '0';
				nlli10i <= '0';
				nlli10l <= '0';
				nlli10O <= '0';
				nlO10Ol <= '0';
				nlO10OO <= '0';
		ELSIF (clk_1 = '1' AND clk_1'event) THEN
				n0Oi1i <= wire_n0Oili_dataout;
				n0Oi1l <= wire_n0OiiO_dataout;
				niiOlO <= wire_n0Oill_dataout;
				niiOOi <= wire_n0OilO_dataout;
				niiOOO <= wire_n0OiOi_dataout;
				nlli10i <= wire_nlO1ill_dataout;
				nlli10l <= wire_nlO1ili_dataout;
				nlli10O <= wire_nlO1iiO_dataout;
				nlO10Ol <= wire_nlO1iil_dataout;
				nlO10OO <= wire_nlO1iii_dataout;
		END IF;
	END PROCESS;
	wire_niiOOl_CLRN <= (nliiOOO52 XOR nliiOOO51);
	wire_niiOOl_PRN <= (nliiOOl54 XOR nliiOOl53);
	PROCESS (clk_1, nliO1il, wire_nl_CLRN)
	BEGIN
		IF (nliO1il = '1') THEN
				nl0l <= '1';
				nO <= '1';
		ELSIF (wire_nl_CLRN = '0') THEN
				nl0l <= '0';
				nO <= '0';
		ELSIF (clk_1 = '1' AND clk_1'event) THEN
				nl0l <= nlilOil;
				nO <= nl0l;
		END IF;
		if (now = 0 ns) then
			nl0l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nO <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nl_CLRN <= (nliO1iO2 XOR nliO1iO1);
	PROCESS (clk_2, nliO1il)
	BEGIN
		IF (nliO1il = '1') THEN
				n100iO <= '1';
				n10iOi <= '1';
				niOOiO <= '1';
				nl11Ol <= '1';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
				n100iO <= wire_n10OOO_dataout;
				n10iOi <= wire_n1i00i_dataout;
				niOOiO <= wire_nl1l1i_dataout;
				nl11Ol <= wire_nl1O0l_dataout;
		END IF;
		if (now = 0 ns) then
			n100iO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n10iOi <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			niOOiO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl11Ol <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2, wire_nli01i_PRN)
	BEGIN
		IF (wire_nli01i_PRN = '0') THEN
				n0l00i <= '1';
				n0l01l <= '1';
				n0l01O <= '1';
				n1O00O <= '1';
				n1O0ii <= '1';
				nli01l <= '1';
				nli1OO <= '1';
				nlli11i <= '1';
				nlli11l <= '1';
				nlli11O <= '1';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
				n0l00i <= wire_nli0ll_dataout;
				n0l01l <= wire_nli0Oi_dataout;
				n0l01O <= wire_nli0lO_dataout;
				n1O00O <= wire_n1O0Ol_dataout;
				n1O0ii <= wire_n1O0Oi_dataout;
				nli01l <= wire_nli0iO_dataout;
				nli1OO <= wire_nli0li_dataout;
				nlli11i <= wire_n1Oi1l_dataout;
				nlli11l <= wire_n1Oi1i_dataout;
				nlli11O <= wire_n1O0OO_dataout;
		END IF;
	END PROCESS;
	wire_nli01i_PRN <= (nlil01l50 XOR nlil01l49);
	PROCESS (clk_2, hard_reset)
	BEGIN
		IF (hard_reset = '1') THEN
				nl0O <= '1';
				nlli <= '1';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
				nl0O <= wire_nllO_dataout;
				nlli <= nl0O;
		END IF;
		if (now = 0 ns) then
			nl0O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlli <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2, wire_nlOliOi_PRN, nliO1il)
	BEGIN
		IF (wire_nlOliOi_PRN = '0') THEN
				nlOiOil <= '1';
				nlOiOli <= '1';
				nlOiOll <= '1';
				nlOiOlO <= '1';
				nlOiOOi <= '1';
				nlOiOOl <= '1';
				nlOiOOO <= '1';
				nlOl00i <= '1';
				nlOl00l <= '1';
				nlOl00O <= '1';
				nlOl01i <= '1';
				nlOl01l <= '1';
				nlOl01O <= '1';
				nlOl0ii <= '1';
				nlOl0il <= '1';
				nlOl0iO <= '1';
				nlOl0li <= '1';
				nlOl0ll <= '1';
				nlOl0lO <= '1';
				nlOl0Oi <= '1';
				nlOl0Ol <= '1';
				nlOl10i <= '1';
				nlOl10l <= '1';
				nlOl10O <= '1';
				nlOl11i <= '1';
				nlOl11l <= '1';
				nlOl11O <= '1';
				nlOl1ii <= '1';
				nlOl1il <= '1';
				nlOl1iO <= '1';
				nlOl1li <= '1';
				nlOl1ll <= '1';
				nlOl1lO <= '1';
				nlOl1Oi <= '1';
				nlOl1Ol <= '1';
				nlOl1OO <= '1';
				nlOlill <= '1';
				nlOliOl <= '1';
		ELSIF (nliO1il = '1') THEN
				nlOiOil <= '0';
				nlOiOli <= '0';
				nlOiOll <= '0';
				nlOiOlO <= '0';
				nlOiOOi <= '0';
				nlOiOOl <= '0';
				nlOiOOO <= '0';
				nlOl00i <= '0';
				nlOl00l <= '0';
				nlOl00O <= '0';
				nlOl01i <= '0';
				nlOl01l <= '0';
				nlOl01O <= '0';
				nlOl0ii <= '0';
				nlOl0il <= '0';
				nlOl0iO <= '0';
				nlOl0li <= '0';
				nlOl0ll <= '0';
				nlOl0lO <= '0';
				nlOl0Oi <= '0';
				nlOl0Ol <= '0';
				nlOl10i <= '0';
				nlOl10l <= '0';
				nlOl10O <= '0';
				nlOl11i <= '0';
				nlOl11l <= '0';
				nlOl11O <= '0';
				nlOl1ii <= '0';
				nlOl1il <= '0';
				nlOl1iO <= '0';
				nlOl1li <= '0';
				nlOl1ll <= '0';
				nlOl1lO <= '0';
				nlOl1Oi <= '0';
				nlOl1Ol <= '0';
				nlOl1OO <= '0';
				nlOlill <= '0';
				nlOliOl <= '0';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
			IF (nlii1Oi = '0') THEN
				nlOiOil <= wire_nlOlOOl_dataout;
				nlOiOli <= wire_nlOlOOO_dataout;
				nlOiOll <= wire_nlOO11i_dataout;
				nlOiOlO <= wire_nlOO11l_dataout;
				nlOiOOi <= wire_nlOO11O_dataout;
				nlOiOOl <= wire_nlOO10i_dataout;
				nlOiOOO <= wire_nlOO10l_dataout;
				nlOl00i <= wire_nlOlO1O_dataout;
				nlOl00l <= wire_nlOlO0i_dataout;
				nlOl00O <= wire_nlOlO0l_dataout;
				nlOl01i <= wire_nlOO00O_dataout;
				nlOl01l <= wire_nlOO0ii_dataout;
				nlOl01O <= wire_nlOlO1l_dataout;
				nlOl0ii <= wire_nlOlO0O_dataout;
				nlOl0il <= wire_nlOlOii_dataout;
				nlOl0iO <= wire_nlOlOil_dataout;
				nlOl0li <= wire_nlOlOiO_dataout;
				nlOl0ll <= wire_nlOlOli_dataout;
				nlOl0lO <= wire_nlOlOll_dataout;
				nlOl0Oi <= wire_nlOlOlO_dataout;
				nlOl0Ol <= wire_nlOlOOi_dataout;
				nlOl10i <= wire_nlOO1iO_dataout;
				nlOl10l <= wire_nlOO1li_dataout;
				nlOl10O <= wire_nlOO1ll_dataout;
				nlOl11i <= wire_nlOO10O_dataout;
				nlOl11l <= wire_nlOO1ii_dataout;
				nlOl11O <= wire_nlOO1il_dataout;
				nlOl1ii <= wire_nlOO1lO_dataout;
				nlOl1il <= wire_nlOO1Oi_dataout;
				nlOl1iO <= wire_nlOO1Ol_dataout;
				nlOl1li <= wire_nlOO1OO_dataout;
				nlOl1ll <= wire_nlOO01i_dataout;
				nlOl1lO <= wire_nlOO01l_dataout;
				nlOl1Oi <= wire_nlOO01O_dataout;
				nlOl1Ol <= wire_nlOO00i_dataout;
				nlOl1OO <= wire_nlOO00l_dataout;
				nlOlill <= wire_nlOOi0i_dataout;
				nlOliOl <= wire_nlOOi0O_dataout;
			END IF;
		END IF;
	END PROCESS;
	wire_nlOliOi_PRN <= (nli0O0O62 XOR nli0O0O61);
	wire_nlOliOi_w_lg_nlOliOl2139w(0) <= NOT nlOliOl;
	wire_n00i_dataout <= wire_nll1il_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi01O_dataout;
	wire_n00l_dataout <= wire_nll1iO_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi00i_dataout;
	wire_n00O_dataout <= wire_nll1li_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi00l_dataout;
	wire_n0110i_dataout <= n0111l AND NOT(wire_w_lg_nlil00O1789w(0));
	wire_n0110l_dataout <= n0111O AND NOT(wire_w_lg_nlil00O1789w(0));
	wire_n0110O_dataout <= wire_nlilOi_o AND (rgenericfifo OR wire_nliOOi_dataout);
	wire_n01i_dataout <= wire_nll10l_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi1OO_dataout;
	wire_n01l_dataout <= wire_nll10O_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi01i_dataout;
	wire_n01O_dataout <= wire_nll1ii_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi01l_dataout;
	wire_n0ii_dataout <= wire_nll1ll_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi00O_dataout;
	wire_n0il_dataout <= wire_nll1lO_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi0ii_dataout;
	wire_n0iO_dataout <= wire_nll1Oi_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi0il_dataout;
	wire_n0li_dataout <= wire_nll1Ol_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi0iO_dataout;
	wire_n0liOO_dataout <= wire_n0lOli_dataout AND NOT(nliiO1i);
	wire_n0ll_dataout <= wire_nll1OO_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi0li_dataout;
	wire_n0ll0i_dataout <= wire_n0lOOl_dataout AND NOT(nliiO1i);
	wire_n0ll0l_dataout <= wire_n0lOOO_dataout OR nliiO1i;
	wire_n0ll0O_dataout <= wire_n0O11i_dataout AND NOT(nliiO1i);
	wire_n0ll1i_dataout <= wire_n0lOll_dataout AND NOT(nliiO1i);
	wire_n0ll1l_dataout <= wire_n0lOlO_dataout AND NOT(nliiO1i);
	wire_n0ll1O_dataout <= wire_n0lOOi_dataout AND NOT(nliiO1i);
	wire_n0llii_dataout <= wire_n0O11l_dataout AND NOT(nliiO1i);
	wire_n0llil_dataout <= wire_n0O11O_dataout AND NOT(nliiO1i);
	wire_n0lliO_dataout <= wire_n0O10i_dataout AND NOT(nliiO1i);
	wire_n0llli_dataout <= wire_n0O10l_dataout AND NOT(nliiO1i);
	wire_n0llll_dataout <= wire_n0O10O_dataout AND NOT(nliiO1i);
	wire_n0lllO_dataout <= wire_n0O1ii_dataout AND NOT(nliiO1i);
	wire_n0llOi_dataout <= wire_n0O1il_dataout AND NOT(nliiO1i);
	wire_n0llOl_dataout <= wire_n0O1iO_dataout AND NOT(nliiO1i);
	wire_n0llOO_dataout <= wire_n0O1li_dataout AND NOT(nliiO1i);
	wire_n0lO_dataout <= wire_nll01i_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi0ll_dataout;
	wire_n0lO0i_dataout <= wire_n0O1Ol_dataout AND NOT(nliiO1i);
	wire_n0lO0l_dataout <= wire_n0O1OO_dataout AND NOT(nliiO1i);
	wire_n0lO0O_dataout <= wire_n0O01i_dataout AND NOT(nliiO1i);
	wire_n0lO1i_dataout <= wire_n0O1ll_dataout AND NOT(nliiO1i);
	wire_n0lO1l_dataout <= wire_n0O1lO_dataout AND NOT(nliiO1i);
	wire_n0lO1O_dataout <= wire_n0O1Oi_dataout AND NOT(nliiO1i);
	wire_n0lOii_dataout <= wire_n0O01l_dataout AND NOT(nliiO1i);
	wire_n0lOil_dataout <= wire_n0O01O_dataout AND NOT(nliiO1i);
	wire_n0lOiO_dataout <= wire_n0O00i_dataout AND NOT(nliiO1i);
	wire_n0lOli_dataout <= wire_n0O00l_dataout WHEN nliilOl = '1'  ELSE n0O0ll;
	wire_n0lOll_dataout <= wire_n0O00O_dataout WHEN nliilOl = '1'  ELSE n0l00l;
	wire_n0lOlO_dataout <= wire_n0O0ii_dataout WHEN nliilOl = '1'  ELSE n0l00O;
	wire_n0lOOi_dataout <= wire_n0O0il_dataout WHEN nliilOl = '1'  ELSE n0l0ii;
	wire_n0lOOl_dataout <= wire_n0O0iO_dataout WHEN nliilOl = '1'  ELSE n0l0il;
	wire_n0lOOO_dataout <= n0liOi WHEN nliilOl = '1'  ELSE n0l0iO;
	wire_n0O00i_dataout <= n0lilO WHEN nliilOl = '1'  ELSE n0liOi;
	wire_n0O00l_dataout <= wire_n0O0li_o(0) AND NOT(nliii0O);
	wire_n0O00O_dataout <= wire_n0O0li_o(1) AND NOT(nliii0O);
	wire_n0O01i_dataout <= n0liiO WHEN nliilOl = '1'  ELSE n0lili;
	wire_n0O01l_dataout <= n0lili WHEN nliilOl = '1'  ELSE n0lill;
	wire_n0O01O_dataout <= n0lill WHEN nliilOl = '1'  ELSE n0lilO;
	wire_n0O0ii_dataout <= wire_n0O0li_o(2) AND NOT(nliii0O);
	wire_n0O0il_dataout <= wire_n0O0li_o(3) AND NOT(nliii0O);
	wire_n0O0iO_dataout <= wire_n0O0li_o(4) AND NOT(nliii0O);
	wire_n0O10i_dataout <= n0l0lO WHEN nliilOl = '1'  ELSE n0l0Oi;
	wire_n0O10l_dataout <= n0l0Oi WHEN nliilOl = '1'  ELSE n0l0Ol;
	wire_n0O10O_dataout <= n0l0Ol WHEN nliilOl = '1'  ELSE n0l0OO;
	wire_n0O11i_dataout <= n0l0iO WHEN nliilOl = '1'  ELSE n0l0li;
	wire_n0O11l_dataout <= n0l0li WHEN nliilOl = '1'  ELSE n0l0ll;
	wire_n0O11O_dataout <= n0l0ll WHEN nliilOl = '1'  ELSE n0l0lO;
	wire_n0O1ii_dataout <= n0l0OO WHEN nliilOl = '1'  ELSE n0li1i;
	wire_n0O1il_dataout <= n0li1i WHEN nliilOl = '1'  ELSE n0li1l;
	wire_n0O1iO_dataout <= n0li1l WHEN nliilOl = '1'  ELSE n0li1O;
	wire_n0O1li_dataout <= n0li1O WHEN nliilOl = '1'  ELSE n0li0i;
	wire_n0O1ll_dataout <= n0li0i WHEN nliilOl = '1'  ELSE n0li0l;
	wire_n0O1lO_dataout <= n0li0l WHEN nliilOl = '1'  ELSE n0li0O;
	wire_n0O1Oi_dataout <= n0li0O WHEN nliilOl = '1'  ELSE n0liii;
	wire_n0O1Ol_dataout <= n0liii WHEN nliilOl = '1'  ELSE n0liil;
	wire_n0O1OO_dataout <= n0liil WHEN nliilOl = '1'  ELSE n0liiO;
	wire_n0Oi_dataout <= wire_nll01l_dataout AND rwa_6g_en;
	wire_n0Oi0i_dataout <= n0Oi1i AND NOT(nliiO1i);
	wire_n0Oi0l_dataout <= niiOlO AND NOT(nliiO1i);
	wire_n0Oi0O_dataout <= niiOOi AND NOT(nliiO1i);
	wire_n0Oi1O_dataout <= n0Oi1l AND NOT(nliiO1i);
	wire_n0Oiii_dataout <= niiOOO AND NOT(nliiO1i);
	wire_n0OiiO_dataout <= niii1i AND NOT(nliiO1i);
	wire_n0Oili_dataout <= niOlOl AND NOT(nliiO1i);
	wire_n0Oill_dataout <= niOlOO AND NOT(nliiO1i);
	wire_n0OilO_dataout <= niOO1i AND NOT(nliiO1i);
	wire_n0OiOi_dataout <= niOO1l AND NOT(nliiO1i);
	wire_n0Ol_dataout <= wire_nll01O_dataout AND rwa_6g_en;
	wire_n0Olii_dataout <= nliiiii AND NOT(nliiO1i);
	wire_n0Olil_dataout <= nliiiil AND NOT(nliiO1i);
	wire_n0OliO_dataout <= nliiiiO AND NOT(nliiO1i);
	wire_n0Olli_dataout <= nliiili AND NOT(nliiO1i);
	wire_n0Olll_dataout <= nliiill AND NOT(nliiO1i);
	wire_n0OO_dataout <= wire_nll00i_dataout AND rwa_6g_en;
	wire_n0OO0i_dataout <= wire_n0OO0l_dataout AND wire_nliOOi_dataout;
	wire_n0OO0l_dataout <= n0Ol0O OR (wire_nii_w_lg_n0Ol0O974w(0) AND nliiilO);
	wire_n0OOii_dataout <= (nliiiOi OR n0OO1O) WHEN nliO11i = '1'  ELSE nliiiOi;
	wire_n1011i_dataout <= wire_n1010i_o(0) AND nli0OOi;
	wire_n1011l_dataout <= wire_n1010i_o(1) AND nli0OOi;
	wire_n1011O_dataout <= wire_n1010i_o(2) AND nli0OOi;
	wire_n101iO_dataout <= n11O1l AND wire_nlOi11i_dataout;
	wire_n101li_dataout <= (rclkcmpsqmd AND (nlii1li AND wire_n1i_w_lg_n11O1l2086w(0))) AND wire_nlOi11i_dataout;
	wire_n101ll_dataout <= nlii1li AND wire_nlOi11i_dataout;
	wire_n10i_dataout <= nl10OO WHEN rwa_6g_en = '1'  ELSE n10lOl;
	wire_n10l_dataout <= nl1i1i WHEN rwa_6g_en = '1'  ELSE n10lOO;
	wire_n10O_dataout <= nl1i1l WHEN rwa_6g_en = '1'  ELSE n10O1i;
	wire_n10O0i_dataout <= wire_n1iiiO_dataout AND NOT(nlii00O);
	wire_n10O0l_dataout <= wire_n1iili_dataout AND NOT(nlii00O);
	wire_n10O0O_dataout <= wire_n1iill_dataout AND NOT(nlii00O);
	wire_n10Oii_dataout <= wire_n1iilO_dataout AND NOT(nlii00O);
	wire_n10Oil_dataout <= wire_n1iiOi_dataout AND NOT(nlii00O);
	wire_n10OiO_dataout <= wire_n1iiOl_dataout AND NOT(nlii00O);
	wire_n10Oli_dataout <= wire_n1iiOO_dataout AND NOT(nlii00O);
	wire_n10Oll_dataout <= wire_n1il1i_dataout AND NOT(nlii00O);
	wire_n10OlO_dataout <= wire_n1il1l_dataout AND NOT(nlii00O);
	wire_n10OOi_dataout <= wire_n1il1O_dataout AND NOT(nlii00O);
	wire_n10OOl_dataout <= wire_n1il0i_dataout AND NOT(nlii00O);
	wire_n10OOO_dataout <= wire_n1il0l_dataout OR nlii00O;
	wire_n1100i_dataout <= wire_nlOliOi_w_lg_nlOliOl2139w(0) WHEN rclkcmpinsertpad = '1'  ELSE nlOliOl;
	wire_n1100l_dataout <= nlOliOl WHEN rclkcmpinsertpad = '1'  ELSE wire_nlOliOi_w_lg_nlOliOl2139w(0);
	wire_n1100O_dataout <= (nli0OiO OR nlOll1l) WHEN nlilOiO = '1'  ELSE nli0OiO;
	wire_n1101i_dataout <= nlOll1i OR nlii1li;
	wire_n110Oi_dataout <= nliO01l AND NOT(nlii00O);
	wire_n110Ol_dataout <= ((((n1lili AND nliO01l) AND wire_n1i_w_lg_n110li2131w(0)) AND (rskpsetbased OR nli0Oll)) AND wire_w_lg_nli0Oli2135w(0)) AND NOT(nlii00O);
	wire_n1110i_dataout <= nlOiOlO WHEN nlii1li = '1'  ELSE nlOli1O;
	wire_n1110l_dataout <= nlOiOOi WHEN nlii1li = '1'  ELSE nlOli0i;
	wire_n1110O_dataout <= nlOiOOl WHEN nlii1li = '1'  ELSE nlOli0l;
	wire_n1111i_dataout <= nlOiOil WHEN nlii1li = '1'  ELSE nlOl0OO;
	wire_n1111l_dataout <= nlOiOli WHEN nlii1li = '1'  ELSE nlOli1i;
	wire_n1111O_dataout <= nlOiOll WHEN nlii1li = '1'  ELSE nlOli1l;
	wire_n111ii_dataout <= nlOiOOO WHEN nlii1li = '1'  ELSE nlOli0O;
	wire_n111il_dataout <= nlOl11i WHEN nlii1li = '1'  ELSE nlOliii;
	wire_n111iO_dataout <= nlOl11l WHEN nlii1li = '1'  ELSE nlOliil;
	wire_n111li_dataout <= nlOl11O WHEN nlii1li = '1'  ELSE nlOliiO;
	wire_n111ll_dataout <= nlOlili AND NOT(nlii1li);
	wire_n111lO_dataout <= nlOl10i WHEN nlii1li = '1'  ELSE nlOlill;
	wire_n111Oi_dataout <= nlOlilO AND NOT(nlii1li);
	wire_n111Ol_dataout <= nlOl10l WHEN nlii1li = '1'  ELSE nlOliOl;
	wire_n111OO_dataout <= nlOliOO AND NOT(nlii1li);
	wire_n11i_dataout <= nl10lO WHEN rwa_6g_en = '1'  ELSE n10lll;
	wire_n11l_dataout <= nl10Oi WHEN rwa_6g_en = '1'  ELSE n10llO;
	wire_n11l0i_dataout <= wire_n11lll_dataout AND NOT(nlii00O);
	wire_n11l0l_dataout <= wire_n11llO_dataout AND NOT(nlii00O);
	wire_n11l0O_dataout <= wire_n11lOi_dataout AND NOT(nlii00O);
	wire_n11l1i_dataout <= nlii1li AND NOT(nlii00O);
	wire_n11l1l_dataout <= wire_n11liO_dataout AND NOT(nlii00O);
	wire_n11l1O_dataout <= wire_n11lli_dataout AND NOT(nlii00O);
	wire_n11lii_dataout <= wire_n11lOl_dataout AND NOT(nlii00O);
	wire_n11lil_dataout <= wire_n11lOO_dataout AND NOT(nlii00O);
	wire_n11liO_dataout <= n110lO AND NOT(nlii1li);
	wire_n11lli_dataout <= n11iil AND NOT(nlii1li);
	wire_n11lll_dataout <= n11iiO AND NOT(nlii1li);
	wire_n11llO_dataout <= n11ili AND NOT(nlii1li);
	wire_n11lOi_dataout <= n11ill AND NOT(nlii1li);
	wire_n11lOl_dataout <= n11ilO AND NOT(nlii1li);
	wire_n11lOO_dataout <= n11iOi AND NOT(nlii1li);
	wire_n11O_dataout <= nl10Ol WHEN rwa_6g_en = '1'  ELSE n10lOi;
	wire_n11Oii_dataout <= wire_n11Oli_dataout AND wire_nlOi11i_dataout;
	wire_n11Oil_dataout <= wire_n11Oll_dataout AND wire_nlOi11i_dataout;
	wire_n11OiO_dataout <= wire_n11OlO_dataout AND wire_nlOi11i_dataout;
	wire_n11Oli_dataout <= wire_n11OOi_dataout OR nli0OOO;
	wire_n11Oll_dataout <= wire_n11OOl_dataout AND NOT(nli0OOO);
	wire_n11OlO_dataout <= wire_n11OOO_dataout AND NOT(nli0OOO);
	wire_n11OOi_dataout <= wire_n1010i_o(0) WHEN nli0OOl = '1'  ELSE wire_n1011i_dataout;
	wire_n11OOl_dataout <= wire_n1010i_o(1) WHEN nli0OOl = '1'  ELSE wire_n1011l_dataout;
	wire_n11OOO_dataout <= wire_n1010i_o(2) WHEN nli0OOl = '1'  ELSE wire_n1011O_dataout;
	wire_n1i00i_dataout <= wire_n1iOiO_dataout OR nlii00O;
	wire_n1i00l_dataout <= wire_n1iOli_dataout AND NOT(nlii00O);
	wire_n1i00O_dataout <= wire_n1iOll_dataout AND NOT(nlii00O);
	wire_n1i01i_dataout <= wire_n1iO0O_dataout AND NOT(nlii00O);
	wire_n1i01l_dataout <= wire_n1iOii_dataout AND NOT(nlii00O);
	wire_n1i01O_dataout <= wire_n1iOil_dataout AND NOT(nlii00O);
	wire_n1i0ii_dataout <= wire_n1iOlO_dataout AND NOT(nlii00O);
	wire_n1i0il_dataout <= wire_n1iOOi_dataout AND NOT(nlii00O);
	wire_n1i0iO_dataout <= wire_n1iOOl_dataout AND NOT(nlii00O);
	wire_n1i0li_dataout <= wire_n1iOOO_dataout AND NOT(nlii00O);
	wire_n1i0ll_dataout <= wire_n1l11i_dataout AND NOT(nlii00O);
	wire_n1i0lO_dataout <= wire_n1l11l_dataout AND NOT(nlii00O);
	wire_n1i0Oi_dataout <= wire_n1l11O_dataout AND NOT(nlii00O);
	wire_n1i0Ol_dataout <= wire_n1l10i_dataout AND NOT(nlii00O);
	wire_n1i0OO_dataout <= wire_n1l10l_dataout AND NOT(nlii00O);
	wire_n1i10i_dataout <= wire_n1iliO_dataout AND NOT(nlii00O);
	wire_n1i10l_dataout <= wire_n1illi_dataout AND NOT(nlii00O);
	wire_n1i10O_dataout <= wire_n1illl_dataout AND NOT(nlii00O);
	wire_n1i11i_dataout <= wire_n1il0O_dataout AND NOT(nlii00O);
	wire_n1i11l_dataout <= wire_n1ilii_dataout AND NOT(nlii00O);
	wire_n1i11O_dataout <= wire_n1ilil_dataout AND NOT(nlii00O);
	wire_n1i1ii_dataout <= wire_n1illO_dataout AND NOT(nlii00O);
	wire_n1i1il_dataout <= wire_n1ilOi_dataout AND NOT(nlii00O);
	wire_n1i1iO_dataout <= wire_n1ilOl_dataout AND NOT(nlii00O);
	wire_n1i1li_dataout <= wire_n1ilOO_dataout AND NOT(nlii00O);
	wire_n1i1ll_dataout <= wire_n1iO1i_dataout AND NOT(nlii00O);
	wire_n1i1lO_dataout <= wire_n1iO1l_dataout AND NOT(nlii00O);
	wire_n1i1Oi_dataout <= wire_n1iO1O_dataout AND NOT(nlii00O);
	wire_n1i1Ol_dataout <= wire_n1iO0i_dataout AND NOT(nlii00O);
	wire_n1i1OO_dataout <= wire_n1iO0l_dataout AND NOT(nlii00O);
	wire_n1ii_dataout <= nl1i1O WHEN rwa_6g_en = '1'  ELSE n10O1l;
	wire_n1ii0i_dataout <= wire_n1l1iO_dataout AND NOT(nlii00O);
	wire_n1ii0l_dataout <= wire_n1l1li_dataout AND NOT(nlii00O);
	wire_n1ii0O_dataout <= wire_n1l1ll_dataout AND NOT(nlii00O);
	wire_n1ii1i_dataout <= wire_n1l10O_dataout AND NOT(nlii00O);
	wire_n1ii1l_dataout <= wire_n1l1ii_dataout AND NOT(nlii00O);
	wire_n1ii1O_dataout <= wire_n1l1il_dataout AND NOT(nlii00O);
	wire_n1iiii_dataout <= wire_n1l1lO_dataout AND NOT(nlii00O);
	wire_n1iiil_dataout <= wire_n1l1Oi_dataout AND NOT(nlii00O);
	wire_n1iiiO_dataout <= nlii11i WHEN nlii10l = '1'  ELSE n11O0O;
	wire_n1iili_dataout <= (((wire_n1l01l_o(4) OR wire_n1l01l_o(3)) OR wire_n1l01l_o(2)) OR wire_n1l01l_o(1)) WHEN nlii10l = '1'  ELSE n101Ol;
	wire_n1iill_dataout <= nlii11l WHEN nlii10l = '1'  ELSE n101OO;
	wire_n1iilO_dataout <= nlii11O WHEN nlii10l = '1'  ELSE n1001i;
	wire_n1iiOi_dataout <= (((wire_n1l00O_o(18) OR wire_n1l00O_o(17)) OR wire_n1l00O_o(16)) OR wire_n1l00O_o(15)) WHEN nlii10l = '1'  ELSE n1001l;
	wire_n1iiOl_dataout <= wire_n1l0ii_dataout WHEN nlii10l = '1'  ELSE n1001O;
	wire_n1iiOO_dataout <= wire_n1l0il_dataout WHEN nlii10l = '1'  ELSE n1000i;
	wire_n1il_dataout <= wire_ni1i1i_o WHEN rwa_6g_en = '1'  ELSE wire_nlli0iO_o;
	wire_n1il0i_dataout <= n10ilO WHEN nlii10l = '1'  ELSE n100il;
	wire_n1il0l_dataout <= n100il WHEN nlii10l = '1'  ELSE n100iO;
	wire_n1il0O_dataout <= n100iO WHEN nlii10l = '1'  ELSE n100li;
	wire_n1il1i_dataout <= wire_n1l0iO_dataout WHEN nlii10l = '1'  ELSE n1000l;
	wire_n1il1l_dataout <= wire_n1l0li_dataout WHEN nlii10l = '1'  ELSE n1000O;
	wire_n1il1O_dataout <= wire_n1l0ll_dataout WHEN nlii10l = '1'  ELSE n100ii;
	wire_n1ilii_dataout <= n100li WHEN nlii10l = '1'  ELSE n100ll;
	wire_n1ilil_dataout <= n100ll WHEN nlii10l = '1'  ELSE n100lO;
	wire_n1iliO_dataout <= n100lO WHEN nlii10l = '1'  ELSE n100Oi;
	wire_n1illi_dataout <= n100Oi WHEN nlii10l = '1'  ELSE n100Ol;
	wire_n1illl_dataout <= n100Ol WHEN nlii10l = '1'  ELSE n100OO;
	wire_n1illO_dataout <= n100OO WHEN nlii10l = '1'  ELSE n10i1i;
	wire_n1ilOi_dataout <= n10i1i WHEN nlii10l = '1'  ELSE n10i1l;
	wire_n1ilOl_dataout <= n10i1l WHEN nlii10l = '1'  ELSE n10i1O;
	wire_n1ilOO_dataout <= n10i1O WHEN nlii10l = '1'  ELSE n10i0i;
	wire_n1iO_dataout <= wire_nllOiO_o WHEN rwa_6g_en = '1'  ELSE wire_n1OllO_o;
	wire_n1iO0i_dataout <= n10iii WHEN nlii10l = '1'  ELSE n10iil;
	wire_n1iO0l_dataout <= n10iil WHEN nlii10l = '1'  ELSE n10iiO;
	wire_n1iO0O_dataout <= n10iiO WHEN nlii10l = '1'  ELSE n10ili;
	wire_n1iO1i_dataout <= n10i0i WHEN nlii10l = '1'  ELSE n10i0l;
	wire_n1iO1l_dataout <= n10i0l WHEN nlii10l = '1'  ELSE n10i0O;
	wire_n1iO1O_dataout <= n10i0O WHEN nlii10l = '1'  ELSE n10iii;
	wire_n1iOii_dataout <= n10ili WHEN nlii10l = '1'  ELSE n10ill;
	wire_n1iOil_dataout <= n10ill WHEN nlii10l = '1'  ELSE n10ilO;
	wire_n1iOiO_dataout <= n10O1l WHEN nlii10l = '1'  ELSE n10iOi;
	wire_n1iOli_dataout <= n10iOi WHEN nlii10l = '1'  ELSE n10iOl;
	wire_n1iOll_dataout <= n10iOl WHEN nlii10l = '1'  ELSE n10iOO;
	wire_n1iOlO_dataout <= n10iOO WHEN nlii10l = '1'  ELSE n10l1i;
	wire_n1iOOi_dataout <= n10l1i WHEN nlii10l = '1'  ELSE n10l1l;
	wire_n1iOOl_dataout <= n10l1l WHEN nlii10l = '1'  ELSE n10l1O;
	wire_n1iOOO_dataout <= n10l1O WHEN nlii10l = '1'  ELSE n10l0i;
	wire_n1l0ii_dataout <= wire_n1l0lO_o(0) AND NOT(nlii10i);
	wire_n1l0il_dataout <= wire_n1l0lO_o(1) AND NOT(nlii10i);
	wire_n1l0iO_dataout <= wire_n1l0lO_o(2) AND NOT(nlii10i);
	wire_n1l0li_dataout <= wire_n1l0lO_o(3) AND NOT(nlii10i);
	wire_n1l0ll_dataout <= wire_n1l0lO_o(4) AND NOT(nlii10i);
	wire_n1l10i_dataout <= n10lii WHEN nlii10l = '1'  ELSE n10lil;
	wire_n1l10l_dataout <= n10lil WHEN nlii10l = '1'  ELSE n10liO;
	wire_n1l10O_dataout <= n10liO WHEN nlii10l = '1'  ELSE n10lli;
	wire_n1l11i_dataout <= n10l0i WHEN nlii10l = '1'  ELSE n10l0l;
	wire_n1l11l_dataout <= n10l0l WHEN nlii10l = '1'  ELSE n10l0O;
	wire_n1l11O_dataout <= n10l0O WHEN nlii10l = '1'  ELSE n10lii;
	wire_n1l1ii_dataout <= n10lli WHEN nlii10l = '1'  ELSE n10lll;
	wire_n1l1il_dataout <= n10lll WHEN nlii10l = '1'  ELSE n10llO;
	wire_n1l1iO_dataout <= n10llO WHEN nlii10l = '1'  ELSE n10lOi;
	wire_n1l1li_dataout <= n10lOi WHEN nlii10l = '1'  ELSE n10lOl;
	wire_n1l1ll_dataout <= n10lOl WHEN nlii10l = '1'  ELSE n10lOO;
	wire_n1l1lO_dataout <= n10lOO WHEN nlii10l = '1'  ELSE n10O1i;
	wire_n1l1Oi_dataout <= n10O1i WHEN nlii10l = '1'  ELSE n10O1l;
	wire_n1li_dataout <= wire_nllOli_o WHEN rwa_6g_en = '1'  ELSE wire_n1OlOi_o;
	wire_n1li0i_dataout <= fifo_rd_in_comp_2 WHEN nlii10O = '1'  ELSE n1lili;
	wire_n1li1O_dataout <= fifo_rd_in_comp_0 WHEN nlii1ii = '1'  ELSE wire_n1li0i_dataout;
	wire_n1lill_dataout <= ((wire_w_lg_rgenericfifo32w(0) AND n1lili) OR nlii1iO) AND NOT(nlii00O);
	wire_n1lilO_dataout <= n1liiO AND NOT(nlii00O);
	wire_n1liOi_dataout <= nllOOi AND NOT(nlii00O);
	wire_n1ll_dataout <= (wire_nllOil_o AND wire_nllOii_o) WHEN rwa_6g_en = '1'  ELSE ((wire_n1OOOi_o AND wire_n1OOlO_o) AND (nlilO0O16 XOR nlilO0O15));
	wire_n1lO_dataout <= wire_nll11i_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi1ll_dataout;
	wire_n1O0il_dataout <= n1O0ii AND NOT(nlii00O);
	wire_n1O0iO_dataout <= n1O00O AND NOT(nlii00O);
	wire_n1O0li_dataout <= nlli11O AND NOT(nlii00O);
	wire_n1O0ll_dataout <= nlli11l AND NOT(nlii00O);
	wire_n1O0lO_dataout <= nlli11i AND NOT(nlii00O);
	wire_n1O0Oi_dataout <= nlli00O AND NOT(nlii00O);
	wire_n1O0Ol_dataout <= nlli1ii AND NOT(nlii00O);
	wire_n1O0OO_dataout <= nlli1il AND NOT(nlii00O);
	wire_n1O1ll_dataout <= insert_incomplete_0 WHEN nlilO0l = '1'  ELSE n1liil;
	wire_n1O1ll_w_lg_dataout1963w(0) <= wire_n1O1ll_dataout AND wire_w_lg_w_lg_rskpsetbased1866w1962w(0);
	wire_n1O1lO_dataout <= latency_comp_0 WHEN nlilO0l = '1'  ELSE wire_w_lg_nlillii120w(0);
	wire_n1Oi_dataout <= wire_nll11l_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi1lO_dataout;
	wire_n1Oi1i_dataout <= nlli1iO AND NOT(nlii00O);
	wire_n1Oi1l_dataout <= nlli1li AND NOT(nlii00O);
	wire_n1Oi1O_dataout <= (rskpsetbased AND (nlii0li OR nlii0iO)) OR (wire_w_lg_rskpsetbased1866w(0) AND (nlii0il OR nlii0ii));
	wire_n1Oi1O_w_lg_dataout2151w(0) <= wire_n1Oi1O_dataout AND wire_w_lg_rmatchen2150w(0);
	wire_n1Oiil_dataout <= (nlii0lO OR nlii0ll) WHEN rskpsetbased = '1'  ELSE (nlii0Ol OR nlii0Oi);
	wire_n1Oiil_w_lg_dataout1964w(0) <= wire_n1Oiil_dataout AND wire_n1O1ll_w_lg_dataout1963w(0);
	wire_n1Oiil_w_lg_dataout2152w(0) <= wire_n1Oiil_dataout AND wire_n1Oi1O_w_lg_dataout2151w(0);
	wire_n1Oiil_w_lg_dataout1939w(0) <= NOT wire_n1Oiil_dataout;
	wire_n1OiOi_dataout <= rclkcmpsq1n(0) WHEN nliii1O = '1'  ELSE rclkcmpsq1n(10);
	wire_n1OiOl_dataout <= rclkcmpsq1n(1) WHEN nliii1O = '1'  ELSE rclkcmpsq1n(11);
	wire_n1OiOO_dataout <= rclkcmpsq1n(2) WHEN nliii1O = '1'  ELSE rclkcmpsq1n(12);
	wire_n1Ol_dataout <= wire_nll11O_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi1Oi_dataout;
	wire_n1Ol0i_dataout <= rclkcmpsq1n(6) WHEN nliii1O = '1'  ELSE rclkcmpsq1n(16);
	wire_n1Ol0l_dataout <= rclkcmpsq1n(7) WHEN nliii1O = '1'  ELSE rclkcmpsq1n(17);
	wire_n1Ol0O_dataout <= rclkcmpsq1n(8) WHEN nliii1O = '1'  ELSE rclkcmpsq1n(18);
	wire_n1Ol1i_dataout <= rclkcmpsq1n(3) WHEN nliii1O = '1'  ELSE rclkcmpsq1n(13);
	wire_n1Ol1l_dataout <= rclkcmpsq1n(4) WHEN nliii1O = '1'  ELSE rclkcmpsq1n(14);
	wire_n1Ol1O_dataout <= rclkcmpsq1n(5) WHEN nliii1O = '1'  ELSE rclkcmpsq1n(15);
	wire_n1Olii_dataout <= rclkcmpsq1n(9) WHEN nliii1O = '1'  ELSE rclkcmpsq1n(19);
	wire_n1Olli_dataout <= fifo_ovr_0 WHEN nlilO0l = '1'  ELSE nlO01O;
	wire_n1Olli_w_lg_dataout2356w(0) <= wire_n1Olli_dataout AND wire_w_lg_nlillil2355w(0);
	wire_n1Olll_dataout <= del_cond_met_0 WHEN nlilO0l = '1'  ELSE wire_n1OllO_o;
	wire_n1Olll_w_lg_dataout2357w(0) <= wire_n1Olll_dataout AND wire_n1Olli_w_lg_dataout2356w(0);
	wire_n1OlOl_dataout <= rclkcmpsq1p(10) WHEN nliii0i = '1'  ELSE rclkcmpsq1p(0);
	wire_n1OlOO_dataout <= rclkcmpsq1p(11) WHEN nliii0i = '1'  ELSE rclkcmpsq1p(1);
	wire_n1OO_dataout <= wire_nll10i_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi1Ol_dataout;
	wire_n1OO0i_dataout <= rclkcmpsq1p(15) WHEN nliii0i = '1'  ELSE rclkcmpsq1p(5);
	wire_n1OO0l_dataout <= rclkcmpsq1p(16) WHEN nliii0i = '1'  ELSE rclkcmpsq1p(6);
	wire_n1OO0O_dataout <= rclkcmpsq1p(17) WHEN nliii0i = '1'  ELSE rclkcmpsq1p(7);
	wire_n1OO1i_dataout <= rclkcmpsq1p(12) WHEN nliii0i = '1'  ELSE rclkcmpsq1p(2);
	wire_n1OO1l_dataout <= rclkcmpsq1p(13) WHEN nliii0i = '1'  ELSE rclkcmpsq1p(3);
	wire_n1OO1O_dataout <= rclkcmpsq1p(14) WHEN nliii0i = '1'  ELSE rclkcmpsq1p(4);
	wire_n1OOii_dataout <= rclkcmpsq1p(18) WHEN nliii0i = '1'  ELSE rclkcmpsq1p(8);
	wire_n1OOil_dataout <= rclkcmpsq1p(19) WHEN nliii0i = '1'  ELSE rclkcmpsq1p(9);
	wire_ni_dataout <= ni101i WHEN rwa_6g_en = '1'  ELSE nllil0i;
	wire_ni000O_dataout <= nliiO0O AND NOT(nliiO1i);
	wire_ni00ii_dataout <= nliiO0O AND NOT(nliiO1i);
	wire_ni00li_dataout <= (nliiOii AND (nliiO1O OR nliiO1l)) AND wire_nliOOi_dataout;
	wire_ni00ll_dataout <= (nliiO0l OR nliiO0i) AND wire_nliOOi_dataout;
	wire_ni00OO_dataout <= (wire_w_lg_nliiOli735w(0) AND wire_w_lg_nliiO0O726w(0)) OR (rtruebac2bac AND (nliiOli AND (nliiOii AND (wire_nliOOi_dataout AND ni00iO))));
	wire_ni010i_dataout <= wire_ni01ii_o(3) WHEN wire_w_lg_nliilll798w(0) = '1'  ELSE ni1O1O;
	wire_ni010l_dataout <= wire_ni01ii_o(4) WHEN wire_w_lg_nliilll798w(0) = '1'  ELSE ni1O0i;
	wire_ni010O_dataout <= wire_ni01ii_o(5) WHEN wire_w_lg_nliilll798w(0) = '1'  ELSE ni1O0l;
	wire_ni011i_dataout <= wire_ni01il_o(4) WHEN nliillO = '1'  ELSE wire_ni010O_dataout;
	wire_ni011l_dataout <= wire_ni01ii_o(1) WHEN wire_w_lg_nliilll798w(0) = '1'  ELSE ni1llO;
	wire_ni011O_dataout <= wire_ni01ii_o(2) WHEN wire_w_lg_nliilll798w(0) = '1'  ELSE ni1O1l;
	wire_ni0i_dataout <= wire_nll0il_dataout AND rwa_6g_en;
	wire_ni0iiO_dataout <= wire_ni0ili_dataout OR (rtruebac2bac AND (nliiOii AND (nliiOli AND (wire_nliOOi_dataout AND ni00Oi))));
	wire_ni0ili_dataout <= ((nliiOli AND nliiOii) AND wire_w_lg_nliiO0O726w(0)) AND (wire_nliOOi_dataout AND ni00il);
	wire_ni0l_dataout <= wire_nll0iO_dataout AND rwa_6g_en;
	wire_ni0O_dataout <= wire_nll0li_dataout AND rwa_6g_en;
	wire_ni100i_dataout <= ni11lO OR nliiO1i;
	wire_ni100l_dataout <= wire_nllOli_o OR nliiO1i;
	wire_ni100O_dataout <= wire_ni10iO_dataout OR nliiO1i;
	wire_ni101O_dataout <= ni11OO AND NOT(nliiO1i);
	wire_ni10ii_dataout <= wire_nllOiO_o AND NOT(nliiO1i);
	wire_ni10il_dataout <= wire_ni10lO_dataout AND NOT(nliiO1i);
	wire_ni10iO_dataout <= (nliil1O OR ni11ll) WHEN nliO11i = '1'  ELSE nliil1O;
	wire_ni10lO_dataout <= (nliil0i OR ni110l) WHEN nliO11i = '1'  ELSE nliil0i;
	wire_ni110O_dataout <= ni101l AND NOT(nliiO1i);
	wire_ni11ii_dataout <= ni1i1l AND NOT(nliiO1i);
	wire_ni11il_dataout <= ni1i1O AND NOT(nliiO1i);
	wire_ni11iO_dataout <= ni1i0i AND NOT(nliiO1i);
	wire_ni11li_dataout <= ni1i0l AND NOT(nliiO1i);
	wire_ni1i_dataout <= wire_nll00l_dataout AND rwa_6g_en;
	wire_ni1iii_dataout <= wire_ni1ilO_dataout AND NOT(nliiO1i);
	wire_ni1iil_dataout <= wire_ni1iOi_dataout AND NOT(nliiO1i);
	wire_ni1iiO_dataout <= wire_ni1iOl_dataout AND NOT(nliiO1i);
	wire_ni1ili_dataout <= wire_ni1iOO_dataout AND NOT(nliiO1i);
	wire_ni1ill_dataout <= wire_ni1l1i_dataout AND NOT(nliiO1i);
	wire_ni1ilO_dataout <= wire_ni1l1l_dataout AND NOT(nliil0l);
	wire_ni1iOi_dataout <= wire_ni1l1O_dataout AND NOT(nliil0l);
	wire_ni1iOl_dataout <= n0Ol0O WHEN nliil0l = '1'  ELSE wire_ni1l0i_dataout;
	wire_ni1iOO_dataout <= wire_ni1l0l_dataout AND NOT(nliil0l);
	wire_ni1l_dataout <= wire_nll00O_dataout AND rwa_6g_en;
	wire_ni1l0i_dataout <= wire_ni1liO_o(3) WHEN wire_ni1lli_o = '1'  ELSE wire_ni1lii_o(3);
	wire_ni1l0l_dataout <= wire_ni1liO_o(4) WHEN wire_ni1lli_o = '1'  ELSE wire_ni1lii_o(4);
	wire_ni1l0O_dataout <= wire_ni1liO_o(5) WHEN wire_ni1lli_o = '1'  ELSE wire_ni1lii_o(5);
	wire_ni1l1i_dataout <= n0Ol0O WHEN nliil0l = '1'  ELSE wire_ni1l0O_dataout;
	wire_ni1l1l_dataout <= wire_ni1liO_o(1) WHEN wire_ni1lli_o = '1'  ELSE wire_ni1lii_o(1);
	wire_ni1l1O_dataout <= wire_ni1liO_o(2) WHEN wire_ni1lli_o = '1'  ELSE wire_ni1lii_o(2);
	wire_ni1lOi_dataout <= nliilli AND NOT(nliiO1i);
	wire_ni1O_dataout <= wire_nll0ii_dataout AND rwa_6g_en;
	wire_ni1Oii_dataout <= wire_ni1OlO_dataout AND NOT(nliiO1i);
	wire_ni1Oil_dataout <= wire_ni1OOi_dataout AND NOT(nliiO1i);
	wire_ni1OiO_dataout <= wire_ni1OOl_dataout AND NOT(nliiO1i);
	wire_ni1Oli_dataout <= wire_ni1OOO_dataout AND NOT(nliiO1i);
	wire_ni1Oll_dataout <= wire_ni011i_dataout AND NOT(nliiO1i);
	wire_ni1OlO_dataout <= wire_ni01il_o(0) WHEN nliillO = '1'  ELSE wire_ni011l_dataout;
	wire_ni1OOi_dataout <= wire_ni01il_o(1) WHEN nliillO = '1'  ELSE wire_ni011O_dataout;
	wire_ni1OOl_dataout <= wire_ni01il_o(2) WHEN nliillO = '1'  ELSE wire_ni010i_dataout;
	wire_ni1OOO_dataout <= wire_ni01il_o(3) WHEN nliillO = '1'  ELSE wire_ni010l_dataout;
	wire_niii_dataout <= wire_nll0ll_dataout AND rwa_6g_en;
	wire_niii0i_dataout <= wire_nii0lO_w_lg_nii0Oi640w(0) WHEN nlil0l = '1'  ELSE wire_nil1Oi_dataout;
	wire_niii0l_dataout <= wire_niOlOi_dataout WHEN nlil0l = '1'  ELSE wire_nil1Ol_dataout;
	wire_niii0O_dataout <= wire_nii0lO_w_lg_nii0Oi640w(0) WHEN nlil0l = '1'  ELSE wire_nil1OO_dataout;
	wire_niii1l_dataout <= wire_niOllO_dataout WHEN nlil0l = '1'  ELSE wire_nil1ll_dataout;
	wire_niii1O_dataout <= wire_nii0lO_w_lg_nii0Oi640w(0) WHEN nlil0l = '1'  ELSE wire_nil1lO_dataout;
	wire_niiiii_dataout <= nii0Oi WHEN nlil0l = '1'  ELSE wire_nil01i_dataout;
	wire_niiiil_dataout <= wire_nii0lO_w_lg_nii0Oi640w(0) WHEN nlil0l = '1'  ELSE wire_nil01l_dataout;
	wire_niiiiO_dataout <= nii0Oi WHEN nlil0l = '1'  ELSE wire_nil01O_dataout;
	wire_niiili_dataout <= nii0Oi WHEN nlil0l = '1'  ELSE wire_nil00i_dataout;
	wire_niiill_dataout <= nii0Oi WHEN nlil0l = '1'  ELSE wire_nil00l_dataout;
	wire_niiilO_dataout <= wire_nil00O_dataout AND NOT(nlil0l);
	wire_niiiOi_dataout <= nii0li WHEN nlil0l = '1'  ELSE wire_nil0ii_dataout;
	wire_niiiOl_dataout <= wire_nil0il_dataout AND NOT(nlil0l);
	wire_niiiOO_dataout <= nii0Oi WHEN nlil0l = '1'  ELSE wire_nil0iO_dataout;
	wire_niil_dataout <= wire_nll0lO_dataout AND rwa_6g_en;
	wire_niil0i_dataout <= wire_nii0lO_w_lg_nii0Oi640w(0) WHEN nlil0l = '1'  ELSE wire_nil0Oi_dataout;
	wire_niil0l_dataout <= wire_nii0lO_w_lg_nii0Oi640w(0) WHEN nlil0l = '1'  ELSE wire_nil0Ol_dataout;
	wire_niil0O_dataout <= wire_niOlOi_dataout WHEN nlil0l = '1'  ELSE wire_nil0OO_dataout;
	wire_niil1i_dataout <= wire_nil0li_dataout AND NOT(nlil0l);
	wire_niil1l_dataout <= wire_nil0ll_dataout OR nlil0l;
	wire_niil1O_dataout <= wire_niOllO_dataout WHEN nlil0l = '1'  ELSE wire_nil0lO_dataout;
	wire_niilii_dataout <= wire_nii0lO_w_lg_nii0Oi640w(0) WHEN nlil0l = '1'  ELSE wire_nili1i_dataout;
	wire_niilil_dataout <= nii0Oi WHEN nlil0l = '1'  ELSE wire_nili1l_dataout;
	wire_niiliO_dataout <= wire_nii0lO_w_lg_nii0Oi640w(0) WHEN nlil0l = '1'  ELSE wire_nili1O_dataout;
	wire_niilli_dataout <= nii0Oi WHEN nlil0l = '1'  ELSE wire_nili0i_dataout;
	wire_niilll_dataout <= nii0Oi WHEN nlil0l = '1'  ELSE wire_nili0l_dataout;
	wire_niillO_dataout <= nii0Oi WHEN nlil0l = '1'  ELSE wire_nili0O_dataout;
	wire_niilOi_dataout <= wire_niliii_dataout AND NOT(nlil0l);
	wire_niilOl_dataout <= wire_niliiO_dataout AND NOT(nlil0l);
	wire_niilOO_dataout <= wire_nilill_dataout AND NOT(nlil0l);
	wire_niiO_dataout <= wire_nll0Oi_dataout AND rwa_6g_en;
	wire_niiO0i_dataout <= wire_nllOll_data_out2(2) WHEN nlil10O = '1'  ELSE ni0lli;
	wire_niiO0l_dataout <= wire_nllOll_data_out2(3) WHEN nlil10O = '1'  ELSE ni0lll;
	wire_niiO0O_dataout <= wire_nllOll_data_out2(4) WHEN nlil10O = '1'  ELSE ni0llO;
	wire_niiO1i_dataout <= wire_nililO_dataout OR nlil0l;
	wire_niiO1l_dataout <= wire_nllOll_data_out2(0) WHEN nlil10O = '1'  ELSE ni00Ol;
	wire_niiO1O_dataout <= wire_nllOll_data_out2(1) WHEN nlil10O = '1'  ELSE ni0liO;
	wire_niiOi_dataout <= wire_nliOOO_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi1il_dataout;
	wire_niiOii_dataout <= wire_nllOll_data_out2(5) WHEN nlil10O = '1'  ELSE ni0lOi;
	wire_niiOil_dataout <= wire_nllOll_data_out2(6) WHEN nlil10O = '1'  ELSE ni0lOl;
	wire_niiOiO_dataout <= wire_nllOll_data_out2(7) WHEN nlil10O = '1'  ELSE ni0lOO;
	wire_niiOl_dataout <= wire_nll11i_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi1ll_dataout;
	wire_niiOli_dataout <= wire_nllOll_data_out2(8) WHEN nlil10O = '1'  ELSE ni0O1i;
	wire_niiOll_dataout <= wire_nllOll_data_out2(9) WHEN nlil10O = '1'  ELSE ni0O1l;
	wire_niiOO_dataout <= wire_nll11l_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi1lO_dataout;
	wire_nil00i_dataout <= wire_nllOll_data_out1(8) WHEN nlil10O = '1'  ELSE wire_nill0O_dataout;
	wire_nil00l_dataout <= wire_nllOll_data_out1(9) WHEN nlil10O = '1'  ELSE wire_nillii_dataout;
	wire_nil00O_dataout <= wire_nllOll_data_out1(10) WHEN nlil10O = '1'  ELSE wire_nillil_dataout;
	wire_nil01i_dataout <= wire_nllOll_data_out1(5) WHEN nlil10O = '1'  ELSE wire_nill1O_dataout;
	wire_nil01l_dataout <= wire_nllOll_data_out1(6) WHEN nlil10O = '1'  ELSE wire_nill0i_dataout;
	wire_nil01O_dataout <= wire_nllOll_data_out1(7) WHEN nlil10O = '1'  ELSE wire_nill0l_dataout;
	wire_nil0i_dataout <= wire_nll10O_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi01i_dataout;
	wire_nil0ii_dataout <= wire_nllOll_data_out1(11) WHEN nlil10O = '1'  ELSE wire_nilliO_dataout;
	wire_nil0il_dataout <= wire_nllOll_data_out1(12) WHEN nlil10O = '1'  ELSE wire_nillli_dataout;
	wire_nil0iO_dataout <= wire_nllOll_data_out1(13) WHEN nlil10O = '1'  ELSE wire_nillll_dataout;
	wire_nil0l_dataout <= wire_nll1ii_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi01l_dataout;
	wire_nil0li_dataout <= wire_nllOll_data_out1(14) AND nlil10O;
	wire_nil0ll_dataout <= wire_nllOll_data_out1(15) OR NOT(nlil10O);
	wire_nil0lO_dataout <= wire_nllOlO_data_out1(0) WHEN nlil10O = '1'  ELSE wire_nilllO_dataout;
	wire_nil0O_dataout <= wire_nll1il_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi01O_dataout;
	wire_nil0Oi_dataout <= wire_nllOlO_data_out1(1) WHEN nlil10O = '1'  ELSE wire_nillOi_dataout;
	wire_nil0Ol_dataout <= wire_nllOlO_data_out1(2) WHEN nlil10O = '1'  ELSE wire_nillOl_dataout;
	wire_nil0OO_dataout <= wire_nllOlO_data_out1(3) WHEN nlil10O = '1'  ELSE wire_nillOO_dataout;
	wire_nil10i_dataout <= wire_nllOlO_data_out2(3) WHEN nlil10O = '1'  ELSE ni0O0O;
	wire_nil10l_dataout <= wire_nllOlO_data_out2(4) WHEN nlil10O = '1'  ELSE ni0Oii;
	wire_nil10O_dataout <= wire_nllOlO_data_out2(5) WHEN nlil10O = '1'  ELSE ni0Oil;
	wire_nil11i_dataout <= wire_nllOlO_data_out2(0) WHEN nlil10O = '1'  ELSE ni0O1O;
	wire_nil11l_dataout <= wire_nllOlO_data_out2(1) WHEN nlil10O = '1'  ELSE ni0O0i;
	wire_nil11O_dataout <= wire_nllOlO_data_out2(2) WHEN nlil10O = '1'  ELSE ni0O0l;
	wire_nil1i_dataout <= wire_nll11O_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi1Oi_dataout;
	wire_nil1ii_dataout <= wire_nllOlO_data_out2(6) WHEN nlil10O = '1'  ELSE ni0OiO;
	wire_nil1il_dataout <= wire_nllOlO_data_out2(7) WHEN nlil10O = '1'  ELSE ni0Oli;
	wire_nil1iO_dataout <= wire_nllOlO_data_out2(8) WHEN nlil10O = '1'  ELSE ni0Oll;
	wire_nil1l_dataout <= wire_nll10i_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi1Ol_dataout;
	wire_nil1li_dataout <= wire_nllOlO_data_out2(9) WHEN nlil10O = '1'  ELSE ni0OlO;
	wire_nil1ll_dataout <= wire_nllOll_data_out1(0) WHEN nlil10O = '1'  ELSE wire_niliOi_dataout;
	wire_nil1lO_dataout <= wire_nllOll_data_out1(1) WHEN nlil10O = '1'  ELSE wire_niliOl_dataout;
	wire_nil1O_dataout <= wire_nll10l_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi1OO_dataout;
	wire_nil1Oi_dataout <= wire_nllOll_data_out1(2) WHEN nlil10O = '1'  ELSE wire_niliOO_dataout;
	wire_nil1Ol_dataout <= wire_nllOll_data_out1(3) WHEN nlil10O = '1'  ELSE wire_nill1i_dataout;
	wire_nil1OO_dataout <= wire_nllOll_data_out1(4) WHEN nlil10O = '1'  ELSE wire_nill1l_dataout;
	wire_nili_dataout <= wire_nll0Ol_dataout AND rwa_6g_en;
	wire_nili0i_dataout <= wire_nllOlO_data_out1(7) WHEN nlil10O = '1'  ELSE wire_nilO0i_dataout;
	wire_nili0l_dataout <= wire_nllOlO_data_out1(8) WHEN nlil10O = '1'  ELSE wire_nilO0l_dataout;
	wire_nili0O_dataout <= wire_nllOlO_data_out1(9) WHEN nlil10O = '1'  ELSE wire_nilO0O_dataout;
	wire_nili1i_dataout <= wire_nllOlO_data_out1(4) WHEN nlil10O = '1'  ELSE wire_nilO1i_dataout;
	wire_nili1l_dataout <= wire_nllOlO_data_out1(5) WHEN nlil10O = '1'  ELSE wire_nilO1l_dataout;
	wire_nili1O_dataout <= wire_nllOlO_data_out1(6) WHEN nlil10O = '1'  ELSE wire_nilO1O_dataout;
	wire_nilii_dataout <= wire_nll1iO_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi00i_dataout;
	wire_niliii_dataout <= wire_nllOlO_data_out1(10) WHEN nlil10O = '1'  ELSE wire_nilOii_dataout;
	wire_niliil_dataout <= wire_nllOlO_data_out1(11) WHEN nlil10O = '1'  ELSE nii0li;
	wire_niliiO_dataout <= wire_nllOlO_data_out1(12) WHEN nlil10O = '1'  ELSE wire_nilOil_dataout;
	wire_nilil_dataout <= wire_nll1li_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi00l_dataout;
	wire_nilili_dataout <= wire_nllOlO_data_out1(13) WHEN nlil10O = '1'  ELSE nii0Oi;
	wire_nilill_dataout <= wire_nllOlO_data_out1(14) AND nlil10O;
	wire_nililO_dataout <= wire_nllOlO_data_out1(15) OR NOT(nlil10O);
	wire_niliO_dataout <= wire_nll01l_dataout AND rwa_6g_en;
	wire_niliOi_dataout <= ni0OOi WHEN nlil10l = '1'  ELSE wire_nilOiO_dataout;
	wire_niliOl_dataout <= ni0OOl WHEN nlil10l = '1'  ELSE wire_nilOli_dataout;
	wire_niliOO_dataout <= ni0OOO WHEN nlil10l = '1'  ELSE wire_nilOll_dataout;
	wire_nill_dataout <= wire_nll0OO_dataout AND rwa_6g_en;
	wire_nill0i_dataout <= nii10i WHEN nlil10l = '1'  ELSE wire_nilOOO_dataout;
	wire_nill0l_dataout <= nii10l WHEN nlil10l = '1'  ELSE wire_niO11i_dataout;
	wire_nill0O_dataout <= nii10O WHEN nlil10l = '1'  ELSE wire_niO11l_dataout;
	wire_nill1i_dataout <= nii11i WHEN nlil10l = '1'  ELSE wire_nilOlO_dataout;
	wire_nill1l_dataout <= nii11l WHEN nlil10l = '1'  ELSE wire_nilOOi_dataout;
	wire_nill1O_dataout <= nii11O WHEN nlil10l = '1'  ELSE wire_nilOOl_dataout;
	wire_nilli_dataout <= wire_nll01O_dataout AND rwa_6g_en;
	wire_nillii_dataout <= nii1ii WHEN nlil10l = '1'  ELSE wire_niO11O_dataout;
	wire_nillil_dataout <= nii1il AND nlil10l;
	wire_nilliO_dataout <= nii1iO WHEN nlil10l = '1'  ELSE nii0li;
	wire_nilll_dataout <= wire_nll00i_dataout AND rwa_6g_en;
	wire_nillli_dataout <= nii1li AND nlil10l;
	wire_nillll_dataout <= nii1ll WHEN nlil10l = '1'  ELSE nii0Oi;
	wire_nilllO_dataout <= nii1Ol WHEN nlil10l = '1'  ELSE wire_niO0iO_dataout;
	wire_nillO_dataout <= wire_nll00l_dataout AND rwa_6g_en;
	wire_nillOi_dataout <= nii1OO WHEN nlil10l = '1'  ELSE wire_niO0li_dataout;
	wire_nillOl_dataout <= nii01i WHEN nlil10l = '1'  ELSE wire_niO0ll_dataout;
	wire_nillOO_dataout <= nii01l WHEN nlil10l = '1'  ELSE wire_niO0lO_dataout;
	wire_nilO_dataout <= wire_nlli1i_dataout AND rwa_6g_en;
	wire_nilO0i_dataout <= nii00O WHEN nlil10l = '1'  ELSE wire_niOi1i_dataout;
	wire_nilO0l_dataout <= nii0ii WHEN nlil10l = '1'  ELSE wire_niOi1l_dataout;
	wire_nilO0O_dataout <= nii0il WHEN nlil10l = '1'  ELSE wire_niOi1O_dataout;
	wire_nilO1i_dataout <= nii01O WHEN nlil10l = '1'  ELSE wire_niO0Oi_dataout;
	wire_nilO1l_dataout <= nii00i WHEN nlil10l = '1'  ELSE wire_niO0Ol_dataout;
	wire_nilO1O_dataout <= nii00l WHEN nlil10l = '1'  ELSE wire_niO0OO_dataout;
	wire_nilOi_dataout <= wire_nll00O_dataout AND rwa_6g_en;
	wire_nilOii_dataout <= nii0iO AND nlil10l;
	wire_nilOil_dataout <= nii0ll AND nlil10l;
	wire_nilOiO_dataout <= wire_niO1Ol_dataout WHEN nii0Oi = '1'  ELSE wire_niO10i_dataout;
	wire_nilOl_dataout <= wire_nll0ii_dataout AND rwa_6g_en;
	wire_nilOli_dataout <= wire_niO1OO_dataout WHEN nii0Oi = '1'  ELSE wire_niO10l_dataout;
	wire_nilOll_dataout <= wire_niO01i_dataout WHEN nii0Oi = '1'  ELSE wire_niO10O_dataout;
	wire_nilOlO_dataout <= wire_niO01l_dataout WHEN nii0Oi = '1'  ELSE wire_niO1ii_dataout;
	wire_nilOO_dataout <= wire_nll0il_dataout AND rwa_6g_en;
	wire_nilOOi_dataout <= wire_niO01O_dataout WHEN nii0Oi = '1'  ELSE wire_niO1il_dataout;
	wire_nilOOl_dataout <= wire_niO00i_dataout WHEN nii0Oi = '1'  ELSE wire_niO1iO_dataout;
	wire_nilOOO_dataout <= wire_niO00l_dataout WHEN nii0Oi = '1'  ELSE wire_niO1li_dataout;
	wire_niO_dataout <= gen2ngen1 WHEN rindv_rx = '1'  ELSE gen2ngen1_bundle;
	wire_niO00i_dataout <= rclkcmpsq1p(15) OR nlil11l;
	wire_niO00l_dataout <= rclkcmpsq1p(16) AND NOT(nlil11l);
	wire_niO00O_dataout <= rclkcmpsq1p(17) OR nlil11l;
	wire_niO01i_dataout <= rclkcmpsq1p(12) AND NOT(nlil11l);
	wire_niO01l_dataout <= rclkcmpinsertpad WHEN nlil11l = '1'  ELSE rclkcmpsq1p(13);
	wire_niO01O_dataout <= rclkcmpsq1p(14) AND NOT(nlil11l);
	wire_niO0i_dataout <= nliO1l WHEN rwa_6g_en = '1'  ELSE wire_nlOiiOi_dataout;
	wire_niO0ii_dataout <= rclkcmpsq1p(18) OR nlil11l;
	wire_niO0il_dataout <= rclkcmpsq1p(19) OR nlil11l;
	wire_niO0iO_dataout <= wire_niOiOl_dataout WHEN nii0Oi = '1'  ELSE wire_niOi0i_dataout;
	wire_niO0l_dataout <= nlliiO WHEN rwa_6g_en = '1'  ELSE wire_nlOiiOl_dataout;
	wire_niO0li_dataout <= wire_niOiOO_dataout WHEN nii0Oi = '1'  ELSE wire_niOi0l_dataout;
	wire_niO0ll_dataout <= wire_niOl1i_dataout WHEN nii0Oi = '1'  ELSE wire_niOi0O_dataout;
	wire_niO0lO_dataout <= wire_niOl1l_dataout WHEN nii0Oi = '1'  ELSE wire_niOiii_dataout;
	wire_niO0O_dataout <= nllili WHEN rwa_6g_en = '1'  ELSE wire_nlOiiOO_dataout;
	wire_niO0Oi_dataout <= wire_niOl1O_dataout WHEN nii0Oi = '1'  ELSE wire_niOiil_dataout;
	wire_niO0Ol_dataout <= wire_niOl0i_dataout WHEN nii0Oi = '1'  ELSE wire_niOiiO_dataout;
	wire_niO0OO_dataout <= wire_niOl0l_dataout WHEN nii0Oi = '1'  ELSE wire_niOili_dataout;
	wire_niO10i_dataout <= rclkcmpinsertpad WHEN nlil11i = '1'  ELSE rclkcmpsq1n(10);
	wire_niO10l_dataout <= rclkcmpsq1n(11) OR nlil11i;
	wire_niO10O_dataout <= rclkcmpsq1n(12) OR nlil11i;
	wire_niO11i_dataout <= wire_niO00O_dataout WHEN nii0Oi = '1'  ELSE wire_niO1ll_dataout;
	wire_niO11l_dataout <= wire_niO0ii_dataout WHEN nii0Oi = '1'  ELSE wire_niO1lO_dataout;
	wire_niO11O_dataout <= wire_niO0il_dataout WHEN nii0Oi = '1'  ELSE wire_niO1Oi_dataout;
	wire_niO1i_dataout <= wire_nll0iO_dataout AND rwa_6g_en;
	wire_niO1ii_dataout <= wire_w_lg_rclkcmpinsertpad655w(0) WHEN nlil11i = '1'  ELSE rclkcmpsq1n(13);
	wire_niO1il_dataout <= rclkcmpsq1n(14) OR nlil11i;
	wire_niO1iO_dataout <= rclkcmpsq1n(15) AND NOT(nlil11i);
	wire_niO1l_dataout <= wire_nll0li_dataout AND rwa_6g_en;
	wire_niO1li_dataout <= rclkcmpsq1n(16) OR nlil11i;
	wire_niO1ll_dataout <= rclkcmpsq1n(17) AND NOT(nlil11i);
	wire_niO1lO_dataout <= rclkcmpsq1n(18) AND NOT(nlil11i);
	wire_niO1O_dataout <= wire_nll0ll_dataout AND rwa_6g_en;
	wire_niO1Oi_dataout <= rclkcmpsq1n(19) AND NOT(nlil11i);
	wire_niO1Ol_dataout <= wire_w_lg_rclkcmpinsertpad655w(0) WHEN nlil11l = '1'  ELSE rclkcmpsq1p(10);
	wire_niO1OO_dataout <= rclkcmpsq1p(11) AND NOT(nlil11l);
	wire_niOi_dataout <= wire_nlli1l_dataout AND rwa_6g_en;
	wire_niOi0i_dataout <= rclkcmpinsertpad WHEN nlil11O = '1'  ELSE rclkcmpsq1n(10);
	wire_niOi0l_dataout <= rclkcmpsq1n(11) OR nlil11O;
	wire_niOi0O_dataout <= rclkcmpsq1n(12) OR nlil11O;
	wire_niOi1i_dataout <= wire_niOl0O_dataout WHEN nii0Oi = '1'  ELSE wire_niOill_dataout;
	wire_niOi1l_dataout <= wire_niOlii_dataout WHEN nii0Oi = '1'  ELSE wire_niOilO_dataout;
	wire_niOi1O_dataout <= wire_niOlil_dataout WHEN nii0Oi = '1'  ELSE wire_niOiOi_dataout;
	wire_niOii_dataout <= nllill WHEN rwa_6g_en = '1'  ELSE wire_nlOil1i_dataout;
	wire_niOiii_dataout <= wire_w_lg_rclkcmpinsertpad655w(0) WHEN nlil11O = '1'  ELSE rclkcmpsq1n(13);
	wire_niOiil_dataout <= rclkcmpsq1n(14) OR nlil11O;
	wire_niOiiO_dataout <= rclkcmpsq1n(15) AND NOT(nlil11O);
	wire_niOil_dataout <= nllilO WHEN rwa_6g_en = '1'  ELSE wire_nlOil1l_dataout;
	wire_niOili_dataout <= rclkcmpsq1n(16) OR nlil11O;
	wire_niOill_dataout <= rclkcmpsq1n(17) AND NOT(nlil11O);
	wire_niOilO_dataout <= rclkcmpsq1n(18) AND NOT(nlil11O);
	wire_niOiO_dataout <= nlliOi WHEN rwa_6g_en = '1'  ELSE wire_nlOil1O_dataout;
	wire_niOiOi_dataout <= rclkcmpsq1n(19) AND NOT(nlil11O);
	wire_niOiOl_dataout <= wire_w_lg_rclkcmpinsertpad655w(0) WHEN nlil10i = '1'  ELSE rclkcmpsq1p(10);
	wire_niOiOO_dataout <= rclkcmpsq1p(11) AND NOT(nlil10i);
	wire_niOl_dataout <= ni101l WHEN rwa_6g_en = '1'  ELSE nlO1OiO;
	wire_niOl0i_dataout <= rclkcmpsq1p(15) OR nlil10i;
	wire_niOl0l_dataout <= rclkcmpsq1p(16) AND NOT(nlil10i);
	wire_niOl0O_dataout <= rclkcmpsq1p(17) OR nlil10i;
	wire_niOl1i_dataout <= rclkcmpsq1p(12) AND NOT(nlil10i);
	wire_niOl1l_dataout <= rclkcmpinsertpad WHEN nlil10i = '1'  ELSE rclkcmpsq1p(13);
	wire_niOl1O_dataout <= rclkcmpsq1p(14) AND NOT(nlil10i);
	wire_niOli_dataout <= nlliOl WHEN rwa_6g_en = '1'  ELSE wire_nlOil0i_dataout;
	wire_niOlii_dataout <= rclkcmpsq1p(18) OR nlil10i;
	wire_niOlil_dataout <= rclkcmpsq1p(19) OR nlil10i;
	wire_niOll_dataout <= nlliOO WHEN rwa_6g_en = '1'  ELSE wire_nlOil0l_dataout;
	wire_niOllO_dataout <= wire_nii0lO_w_lg_nii0Oi640w(0) WHEN rclkcmpinsertpad = '1'  ELSE nii0Oi;
	wire_niOlO_dataout <= nlll1i WHEN rwa_6g_en = '1'  ELSE wire_nlOil0O_dataout;
	wire_niOlOi_dataout <= nii0Oi WHEN rclkcmpinsertpad = '1'  ELSE wire_nii0lO_w_lg_nii0Oi640w(0);
	wire_niOO_dataout <= ni1i1l WHEN rwa_6g_en = '1'  ELSE nlO1OOi;
	wire_niOOi_dataout <= nlll1l WHEN rwa_6g_en = '1'  ELSE wire_nlOilii_dataout;
	wire_niOOl_dataout <= nlll1O WHEN rwa_6g_en = '1'  ELSE wire_nlO0Oli_dataout;
	wire_niOOO_dataout <= nlll0i WHEN rwa_6g_en = '1'  ELSE wire_nlO0Oll_dataout;
	wire_nl000i_dataout <= wire_nl0OlO_dataout WHEN nlil1ll = '1'  ELSE niOOii;
	wire_nl000l_dataout <= nl11lO WHEN nlil1ll = '1'  ELSE niOOil;
	wire_nl000O_dataout <= niOOil WHEN nlil1ll = '1'  ELSE niOOiO;
	wire_nl001i_dataout <= wire_nl0OiO_dataout WHEN nlil1ll = '1'  ELSE niOO0i;
	wire_nl001l_dataout <= wire_nl0Oli_dataout WHEN nlil1ll = '1'  ELSE niOO0l;
	wire_nl001O_dataout <= wire_nl0Oll_dataout WHEN nlil1ll = '1'  ELSE niOO0O;
	wire_nl00i_dataout <= (nlillOO OR ni1O0O) AND rwa_6g_en;
	wire_nl00ii_dataout <= niOOiO WHEN nlil1ll = '1'  ELSE niOOli;
	wire_nl00il_dataout <= niOOli WHEN nlil1ll = '1'  ELSE niOOll;
	wire_nl00iO_dataout <= niOOll WHEN nlil1ll = '1'  ELSE niOOlO;
	wire_nl00l_dataout <= ni000i AND rwa_6g_en;
	wire_nl00li_dataout <= niOOlO WHEN nlil1ll = '1'  ELSE niOOOi;
	wire_nl00ll_dataout <= niOOOi WHEN nlil1ll = '1'  ELSE niOOOl;
	wire_nl00lO_dataout <= niOOOl WHEN nlil1ll = '1'  ELSE niOOOO;
	wire_nl00O_dataout <= wire_nliOOi_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlOi10l_dataout;
	wire_nl00O_w_lg_dataout123w(0) <= NOT wire_nl00O_dataout;
	wire_nl00Oi_dataout <= niOOOO WHEN nlil1ll = '1'  ELSE nl111i;
	wire_nl00Ol_dataout <= nl111i WHEN nlil1ll = '1'  ELSE nl111l;
	wire_nl00OO_dataout <= nl111l WHEN nlil1ll = '1'  ELSE nl111O;
	wire_nl010i_dataout <= wire_nl0liO_dataout AND NOT(nlil00l);
	wire_nl010l_dataout <= wire_nl0lli_dataout AND NOT(nlil00l);
	wire_nl010O_dataout <= wire_nl0lll_dataout AND NOT(nlil00l);
	wire_nl011i_dataout <= wire_nl0l0O_dataout AND NOT(nlil00l);
	wire_nl011l_dataout <= wire_nl0lii_dataout AND NOT(nlil00l);
	wire_nl011O_dataout <= wire_nl0lil_dataout AND NOT(nlil00l);
	wire_nl01i_dataout <= nllO1O AND rwa_6g_en;
	wire_nl01ii_dataout <= wire_nl0llO_dataout AND NOT(nlil00l);
	wire_nl01il_dataout <= wire_nl0lOi_dataout AND NOT(nlil00l);
	wire_nl01iO_dataout <= wire_nl0lOl_dataout AND NOT(nlil00l);
	wire_nl01l_dataout <= nllO0i AND rwa_6g_en;
	wire_nl01li_dataout <= nlil1ii WHEN nlil1ll = '1'  ELSE niii1i;
	wire_nl01ll_dataout <= (((wire_nl0O1O_o(4) OR wire_nl0O1O_o(3)) OR wire_nl0O1O_o(2)) OR wire_nl0O1O_o(1)) WHEN nlil1ll = '1'  ELSE niOlOl;
	wire_nl01lO_dataout <= nlil1il WHEN nlil1ll = '1'  ELSE niOlOO;
	wire_nl01O_dataout <= nllO0l AND rwa_6g_en;
	wire_nl01Oi_dataout <= nlil1iO WHEN nlil1ll = '1'  ELSE niOO1i;
	wire_nl01Ol_dataout <= (((wire_nl0Oii_o(18) OR wire_nl0Oii_o(17)) OR wire_nl0Oii_o(16)) OR wire_nl0Oii_o(15)) WHEN nlil1ll = '1'  ELSE niOO1l;
	wire_nl01OO_dataout <= wire_nl0Oil_dataout WHEN nlil1ll = '1'  ELSE niOO1O;
	wire_nl0i_dataout <= nO AND NOT(scan_mode);
	wire_nl0i_w_lg_dataout4w(0) <= NOT wire_nl0i_dataout;
	wire_nl0i0i_dataout <= nl110O WHEN nlil1ll = '1'  ELSE nl11ii;
	wire_nl0i0l_dataout <= nl11ii WHEN nlil1ll = '1'  ELSE nl11il;
	wire_nl0i0O_dataout <= nl11il WHEN nlil1ll = '1'  ELSE nl11iO;
	wire_nl0i1i_dataout <= nl111O WHEN nlil1ll = '1'  ELSE nl110i;
	wire_nl0i1l_dataout <= nl110i WHEN nlil1ll = '1'  ELSE nl110l;
	wire_nl0i1O_dataout <= nl110l WHEN nlil1ll = '1'  ELSE nl110O;
	wire_nl0ii_dataout <= (rmatchen AND wire_w_lg_rgenericfifo32w(0)) WHEN rwa_6g_en = '1'  ELSE ((wire_w_lg_rgenericfifo32w(0) AND (wire_w_lg_w_lg_w_lg_w_dskwclksel_range33w34w35w36w(0) OR (NOT (nlilO1O18 XOR nlilO1O17)))) AND (nlilO1i20 XOR nlilO1i19));
	wire_nl0ii_w_lg_w_lg_dataout138w141w(0) <= wire_nl0ii_w_lg_dataout138w(0) AND wire_nlill1O28_w_lg_q140w(0);
	wire_nl0ii_w_lg_dataout138w(0) <= wire_nl0ii_dataout AND wire_nl00O_dataout;
	wire_nl0iii_dataout <= nl11iO WHEN nlil1ll = '1'  ELSE nl11li;
	wire_nl0iil_dataout <= nl11li WHEN nlil1ll = '1'  ELSE nl11ll;
	wire_nl0iiO_dataout <= nl11ll WHEN nlil1ll = '1'  ELSE nl11lO;
	wire_nl0il_dataout <= n0l0iO WHEN rwa_6g_en = '1'  ELSE nlllO0l;
	wire_nl0ili_dataout <= nl1i1O WHEN nlil1ll = '1'  ELSE nl11Ol;
	wire_nl0ill_dataout <= nl11Ol WHEN nlil1ll = '1'  ELSE nl11OO;
	wire_nl0ilO_dataout <= nl11OO WHEN nlil1ll = '1'  ELSE nl101i;
	wire_nl0iO_dataout <= n0l0li WHEN rwa_6g_en = '1'  ELSE nlllO0O;
	wire_nl0iOi_dataout <= nl101i WHEN nlil1ll = '1'  ELSE nl101l;
	wire_nl0iOl_dataout <= nl101l WHEN nlil1ll = '1'  ELSE nl101O;
	wire_nl0iOO_dataout <= nl101O WHEN nlil1ll = '1'  ELSE nl100i;
	wire_nl0l0i_dataout <= nl10ii WHEN nlil1ll = '1'  ELSE nl10il;
	wire_nl0l0l_dataout <= nl10il WHEN nlil1ll = '1'  ELSE nl10iO;
	wire_nl0l0O_dataout <= nl10iO WHEN nlil1ll = '1'  ELSE nl10li;
	wire_nl0l1i_dataout <= nl100i WHEN nlil1ll = '1'  ELSE nl100l;
	wire_nl0l1l_dataout <= nl100l WHEN nlil1ll = '1'  ELSE nl100O;
	wire_nl0l1O_dataout <= nl100O WHEN nlil1ll = '1'  ELSE nl10ii;
	wire_nl0li_dataout <= n0l0ll WHEN rwa_6g_en = '1'  ELSE nlllOii;
	wire_nl0lii_dataout <= nl10li WHEN nlil1ll = '1'  ELSE nl10ll;
	wire_nl0lil_dataout <= nl10ll WHEN nlil1ll = '1'  ELSE nl10lO;
	wire_nl0liO_dataout <= nl10lO WHEN nlil1ll = '1'  ELSE nl10Oi;
	wire_nl0ll_dataout <= n0l0lO WHEN rwa_6g_en = '1'  ELSE nlllOil;
	wire_nl0lli_dataout <= nl10Oi WHEN nlil1ll = '1'  ELSE nl10Ol;
	wire_nl0lll_dataout <= nl10Ol WHEN nlil1ll = '1'  ELSE nl10OO;
	wire_nl0llO_dataout <= nl10OO WHEN nlil1ll = '1'  ELSE nl1i1i;
	wire_nl0lO_dataout <= n0l0Oi WHEN rwa_6g_en = '1'  ELSE nlllOiO;
	wire_nl0lOi_dataout <= nl1i1i WHEN nlil1ll = '1'  ELSE nl1i1l;
	wire_nl0lOl_dataout <= nl1i1l WHEN nlil1ll = '1'  ELSE nl1i1O;
	wire_nl0Oi_dataout <= n0l0Ol WHEN rwa_6g_en = '1'  ELSE nlllOli;
	wire_nl0Oil_dataout <= wire_nl0OOi_o(0) AND NOT(nlil1li);
	wire_nl0OiO_dataout <= wire_nl0OOi_o(1) AND NOT(nlil1li);
	wire_nl0Ol_dataout <= n0l0OO WHEN rwa_6g_en = '1'  ELSE nlllOll;
	wire_nl0Oli_dataout <= wire_nl0OOi_o(2) AND NOT(nlil1li);
	wire_nl0Oll_dataout <= wire_nl0OOi_o(3) AND NOT(nlil1li);
	wire_nl0OlO_dataout <= wire_nl0OOi_o(4) AND NOT(nlil1li);
	wire_nl0OO_dataout <= n0li1i WHEN rwa_6g_en = '1'  ELSE nlllOlO;
	wire_nl10i_dataout <= ni000i WHEN rwa_6g_en = '1'  ELSE nlllliO;
	wire_nl10l_dataout <= nlllii AND rwa_6g_en;
	wire_nl10O_dataout <= nlllil AND rwa_6g_en;
	wire_nl11i_dataout <= nlll0l WHEN rwa_6g_en = '1'  ELSE wire_nlO0OlO_dataout;
	wire_nl11l_dataout <= nlll0O WHEN rwa_6g_en = '1'  ELSE wire_nlOiliO_dataout;
	wire_nl11O_dataout <= ((nlillOO OR ni1O0O) OR (NOT (nlilliO24 XOR nlilliO23))) WHEN rwa_6g_en = '1'  ELSE (wire_nii_w_lg_w_lg_nllllii47w48w(0) OR (NOT (nlillll22 XOR nlillll21)));
	wire_nl1i_dataout <= ni1i1O WHEN rwa_6g_en = '1'  ELSE nlO1OOl;
	wire_nl1i0l_dataout <= wire_nl01li_dataout AND NOT(nlil00l);
	wire_nl1i0O_dataout <= wire_nl01ll_dataout AND NOT(nlil00l);
	wire_nl1ii_dataout <= nllliO AND rwa_6g_en;
	wire_nl1iii_dataout <= wire_nl01lO_dataout AND NOT(nlil00l);
	wire_nl1iil_dataout <= wire_nl01Oi_dataout AND NOT(nlil00l);
	wire_nl1iiO_dataout <= wire_nl01Ol_dataout AND NOT(nlil00l);
	wire_nl1il_dataout <= nlllli AND rwa_6g_en;
	wire_nl1ili_dataout <= wire_nl01OO_dataout AND NOT(nlil00l);
	wire_nl1ill_dataout <= wire_nl001i_dataout AND NOT(nlil00l);
	wire_nl1ilO_dataout <= wire_nl001l_dataout AND NOT(nlil00l);
	wire_nl1iO_dataout <= nlllll AND rwa_6g_en;
	wire_nl1iOi_dataout <= wire_nl001O_dataout AND NOT(nlil00l);
	wire_nl1iOl_dataout <= wire_nl000i_dataout AND NOT(nlil00l);
	wire_nl1iOO_dataout <= wire_nl000l_dataout AND NOT(nlil00l);
	wire_nl1l_dataout <= ni1i0i WHEN rwa_6g_en = '1'  ELSE nlO1OOO;
	wire_nl1l0i_dataout <= wire_nl00iO_dataout AND NOT(nlil00l);
	wire_nl1l0l_dataout <= wire_nl00li_dataout AND NOT(nlil00l);
	wire_nl1l0O_dataout <= wire_nl00ll_dataout AND NOT(nlil00l);
	wire_nl1l1i_dataout <= wire_nl000O_dataout OR nlil00l;
	wire_nl1l1l_dataout <= wire_nl00ii_dataout AND NOT(nlil00l);
	wire_nl1l1O_dataout <= wire_nl00il_dataout AND NOT(nlil00l);
	wire_nl1li_dataout <= nllllO AND rwa_6g_en;
	wire_nl1lii_dataout <= wire_nl00lO_dataout AND NOT(nlil00l);
	wire_nl1lil_dataout <= wire_nl00Oi_dataout AND NOT(nlil00l);
	wire_nl1liO_dataout <= wire_nl00Ol_dataout AND NOT(nlil00l);
	wire_nl1ll_dataout <= nlllOi AND rwa_6g_en;
	wire_nl1lli_dataout <= wire_nl00OO_dataout AND NOT(nlil00l);
	wire_nl1lll_dataout <= wire_nl0i1i_dataout AND NOT(nlil00l);
	wire_nl1llO_dataout <= wire_nl0i1l_dataout AND NOT(nlil00l);
	wire_nl1lO_dataout <= nlllOl AND rwa_6g_en;
	wire_nl1lOi_dataout <= wire_nl0i1O_dataout AND NOT(nlil00l);
	wire_nl1lOl_dataout <= wire_nl0i0i_dataout AND NOT(nlil00l);
	wire_nl1lOO_dataout <= wire_nl0i0l_dataout AND NOT(nlil00l);
	wire_nl1O_dataout <= ni1i0l WHEN rwa_6g_en = '1'  ELSE nlO011i;
	wire_nl1O0i_dataout <= wire_nl0iiO_dataout AND NOT(nlil00l);
	wire_nl1O0l_dataout <= wire_nl0ili_dataout OR nlil00l;
	wire_nl1O0O_dataout <= wire_nl0ill_dataout AND NOT(nlil00l);
	wire_nl1O1i_dataout <= wire_nl0i0O_dataout AND NOT(nlil00l);
	wire_nl1O1l_dataout <= wire_nl0iii_dataout AND NOT(nlil00l);
	wire_nl1O1O_dataout <= wire_nl0iil_dataout AND NOT(nlil00l);
	wire_nl1Oi_dataout <= nlllOO AND rwa_6g_en;
	wire_nl1Oii_dataout <= wire_nl0ilO_dataout AND NOT(nlil00l);
	wire_nl1Oil_dataout <= wire_nl0iOi_dataout AND NOT(nlil00l);
	wire_nl1OiO_dataout <= wire_nl0iOl_dataout AND NOT(nlil00l);
	wire_nl1Ol_dataout <= nllO1i AND rwa_6g_en;
	wire_nl1Oli_dataout <= wire_nl0iOO_dataout AND NOT(nlil00l);
	wire_nl1Oll_dataout <= wire_nl0l1i_dataout AND NOT(nlil00l);
	wire_nl1OlO_dataout <= wire_nl0l1l_dataout AND NOT(nlil00l);
	wire_nl1OO_dataout <= nllO1l AND rwa_6g_en;
	wire_nl1OOi_dataout <= wire_nl0l1O_dataout AND NOT(nlil00l);
	wire_nl1OOl_dataout <= wire_nl0l0i_dataout AND NOT(nlil00l);
	wire_nl1OOO_dataout <= wire_nl0l0l_dataout AND NOT(nlil00l);
	wire_nli_dataout <= wire_nliiOO_dataout WHEN rwa_6g_en = '1'  ELSE wire_n1100O_dataout;
	wire_nli00i_dataout <= nli1OO AND NOT(nlil00l);
	wire_nli00l_dataout <= n0l00i AND NOT(nlil00l);
	wire_nli00O_dataout <= n0l01O AND NOT(nlil00l);
	wire_nli01O_dataout <= nli01l AND NOT(nlil00l);
	wire_nli0i_dataout <= n0li0l WHEN rwa_6g_en = '1'  ELSE nllO11i;
	wire_nli0ii_dataout <= n0l01l AND NOT(nlil00l);
	wire_nli0iO_dataout <= n0OiOO AND NOT(nlil00l);
	wire_nli0l_dataout <= n0li0O WHEN rwa_6g_en = '1'  ELSE nllO11l;
	wire_nli0li_dataout <= n0Ol1l AND NOT(nlil00l);
	wire_nli0ll_dataout <= n0Ol1O AND NOT(nlil00l);
	wire_nli0lO_dataout <= n0Ol0i AND NOT(nlil00l);
	wire_nli0O_dataout <= n0liii WHEN rwa_6g_en = '1'  ELSE nllO11O;
	wire_nli0Oi_dataout <= n0Ol0l AND NOT(nlil00l);
	wire_nli1i_dataout <= n0li1l WHEN rwa_6g_en = '1'  ELSE nlllOOi;
	wire_nli1l_dataout <= n0li1O WHEN rwa_6g_en = '1'  ELSE nlllOOl;
	wire_nli1O_dataout <= n0li0i WHEN rwa_6g_en = '1'  ELSE nlllOOO;
	wire_nliii_dataout <= n0liil WHEN rwa_6g_en = '1'  ELSE nllO10i;
	wire_nliiii_dataout <= ((wire_w_lg_rgenericfifo32w(0) AND nlii0O) OR nlil01O) AND NOT(nlil00l);
	wire_nliiil_dataout <= nlii0l AND NOT(nlil00l);
	wire_nliiiO_dataout <= nllOOi AND NOT(nlil00l);
	wire_nliil_dataout <= n0liiO WHEN rwa_6g_en = '1'  ELSE nllO10l;
	wire_nliiO_dataout <= n0lili WHEN rwa_6g_en = '1'  ELSE nllO10O;
	wire_nliiOO_dataout <= (nlil00i OR nliiOi) WHEN nlilOiO = '1'  ELSE nlil00i;
	wire_nlil_dataout <= nlli AND NOT(scan_mode);
	wire_nlili_dataout <= n0lill WHEN rwa_6g_en = '1'  ELSE nllO1ii;
	wire_nlilii_dataout <= n0111i AND NOT(nlil00l);
	wire_nlilil_dataout <= ((nlii0O AND n0111i) AND wire_n1i_w_lg_nlil0i484w(0)) AND NOT(nlil00l);
	wire_nlill_dataout <= n0lilO WHEN rwa_6g_en = '1'  ELSE nllO1il;
	wire_nlilO_dataout <= n0liOi WHEN rwa_6g_en = '1'  ELSE nllO1iO;
	wire_nlilOO_dataout <= (nlil0il OR nlil0ii) AND wire_nliOlO_dataout;
	wire_nliO00l_dataout <= nliO01O AND NOT(wire_w_lg_nli0OlO3183w(0));
	wire_nliO00O_dataout <= nliO00i AND NOT(wire_w_lg_nli0OlO3183w(0));
	wire_nliO0i_dataout <= nlil0iO AND wire_nliOlO_dataout;
	wire_nliO0ii_dataout <= wire_n11iii_o AND (rgenericfifo OR wire_nlOi10l_dataout);
	wire_nliO0l_dataout <= ((nlil0Oi OR nlil0lO) OR (NOT (nlil0li48 XOR nlil0li47))) WHEN (wire_n1i_w_lg_w_lg_nlilOl458w459w(0) AND wire_w_lg_nliliii460w(0)) = '1'  ELSE wire_nliO0O_dataout;
	wire_nliO0O_dataout <= (rtruebac2bac AND (wire_w_lg_w_lg_nliliil440w441w(0) AND (nlili0l44 XOR nlili0l43))) OR ((nlili0i OR nlili1O) AND ((nlili1l OR nlili1i) OR (NOT (nlil0Ol46 XOR nlil0Ol45))));
	wire_nliO1O_dataout <= wire_nliO0l_dataout AND wire_nliOlO_dataout;
	wire_nliOi_dataout <= niOOil WHEN rwa_6g_en = '1'  ELSE n100il;
	wire_nliOl_dataout <= niOOiO WHEN rwa_6g_en = '1'  ELSE n100iO;
	wire_nliOlO_dataout <= nli0OO AND NOT(nliliiO);
	wire_nliOlO_w_lg_dataout544w(0) <= NOT wire_nliOlO_dataout;
	wire_nliOO_dataout <= niOOli WHEN rwa_6g_en = '1'  ELSE n100li;
	wire_nliOOi_dataout <= sync_status AND NOT(nliliiO);
	wire_nliOOi_w_lg_dataout733w(0) <= wire_nliOOi_dataout AND ni000l;
	wire_nliOOi_w_lg_dataout924w(0) <= NOT wire_nliOOi_dataout;
	wire_nliOOO_dataout <= nlii1l WHEN nlilili = '1'  ELSE sync_status;
	wire_nll_dataout <= ni11Ol WHEN rwa_6g_en = '1'  ELSE nllil1l;
	wire_nll00i_dataout <= nii01i WHEN nlilili = '1'  ELSE sudi(16);
	wire_nll00l_dataout <= nii01l WHEN nlilili = '1'  ELSE sudi(17);
	wire_nll00O_dataout <= nii01O WHEN nlilili = '1'  ELSE sudi(18);
	wire_nll01i_dataout <= nii1Oi AND nlilili;
	wire_nll01l_dataout <= nii1Ol WHEN nlilili = '1'  ELSE sudi(14);
	wire_nll01O_dataout <= nii1OO WHEN nlilili = '1'  ELSE sudi(15);
	wire_nll0i_dataout <= niOOOl WHEN rwa_6g_en = '1'  ELSE n100Ol;
	wire_nll0ii_dataout <= nii00i WHEN nlilili = '1'  ELSE sudi(19);
	wire_nll0il_dataout <= nii00l WHEN nlilili = '1'  ELSE sudi(20);
	wire_nll0iO_dataout <= nii00O WHEN nlilili = '1'  ELSE sudi(21);
	wire_nll0l_dataout <= niOOOO WHEN rwa_6g_en = '1'  ELSE n100OO;
	wire_nll0li_dataout <= nii0ii WHEN nlilili = '1'  ELSE sudi(22);
	wire_nll0ll_dataout <= nii0il WHEN nlilili = '1'  ELSE sudi(23);
	wire_nll0lO_dataout <= nii0iO WHEN nlilili = '1'  ELSE sudi(24);
	wire_nll0O_dataout <= nl111i WHEN rwa_6g_en = '1'  ELSE n10i1i;
	wire_nll0Oi_dataout <= nii0li WHEN nlilili = '1'  ELSE sudi(25);
	wire_nll0Ol_dataout <= nii0ll WHEN nlilili = '1'  ELSE sudi(26);
	wire_nll0OO_dataout <= nii0Oi WHEN nlilili = '1'  ELSE sudi(27);
	wire_nll10i_dataout <= nii11i WHEN nlilili = '1'  ELSE sudi(3);
	wire_nll10l_dataout <= nii11l WHEN nlilili = '1'  ELSE sudi(4);
	wire_nll10O_dataout <= nii11O WHEN nlilili = '1'  ELSE sudi(5);
	wire_nll11i_dataout <= ni0OOi WHEN nlilili = '1'  ELSE sudi(0);
	wire_nll11l_dataout <= ni0OOl WHEN nlilili = '1'  ELSE sudi(1);
	wire_nll11O_dataout <= ni0OOO WHEN nlilili = '1'  ELSE sudi(2);
	wire_nll1i_dataout <= niOOll WHEN rwa_6g_en = '1'  ELSE n100ll;
	wire_nll1ii_dataout <= nii10i WHEN nlilili = '1'  ELSE sudi(6);
	wire_nll1il_dataout <= nii10l WHEN nlilili = '1'  ELSE sudi(7);
	wire_nll1iO_dataout <= nii10O WHEN nlilili = '1'  ELSE sudi(8);
	wire_nll1l_dataout <= niOOlO WHEN rwa_6g_en = '1'  ELSE n100lO;
	wire_nll1li_dataout <= nii1ii WHEN nlilili = '1'  ELSE sudi(9);
	wire_nll1ll_dataout <= nii1il WHEN nlilili = '1'  ELSE sudi(10);
	wire_nll1lO_dataout <= nii1iO WHEN nlilili = '1'  ELSE sudi(11);
	wire_nll1O_dataout <= niOOOi WHEN rwa_6g_en = '1'  ELSE n100Oi;
	wire_nll1Oi_dataout <= nii1li WHEN nlilili = '1'  ELSE sudi(12);
	wire_nll1Ol_dataout <= nii1ll WHEN nlilili = '1'  ELSE sudi(13);
	wire_nll1OO_dataout <= nii1lO AND nlilili;
	wire_nlli01i_dataout <= nli0i1i AND NOT(nli0lii);
	wire_nlli0li_dataout <= (nli0i1l OR nlli1ll) WHEN nliO11i = '1'  ELSE nli0i1l;
	wire_nlli1i_dataout <= nii0Ol AND nlilili;
	wire_nlli1l_dataout <= nii0OO AND nlilili;
	wire_nlli1lO_dataout <= nli00lO AND NOT(nli0lii);
	wire_nlli1Oi_dataout <= nli00Oi AND NOT(nli0lii);
	wire_nlli1Ol_dataout <= nli00Ol AND NOT(nli0lii);
	wire_nlli1OO_dataout <= nli00OO AND NOT(nli0lii);
	wire_nllii_dataout <= nl111l WHEN rwa_6g_en = '1'  ELSE n10i1l;
	wire_nllii0i_dataout <= nli0l0l AND NOT(nli0lii);
	wire_nlliili_dataout <= nlO1OiO AND NOT(nli0lii);
	wire_nlliill_dataout <= nlO1OOi AND NOT(nli0lii);
	wire_nlliilO_dataout <= nlO1OOl AND NOT(nli0lii);
	wire_nlliiOi_dataout <= nlO1OOO AND NOT(nli0lii);
	wire_nlliiOl_dataout <= nlO011i AND NOT(nli0lii);
	wire_nllil_dataout <= nl111O WHEN rwa_6g_en = '1'  ELSE n10i1O;
	wire_nllil0O_dataout <= nllil1O AND NOT(nli0lii);
	wire_nllilii_dataout <= nllil1i OR nli0lii;
	wire_nllilil_dataout <= wire_n1OlOi_o OR nli0lii;
	wire_nlliliO_dataout <= wire_nllillO_dataout OR nli0lii;
	wire_nllilli_dataout <= wire_n1OllO_o AND NOT(nli0lii);
	wire_nllilll_dataout <= wire_nllilOO_dataout AND NOT(nli0lii);
	wire_nllillO_dataout <= (nli0i0i OR nlliiOO) WHEN nliO11i = '1'  ELSE nli0i0i;
	wire_nllilOO_dataout <= (nli0i0l OR nlliiiO) WHEN nliO11i = '1'  ELSE nli0i0l;
	wire_nlliO_dataout <= nl110i WHEN rwa_6g_en = '1'  ELSE n10i0i;
	wire_nlll00i_dataout <= wire_nllll1i_o(2) WHEN nli0ili = '1'  ELSE wire_nlll0iO_dataout;
	wire_nlll00l_dataout <= wire_nllll1i_o(3) WHEN nli0ili = '1'  ELSE wire_nlll0li_dataout;
	wire_nlll00O_dataout <= wire_nllll1i_o(4) WHEN nli0ili = '1'  ELSE wire_nlll0ll_dataout;
	wire_nlll01i_dataout <= wire_nlll00O_dataout AND NOT(nli0lii);
	wire_nlll01l_dataout <= wire_nllll1i_o(0) WHEN nli0ili = '1'  ELSE wire_nlll0ii_dataout;
	wire_nlll01O_dataout <= wire_nllll1i_o(1) WHEN nli0ili = '1'  ELSE wire_nlll0il_dataout;
	wire_nlll0ii_dataout <= nlll10l WHEN nli0iiO = '1'  ELSE wire_nlll0lO_dataout;
	wire_nlll0il_dataout <= wire_nllliOl_o(0) WHEN nli0iiO = '1'  ELSE wire_nlll0Oi_dataout;
	wire_nlll0iO_dataout <= wire_nllliOl_o(1) WHEN nli0iiO = '1'  ELSE wire_nlll0Ol_dataout;
	wire_nlll0li_dataout <= wire_nllliOl_o(2) WHEN nli0iiO = '1'  ELSE wire_nlll0OO_dataout;
	wire_nlll0ll_dataout <= wire_nllliOl_o(3) WHEN nli0iiO = '1'  ELSE wire_nllli1i_dataout;
	wire_nlll0lO_dataout <= wire_nllliil_o(0) WHEN nli0iil = '1'  ELSE wire_nllli1l_dataout;
	wire_nlll0Oi_dataout <= wire_nllliil_o(1) WHEN nli0iil = '1'  ELSE wire_nllli1O_dataout;
	wire_nlll0Ol_dataout <= wire_nllliil_o(2) WHEN nli0iil = '1'  ELSE wire_nllli0i_dataout;
	wire_nlll0OO_dataout <= wire_nllliil_o(3) WHEN nli0iil = '1'  ELSE wire_nllli0l_dataout;
	wire_nlll1ll_dataout <= nlillOl AND NOT(nli0lii);
	wire_nlll1lO_dataout <= wire_nlll01l_dataout AND NOT(nli0lii);
	wire_nlll1Oi_dataout <= wire_nlll01O_dataout AND NOT(nli0lii);
	wire_nlll1Ol_dataout <= wire_nlll00i_dataout AND NOT(nli0lii);
	wire_nlll1OO_dataout <= wire_nlll00l_dataout AND NOT(nli0lii);
	wire_nllli_dataout <= nl110l WHEN rwa_6g_en = '1'  ELSE n10i0l;
	wire_nllli0i_dataout <= wire_nllliii_o(3) WHEN wire_w_lg_nli0iii2509w(0) = '1'  ELSE nlll1ii;
	wire_nllli0l_dataout <= wire_nllliii_o(4) WHEN wire_w_lg_nli0iii2509w(0) = '1'  ELSE nlll1il;
	wire_nllli0O_dataout <= wire_nllliii_o(5) WHEN wire_w_lg_nli0iii2509w(0) = '1'  ELSE nlll1iO;
	wire_nllli1i_dataout <= wire_nllliil_o(4) WHEN nli0iil = '1'  ELSE wire_nllli0O_dataout;
	wire_nllli1l_dataout <= wire_nllliii_o(1) WHEN wire_w_lg_nli0iii2509w(0) = '1'  ELSE nlll10l;
	wire_nllli1O_dataout <= wire_nllliii_o(2) WHEN wire_w_lg_nli0iii2509w(0) = '1'  ELSE nlll10O;
	wire_nllll_dataout <= nl110O WHEN rwa_6g_en = '1'  ELSE n10i0O;
	wire_nllllll_dataout <= nli0ilO AND NOT(nli0lii);
	wire_nlllllO_dataout <= nli0ilO AND NOT(nli0lii);
	wire_nlllO_dataout <= nl11ii WHEN rwa_6g_en = '1'  ELSE n10iii;
	wire_nllO_dataout <= cmpfifourst AND rcmpfifourst;
	wire_nllO00i_dataout <= wire_nllOiOl_dataout AND NOT(nli0lii);
	wire_nllO00l_dataout <= wire_nllOiOO_dataout AND NOT(nli0lii);
	wire_nllO00O_dataout <= wire_nllOl1i_dataout AND NOT(nli0lii);
	wire_nllO01i_dataout <= wire_nllOill_dataout OR nli0lii;
	wire_nllO01l_dataout <= wire_nllOilO_dataout AND NOT(nli0lii);
	wire_nllO01O_dataout <= wire_nllOiOi_dataout AND NOT(nli0lii);
	wire_nllO0ii_dataout <= wire_nllOl1l_dataout AND NOT(nli0lii);
	wire_nllO0il_dataout <= wire_nllOl1O_dataout AND NOT(nli0lii);
	wire_nllO0iO_dataout <= wire_nllOl0i_dataout AND NOT(nli0lii);
	wire_nllO0li_dataout <= wire_nllOl0l_dataout AND NOT(nli0lii);
	wire_nllO0ll_dataout <= wire_nllOl0O_dataout AND NOT(nli0lii);
	wire_nllO0lO_dataout <= wire_nllOlii_dataout AND NOT(nli0lii);
	wire_nllO0Oi_dataout <= wire_nllOlil_dataout AND NOT(nli0lii);
	wire_nllO0Ol_dataout <= wire_nllOliO_dataout AND NOT(nli0lii);
	wire_nllO0OO_dataout <= wire_nllOlli_dataout AND NOT(nli0lii);
	wire_nllO1ll_dataout <= wire_nllOi0O_dataout AND NOT(nli0lii);
	wire_nllO1lO_dataout <= wire_nllOiii_dataout AND NOT(nli0lii);
	wire_nllO1Oi_dataout <= wire_nllOiil_dataout AND NOT(nli0lii);
	wire_nllO1Ol_dataout <= wire_nllOiiO_dataout AND NOT(nli0lii);
	wire_nllO1OO_dataout <= wire_nllOili_dataout AND NOT(nli0lii);
	wire_nllOi_dataout <= nl11il WHEN rwa_6g_en = '1'  ELSE n10iil;
	wire_nllOi0i_dataout <= wire_nllOlOl_dataout AND NOT(nli0lii);
	wire_nllOi0l_dataout <= wire_nllOlOO_dataout AND NOT(nli0lii);
	wire_nllOi0O_dataout <= wire_nlO100i_dataout WHEN nli0iOi = '1'  ELSE wire_nllOO1i_dataout;
	wire_nllOi1i_dataout <= wire_nllOlll_dataout AND NOT(nli0lii);
	wire_nllOi1l_dataout <= wire_nllOllO_dataout AND NOT(nli0lii);
	wire_nllOi1O_dataout <= wire_nllOlOi_dataout AND NOT(nli0lii);
	wire_nllOiii_dataout <= wire_nlO100l_dataout WHEN nli0iOi = '1'  ELSE wire_nllOO1l_dataout;
	wire_nllOiil_dataout <= wire_nlO100O_dataout WHEN nli0iOi = '1'  ELSE wire_nllOO1O_dataout;
	wire_nllOiiO_dataout <= wire_nlO10ii_dataout WHEN nli0iOi = '1'  ELSE wire_nllOO0i_dataout;
	wire_nllOili_dataout <= wire_nlO10il_dataout WHEN nli0iOi = '1'  ELSE wire_nllOO0l_dataout;
	wire_nllOill_dataout <= nllO1iO WHEN nli0iOi = '1'  ELSE wire_nllOO0O_dataout;
	wire_nllOilO_dataout <= nlllO0l WHEN nli0iOi = '1'  ELSE wire_nllOOii_dataout;
	wire_nllOiOi_dataout <= nlllO0O WHEN nli0iOi = '1'  ELSE wire_nllOOil_dataout;
	wire_nllOiOl_dataout <= nlllOii WHEN nli0iOi = '1'  ELSE wire_nllOOiO_dataout;
	wire_nllOiOO_dataout <= nlllOil WHEN nli0iOi = '1'  ELSE wire_nllOOli_dataout;
	wire_nllOl_dataout <= nl11iO WHEN rwa_6g_en = '1'  ELSE n10iiO;
	wire_nllOl0i_dataout <= nlllOlO WHEN nli0iOi = '1'  ELSE wire_nllOOOl_dataout;
	wire_nllOl0l_dataout <= nlllOOi WHEN nli0iOi = '1'  ELSE wire_nllOOOO_dataout;
	wire_nllOl0O_dataout <= nlllOOl WHEN nli0iOi = '1'  ELSE wire_nlO111i_dataout;
	wire_nllOl1i_dataout <= nlllOiO WHEN nli0iOi = '1'  ELSE wire_nllOOll_dataout;
	wire_nllOl1l_dataout <= nlllOli WHEN nli0iOi = '1'  ELSE wire_nllOOlO_dataout;
	wire_nllOl1O_dataout <= nlllOll WHEN nli0iOi = '1'  ELSE wire_nllOOOi_dataout;
	wire_nllOlii_dataout <= nlllOOO WHEN nli0iOi = '1'  ELSE wire_nlO111l_dataout;
	wire_nllOlil_dataout <= nllO11i WHEN nli0iOi = '1'  ELSE wire_nlO111O_dataout;
	wire_nllOliO_dataout <= nllO11l WHEN nli0iOi = '1'  ELSE wire_nlO110i_dataout;
	wire_nllOlli_dataout <= nllO11O WHEN nli0iOi = '1'  ELSE wire_nlO110l_dataout;
	wire_nllOlll_dataout <= nllO10i WHEN nli0iOi = '1'  ELSE wire_nlO110O_dataout;
	wire_nllOllO_dataout <= nllO10l WHEN nli0iOi = '1'  ELSE wire_nlO11ii_dataout;
	wire_nllOlOi_dataout <= nllO10O WHEN nli0iOi = '1'  ELSE wire_nlO11il_dataout;
	wire_nllOlOl_dataout <= nllO1ii WHEN nli0iOi = '1'  ELSE wire_nlO11iO_dataout;
	wire_nllOlOO_dataout <= nllO1il WHEN nli0iOi = '1'  ELSE wire_nlO11li_dataout;
	wire_nllOO_dataout <= nl11li WHEN rwa_6g_en = '1'  ELSE n10ili;
	wire_nllOO0i_dataout <= wire_nlO11Ol_dataout WHEN nli0iOO = '1'  ELSE nlllO1O;
	wire_nllOO0l_dataout <= wire_nlO11OO_dataout WHEN nli0iOO = '1'  ELSE nlllO0i;
	wire_nllOO0O_dataout <= nlllO0O WHEN nli0iOO = '1'  ELSE nlllO0l;
	wire_nllOO1i_dataout <= wire_nlO11ll_dataout WHEN nli0iOO = '1'  ELSE nllllli;
	wire_nllOO1l_dataout <= wire_nlO11lO_dataout WHEN nli0iOO = '1'  ELSE nlllO1i;
	wire_nllOO1O_dataout <= wire_nlO11Oi_dataout WHEN nli0iOO = '1'  ELSE nlllO1l;
	wire_nllOOii_dataout <= nlllOii WHEN nli0iOO = '1'  ELSE nlllO0O;
	wire_nllOOil_dataout <= nlllOil WHEN nli0iOO = '1'  ELSE nlllOii;
	wire_nllOOiO_dataout <= nlllOiO WHEN nli0iOO = '1'  ELSE nlllOil;
	wire_nllOOli_dataout <= nlllOli WHEN nli0iOO = '1'  ELSE nlllOiO;
	wire_nllOOll_dataout <= nlllOll WHEN nli0iOO = '1'  ELSE nlllOli;
	wire_nllOOlO_dataout <= nlllOlO WHEN nli0iOO = '1'  ELSE nlllOll;
	wire_nllOOOi_dataout <= nlllOOi WHEN nli0iOO = '1'  ELSE nlllOlO;
	wire_nllOOOl_dataout <= nlllOOl WHEN nli0iOO = '1'  ELSE nlllOOi;
	wire_nllOOOO_dataout <= nlllOOO WHEN nli0iOO = '1'  ELSE nlllOOl;
	wire_nlO_dataout <= wire_n0OOii_dataout WHEN rwa_6g_en = '1'  ELSE wire_nlli0li_dataout;
	wire_nlO001i_dataout <= wire_nlO000l_o(4) WHEN wire_nlO000O_o = '1'  ELSE wire_nlO001O_o(4);
	wire_nlO001l_dataout <= wire_nlO000l_o(5) WHEN wire_nlO000O_o = '1'  ELSE wire_nlO001O_o(5);
	wire_nlO00il_dataout <= (nli0lOl OR nli0lOi) AND (wire_nlOi10l_dataout AND nliii0i);
	wire_nlO010i_dataout <= wire_nlO01iO_dataout AND NOT(nli0lii);
	wire_nlO010l_dataout <= wire_nlO01li_dataout AND NOT(nli0lii);
	wire_nlO010O_dataout <= wire_nlO01ll_dataout AND NOT(nli0lii);
	wire_nlO011O_dataout <= wire_nlO01il_dataout AND NOT(nli0lii);
	wire_nlO01ii_dataout <= wire_nlO01lO_dataout AND NOT(nli0lii);
	wire_nlO01il_dataout <= wire_nlO01Oi_dataout AND NOT(nli0lil);
	wire_nlO01iO_dataout <= wire_nlO01Ol_dataout AND NOT(nli0lil);
	wire_nlO01li_dataout <= nlO1Oii WHEN nli0lil = '1'  ELSE wire_nlO01OO_dataout;
	wire_nlO01ll_dataout <= wire_nlO001i_dataout AND NOT(nli0lil);
	wire_nlO01lO_dataout <= nlO1Oii WHEN nli0lil = '1'  ELSE wire_nlO001l_dataout;
	wire_nlO01Oi_dataout <= wire_nlO000l_o(1) WHEN wire_nlO000O_o = '1'  ELSE wire_nlO001O_o(1);
	wire_nlO01Ol_dataout <= wire_nlO000l_o(2) WHEN wire_nlO000O_o = '1'  ELSE wire_nlO001O_o(2);
	wire_nlO01OO_dataout <= wire_nlO000l_o(3) WHEN wire_nlO000O_o = '1'  ELSE wire_nlO001O_o(3);
	wire_nlO0i_dataout <= nl11OO WHEN rwa_6g_en = '1'  ELSE n10iOl;
	wire_nlO0i0l_dataout <= nli0lOO AND (wire_nlOi10l_dataout AND nlO00Oi);
	wire_nlO0i1i_dataout <= nli0lOO AND (wire_nlOi10l_dataout AND nlO00ll);
	wire_nlO0i1O_dataout <= nli0lOO AND (wire_nlOi10l_dataout AND nlO00lO);
	wire_nlO0iiO_dataout <= nlii0OO AND (wire_nlOi10l_dataout AND ((wire_w_lg_rclkcmpsqmd1941w(0) AND nlillil) OR nlO00ii));
	wire_nlO0l_dataout <= nl101i WHEN rwa_6g_en = '1'  ELSE n10iOO;
	wire_nlO0l1O_dataout <= nlii0OO AND (wire_nlOi10l_dataout AND (nli0O1i OR wire_w_lg_nliii0i2234w(0)));
	wire_nlO0lOi_dataout <= audi_pre(0) WHEN dskwclksel(1) = '1'  ELSE sudi_pre(0);
	wire_nlO0lOl_dataout <= audi_pre(1) WHEN dskwclksel(1) = '1'  ELSE sudi_pre(1);
	wire_nlO0lOO_dataout <= audi_pre(2) WHEN dskwclksel(1) = '1'  ELSE sudi_pre(2);
	wire_nlO0O_dataout <= nl101l WHEN rwa_6g_en = '1'  ELSE n10l1i;
	wire_nlO0O0i_dataout <= audi_pre(6) WHEN dskwclksel(1) = '1'  ELSE sudi_pre(6);
	wire_nlO0O0l_dataout <= audi_pre(7) WHEN dskwclksel(1) = '1'  ELSE sudi_pre(7);
	wire_nlO0O0O_dataout <= audi_pre(8) WHEN dskwclksel(1) = '1'  ELSE sudi_pre(8);
	wire_nlO0O1i_dataout <= audi_pre(3) WHEN dskwclksel(1) = '1'  ELSE sudi_pre(3);
	wire_nlO0O1l_dataout <= audi_pre(4) WHEN dskwclksel(1) = '1'  ELSE sudi_pre(4);
	wire_nlO0O1O_dataout <= audi_pre(5) WHEN dskwclksel(1) = '1'  ELSE sudi_pre(5);
	wire_nlO0Oii_dataout <= audi_pre(9) WHEN dskwclksel(1) = '1'  ELSE sudi_pre(9);
	wire_nlO0Oil_dataout <= audi_pre(10) WHEN dskwclksel(1) = '1'  ELSE sudi_pre(10);
	wire_nlO0Oil_w_lg_w_lg_dataout2541w2543w(0) <= wire_nlO0Oil_w_lg_dataout2541w(0) AND wire_w_lg_rrx_pipe_enable2542w(0);
	wire_nlO0Oil_w_lg_dataout2541w(0) <= NOT wire_nlO0Oil_dataout;
	wire_nlO0OiO_dataout <= audi_pre(12) WHEN dskwclksel(1) = '1'  ELSE sudi_pre(12);
	wire_nlO0OiO_w_lg_w_lg_w_lg_dataout2540w2544w2545w(0) <= wire_nlO0OiO_w_lg_w_lg_dataout2540w2544w(0) AND nlO01O;
	wire_nlO0OiO_w_lg_w_lg_dataout2540w2544w(0) <= wire_nlO0OiO_w_lg_dataout2540w(0) AND wire_nlO0Oil_w_lg_w_lg_dataout2541w2543w(0);
	wire_nlO0OiO_w_lg_dataout2540w(0) <= NOT wire_nlO0OiO_dataout;
	wire_nlO0Oli_dataout <= audi(10) WHEN dskwclksel(1) = '1'  ELSE sudi(10);
	wire_nlO0Oli_w_lg_w_lg_dataout2226w2227w(0) <= wire_nlO0Oli_w_lg_dataout2226w(0) AND nlO00Ol;
	wire_nlO0Oli_w_lg_w_lg_dataout2226w2232w(0) <= wire_nlO0Oli_w_lg_dataout2226w(0) AND nlO011l;
	wire_nlO0Oli_w_lg_dataout2226w(0) <= NOT wire_nlO0Oli_dataout;
	wire_nlO0Oll_dataout <= audi(11) WHEN dskwclksel(1) = '1'  ELSE (sudi(11) AND inferred_rxvalid);
	wire_nlO0OlO_dataout <= audi(12) WHEN dskwclksel(1) = '1'  ELSE sudi(12);
	wire_nlO0OlO_w_lg_dataout2225w(0) <= NOT wire_nlO0OlO_dataout;
	wire_nlO100i_dataout <= wire_nlO10iO_o(0) AND NOT(nli0l1l);
	wire_nlO100l_dataout <= wire_nlO10iO_o(1) AND NOT(nli0l1l);
	wire_nlO100O_dataout <= wire_nlO10iO_o(2) AND NOT(nli0l1l);
	wire_nlO10i_dataout <= wire_n1ll_dataout AND NOT(wire_nl00O_w_lg_dataout123w(0));
	wire_nlO10ii_dataout <= wire_nlO10iO_o(3) AND NOT(nli0l1l);
	wire_nlO10il_dataout <= wire_nlO10iO_o(4) AND NOT(nli0l1l);
	wire_nlO10l_dataout <= wire_nlO1ii_dataout AND NOT(wire_nl00O_w_lg_dataout123w(0));
	wire_nlO10O_dataout <= wire_nlO1il_dataout AND NOT(wire_nl00O_w_lg_dataout123w(0));
	wire_nlO110i_dataout <= nllO10i WHEN nli0iOO = '1'  ELSE nllO11O;
	wire_nlO110l_dataout <= nllO10l WHEN nli0iOO = '1'  ELSE nllO10i;
	wire_nlO110O_dataout <= nllO10O WHEN nli0iOO = '1'  ELSE nllO10l;
	wire_nlO111i_dataout <= nllO11i WHEN nli0iOO = '1'  ELSE nlllOOO;
	wire_nlO111l_dataout <= nllO11l WHEN nli0iOO = '1'  ELSE nllO11i;
	wire_nlO111O_dataout <= nllO11O WHEN nli0iOO = '1'  ELSE nllO11l;
	wire_nlO11ii_dataout <= nllO1ii WHEN nli0iOO = '1'  ELSE nllO10O;
	wire_nlO11il_dataout <= nllO1il WHEN nli0iOO = '1'  ELSE nllO1ii;
	wire_nlO11iO_dataout <= nllO1iO WHEN nli0iOO = '1'  ELSE nllO1il;
	wire_nlO11li_dataout <= nlllO0l WHEN nli0iOO = '1'  ELSE nllO1iO;
	wire_nlO11ll_dataout <= wire_nlO101i_o(1) OR nli0iOl;
	wire_nlO11lO_dataout <= wire_nlO101i_o(2) OR nli0iOl;
	wire_nlO11Oi_dataout <= wire_nlO101i_o(3) AND NOT(nli0iOl);
	wire_nlO11Ol_dataout <= wire_nlO101i_o(4) AND NOT(nli0iOl);
	wire_nlO11OO_dataout <= wire_nlO101i_o(5) OR nli0iOl;
	wire_nlO1i_dataout <= nl11ll WHEN rwa_6g_en = '1'  ELSE n10ill;
	wire_nlO1i0i_dataout <= nlli10l AND NOT(nli0lii);
	wire_nlO1i0l_dataout <= nlli10i AND NOT(nli0lii);
	wire_nlO1i1i_dataout <= nlO10OO AND NOT(nli0lii);
	wire_nlO1i1l_dataout <= nlO10Ol AND NOT(nli0lii);
	wire_nlO1i1O_dataout <= nlli10O AND NOT(nli0lii);
	wire_nlO1ii_dataout <= nllOOi AND NOT(wire_n1ll_dataout);
	wire_nlO1iii_dataout <= n11O0O AND NOT(nli0lii);
	wire_nlO1iil_dataout <= n101Ol AND NOT(nli0lii);
	wire_nlO1iiO_dataout <= n101OO AND NOT(nli0lii);
	wire_nlO1il_dataout <= nlO01O AND NOT(wire_n1ll_dataout);
	wire_nlO1ili_dataout <= n1001i AND NOT(nli0lii);
	wire_nlO1ill_dataout <= n1001l AND NOT(nli0lii);
	wire_nlO1iO_dataout <= nlO01O WHEN wire_nl00O_w_lg_dataout123w(0) = '1'  ELSE wire_nlO1lO_dataout;
	wire_nlO1l_dataout <= nl11lO WHEN rwa_6g_en = '1'  ELSE n10ilO;
	wire_nlO1li_dataout <= nllOOi WHEN wire_nl00O_w_lg_dataout123w(0) = '1'  ELSE wire_nlO1Oi_dataout;
	wire_nlO1ll_dataout <= wire_w_lg_nlill0O122w(0) AND NOT(wire_nl00O_w_lg_dataout123w(0));
	wire_nlO1lO_dataout <= wire_n1iO_dataout WHEN nlill0O = '1'  ELSE nlO01O;
	wire_nlO1O_dataout <= nl11Ol WHEN rwa_6g_en = '1'  ELSE n10iOi;
	wire_nlO1Oi_dataout <= wire_n1li_dataout WHEN nlill0O = '1'  ELSE nllOOi;
	wire_nlO1Oil_dataout <= nlillOi AND wire_nlOi10l_dataout;
	wire_nlO1Oli_dataout <= wire_nlO1Oll_dataout AND wire_nlOi10l_dataout;
	wire_nlO1Oll_dataout <= nlO1Oii OR (wire_nii_w_lg_nlO1Oii2347w(0) AND nli0l0O);
	wire_nlO1OO_dataout <= wire_n1il_dataout AND wire_nl00O_dataout;
	wire_nlOi00i_dataout <= nlOliil WHEN nli0Oli = '1'  ELSE wire_nlOii0l_dataout;
	wire_nlOi00l_dataout <= nlOliiO WHEN nli0Oli = '1'  ELSE wire_nlOii0O_dataout;
	wire_nlOi00O_dataout <= nlOlili WHEN nli0Oli = '1'  ELSE wire_nlOiiii_dataout;
	wire_nlOi01i_dataout <= nlOli0l WHEN nli0Oli = '1'  ELSE wire_nlOii1l_dataout;
	wire_nlOi01l_dataout <= nlOli0O WHEN nli0Oli = '1'  ELSE wire_nlOii1O_dataout;
	wire_nlOi01O_dataout <= nlOliii WHEN nli0Oli = '1'  ELSE wire_nlOii0i_dataout;
	wire_nlOi0ii_dataout <= nlOlill WHEN nli0Oli = '1'  ELSE wire_nlOiiil_dataout;
	wire_nlOi0il_dataout <= nlOlilO WHEN nli0Oli = '1'  ELSE wire_nlOiiiO_dataout;
	wire_nlOi0iO_dataout <= nlOliOl WHEN nli0Oli = '1'  ELSE wire_nlOiili_dataout;
	wire_nlOi0li_dataout <= wire_nlOiill_dataout AND NOT(nli0Oli);
	wire_nlOi0ll_dataout <= wire_nlOiilO_dataout OR nli0Oli;
	wire_nlOi0lO_dataout <= nlOl0OO WHEN nli0O0l = '1'  ELSE wire_nlOiiOi_dataout;
	wire_nlOi0Oi_dataout <= nlOli1i WHEN nli0O0l = '1'  ELSE wire_nlOiiOl_dataout;
	wire_nlOi0Ol_dataout <= nlOli1l WHEN nli0O0l = '1'  ELSE wire_nlOiiOO_dataout;
	wire_nlOi0OO_dataout <= nlOli1O WHEN nli0O0l = '1'  ELSE wire_nlOil1i_dataout;
	wire_nlOi10i_dataout <= nlOiO0O WHEN dskwclksel(1) = '1'  ELSE nlOiO0i;
	wire_nlOi10l_dataout <= wire_nlOi10O_dataout AND NOT(nli0O0i);
	wire_nlOi10l_w_lg_dataout2551w(0) <= NOT wire_nlOi10l_dataout;
	wire_nlOi10O_dataout <= align_status WHEN dskwclksel(1) = '1'  ELSE sync_status;
	wire_nlOi11i_dataout <= wire_nlOi11l_dataout AND NOT(nli0O0i);
	wire_nlOi11i_w_lg_dataout1990w(0) <= NOT wire_nlOi11i_dataout;
	wire_nlOi11l_dataout <= align_status_sync_0 WHEN nlii1ii = '1'  ELSE wire_nlOi11O_dataout;
	wire_nlOi11O_dataout <= align_status_sync_2 WHEN nlii10O = '1'  ELSE wire_nlOi10i_dataout;
	wire_nlOi1il_dataout <= n10O1O WHEN nli0O0l = '1'  ELSE wire_nlOi10O_dataout;
	wire_nlOi1li_dataout <= nli0Oli AND wire_nlOi11i_dataout;
	wire_nlOi1ll_dataout <= nlOl0OO WHEN nli0Oli = '1'  ELSE wire_nlOi0lO_dataout;
	wire_nlOi1lO_dataout <= nlOli1i WHEN nli0Oli = '1'  ELSE wire_nlOi0Oi_dataout;
	wire_nlOi1Oi_dataout <= nlOli1l WHEN nli0Oli = '1'  ELSE wire_nlOi0Ol_dataout;
	wire_nlOi1Ol_dataout <= nlOli1O WHEN nli0Oli = '1'  ELSE wire_nlOi0OO_dataout;
	wire_nlOi1OO_dataout <= nlOli0i WHEN nli0Oli = '1'  ELSE wire_nlOii1i_dataout;
	wire_nlOii_dataout <= nl101O WHEN rwa_6g_en = '1'  ELSE n10l1l;
	wire_nlOii0i_dataout <= nlOliii WHEN nli0O0l = '1'  ELSE wire_nlOil0l_dataout;
	wire_nlOii0l_dataout <= nlOliil WHEN nli0O0l = '1'  ELSE wire_nlOil0O_dataout;
	wire_nlOii0O_dataout <= nlOliiO WHEN nli0O0l = '1'  ELSE wire_nlOilii_dataout;
	wire_nlOii1i_dataout <= nlOli0i WHEN nli0O0l = '1'  ELSE wire_nlOil1l_dataout;
	wire_nlOii1l_dataout <= nlOli0l WHEN nli0O0l = '1'  ELSE wire_nlOil1O_dataout;
	wire_nlOii1O_dataout <= nlOli0O WHEN nli0O0l = '1'  ELSE wire_nlOil0i_dataout;
	wire_nlOiiii_dataout <= nlOlili WHEN nli0O0l = '1'  ELSE wire_nlO0Oli_dataout;
	wire_nlOiiil_dataout <= nlOlill WHEN nli0O0l = '1'  ELSE wire_nlOilil_dataout;
	wire_nlOiiiO_dataout <= nlOlilO WHEN nli0O0l = '1'  ELSE wire_nlO0OlO_dataout;
	wire_nlOiili_dataout <= nlOliOl WHEN nli0O0l = '1'  ELSE wire_nlOiliO_dataout;
	wire_nlOiill_dataout <= nlOliOO AND nli0O0l;
	wire_nlOiilO_dataout <= nlOll1i AND nli0O0l;
	wire_nlOiiOi_dataout <= audi(0) WHEN dskwclksel(1) = '1'  ELSE sudi(0);
	wire_nlOiiOl_dataout <= audi(1) WHEN dskwclksel(1) = '1'  ELSE sudi(1);
	wire_nlOiiOO_dataout <= audi(2) WHEN dskwclksel(1) = '1'  ELSE sudi(2);
	wire_nlOil_dataout <= nl100i WHEN rwa_6g_en = '1'  ELSE n10l1O;
	wire_nlOil0i_dataout <= audi(6) WHEN dskwclksel(1) = '1'  ELSE sudi(6);
	wire_nlOil0l_dataout <= audi(7) WHEN dskwclksel(1) = '1'  ELSE sudi(7);
	wire_nlOil0O_dataout <= audi(8) WHEN dskwclksel(1) = '1'  ELSE sudi(8);
	wire_nlOil1i_dataout <= audi(3) WHEN dskwclksel(1) = '1'  ELSE sudi(3);
	wire_nlOil1l_dataout <= audi(4) WHEN dskwclksel(1) = '1'  ELSE sudi(4);
	wire_nlOil1O_dataout <= audi(5) WHEN dskwclksel(1) = '1'  ELSE sudi(5);
	wire_nlOilii_dataout <= audi(9) WHEN dskwclksel(1) = '1'  ELSE sudi(9);
	wire_nlOilil_dataout <= audi(11) WHEN dskwclksel(1) = '1'  ELSE sudi(11);
	wire_nlOiliO_dataout <= audi(13) WHEN dskwclksel(1) = '1'  ELSE sudi(13);
	wire_nlOiO_dataout <= nl100l WHEN rwa_6g_en = '1'  ELSE n10l0i;
	wire_nlOli_dataout <= nl100O WHEN rwa_6g_en = '1'  ELSE n10l0l;
	wire_nlOll_dataout <= nl10ii WHEN rwa_6g_en = '1'  ELSE n10l0O;
	wire_nlOll0i_dataout <= wire_nlOliOi_w_lg_nlOliOl2139w(0) WHEN nlii1Oi = '1'  ELSE wire_nlOO0iO_dataout;
	wire_nlOll0l_dataout <= wire_nlOliOi_w_lg_nlOliOl2139w(0) WHEN nlii1Oi = '1'  ELSE wire_nlOO0li_dataout;
	wire_nlOll0O_dataout <= wire_n1100l_dataout WHEN nlii1Oi = '1'  ELSE wire_nlOO0ll_dataout;
	wire_nlOll1O_dataout <= wire_n1100i_dataout WHEN nlii1Oi = '1'  ELSE wire_nlOO0il_dataout;
	wire_nlOllii_dataout <= wire_nlOliOi_w_lg_nlOliOl2139w(0) WHEN nlii1Oi = '1'  ELSE wire_nlOO0lO_dataout;
	wire_nlOllil_dataout <= nlOliOl WHEN nlii1Oi = '1'  ELSE wire_nlOO0Oi_dataout;
	wire_nlOlliO_dataout <= wire_nlOliOi_w_lg_nlOliOl2139w(0) WHEN nlii1Oi = '1'  ELSE wire_nlOO0Ol_dataout;
	wire_nlOllli_dataout <= nlOliOl WHEN nlii1Oi = '1'  ELSE wire_nlOO0OO_dataout;
	wire_nlOllll_dataout <= nlOliOl WHEN nlii1Oi = '1'  ELSE wire_nlOOi1i_dataout;
	wire_nlOlllO_dataout <= nlOliOl WHEN nlii1Oi = '1'  ELSE wire_nlOOi1l_dataout;
	wire_nlOllOi_dataout <= wire_nlOOi1O_dataout AND NOT(nlii1Oi);
	wire_nlOllOl_dataout <= wire_nlOOi0l_dataout AND NOT(nlii1Oi);
	wire_nlOllOO_dataout <= wire_nlOOiii_dataout AND NOT(nlii1Oi);
	wire_nlOlO_dataout <= nl10il WHEN rwa_6g_en = '1'  ELSE n10lii;
	wire_nlOlO0i_dataout <= wire_nllOll_data_out2(2) WHEN nli0Oil = '1'  ELSE nlOl00l;
	wire_nlOlO0l_dataout <= wire_nllOll_data_out2(3) WHEN nli0Oil = '1'  ELSE nlOl00O;
	wire_nlOlO0O_dataout <= wire_nllOll_data_out2(4) WHEN nli0Oil = '1'  ELSE nlOl0ii;
	wire_nlOlO1i_dataout <= wire_nlOOiil_dataout OR nlii1Oi;
	wire_nlOlO1l_dataout <= wire_nllOll_data_out2(0) WHEN nli0Oil = '1'  ELSE nlOl01O;
	wire_nlOlO1O_dataout <= wire_nllOll_data_out2(1) WHEN nli0Oil = '1'  ELSE nlOl00i;
	wire_nlOlOii_dataout <= wire_nllOll_data_out2(5) WHEN nli0Oil = '1'  ELSE nlOl0il;
	wire_nlOlOil_dataout <= wire_nllOll_data_out2(6) WHEN nli0Oil = '1'  ELSE nlOl0iO;
	wire_nlOlOiO_dataout <= wire_nllOll_data_out2(7) WHEN nli0Oil = '1'  ELSE nlOl0li;
	wire_nlOlOli_dataout <= wire_nllOll_data_out2(8) WHEN nli0Oil = '1'  ELSE nlOl0ll;
	wire_nlOlOll_dataout <= wire_nllOll_data_out2(9) WHEN nli0Oil = '1'  ELSE nlOl0lO;
	wire_nlOlOlO_dataout <= wire_nllOll_data_out2(11) WHEN nli0Oil = '1'  ELSE nlOl0Oi;
	wire_nlOlOOi_dataout <= wire_nllOll_data_out2(13) WHEN nli0Oil = '1'  ELSE nlOl0Ol;
	wire_nlOlOOl_dataout <= nlOl10O WHEN nli0Oil = '1'  ELSE nlOiOil;
	wire_nlOlOOO_dataout <= nlOl1ii WHEN nli0Oil = '1'  ELSE nlOiOli;
	wire_nlOO00i_dataout <= nlOl0ll WHEN nli0Oil = '1'  ELSE nlOl1Ol;
	wire_nlOO00l_dataout <= nlOl0lO WHEN nli0Oil = '1'  ELSE nlOl1OO;
	wire_nlOO00O_dataout <= nlOl0Oi WHEN nli0Oil = '1'  ELSE nlOl01i;
	wire_nlOO01i_dataout <= nlOl0il WHEN nli0Oil = '1'  ELSE nlOl1ll;
	wire_nlOO01l_dataout <= nlOl0iO WHEN nli0Oil = '1'  ELSE nlOl1lO;
	wire_nlOO01O_dataout <= nlOl0li WHEN nli0Oil = '1'  ELSE nlOl1Oi;
	wire_nlOO0ii_dataout <= nlOl0Ol WHEN nli0Oil = '1'  ELSE nlOl01l;
	wire_nlOO0il_dataout <= wire_nllOll_data_out1(0) WHEN nli0Oil = '1'  ELSE wire_nlOOiiO_dataout;
	wire_nlOO0iO_dataout <= wire_nllOll_data_out1(1) WHEN nli0Oil = '1'  ELSE wire_nlOOili_dataout;
	wire_nlOO0li_dataout <= wire_nllOll_data_out1(2) WHEN nli0Oil = '1'  ELSE wire_nlOOill_dataout;
	wire_nlOO0ll_dataout <= wire_nllOll_data_out1(3) WHEN nli0Oil = '1'  ELSE wire_nlOOilO_dataout;
	wire_nlOO0lO_dataout <= wire_nllOll_data_out1(4) WHEN nli0Oil = '1'  ELSE wire_nlOOiOi_dataout;
	wire_nlOO0Oi_dataout <= wire_nllOll_data_out1(5) WHEN nli0Oil = '1'  ELSE wire_nlOOiOl_dataout;
	wire_nlOO0Ol_dataout <= wire_nllOll_data_out1(6) WHEN nli0Oil = '1'  ELSE wire_nlOOiOO_dataout;
	wire_nlOO0OO_dataout <= wire_nllOll_data_out1(7) WHEN nli0Oil = '1'  ELSE wire_nlOOl1i_dataout;
	wire_nlOO10i_dataout <= nlOl1ll WHEN nli0Oil = '1'  ELSE nlOiOOl;
	wire_nlOO10l_dataout <= nlOl1lO WHEN nli0Oil = '1'  ELSE nlOiOOO;
	wire_nlOO10O_dataout <= nlOl1Oi WHEN nli0Oil = '1'  ELSE nlOl11i;
	wire_nlOO11i_dataout <= nlOl1il WHEN nli0Oil = '1'  ELSE nlOiOll;
	wire_nlOO11l_dataout <= nlOl1iO WHEN nli0Oil = '1'  ELSE nlOiOlO;
	wire_nlOO11O_dataout <= nlOl1li WHEN nli0Oil = '1'  ELSE nlOiOOi;
	wire_nlOO1ii_dataout <= nlOl1Ol WHEN nli0Oil = '1'  ELSE nlOl11l;
	wire_nlOO1il_dataout <= nlOl1OO WHEN nli0Oil = '1'  ELSE nlOl11O;
	wire_nlOO1iO_dataout <= nlOl01i WHEN nli0Oil = '1'  ELSE nlOl10i;
	wire_nlOO1li_dataout <= nlOl01l WHEN nli0Oil = '1'  ELSE nlOl10l;
	wire_nlOO1ll_dataout <= nlOl01O WHEN nli0Oil = '1'  ELSE nlOl10O;
	wire_nlOO1lO_dataout <= nlOl00i WHEN nli0Oil = '1'  ELSE nlOl1ii;
	wire_nlOO1Oi_dataout <= nlOl00l WHEN nli0Oil = '1'  ELSE nlOl1il;
	wire_nlOO1Ol_dataout <= nlOl00O WHEN nli0Oil = '1'  ELSE nlOl1iO;
	wire_nlOO1OO_dataout <= nlOl0ii WHEN nli0Oil = '1'  ELSE nlOl1li;
	wire_nlOOi_dataout <= nl10iO WHEN rwa_6g_en = '1'  ELSE n10lil;
	wire_nlOOi0i_dataout <= wire_nllOll_data_out1(11) WHEN nli0Oil = '1'  ELSE wire_nlOOl0l_dataout;
	wire_nlOOi0l_dataout <= wire_nllOll_data_out1(12) WHEN nli0Oil = '1'  ELSE wire_nlOOl0O_dataout;
	wire_nlOOi0O_dataout <= wire_nllOll_data_out1(13) WHEN nli0Oil = '1'  ELSE wire_nlOOlii_dataout;
	wire_nlOOi1i_dataout <= wire_nllOll_data_out1(8) WHEN nli0Oil = '1'  ELSE wire_nlOOl1l_dataout;
	wire_nlOOi1l_dataout <= wire_nllOll_data_out1(9) WHEN nli0Oil = '1'  ELSE wire_nlOOl1O_dataout;
	wire_nlOOi1O_dataout <= wire_nllOll_data_out1(10) WHEN nli0Oil = '1'  ELSE wire_nlOOl0i_dataout;
	wire_nlOOiii_dataout <= wire_nllOll_data_out1(14) WHEN nli0Oil = '1'  ELSE wire_nlOOlil_dataout;
	wire_nlOOiil_dataout <= wire_nllOll_data_out1(15) WHEN nli0Oil = '1'  ELSE wire_nlOOliO_dataout;
	wire_nlOOiiO_dataout <= wire_nlOOlOO_dataout WHEN rclkcmpsqmd = '1'  ELSE nlOl0OO;
	wire_nlOOili_dataout <= wire_nlOOO1i_dataout WHEN rclkcmpsqmd = '1'  ELSE nlOli1i;
	wire_nlOOill_dataout <= wire_nlOOO1l_dataout WHEN rclkcmpsqmd = '1'  ELSE nlOli1l;
	wire_nlOOilO_dataout <= wire_nlOOO1O_dataout WHEN rclkcmpsqmd = '1'  ELSE nlOli1O;
	wire_nlOOiOi_dataout <= wire_nlOOO0i_dataout WHEN rclkcmpsqmd = '1'  ELSE nlOli0i;
	wire_nlOOiOl_dataout <= wire_nlOOO0l_dataout WHEN rclkcmpsqmd = '1'  ELSE nlOli0l;
	wire_nlOOiOO_dataout <= wire_nlOOO0O_dataout WHEN rclkcmpsqmd = '1'  ELSE nlOli0O;
	wire_nlOOl_dataout <= nl10li WHEN rwa_6g_en = '1'  ELSE n10liO;
	wire_nlOOl0i_dataout <= wire_nlOOOli_dataout WHEN rclkcmpsqmd = '1'  ELSE wire_nlOOlli_dataout;
	wire_nlOOl0l_dataout <= wire_nlOOOll_dataout WHEN rclkcmpsqmd = '1'  ELSE nlOlill;
	wire_nlOOl0O_dataout <= wire_nlOOOlO_dataout WHEN rclkcmpsqmd = '1'  ELSE wire_nlOOlll_dataout;
	wire_nlOOl1i_dataout <= wire_nlOOOii_dataout WHEN rclkcmpsqmd = '1'  ELSE nlOliii;
	wire_nlOOl1l_dataout <= wire_nlOOOil_dataout WHEN rclkcmpsqmd = '1'  ELSE nlOliil;
	wire_nlOOl1O_dataout <= wire_nlOOOiO_dataout WHEN rclkcmpsqmd = '1'  ELSE nlOliiO;
	wire_nlOOlii_dataout <= wire_nlOOOOi_dataout WHEN rclkcmpsqmd = '1'  ELSE nlOliOl;
	wire_nlOOlil_dataout <= wire_nlOOOOl_dataout AND rclkcmpsqmd;
	wire_nlOOliO_dataout <= wire_nlOOOOO_dataout WHEN rclkcmpsqmd = '1'  ELSE wire_w_lg_rrx_pipe_enable1940w(0);
	wire_nlOOlli_dataout <= wire_nlOOllO_dataout AND NOT(rrx_pipe_enable);
	wire_nlOOlll_dataout <= wire_nlOOlOi_dataout AND NOT(rrx_pipe_enable);
	wire_nlOOllO_dataout <= nlOlili AND nli0Oii;
	wire_nlOOlOi_dataout <= nlOlilO AND nli0Oii;
	wire_nlOOlOO_dataout <= nlOl10O WHEN n11O1l = '1'  ELSE wire_n1111i_dataout;
	wire_nlOOO_dataout <= nl10ll WHEN rwa_6g_en = '1'  ELSE n10lli;
	wire_nlOOO0i_dataout <= nlOl1li WHEN n11O1l = '1'  ELSE wire_n1110l_dataout;
	wire_nlOOO0l_dataout <= nlOl1ll WHEN n11O1l = '1'  ELSE wire_n1110O_dataout;
	wire_nlOOO0O_dataout <= nlOl1lO WHEN n11O1l = '1'  ELSE wire_n111ii_dataout;
	wire_nlOOO1i_dataout <= nlOl1ii WHEN n11O1l = '1'  ELSE wire_n1111l_dataout;
	wire_nlOOO1l_dataout <= nlOl1il WHEN n11O1l = '1'  ELSE wire_n1111O_dataout;
	wire_nlOOO1O_dataout <= nlOl1iO WHEN n11O1l = '1'  ELSE wire_n1110i_dataout;
	wire_nlOOOii_dataout <= nlOl1Oi WHEN n11O1l = '1'  ELSE wire_n111il_dataout;
	wire_nlOOOil_dataout <= nlOl1Ol WHEN n11O1l = '1'  ELSE wire_n111iO_dataout;
	wire_nlOOOiO_dataout <= nlOl1OO WHEN n11O1l = '1'  ELSE wire_n111li_dataout;
	wire_nlOOOli_dataout <= wire_n111ll_dataout AND NOT(n11O1l);
	wire_nlOOOll_dataout <= nlOl01i WHEN n11O1l = '1'  ELSE wire_n111lO_dataout;
	wire_nlOOOlO_dataout <= wire_n111Oi_dataout AND NOT(n11O1l);
	wire_nlOOOOi_dataout <= nlOl01l WHEN n11O1l = '1'  ELSE wire_n111Ol_dataout;
	wire_nlOOOOl_dataout <= wire_n111OO_dataout AND NOT(n11O1l);
	wire_nlOOOOO_dataout <= wire_n1101i_dataout OR n11O1l;
	wire_n0O0li_a <= ( n0l0il & n0l0ii & n0l00O & n0l00l & n0O0ll);
	wire_n0O0li_b <= ( "0" & "0" & "0" & "0" & "1");
	n0O0li :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_n0O0li_a,
		b => wire_n0O0li_b,
		cin => wire_gnd,
		o => wire_n0O0li_o
	  );
	wire_n0OOOO_w_lg_w_o_range1678w1682w(0) <= wire_n0OOOO_w_o_range1678w(0) AND wire_n0OOOO_w_lg_w_lg_w_o_range1679w1680w1681w(0);
	wire_n0OOOO_w_lg_w_lg_w_o_range1679w1680w1681w(0) <= NOT wire_n0OOOO_w_lg_w_o_range1679w1680w(0);
	wire_n0OOOO_w_lg_w_o_range1679w1680w(0) <= wire_n0OOOO_w_o_range1679w(0) XOR n0OOll;
	wire_n0OOOO_a <= ( "0" & rfull_threshold(4 DOWNTO 0) & "1");
	wire_n0OOOO_b <= ( "0" & "1" & "1" & "1" & "1" & "0" & "1");
	wire_n0OOOO_w_o_range1679w(0) <= wire_n0OOOO_o(1);
	wire_n0OOOO_w_o_range1678w(0) <= wire_n0OOOO_o(6);
	n0OOOO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 7,
		width_b => 7,
		width_o => 7
	  )
	  PORT MAP ( 
		a => wire_n0OOOO_a,
		b => wire_n0OOOO_b,
		cin => wire_gnd,
		o => wire_n0OOOO_o
	  );
	wire_n1010i_a <= ( n11O0l & n11O0i & n11O1O);
	wire_n1010i_b <= ( "0" & "0" & "1");
	n1010i :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 3,
		width_b => 3,
		width_o => 3
	  )
	  PORT MAP ( 
		a => wire_n1010i_a,
		b => wire_n1010i_b,
		cin => wire_gnd,
		o => wire_n1010i_o
	  );
	wire_n1l0lO_a <= ( n100ii & n1000O & n1000l & n1000i & n1001O);
	wire_n1l0lO_b <= ( "0" & "0" & "0" & "0" & "1");
	n1l0lO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_n1l0lO_a,
		b => wire_n1l0lO_b,
		cin => wire_gnd,
		o => wire_n1l0lO_o
	  );
	wire_n1O1OO_w_lg_w_o_range3053w3057w(0) <= wire_n1O1OO_w_o_range3053w(0) AND wire_n1O1OO_w_lg_w_lg_w_o_range3054w3055w3056w(0);
	wire_n1O1OO_w_lg_w_lg_w_o_range3054w3055w3056w(0) <= NOT wire_n1O1OO_w_lg_w_o_range3054w3055w(0);
	wire_n1O1OO_w_lg_w_o_range3054w3055w(0) <= wire_n1O1OO_w_o_range3054w(0) XOR nlii00l;
	wire_n1O1OO_a <= ( "0" & rins_threshold(4 DOWNTO 0) & "1");
	wire_n1O1OO_b <= ( "0" & "1" & "1" & "1" & "1" & "0" & "1");
	wire_n1O1OO_w_o_range3054w(0) <= wire_n1O1OO_o(1);
	wire_n1O1OO_w_o_range3053w(0) <= wire_n1O1OO_o(6);
	n1O1OO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 7,
		width_b => 7,
		width_o => 7
	  )
	  PORT MAP ( 
		a => wire_n1O1OO_a,
		b => wire_n1O1OO_b,
		cin => wire_gnd,
		o => wire_n1O1OO_o
	  );
	wire_ni01ii_a <= ( ni1O0l & ni1O0i & ni1O1O & ni1O1l & ni1llO & "1");
	wire_ni01ii_b <= ( "1" & "1" & "1" & "1" & "0" & "1");
	ni01ii :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 6,
		width_b => 6,
		width_o => 6
	  )
	  PORT MAP ( 
		a => wire_ni01ii_a,
		b => wire_ni01ii_b,
		cin => wire_gnd,
		o => wire_ni01ii_o
	  );
	wire_ni01il_a <= ( ni1O0l & ni1O0i & ni1O1O & ni1O1l & ni1llO);
	wire_ni01il_b <= ( "0" & "0" & "0" & "0" & "1");
	ni01il :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_ni01il_a,
		b => wire_ni01il_b,
		cin => wire_gnd,
		o => wire_ni01il_o
	  );
	wire_ni1lii_a <= ( wire_ni1lil_w_lg_w_o_range881w882w & wire_ni1lil_w_lg_w_o_range878w879w & wire_ni1lil_w_lg_w_o_range875w876w & wire_ni1lil_w_lg_w_o_range872w873w & wire_ni1lil_w_lg_w_o_range869w870w & "1");
	wire_ni1lii_b <= ( "1" & "0" & "1" & "0" & "0" & "1");
	ni1lii :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 6,
		width_b => 6,
		width_o => 6
	  )
	  PORT MAP ( 
		a => wire_ni1lii_a,
		b => wire_ni1lii_b,
		cin => wire_gnd,
		o => wire_ni1lii_o
	  );
	wire_ni1lil_w_lg_w_o_range869w870w(0) <= NOT wire_ni1lil_w_o_range869w(0);
	wire_ni1lil_w_lg_w_o_range872w873w(0) <= NOT wire_ni1lil_w_o_range872w(0);
	wire_ni1lil_w_lg_w_o_range875w876w(0) <= NOT wire_ni1lil_w_o_range875w(0);
	wire_ni1lil_w_lg_w_o_range878w879w(0) <= NOT wire_ni1lil_w_o_range878w(0);
	wire_ni1lil_w_lg_w_o_range881w882w(0) <= NOT wire_ni1lil_w_o_range881w(0);
	wire_ni1lil_a <= ( n0O0OO & nliil0O & nliilii & nliilil & nliiliO & "1");
	wire_ni1lil_b <= ( wire_nii_w_lg_n0l0il864w & wire_nii_w_lg_n0l0ii862w & wire_nii_w_lg_n0l00O860w & wire_nii_w_lg_n0l00l858w & wire_nii_w_lg_n0O0ll856w & "1");
	wire_ni1lil_w_o_range869w(0) <= wire_ni1lil_o(1);
	wire_ni1lil_w_o_range872w(0) <= wire_ni1lil_o(2);
	wire_ni1lil_w_o_range875w(0) <= wire_ni1lil_o(3);
	wire_ni1lil_w_o_range878w(0) <= wire_ni1lil_o(4);
	wire_ni1lil_w_o_range881w(0) <= wire_ni1lil_o(5);
	ni1lil :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 6,
		width_b => 6,
		width_o => 6
	  )
	  PORT MAP ( 
		a => wire_ni1lil_a,
		b => wire_ni1lil_b,
		cin => wire_gnd,
		o => wire_ni1lil_o
	  );
	wire_ni1liO_a <= ( n0l0il & n0l0ii & n0l00O & n0l00l & n0O0ll & "1");
	wire_ni1liO_b <= ( wire_nii_w_lg_n0O0OO843w & wire_w_lg_nliil0O841w & wire_w_lg_nliilii839w & wire_w_lg_nliilil837w & wire_w_lg_nliiliO835w & "1");
	ni1liO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 6,
		width_b => 6,
		width_o => 6
	  )
	  PORT MAP ( 
		a => wire_ni1liO_a,
		b => wire_ni1liO_b,
		cin => wire_gnd,
		o => wire_ni1liO_o
	  );
	wire_nl0OOi_a <= ( niOOii & niOO0O & niOO0l & niOO0i & niOO1O);
	wire_nl0OOi_b <= ( "0" & "0" & "0" & "0" & "1");
	nl0OOi :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_nl0OOi_a,
		b => wire_nl0OOi_b,
		cin => wire_gnd,
		o => wire_nl0OOi_o
	  );
	wire_nli1iO_w_lg_w_o_range1314w1318w(0) <= wire_nli1iO_w_o_range1314w(0) AND wire_nli1iO_w_lg_w_lg_w_o_range1315w1316w1317w(0);
	wire_nli1iO_w_lg_w_lg_w_o_range1315w1316w1317w(0) <= NOT wire_nli1iO_w_lg_w_o_range1315w1316w(0);
	wire_nli1iO_w_lg_w_o_range1315w1316w(0) <= wire_nli1iO_w_o_range1315w(0) XOR nlil01i;
	wire_nli1iO_a <= ( "0" & rins_threshold(4 DOWNTO 0) & "1");
	wire_nli1iO_b <= ( "0" & "1" & "1" & "1" & "1" & "0" & "1");
	wire_nli1iO_w_o_range1315w(0) <= wire_nli1iO_o(1);
	wire_nli1iO_w_o_range1314w(0) <= wire_nli1iO_o(6);
	nli1iO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 7,
		width_b => 7,
		width_o => 7
	  )
	  PORT MAP ( 
		a => wire_nli1iO_a,
		b => wire_nli1iO_b,
		cin => wire_gnd,
		o => wire_nli1iO_o
	  );
	wire_nllliii_a <= ( nlll1iO & nlll1il & nlll1ii & nlll10O & nlll10l & "1");
	wire_nllliii_b <= ( "1" & "1" & "1" & "1" & "0" & "1");
	nllliii :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 6,
		width_b => 6,
		width_o => 6
	  )
	  PORT MAP ( 
		a => wire_nllliii_a,
		b => wire_nllliii_b,
		cin => wire_gnd,
		o => wire_nllliii_o
	  );
	wire_nllliil_a <= ( nlll1iO & nlll1il & nlll1ii & nlll10O & nlll10l);
	wire_nllliil_b <= ( "0" & "0" & "0" & "0" & "1");
	nllliil :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_nllliil_a,
		b => wire_nllliil_b,
		cin => wire_gnd,
		o => wire_nllliil_o
	  );
	wire_nllliOl_a <= ( nlll1iO & nlll1il & nlll1ii & nlll10O);
	wire_nllliOl_b <= ( "0" & "0" & "0" & "1");
	nllliOl :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 4,
		width_b => 4,
		width_o => 4
	  )
	  PORT MAP ( 
		a => wire_nllliOl_a,
		b => wire_nllliOl_b,
		cin => wire_gnd,
		o => wire_nllliOl_o
	  );
	wire_nllll1i_a <= ( nlll1iO & nlll1il & nlll1ii & nlll10O & nlll10l);
	wire_nllll1i_b <= ( "0" & "0" & "0" & "1" & "1");
	nllll1i :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_nllll1i_a,
		b => wire_nllll1i_b,
		cin => wire_gnd,
		o => wire_nllll1i_o
	  );
	wire_nlO000i_w_lg_w_o_range2309w2310w(0) <= NOT wire_nlO000i_w_o_range2309w(0);
	wire_nlO000i_w_lg_w_o_range2312w2313w(0) <= NOT wire_nlO000i_w_o_range2312w(0);
	wire_nlO000i_w_lg_w_o_range2315w2316w(0) <= NOT wire_nlO000i_w_o_range2315w(0);
	wire_nlO000i_w_lg_w_o_range2318w2319w(0) <= NOT wire_nlO000i_w_o_range2318w(0);
	wire_nlO000i_w_lg_w_o_range2321w2322w(0) <= NOT wire_nlO000i_w_o_range2321w(0);
	wire_nlO000i_a <= ( nlO10Oi & nli0liO & nli0lli & nli0lll & nli0llO & "1");
	wire_nlO000i_b <= ( wire_nii_w_lg_nlllO0i2304w & wire_nii_w_lg_nlllO1O2302w & wire_nii_w_lg_nlllO1l2300w & wire_nii_w_lg_nlllO1i2298w & wire_nii_w_lg_nllllli2296w & "1");
	wire_nlO000i_w_o_range2309w(0) <= wire_nlO000i_o(1);
	wire_nlO000i_w_o_range2312w(0) <= wire_nlO000i_o(2);
	wire_nlO000i_w_o_range2315w(0) <= wire_nlO000i_o(3);
	wire_nlO000i_w_o_range2318w(0) <= wire_nlO000i_o(4);
	wire_nlO000i_w_o_range2321w(0) <= wire_nlO000i_o(5);
	nlO000i :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 6,
		width_b => 6,
		width_o => 6
	  )
	  PORT MAP ( 
		a => wire_nlO000i_a,
		b => wire_nlO000i_b,
		cin => wire_gnd,
		o => wire_nlO000i_o
	  );
	wire_nlO000l_a <= ( nlllO0i & nlllO1O & nlllO1l & nlllO1i & nllllli & "1");
	wire_nlO000l_b <= ( wire_nii_w_lg_nlO10Oi2283w & wire_w_lg_nli0liO2281w & wire_w_lg_nli0lli2279w & wire_w_lg_nli0lll2277w & wire_w_lg_nli0llO2275w & "1");
	nlO000l :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 6,
		width_b => 6,
		width_o => 6
	  )
	  PORT MAP ( 
		a => wire_nlO000l_a,
		b => wire_nlO000l_b,
		cin => wire_gnd,
		o => wire_nlO000l_o
	  );
	wire_nlO001O_a <= ( wire_nlO000i_w_lg_w_o_range2321w2322w & wire_nlO000i_w_lg_w_o_range2318w2319w & wire_nlO000i_w_lg_w_o_range2315w2316w & wire_nlO000i_w_lg_w_o_range2312w2313w & wire_nlO000i_w_lg_w_o_range2309w2310w & "1");
	wire_nlO001O_b <= ( "1" & "0" & "1" & "0" & "0" & "1");
	nlO001O :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 6,
		width_b => 6,
		width_o => 6
	  )
	  PORT MAP ( 
		a => wire_nlO001O_a,
		b => wire_nlO001O_b,
		cin => wire_gnd,
		o => wire_nlO001O_o
	  );
	wire_nlO0lli_w_lg_w_o_range3109w3113w(0) <= wire_nlO0lli_w_o_range3109w(0) AND wire_nlO0lli_w_lg_w_lg_w_o_range3110w3111w3112w(0);
	wire_nlO0lli_w_lg_w_lg_w_o_range3110w3111w3112w(0) <= NOT wire_nlO0lli_w_lg_w_o_range3110w3111w(0);
	wire_nlO0lli_w_lg_w_o_range3110w3111w(0) <= wire_nlO0lli_w_o_range3110w(0) XOR nllii1O;
	wire_nlO0lli_a <= ( "0" & rfull_threshold(4 DOWNTO 0) & "1");
	wire_nlO0lli_b <= ( "0" & "1" & "1" & "1" & "1" & "0" & "1");
	wire_nlO0lli_w_o_range3110w(0) <= wire_nlO0lli_o(1);
	wire_nlO0lli_w_o_range3109w(0) <= wire_nlO0lli_o(6);
	nlO0lli :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 7,
		width_b => 7,
		width_o => 7
	  )
	  PORT MAP ( 
		a => wire_nlO0lli_a,
		b => wire_nlO0lli_b,
		cin => wire_gnd,
		o => wire_nlO0lli_o
	  );
	wire_nlO101i_a <= ( nlllO0i & nlllO1O & nlllO1l & nlllO1i & nllllli & "1");
	wire_nlO101i_b <= ( "1" & "1" & "1" & "1" & "0" & "1");
	nlO101i :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 6,
		width_b => 6,
		width_o => 6
	  )
	  PORT MAP ( 
		a => wire_nlO101i_a,
		b => wire_nlO101i_b,
		cin => wire_gnd,
		o => wire_nlO101i_o
	  );
	wire_nlO10iO_a <= ( nlllO0i & nlllO1O & nlllO1l & nlllO1i & nllllli);
	wire_nlO10iO_b <= ( "0" & "0" & "0" & "0" & "1");
	nlO10iO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_nlO10iO_a,
		b => wire_nlO10iO_b,
		cin => wire_gnd,
		o => wire_nlO10iO_o
	  );
	wire_n011iO_i <= ( nli1Ol & nli1Oi & nli1lO & nli1ll);
	n011iO :  oper_decoder
	  GENERIC MAP (
		width_i => 4,
		width_o => 16
	  )
	  PORT MAP ( 
		i => wire_n011iO_i,
		o => wire_n011iO_o
	  );
	wire_n011ll_i <= ( nli1Ol & nli1Oi);
	n011ll :  oper_decoder
	  GENERIC MAP (
		width_i => 2,
		width_o => 4
	  )
	  PORT MAP ( 
		i => wire_n011ll_i,
		o => wire_n011ll_o
	  );
	wire_n011Oi_i <= ( nli1Ol & nli1Oi & nli1lO & nli1ll & nl1i0i);
	n011Oi :  oper_decoder
	  GENERIC MAP (
		width_i => 5,
		width_o => 32
	  )
	  PORT MAP ( 
		i => wire_n011Oi_i,
		o => wire_n011Oi_o
	  );
	wire_n0OO1l_i <= ( wire_ni1l1i_dataout & wire_ni1iOO_dataout & wire_ni1iOl_dataout & wire_ni1iOi_dataout & wire_ni1ilO_dataout);
	n0OO1l :  oper_decoder
	  GENERIC MAP (
		width_i => 5,
		width_o => 32
	  )
	  PORT MAP ( 
		i => wire_n0OO1l_i,
		o => wire_n0OO1l_o
	  );
	wire_n1l00O_i <= ( n100ii & n1000O & n1000l & n1000i & n1001O);
	n1l00O :  oper_decoder
	  GENERIC MAP (
		width_i => 5,
		width_o => 32
	  )
	  PORT MAP ( 
		i => wire_n1l00O_i,
		o => wire_n1l00O_o
	  );
	wire_n1l01l_i <= ( n100ii & n1000l & n1000i & n1001O);
	n1l01l :  oper_decoder
	  GENERIC MAP (
		width_i => 4,
		width_o => 16
	  )
	  PORT MAP ( 
		i => wire_n1l01l_i,
		o => wire_n1l01l_o
	  );
	wire_n1l1OO_i <= ( n100ii & n1000O & n1000l & n1000i);
	n1l1OO :  oper_decoder
	  GENERIC MAP (
		width_i => 4,
		width_o => 16
	  )
	  PORT MAP ( 
		i => wire_n1l1OO_i,
		o => wire_n1l1OO_o
	  );
	wire_n1OliO_i <= ( rskpsetbased & rclkcmpsqmd);
	n1OliO :  oper_decoder
	  GENERIC MAP (
		width_i => 2,
		width_o => 4
	  )
	  PORT MAP ( 
		i => wire_n1OliO_i,
		o => wire_n1OliO_o
	  );
	wire_nl0O1i_i <= ( niOOii & niOO0O & niOO0l & niOO0i);
	nl0O1i :  oper_decoder
	  GENERIC MAP (
		width_i => 4,
		width_o => 16
	  )
	  PORT MAP ( 
		i => wire_nl0O1i_i,
		o => wire_nl0O1i_o
	  );
	wire_nl0O1O_i <= ( niOOii & niOO0l & niOO0i & niOO1O);
	nl0O1O :  oper_decoder
	  GENERIC MAP (
		width_i => 4,
		width_o => 16
	  )
	  PORT MAP ( 
		i => wire_nl0O1O_i,
		o => wire_nl0O1O_o
	  );
	wire_nl0Oii_i <= ( niOOii & niOO0O & niOO0l & niOO0i & niOO1O);
	nl0Oii :  oper_decoder
	  GENERIC MAP (
		width_i => 5,
		width_o => 32
	  )
	  PORT MAP ( 
		i => wire_nl0Oii_i,
		o => wire_nl0Oii_o
	  );
	wire_nliO01i_i <= ( n1O00l & n1O00i & n1O01O & n1O01l & n1ll1l);
	nliO01i :  oper_decoder
	  GENERIC MAP (
		width_i => 5,
		width_o => 32
	  )
	  PORT MAP ( 
		i => wire_nliO01i_i,
		o => wire_nliO01i_o
	  );
	wire_nliO1lO_i <= ( n1O00l & n1O00i & n1O01O & n1O01l);
	nliO1lO :  oper_decoder
	  GENERIC MAP (
		width_i => 4,
		width_o => 16
	  )
	  PORT MAP ( 
		i => wire_nliO1lO_i,
		o => wire_nliO1lO_o
	  );
	wire_nliO1Ol_i <= ( n1O00l & n1O00i);
	nliO1Ol :  oper_decoder
	  GENERIC MAP (
		width_i => 2,
		width_o => 4
	  )
	  PORT MAP ( 
		i => wire_nliO1Ol_i,
		o => wire_nliO1Ol_o
	  );
	wire_nlli01O_i <= ( wire_nlO01lO_dataout & wire_nlO01ll_dataout & wire_nlO01li_dataout & wire_nlO01iO_dataout & wire_nlO01il_dataout);
	nlli01O :  oper_decoder
	  GENERIC MAP (
		width_i => 5,
		width_o => 32
	  )
	  PORT MAP ( 
		i => wire_nlli01O_i,
		o => wire_nlli01O_o
	  );
	wire_n11iii_a <= ( nlO011i & nlO1OOO & nlO1OOl & nlO1OOi & nlO1OiO);
	wire_n11iii_b <= ( "0" & "0" & rempty_threshold(2 DOWNTO 0));
	n11iii :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_n11iii_a,
		b => wire_n11iii_b,
		cin => wire_gnd,
		o => wire_n11iii_o
	  );
	wire_n1O01i_a <= ( rins_threshold(4 DOWNTO 0));
	wire_n1O01i_b <= ( nlii01l & wire_nliO1Ol_o(1) & nlii01O & nlii00i & nlii00l);
	n1O01i :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_n1O01i_a,
		b => wire_n1O01i_b,
		cin => wire_vcc,
		o => wire_n1O01i_o
	  );
	wire_n1O10l_a <= ( "0" & "0" & "0");
	wire_n1O10l_b <= ( n11O0l & n11O0i & n11O1O);
	n1O10l :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 3,
		width_b => 3
	  )
	  PORT MAP ( 
		a => wire_n1O10l_a,
		b => wire_n1O10l_b,
		cin => wire_gnd,
		o => wire_n1O10l_o
	  );
	wire_n1O11l_a <= ( n11O0l & n11O0i & n11O1O);
	wire_n1O11l_b <= ( "1" & "0" & "1");
	n1O11l :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 3,
		width_b => 3
	  )
	  PORT MAP ( 
		a => wire_n1O11l_a,
		b => wire_n1O11l_b,
		cin => wire_gnd,
		o => wire_n1O11l_o
	  );
	wire_n1OllO_w_lg_o2370w(0) <= wire_n1OllO_o AND wire_w_lg_w_lg_w_lg_rskpsetbased2364w2368w2369w(0);
	wire_n1OllO_w_lg_o2547w(0) <= wire_n1OllO_o AND wire_w_lg_nli0O1i2546w(0);
	wire_n1OllO_a <= ( rdel_threshold(4 DOWNTO 0));
	wire_n1OllO_b <= ( nlO011i & nlO1OOO & nlO1OOl & nlO1OOi & nlO1OiO);
	n1OllO :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_n1OllO_a,
		b => wire_n1OllO_b,
		cin => wire_gnd,
		o => wire_n1OllO_o
	  );
	wire_n1OlOi_a <= ( nlO011i & nlO1OOO & nlO1OOl & nlO1OOi & nlO1OiO);
	wire_n1OlOi_b <= ( rins_threshold(4 DOWNTO 0));
	n1OlOi :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_n1OlOi_a,
		b => wire_n1OlOi_b,
		cin => wire_gnd,
		o => wire_n1OlOi_o
	  );
	wire_n1OOlO_a <= ( nlO011i & nlO1OOO & nlO1OOl & nlO1OOi & nlO1OiO);
	wire_n1OOlO_b <= ( rdel_threshold(4 DOWNTO 0));
	n1OOlO :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_n1OOlO_a,
		b => wire_n1OOlO_b,
		cin => wire_vcc,
		o => wire_n1OOlO_o
	  );
	wire_n1OOOi_a <= ( rins_threshold(4 DOWNTO 0));
	wire_n1OOOi_b <= ( nlO011i & nlO1OOO & nlO1OOl & nlO1OOi & nlO1OiO);
	n1OOOi :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_n1OOOi_a,
		b => wire_n1OOOi_b,
		cin => wire_vcc,
		o => wire_n1OOOi_o
	  );
	wire_ni1i1i_a <= ( "0" & "0" & "0" & "0" & "0");
	wire_ni1i1i_b <= ( n0O0OO & nliil0O & nliilii & nliilil & nliiliO);
	ni1i1i :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_ni1i1i_a,
		b => wire_ni1i1i_b,
		cin => wire_gnd,
		o => wire_ni1i1i_o
	  );
	wire_ni1lli_a <= ( n0O0OO & nliil0O & nliilii & nliilil & nliiliO);
	wire_ni1lli_b <= ( n0l0il & n0l0ii & n0l00O & n0l00l & n0O0ll);
	ni1lli :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_ni1lli_a,
		b => wire_ni1lli_b,
		cin => wire_gnd,
		o => wire_ni1lli_o
	  );
	wire_nli1li_a <= ( rins_threshold(4 DOWNTO 0));
	wire_nli1li_b <= ( nlil1Oi & wire_n011ll_o(1) & nlil1Ol & nlil1OO & nlil01i);
	nli1li :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_nli1li_a,
		b => wire_nli1li_b,
		cin => wire_vcc,
		o => wire_nli1li_o
	  );
	wire_nlilOi_a <= ( ni1i0l & ni1i0i & ni1i1O & ni1i1l & ni101l);
	wire_nlilOi_b <= ( "0" & "0" & rempty_threshold(2 DOWNTO 0));
	nlilOi :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_nlilOi_a,
		b => wire_nlilOi_b,
		cin => wire_gnd,
		o => wire_nlilOi_o
	  );
	wire_nlli0iO_a <= ( "0" & "0" & "0" & "0" & "0");
	wire_nlli0iO_b <= ( nlO10Oi & nli0liO & nli0lli & nli0lll & nli0llO);
	nlli0iO :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_nlli0iO_a,
		b => wire_nlli0iO_b,
		cin => wire_gnd,
		o => wire_nlli0iO_o
	  );
	wire_nllOii_a <= ( wire_nlililO40_w_lg_w_lg_q396w397w & ni1i0i & ni1i1O & ni1i1l & ni101l);
	wire_nllOii_b <= ( rdel_threshold(4) & wire_nlilill42_w_lg_w_lg_q405w406w & rdel_threshold(2 DOWNTO 0));
	nllOii :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_nllOii_a,
		b => wire_nllOii_b,
		cin => wire_vcc,
		o => wire_nllOii_o
	  );
	wire_nllOil_a <= ( rins_threshold(4 DOWNTO 0));
	wire_nllOil_b <= ( ni1i0l & ni1i0i & ni1i1O & ni1i1l & ni101l);
	nllOil :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_nllOil_a,
		b => wire_nllOil_b,
		cin => wire_vcc,
		o => wire_nllOil_o
	  );
	wire_nllOiO_a <= ( rdel_threshold(4 DOWNTO 0));
	wire_nllOiO_b <= ( ni1i0l & ni1i0i & ni1i1O & wire_nliliOi38_w_lg_w_lg_q369w370w & ni101l);
	nllOiO :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_nllOiO_a,
		b => wire_nllOiO_b,
		cin => wire_gnd,
		o => wire_nllOiO_o
	  );
	wire_nllOli_a <= ( ni1i0l & ni1i0i & wire_nliliOl36_w_lg_w_lg_q332w333w & ni1i1l & ni101l);
	wire_nllOli_b <= ( rins_threshold(4 DOWNTO 0));
	nllOli :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_nllOli_a,
		b => wire_nllOli_b,
		cin => wire_gnd,
		o => wire_nllOli_o
	  );
	wire_nlO000O_a <= ( nlO10Oi & nli0liO & nli0lli & nli0lll & nli0llO);
	wire_nlO000O_b <= ( nlllO0i & nlllO1O & nlllO1l & nlllO1i & nllllli);
	nlO000O :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_nlO000O_a,
		b => wire_nlO000O_b,
		cin => wire_gnd,
		o => wire_nlO000O_o
	  );
	wire_nllOOO_data <= ( wire_nliliOO34_w_lg_w_lg_q166w167w & wire_nlO10O_dataout & nlO01O & nlO01O);
	wire_nllOOO_sel <= ( nlO01l & nllOOl);
	nllOOO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nllOOO_data,
		o => wire_nllOOO_o,
		sel => wire_nllOOO_sel
	  );
	wire_nlO11i_data <= ( wire_nlO1li_dataout & wire_nlill1i32_w_lg_w_lg_q155w156w & wire_nlill1l30_w_lg_w_lg_q152w153w & nllOOi);
	wire_nlO11i_sel <= ( nlO01l & nllOOl);
	nlO11i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlO11i_data,
		o => wire_nlO11i_o,
		sel => wire_nlO11i_sel
	  );
	wire_nlO11l_data <= ( wire_nlO1ll_dataout & wire_nlO10i_dataout & wire_nl00O_dataout & wire_nl0ii_w_lg_w_lg_dataout138w141w);
	wire_nlO11l_sel <= ( nlO01l & nllOOl);
	nlO11l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlO11l_data,
		o => wire_nlO11l_o,
		sel => wire_nlO11l_sel
	  );
	wire_nlO11O_data <= ( wire_nl00O_dataout & wire_nl00O_dataout & wire_nlO1OO_dataout & "0");
	wire_nlO11O_sel <= ( nlO01l & wire_nlill0l26_w_lg_w_lg_q124w125w);
	nlO11O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlO11O_data,
		o => wire_nlO11O_o,
		sel => wire_nlO11O_sel
	  );
	wire_nllOll_data_in <= ( wire_nl10i_dataout & wire_nl11O_dataout & wire_nl11l_dataout & wire_nl11i_dataout & wire_niOOO_dataout & wire_niOOl_dataout & wire_niOOi_dataout & wire_niOlO_dataout & wire_niOll_dataout & wire_niOli_dataout & wire_niOiO_dataout & wire_niOil_dataout & wire_niOii_dataout & wire_niO0O_dataout & wire_niO0l_dataout & wire_niO0i_dataout);
	wire_nllOll_fifo_re1 <= ( wire_n1ii_dataout & wire_n10O_dataout & wire_n10l_dataout & wire_n10i_dataout & wire_n11O_dataout & wire_n11l_dataout & wire_n11i_dataout & wire_nlOOO_dataout & wire_nlOOl_dataout & wire_nlOOi_dataout & wire_nlOlO_dataout & wire_nlOll_dataout & wire_nlOli_dataout & wire_nlOiO_dataout & wire_nlOil_dataout & wire_nlOii_dataout & wire_nlO0O_dataout & wire_nlO0l_dataout & wire_nlO0i_dataout & wire_nlO1O_dataout);
	wire_nllOll_fifo_re2 <= ( wire_nlO1l_dataout & wire_nlO1i_dataout & wire_nllOO_dataout & wire_nllOl_dataout & wire_nllOi_dataout & wire_nlllO_dataout & wire_nllll_dataout & wire_nllli_dataout & wire_nlliO_dataout & wire_nllil_dataout & wire_nllii_dataout & wire_nll0O_dataout & wire_nll0l_dataout & wire_nll0i_dataout & wire_nll1O_dataout & wire_nll1l_dataout & wire_nll1i_dataout & wire_nliOO_dataout & wire_nliOl_dataout & wire_nliOi_dataout);
	wire_nllOll_fifo_wr <= ( wire_nlilO_dataout & wire_nlill_dataout & wire_nlili_dataout & wire_nliiO_dataout & wire_nliil_dataout & wire_nliii_dataout & wire_nli0O_dataout & wire_nli0l_dataout & wire_nli0i_dataout & wire_nli1O_dataout & wire_nli1l_dataout & wire_nli1i_dataout & wire_nl0OO_dataout & wire_nl0Ol_dataout & wire_nl0Oi_dataout & wire_nl0lO_dataout & wire_nl0ll_dataout & wire_nl0li_dataout & wire_nl0iO_dataout & wire_nl0il_dataout);
	wire_nllOll_rst_l <= wire_nl0i_w_lg_dataout4w(0);
	nllOll :  stratixiv_hssi_rx_digis_ram20x16_syn
	  GENERIC MAP (
		ram_width => 16,
		read_access_time => 0,
		write_access_time => 0
	  )
	  PORT MAP ( 
		clk => clk_1,
		data_in => wire_nllOll_data_in,
		data_out1 => wire_nllOll_data_out1,
		data_out2 => wire_nllOll_data_out2,
		fifo_re1 => wire_nllOll_fifo_re1,
		fifo_re2 => wire_nllOll_fifo_re2,
		fifo_wr => wire_nllOll_fifo_wr,
		rst_l => wire_nllOll_rst_l
	  );
	wire_nllOlO_data_in <= ( wire_nl00l_dataout & wire_nl00i_dataout & wire_nl01O_dataout & wire_nl01l_dataout & wire_nl01i_dataout & wire_nl1OO_dataout & wire_nl1Ol_dataout & wire_nl1Oi_dataout & wire_nl1lO_dataout & wire_nl1ll_dataout & wire_nl1li_dataout & wire_nl1iO_dataout & wire_nl1il_dataout & wire_nl1ii_dataout & wire_nl10O_dataout & wire_nl10l_dataout);
	wire_nllOlO_fifo_re1 <= ( wire_n1ii_dataout & wire_n10O_dataout & wire_n10l_dataout & wire_n10i_dataout & wire_n11O_dataout & wire_n11l_dataout & wire_n11i_dataout & wire_nlOOO_dataout & wire_nlOOl_dataout & wire_nlOOi_dataout & wire_nlOlO_dataout & wire_nlOll_dataout & wire_nlOli_dataout & wire_nlOiO_dataout & wire_nlOil_dataout & wire_nlOii_dataout & wire_nlO0O_dataout & wire_nlO0l_dataout & wire_nlO0i_dataout & wire_nlO1O_dataout);
	wire_nllOlO_fifo_re2 <= ( wire_nlO1l_dataout & wire_nlO1i_dataout & wire_nllOO_dataout & wire_nllOl_dataout & wire_nllOi_dataout & wire_nlllO_dataout & wire_nllll_dataout & wire_nllli_dataout & wire_nlliO_dataout & wire_nllil_dataout & wire_nllii_dataout & wire_nll0O_dataout & wire_nll0l_dataout & wire_nll0i_dataout & wire_nll1O_dataout & wire_nll1l_dataout & wire_nll1i_dataout & wire_nliOO_dataout & wire_nliOl_dataout & wire_nliOi_dataout);
	wire_nllOlO_fifo_wr <= ( wire_nlilO_dataout & wire_nlill_dataout & wire_nlili_dataout & wire_nliiO_dataout & wire_nliil_dataout & wire_nliii_dataout & wire_nli0O_dataout & wire_nli0l_dataout & wire_nli0i_dataout & wire_nli1O_dataout & wire_nli1l_dataout & wire_nli1i_dataout & wire_nl0OO_dataout & wire_nl0Ol_dataout & wire_nl0Oi_dataout & wire_nl0lO_dataout & wire_nl0ll_dataout & wire_nl0li_dataout & wire_nl0iO_dataout & wire_nl0il_dataout);
	wire_nllOlO_rst_l <= wire_nl0i_w_lg_dataout4w(0);
	nllOlO :  stratixiv_hssi_rx_digis_ram20x16_syn
	  GENERIC MAP (
		ram_width => 16,
		read_access_time => 0,
		write_access_time => 0
	  )
	  PORT MAP ( 
		clk => clk_1,
		data_in => wire_nllOlO_data_in,
		data_out1 => wire_nllOlO_data_out1,
		data_out2 => wire_nllOlO_data_out2,
		fifo_re1 => wire_nllOlO_fifo_re1,
		fifo_re2 => wire_nllOlO_fifo_re2,
		fifo_wr => wire_nllOlO_fifo_wr,
		rst_l => wire_nllOlO_rst_l
	  );

 END RTL; --stratixiv_hssi_rx_digi_comp_chnl_top
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 9.0 cbx_mgl 2008:11:18:11:51:17:SJ cbx_simgen 2008:08:06:16:30:59:SJ  VERSION_END


-- Legal Notice:  2003 Altera Corporation. All rights reserved.
-- You may only use these  simulation  model  output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event  Altera disclaims all warranties of any kind). Your use of  Altera
-- Corporation's design tools, logic functions and other software and tools,
-- and its AMPP partner logic functions, and any output files any of the
-- foregoing (including device programming or simulation files), and any
-- associated documentation or information  are expressly subject to the
-- terms and conditions of the  Altera Program License Subscription Agreement
-- or other applicable license agreement, including, without limitation, that
-- your use is for the sole purpose of programming logic devices manufactured
-- by Altera and sold by Altera or its authorized distributors.  Please refer
-- to the applicable agreement for further details.


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 419 mux21 1388 oper_decoder 5 oper_mux 200 oper_selector 2 stratixiv_hssi_rx_digis_ph_fifo 1 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_rx_digi_rx_ctrl IS 
	 PORT 
	 ( 
		 bytord_valid_out	:	OUT  STD_LOGIC;
		 bytordplden	:	IN  STD_LOGIC;
		 clk_2	:	IN  STD_LOGIC;
		 dec_data_valid	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 dec_data_valid_pre	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 dis_pc_byte	:	IN  STD_LOGIC;
		 disp_err_delay	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 disp_val_delay	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 endec_rx	:	IN  STD_LOGIC;
		 gen2ngen1	:	IN  STD_LOGIC;
		 gen2ngen1_bundle	:	IN  STD_LOGIC;
		 invalid_code_delay	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 ovr_undflow	:	IN  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 pcs_wrapback_in	:	IN  STD_LOGIC_VECTOR (69 DOWNTO 0);
		 ph_fifo_empty	:	OUT  STD_LOGIC;
		 ph_fifo_full	:	OUT  STD_LOGIC;
		 phystatus	:	OUT  STD_LOGIC;
		 phystatus_int	:	IN  STD_LOGIC;
		 pipe_data	:	OUT  STD_LOGIC_VECTOR (63 DOWNTO 0);
		 pld_re	:	IN  STD_LOGIC;
		 pld_wr_dis	:	IN  STD_LOGIC;
		 powerdown	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rauto_speed_ena	:	IN  STD_LOGIC;
		 rautoinsdis	:	IN  STD_LOGIC;
		 rbytord_2sym_en	:	IN  STD_LOGIC;
		 rbytord_6g_mask_en	:	IN  STD_LOGIC;
		 rbytord_s2gx	:	IN  STD_LOGIC;
		 rbytorden	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rbytordpadval	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 rbytordpat	:	IN  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 rbytordplden	:	IN  STD_LOGIC;
		 rclkcmpinsertpad	:	IN  STD_LOGIC;
		 rd_enable2	:	OUT  STD_LOGIC;
		 rd_enable_centrl	:	IN  STD_LOGIC;
		 rd_enable_out	:	OUT  STD_LOGIC;
		 rd_enable_quad_down	:	IN  STD_LOGIC;
		 rd_enable_quad_up	:	IN  STD_LOGIC;
		 rdwidth	:	IN  STD_LOGIC;
		 rendec_data_sel_rx	:	IN  STD_LOGIC;
		 reset_pc_ptrs	:	IN  STD_LOGIC;
		 reset_pc_ptrs_centrl	:	IN  STD_LOGIC;
		 reset_pc_ptrs_quad_down	:	IN  STD_LOGIC;
		 reset_pc_ptrs_quad_up	:	IN  STD_LOGIC;
		 rfreq_sel	:	IN  STD_LOGIC;
		 rindv_rx	:	IN  STD_LOGIC;
		 rinvalid_code_err_only	:	IN  STD_LOGIC;
		 rmaster_rx	:	IN  STD_LOGIC;
		 rmaster_up_rx	:	IN  STD_LOGIC;
		 rpcs_wrapback_en	:	IN  STD_LOGIC;
		 rphfifo_regmode_rx	:	IN  STD_LOGIC;
		 rpmadatawidth	:	IN  STD_LOGIC;
		 rptr_bin	:	OUT  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 rrx_pipe_enable	:	IN  STD_LOGIC;
		 rrxfifo_dis	:	IN  STD_LOGIC;
		 rrxfifo_lowlatency_en	:	IN  STD_LOGIC;
		 rrxfifo_urst_en	:	IN  STD_LOGIC;
		 rrxpcsbypass_en	:	IN  STD_LOGIC;
		 rrxphfifopldctl_en	:	IN  STD_LOGIC;
		 rsync_comp_pat	:	IN  STD_LOGIC_VECTOR (39 DOWNTO 0);
		 rsync_comp_porn	:	IN  STD_LOGIC;
		 rsync_comp_size	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 rsync_sm_dis	:	IN  STD_LOGIC;
		 running_disp	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rwa_6g_en	:	IN  STD_LOGIC;
		 rx_control_dt	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rx_control_rs	:	IN  STD_LOGIC;
		 rx_data_dt	:	IN  STD_LOGIC_VECTOR (15 DOWNTO 0);
		 rx_data_rs	:	IN  STD_LOGIC_VECTOR (7 DOWNTO 0);
		 rx_rd_clk	:	IN  STD_LOGIC;
		 rx_we_in_centrl	:	IN  STD_LOGIC;
		 rx_we_in_quad_down	:	IN  STD_LOGIC;
		 rx_we_in_quad_up	:	IN  STD_LOGIC;
		 rx_we_out	:	OUT  STD_LOGIC;
		 rx_wr_clk	:	IN  STD_LOGIC;
		 rxc	:	OUT  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 rxd	:	OUT  STD_LOGIC_VECTOR (63 DOWNTO 0);
		 rxd_19	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rxd_9	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rxd_lpbk	:	OUT  STD_LOGIC_VECTOR (39 DOWNTO 0);
		 rxfifo_urst	:	IN  STD_LOGIC;
		 rxstatus	:	OUT  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 rxstatus_int	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 rxvalid	:	OUT  STD_LOGIC;
		 rxvalid_int	:	IN  STD_LOGIC;
		 scan_mode	:	IN  STD_LOGIC;
		 sigdetni	:	IN  STD_LOGIC;
		 signal_detect_out	:	OUT  STD_LOGIC;
		 soft_reset	:	IN  STD_LOGIC;
		 soft_reset_rclk1	:	OUT  STD_LOGIC;
		 soft_reset_wclk1	:	OUT  STD_LOGIC;
		 sync_resync_delay	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 sync_resync_pre	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 tenb_data	:	IN  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 wptr_bin	:	OUT  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 wr_enable2	:	OUT  STD_LOGIC;
		 wr_enable_centrl	:	IN  STD_LOGIC;
		 wr_enable_out	:	OUT  STD_LOGIC;
		 wr_enable_quad_down	:	IN  STD_LOGIC;
		 wr_enable_quad_up	:	IN  STD_LOGIC
	 ); 
 END stratixiv_hssi_rx_digi_rx_ctrl;

 ARCHITECTURE RTL OF stratixiv_hssi_rx_digi_rx_ctrl IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 niOllOO57	:	STD_LOGIC := '0';
	 SIGNAL	 niOllOO58	:	STD_LOGIC := '0';
	 SIGNAL	 niOlO1i55	:	STD_LOGIC := '0';
	 SIGNAL	 niOlO1i56	:	STD_LOGIC := '0';
	 SIGNAL	 niOOO0i49	:	STD_LOGIC := '0';
	 SIGNAL	 niOOO0i50	:	STD_LOGIC := '0';
	 SIGNAL	 niOOO0O47	:	STD_LOGIC := '0';
	 SIGNAL	 niOOO0O48	:	STD_LOGIC := '0';
	 SIGNAL	 niOOO1l53	:	STD_LOGIC := '0';
	 SIGNAL	 niOOO1l54	:	STD_LOGIC := '0';
	 SIGNAL	 niOOO1O51	:	STD_LOGIC := '0';
	 SIGNAL	 niOOO1O52	:	STD_LOGIC := '0';
	 SIGNAL	 niOOOOO45	:	STD_LOGIC := '0';
	 SIGNAL	 niOOOOO46	:	STD_LOGIC := '0';
	 SIGNAL	 nl1010l11	:	STD_LOGIC := '0';
	 SIGNAL	 nl1010l12	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl1010l12_w_lg_w_lg_q111w112w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1010l12_w_lg_q111w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl1010O10	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl1010O10_w_lg_w_lg_q106w107w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1010O10_w_lg_q106w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl1010O9	:	STD_LOGIC := '0';
	 SIGNAL	 nl1011i15	:	STD_LOGIC := '0';
	 SIGNAL	 nl1011i16	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl1011i16_w_lg_w_lg_q221w222w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1011i16_w_lg_q221w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl1011O13	:	STD_LOGIC := '0';
	 SIGNAL	 nl1011O14	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl1011O14_w_lg_w_lg_q214w215w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1011O14_w_lg_q214w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl101ii7	:	STD_LOGIC := '0';
	 SIGNAL	 nl101ii8	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl101ii8_w_lg_w_lg_q102w103w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl101ii8_w_lg_q102w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl101iO5	:	STD_LOGIC := '0';
	 SIGNAL	 nl101iO6	:	STD_LOGIC := '0';
	 SIGNAL	 nl101lO3	:	STD_LOGIC := '0';
	 SIGNAL	 nl101lO4	:	STD_LOGIC := '0';
	 SIGNAL	 nl101OO1	:	STD_LOGIC := '0';
	 SIGNAL	 nl101OO2	:	STD_LOGIC := '0';
	 SIGNAL	 nl1111i43	:	STD_LOGIC := '0';
	 SIGNAL	 nl1111i44	:	STD_LOGIC := '0';
	 SIGNAL	 nl111ii41	:	STD_LOGIC := '0';
	 SIGNAL	 nl111ii42	:	STD_LOGIC := '0';
	 SIGNAL	 nl11l0l35	:	STD_LOGIC := '0';
	 SIGNAL	 nl11l0l36	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl11l0l36_w_lg_q296w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl11l1l39	:	STD_LOGIC := '0';
	 SIGNAL	 nl11l1l40	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl11l1l40_w_lg_w_lg_q303w304w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl11l1l40_w_lg_q303w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl11l1O37	:	STD_LOGIC := '0';
	 SIGNAL	 nl11l1O38	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl11l1O38_w_lg_w_lg_q300w301w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl11l1O38_w_lg_q300w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl11liO33	:	STD_LOGIC := '0';
	 SIGNAL	 nl11liO34	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl11liO34_w_lg_w_lg_q291w292w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl11liO34_w_lg_q291w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl11lli31	:	STD_LOGIC := '0';
	 SIGNAL	 nl11lli32	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl11lli32_w_lg_q288w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl11lOl29	:	STD_LOGIC := '0';
	 SIGNAL	 nl11lOl30	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl11lOl30_w_lg_w_lg_q279w280w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl11lOl30_w_lg_q279w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl11lOO27	:	STD_LOGIC := '0';
	 SIGNAL	 nl11lOO28	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl11lOO28_w_lg_q277w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl11O0O25	:	STD_LOGIC := '0';
	 SIGNAL	 nl11O0O26	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl11O0O26_w_lg_w_lg_q264w265w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl11O0O26_w_lg_q264w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl11Oli23	:	STD_LOGIC := '0';
	 SIGNAL	 nl11Oli24	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl11Oli24_w_lg_w_lg_q257w258w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl11Oli24_w_lg_q257w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl11OlO21	:	STD_LOGIC := '0';
	 SIGNAL	 nl11OlO22	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl11OlO22_w_lg_w_lg_q242w243w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl11OlO22_w_lg_q242w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl11OOi19	:	STD_LOGIC := '0';
	 SIGNAL	 nl11OOi20	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl11OOi20_w_lg_w_lg_q239w240w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl11OOi20_w_lg_q239w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl11OOO17	:	STD_LOGIC := '0';
	 SIGNAL	 nl11OOO18	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl11OOO18_w_lg_w_lg_q228w229w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl11OOO18_w_lg_q228w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n1i0i	:	STD_LOGIC := '0';
	 SIGNAL	n1i0O	:	STD_LOGIC := '0';
	 SIGNAL	n1i1O	:	STD_LOGIC := '0';
	 SIGNAL	n1iii	:	STD_LOGIC := '0';
	 SIGNAL	n1iil	:	STD_LOGIC := '0';
	 SIGNAL	n1iiO	:	STD_LOGIC := '0';
	 SIGNAL	n1ili	:	STD_LOGIC := '0';
	 SIGNAL	n1ilO	:	STD_LOGIC := '0';
	 SIGNAL	nli0iO	:	STD_LOGIC := '0';
	 SIGNAL	nlilOO	:	STD_LOGIC := '0';
	 SIGNAL	nliO0i	:	STD_LOGIC := '0';
	 SIGNAL	nliO0l	:	STD_LOGIC := '0';
	 SIGNAL	nliO0O	:	STD_LOGIC := '0';
	 SIGNAL	nliO1i	:	STD_LOGIC := '0';
	 SIGNAL	nliOii	:	STD_LOGIC := '0';
	 SIGNAL	nliOil	:	STD_LOGIC := '0';
	 SIGNAL	nliOiO	:	STD_LOGIC := '0';
	 SIGNAL	nliOli	:	STD_LOGIC := '0';
	 SIGNAL	nliOll	:	STD_LOGIC := '0';
	 SIGNAL	nliOlO	:	STD_LOGIC := '0';
	 SIGNAL	nliOOi	:	STD_LOGIC := '0';
	 SIGNAL	nliOOl	:	STD_LOGIC := '0';
	 SIGNAL	nliOOO	:	STD_LOGIC := '0';
	 SIGNAL	nll00i	:	STD_LOGIC := '0';
	 SIGNAL	nll00l	:	STD_LOGIC := '0';
	 SIGNAL	nll00O	:	STD_LOGIC := '0';
	 SIGNAL	nll01i	:	STD_LOGIC := '0';
	 SIGNAL	nll01l	:	STD_LOGIC := '0';
	 SIGNAL	nll01O	:	STD_LOGIC := '0';
	 SIGNAL	nll0ii	:	STD_LOGIC := '0';
	 SIGNAL	nll0il	:	STD_LOGIC := '0';
	 SIGNAL	nll0iO	:	STD_LOGIC := '0';
	 SIGNAL	nll0li	:	STD_LOGIC := '0';
	 SIGNAL	nll0ll	:	STD_LOGIC := '0';
	 SIGNAL	nll0lO	:	STD_LOGIC := '0';
	 SIGNAL	nll0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nll0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nll0OO	:	STD_LOGIC := '0';
	 SIGNAL	nll10i	:	STD_LOGIC := '0';
	 SIGNAL	nll10l	:	STD_LOGIC := '0';
	 SIGNAL	nll10O	:	STD_LOGIC := '0';
	 SIGNAL	nll11i	:	STD_LOGIC := '0';
	 SIGNAL	nll11l	:	STD_LOGIC := '0';
	 SIGNAL	nll11O	:	STD_LOGIC := '0';
	 SIGNAL	nll1ii	:	STD_LOGIC := '0';
	 SIGNAL	nll1il	:	STD_LOGIC := '0';
	 SIGNAL	nll1iO	:	STD_LOGIC := '0';
	 SIGNAL	nll1li	:	STD_LOGIC := '0';
	 SIGNAL	nll1ll	:	STD_LOGIC := '0';
	 SIGNAL	nll1lO	:	STD_LOGIC := '0';
	 SIGNAL	nll1Oi	:	STD_LOGIC := '0';
	 SIGNAL	nll1Ol	:	STD_LOGIC := '0';
	 SIGNAL	nll1OO	:	STD_LOGIC := '0';
	 SIGNAL	nlli0i	:	STD_LOGIC := '0';
	 SIGNAL	nlli0l	:	STD_LOGIC := '0';
	 SIGNAL	nlli0O	:	STD_LOGIC := '0';
	 SIGNAL	nlli1i	:	STD_LOGIC := '0';
	 SIGNAL	nlli1l	:	STD_LOGIC := '0';
	 SIGNAL	nlli1O	:	STD_LOGIC := '0';
	 SIGNAL	nlliii	:	STD_LOGIC := '0';
	 SIGNAL	nlliil	:	STD_LOGIC := '0';
	 SIGNAL	nlliiO	:	STD_LOGIC := '0';
	 SIGNAL	nllili	:	STD_LOGIC := '0';
	 SIGNAL	nllill	:	STD_LOGIC := '0';
	 SIGNAL	nllilO	:	STD_LOGIC := '0';
	 SIGNAL	nlliOi	:	STD_LOGIC := '0';
	 SIGNAL	nlliOl	:	STD_LOGIC := '0';
	 SIGNAL	nlliOO	:	STD_LOGIC := '0';
	 SIGNAL	nlll0i	:	STD_LOGIC := '0';
	 SIGNAL	nlll0l	:	STD_LOGIC := '0';
	 SIGNAL	nlll0O	:	STD_LOGIC := '0';
	 SIGNAL	nlll1i	:	STD_LOGIC := '0';
	 SIGNAL	nlll1l	:	STD_LOGIC := '0';
	 SIGNAL	nlll1O	:	STD_LOGIC := '0';
	 SIGNAL	nlllii	:	STD_LOGIC := '0';
	 SIGNAL	nlllil	:	STD_LOGIC := '0';
	 SIGNAL	nllliO	:	STD_LOGIC := '0';
	 SIGNAL	nlllli	:	STD_LOGIC := '0';
	 SIGNAL	nlllll	:	STD_LOGIC := '0';
	 SIGNAL	nllllO	:	STD_LOGIC := '0';
	 SIGNAL	nlllOi	:	STD_LOGIC := '0';
	 SIGNAL	nlllOl	:	STD_LOGIC := '0';
	 SIGNAL	nlO10Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlO10OO	:	STD_LOGIC := '0';
	 SIGNAL	nlO1ili	:	STD_LOGIC := '0';
	 SIGNAL	nlOl0O	:	STD_LOGIC := '0';
	 SIGNAL	wire_n1ill_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_n1ill_w_lg_w_lg_nll10l275w278w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_w_lg_n1ili661w662w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_n1iil670w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_nliOOi312w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_nliOOO284w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_nll10i308w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_nll10l275w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_nll11l494w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_nll11O482w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_n1i0i4636w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_n1iii669w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_n1iil658w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_n1iiO656w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_n1ili661w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_n1ilO602w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_nll0ll513w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ill_w_lg_nll0lO536w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	niOiil	:	STD_LOGIC := '0';
	 SIGNAL	nl011i	:	STD_LOGIC := '0';
	 SIGNAL	nl011O	:	STD_LOGIC := '0';
	 SIGNAL	nl1OOO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl011l_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nl011l_PRN	:	STD_LOGIC;
	 SIGNAL	nli00i	:	STD_LOGIC := '0';
	 SIGNAL	nli1iO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nli01O_PRN	:	STD_LOGIC;
	 SIGNAL	nli00l	:	STD_LOGIC := '0';
	 SIGNAL	nli0il	:	STD_LOGIC := '0';
	 SIGNAL	niiO0i	:	STD_LOGIC := '0';
	 SIGNAL	niiO0l	:	STD_LOGIC := '0';
	 SIGNAL	niiO0O	:	STD_LOGIC := '0';
	 SIGNAL	niiO1O	:	STD_LOGIC := '0';
	 SIGNAL	niiOii	:	STD_LOGIC := '0';
	 SIGNAL	niiOil	:	STD_LOGIC := '0';
	 SIGNAL	niiOiO	:	STD_LOGIC := '0';
	 SIGNAL	niiOli	:	STD_LOGIC := '0';
	 SIGNAL	niiOll	:	STD_LOGIC := '0';
	 SIGNAL	niiOlO	:	STD_LOGIC := '0';
	 SIGNAL	niiOOi	:	STD_LOGIC := '0';
	 SIGNAL	niiOOl	:	STD_LOGIC := '0';
	 SIGNAL	niiOOO	:	STD_LOGIC := '0';
	 SIGNAL	nil00i	:	STD_LOGIC := '0';
	 SIGNAL	nil00l	:	STD_LOGIC := '0';
	 SIGNAL	nil00O	:	STD_LOGIC := '0';
	 SIGNAL	nil01i	:	STD_LOGIC := '0';
	 SIGNAL	nil01l	:	STD_LOGIC := '0';
	 SIGNAL	nil01O	:	STD_LOGIC := '0';
	 SIGNAL	nil0ii	:	STD_LOGIC := '0';
	 SIGNAL	nil0il	:	STD_LOGIC := '0';
	 SIGNAL	nil0iO	:	STD_LOGIC := '0';
	 SIGNAL	nil0li	:	STD_LOGIC := '0';
	 SIGNAL	nil0ll	:	STD_LOGIC := '0';
	 SIGNAL	nil0lO	:	STD_LOGIC := '0';
	 SIGNAL	nil0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nil0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nil0OO	:	STD_LOGIC := '0';
	 SIGNAL	nil10i	:	STD_LOGIC := '0';
	 SIGNAL	nil10l	:	STD_LOGIC := '0';
	 SIGNAL	nil10O	:	STD_LOGIC := '0';
	 SIGNAL	nil11i	:	STD_LOGIC := '0';
	 SIGNAL	nil11l	:	STD_LOGIC := '0';
	 SIGNAL	nil11O	:	STD_LOGIC := '0';
	 SIGNAL	nil1ii	:	STD_LOGIC := '0';
	 SIGNAL	nil1il	:	STD_LOGIC := '0';
	 SIGNAL	nil1iO	:	STD_LOGIC := '0';
	 SIGNAL	nil1li	:	STD_LOGIC := '0';
	 SIGNAL	nil1ll	:	STD_LOGIC := '0';
	 SIGNAL	nil1lO	:	STD_LOGIC := '0';
	 SIGNAL	nil1Oi	:	STD_LOGIC := '0';
	 SIGNAL	nil1Ol	:	STD_LOGIC := '0';
	 SIGNAL	nil1OO	:	STD_LOGIC := '0';
	 SIGNAL	nili0i	:	STD_LOGIC := '0';
	 SIGNAL	nili0l	:	STD_LOGIC := '0';
	 SIGNAL	nili0O	:	STD_LOGIC := '0';
	 SIGNAL	nili1i	:	STD_LOGIC := '0';
	 SIGNAL	nili1l	:	STD_LOGIC := '0';
	 SIGNAL	nili1O	:	STD_LOGIC := '0';
	 SIGNAL	niliii	:	STD_LOGIC := '0';
	 SIGNAL	niliil	:	STD_LOGIC := '0';
	 SIGNAL	niliiO	:	STD_LOGIC := '0';
	 SIGNAL	nilili	:	STD_LOGIC := '0';
	 SIGNAL	nilill	:	STD_LOGIC := '0';
	 SIGNAL	nililO	:	STD_LOGIC := '0';
	 SIGNAL	niliOi	:	STD_LOGIC := '0';
	 SIGNAL	niliOl	:	STD_LOGIC := '0';
	 SIGNAL	niliOO	:	STD_LOGIC := '0';
	 SIGNAL	nill0i	:	STD_LOGIC := '0';
	 SIGNAL	nill0l	:	STD_LOGIC := '0';
	 SIGNAL	nill0O	:	STD_LOGIC := '0';
	 SIGNAL	nill1i	:	STD_LOGIC := '0';
	 SIGNAL	nill1l	:	STD_LOGIC := '0';
	 SIGNAL	nill1O	:	STD_LOGIC := '0';
	 SIGNAL	nillii	:	STD_LOGIC := '0';
	 SIGNAL	nillil	:	STD_LOGIC := '0';
	 SIGNAL	nilliO	:	STD_LOGIC := '0';
	 SIGNAL	nillli	:	STD_LOGIC := '0';
	 SIGNAL	nillll	:	STD_LOGIC := '0';
	 SIGNAL	nilllO	:	STD_LOGIC := '0';
	 SIGNAL	nillOi	:	STD_LOGIC := '0';
	 SIGNAL	nillOl	:	STD_LOGIC := '0';
	 SIGNAL	nillOO	:	STD_LOGIC := '0';
	 SIGNAL	nilO0i	:	STD_LOGIC := '0';
	 SIGNAL	nilO0l	:	STD_LOGIC := '0';
	 SIGNAL	nilO0O	:	STD_LOGIC := '0';
	 SIGNAL	nilO1i	:	STD_LOGIC := '0';
	 SIGNAL	nilO1l	:	STD_LOGIC := '0';
	 SIGNAL	nilO1O	:	STD_LOGIC := '0';
	 SIGNAL	nilOii	:	STD_LOGIC := '0';
	 SIGNAL	nilOil	:	STD_LOGIC := '0';
	 SIGNAL	nilOiO	:	STD_LOGIC := '0';
	 SIGNAL	nilOli	:	STD_LOGIC := '0';
	 SIGNAL	nilOll	:	STD_LOGIC := '0';
	 SIGNAL	nilOlO	:	STD_LOGIC := '0';
	 SIGNAL	nilOOi	:	STD_LOGIC := '0';
	 SIGNAL	nilOOl	:	STD_LOGIC := '0';
	 SIGNAL	nilOOO	:	STD_LOGIC := '0';
	 SIGNAL	niO00i	:	STD_LOGIC := '0';
	 SIGNAL	niO00l	:	STD_LOGIC := '0';
	 SIGNAL	niO00O	:	STD_LOGIC := '0';
	 SIGNAL	niO01i	:	STD_LOGIC := '0';
	 SIGNAL	niO01l	:	STD_LOGIC := '0';
	 SIGNAL	niO01O	:	STD_LOGIC := '0';
	 SIGNAL	niO0ii	:	STD_LOGIC := '0';
	 SIGNAL	niO0il	:	STD_LOGIC := '0';
	 SIGNAL	niO0iO	:	STD_LOGIC := '0';
	 SIGNAL	niO0li	:	STD_LOGIC := '0';
	 SIGNAL	niO0ll	:	STD_LOGIC := '0';
	 SIGNAL	niO0lO	:	STD_LOGIC := '0';
	 SIGNAL	niO0Oi	:	STD_LOGIC := '0';
	 SIGNAL	niO0Ol	:	STD_LOGIC := '0';
	 SIGNAL	niO0OO	:	STD_LOGIC := '0';
	 SIGNAL	niO10i	:	STD_LOGIC := '0';
	 SIGNAL	niO10l	:	STD_LOGIC := '0';
	 SIGNAL	niO10O	:	STD_LOGIC := '0';
	 SIGNAL	niO11i	:	STD_LOGIC := '0';
	 SIGNAL	niO11l	:	STD_LOGIC := '0';
	 SIGNAL	niO11O	:	STD_LOGIC := '0';
	 SIGNAL	niO1ii	:	STD_LOGIC := '0';
	 SIGNAL	niO1il	:	STD_LOGIC := '0';
	 SIGNAL	niO1iO	:	STD_LOGIC := '0';
	 SIGNAL	niO1li	:	STD_LOGIC := '0';
	 SIGNAL	niO1ll	:	STD_LOGIC := '0';
	 SIGNAL	niO1lO	:	STD_LOGIC := '0';
	 SIGNAL	niO1Oi	:	STD_LOGIC := '0';
	 SIGNAL	niO1Ol	:	STD_LOGIC := '0';
	 SIGNAL	niO1OO	:	STD_LOGIC := '0';
	 SIGNAL	niOi0i	:	STD_LOGIC := '0';
	 SIGNAL	niOi0l	:	STD_LOGIC := '0';
	 SIGNAL	niOi0O	:	STD_LOGIC := '0';
	 SIGNAL	niOi1i	:	STD_LOGIC := '0';
	 SIGNAL	niOi1l	:	STD_LOGIC := '0';
	 SIGNAL	niOi1O	:	STD_LOGIC := '0';
	 SIGNAL	niOiii	:	STD_LOGIC := '0';
	 SIGNAL	nl000i	:	STD_LOGIC := '0';
	 SIGNAL	nl000l	:	STD_LOGIC := '0';
	 SIGNAL	nl000O	:	STD_LOGIC := '0';
	 SIGNAL	nl001i	:	STD_LOGIC := '0';
	 SIGNAL	nl001l	:	STD_LOGIC := '0';
	 SIGNAL	nl001O	:	STD_LOGIC := '0';
	 SIGNAL	nl00ii	:	STD_LOGIC := '0';
	 SIGNAL	nl00il	:	STD_LOGIC := '0';
	 SIGNAL	nl00iO	:	STD_LOGIC := '0';
	 SIGNAL	nl00li	:	STD_LOGIC := '0';
	 SIGNAL	nl00ll	:	STD_LOGIC := '0';
	 SIGNAL	nl00lO	:	STD_LOGIC := '0';
	 SIGNAL	nl00Oi	:	STD_LOGIC := '0';
	 SIGNAL	nl00Ol	:	STD_LOGIC := '0';
	 SIGNAL	nl00OO	:	STD_LOGIC := '0';
	 SIGNAL	nl010i	:	STD_LOGIC := '0';
	 SIGNAL	nl01li	:	STD_LOGIC := '0';
	 SIGNAL	nl01ll	:	STD_LOGIC := '0';
	 SIGNAL	nl01lO	:	STD_LOGIC := '0';
	 SIGNAL	nl01Oi	:	STD_LOGIC := '0';
	 SIGNAL	nl01Ol	:	STD_LOGIC := '0';
	 SIGNAL	nl01OO	:	STD_LOGIC := '0';
	 SIGNAL	nl0i0i	:	STD_LOGIC := '0';
	 SIGNAL	nl0i0l	:	STD_LOGIC := '0';
	 SIGNAL	nl0i0O	:	STD_LOGIC := '0';
	 SIGNAL	nl0i1i	:	STD_LOGIC := '0';
	 SIGNAL	nl0i1l	:	STD_LOGIC := '0';
	 SIGNAL	nl0i1O	:	STD_LOGIC := '0';
	 SIGNAL	nl0iii	:	STD_LOGIC := '0';
	 SIGNAL	nl0iil	:	STD_LOGIC := '0';
	 SIGNAL	nl0iiO	:	STD_LOGIC := '0';
	 SIGNAL	nl0ili	:	STD_LOGIC := '0';
	 SIGNAL	nl0ill	:	STD_LOGIC := '0';
	 SIGNAL	nl0ilO	:	STD_LOGIC := '0';
	 SIGNAL	nl0iOi	:	STD_LOGIC := '0';
	 SIGNAL	nl0iOl	:	STD_LOGIC := '0';
	 SIGNAL	nl0iOO	:	STD_LOGIC := '0';
	 SIGNAL	nl0l0i	:	STD_LOGIC := '0';
	 SIGNAL	nl0l0l	:	STD_LOGIC := '0';
	 SIGNAL	nl0l0O	:	STD_LOGIC := '0';
	 SIGNAL	nl0l1i	:	STD_LOGIC := '0';
	 SIGNAL	nl0l1l	:	STD_LOGIC := '0';
	 SIGNAL	nl0l1O	:	STD_LOGIC := '0';
	 SIGNAL	nl0lii	:	STD_LOGIC := '0';
	 SIGNAL	nl0lil	:	STD_LOGIC := '0';
	 SIGNAL	nl0liO	:	STD_LOGIC := '0';
	 SIGNAL	nl0lli	:	STD_LOGIC := '0';
	 SIGNAL	nl0lll	:	STD_LOGIC := '0';
	 SIGNAL	nl0llO	:	STD_LOGIC := '0';
	 SIGNAL	nl0lOi	:	STD_LOGIC := '0';
	 SIGNAL	nl0lOl	:	STD_LOGIC := '0';
	 SIGNAL	nl0lOO	:	STD_LOGIC := '0';
	 SIGNAL	nl0O0i	:	STD_LOGIC := '0';
	 SIGNAL	nl0O0l	:	STD_LOGIC := '0';
	 SIGNAL	nl0O0O	:	STD_LOGIC := '0';
	 SIGNAL	nl0O1i	:	STD_LOGIC := '0';
	 SIGNAL	nl0O1l	:	STD_LOGIC := '0';
	 SIGNAL	nl0O1O	:	STD_LOGIC := '0';
	 SIGNAL	nl0Oii	:	STD_LOGIC := '0';
	 SIGNAL	nl0Oil	:	STD_LOGIC := '0';
	 SIGNAL	nl0OiO	:	STD_LOGIC := '0';
	 SIGNAL	nl0Oli	:	STD_LOGIC := '0';
	 SIGNAL	nl0Oll	:	STD_LOGIC := '0';
	 SIGNAL	nl0OlO	:	STD_LOGIC := '0';
	 SIGNAL	nl0OOi	:	STD_LOGIC := '0';
	 SIGNAL	nl0OOl	:	STD_LOGIC := '0';
	 SIGNAL	nl0OOO	:	STD_LOGIC := '0';
	 SIGNAL	nli10i	:	STD_LOGIC := '0';
	 SIGNAL	nli10l	:	STD_LOGIC := '0';
	 SIGNAL	nli10O	:	STD_LOGIC := '0';
	 SIGNAL	nli11i	:	STD_LOGIC := '0';
	 SIGNAL	nli11l	:	STD_LOGIC := '0';
	 SIGNAL	nli11O	:	STD_LOGIC := '0';
	 SIGNAL	nli1il	:	STD_LOGIC := '0';
	 SIGNAL	nlO1i1O	:	STD_LOGIC := '0';
	 SIGNAL	wire_nli1ii_PRN	:	STD_LOGIC;
	 SIGNAL  wire_nli1ii_w_lg_niiO0l6511w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1ii_w_lg_niiO0O6509w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1ii_w_lg_niiOii3801w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1ii_w_lg_niiOil6507w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1ii_w_lg_niOi0i600w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1ii_w_lg_niOi0l676w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1ii_w_lg_nl01Oi645w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1ii_w_lg_nlO1i1O604w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nliO1l	:	STD_LOGIC := '0';
	 SIGNAL	nlllOO	:	STD_LOGIC := '0';
	 SIGNAL	nllO0i	:	STD_LOGIC := '0';
	 SIGNAL	nllO0l	:	STD_LOGIC := '0';
	 SIGNAL	nllO0O	:	STD_LOGIC := '0';
	 SIGNAL	nllO1i	:	STD_LOGIC := '0';
	 SIGNAL	nllO1l	:	STD_LOGIC := '0';
	 SIGNAL	nllO1O	:	STD_LOGIC := '0';
	 SIGNAL	nllOii	:	STD_LOGIC := '0';
	 SIGNAL	nllOil	:	STD_LOGIC := '0';
	 SIGNAL	nllOiO	:	STD_LOGIC := '0';
	 SIGNAL	nllOli	:	STD_LOGIC := '0';
	 SIGNAL	nllOll	:	STD_LOGIC := '0';
	 SIGNAL	nllOlO	:	STD_LOGIC := '0';
	 SIGNAL	nllOOi	:	STD_LOGIC := '0';
	 SIGNAL	nllOOl	:	STD_LOGIC := '0';
	 SIGNAL	nllOOO	:	STD_LOGIC := '0';
	 SIGNAL	nlO01l	:	STD_LOGIC := '0';
	 SIGNAL	nlO10i	:	STD_LOGIC := '0';
	 SIGNAL	nlO10l	:	STD_LOGIC := '0';
	 SIGNAL	nlO10O	:	STD_LOGIC := '0';
	 SIGNAL	nlO11i	:	STD_LOGIC := '0';
	 SIGNAL	nlO11l	:	STD_LOGIC := '0';
	 SIGNAL	nlO11O	:	STD_LOGIC := '0';
	 SIGNAL	nlO1ii	:	STD_LOGIC := '0';
	 SIGNAL	nlO1il	:	STD_LOGIC := '0';
	 SIGNAL	nlO1iO	:	STD_LOGIC := '0';
	 SIGNAL	nlO1li	:	STD_LOGIC := '0';
	 SIGNAL	nlO1ll	:	STD_LOGIC := '0';
	 SIGNAL	nlO1lO	:	STD_LOGIC := '0';
	 SIGNAL	nlO1Oi	:	STD_LOGIC := '0';
	 SIGNAL	nlO1Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlO1OO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlO01i_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nlO01i_PRN	:	STD_LOGIC;
	 SIGNAL	nlO1i1l	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlO1i1i_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i1i_PRN	:	STD_LOGIC;
	 SIGNAL  wire_nlO1i1i_w_lg_nlO1i1l613w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nliO1O	:	STD_LOGIC := '0';
	 SIGNAL	nlO00i	:	STD_LOGIC := '0';
	 SIGNAL	nlO00l	:	STD_LOGIC := '0';
	 SIGNAL	nlO00O	:	STD_LOGIC := '0';
	 SIGNAL	nlO01O	:	STD_LOGIC := '0';
	 SIGNAL	nlO0ii	:	STD_LOGIC := '0';
	 SIGNAL	nlO0il	:	STD_LOGIC := '0';
	 SIGNAL	nlO0iO	:	STD_LOGIC := '0';
	 SIGNAL	nlO0li	:	STD_LOGIC := '0';
	 SIGNAL	nlO0ll	:	STD_LOGIC := '0';
	 SIGNAL	nlO0lO	:	STD_LOGIC := '0';
	 SIGNAL	nlO0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nlO0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlO0OO	:	STD_LOGIC := '0';
	 SIGNAL	nlOi0i	:	STD_LOGIC := '0';
	 SIGNAL	nlOi0l	:	STD_LOGIC := '0';
	 SIGNAL	nlOi0O	:	STD_LOGIC := '0';
	 SIGNAL	nlOi1i	:	STD_LOGIC := '0';
	 SIGNAL	nlOi1l	:	STD_LOGIC := '0';
	 SIGNAL	nlOi1O	:	STD_LOGIC := '0';
	 SIGNAL	nlOiii	:	STD_LOGIC := '0';
	 SIGNAL	nlOiil	:	STD_LOGIC := '0';
	 SIGNAL	nlOiiO	:	STD_LOGIC := '0';
	 SIGNAL	nlOili	:	STD_LOGIC := '0';
	 SIGNAL	nlOill	:	STD_LOGIC := '0';
	 SIGNAL	nlOilO	:	STD_LOGIC := '0';
	 SIGNAL	nlOiOi	:	STD_LOGIC := '0';
	 SIGNAL	nlOiOl	:	STD_LOGIC := '0';
	 SIGNAL	nlOiOO	:	STD_LOGIC := '0';
	 SIGNAL	nlOl0l	:	STD_LOGIC := '0';
	 SIGNAL	nlOl1i	:	STD_LOGIC := '0';
	 SIGNAL	nlOl1l	:	STD_LOGIC := '0';
	 SIGNAL	nlOl1O	:	STD_LOGIC := '0';
	 SIGNAL	wire_n0000i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0000l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0000O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0001i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0001O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0100i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0100l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0100O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0101i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0101l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0101O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0110i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0110l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0111i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0111l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0111O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0il0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0il0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0illi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0illl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0illO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0liii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0liil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0liiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0liOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0liOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0liOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1000i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1000l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1000O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1001i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1001O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1100i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1100l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1100O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1101i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1101l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1101O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1110i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1110l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1111i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1111l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1111O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1illi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1illl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1illO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ll1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ll1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1llii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1llil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1llli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1llll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1llOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1llOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1llOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Olii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Olil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Olli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Olll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni000l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni100i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni100l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni100O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni101i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni101l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni101O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1liO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1liO_w_lg_dataout678w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1lli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1lli_w_lg_w_lg_w_lg_dataout679w680w681w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1lli_w_lg_w_lg_dataout679w680w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1lli_w_lg_dataout679w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni1lll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1lll_w_lg_dataout3799w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni1llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niO_w_lg_dataout512w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl100i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl100l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl100O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl101i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl101l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl101O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl110i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl110l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl111i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl111l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl111O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1l0i_w_lg_dataout5769w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl1l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl1l1O_w_lg_dataout5768w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl1lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli_w_lg_dataout535w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nli00O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli00O_w_lg_dataout647w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nli01l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli01l_w_lg_dataout653w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nli0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlilOi_w_lg_dataout523w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlilOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlilOl_w_lg_dataout545w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOliii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOliil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOliiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0iO0O_i	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n0iO0O_o	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0l0lO_i	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0l0lO_o	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0l1iO_i	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0l1iO_o	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_lg_w_o_range432w434w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_lg_w_o_range437w439w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_lg_w_o_range441w443w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_lg_w_o_range445w447w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_lg_w_o_range449w451w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_lg_w_o_range453w455w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_lg_w_o_range457w459w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_lg_w_o_range461w463w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_lg_w_o_range465w467w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_i	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_niOOi_o	:	STD_LOGIC_VECTOR (63 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range433w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range432w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range438w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range437w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range442w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range441w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range446w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range445w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range450w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range449w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range454w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range453w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range458w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range457w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range462w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range461w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range466w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOOi_w_o_range465w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_o_range217w219w223w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_o_range235w237w241w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_o_range253w255w259w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_o_range206w208w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_o_range211w213w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_o_range217w219w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_o_range225w227w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_o_range231w233w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_o_range235w237w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_o_range245w247w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_o_range249w251w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_o_range253w255w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_i	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nliOi_o	:	STD_LOGIC_VECTOR (63 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range207w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range206w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range212w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range211w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range218w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range217w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range226w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range225w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range232w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range231w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range236w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range235w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range246w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range245w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range250w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range249w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range254w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_o_range253w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n00O0i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n00O0i_o	:	STD_LOGIC;
	 SIGNAL  wire_n00O0i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n00O0l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n00O0l_o	:	STD_LOGIC;
	 SIGNAL  wire_n00O0l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n00O0O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n00O0O_o	:	STD_LOGIC;
	 SIGNAL  wire_n00O0O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n00O1i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n00O1i_o	:	STD_LOGIC;
	 SIGNAL  wire_n00O1i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n00O1l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n00O1l_o	:	STD_LOGIC;
	 SIGNAL  wire_n00O1l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n00O1O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n00O1O_o	:	STD_LOGIC;
	 SIGNAL  wire_n00O1O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n00Oii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n00Oii_o	:	STD_LOGIC;
	 SIGNAL  wire_n00Oii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n00Oil_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n00Oil_o	:	STD_LOGIC;
	 SIGNAL  wire_n00Oil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n00OiO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n00OiO_o	:	STD_LOGIC;
	 SIGNAL  wire_n00OiO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n00Oli_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n00Oli_o	:	STD_LOGIC;
	 SIGNAL  wire_n00Oli_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n00Oll_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n00Oll_o	:	STD_LOGIC;
	 SIGNAL  wire_n00Oll_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n00OlO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n00OlO_o	:	STD_LOGIC;
	 SIGNAL  wire_n00OlO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n00OOi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n00OOi_o	:	STD_LOGIC;
	 SIGNAL  wire_n00OOi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n00OOl_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n00OOl_o	:	STD_LOGIC;
	 SIGNAL  wire_n00OOl_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n00OOO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n00OOO_o	:	STD_LOGIC;
	 SIGNAL  wire_n00OOO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i00i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i00i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i00i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i00l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i00l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i00l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i00O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i00O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i00O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i01i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i01i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i01i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i01l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i01l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i01l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i01O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i01O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i01O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i0ii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i0ii_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i0ii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i0il_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i0il_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i0il_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i0iO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i0iO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i0iO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i0li_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i0li_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i0li_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i0ll_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i0ll_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i0ll_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i0lO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i0lO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i0lO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i0Oi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i0Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i0Oi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i0Ol_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i0Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i0Ol_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i0OO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i0OO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i0OO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i10i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i10i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i10i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i10l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i10l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i10l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i10O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i10O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i10O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i11i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i11i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i11i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i11l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i11l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i11l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i11O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i11O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i11O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i1ii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i1ii_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i1ii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i1il_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i1il_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i1il_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i1iO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i1iO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i1iO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i1li_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i1li_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i1li_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i1ll_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i1ll_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i1ll_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i1lO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i1lO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i1lO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i1Oi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i1Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i1Oi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i1Ol_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i1Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i1Ol_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0i1OO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0i1OO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0i1OO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0ii0i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0ii0i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0ii0i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0ii0l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0ii0l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0ii0l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0ii0O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0ii0O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0ii0O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0ii1i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0ii1i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0ii1i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0ii1l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0ii1l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0ii1l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0ii1O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0ii1O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0ii1O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0iiii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0iiii_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iiii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0iiil_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0iiil_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iiil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0iiiO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0iiiO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iiiO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0iili_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0iili_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iili_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0iill_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0iill_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iill_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0iilO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0iilO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iilO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0iiOi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0iiOi_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iiOi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0iiOl_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0iiOl_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iiOl_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0iiOO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0iiOO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0iiOO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0il0i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0il0i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0il0i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0il1i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0il1i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0il1i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0il1l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0il1l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0il1l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0il1O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0il1O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0il1O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0l00l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0l00l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0l00l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0l11l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n0l11l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0l11l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0O00i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0O00i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O00i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0O00l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0O00l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O00l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0O00O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0O00O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O00O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0O01l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0O01l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O01l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0O01O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0O01O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O01O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0O0ii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0O0ii_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O0ii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0O0il_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0O0il_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O0il_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0O0iO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0O0iO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O0iO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0O0li_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0O0li_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O0li_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0O0ll_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0O0ll_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O0ll_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0O0lO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0O0lO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O0lO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0O0Oi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0O0Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O0Oi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0O0Ol_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0O0Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O0Ol_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0O0OO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0O0OO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0O0OO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Oi0i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Oi0i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oi0i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Oi0l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Oi0l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oi0l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Oi0O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Oi0O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oi0O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Oi1i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Oi1i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oi1i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Oi1l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Oi1l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oi1l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Oi1O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Oi1O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oi1O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Oiii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Oiii_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oiii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Oiil_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Oiil_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oiil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OiiO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OiiO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OiiO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Oili_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Oili_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oili_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Oill_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Oill_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oill_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OilO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OilO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OilO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OiOi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OiOi_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OiOi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OiOl_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OiOl_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OiOl_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OiOO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OiOO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OiOO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Ol0i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Ol0i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Ol0i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Ol0l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Ol0l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Ol0l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Ol0O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Ol0O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Ol0O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Ol1i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Ol1i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Ol1i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Ol1l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Ol1l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Ol1l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Ol1O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Ol1O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Ol1O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Olii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Olii_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Olii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Olil_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Olil_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Olil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OliO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OliO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OliO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Olli_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Olli_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Olli_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Olll_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Olll_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Olll_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OllO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OllO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OllO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OlOi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OlOi_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OlOi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OlOl_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OlOl_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OlOl_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OlOO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OlOO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OlOO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OO0i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OO0i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OO0i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OO0l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OO0l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OO0l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OO0O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OO0O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OO0O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OO1i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OO1i_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OO1i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OO1l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OO1l_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OO1l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OO1O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OO1O_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OO1O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OOii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OOii_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OOii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OOil_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OOil_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OOil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OOiO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OOiO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OOiO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OOli_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OOli_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OOli_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OOll_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OOll_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OOll_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OOlO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OOlO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OOlO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OOOi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OOOi_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OOOi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OOOl_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OOOl_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OOOl_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OOOO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OOOO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OOOO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni110i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni110i_o	:	STD_LOGIC;
	 SIGNAL  wire_ni110i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni110l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni110l_o	:	STD_LOGIC;
	 SIGNAL  wire_ni110l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni111i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni111i_o	:	STD_LOGIC;
	 SIGNAL  wire_ni111i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni111l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni111l_o	:	STD_LOGIC;
	 SIGNAL  wire_ni111l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni111O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni111O_o	:	STD_LOGIC;
	 SIGNAL  wire_ni111O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni1i1l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_ni1i1l_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1i1l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_ni1l1O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni1l1O_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1l1O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni1lOi_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_ni1lOi_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1lOi_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_ni1lOl_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_ni1lOl_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1lOl_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_ni1lOO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_ni1lOO_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1lOO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_ni1O1i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_ni1O1i_o	:	STD_LOGIC;
	 SIGNAL  wire_ni1O1i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO000i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO000i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO000i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO000l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO000l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO000l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO000O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO000O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO000O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO001i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO001i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO001i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO001l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO001l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO001l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO001O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO001O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO001O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO00ii_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO00ii_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO00ii_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO00il_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO00il_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO00il_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO00iO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO00iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO00iO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO00li_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO00li_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO00li_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO00ll_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO00ll_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO00ll_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO00lO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO00lO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO00lO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO00Oi_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO00Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO00Oi_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO00Ol_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO00Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO00Ol_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO00OO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO00OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO00OO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO010i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO010i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO010i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO010l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO010l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO010l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO010O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO010O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO010O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO011i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO011i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO011i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO011l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO011l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO011l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO011O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO011O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO011O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO01ii_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO01ii_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO01ii_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO01il_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO01il_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO01il_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO01iO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO01iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO01iO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO01li_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO01li_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO01li_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO01ll_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO01ll_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO01ll_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO01lO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO01lO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO01lO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO01Oi_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO01Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO01Oi_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO01Ol_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO01Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO01Ol_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO01OO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO01OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO01OO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO0i0i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO0i0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0i0i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO0i0l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO0i0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0i0l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO0i0O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO0i0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0i0O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO0i1i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO0i1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0i1i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO0i1l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO0i1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0i1l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO0i1O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO0i1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0i1O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO0iii_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO0iii_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0iii_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO0iil_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO0iil_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0iil_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO0iiO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO0iiO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0iiO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO0ili_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO0ili_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0ili_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1lii_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1lii_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1lii_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1lil_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1lil_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1lil_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1liO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1liO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1liO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1lli_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1lli_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1lli_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1lll_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1lll_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1lll_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1llO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1llO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1llO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1lOi_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1lOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1lOi_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1lOl_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1lOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1lOl_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1lOO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1lOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1lOO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1O0i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1O0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1O0i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1O0l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1O0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1O0l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1O0O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1O0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1O0O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1O1i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1O1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1O1i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1O1l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1O1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1O1l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1O1O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1O1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1O1O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1Oii_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1Oii_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1Oii_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1Oil_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1Oil_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1Oil_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1OiO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1OiO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1OiO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1Oli_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1Oli_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1Oli_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1Oll_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1Oll_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1Oll_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1OlO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1OlO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1OlO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1OOi_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1OOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1OOi_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1OOl_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1OOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1OOl_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlO1OOO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nlO1OOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO1OOO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO1l_data	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_niO1l_o	:	STD_LOGIC;
	 SIGNAL  wire_niO1l_sel	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nli1l_data	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nli1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nli1l_sel	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nl1000i_data_out	:	STD_LOGIC_VECTOR (69 DOWNTO 0);
	 SIGNAL  wire_nl1000i_din	:	STD_LOGIC_VECTOR (69 DOWNTO 0);
	 SIGNAL  wire_vcc	:	STD_LOGIC;
	 SIGNAL  wire_nl1000i_pcs_wrapback_in	:	STD_LOGIC_VECTOR (69 DOWNTO 0);
	 SIGNAL  wire_nl1000i_ph_fifo_empty	:	STD_LOGIC;
	 SIGNAL  wire_nl1000i_ph_fifo_full	:	STD_LOGIC;
	 SIGNAL  wire_nl1000i_rptr_bin	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl1000i_wptr_bin	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rsync_comp_porn490w492w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rsync_comp_porn478w480w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rsync_comp_porn294w297w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rsync_comp_porn286w289w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rautoinsdis499w510w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rautoinsdis499w533w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rsync_sm_dis1w511w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rsync_sm_dis1w534w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_invalid_code_delay_range17w515w516w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl110ll484w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl111OO539w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rrxfifo_urst_en7w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rsync_comp_porn632w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rsync_comp_porn626w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rsync_comp_porn490w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rsync_comp_porn478w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rsync_comp_porn320w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rsync_comp_porn310w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rsync_comp_porn306w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rsync_comp_porn294w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rsync_comp_porn282w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rsync_comp_porn273w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rsync_comp_porn270w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rsync_comp_porn286w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_disp_err_delay_range16w517w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_disp_err_delay_range13w540w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_sync_resync_delay_range514w518w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_sync_resync_delay_range537w541w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOlO0i3798w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOlO0l3797w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOO0li759w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOO0ll758w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOO0lO753w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOO0Oi752w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOi0i735w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOi1i742w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOi1l741w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOi1O736w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOiil729w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOiiO728w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOili724w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOill720w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOiOi714w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOiOl710w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOl0l692w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOl0O688w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOl1i706w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOl1l702w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOl1O698w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOlil684w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOO0l650w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl101ll641w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1110l617w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl111ll574w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rautoinsdis499w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rbytord_s2gx660w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rbytordplden683w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rclkcmpinsertpad522w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rdwidth639w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rfreq_sel609w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rinvalid_code_err_only497w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rsync_sm_dis1w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rwa_6g_en2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rx_we_in_centrl4642w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rx_we_in_quad_down4643w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rx_we_in_quad_up4644w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_soft_reset607w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_invalid_code_delay_range17w515w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_invalid_code_delay_range14w538w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range4891w4918w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range4954w4955w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range4959w4960w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range4964w4965w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range4969w4970w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range4974w4975w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range4979w4980w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5001w5034w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5005w5038w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5009w5042w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5013w5046w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range4894w4921w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5413w5464w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5417w5468w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5421w5472w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5425w5476w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5050w5081w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5053w5084w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5057w5088w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5061w5092w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5065w5096w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5069w5100w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range4898w4925w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5073w5104w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5077w5108w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5117w5154w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5121w5158w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5125w5162w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5129w5166w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5133w5170w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5137w5174w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5141w5178w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5145w5182w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range4902w4929w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range4906w4933w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range4910w4937w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range4914w4941w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range5249w5253w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range4945w4946w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rsync_comp_pat_range4949w4950w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rx_data_rs_range547w548w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rsync_comp_porn273w274w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nl11lil298w302w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nl11OiO262w266w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOlOO671w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOO1i663w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOOli631w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOOOi625w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1100i489w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1100l493w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1101l491w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl110ii479w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl110iO477w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl110li481w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl110lO485w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl110lO470w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl11iiO473w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl11iOl311w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl11l1i307w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl11lil298w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl11lOi283w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl11O0i271w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl11O0i319w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl11OiO290w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl11OiO262w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_soft_reset8w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rx_data_rs_range546w549w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range597w4919w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range597w5017w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range597w5453w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range597w5569w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range597w5082w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range597w5149w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range597w4947w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range588w5373w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range588w5674w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range588w5736w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range588w5487w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range588w5607w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range588w5299w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range587w5375w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range587w5676w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range587w5738w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range587w5489w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range587w5609w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range587w5301w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range586w5304w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range586w5378w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range586w5679w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range586w5741w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range586w5492w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range586w5612w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range585w5307w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range585w5381w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range585w5682w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range585w5744w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range585w5495w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range585w5615w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range584w5310w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range584w5384w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range584w5685w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range584w5747w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range584w5498w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range584w5618w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range583w5313w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range583w5387w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range583w5688w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range583w5750w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range583w5501w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range583w5621w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range582w5316w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range582w5390w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range582w5691w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range582w5753w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range582w5504w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range582w5624w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range581w5319w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range581w5393w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range581w5694w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range581w5756w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range581w5507w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range581w5627w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range331w5396w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range331w5759w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range331w5630w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range580w5399w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range580w5762w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range580w5633w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range596w5019w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range596w5455w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range596w4922w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range596w5571w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range596w5085w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range596w5151w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range596w4951w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range595w4956w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range595w5022w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range595w5458w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range595w5574w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range595w5089w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range595w4926w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range595w5155w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range594w4961w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range594w5025w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range594w5461w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range594w5577w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range594w5093w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range594w5159w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range594w4930w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range593w4966w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range593w5028w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range593w5465w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range593w5580w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range593w5097w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range593w5163w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range593w4934w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range592w4971w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range592w5031w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range592w5469w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range592w5583w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range592w5101w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range592w5167w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range592w4938w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range591w4976w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range591w5035w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range591w5473w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range591w5586w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range591w5105w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range591w5171w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range591w4942w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range590w4981w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range590w5039w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range590w5477w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range590w5589w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range590w5109w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range590w5175w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range590w5296w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range98w5043w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range98w5592w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range98w5179w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range98w5358w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range589w5047w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range589w5595w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range589w5183w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tenb_data_range589w5361w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  niOlO0i :	STD_LOGIC;
	 SIGNAL  niOlO0l :	STD_LOGIC;
	 SIGNAL  niOlO0O :	STD_LOGIC;
	 SIGNAL  niOlO1l :	STD_LOGIC;
	 SIGNAL  niOlO1O :	STD_LOGIC;
	 SIGNAL  niOlOii :	STD_LOGIC;
	 SIGNAL  niOlOil :	STD_LOGIC;
	 SIGNAL  niOlOiO :	STD_LOGIC;
	 SIGNAL  niOlOli :	STD_LOGIC;
	 SIGNAL  niOlOll :	STD_LOGIC;
	 SIGNAL  niOlOlO :	STD_LOGIC;
	 SIGNAL  niOlOOi :	STD_LOGIC;
	 SIGNAL  niOlOOl :	STD_LOGIC;
	 SIGNAL  niOlOOO :	STD_LOGIC;
	 SIGNAL  niOO00i :	STD_LOGIC;
	 SIGNAL  niOO00l :	STD_LOGIC;
	 SIGNAL  niOO00O :	STD_LOGIC;
	 SIGNAL  niOO01i :	STD_LOGIC;
	 SIGNAL  niOO01l :	STD_LOGIC;
	 SIGNAL  niOO01O :	STD_LOGIC;
	 SIGNAL  niOO0ii :	STD_LOGIC;
	 SIGNAL  niOO0il :	STD_LOGIC;
	 SIGNAL  niOO0iO :	STD_LOGIC;
	 SIGNAL  niOO0li :	STD_LOGIC;
	 SIGNAL  niOO0ll :	STD_LOGIC;
	 SIGNAL  niOO0lO :	STD_LOGIC;
	 SIGNAL  niOO0Oi :	STD_LOGIC;
	 SIGNAL  niOO0Ol :	STD_LOGIC;
	 SIGNAL  niOO0OO :	STD_LOGIC;
	 SIGNAL  niOO10i :	STD_LOGIC;
	 SIGNAL  niOO10l :	STD_LOGIC;
	 SIGNAL  niOO10O :	STD_LOGIC;
	 SIGNAL  niOO11i :	STD_LOGIC;
	 SIGNAL  niOO11l :	STD_LOGIC;
	 SIGNAL  niOO11O :	STD_LOGIC;
	 SIGNAL  niOO1ii :	STD_LOGIC;
	 SIGNAL  niOO1il :	STD_LOGIC;
	 SIGNAL  niOO1iO :	STD_LOGIC;
	 SIGNAL  niOO1li :	STD_LOGIC;
	 SIGNAL  niOO1ll :	STD_LOGIC;
	 SIGNAL  niOO1lO :	STD_LOGIC;
	 SIGNAL  niOO1Oi :	STD_LOGIC;
	 SIGNAL  niOO1Ol :	STD_LOGIC;
	 SIGNAL  niOO1OO :	STD_LOGIC;
	 SIGNAL  niOOi0i :	STD_LOGIC;
	 SIGNAL  niOOi0l :	STD_LOGIC;
	 SIGNAL  niOOi0O :	STD_LOGIC;
	 SIGNAL  niOOi1i :	STD_LOGIC;
	 SIGNAL  niOOi1l :	STD_LOGIC;
	 SIGNAL  niOOi1O :	STD_LOGIC;
	 SIGNAL  niOOiii :	STD_LOGIC;
	 SIGNAL  niOOiil :	STD_LOGIC;
	 SIGNAL  niOOiiO :	STD_LOGIC;
	 SIGNAL  niOOili :	STD_LOGIC;
	 SIGNAL  niOOill :	STD_LOGIC;
	 SIGNAL  niOOilO :	STD_LOGIC;
	 SIGNAL  niOOiOi :	STD_LOGIC;
	 SIGNAL  niOOiOl :	STD_LOGIC;
	 SIGNAL  niOOiOO :	STD_LOGIC;
	 SIGNAL  niOOl0i :	STD_LOGIC;
	 SIGNAL  niOOl0l :	STD_LOGIC;
	 SIGNAL  niOOl0O :	STD_LOGIC;
	 SIGNAL  niOOl1i :	STD_LOGIC;
	 SIGNAL  niOOl1l :	STD_LOGIC;
	 SIGNAL  niOOl1O :	STD_LOGIC;
	 SIGNAL  niOOlii :	STD_LOGIC;
	 SIGNAL  niOOlil :	STD_LOGIC;
	 SIGNAL  niOOliO :	STD_LOGIC;
	 SIGNAL  niOOlli :	STD_LOGIC;
	 SIGNAL  niOOlll :	STD_LOGIC;
	 SIGNAL  niOOllO :	STD_LOGIC;
	 SIGNAL  niOOlOi :	STD_LOGIC;
	 SIGNAL  niOOlOl :	STD_LOGIC;
	 SIGNAL  niOOlOO :	STD_LOGIC;
	 SIGNAL  niOOO0l :	STD_LOGIC;
	 SIGNAL  niOOO1i :	STD_LOGIC;
	 SIGNAL  niOOOii :	STD_LOGIC;
	 SIGNAL  niOOOil :	STD_LOGIC;
	 SIGNAL  niOOOiO :	STD_LOGIC;
	 SIGNAL  niOOOli :	STD_LOGIC;
	 SIGNAL  niOOOll :	STD_LOGIC;
	 SIGNAL  niOOOlO :	STD_LOGIC;
	 SIGNAL  niOOOOi :	STD_LOGIC;
	 SIGNAL  niOOOOl :	STD_LOGIC;
	 SIGNAL  nl1010i :	STD_LOGIC;
	 SIGNAL  nl101il :	STD_LOGIC;
	 SIGNAL  nl101ll :	STD_LOGIC;
	 SIGNAL  nl101Ol :	STD_LOGIC;
	 SIGNAL  nl1100i :	STD_LOGIC;
	 SIGNAL  nl1100l :	STD_LOGIC;
	 SIGNAL  nl1100O :	STD_LOGIC;
	 SIGNAL  nl1101i :	STD_LOGIC;
	 SIGNAL  nl1101l :	STD_LOGIC;
	 SIGNAL  nl1101O :	STD_LOGIC;
	 SIGNAL  nl110ii :	STD_LOGIC;
	 SIGNAL  nl110il :	STD_LOGIC;
	 SIGNAL  nl110iO :	STD_LOGIC;
	 SIGNAL  nl110li :	STD_LOGIC;
	 SIGNAL  nl110ll :	STD_LOGIC;
	 SIGNAL  nl110lO :	STD_LOGIC;
	 SIGNAL  nl110Oi :	STD_LOGIC;
	 SIGNAL  nl110Ol :	STD_LOGIC;
	 SIGNAL  nl110OO :	STD_LOGIC;
	 SIGNAL  nl1110i :	STD_LOGIC;
	 SIGNAL  nl1110l :	STD_LOGIC;
	 SIGNAL  nl1110O :	STD_LOGIC;
	 SIGNAL  nl1111l :	STD_LOGIC;
	 SIGNAL  nl1111O :	STD_LOGIC;
	 SIGNAL  nl111il :	STD_LOGIC;
	 SIGNAL  nl111iO :	STD_LOGIC;
	 SIGNAL  nl111li :	STD_LOGIC;
	 SIGNAL  nl111ll :	STD_LOGIC;
	 SIGNAL  nl111lO :	STD_LOGIC;
	 SIGNAL  nl111Oi :	STD_LOGIC;
	 SIGNAL  nl111Ol :	STD_LOGIC;
	 SIGNAL  nl111OO :	STD_LOGIC;
	 SIGNAL  nl11i0i :	STD_LOGIC;
	 SIGNAL  nl11i0l :	STD_LOGIC;
	 SIGNAL  nl11i0O :	STD_LOGIC;
	 SIGNAL  nl11i1i :	STD_LOGIC;
	 SIGNAL  nl11i1l :	STD_LOGIC;
	 SIGNAL  nl11i1O :	STD_LOGIC;
	 SIGNAL  nl11iii :	STD_LOGIC;
	 SIGNAL  nl11iil :	STD_LOGIC;
	 SIGNAL  nl11iiO :	STD_LOGIC;
	 SIGNAL  nl11ili :	STD_LOGIC;
	 SIGNAL  nl11ill :	STD_LOGIC;
	 SIGNAL  nl11ilO :	STD_LOGIC;
	 SIGNAL  nl11iOi :	STD_LOGIC;
	 SIGNAL  nl11iOl :	STD_LOGIC;
	 SIGNAL  nl11iOO :	STD_LOGIC;
	 SIGNAL  nl11l1i :	STD_LOGIC;
	 SIGNAL  nl11lii :	STD_LOGIC;
	 SIGNAL  nl11lil :	STD_LOGIC;
	 SIGNAL  nl11llO :	STD_LOGIC;
	 SIGNAL  nl11lOi :	STD_LOGIC;
	 SIGNAL  nl11O0i :	STD_LOGIC;
	 SIGNAL  nl11O0l :	STD_LOGIC;
	 SIGNAL  nl11O1l :	STD_LOGIC;
	 SIGNAL  nl11O1O :	STD_LOGIC;
	 SIGNAL  nl11Oil :	STD_LOGIC;
	 SIGNAL  nl11OiO :	STD_LOGIC;
	 SIGNAL  wire_w_disp_err_delay_range16w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_disp_err_delay_range13w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_invalid_code_delay_range17w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_invalid_code_delay_range14w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range4891w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range4954w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range4959w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range4964w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range4969w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range4974w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range4979w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5001w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5005w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5009w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5013w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range4894w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5413w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5417w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5421w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5425w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5050w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5053w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5057w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5061w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5065w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5069w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range4898w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5073w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5077w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5117w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5121w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5125w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5129w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5133w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5137w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5141w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5145w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range4902w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range4906w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range4910w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range4914w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range5249w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range4945w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_pat_range4949w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_size_range101w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rsync_comp_size_range105w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rx_data_rs_range546w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rx_data_rs_range547w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_sync_resync_delay_range514w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_sync_resync_delay_range537w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range597w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range588w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range587w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range586w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range585w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range584w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range583w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range582w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range581w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range331w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range580w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range596w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range595w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range594w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range593w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range592w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range591w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range590w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range98w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tenb_data_range589w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 COMPONENT  stratixiv_hssi_rx_digis_ph_fifo
	 PORT
	 ( 
		data_out	:	OUT STD_LOGIC_VECTOR(69 DOWNTO 0);
		din	:	IN STD_LOGIC_VECTOR(69 DOWNTO 0);
		en	:	IN STD_LOGIC;
		lowlatency_en	:	IN STD_LOGIC;
		pcs_wrapback_in	:	IN STD_LOGIC_VECTOR(69 DOWNTO 0);
		ph_fifo_empty	:	OUT STD_LOGIC;
		ph_fifo_full	:	OUT STD_LOGIC;
		rauto_speed_ena	:	IN STD_LOGIC;
		rd_clk	:	IN STD_LOGIC;
		re	:	IN STD_LOGIC;
		reset_pc_ptrs	:	IN STD_LOGIC;
		reset_pc_ptrs_centrl	:	IN STD_LOGIC;
		reset_pc_ptrs_quad_down	:	IN STD_LOGIC;
		reset_pc_ptrs_quad_up	:	IN STD_LOGIC;
		rindv_rx	:	IN STD_LOGIC;
		rmaster_rx	:	IN STD_LOGIC;
		rmaster_up_rx	:	IN STD_LOGIC;
		rpcs_wrapback_en	:	IN STD_LOGIC;
		rphfifo_regmode_rx	:	IN STD_LOGIC;
		rptr_bin	:	OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
		rst_rclk	:	IN STD_LOGIC;
		rst_wclk	:	IN STD_LOGIC;
		scan_mode	:	IN STD_LOGIC;
		we	:	IN STD_LOGIC;
		wptr_bin	:	OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
		wr_clk	:	IN STD_LOGIC
	 ); 
	 END COMPONENT;
 BEGIN

	wire_vcc <= '1';
	wire_w_lg_w_lg_rsync_comp_porn490w492w(0) <= wire_w_lg_rsync_comp_porn490w(0) AND wire_w_lg_nl1101l491w(0);
	wire_w_lg_w_lg_rsync_comp_porn478w480w(0) <= wire_w_lg_rsync_comp_porn478w(0) AND wire_w_lg_nl110ii479w(0);
	wire_w_lg_w_lg_rsync_comp_porn294w297w(0) <= wire_w_lg_rsync_comp_porn294w(0) AND wire_nl11l0l36_w_lg_q296w(0);
	wire_w_lg_w_lg_rsync_comp_porn286w289w(0) <= wire_w_lg_rsync_comp_porn286w(0) AND wire_nl11lli32_w_lg_q288w(0);
	wire_w_lg_w_lg_rautoinsdis499w510w(0) <= wire_w_lg_rautoinsdis499w(0) AND wire_nlilOi_dataout;
	wire_w_lg_w_lg_rautoinsdis499w533w(0) <= wire_w_lg_rautoinsdis499w(0) AND wire_nlilOl_dataout;
	wire_w_lg_w_lg_rsync_sm_dis1w511w(0) <= wire_w_lg_rsync_sm_dis1w(0) AND wire_w_lg_w_lg_rautoinsdis499w510w(0);
	wire_w_lg_w_lg_rsync_sm_dis1w534w(0) <= wire_w_lg_rsync_sm_dis1w(0) AND wire_w_lg_w_lg_rautoinsdis499w533w(0);
	wire_w_lg_w_lg_w_invalid_code_delay_range17w515w516w(0) <= wire_w_lg_w_invalid_code_delay_range17w515w(0) AND nl111OO;
	wire_w_lg_nl110ll484w(0) <= nl110ll AND rsync_comp_porn;
	wire_w_lg_nl111OO539w(0) <= nl111OO AND wire_w_lg_w_invalid_code_delay_range14w538w(0);
	wire_w_lg_rrxfifo_urst_en7w(0) <= rrxfifo_urst_en AND rxfifo_urst;
	wire_w_lg_rsync_comp_porn632w(0) <= rsync_comp_porn AND wire_w_lg_niOOOli631w(0);
	wire_w_lg_rsync_comp_porn626w(0) <= rsync_comp_porn AND wire_w_lg_niOOOOi625w(0);
	wire_w_lg_rsync_comp_porn490w(0) <= rsync_comp_porn AND wire_w_lg_nl1100i489w(0);
	wire_w_lg_rsync_comp_porn478w(0) <= rsync_comp_porn AND wire_w_lg_nl110iO477w(0);
	wire_w_lg_rsync_comp_porn320w(0) <= rsync_comp_porn AND wire_w_lg_nl11O0i319w(0);
	wire_w_lg_rsync_comp_porn310w(0) <= rsync_comp_porn AND nl11iOi;
	wire_w_lg_rsync_comp_porn306w(0) <= rsync_comp_porn AND nl11iOO;
	wire_w_lg_rsync_comp_porn294w(0) <= rsync_comp_porn AND nl11lii;
	wire_w_lg_rsync_comp_porn282w(0) <= rsync_comp_porn AND nl11llO;
	wire_w_lg_rsync_comp_porn273w(0) <= rsync_comp_porn AND nl11O1l;
	wire_w_lg_rsync_comp_porn270w(0) <= rsync_comp_porn AND nl11O1O;
	wire_w_lg_rsync_comp_porn286w(0) <= rsync_comp_porn AND nl11Oil;
	wire_w_lg_w_disp_err_delay_range16w517w(0) <= wire_w_disp_err_delay_range16w(0) AND wire_w_lg_w_lg_w_invalid_code_delay_range17w515w516w(0);
	wire_w_lg_w_disp_err_delay_range13w540w(0) <= wire_w_disp_err_delay_range13w(0) AND wire_w_lg_nl111OO539w(0);
	wire_w_lg_w_sync_resync_delay_range514w518w(0) <= wire_w_sync_resync_delay_range514w(0) AND wire_w_lg_w_disp_err_delay_range16w517w(0);
	wire_w_lg_w_sync_resync_delay_range537w541w(0) <= wire_w_sync_resync_delay_range537w(0) AND wire_w_lg_w_disp_err_delay_range13w540w(0);
	wire_w_lg_niOlO0i3798w(0) <= NOT niOlO0i;
	wire_w_lg_niOlO0l3797w(0) <= NOT niOlO0l;
	wire_w_lg_niOO0li759w(0) <= NOT niOO0li;
	wire_w_lg_niOO0ll758w(0) <= NOT niOO0ll;
	wire_w_lg_niOO0lO753w(0) <= NOT niOO0lO;
	wire_w_lg_niOO0Oi752w(0) <= NOT niOO0Oi;
	wire_w_lg_niOOi0i735w(0) <= NOT niOOi0i;
	wire_w_lg_niOOi1i742w(0) <= NOT niOOi1i;
	wire_w_lg_niOOi1l741w(0) <= NOT niOOi1l;
	wire_w_lg_niOOi1O736w(0) <= NOT niOOi1O;
	wire_w_lg_niOOiil729w(0) <= NOT niOOiil;
	wire_w_lg_niOOiiO728w(0) <= NOT niOOiiO;
	wire_w_lg_niOOili724w(0) <= NOT niOOili;
	wire_w_lg_niOOill720w(0) <= NOT niOOill;
	wire_w_lg_niOOiOi714w(0) <= NOT niOOiOi;
	wire_w_lg_niOOiOl710w(0) <= NOT niOOiOl;
	wire_w_lg_niOOl0l692w(0) <= NOT niOOl0l;
	wire_w_lg_niOOl0O688w(0) <= NOT niOOl0O;
	wire_w_lg_niOOl1i706w(0) <= NOT niOOl1i;
	wire_w_lg_niOOl1l702w(0) <= NOT niOOl1l;
	wire_w_lg_niOOl1O698w(0) <= NOT niOOl1O;
	wire_w_lg_niOOlil684w(0) <= NOT niOOlil;
	wire_w_lg_niOOO0l650w(0) <= NOT niOOO0l;
	wire_w_lg_nl101ll641w(0) <= NOT nl101ll;
	wire_w_lg_nl1110l617w(0) <= NOT nl1110l;
	wire_w_lg_nl111ll574w(0) <= NOT nl111ll;
	wire_w_lg_rautoinsdis499w(0) <= NOT rautoinsdis;
	wire_w_lg_rbytord_s2gx660w(0) <= NOT rbytord_s2gx;
	wire_w_lg_rbytordplden683w(0) <= NOT rbytordplden;
	wire_w_lg_rclkcmpinsertpad522w(0) <= NOT rclkcmpinsertpad;
	wire_w_lg_rdwidth639w(0) <= NOT rdwidth;
	wire_w_lg_rfreq_sel609w(0) <= NOT rfreq_sel;
	wire_w_lg_rinvalid_code_err_only497w(0) <= NOT rinvalid_code_err_only;
	wire_w_lg_rsync_sm_dis1w(0) <= NOT rsync_sm_dis;
	wire_w_lg_rwa_6g_en2w(0) <= NOT rwa_6g_en;
	wire_w_lg_rx_we_in_centrl4642w(0) <= NOT rx_we_in_centrl;
	wire_w_lg_rx_we_in_quad_down4643w(0) <= NOT rx_we_in_quad_down;
	wire_w_lg_rx_we_in_quad_up4644w(0) <= NOT rx_we_in_quad_up;
	wire_w_lg_soft_reset607w(0) <= NOT soft_reset;
	wire_w_lg_w_invalid_code_delay_range17w515w(0) <= NOT wire_w_invalid_code_delay_range17w(0);
	wire_w_lg_w_invalid_code_delay_range14w538w(0) <= NOT wire_w_invalid_code_delay_range14w(0);
	wire_w_lg_w_rsync_comp_pat_range4891w4918w(0) <= NOT wire_w_rsync_comp_pat_range4891w(0);
	wire_w_lg_w_rsync_comp_pat_range4954w4955w(0) <= NOT wire_w_rsync_comp_pat_range4954w(0);
	wire_w_lg_w_rsync_comp_pat_range4959w4960w(0) <= NOT wire_w_rsync_comp_pat_range4959w(0);
	wire_w_lg_w_rsync_comp_pat_range4964w4965w(0) <= NOT wire_w_rsync_comp_pat_range4964w(0);
	wire_w_lg_w_rsync_comp_pat_range4969w4970w(0) <= NOT wire_w_rsync_comp_pat_range4969w(0);
	wire_w_lg_w_rsync_comp_pat_range4974w4975w(0) <= NOT wire_w_rsync_comp_pat_range4974w(0);
	wire_w_lg_w_rsync_comp_pat_range4979w4980w(0) <= NOT wire_w_rsync_comp_pat_range4979w(0);
	wire_w_lg_w_rsync_comp_pat_range5001w5034w(0) <= NOT wire_w_rsync_comp_pat_range5001w(0);
	wire_w_lg_w_rsync_comp_pat_range5005w5038w(0) <= NOT wire_w_rsync_comp_pat_range5005w(0);
	wire_w_lg_w_rsync_comp_pat_range5009w5042w(0) <= NOT wire_w_rsync_comp_pat_range5009w(0);
	wire_w_lg_w_rsync_comp_pat_range5013w5046w(0) <= NOT wire_w_rsync_comp_pat_range5013w(0);
	wire_w_lg_w_rsync_comp_pat_range4894w4921w(0) <= NOT wire_w_rsync_comp_pat_range4894w(0);
	wire_w_lg_w_rsync_comp_pat_range5413w5464w(0) <= NOT wire_w_rsync_comp_pat_range5413w(0);
	wire_w_lg_w_rsync_comp_pat_range5417w5468w(0) <= NOT wire_w_rsync_comp_pat_range5417w(0);
	wire_w_lg_w_rsync_comp_pat_range5421w5472w(0) <= NOT wire_w_rsync_comp_pat_range5421w(0);
	wire_w_lg_w_rsync_comp_pat_range5425w5476w(0) <= NOT wire_w_rsync_comp_pat_range5425w(0);
	wire_w_lg_w_rsync_comp_pat_range5050w5081w(0) <= NOT wire_w_rsync_comp_pat_range5050w(0);
	wire_w_lg_w_rsync_comp_pat_range5053w5084w(0) <= NOT wire_w_rsync_comp_pat_range5053w(0);
	wire_w_lg_w_rsync_comp_pat_range5057w5088w(0) <= NOT wire_w_rsync_comp_pat_range5057w(0);
	wire_w_lg_w_rsync_comp_pat_range5061w5092w(0) <= NOT wire_w_rsync_comp_pat_range5061w(0);
	wire_w_lg_w_rsync_comp_pat_range5065w5096w(0) <= NOT wire_w_rsync_comp_pat_range5065w(0);
	wire_w_lg_w_rsync_comp_pat_range5069w5100w(0) <= NOT wire_w_rsync_comp_pat_range5069w(0);
	wire_w_lg_w_rsync_comp_pat_range4898w4925w(0) <= NOT wire_w_rsync_comp_pat_range4898w(0);
	wire_w_lg_w_rsync_comp_pat_range5073w5104w(0) <= NOT wire_w_rsync_comp_pat_range5073w(0);
	wire_w_lg_w_rsync_comp_pat_range5077w5108w(0) <= NOT wire_w_rsync_comp_pat_range5077w(0);
	wire_w_lg_w_rsync_comp_pat_range5117w5154w(0) <= NOT wire_w_rsync_comp_pat_range5117w(0);
	wire_w_lg_w_rsync_comp_pat_range5121w5158w(0) <= NOT wire_w_rsync_comp_pat_range5121w(0);
	wire_w_lg_w_rsync_comp_pat_range5125w5162w(0) <= NOT wire_w_rsync_comp_pat_range5125w(0);
	wire_w_lg_w_rsync_comp_pat_range5129w5166w(0) <= NOT wire_w_rsync_comp_pat_range5129w(0);
	wire_w_lg_w_rsync_comp_pat_range5133w5170w(0) <= NOT wire_w_rsync_comp_pat_range5133w(0);
	wire_w_lg_w_rsync_comp_pat_range5137w5174w(0) <= NOT wire_w_rsync_comp_pat_range5137w(0);
	wire_w_lg_w_rsync_comp_pat_range5141w5178w(0) <= NOT wire_w_rsync_comp_pat_range5141w(0);
	wire_w_lg_w_rsync_comp_pat_range5145w5182w(0) <= NOT wire_w_rsync_comp_pat_range5145w(0);
	wire_w_lg_w_rsync_comp_pat_range4902w4929w(0) <= NOT wire_w_rsync_comp_pat_range4902w(0);
	wire_w_lg_w_rsync_comp_pat_range4906w4933w(0) <= NOT wire_w_rsync_comp_pat_range4906w(0);
	wire_w_lg_w_rsync_comp_pat_range4910w4937w(0) <= NOT wire_w_rsync_comp_pat_range4910w(0);
	wire_w_lg_w_rsync_comp_pat_range4914w4941w(0) <= NOT wire_w_rsync_comp_pat_range4914w(0);
	wire_w_lg_w_rsync_comp_pat_range5249w5253w(0) <= NOT wire_w_rsync_comp_pat_range5249w(0);
	wire_w_lg_w_rsync_comp_pat_range4945w4946w(0) <= NOT wire_w_rsync_comp_pat_range4945w(0);
	wire_w_lg_w_rsync_comp_pat_range4949w4950w(0) <= NOT wire_w_rsync_comp_pat_range4949w(0);
	wire_w_lg_w_rx_data_rs_range547w548w(0) <= NOT wire_w_rx_data_rs_range547w(0);
	wire_w_lg_w_lg_rsync_comp_porn273w274w(0) <= wire_w_lg_rsync_comp_porn273w(0) OR nl101il;
	wire_w_lg_w_lg_nl11lil298w302w(0) <= wire_w_lg_nl11lil298w(0) OR wire_nl11l1O38_w_lg_w_lg_q300w301w(0);
	wire_w_lg_w_lg_nl11OiO262w266w(0) <= wire_w_lg_nl11OiO262w(0) OR wire_nl11O0O26_w_lg_w_lg_q264w265w(0);
	wire_w_lg_niOOlOO671w(0) <= niOOlOO OR wire_n1ill_w_lg_n1iil670w(0);
	wire_w_lg_niOOO1i663w(0) <= niOOO1i OR wire_n1ill_w_lg_w_lg_n1ili661w662w(0);
	wire_w_lg_niOOOli631w(0) <= niOOOli OR niOOOiO;
	wire_w_lg_niOOOOi625w(0) <= niOOOOi OR niOOOlO;
	wire_w_lg_nl1100i489w(0) <= nl1100i OR nl1101O;
	wire_w_lg_nl1100l493w(0) <= nl1100l OR wire_w_lg_w_lg_rsync_comp_porn490w492w(0);
	wire_w_lg_nl1101l491w(0) <= nl1101l OR nl1101i;
	wire_w_lg_nl110ii479w(0) <= nl110ii OR nl1100O;
	wire_w_lg_nl110iO477w(0) <= nl110iO OR nl110il;
	wire_w_lg_nl110li481w(0) <= nl110li OR wire_w_lg_w_lg_rsync_comp_porn478w480w(0);
	wire_w_lg_nl110lO485w(0) <= nl110lO OR wire_w_lg_nl110ll484w(0);
	wire_w_lg_nl110lO470w(0) <= nl110lO OR nl110ll;
	wire_w_lg_nl11iiO473w(0) <= nl11iiO OR nl11iil;
	wire_w_lg_nl11iOl311w(0) <= nl11iOl OR wire_w_lg_rsync_comp_porn310w(0);
	wire_w_lg_nl11l1i307w(0) <= nl11l1i OR wire_w_lg_rsync_comp_porn306w(0);
	wire_w_lg_nl11lil298w(0) <= nl11lil OR wire_w_lg_w_lg_rsync_comp_porn294w297w(0);
	wire_w_lg_nl11lOi283w(0) <= nl11lOi OR wire_w_lg_rsync_comp_porn282w(0);
	wire_w_lg_nl11O0i271w(0) <= nl11O0i OR wire_w_lg_rsync_comp_porn270w(0);
	wire_w_lg_nl11O0i319w(0) <= nl11O0i OR nl11O1O;
	wire_w_lg_nl11OiO290w(0) <= nl11OiO OR wire_w_lg_w_lg_rsync_comp_porn286w289w(0);
	wire_w_lg_nl11OiO262w(0) <= nl11OiO OR nl11Oil;
	wire_w_lg_soft_reset8w(0) <= soft_reset OR wire_w_lg_rrxfifo_urst_en7w(0);
	wire_w_lg_w_rx_data_rs_range546w549w(0) <= wire_w_rx_data_rs_range546w(0) OR wire_w_lg_w_rx_data_rs_range547w548w(0);
	wire_w_lg_w_tenb_data_range597w4919w(0) <= wire_w_tenb_data_range597w(0) XOR wire_w_lg_w_rsync_comp_pat_range4891w4918w(0);
	wire_w_lg_w_tenb_data_range597w5017w(0) <= wire_w_tenb_data_range597w(0) XOR wire_w_lg_w_rsync_comp_pat_range4954w4955w(0);
	wire_w_lg_w_tenb_data_range597w5453w(0) <= wire_w_tenb_data_range597w(0) XOR wire_w_lg_w_rsync_comp_pat_range5001w5034w(0);
	wire_w_lg_w_tenb_data_range597w5569w(0) <= wire_w_tenb_data_range597w(0) XOR wire_w_lg_w_rsync_comp_pat_range5413w5464w(0);
	wire_w_lg_w_tenb_data_range597w5082w(0) <= wire_w_tenb_data_range597w(0) XOR wire_w_lg_w_rsync_comp_pat_range5050w5081w(0);
	wire_w_lg_w_tenb_data_range597w5149w(0) <= wire_w_tenb_data_range597w(0) XOR wire_w_lg_w_rsync_comp_pat_range5073w5104w(0);
	wire_w_lg_w_tenb_data_range597w4947w(0) <= wire_w_tenb_data_range597w(0) XOR wire_w_lg_w_rsync_comp_pat_range4945w4946w(0);
	wire_w_lg_w_tenb_data_range588w5373w(0) <= wire_w_tenb_data_range588w(0) XOR wire_w_lg_w_rsync_comp_pat_range4954w4955w(0);
	wire_w_lg_w_tenb_data_range588w5674w(0) <= wire_w_tenb_data_range588w(0) XOR wire_w_lg_w_rsync_comp_pat_range5001w5034w(0);
	wire_w_lg_w_tenb_data_range588w5736w(0) <= wire_w_tenb_data_range588w(0) XOR wire_w_lg_w_rsync_comp_pat_range5413w5464w(0);
	wire_w_lg_w_tenb_data_range588w5487w(0) <= wire_w_tenb_data_range588w(0) XOR wire_w_lg_w_rsync_comp_pat_range5050w5081w(0);
	wire_w_lg_w_tenb_data_range588w5607w(0) <= wire_w_tenb_data_range588w(0) XOR wire_w_lg_w_rsync_comp_pat_range5073w5104w(0);
	wire_w_lg_w_tenb_data_range588w5299w(0) <= wire_w_tenb_data_range588w(0) XOR wire_w_lg_w_rsync_comp_pat_range4945w4946w(0);
	wire_w_lg_w_tenb_data_range587w5375w(0) <= wire_w_tenb_data_range587w(0) XOR wire_w_lg_w_rsync_comp_pat_range4959w4960w(0);
	wire_w_lg_w_tenb_data_range587w5676w(0) <= wire_w_tenb_data_range587w(0) XOR wire_w_lg_w_rsync_comp_pat_range5005w5038w(0);
	wire_w_lg_w_tenb_data_range587w5738w(0) <= wire_w_tenb_data_range587w(0) XOR wire_w_lg_w_rsync_comp_pat_range5417w5468w(0);
	wire_w_lg_w_tenb_data_range587w5489w(0) <= wire_w_tenb_data_range587w(0) XOR wire_w_lg_w_rsync_comp_pat_range5053w5084w(0);
	wire_w_lg_w_tenb_data_range587w5609w(0) <= wire_w_tenb_data_range587w(0) XOR wire_w_lg_w_rsync_comp_pat_range5077w5108w(0);
	wire_w_lg_w_tenb_data_range587w5301w(0) <= wire_w_tenb_data_range587w(0) XOR wire_w_lg_w_rsync_comp_pat_range4949w4950w(0);
	wire_w_lg_w_tenb_data_range586w5304w(0) <= wire_w_tenb_data_range586w(0) XOR wire_w_lg_w_rsync_comp_pat_range4954w4955w(0);
	wire_w_lg_w_tenb_data_range586w5378w(0) <= wire_w_tenb_data_range586w(0) XOR wire_w_lg_w_rsync_comp_pat_range4964w4965w(0);
	wire_w_lg_w_tenb_data_range586w5679w(0) <= wire_w_tenb_data_range586w(0) XOR wire_w_lg_w_rsync_comp_pat_range5009w5042w(0);
	wire_w_lg_w_tenb_data_range586w5741w(0) <= wire_w_tenb_data_range586w(0) XOR wire_w_lg_w_rsync_comp_pat_range5421w5472w(0);
	wire_w_lg_w_tenb_data_range586w5492w(0) <= wire_w_tenb_data_range586w(0) XOR wire_w_lg_w_rsync_comp_pat_range5057w5088w(0);
	wire_w_lg_w_tenb_data_range586w5612w(0) <= wire_w_tenb_data_range586w(0) XOR wire_w_lg_w_rsync_comp_pat_range5117w5154w(0);
	wire_w_lg_w_tenb_data_range585w5307w(0) <= wire_w_tenb_data_range585w(0) XOR wire_w_lg_w_rsync_comp_pat_range4959w4960w(0);
	wire_w_lg_w_tenb_data_range585w5381w(0) <= wire_w_tenb_data_range585w(0) XOR wire_w_lg_w_rsync_comp_pat_range4969w4970w(0);
	wire_w_lg_w_tenb_data_range585w5682w(0) <= wire_w_tenb_data_range585w(0) XOR wire_w_lg_w_rsync_comp_pat_range5013w5046w(0);
	wire_w_lg_w_tenb_data_range585w5744w(0) <= wire_w_tenb_data_range585w(0) XOR wire_w_lg_w_rsync_comp_pat_range5425w5476w(0);
	wire_w_lg_w_tenb_data_range585w5495w(0) <= wire_w_tenb_data_range585w(0) XOR wire_w_lg_w_rsync_comp_pat_range5061w5092w(0);
	wire_w_lg_w_tenb_data_range585w5615w(0) <= wire_w_tenb_data_range585w(0) XOR wire_w_lg_w_rsync_comp_pat_range5121w5158w(0);
	wire_w_lg_w_tenb_data_range584w5310w(0) <= wire_w_tenb_data_range584w(0) XOR wire_w_lg_w_rsync_comp_pat_range4964w4965w(0);
	wire_w_lg_w_tenb_data_range584w5384w(0) <= wire_w_tenb_data_range584w(0) XOR wire_w_lg_w_rsync_comp_pat_range4974w4975w(0);
	wire_w_lg_w_tenb_data_range584w5685w(0) <= wire_w_tenb_data_range584w(0) XOR wire_w_lg_w_rsync_comp_pat_range5413w5464w(0);
	wire_w_lg_w_tenb_data_range584w5747w(0) <= wire_w_tenb_data_range584w(0) XOR wire_w_lg_w_rsync_comp_pat_range5050w5081w(0);
	wire_w_lg_w_tenb_data_range584w5498w(0) <= wire_w_tenb_data_range584w(0) XOR wire_w_lg_w_rsync_comp_pat_range5065w5096w(0);
	wire_w_lg_w_tenb_data_range584w5618w(0) <= wire_w_tenb_data_range584w(0) XOR wire_w_lg_w_rsync_comp_pat_range5125w5162w(0);
	wire_w_lg_w_tenb_data_range583w5313w(0) <= wire_w_tenb_data_range583w(0) XOR wire_w_lg_w_rsync_comp_pat_range4969w4970w(0);
	wire_w_lg_w_tenb_data_range583w5387w(0) <= wire_w_tenb_data_range583w(0) XOR wire_w_lg_w_rsync_comp_pat_range4979w4980w(0);
	wire_w_lg_w_tenb_data_range583w5688w(0) <= wire_w_tenb_data_range583w(0) XOR wire_w_lg_w_rsync_comp_pat_range5417w5468w(0);
	wire_w_lg_w_tenb_data_range583w5750w(0) <= wire_w_tenb_data_range583w(0) XOR wire_w_lg_w_rsync_comp_pat_range5053w5084w(0);
	wire_w_lg_w_tenb_data_range583w5501w(0) <= wire_w_tenb_data_range583w(0) XOR wire_w_lg_w_rsync_comp_pat_range5069w5100w(0);
	wire_w_lg_w_tenb_data_range583w5621w(0) <= wire_w_tenb_data_range583w(0) XOR wire_w_lg_w_rsync_comp_pat_range5129w5166w(0);
	wire_w_lg_w_tenb_data_range582w5316w(0) <= wire_w_tenb_data_range582w(0) XOR wire_w_lg_w_rsync_comp_pat_range4974w4975w(0);
	wire_w_lg_w_tenb_data_range582w5390w(0) <= wire_w_tenb_data_range582w(0) XOR wire_w_lg_w_rsync_comp_pat_range5001w5034w(0);
	wire_w_lg_w_tenb_data_range582w5691w(0) <= wire_w_tenb_data_range582w(0) XOR wire_w_lg_w_rsync_comp_pat_range5421w5472w(0);
	wire_w_lg_w_tenb_data_range582w5753w(0) <= wire_w_tenb_data_range582w(0) XOR wire_w_lg_w_rsync_comp_pat_range5057w5088w(0);
	wire_w_lg_w_tenb_data_range582w5504w(0) <= wire_w_tenb_data_range582w(0) XOR wire_w_lg_w_rsync_comp_pat_range5073w5104w(0);
	wire_w_lg_w_tenb_data_range582w5624w(0) <= wire_w_tenb_data_range582w(0) XOR wire_w_lg_w_rsync_comp_pat_range5133w5170w(0);
	wire_w_lg_w_tenb_data_range581w5319w(0) <= wire_w_tenb_data_range581w(0) XOR wire_w_lg_w_rsync_comp_pat_range4979w4980w(0);
	wire_w_lg_w_tenb_data_range581w5393w(0) <= wire_w_tenb_data_range581w(0) XOR wire_w_lg_w_rsync_comp_pat_range5005w5038w(0);
	wire_w_lg_w_tenb_data_range581w5694w(0) <= wire_w_tenb_data_range581w(0) XOR wire_w_lg_w_rsync_comp_pat_range5425w5476w(0);
	wire_w_lg_w_tenb_data_range581w5756w(0) <= wire_w_tenb_data_range581w(0) XOR wire_w_lg_w_rsync_comp_pat_range5061w5092w(0);
	wire_w_lg_w_tenb_data_range581w5507w(0) <= wire_w_tenb_data_range581w(0) XOR wire_w_lg_w_rsync_comp_pat_range5077w5108w(0);
	wire_w_lg_w_tenb_data_range581w5627w(0) <= wire_w_tenb_data_range581w(0) XOR wire_w_lg_w_rsync_comp_pat_range5137w5174w(0);
	wire_w_lg_w_tenb_data_range331w5396w(0) <= wire_w_tenb_data_range331w(0) XOR wire_w_lg_w_rsync_comp_pat_range5009w5042w(0);
	wire_w_lg_w_tenb_data_range331w5759w(0) <= wire_w_tenb_data_range331w(0) XOR wire_w_lg_w_rsync_comp_pat_range5065w5096w(0);
	wire_w_lg_w_tenb_data_range331w5630w(0) <= wire_w_tenb_data_range331w(0) XOR wire_w_lg_w_rsync_comp_pat_range5141w5178w(0);
	wire_w_lg_w_tenb_data_range580w5399w(0) <= wire_w_tenb_data_range580w(0) XOR wire_w_lg_w_rsync_comp_pat_range5013w5046w(0);
	wire_w_lg_w_tenb_data_range580w5762w(0) <= wire_w_tenb_data_range580w(0) XOR wire_w_lg_w_rsync_comp_pat_range5069w5100w(0);
	wire_w_lg_w_tenb_data_range580w5633w(0) <= wire_w_tenb_data_range580w(0) XOR wire_w_lg_w_rsync_comp_pat_range5145w5182w(0);
	wire_w_lg_w_tenb_data_range596w5019w(0) <= wire_w_tenb_data_range596w(0) XOR wire_w_lg_w_rsync_comp_pat_range4959w4960w(0);
	wire_w_lg_w_tenb_data_range596w5455w(0) <= wire_w_tenb_data_range596w(0) XOR wire_w_lg_w_rsync_comp_pat_range5005w5038w(0);
	wire_w_lg_w_tenb_data_range596w4922w(0) <= wire_w_tenb_data_range596w(0) XOR wire_w_lg_w_rsync_comp_pat_range4894w4921w(0);
	wire_w_lg_w_tenb_data_range596w5571w(0) <= wire_w_tenb_data_range596w(0) XOR wire_w_lg_w_rsync_comp_pat_range5417w5468w(0);
	wire_w_lg_w_tenb_data_range596w5085w(0) <= wire_w_tenb_data_range596w(0) XOR wire_w_lg_w_rsync_comp_pat_range5053w5084w(0);
	wire_w_lg_w_tenb_data_range596w5151w(0) <= wire_w_tenb_data_range596w(0) XOR wire_w_lg_w_rsync_comp_pat_range5077w5108w(0);
	wire_w_lg_w_tenb_data_range596w4951w(0) <= wire_w_tenb_data_range596w(0) XOR wire_w_lg_w_rsync_comp_pat_range4949w4950w(0);
	wire_w_lg_w_tenb_data_range595w4956w(0) <= wire_w_tenb_data_range595w(0) XOR wire_w_lg_w_rsync_comp_pat_range4954w4955w(0);
	wire_w_lg_w_tenb_data_range595w5022w(0) <= wire_w_tenb_data_range595w(0) XOR wire_w_lg_w_rsync_comp_pat_range4964w4965w(0);
	wire_w_lg_w_tenb_data_range595w5458w(0) <= wire_w_tenb_data_range595w(0) XOR wire_w_lg_w_rsync_comp_pat_range5009w5042w(0);
	wire_w_lg_w_tenb_data_range595w5574w(0) <= wire_w_tenb_data_range595w(0) XOR wire_w_lg_w_rsync_comp_pat_range5421w5472w(0);
	wire_w_lg_w_tenb_data_range595w5089w(0) <= wire_w_tenb_data_range595w(0) XOR wire_w_lg_w_rsync_comp_pat_range5057w5088w(0);
	wire_w_lg_w_tenb_data_range595w4926w(0) <= wire_w_tenb_data_range595w(0) XOR wire_w_lg_w_rsync_comp_pat_range4898w4925w(0);
	wire_w_lg_w_tenb_data_range595w5155w(0) <= wire_w_tenb_data_range595w(0) XOR wire_w_lg_w_rsync_comp_pat_range5117w5154w(0);
	wire_w_lg_w_tenb_data_range594w4961w(0) <= wire_w_tenb_data_range594w(0) XOR wire_w_lg_w_rsync_comp_pat_range4959w4960w(0);
	wire_w_lg_w_tenb_data_range594w5025w(0) <= wire_w_tenb_data_range594w(0) XOR wire_w_lg_w_rsync_comp_pat_range4969w4970w(0);
	wire_w_lg_w_tenb_data_range594w5461w(0) <= wire_w_tenb_data_range594w(0) XOR wire_w_lg_w_rsync_comp_pat_range5013w5046w(0);
	wire_w_lg_w_tenb_data_range594w5577w(0) <= wire_w_tenb_data_range594w(0) XOR wire_w_lg_w_rsync_comp_pat_range5425w5476w(0);
	wire_w_lg_w_tenb_data_range594w5093w(0) <= wire_w_tenb_data_range594w(0) XOR wire_w_lg_w_rsync_comp_pat_range5061w5092w(0);
	wire_w_lg_w_tenb_data_range594w5159w(0) <= wire_w_tenb_data_range594w(0) XOR wire_w_lg_w_rsync_comp_pat_range5121w5158w(0);
	wire_w_lg_w_tenb_data_range594w4930w(0) <= wire_w_tenb_data_range594w(0) XOR wire_w_lg_w_rsync_comp_pat_range4902w4929w(0);
	wire_w_lg_w_tenb_data_range593w4966w(0) <= wire_w_tenb_data_range593w(0) XOR wire_w_lg_w_rsync_comp_pat_range4964w4965w(0);
	wire_w_lg_w_tenb_data_range593w5028w(0) <= wire_w_tenb_data_range593w(0) XOR wire_w_lg_w_rsync_comp_pat_range4974w4975w(0);
	wire_w_lg_w_tenb_data_range593w5465w(0) <= wire_w_tenb_data_range593w(0) XOR wire_w_lg_w_rsync_comp_pat_range5413w5464w(0);
	wire_w_lg_w_tenb_data_range593w5580w(0) <= wire_w_tenb_data_range593w(0) XOR wire_w_lg_w_rsync_comp_pat_range5050w5081w(0);
	wire_w_lg_w_tenb_data_range593w5097w(0) <= wire_w_tenb_data_range593w(0) XOR wire_w_lg_w_rsync_comp_pat_range5065w5096w(0);
	wire_w_lg_w_tenb_data_range593w5163w(0) <= wire_w_tenb_data_range593w(0) XOR wire_w_lg_w_rsync_comp_pat_range5125w5162w(0);
	wire_w_lg_w_tenb_data_range593w4934w(0) <= wire_w_tenb_data_range593w(0) XOR wire_w_lg_w_rsync_comp_pat_range4906w4933w(0);
	wire_w_lg_w_tenb_data_range592w4971w(0) <= wire_w_tenb_data_range592w(0) XOR wire_w_lg_w_rsync_comp_pat_range4969w4970w(0);
	wire_w_lg_w_tenb_data_range592w5031w(0) <= wire_w_tenb_data_range592w(0) XOR wire_w_lg_w_rsync_comp_pat_range4979w4980w(0);
	wire_w_lg_w_tenb_data_range592w5469w(0) <= wire_w_tenb_data_range592w(0) XOR wire_w_lg_w_rsync_comp_pat_range5417w5468w(0);
	wire_w_lg_w_tenb_data_range592w5583w(0) <= wire_w_tenb_data_range592w(0) XOR wire_w_lg_w_rsync_comp_pat_range5053w5084w(0);
	wire_w_lg_w_tenb_data_range592w5101w(0) <= wire_w_tenb_data_range592w(0) XOR wire_w_lg_w_rsync_comp_pat_range5069w5100w(0);
	wire_w_lg_w_tenb_data_range592w5167w(0) <= wire_w_tenb_data_range592w(0) XOR wire_w_lg_w_rsync_comp_pat_range5129w5166w(0);
	wire_w_lg_w_tenb_data_range592w4938w(0) <= wire_w_tenb_data_range592w(0) XOR wire_w_lg_w_rsync_comp_pat_range4910w4937w(0);
	wire_w_lg_w_tenb_data_range591w4976w(0) <= wire_w_tenb_data_range591w(0) XOR wire_w_lg_w_rsync_comp_pat_range4974w4975w(0);
	wire_w_lg_w_tenb_data_range591w5035w(0) <= wire_w_tenb_data_range591w(0) XOR wire_w_lg_w_rsync_comp_pat_range5001w5034w(0);
	wire_w_lg_w_tenb_data_range591w5473w(0) <= wire_w_tenb_data_range591w(0) XOR wire_w_lg_w_rsync_comp_pat_range5421w5472w(0);
	wire_w_lg_w_tenb_data_range591w5586w(0) <= wire_w_tenb_data_range591w(0) XOR wire_w_lg_w_rsync_comp_pat_range5057w5088w(0);
	wire_w_lg_w_tenb_data_range591w5105w(0) <= wire_w_tenb_data_range591w(0) XOR wire_w_lg_w_rsync_comp_pat_range5073w5104w(0);
	wire_w_lg_w_tenb_data_range591w5171w(0) <= wire_w_tenb_data_range591w(0) XOR wire_w_lg_w_rsync_comp_pat_range5133w5170w(0);
	wire_w_lg_w_tenb_data_range591w4942w(0) <= wire_w_tenb_data_range591w(0) XOR wire_w_lg_w_rsync_comp_pat_range4914w4941w(0);
	wire_w_lg_w_tenb_data_range590w4981w(0) <= wire_w_tenb_data_range590w(0) XOR wire_w_lg_w_rsync_comp_pat_range4979w4980w(0);
	wire_w_lg_w_tenb_data_range590w5039w(0) <= wire_w_tenb_data_range590w(0) XOR wire_w_lg_w_rsync_comp_pat_range5005w5038w(0);
	wire_w_lg_w_tenb_data_range590w5477w(0) <= wire_w_tenb_data_range590w(0) XOR wire_w_lg_w_rsync_comp_pat_range5425w5476w(0);
	wire_w_lg_w_tenb_data_range590w5589w(0) <= wire_w_tenb_data_range590w(0) XOR wire_w_lg_w_rsync_comp_pat_range5061w5092w(0);
	wire_w_lg_w_tenb_data_range590w5109w(0) <= wire_w_tenb_data_range590w(0) XOR wire_w_lg_w_rsync_comp_pat_range5077w5108w(0);
	wire_w_lg_w_tenb_data_range590w5175w(0) <= wire_w_tenb_data_range590w(0) XOR wire_w_lg_w_rsync_comp_pat_range5137w5174w(0);
	wire_w_lg_w_tenb_data_range590w5296w(0) <= wire_w_tenb_data_range590w(0) XOR wire_w_lg_w_rsync_comp_pat_range5249w5253w(0);
	wire_w_lg_w_tenb_data_range98w5043w(0) <= wire_w_tenb_data_range98w(0) XOR wire_w_lg_w_rsync_comp_pat_range5009w5042w(0);
	wire_w_lg_w_tenb_data_range98w5592w(0) <= wire_w_tenb_data_range98w(0) XOR wire_w_lg_w_rsync_comp_pat_range5065w5096w(0);
	wire_w_lg_w_tenb_data_range98w5179w(0) <= wire_w_tenb_data_range98w(0) XOR wire_w_lg_w_rsync_comp_pat_range5141w5178w(0);
	wire_w_lg_w_tenb_data_range98w5358w(0) <= wire_w_tenb_data_range98w(0) XOR wire_w_lg_w_rsync_comp_pat_range4945w4946w(0);
	wire_w_lg_w_tenb_data_range589w5047w(0) <= wire_w_tenb_data_range589w(0) XOR wire_w_lg_w_rsync_comp_pat_range5013w5046w(0);
	wire_w_lg_w_tenb_data_range589w5595w(0) <= wire_w_tenb_data_range589w(0) XOR wire_w_lg_w_rsync_comp_pat_range5069w5100w(0);
	wire_w_lg_w_tenb_data_range589w5183w(0) <= wire_w_tenb_data_range589w(0) XOR wire_w_lg_w_rsync_comp_pat_range5145w5182w(0);
	wire_w_lg_w_tenb_data_range589w5361w(0) <= wire_w_tenb_data_range589w(0) XOR wire_w_lg_w_rsync_comp_pat_range4949w4950w(0);
	bytord_valid_out <= wire_nlOll_dataout;
	niOlO0i <= ((wire_nli1ii_w_lg_niiOii3801w(0) OR niiO0O) OR niiO0l);
	niOlO0l <= (wire_ni1lli_w_lg_dataout679w(0) OR wire_ni1lll_w_lg_dataout3799w(0));
	niOlO0O <= (wire_nli1ii_w_lg_niiO0O6509w(0) AND wire_nli1ii_w_lg_niiO0l6511w(0));
	niOlO1l <= (wire_nl1l1O_dataout AND niiO0i);
	niOlO1O <= (n1i0O AND (wire_nl1l1O_dataout AND wire_ni1liO_dataout));
	niOlOii <= (niiO0O AND wire_nli1ii_w_lg_niiO0l6511w(0));
	niOlOil <= (wire_ni1lli_dataout AND wire_ni1liO_w_lg_dataout678w(0));
	niOlOiO <= ((wire_n0l1iO_o(6) OR wire_n0l1iO_o(4)) OR wire_n0l1iO_o(2));
	niOlOli <= ((((((wire_n0l0lO_o(14) OR wire_n0l0lO_o(12)) OR wire_n0l0lO_o(10)) OR wire_n0l0lO_o(8)) OR wire_n0l0lO_o(6)) OR wire_n0l0lO_o(4)) OR wire_n0l0lO_o(2));
	niOlOll <= (niOlOOi OR niOlOlO);
	niOlOlO <= ((((((((((NOT (niliOi XOR (NOT rbytordpat(0)))) AND (NOT (niliOl XOR (NOT rbytordpat(1))))) AND (NOT (niliOO XOR (NOT rbytordpat(2))))) AND (NOT (nill1i XOR (NOT rbytordpat(3))))) AND (NOT (nill1l XOR (NOT rbytordpat(4))))) AND (NOT (nill1O XOR (NOT rbytordpat(5))))) AND (NOT (nill0i XOR (NOT rbytordpat(6))))) AND (NOT (nill0l XOR (NOT rbytordpat(7))))) AND (NOT (nill0O XOR (NOT rbytordpat(8))))) AND (NOT (nillii XOR (NOT rbytordpat(9)))));
	niOlOOi <= ((((((((((NOT (niliOi XOR rbytordpat(0))) AND (NOT (niliOl XOR rbytordpat(1)))) AND (NOT (niliOO XOR rbytordpat(2)))) AND (NOT (nill1i XOR rbytordpat(3)))) AND (NOT (nill1l XOR rbytordpat(4)))) AND (NOT (nill1O XOR rbytordpat(5)))) AND (NOT (nill0i XOR rbytordpat(6)))) AND (NOT (nill0l XOR rbytordpat(7)))) AND (NOT (nill0O XOR rbytordpat(8)))) AND (NOT (nillii XOR rbytordpat(9))));
	niOlOOl <= ((((((((((NOT (nillOl XOR (NOT rbytordpat(10)))) AND (NOT (nillOO XOR (NOT rbytordpat(11))))) AND (NOT (nilO1i XOR (NOT rbytordpat(12))))) AND (NOT (nilO1l XOR (NOT rbytordpat(13))))) AND (NOT (nilO1O XOR (NOT rbytordpat(14))))) AND (NOT (nilO0i XOR (NOT rbytordpat(15))))) AND (NOT (nilO0l XOR (NOT rbytordpat(16))))) AND (NOT (nilO0O XOR (NOT rbytordpat(17))))) AND (NOT (nilOii XOR (NOT rbytordpat(18))))) AND (NOT (nilOil XOR (NOT rbytordpat(19)))));
	niOlOOO <= ((((((((((NOT (nillOl XOR rbytordpat(10))) AND (NOT (nillOO XOR rbytordpat(11)))) AND (NOT (nilO1i XOR rbytordpat(12)))) AND (NOT (nilO1l XOR rbytordpat(13)))) AND (NOT (nilO1O XOR rbytordpat(14)))) AND (NOT (nilO0i XOR rbytordpat(15)))) AND (NOT (nilO0l XOR rbytordpat(16)))) AND (NOT (nilO0O XOR rbytordpat(17)))) AND (NOT (nilOii XOR rbytordpat(18)))) AND (NOT (nilOil XOR rbytordpat(19))));
	niOO00i <= ((((((((NOT (niliOi XOR rbytordpat(0))) AND (NOT (niliOl XOR rbytordpat(1)))) AND (NOT (niliOO XOR rbytordpat(2)))) AND (NOT (nill1i XOR rbytordpat(3)))) AND (NOT (nill1l XOR rbytordpat(4)))) AND (NOT (nill1O XOR rbytordpat(5)))) AND (NOT (nill0i XOR rbytordpat(6)))) AND (NOT (nill0l XOR rbytordpat(7))));
	niOO00l <= ((((((((NOT (nillOl XOR rbytordpat(10))) AND (NOT (nillOO XOR rbytordpat(11)))) AND (NOT (nilO1i XOR rbytordpat(12)))) AND (NOT (nilO1l XOR rbytordpat(13)))) AND (NOT (nilO1O XOR rbytordpat(14)))) AND (NOT (nilO0i XOR rbytordpat(15)))) AND (NOT (nilO0l XOR rbytordpat(16)))) AND (NOT (nilO0O XOR rbytordpat(17))));
	niOO00O <= ((((((((NOT (nillOl XOR rbytordpat(0))) AND (NOT (nillOO XOR rbytordpat(1)))) AND (NOT (nilO1i XOR rbytordpat(2)))) AND (NOT (nilO1l XOR rbytordpat(3)))) AND (NOT (nilO1O XOR rbytordpat(4)))) AND (NOT (nilO0i XOR rbytordpat(5)))) AND (NOT (nilO0l XOR rbytordpat(6)))) AND (NOT (nilO0O XOR rbytordpat(7))));
	niOO01i <= (((((((((NOT (nilOOO XOR rbytordpat(10))) AND (NOT (niO11i XOR rbytordpat(11)))) AND (NOT (niO11l XOR rbytordpat(12)))) AND (NOT (niO11O XOR rbytordpat(13)))) AND (NOT (niO10i XOR rbytordpat(14)))) AND (NOT (niO10l XOR rbytordpat(15)))) AND (NOT (niO10O XOR rbytordpat(16)))) AND (NOT (niO1ii XOR rbytordpat(17)))) AND (NOT (niO1il XOR rbytordpat(18))));
	niOO01l <= (((((((((NOT (niO01i XOR rbytordpat(10))) AND (NOT (niO01l XOR rbytordpat(11)))) AND (NOT (niO01O XOR rbytordpat(12)))) AND (NOT (niO00i XOR rbytordpat(13)))) AND (NOT (niO00l XOR rbytordpat(14)))) AND (NOT (niO00O XOR rbytordpat(15)))) AND (NOT (niO0ii XOR rbytordpat(16)))) AND (NOT (niO0il XOR rbytordpat(17)))) AND (NOT (niO0iO XOR rbytordpat(18))));
	niOO01O <= (((((((((NOT (wire_niOlOl_dataout XOR rbytordpat(10))) AND (NOT (wire_niOlOO_dataout XOR rbytordpat(11)))) AND (NOT (wire_niOO1i_dataout XOR rbytordpat(12)))) AND (NOT (wire_niOO1l_dataout XOR rbytordpat(13)))) AND (NOT (wire_niOO1O_dataout XOR rbytordpat(14)))) AND (NOT (wire_niOO0i_dataout XOR rbytordpat(15)))) AND (NOT (wire_niOO0l_dataout XOR rbytordpat(16)))) AND (NOT (wire_niOO0O_dataout XOR rbytordpat(17)))) AND (NOT (wire_niOOii_dataout XOR rbytordpat(18))));
	niOO0ii <= ((((((((NOT (nilOOO XOR rbytordpat(10))) AND (NOT (niO11i XOR rbytordpat(11)))) AND (NOT (niO11l XOR rbytordpat(12)))) AND (NOT (niO11O XOR rbytordpat(13)))) AND (NOT (niO10i XOR rbytordpat(14)))) AND (NOT (niO10l XOR rbytordpat(15)))) AND (NOT (niO10O XOR rbytordpat(16)))) AND (NOT (niO1ii XOR rbytordpat(17))));
	niOO0il <= ((((((((NOT (niO01i XOR rbytordpat(10))) AND (NOT (niO01l XOR rbytordpat(11)))) AND (NOT (niO01O XOR rbytordpat(12)))) AND (NOT (niO00i XOR rbytordpat(13)))) AND (NOT (niO00l XOR rbytordpat(14)))) AND (NOT (niO00O XOR rbytordpat(15)))) AND (NOT (niO0ii XOR rbytordpat(16)))) AND (NOT (niO0il XOR rbytordpat(17))));
	niOO0iO <= ((((((((NOT (wire_niOlOl_dataout XOR rbytordpat(10))) AND (NOT (wire_niOlOO_dataout XOR rbytordpat(11)))) AND (NOT (wire_niOO1i_dataout XOR rbytordpat(12)))) AND (NOT (wire_niOO1l_dataout XOR rbytordpat(13)))) AND (NOT (wire_niOO1O_dataout XOR rbytordpat(14)))) AND (NOT (wire_niOO0i_dataout XOR rbytordpat(15)))) AND (NOT (wire_niOO0l_dataout XOR rbytordpat(16)))) AND (NOT (wire_niOO0O_dataout XOR rbytordpat(17))));
	niOO0li <= ((((((((((NOT (niO01i XOR (NOT rbytordpat(0)))) AND (NOT (niO01l XOR (NOT rbytordpat(1))))) AND (NOT (niO01O XOR (NOT rbytordpat(2))))) AND (NOT (niO00i XOR (NOT rbytordpat(3))))) AND (NOT (niO00l XOR (NOT rbytordpat(4))))) AND (NOT (niO00O XOR (NOT rbytordpat(5))))) AND (NOT (niO0ii XOR (NOT rbytordpat(6))))) AND (NOT (niO0il XOR (NOT rbytordpat(7))))) AND (NOT (niO0iO XOR (NOT rbytordpat(8))))) AND (NOT (niO0li XOR (NOT rbytordpat(9)))));
	niOO0ll <= ((((((((((NOT (niO01i XOR rbytordpat(0))) AND (NOT (niO01l XOR rbytordpat(1)))) AND (NOT (niO01O XOR rbytordpat(2)))) AND (NOT (niO00i XOR rbytordpat(3)))) AND (NOT (niO00l XOR rbytordpat(4)))) AND (NOT (niO00O XOR rbytordpat(5)))) AND (NOT (niO0ii XOR rbytordpat(6)))) AND (NOT (niO0il XOR rbytordpat(7)))) AND (NOT (niO0iO XOR rbytordpat(8)))) AND (NOT (niO0li XOR rbytordpat(9))));
	niOO0lO <= ((((((((((NOT (nilOOO XOR (NOT rbytordpat(0)))) AND (NOT (niO11i XOR (NOT rbytordpat(1))))) AND (NOT (niO11l XOR (NOT rbytordpat(2))))) AND (NOT (niO11O XOR (NOT rbytordpat(3))))) AND (NOT (niO10i XOR (NOT rbytordpat(4))))) AND (NOT (niO10l XOR (NOT rbytordpat(5))))) AND (NOT (niO10O XOR (NOT rbytordpat(6))))) AND (NOT (niO1ii XOR (NOT rbytordpat(7))))) AND (NOT (niO1il XOR (NOT rbytordpat(8))))) AND (NOT (niO1iO XOR (NOT rbytordpat(9)))));
	niOO0Oi <= ((((((((((NOT (nilOOO XOR rbytordpat(0))) AND (NOT (niO11i XOR rbytordpat(1)))) AND (NOT (niO11l XOR rbytordpat(2)))) AND (NOT (niO11O XOR rbytordpat(3)))) AND (NOT (niO10i XOR rbytordpat(4)))) AND (NOT (niO10l XOR rbytordpat(5)))) AND (NOT (niO10O XOR rbytordpat(6)))) AND (NOT (niO1ii XOR rbytordpat(7)))) AND (NOT (niO1il XOR rbytordpat(8)))) AND (NOT (niO1iO XOR rbytordpat(9))));
	niOO0Ol <= (niOOi1l OR niOOi1i);
	niOO0OO <= (wire_w_lg_rbytordplden683w(0) OR (wire_w_lg_niOOi1l741w(0) AND wire_w_lg_niOOi1i742w(0)));
	niOO10i <= (niOO10O OR niOO10l);
	niOO10l <= ((((((((((NOT (nilOOO XOR (NOT rbytordpat(10)))) AND (NOT (niO11i XOR (NOT rbytordpat(11))))) AND (NOT (niO11l XOR (NOT rbytordpat(12))))) AND (NOT (niO11O XOR (NOT rbytordpat(13))))) AND (NOT (niO10i XOR (NOT rbytordpat(14))))) AND (NOT (niO10l XOR (NOT rbytordpat(15))))) AND (NOT (niO10O XOR (NOT rbytordpat(16))))) AND (NOT (niO1ii XOR (NOT rbytordpat(17))))) AND (NOT (niO1il XOR (NOT rbytordpat(18))))) AND (NOT (niO1iO XOR (NOT rbytordpat(19)))));
	niOO10O <= ((((((((((NOT (nilOOO XOR rbytordpat(10))) AND (NOT (niO11i XOR rbytordpat(11)))) AND (NOT (niO11l XOR rbytordpat(12)))) AND (NOT (niO11O XOR rbytordpat(13)))) AND (NOT (niO10i XOR rbytordpat(14)))) AND (NOT (niO10l XOR rbytordpat(15)))) AND (NOT (niO10O XOR rbytordpat(16)))) AND (NOT (niO1ii XOR rbytordpat(17)))) AND (NOT (niO1il XOR rbytordpat(18)))) AND (NOT (niO1iO XOR rbytordpat(19))));
	niOO11i <= (niOO11O OR niOO11l);
	niOO11l <= ((((((((((NOT (nillOl XOR (NOT rbytordpat(0)))) AND (NOT (nillOO XOR (NOT rbytordpat(1))))) AND (NOT (nilO1i XOR (NOT rbytordpat(2))))) AND (NOT (nilO1l XOR (NOT rbytordpat(3))))) AND (NOT (nilO1O XOR (NOT rbytordpat(4))))) AND (NOT (nilO0i XOR (NOT rbytordpat(5))))) AND (NOT (nilO0l XOR (NOT rbytordpat(6))))) AND (NOT (nilO0O XOR (NOT rbytordpat(7))))) AND (NOT (nilOii XOR (NOT rbytordpat(8))))) AND (NOT (nilOil XOR (NOT rbytordpat(9)))));
	niOO11O <= ((((((((((NOT (nillOl XOR rbytordpat(0))) AND (NOT (nillOO XOR rbytordpat(1)))) AND (NOT (nilO1i XOR rbytordpat(2)))) AND (NOT (nilO1l XOR rbytordpat(3)))) AND (NOT (nilO1O XOR rbytordpat(4)))) AND (NOT (nilO0i XOR rbytordpat(5)))) AND (NOT (nilO0l XOR rbytordpat(6)))) AND (NOT (nilO0O XOR rbytordpat(7)))) AND (NOT (nilOii XOR rbytordpat(8)))) AND (NOT (nilOil XOR rbytordpat(9))));
	niOO1ii <= (niOO0Oi OR niOO0lO);
	niOO1il <= ((((((((((NOT (niO01i XOR (NOT rbytordpat(10)))) AND (NOT (niO01l XOR (NOT rbytordpat(11))))) AND (NOT (niO01O XOR (NOT rbytordpat(12))))) AND (NOT (niO00i XOR (NOT rbytordpat(13))))) AND (NOT (niO00l XOR (NOT rbytordpat(14))))) AND (NOT (niO00O XOR (NOT rbytordpat(15))))) AND (NOT (niO0ii XOR (NOT rbytordpat(16))))) AND (NOT (niO0il XOR (NOT rbytordpat(17))))) AND (NOT (niO0iO XOR (NOT rbytordpat(18))))) AND (NOT (niO0li XOR (NOT rbytordpat(19)))));
	niOO1iO <= ((((((((((NOT (niO01i XOR rbytordpat(10))) AND (NOT (niO01l XOR rbytordpat(11)))) AND (NOT (niO01O XOR rbytordpat(12)))) AND (NOT (niO00i XOR rbytordpat(13)))) AND (NOT (niO00l XOR rbytordpat(14)))) AND (NOT (niO00O XOR rbytordpat(15)))) AND (NOT (niO0ii XOR rbytordpat(16)))) AND (NOT (niO0il XOR rbytordpat(17)))) AND (NOT (niO0iO XOR rbytordpat(18)))) AND (NOT (niO0li XOR rbytordpat(19))));
	niOO1li <= (niOO1lO OR niOO1ll);
	niOO1ll <= ((((((((((NOT (wire_niOlOl_dataout XOR (NOT rbytordpat(10)))) AND (NOT (wire_niOlOO_dataout XOR (NOT rbytordpat(11))))) AND (NOT (wire_niOO1i_dataout XOR (NOT rbytordpat(12))))) AND (NOT (wire_niOO1l_dataout XOR (NOT rbytordpat(13))))) AND (NOT (wire_niOO1O_dataout XOR (NOT rbytordpat(14))))) AND (NOT (wire_niOO0i_dataout XOR (NOT rbytordpat(15))))) AND (NOT (wire_niOO0l_dataout XOR (NOT rbytordpat(16))))) AND (NOT (wire_niOO0O_dataout XOR (NOT rbytordpat(17))))) AND (NOT (wire_niOOii_dataout XOR (NOT rbytordpat(18))))) AND (NOT (wire_niOOil_dataout XOR (NOT rbytordpat(19)))));
	niOO1lO <= ((((((((((NOT (wire_niOlOl_dataout XOR rbytordpat(10))) AND (NOT (wire_niOlOO_dataout XOR rbytordpat(11)))) AND (NOT (wire_niOO1i_dataout XOR rbytordpat(12)))) AND (NOT (wire_niOO1l_dataout XOR rbytordpat(13)))) AND (NOT (wire_niOO1O_dataout XOR rbytordpat(14)))) AND (NOT (wire_niOO0i_dataout XOR rbytordpat(15)))) AND (NOT (wire_niOO0l_dataout XOR rbytordpat(16)))) AND (NOT (wire_niOO0O_dataout XOR rbytordpat(17)))) AND (NOT (wire_niOOii_dataout XOR rbytordpat(18)))) AND (NOT (wire_niOOil_dataout XOR rbytordpat(19))));
	niOO1Oi <= (((((((((NOT (niliOi XOR rbytordpat(0))) AND (NOT (niliOl XOR rbytordpat(1)))) AND (NOT (niliOO XOR rbytordpat(2)))) AND (NOT (nill1i XOR rbytordpat(3)))) AND (NOT (nill1l XOR rbytordpat(4)))) AND (NOT (nill1O XOR rbytordpat(5)))) AND (NOT (nill0i XOR rbytordpat(6)))) AND (NOT (nill0l XOR rbytordpat(7)))) AND (NOT (nill0O XOR rbytordpat(8))));
	niOO1Ol <= (((((((((NOT (nillOl XOR rbytordpat(10))) AND (NOT (nillOO XOR rbytordpat(11)))) AND (NOT (nilO1i XOR rbytordpat(12)))) AND (NOT (nilO1l XOR rbytordpat(13)))) AND (NOT (nilO1O XOR rbytordpat(14)))) AND (NOT (nilO0i XOR rbytordpat(15)))) AND (NOT (nilO0l XOR rbytordpat(16)))) AND (NOT (nilO0O XOR rbytordpat(17)))) AND (NOT (nilOii XOR rbytordpat(18))));
	niOO1OO <= (((((((((NOT (nillOl XOR rbytordpat(0))) AND (NOT (nillOO XOR rbytordpat(1)))) AND (NOT (nilO1i XOR rbytordpat(2)))) AND (NOT (nilO1l XOR rbytordpat(3)))) AND (NOT (nilO1O XOR rbytordpat(4)))) AND (NOT (nilO0i XOR rbytordpat(5)))) AND (NOT (nilO0l XOR rbytordpat(6)))) AND (NOT (nilO0O XOR rbytordpat(7)))) AND (NOT (nilOii XOR rbytordpat(8))));
	niOOi0i <= ((((((((((NOT (wire_niOOOO_dataout XOR rbytordpat(0))) AND (NOT (rbytordpat(1) XOR wire_nl111i_dataout))) AND (NOT (rbytordpat(2) XOR wire_nl111l_dataout))) AND (NOT (rbytordpat(3) XOR wire_nl111O_dataout))) AND (NOT (rbytordpat(4) XOR wire_nl110i_dataout))) AND (NOT (rbytordpat(5) XOR wire_nl110l_dataout))) AND (NOT (rbytordpat(6) XOR wire_nl110O_dataout))) AND (NOT (rbytordpat(7) XOR wire_nl11ii_dataout))) AND (NOT (rbytordpat(8) XOR wire_nl11il_dataout))) AND (NOT (rbytordpat(9) XOR wire_nl11iO_dataout)));
	niOOi0l <= (niOOiiO OR niOOiil);
	niOOi0O <= ((((((((((NOT ((NOT rbytordpat(0)) XOR wire_nl1i1l_dataout)) AND (NOT ((NOT rbytordpat(1)) XOR wire_nl1i1O_dataout))) AND (NOT ((NOT rbytordpat(2)) XOR wire_nl1i0i_dataout))) AND (NOT ((NOT rbytordpat(3)) XOR wire_nl1i0l_dataout))) AND (NOT ((NOT rbytordpat(4)) XOR wire_nl1i0O_dataout))) AND (NOT ((NOT rbytordpat(5)) XOR wire_nl1iii_dataout))) AND (NOT ((NOT rbytordpat(6)) XOR wire_nl1iil_dataout))) AND (NOT ((NOT rbytordpat(7)) XOR wire_nl1iiO_dataout))) AND (NOT ((NOT rbytordpat(8)) XOR wire_nl1ili_dataout))) AND (NOT ((NOT rbytordpat(9)) XOR wire_nl1ill_dataout)));
	niOOi1i <= ((((((((((NOT (wire_niOlOl_dataout XOR (NOT rbytordpat(0)))) AND (NOT (wire_niOlOO_dataout XOR (NOT rbytordpat(1))))) AND (NOT (wire_niOO1i_dataout XOR (NOT rbytordpat(2))))) AND (NOT (wire_niOO1l_dataout XOR (NOT rbytordpat(3))))) AND (NOT (wire_niOO1O_dataout XOR (NOT rbytordpat(4))))) AND (NOT (wire_niOO0i_dataout XOR (NOT rbytordpat(5))))) AND (NOT (wire_niOO0l_dataout XOR (NOT rbytordpat(6))))) AND (NOT (wire_niOO0O_dataout XOR (NOT rbytordpat(7))))) AND (NOT (wire_niOOii_dataout XOR (NOT rbytordpat(8))))) AND (NOT (wire_niOOil_dataout XOR (NOT rbytordpat(9)))));
	niOOi1l <= ((((((((((NOT (wire_niOlOl_dataout XOR rbytordpat(0))) AND (NOT (wire_niOlOO_dataout XOR rbytordpat(1)))) AND (NOT (wire_niOO1i_dataout XOR rbytordpat(2)))) AND (NOT (wire_niOO1l_dataout XOR rbytordpat(3)))) AND (NOT (wire_niOO1O_dataout XOR rbytordpat(4)))) AND (NOT (wire_niOO0i_dataout XOR rbytordpat(5)))) AND (NOT (wire_niOO0l_dataout XOR rbytordpat(6)))) AND (NOT (wire_niOO0O_dataout XOR rbytordpat(7)))) AND (NOT (wire_niOOii_dataout XOR rbytordpat(8)))) AND (NOT (wire_niOOil_dataout XOR rbytordpat(9))));
	niOOi1O <= ((((((((((NOT (wire_niOOOO_dataout XOR (NOT rbytordpat(0)))) AND (NOT ((NOT rbytordpat(1)) XOR wire_nl111i_dataout))) AND (NOT ((NOT rbytordpat(2)) XOR wire_nl111l_dataout))) AND (NOT ((NOT rbytordpat(3)) XOR wire_nl111O_dataout))) AND (NOT ((NOT rbytordpat(4)) XOR wire_nl110i_dataout))) AND (NOT ((NOT rbytordpat(5)) XOR wire_nl110l_dataout))) AND (NOT ((NOT rbytordpat(6)) XOR wire_nl110O_dataout))) AND (NOT ((NOT rbytordpat(7)) XOR wire_nl11ii_dataout))) AND (NOT ((NOT rbytordpat(8)) XOR wire_nl11il_dataout))) AND (NOT ((NOT rbytordpat(9)) XOR wire_nl11iO_dataout)));
	niOOiii <= ((((((((((NOT (rbytordpat(0) XOR wire_nl1i1l_dataout)) AND (NOT (rbytordpat(1) XOR wire_nl1i1O_dataout))) AND (NOT (rbytordpat(2) XOR wire_nl1i0i_dataout))) AND (NOT (rbytordpat(3) XOR wire_nl1i0l_dataout))) AND (NOT (rbytordpat(4) XOR wire_nl1i0O_dataout))) AND (NOT (rbytordpat(5) XOR wire_nl1iii_dataout))) AND (NOT (rbytordpat(6) XOR wire_nl1iil_dataout))) AND (NOT (rbytordpat(7) XOR wire_nl1iiO_dataout))) AND (NOT (rbytordpat(8) XOR wire_nl1ili_dataout))) AND (NOT (rbytordpat(9) XOR wire_nl1ill_dataout)));
	niOOiil <= ((((((((((NOT ((NOT rbytordpat(0)) XOR wire_nl101i_dataout)) AND (NOT ((NOT rbytordpat(1)) XOR wire_nl101l_dataout))) AND (NOT ((NOT rbytordpat(2)) XOR wire_nl101O_dataout))) AND (NOT ((NOT rbytordpat(3)) XOR wire_nl100i_dataout))) AND (NOT ((NOT rbytordpat(4)) XOR wire_nl100l_dataout))) AND (NOT ((NOT rbytordpat(5)) XOR wire_nl100O_dataout))) AND (NOT ((NOT rbytordpat(6)) XOR wire_nl10ii_dataout))) AND (NOT ((NOT rbytordpat(7)) XOR wire_nl10il_dataout))) AND (NOT ((NOT rbytordpat(8)) XOR wire_nl10iO_dataout))) AND (NOT ((NOT rbytordpat(9)) XOR wire_nl10li_dataout)));
	niOOiiO <= ((((((((((NOT (rbytordpat(0) XOR wire_nl101i_dataout)) AND (NOT (rbytordpat(1) XOR wire_nl101l_dataout))) AND (NOT (rbytordpat(2) XOR wire_nl101O_dataout))) AND (NOT (rbytordpat(3) XOR wire_nl100i_dataout))) AND (NOT (rbytordpat(4) XOR wire_nl100l_dataout))) AND (NOT (rbytordpat(5) XOR wire_nl100O_dataout))) AND (NOT (rbytordpat(6) XOR wire_nl10ii_dataout))) AND (NOT (rbytordpat(7) XOR wire_nl10il_dataout))) AND (NOT (rbytordpat(8) XOR wire_nl10iO_dataout))) AND (NOT (rbytordpat(9) XOR wire_nl10li_dataout)));
	niOOili <= (((((((((NOT (niO01i XOR rbytordpat(0))) AND (NOT (niO01l XOR rbytordpat(1)))) AND (NOT (niO01O XOR rbytordpat(2)))) AND (NOT (niO00i XOR rbytordpat(3)))) AND (NOT (niO00l XOR rbytordpat(4)))) AND (NOT (niO00O XOR rbytordpat(5)))) AND (NOT (niO0ii XOR rbytordpat(6)))) AND (NOT (niO0il XOR rbytordpat(7)))) AND (NOT (niO0iO XOR rbytordpat(8))));
	niOOill <= (((((((((NOT (nilOOO XOR rbytordpat(0))) AND (NOT (niO11i XOR rbytordpat(1)))) AND (NOT (niO11l XOR rbytordpat(2)))) AND (NOT (niO11O XOR rbytordpat(3)))) AND (NOT (niO10i XOR rbytordpat(4)))) AND (NOT (niO10l XOR rbytordpat(5)))) AND (NOT (niO10O XOR rbytordpat(6)))) AND (NOT (niO1ii XOR rbytordpat(7)))) AND (NOT (niO1il XOR rbytordpat(8))));
	niOOilO <= (wire_w_lg_rbytordplden683w(0) OR wire_w_lg_niOOiOi714w(0));
	niOOiOi <= (((((((((NOT (wire_niOlOl_dataout XOR rbytordpat(0))) AND (NOT (wire_niOlOO_dataout XOR rbytordpat(1)))) AND (NOT (wire_niOO1i_dataout XOR rbytordpat(2)))) AND (NOT (wire_niOO1l_dataout XOR rbytordpat(3)))) AND (NOT (wire_niOO1O_dataout XOR rbytordpat(4)))) AND (NOT (wire_niOO0i_dataout XOR rbytordpat(5)))) AND (NOT (wire_niOO0l_dataout XOR rbytordpat(6)))) AND (NOT (wire_niOO0O_dataout XOR rbytordpat(7)))) AND (NOT (wire_niOOii_dataout XOR rbytordpat(8))));
	niOOiOl <= (((((((((NOT (wire_niOOOO_dataout XOR rbytordpat(0))) AND (NOT (rbytordpat(1) XOR wire_nl111i_dataout))) AND (NOT (rbytordpat(2) XOR wire_nl111l_dataout))) AND (NOT (rbytordpat(3) XOR wire_nl111O_dataout))) AND (NOT (rbytordpat(4) XOR wire_nl110i_dataout))) AND (NOT (rbytordpat(5) XOR wire_nl110l_dataout))) AND (NOT (rbytordpat(6) XOR wire_nl110O_dataout))) AND (NOT (rbytordpat(7) XOR wire_nl11ii_dataout))) AND (NOT (rbytordpat(8) XOR wire_nl11il_dataout)));
	niOOiOO <= (((((((((NOT (rbytordpat(0) XOR wire_nl1i1l_dataout)) AND (NOT (rbytordpat(1) XOR wire_nl1i1O_dataout))) AND (NOT (rbytordpat(2) XOR wire_nl1i0i_dataout))) AND (NOT (rbytordpat(3) XOR wire_nl1i0l_dataout))) AND (NOT (rbytordpat(4) XOR wire_nl1i0O_dataout))) AND (NOT (rbytordpat(5) XOR wire_nl1iii_dataout))) AND (NOT (rbytordpat(6) XOR wire_nl1iil_dataout))) AND (NOT (rbytordpat(7) XOR wire_nl1iiO_dataout))) AND (NOT (rbytordpat(8) XOR wire_nl1ili_dataout)));
	niOOl0i <= (wire_w_lg_rbytordplden683w(0) OR wire_w_lg_niOOl0l692w(0));
	niOOl0l <= ((((((((NOT (wire_niOlOl_dataout XOR rbytordpat(0))) AND (NOT (wire_niOlOO_dataout XOR rbytordpat(1)))) AND (NOT (wire_niOO1i_dataout XOR rbytordpat(2)))) AND (NOT (wire_niOO1l_dataout XOR rbytordpat(3)))) AND (NOT (wire_niOO1O_dataout XOR rbytordpat(4)))) AND (NOT (wire_niOO0i_dataout XOR rbytordpat(5)))) AND (NOT (wire_niOO0l_dataout XOR rbytordpat(6)))) AND (NOT (wire_niOO0O_dataout XOR rbytordpat(7))));
	niOOl0O <= ((((((((NOT (wire_niOOOO_dataout XOR rbytordpat(0))) AND (NOT (rbytordpat(1) XOR wire_nl111i_dataout))) AND (NOT (rbytordpat(2) XOR wire_nl111l_dataout))) AND (NOT (rbytordpat(3) XOR wire_nl111O_dataout))) AND (NOT (rbytordpat(4) XOR wire_nl110i_dataout))) AND (NOT (rbytordpat(5) XOR wire_nl110l_dataout))) AND (NOT (rbytordpat(6) XOR wire_nl110O_dataout))) AND (NOT (rbytordpat(7) XOR wire_nl11ii_dataout)));
	niOOl1i <= (((((((((NOT (rbytordpat(0) XOR wire_nl101i_dataout)) AND (NOT (rbytordpat(1) XOR wire_nl101l_dataout))) AND (NOT (rbytordpat(2) XOR wire_nl101O_dataout))) AND (NOT (rbytordpat(3) XOR wire_nl100i_dataout))) AND (NOT (rbytordpat(4) XOR wire_nl100l_dataout))) AND (NOT (rbytordpat(5) XOR wire_nl100O_dataout))) AND (NOT (rbytordpat(6) XOR wire_nl10ii_dataout))) AND (NOT (rbytordpat(7) XOR wire_nl10il_dataout))) AND (NOT (rbytordpat(8) XOR wire_nl10iO_dataout)));
	niOOl1l <= ((((((((NOT (niO01i XOR rbytordpat(0))) AND (NOT (niO01l XOR rbytordpat(1)))) AND (NOT (niO01O XOR rbytordpat(2)))) AND (NOT (niO00i XOR rbytordpat(3)))) AND (NOT (niO00l XOR rbytordpat(4)))) AND (NOT (niO00O XOR rbytordpat(5)))) AND (NOT (niO0ii XOR rbytordpat(6)))) AND (NOT (niO0il XOR rbytordpat(7))));
	niOOl1O <= ((((((((NOT (nilOOO XOR rbytordpat(0))) AND (NOT (niO11i XOR rbytordpat(1)))) AND (NOT (niO11l XOR rbytordpat(2)))) AND (NOT (niO11O XOR rbytordpat(3)))) AND (NOT (niO10i XOR rbytordpat(4)))) AND (NOT (niO10l XOR rbytordpat(5)))) AND (NOT (niO10O XOR rbytordpat(6)))) AND (NOT (niO1ii XOR rbytordpat(7))));
	niOOlii <= ((((((((NOT (rbytordpat(0) XOR wire_nl1i1l_dataout)) AND (NOT (rbytordpat(1) XOR wire_nl1i1O_dataout))) AND (NOT (rbytordpat(2) XOR wire_nl1i0i_dataout))) AND (NOT (rbytordpat(3) XOR wire_nl1i0l_dataout))) AND (NOT (rbytordpat(4) XOR wire_nl1i0O_dataout))) AND (NOT (rbytordpat(5) XOR wire_nl1iii_dataout))) AND (NOT (rbytordpat(6) XOR wire_nl1iil_dataout))) AND (NOT (rbytordpat(7) XOR wire_nl1iiO_dataout)));
	niOOlil <= ((((((((NOT (rbytordpat(0) XOR wire_nl101i_dataout)) AND (NOT (rbytordpat(1) XOR wire_nl101l_dataout))) AND (NOT (rbytordpat(2) XOR wire_nl101O_dataout))) AND (NOT (rbytordpat(3) XOR wire_nl100i_dataout))) AND (NOT (rbytordpat(4) XOR wire_nl100l_dataout))) AND (NOT (rbytordpat(5) XOR wire_nl100O_dataout))) AND (NOT (rbytordpat(6) XOR wire_nl10ii_dataout))) AND (NOT (rbytordpat(7) XOR wire_nl10il_dataout)));
	niOOliO <= (((wire_nli1ii_w_lg_niiOil6507w(0) AND wire_nli1ii_w_lg_niiOii3801w(0)) AND wire_nli1ii_w_lg_niiO0O6509w(0)) AND wire_nli1ii_w_lg_niiO0l6511w(0));
	niOOlli <= (wire_nl1l1O_w_lg_dataout5768w(0) AND wire_nl1l0i_w_lg_dataout5769w(0));
	niOOlll <= ((NOT rbytorden(0)) AND (NOT rbytorden(1)));
	niOOllO <= ((wire_w_lg_rwa_6g_en2w(0) AND wire_w_lg_niOOlOO671w(0)) AND wire_w_lg_rbytord_s2gx660w(0));
	niOOlOi <= (wire_w_lg_rbytord_s2gx660w(0) AND (wire_w_lg_rwa_6g_en2w(0) AND (niOOlOO OR niOOO1i)));
	niOOlOl <= (wire_w_lg_rbytord_s2gx660w(0) AND (wire_w_lg_rwa_6g_en2w(0) AND wire_w_lg_niOOO1i663w(0)));
	niOOlOO <= (n1iiO AND wire_n1ill_w_lg_n1iil658w(0));
	niOOO0l <= (rauto_speed_ena AND dis_pc_byte);
	niOOO1i <= (wire_n1ill_w_lg_n1iiO656w(0) AND n1ili);
	niOOOii <= '0';
	niOOOil <= (wire_w_lg_rdwidth639w(0) AND rrxpcsbypass_en);
	niOOOiO <= ((((((((((NOT wire_w_lg_w_tenb_data_range588w5736w(0)) AND (NOT wire_w_lg_w_tenb_data_range587w5738w(0))) AND (NOT wire_w_lg_w_tenb_data_range586w5741w(0))) AND (NOT wire_w_lg_w_tenb_data_range585w5744w(0))) AND (NOT wire_w_lg_w_tenb_data_range584w5747w(0))) AND (NOT wire_w_lg_w_tenb_data_range583w5750w(0))) AND (NOT wire_w_lg_w_tenb_data_range582w5753w(0))) AND (NOT wire_w_lg_w_tenb_data_range581w5756w(0))) AND (NOT wire_w_lg_w_tenb_data_range331w5759w(0))) AND (NOT wire_w_lg_w_tenb_data_range580w5762w(0)));
	niOOOli <= ((((((((((NOT (tenb_data(10) XOR rsync_comp_pat(20))) AND (NOT (tenb_data(11) XOR rsync_comp_pat(21)))) AND (NOT (tenb_data(12) XOR rsync_comp_pat(22)))) AND (NOT (tenb_data(13) XOR rsync_comp_pat(23)))) AND (NOT (tenb_data(14) XOR rsync_comp_pat(24)))) AND (NOT (tenb_data(15) XOR rsync_comp_pat(25)))) AND (NOT (tenb_data(16) XOR rsync_comp_pat(26)))) AND (NOT (tenb_data(17) XOR rsync_comp_pat(27)))) AND (NOT (tenb_data(18) XOR rsync_comp_pat(28)))) AND (NOT (tenb_data(19) XOR rsync_comp_pat(29))));
	niOOOll <= ((((((((((((((((((((NOT (tenb_data(0) XOR rsync_comp_pat(10))) AND (NOT (tenb_data(1) XOR rsync_comp_pat(11)))) AND (NOT (tenb_data(2) XOR rsync_comp_pat(12)))) AND (NOT (tenb_data(3) XOR rsync_comp_pat(13)))) AND (NOT (tenb_data(4) XOR rsync_comp_pat(14)))) AND (NOT (tenb_data(5) XOR rsync_comp_pat(15)))) AND (NOT (tenb_data(6) XOR rsync_comp_pat(16)))) AND (NOT (tenb_data(7) XOR rsync_comp_pat(17)))) AND (NOT (tenb_data(8) XOR rsync_comp_pat(18)))) AND (NOT (tenb_data(9) XOR rsync_comp_pat(19)))) AND (NOT (tenb_data(10) XOR rsync_comp_pat(20)))) AND (NOT (tenb_data(11) XOR rsync_comp_pat(21)))) AND (NOT (tenb_data(12) XOR rsync_comp_pat(22)))) AND (NOT (tenb_data(13) XOR rsync_comp_pat(23)))) AND (NOT (tenb_data(14) XOR rsync_comp_pat(24)))) AND (NOT (tenb_data(15) XOR rsync_comp_pat(25)))) AND (NOT (tenb_data(16) XOR rsync_comp_pat(26)))) AND (NOT (tenb_data(17) XOR rsync_comp_pat(27)))) AND (NOT (tenb_data(18) XOR rsync_comp_pat(28)))) AND (NOT (tenb_data(19) XOR rsync_comp_pat(29))));
	niOOOlO <= ((((((((NOT wire_w_lg_w_tenb_data_range588w5674w(0)) AND (NOT wire_w_lg_w_tenb_data_range587w5676w(0))) AND (NOT wire_w_lg_w_tenb_data_range586w5679w(0))) AND (NOT wire_w_lg_w_tenb_data_range585w5682w(0))) AND (NOT wire_w_lg_w_tenb_data_range584w5685w(0))) AND (NOT wire_w_lg_w_tenb_data_range583w5688w(0))) AND (NOT wire_w_lg_w_tenb_data_range582w5691w(0))) AND (NOT wire_w_lg_w_tenb_data_range581w5694w(0)));
	niOOOOi <= ((((((((NOT (tenb_data(10) XOR rsync_comp_pat(16))) AND (NOT (tenb_data(11) XOR rsync_comp_pat(17)))) AND (NOT (tenb_data(12) XOR rsync_comp_pat(18)))) AND (NOT (tenb_data(13) XOR rsync_comp_pat(19)))) AND (NOT (tenb_data(14) XOR rsync_comp_pat(20)))) AND (NOT (tenb_data(15) XOR rsync_comp_pat(21)))) AND (NOT (tenb_data(16) XOR rsync_comp_pat(22)))) AND (NOT (tenb_data(17) XOR rsync_comp_pat(23))));
	niOOOOl <= ((((((((((((((((NOT (tenb_data(0) XOR rsync_comp_pat(8))) AND (NOT (tenb_data(1) XOR rsync_comp_pat(9)))) AND (NOT (tenb_data(2) XOR rsync_comp_pat(10)))) AND (NOT (tenb_data(3) XOR rsync_comp_pat(11)))) AND (NOT (tenb_data(4) XOR rsync_comp_pat(12)))) AND (NOT (tenb_data(5) XOR rsync_comp_pat(13)))) AND (NOT (tenb_data(6) XOR rsync_comp_pat(14)))) AND (NOT (tenb_data(7) XOR rsync_comp_pat(15)))) AND (NOT (tenb_data(10) XOR rsync_comp_pat(16)))) AND (NOT (tenb_data(11) XOR rsync_comp_pat(17)))) AND (NOT (tenb_data(12) XOR rsync_comp_pat(18)))) AND (NOT (tenb_data(13) XOR rsync_comp_pat(19)))) AND (NOT (tenb_data(14) XOR rsync_comp_pat(20)))) AND (NOT (tenb_data(15) XOR rsync_comp_pat(21)))) AND (NOT (tenb_data(16) XOR rsync_comp_pat(22)))) AND (NOT (tenb_data(17) XOR rsync_comp_pat(23))));
	nl1010i <= (((((((((((((((((((((((((((((((((((((((((((((wire_nliOi_o(63) OR wire_nliOi_o(62)) OR wire_nliOi_o(59)) OR wire_nliOi_o(58)) OR wire_nliOi_o(55)) OR wire_nliOi_o(54)) OR wire_nliOi_o(51)) OR wire_nliOi_o(50)) OR wire_nliOi_o(47)) OR wire_nliOi_o(46)) OR wire_nliOi_o(45)) OR wire_nliOi_o(44)) OR wire_nliOi_o(41)) OR wire_nliOi_o(40)) OR wire_nliOi_o(37)) OR wire_nliOi_o(36)) OR wire_nliOi_o(33)) OR wire_nliOi_o(32)) OR wire_nliOi_o(31)) OR wire_nliOi_o(30)) OR wire_nliOi_o(29)) OR wire_nliOi_o(28)) OR wire_nliOi_o(27)) OR wire_nliOi_o(26)) OR wire_nliOi_o(25)) OR wire_nliOi_o(24)) OR wire_nliOi_o(23)) OR wire_nliOi_o(22)) OR wire_nliOi_o(19)) OR wire_nliOi_o(18)) OR wire_nliOi_o(15)) OR wire_nliOi_o(14)) OR wire_nliOi_o(13)) OR wire_nliOi_o(12)) OR wire_nliOi_o(11)) OR wire_nliOi_o(10)) OR wire_nliOi_o(9)) OR wire_nliOi_o(8)) OR wire_nliOi_o(7)) OR wire_nliOi_o(6)) OR wire_nliOi_o(5)) OR wire_nliOi_o(4)) OR wire_nliOi_o(3)) OR wire_nliOi_o(2)) OR wire_nliOi_o(1)) OR wire_nliOi_o(0));
	nl101il <= ((((((((NOT (tenb_data(0) XOR rsync_comp_pat(8))) AND (NOT (tenb_data(1) XOR rsync_comp_pat(9)))) AND (NOT (tenb_data(2) XOR rsync_comp_pat(10)))) AND (NOT (tenb_data(3) XOR rsync_comp_pat(11)))) AND (NOT (tenb_data(4) XOR rsync_comp_pat(12)))) AND (NOT (tenb_data(5) XOR rsync_comp_pat(13)))) AND (NOT (tenb_data(6) XOR rsync_comp_pat(14)))) AND (NOT (tenb_data(7) XOR rsync_comp_pat(15))));
	nl101ll <= (wire_w_lg_soft_reset8w(0) OR (NOT (nl101lO4 XOR nl101lO3)));
	nl101Ol <= ((wire_w_lg_rsync_sm_dis1w(0) AND wire_w_lg_rwa_6g_en2w(0)) AND (nl101OO2 XOR nl101OO1));
	nl1100i <= ((((((((((NOT (tenb_data(0) XOR rsync_comp_pat(20))) AND (NOT (tenb_data(1) XOR rsync_comp_pat(21)))) AND (NOT (tenb_data(2) XOR rsync_comp_pat(22)))) AND (NOT (tenb_data(3) XOR rsync_comp_pat(23)))) AND (NOT (tenb_data(4) XOR rsync_comp_pat(24)))) AND (NOT (tenb_data(5) XOR rsync_comp_pat(25)))) AND (NOT (tenb_data(6) XOR rsync_comp_pat(26)))) AND (NOT (tenb_data(7) XOR rsync_comp_pat(27)))) AND (NOT (tenb_data(8) XOR rsync_comp_pat(28)))) AND (NOT (tenb_data(9) XOR rsync_comp_pat(29))));
	nl1100l <= ((((((((((((((((((((NOT (tenb_data(0) XOR rsync_comp_pat(20))) AND (NOT (tenb_data(1) XOR rsync_comp_pat(21)))) AND (NOT (tenb_data(2) XOR rsync_comp_pat(22)))) AND (NOT (tenb_data(3) XOR rsync_comp_pat(23)))) AND (NOT (tenb_data(4) XOR rsync_comp_pat(24)))) AND (NOT (tenb_data(5) XOR rsync_comp_pat(25)))) AND (NOT (tenb_data(6) XOR rsync_comp_pat(26)))) AND (NOT (tenb_data(7) XOR rsync_comp_pat(27)))) AND (NOT (tenb_data(8) XOR rsync_comp_pat(28)))) AND (NOT (tenb_data(9) XOR rsync_comp_pat(29)))) AND (NOT (tenb_data(10) XOR rsync_comp_pat(30)))) AND (NOT (tenb_data(11) XOR rsync_comp_pat(31)))) AND (NOT (tenb_data(12) XOR rsync_comp_pat(32)))) AND (NOT (tenb_data(13) XOR rsync_comp_pat(33)))) AND (NOT (tenb_data(14) XOR rsync_comp_pat(34)))) AND (NOT (tenb_data(15) XOR rsync_comp_pat(35)))) AND (NOT (tenb_data(16) XOR rsync_comp_pat(36)))) AND (NOT (tenb_data(17) XOR rsync_comp_pat(37)))) AND (NOT (tenb_data(18) XOR rsync_comp_pat(38)))) AND (NOT (tenb_data(19) XOR rsync_comp_pat(39))));
	nl1100O <= ((((((((NOT wire_w_lg_w_tenb_data_range588w5487w(0)) AND (NOT wire_w_lg_w_tenb_data_range587w5489w(0))) AND (NOT wire_w_lg_w_tenb_data_range586w5492w(0))) AND (NOT wire_w_lg_w_tenb_data_range585w5495w(0))) AND (NOT wire_w_lg_w_tenb_data_range584w5498w(0))) AND (NOT wire_w_lg_w_tenb_data_range583w5501w(0))) AND (NOT wire_w_lg_w_tenb_data_range582w5504w(0))) AND (NOT wire_w_lg_w_tenb_data_range581w5507w(0)));
	nl1101i <= ((((((((((NOT wire_w_lg_w_tenb_data_range588w5607w(0)) AND (NOT wire_w_lg_w_tenb_data_range587w5609w(0))) AND (NOT wire_w_lg_w_tenb_data_range586w5612w(0))) AND (NOT wire_w_lg_w_tenb_data_range585w5615w(0))) AND (NOT wire_w_lg_w_tenb_data_range584w5618w(0))) AND (NOT wire_w_lg_w_tenb_data_range583w5621w(0))) AND (NOT wire_w_lg_w_tenb_data_range582w5624w(0))) AND (NOT wire_w_lg_w_tenb_data_range581w5627w(0))) AND (NOT wire_w_lg_w_tenb_data_range331w5630w(0))) AND (NOT wire_w_lg_w_tenb_data_range580w5633w(0)));
	nl1101l <= ((((((((((NOT (tenb_data(10) XOR rsync_comp_pat(30))) AND (NOT (tenb_data(11) XOR rsync_comp_pat(31)))) AND (NOT (tenb_data(12) XOR rsync_comp_pat(32)))) AND (NOT (tenb_data(13) XOR rsync_comp_pat(33)))) AND (NOT (tenb_data(14) XOR rsync_comp_pat(34)))) AND (NOT (tenb_data(15) XOR rsync_comp_pat(35)))) AND (NOT (tenb_data(16) XOR rsync_comp_pat(36)))) AND (NOT (tenb_data(17) XOR rsync_comp_pat(37)))) AND (NOT (tenb_data(18) XOR rsync_comp_pat(38)))) AND (NOT (tenb_data(19) XOR rsync_comp_pat(39))));
	nl1101O <= ((((((((((NOT wire_w_lg_w_tenb_data_range597w5569w(0)) AND (NOT wire_w_lg_w_tenb_data_range596w5571w(0))) AND (NOT wire_w_lg_w_tenb_data_range595w5574w(0))) AND (NOT wire_w_lg_w_tenb_data_range594w5577w(0))) AND (NOT wire_w_lg_w_tenb_data_range593w5580w(0))) AND (NOT wire_w_lg_w_tenb_data_range592w5583w(0))) AND (NOT wire_w_lg_w_tenb_data_range591w5586w(0))) AND (NOT wire_w_lg_w_tenb_data_range590w5589w(0))) AND (NOT wire_w_lg_w_tenb_data_range98w5592w(0))) AND (NOT wire_w_lg_w_tenb_data_range589w5595w(0)));
	nl110ii <= ((((((((NOT (tenb_data(10) XOR rsync_comp_pat(24))) AND (NOT (tenb_data(11) XOR rsync_comp_pat(25)))) AND (NOT (tenb_data(12) XOR rsync_comp_pat(26)))) AND (NOT (tenb_data(13) XOR rsync_comp_pat(27)))) AND (NOT (tenb_data(14) XOR rsync_comp_pat(28)))) AND (NOT (tenb_data(15) XOR rsync_comp_pat(29)))) AND (NOT (tenb_data(16) XOR rsync_comp_pat(30)))) AND (NOT (tenb_data(17) XOR rsync_comp_pat(31))));
	nl110il <= ((((((((NOT wire_w_lg_w_tenb_data_range597w5453w(0)) AND (NOT wire_w_lg_w_tenb_data_range596w5455w(0))) AND (NOT wire_w_lg_w_tenb_data_range595w5458w(0))) AND (NOT wire_w_lg_w_tenb_data_range594w5461w(0))) AND (NOT wire_w_lg_w_tenb_data_range593w5465w(0))) AND (NOT wire_w_lg_w_tenb_data_range592w5469w(0))) AND (NOT wire_w_lg_w_tenb_data_range591w5473w(0))) AND (NOT wire_w_lg_w_tenb_data_range590w5477w(0)));
	nl110iO <= ((((((((NOT (tenb_data(0) XOR rsync_comp_pat(16))) AND (NOT (tenb_data(1) XOR rsync_comp_pat(17)))) AND (NOT (tenb_data(2) XOR rsync_comp_pat(18)))) AND (NOT (tenb_data(3) XOR rsync_comp_pat(19)))) AND (NOT (tenb_data(4) XOR rsync_comp_pat(20)))) AND (NOT (tenb_data(5) XOR rsync_comp_pat(21)))) AND (NOT (tenb_data(6) XOR rsync_comp_pat(22)))) AND (NOT (tenb_data(7) XOR rsync_comp_pat(23))));
	nl110li <= ((((((((((((((((NOT (tenb_data(0) XOR rsync_comp_pat(16))) AND (NOT (tenb_data(1) XOR rsync_comp_pat(17)))) AND (NOT (tenb_data(2) XOR rsync_comp_pat(18)))) AND (NOT (tenb_data(3) XOR rsync_comp_pat(19)))) AND (NOT (tenb_data(4) XOR rsync_comp_pat(20)))) AND (NOT (tenb_data(5) XOR rsync_comp_pat(21)))) AND (NOT (tenb_data(6) XOR rsync_comp_pat(22)))) AND (NOT (tenb_data(7) XOR rsync_comp_pat(23)))) AND (NOT (tenb_data(10) XOR rsync_comp_pat(24)))) AND (NOT (tenb_data(11) XOR rsync_comp_pat(25)))) AND (NOT (tenb_data(12) XOR rsync_comp_pat(26)))) AND (NOT (tenb_data(13) XOR rsync_comp_pat(27)))) AND (NOT (tenb_data(14) XOR rsync_comp_pat(28)))) AND (NOT (tenb_data(15) XOR rsync_comp_pat(29)))) AND (NOT (tenb_data(16) XOR rsync_comp_pat(30)))) AND (NOT (tenb_data(17) XOR rsync_comp_pat(31))));
	nl110ll <= (((((((NOT (wire_w_lg_w_rsync_comp_pat_range4891w4918w(0) XOR tenb_data(10))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4894w4921w(0) XOR tenb_data(11)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4898w4925w(0) XOR tenb_data(12)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4902w4929w(0) XOR tenb_data(13)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4906w4933w(0) XOR tenb_data(14)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4910w4937w(0) XOR tenb_data(15)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4914w4941w(0) XOR tenb_data(16))));
	nl110lO <= (((((((NOT (rsync_comp_pat(0) XOR tenb_data(10))) AND (NOT (rsync_comp_pat(1) XOR tenb_data(11)))) AND (NOT (rsync_comp_pat(2) XOR tenb_data(12)))) AND (NOT (rsync_comp_pat(3) XOR tenb_data(13)))) AND (NOT (rsync_comp_pat(4) XOR tenb_data(14)))) AND (NOT (rsync_comp_pat(5) XOR tenb_data(15)))) AND (NOT (rsync_comp_pat(6) XOR tenb_data(16))));
	nl110Oi <= (((((((((((((((((((((((((((((((((((((((((((((wire_niOOi_o(63) OR wire_niOOi_o(62)) OR wire_niOOi_o(59)) OR wire_niOOi_o(58)) OR wire_niOOi_o(55)) OR wire_niOOi_o(54)) OR wire_niOOi_o(51)) OR wire_niOOi_o(50)) OR wire_niOOi_o(47)) OR wire_niOOi_o(46)) OR wire_niOOi_o(45)) OR wire_niOOi_o(44)) OR wire_niOOi_o(41)) OR wire_niOOi_o(40)) OR wire_niOOi_o(37)) OR wire_niOOi_o(36)) OR wire_niOOi_o(33)) OR wire_niOOi_o(32)) OR wire_niOOi_o(31)) OR wire_niOOi_o(30)) OR wire_niOOi_o(29)) OR wire_niOOi_o(28)) OR wire_niOOi_o(27)) OR wire_niOOi_o(26)) OR wire_niOOi_o(25)) OR wire_niOOi_o(24)) OR wire_niOOi_o(23)) OR wire_niOOi_o(22)) OR wire_niOOi_o(19)) OR wire_niOOi_o(18)) OR wire_niOOi_o(15)) OR wire_niOOi_o(14)) OR wire_niOOi_o(13)) OR wire_niOOi_o(12)) OR wire_niOOi_o(11)) OR wire_niOOi_o(10)) OR wire_niOOi_o(9)) OR wire_niOOi_o(8)) OR wire_niOOi_o(7)) OR wire_niOOi_o(6)) OR wire_niOOi_o(5)) OR wire_niOOi_o(4)) OR wire_niOOi_o(3)) OR wire_niOOi_o(2)) OR wire_niOOi_o(1)) OR wire_niOOi_o(0));
	nl110Ol <= (nl11i1l OR ((rsync_comp_porn AND nl11O0l) AND (nl11i1i OR nl110OO)));
	nl110OO <= ((((((((((NOT wire_w_lg_w_tenb_data_range588w5373w(0)) AND (NOT wire_w_lg_w_tenb_data_range587w5375w(0))) AND (NOT wire_w_lg_w_tenb_data_range586w5378w(0))) AND (NOT wire_w_lg_w_tenb_data_range585w5381w(0))) AND (NOT wire_w_lg_w_tenb_data_range584w5384w(0))) AND (NOT wire_w_lg_w_tenb_data_range583w5387w(0))) AND (NOT wire_w_lg_w_tenb_data_range582w5390w(0))) AND (NOT wire_w_lg_w_tenb_data_range581w5393w(0))) AND (NOT wire_w_lg_w_tenb_data_range331w5396w(0))) AND (NOT wire_w_lg_w_tenb_data_range580w5399w(0)));
	nl1110i <= (wire_nlO1i1i_w_lg_nlO1i1l613w(0) AND nl1110l);
	nl1110l <= (rdwidth OR (nlOl0O AND (rauto_speed_ena AND wire_w_lg_rfreq_sel609w(0))));
	nl1110O <= '1';
	nl1111l <= (nlO1i1l AND nl1110l);
	nl1111O <= (wire_n1liO_dataout OR nliO0i);
	nl111il <= (niiO1O AND wire_nli1ii_w_lg_nlO1i1O604w(0));
	nl111iO <= (wire_n1ill_w_lg_n1ilO602w(0) AND wire_n1liO_dataout);
	nl111li <= (wire_nli1ii_w_lg_niOi0i600w(0) AND niOi0l);
	nl111ll <= ((((((wire_w_lg_w_rx_data_rs_range546w549w(0) OR (NOT rx_data_rs(2))) OR (NOT rx_data_rs(3))) OR (NOT rx_data_rs(4))) OR (NOT rx_data_rs(5))) OR (NOT rx_data_rs(6))) OR (NOT rx_data_rs(7)));
	nl111lO <= (wire_nli_w_lg_dataout535w(0) AND (NOT (wire_n1ill_w_lg_nll0lO536w(0) AND wire_w_lg_w_sync_resync_delay_range537w541w(0))));
	nl111Oi <= (wire_niO_w_lg_dataout512w(0) AND (NOT (wire_n1ill_w_lg_nll0ll513w(0) AND wire_w_lg_w_sync_resync_delay_range514w518w(0))));
	nl111Ol <= (wire_w_lg_rsync_sm_dis1w(0) AND wire_w_lg_rautoinsdis499w(0));
	nl111OO <= (wire_w_lg_rinvalid_code_err_only497w(0) AND rwa_6g_en);
	nl11i0i <= ((((((((NOT (tenb_data(10) XOR rsync_comp_pat(8))) AND (NOT (tenb_data(11) XOR rsync_comp_pat(9)))) AND (NOT (tenb_data(12) XOR rsync_comp_pat(10)))) AND (NOT (tenb_data(13) XOR rsync_comp_pat(11)))) AND (NOT (tenb_data(14) XOR rsync_comp_pat(12)))) AND (NOT (tenb_data(15) XOR rsync_comp_pat(13)))) AND (NOT (tenb_data(16) XOR rsync_comp_pat(14)))) AND (NOT (tenb_data(17) XOR rsync_comp_pat(15))));
	nl11i0l <= ((((((((NOT wire_w_lg_w_tenb_data_range588w5299w(0)) AND (NOT wire_w_lg_w_tenb_data_range587w5301w(0))) AND (NOT wire_w_lg_w_tenb_data_range586w5304w(0))) AND (NOT wire_w_lg_w_tenb_data_range585w5307w(0))) AND (NOT wire_w_lg_w_tenb_data_range584w5310w(0))) AND (NOT wire_w_lg_w_tenb_data_range583w5313w(0))) AND (NOT wire_w_lg_w_tenb_data_range582w5316w(0))) AND (NOT wire_w_lg_w_tenb_data_range581w5319w(0)));
	nl11i0O <= ((((((((((((((((NOT (tenb_data(0) XOR rsync_comp_pat(0))) AND (NOT (tenb_data(1) XOR rsync_comp_pat(1)))) AND (NOT (tenb_data(2) XOR rsync_comp_pat(2)))) AND (NOT (tenb_data(3) XOR rsync_comp_pat(3)))) AND (NOT (tenb_data(4) XOR rsync_comp_pat(4)))) AND (NOT (tenb_data(5) XOR rsync_comp_pat(5)))) AND (NOT (tenb_data(6) XOR rsync_comp_pat(6)))) AND (NOT (tenb_data(7) XOR rsync_comp_pat(7)))) AND (NOT (tenb_data(10) XOR rsync_comp_pat(8)))) AND (NOT (tenb_data(11) XOR rsync_comp_pat(9)))) AND (NOT (tenb_data(12) XOR rsync_comp_pat(10)))) AND (NOT (tenb_data(13) XOR rsync_comp_pat(11)))) AND (NOT (tenb_data(14) XOR rsync_comp_pat(12)))) AND (NOT (tenb_data(15) XOR rsync_comp_pat(13)))) AND (NOT (tenb_data(16) XOR rsync_comp_pat(14)))) AND (NOT (tenb_data(17) XOR rsync_comp_pat(15))));
	nl11i1i <= ((((((((((NOT (tenb_data(10) XOR rsync_comp_pat(10))) AND (NOT (tenb_data(11) XOR rsync_comp_pat(11)))) AND (NOT (tenb_data(12) XOR rsync_comp_pat(12)))) AND (NOT (tenb_data(13) XOR rsync_comp_pat(13)))) AND (NOT (tenb_data(14) XOR rsync_comp_pat(14)))) AND (NOT (tenb_data(15) XOR rsync_comp_pat(15)))) AND (NOT (tenb_data(16) XOR rsync_comp_pat(16)))) AND (NOT (tenb_data(17) XOR rsync_comp_pat(17)))) AND (NOT (tenb_data(18) XOR rsync_comp_pat(18)))) AND (NOT (tenb_data(19) XOR rsync_comp_pat(19))));
	nl11i1l <= ((((((((((((((((((((NOT (tenb_data(0) XOR rsync_comp_pat(0))) AND (NOT (tenb_data(1) XOR rsync_comp_pat(1)))) AND (NOT (tenb_data(2) XOR rsync_comp_pat(2)))) AND (NOT (tenb_data(3) XOR rsync_comp_pat(3)))) AND (NOT (tenb_data(4) XOR rsync_comp_pat(4)))) AND (NOT (tenb_data(5) XOR rsync_comp_pat(5)))) AND (NOT (tenb_data(6) XOR rsync_comp_pat(6)))) AND (NOT (tenb_data(7) XOR rsync_comp_pat(7)))) AND (NOT (tenb_data(8) XOR rsync_comp_pat(8)))) AND (NOT (tenb_data(9) XOR rsync_comp_pat(9)))) AND (NOT (tenb_data(10) XOR rsync_comp_pat(10)))) AND (NOT (tenb_data(11) XOR rsync_comp_pat(11)))) AND (NOT (tenb_data(12) XOR rsync_comp_pat(12)))) AND (NOT (tenb_data(13) XOR rsync_comp_pat(13)))) AND (NOT (tenb_data(14) XOR rsync_comp_pat(14)))) AND (NOT (tenb_data(15) XOR rsync_comp_pat(15)))) AND (NOT (tenb_data(16) XOR rsync_comp_pat(16)))) AND (NOT (tenb_data(17) XOR rsync_comp_pat(17)))) AND (NOT (tenb_data(18) XOR rsync_comp_pat(18)))) AND (NOT (tenb_data(19) XOR rsync_comp_pat(19))));
	nl11i1O <= (nl11i0O OR (wire_w_lg_rsync_comp_porn320w(0) AND (nl11i0l OR nl11i0i)));
	nl11iii <= (nl11iiO OR (rsync_comp_porn AND nl11iil));
	nl11iil <= ((((((((((NOT (wire_w_lg_w_rsync_comp_pat_range4891w4918w(0) XOR tenb_data(10))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4894w4921w(0) XOR tenb_data(11)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4898w4925w(0) XOR tenb_data(12)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4902w4929w(0) XOR tenb_data(13)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4906w4933w(0) XOR tenb_data(14)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4910w4937w(0) XOR tenb_data(15)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4914w4941w(0) XOR tenb_data(16)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range5249w5253w(0) XOR tenb_data(17)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4945w4946w(0) XOR tenb_data(18)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4949w4950w(0) XOR tenb_data(19))));
	nl11iiO <= ((((((((((NOT (rsync_comp_pat(0) XOR tenb_data(10))) AND (NOT (rsync_comp_pat(1) XOR tenb_data(11)))) AND (NOT (rsync_comp_pat(2) XOR tenb_data(12)))) AND (NOT (rsync_comp_pat(3) XOR tenb_data(13)))) AND (NOT (rsync_comp_pat(4) XOR tenb_data(14)))) AND (NOT (rsync_comp_pat(5) XOR tenb_data(15)))) AND (NOT (rsync_comp_pat(6) XOR tenb_data(16)))) AND (NOT (rsync_comp_pat(7) XOR tenb_data(17)))) AND (NOT (rsync_comp_pat(8) XOR tenb_data(18)))) AND (NOT (rsync_comp_pat(9) XOR tenb_data(19))));
	nl11ili <= (nl11ilO OR (rsync_comp_porn AND nl11ill));
	nl11ill <= ((((((((NOT (wire_w_lg_w_rsync_comp_pat_range4891w4918w(0) XOR tenb_data(10))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4894w4921w(0) XOR tenb_data(11)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4898w4925w(0) XOR tenb_data(12)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4902w4929w(0) XOR tenb_data(13)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4906w4933w(0) XOR tenb_data(14)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4910w4937w(0) XOR tenb_data(15)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range4914w4941w(0) XOR tenb_data(16)))) AND (NOT (wire_w_lg_w_rsync_comp_pat_range5249w5253w(0) XOR tenb_data(17))));
	nl11ilO <= ((((((((NOT (rsync_comp_pat(0) XOR tenb_data(10))) AND (NOT (rsync_comp_pat(1) XOR tenb_data(11)))) AND (NOT (rsync_comp_pat(2) XOR tenb_data(12)))) AND (NOT (rsync_comp_pat(3) XOR tenb_data(13)))) AND (NOT (rsync_comp_pat(4) XOR tenb_data(14)))) AND (NOT (rsync_comp_pat(5) XOR tenb_data(15)))) AND (NOT (rsync_comp_pat(6) XOR tenb_data(16)))) AND (NOT (rsync_comp_pat(7) XOR tenb_data(17))));
	nl11iOi <= ((((((((((NOT wire_w_lg_w_tenb_data_range597w5149w(0)) AND (NOT wire_w_lg_w_tenb_data_range596w5151w(0))) AND (NOT wire_w_lg_w_tenb_data_range595w5155w(0))) AND (NOT wire_w_lg_w_tenb_data_range594w5159w(0))) AND (NOT wire_w_lg_w_tenb_data_range593w5163w(0))) AND (NOT wire_w_lg_w_tenb_data_range592w5167w(0))) AND (NOT wire_w_lg_w_tenb_data_range591w5171w(0))) AND (NOT wire_w_lg_w_tenb_data_range590w5175w(0))) AND (NOT wire_w_lg_w_tenb_data_range98w5179w(0))) AND (NOT wire_w_lg_w_tenb_data_range589w5183w(0)));
	nl11iOl <= ((((((((((NOT (tenb_data(0) XOR rsync_comp_pat(30))) AND (NOT (tenb_data(1) XOR rsync_comp_pat(31)))) AND (NOT (tenb_data(2) XOR rsync_comp_pat(32)))) AND (NOT (tenb_data(3) XOR rsync_comp_pat(33)))) AND (NOT (tenb_data(4) XOR rsync_comp_pat(34)))) AND (NOT (tenb_data(5) XOR rsync_comp_pat(35)))) AND (NOT (tenb_data(6) XOR rsync_comp_pat(36)))) AND (NOT (tenb_data(7) XOR rsync_comp_pat(37)))) AND (NOT (tenb_data(8) XOR rsync_comp_pat(38)))) AND (NOT (tenb_data(9) XOR rsync_comp_pat(39))));
	nl11iOO <= ((((((((((NOT wire_w_lg_w_tenb_data_range597w5017w(0)) AND (NOT wire_w_lg_w_tenb_data_range596w5019w(0))) AND (NOT wire_w_lg_w_tenb_data_range595w5022w(0))) AND (NOT wire_w_lg_w_tenb_data_range594w5025w(0))) AND (NOT wire_w_lg_w_tenb_data_range593w5028w(0))) AND (NOT wire_w_lg_w_tenb_data_range592w5031w(0))) AND (NOT wire_w_lg_w_tenb_data_range591w5035w(0))) AND (NOT wire_w_lg_w_tenb_data_range590w5039w(0))) AND (NOT wire_w_lg_w_tenb_data_range98w5043w(0))) AND (NOT wire_w_lg_w_tenb_data_range589w5047w(0)));
	nl11l1i <= ((((((((((NOT (tenb_data(0) XOR rsync_comp_pat(10))) AND (NOT (tenb_data(1) XOR rsync_comp_pat(11)))) AND (NOT (tenb_data(2) XOR rsync_comp_pat(12)))) AND (NOT (tenb_data(3) XOR rsync_comp_pat(13)))) AND (NOT (tenb_data(4) XOR rsync_comp_pat(14)))) AND (NOT (tenb_data(5) XOR rsync_comp_pat(15)))) AND (NOT (tenb_data(6) XOR rsync_comp_pat(16)))) AND (NOT (tenb_data(7) XOR rsync_comp_pat(17)))) AND (NOT (tenb_data(8) XOR rsync_comp_pat(18)))) AND (NOT (tenb_data(9) XOR rsync_comp_pat(19))));
	nl11lii <= ((((((((((NOT wire_w_lg_w_tenb_data_range597w4919w(0)) AND (NOT wire_w_lg_w_tenb_data_range596w4922w(0))) AND (NOT wire_w_lg_w_tenb_data_range595w4926w(0))) AND (NOT wire_w_lg_w_tenb_data_range594w4930w(0))) AND (NOT wire_w_lg_w_tenb_data_range593w4934w(0))) AND (NOT wire_w_lg_w_tenb_data_range592w4938w(0))) AND (NOT wire_w_lg_w_tenb_data_range591w4942w(0))) AND (NOT wire_w_lg_w_tenb_data_range590w5296w(0))) AND (NOT wire_w_lg_w_tenb_data_range98w5358w(0))) AND (NOT wire_w_lg_w_tenb_data_range589w5361w(0)));
	nl11lil <= ((((((((((NOT (tenb_data(0) XOR rsync_comp_pat(0))) AND (NOT (tenb_data(1) XOR rsync_comp_pat(1)))) AND (NOT (tenb_data(2) XOR rsync_comp_pat(2)))) AND (NOT (tenb_data(3) XOR rsync_comp_pat(3)))) AND (NOT (tenb_data(4) XOR rsync_comp_pat(4)))) AND (NOT (tenb_data(5) XOR rsync_comp_pat(5)))) AND (NOT (tenb_data(6) XOR rsync_comp_pat(6)))) AND (NOT (tenb_data(7) XOR rsync_comp_pat(7)))) AND (NOT (tenb_data(8) XOR rsync_comp_pat(8)))) AND (NOT (tenb_data(9) XOR rsync_comp_pat(9))));
	nl11llO <= ((((((((NOT wire_w_lg_w_tenb_data_range597w5082w(0)) AND (NOT wire_w_lg_w_tenb_data_range596w5085w(0))) AND (NOT wire_w_lg_w_tenb_data_range595w5089w(0))) AND (NOT wire_w_lg_w_tenb_data_range594w5093w(0))) AND (NOT wire_w_lg_w_tenb_data_range593w5097w(0))) AND (NOT wire_w_lg_w_tenb_data_range592w5101w(0))) AND (NOT wire_w_lg_w_tenb_data_range591w5105w(0))) AND (NOT wire_w_lg_w_tenb_data_range590w5109w(0)));
	nl11lOi <= ((((((((NOT (tenb_data(0) XOR rsync_comp_pat(24))) AND (NOT (tenb_data(1) XOR rsync_comp_pat(25)))) AND (NOT (tenb_data(2) XOR rsync_comp_pat(26)))) AND (NOT (tenb_data(3) XOR rsync_comp_pat(27)))) AND (NOT (tenb_data(4) XOR rsync_comp_pat(28)))) AND (NOT (tenb_data(5) XOR rsync_comp_pat(29)))) AND (NOT (tenb_data(6) XOR rsync_comp_pat(30)))) AND (NOT (tenb_data(7) XOR rsync_comp_pat(31))));
	nl11O0i <= ((((((((NOT (tenb_data(0) XOR rsync_comp_pat(0))) AND (NOT (tenb_data(1) XOR rsync_comp_pat(1)))) AND (NOT (tenb_data(2) XOR rsync_comp_pat(2)))) AND (NOT (tenb_data(3) XOR rsync_comp_pat(3)))) AND (NOT (tenb_data(4) XOR rsync_comp_pat(4)))) AND (NOT (tenb_data(5) XOR rsync_comp_pat(5)))) AND (NOT (tenb_data(6) XOR rsync_comp_pat(6)))) AND (NOT (tenb_data(7) XOR rsync_comp_pat(7))));
	nl11O0l <= (nl11lil OR nl11lii);
	nl11O1l <= ((((((((NOT wire_w_lg_w_tenb_data_range597w4947w(0)) AND (NOT wire_w_lg_w_tenb_data_range596w4951w(0))) AND (NOT wire_w_lg_w_tenb_data_range595w4956w(0))) AND (NOT wire_w_lg_w_tenb_data_range594w4961w(0))) AND (NOT wire_w_lg_w_tenb_data_range593w4966w(0))) AND (NOT wire_w_lg_w_tenb_data_range592w4971w(0))) AND (NOT wire_w_lg_w_tenb_data_range591w4976w(0))) AND (NOT wire_w_lg_w_tenb_data_range590w4981w(0)));
	nl11O1O <= ((((((((NOT wire_w_lg_w_tenb_data_range597w4919w(0)) AND (NOT wire_w_lg_w_tenb_data_range596w4922w(0))) AND (NOT wire_w_lg_w_tenb_data_range595w4926w(0))) AND (NOT wire_w_lg_w_tenb_data_range594w4930w(0))) AND (NOT wire_w_lg_w_tenb_data_range593w4934w(0))) AND (NOT wire_w_lg_w_tenb_data_range592w4938w(0))) AND (NOT wire_w_lg_w_tenb_data_range591w4942w(0))) AND (NOT wire_w_lg_w_tenb_data_range590w5296w(0)));
	nl11Oil <= (((((((NOT wire_w_lg_w_tenb_data_range597w4919w(0)) AND (NOT wire_w_lg_w_tenb_data_range596w4922w(0))) AND (NOT wire_w_lg_w_tenb_data_range595w4926w(0))) AND (NOT wire_w_lg_w_tenb_data_range594w4930w(0))) AND (NOT wire_w_lg_w_tenb_data_range593w4934w(0))) AND (NOT wire_w_lg_w_tenb_data_range592w4938w(0))) AND (NOT wire_w_lg_w_tenb_data_range591w4942w(0)));
	nl11OiO <= (((((((NOT (tenb_data(0) XOR rsync_comp_pat(0))) AND (NOT (tenb_data(1) XOR rsync_comp_pat(1)))) AND (NOT (tenb_data(2) XOR rsync_comp_pat(2)))) AND (NOT (tenb_data(3) XOR rsync_comp_pat(3)))) AND (NOT (tenb_data(4) XOR rsync_comp_pat(4)))) AND (NOT (tenb_data(5) XOR rsync_comp_pat(5)))) AND (NOT (tenb_data(6) XOR rsync_comp_pat(6))));
	ph_fifo_empty <= wire_nl1000i_ph_fifo_empty;
	ph_fifo_full <= wire_nl1000i_ph_fifo_full;
	phystatus <= wire_nlOli_dataout;
	pipe_data <= ( wire_nlO0ili_o & wire_nlO0iiO_o & wire_nlO0iil_o & wire_nlO0iii_o & wire_nlO0i0O_o & wire_nlO0i0l_o & wire_nlO0i0i_o & wire_nlO0i1O_o & wire_nlO0i1l_o & wire_nlO0i1i_o & wire_nlO00OO_o & wire_nlO00Ol_o & wire_nlO00Oi_o & wire_nlO00lO_o & wire_nlO00ll_o & wire_nlO00li_o & wire_nlO00iO_o & wire_nlO00il_o & wire_nlO00ii_o & wire_nlO000O_o & wire_nlO000l_o & wire_nlO000i_o & wire_nlO001O_o & wire_nlO001l_o & wire_nlO001i_o & wire_nlO01OO_o & wire_nlO01Ol_o & wire_nlO01Oi_o & wire_nlO01lO_o & wire_nlO01ll_o & wire_nlO01li_o & wire_nlO01iO_o & wire_nlO01il_o & wire_nlO01ii_o & wire_nlO010O_o & wire_nlO010l_o & wire_nlO010i_o & wire_nlO011O_o & wire_nlO011l_o & wire_nlO011i_o & wire_nlO1OOO_o & wire_nlO1OOl_o & wire_nlO1OOi_o & wire_nlO1OlO_o & wire_nlO1Oll_o & wire_nlO1Oli_o & wire_nlO1OiO_o & wire_nlO1Oil_o & wire_nlO1Oii_o & wire_nlO1O0O_o & wire_nlO1O0l_o & wire_nlO1O0i_o & wire_nlO1O1O_o & wire_nlO1O1l_o & wire_nlO1O1i_o & wire_nlO1lOO_o & wire_nlO1lOl_o & wire_nlO1lOi_o & wire_nlO1llO_o & wire_nlO1lll_o & wire_nlO1lli_o & wire_nlO1liO_o & wire_nlO1lil_o & wire_nlO1lii_o);
	rd_enable2 <= niOiil;
	rd_enable_out <= nl1OOO;
	rptr_bin <= ( wire_nl1000i_rptr_bin(2 DOWNTO 0));
	running_disp <= ( wire_nli_dataout & wire_niO_dataout);
	rx_we_out <= nlO1i1l;
	rxc <= ( wire_n10i_dataout & wire_n11O_dataout & wire_n11l_dataout & wire_n11i_dataout);
	rxd <= ( wire_nil_dataout & wire_nii_dataout & wire_n0O_dataout & wire_n0l_dataout & wire_n0i_dataout & wire_n1O_dataout & wire_n1l_dataout & wire_n1i_dataout & wire_nlOO_dataout & wire_nlOl_dataout & wire_nlOi_dataout & wire_nllO_dataout & wire_nlll_dataout & wire_nlli_dataout & wire_nliO_dataout & wire_nlil_dataout & wire_nlii_dataout & wire_nl0O_dataout & wire_nl0l_dataout & wire_nl0i_dataout & wire_nl1O_dataout & wire_nl1l_dataout & wire_nl1i_dataout & wire_niOO_dataout & wire_niOl_dataout & wire_niOi_dataout & wire_nilO_dataout & wire_nill_dataout & wire_nili_dataout & wire_niiO_dataout & wire_niil_dataout & wire_niii_dataout & wire_ni0O_dataout & wire_ni0l_dataout & wire_ni0i_dataout & wire_ni1O_dataout & wire_ni1l_dataout & wire_ni1i_dataout & wire_n0OO_dataout & wire_n0Ol_dataout & wire_n0Oi_dataout & wire_n0lO_dataout & wire_n0ll_dataout & wire_n0li_dataout & wire_n0iO_dataout & wire_n0il_dataout & wire_n0ii_dataout & wire_n00O_dataout & wire_n00l_dataout & wire_n00i_dataout & wire_n01O_dataout & wire_n01l_dataout & wire_n01i_dataout & wire_n1OO_dataout & wire_n1Ol_dataout & wire_n1Oi_dataout & wire_n1lO_dataout & wire_n1ll_dataout & wire_n1li_dataout & wire_n1iO_dataout & wire_n1il_dataout & wire_n1ii_dataout & wire_n10O_dataout & wire_n10l_dataout);
	rxd_19 <= ( wire_nlOOi_dataout & wire_nlOlO_dataout);
	rxd_9 <= ( wire_nlOOO_dataout & wire_nlOOl_dataout);
	rxd_lpbk <= ( wire_nl1000i_data_out(57 DOWNTO 48) & wire_nl1000i_data_out(41 DOWNTO 32) & wire_nl1000i_data_out(25 DOWNTO 16) & wire_nl1000i_data_out(9 DOWNTO 0));
	rxstatus <= ( wire_nlOil_dataout & wire_nlOii_dataout & wire_nlO0O_dataout);
	rxvalid <= wire_nlOiO_dataout;
	signal_detect_out <= sigdetni;
	soft_reset_rclk1 <= wire_nli01l_dataout;
	soft_reset_wclk1 <= wire_nli00O_dataout;
	wptr_bin <= ( wire_nl1000i_wptr_bin(2 DOWNTO 0));
	wr_enable2 <= nl010i;
	wr_enable_out <= nl01li;
	wire_w_disp_err_delay_range16w(0) <= disp_err_delay(0);
	wire_w_disp_err_delay_range13w(0) <= disp_err_delay(1);
	wire_w_invalid_code_delay_range17w(0) <= invalid_code_delay(0);
	wire_w_invalid_code_delay_range14w(0) <= invalid_code_delay(1);
	wire_w_rsync_comp_pat_range4891w(0) <= rsync_comp_pat(0);
	wire_w_rsync_comp_pat_range4954w(0) <= rsync_comp_pat(10);
	wire_w_rsync_comp_pat_range4959w(0) <= rsync_comp_pat(11);
	wire_w_rsync_comp_pat_range4964w(0) <= rsync_comp_pat(12);
	wire_w_rsync_comp_pat_range4969w(0) <= rsync_comp_pat(13);
	wire_w_rsync_comp_pat_range4974w(0) <= rsync_comp_pat(14);
	wire_w_rsync_comp_pat_range4979w(0) <= rsync_comp_pat(15);
	wire_w_rsync_comp_pat_range5001w(0) <= rsync_comp_pat(16);
	wire_w_rsync_comp_pat_range5005w(0) <= rsync_comp_pat(17);
	wire_w_rsync_comp_pat_range5009w(0) <= rsync_comp_pat(18);
	wire_w_rsync_comp_pat_range5013w(0) <= rsync_comp_pat(19);
	wire_w_rsync_comp_pat_range4894w(0) <= rsync_comp_pat(1);
	wire_w_rsync_comp_pat_range5413w(0) <= rsync_comp_pat(20);
	wire_w_rsync_comp_pat_range5417w(0) <= rsync_comp_pat(21);
	wire_w_rsync_comp_pat_range5421w(0) <= rsync_comp_pat(22);
	wire_w_rsync_comp_pat_range5425w(0) <= rsync_comp_pat(23);
	wire_w_rsync_comp_pat_range5050w(0) <= rsync_comp_pat(24);
	wire_w_rsync_comp_pat_range5053w(0) <= rsync_comp_pat(25);
	wire_w_rsync_comp_pat_range5057w(0) <= rsync_comp_pat(26);
	wire_w_rsync_comp_pat_range5061w(0) <= rsync_comp_pat(27);
	wire_w_rsync_comp_pat_range5065w(0) <= rsync_comp_pat(28);
	wire_w_rsync_comp_pat_range5069w(0) <= rsync_comp_pat(29);
	wire_w_rsync_comp_pat_range4898w(0) <= rsync_comp_pat(2);
	wire_w_rsync_comp_pat_range5073w(0) <= rsync_comp_pat(30);
	wire_w_rsync_comp_pat_range5077w(0) <= rsync_comp_pat(31);
	wire_w_rsync_comp_pat_range5117w(0) <= rsync_comp_pat(32);
	wire_w_rsync_comp_pat_range5121w(0) <= rsync_comp_pat(33);
	wire_w_rsync_comp_pat_range5125w(0) <= rsync_comp_pat(34);
	wire_w_rsync_comp_pat_range5129w(0) <= rsync_comp_pat(35);
	wire_w_rsync_comp_pat_range5133w(0) <= rsync_comp_pat(36);
	wire_w_rsync_comp_pat_range5137w(0) <= rsync_comp_pat(37);
	wire_w_rsync_comp_pat_range5141w(0) <= rsync_comp_pat(38);
	wire_w_rsync_comp_pat_range5145w(0) <= rsync_comp_pat(39);
	wire_w_rsync_comp_pat_range4902w(0) <= rsync_comp_pat(3);
	wire_w_rsync_comp_pat_range4906w(0) <= rsync_comp_pat(4);
	wire_w_rsync_comp_pat_range4910w(0) <= rsync_comp_pat(5);
	wire_w_rsync_comp_pat_range4914w(0) <= rsync_comp_pat(6);
	wire_w_rsync_comp_pat_range5249w(0) <= rsync_comp_pat(7);
	wire_w_rsync_comp_pat_range4945w(0) <= rsync_comp_pat(8);
	wire_w_rsync_comp_pat_range4949w(0) <= rsync_comp_pat(9);
	wire_w_rsync_comp_size_range101w(0) <= rsync_comp_size(0);
	wire_w_rsync_comp_size_range105w(0) <= rsync_comp_size(1);
	wire_w_rx_data_rs_range546w(0) <= rx_data_rs(0);
	wire_w_rx_data_rs_range547w(0) <= rx_data_rs(1);
	wire_w_sync_resync_delay_range514w(0) <= sync_resync_delay(0);
	wire_w_sync_resync_delay_range537w(0) <= sync_resync_delay(1);
	wire_w_tenb_data_range597w(0) <= tenb_data(0);
	wire_w_tenb_data_range588w(0) <= tenb_data(10);
	wire_w_tenb_data_range587w(0) <= tenb_data(11);
	wire_w_tenb_data_range586w(0) <= tenb_data(12);
	wire_w_tenb_data_range585w(0) <= tenb_data(13);
	wire_w_tenb_data_range584w(0) <= tenb_data(14);
	wire_w_tenb_data_range583w(0) <= tenb_data(15);
	wire_w_tenb_data_range582w(0) <= tenb_data(16);
	wire_w_tenb_data_range581w(0) <= tenb_data(17);
	wire_w_tenb_data_range331w(0) <= tenb_data(18);
	wire_w_tenb_data_range580w(0) <= tenb_data(19);
	wire_w_tenb_data_range596w(0) <= tenb_data(1);
	wire_w_tenb_data_range595w(0) <= tenb_data(2);
	wire_w_tenb_data_range594w(0) <= tenb_data(3);
	wire_w_tenb_data_range593w(0) <= tenb_data(4);
	wire_w_tenb_data_range592w(0) <= tenb_data(5);
	wire_w_tenb_data_range591w(0) <= tenb_data(6);
	wire_w_tenb_data_range590w(0) <= tenb_data(7);
	wire_w_tenb_data_range98w(0) <= tenb_data(8);
	wire_w_tenb_data_range589w(0) <= tenb_data(9);
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN niOllOO57 <= niOllOO58;
		END IF;
		if (now = 0 ns) then
			niOllOO57 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN niOllOO58 <= niOllOO57;
		END IF;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN niOlO1i55 <= niOlO1i56;
		END IF;
		if (now = 0 ns) then
			niOlO1i55 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN niOlO1i56 <= niOlO1i55;
		END IF;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN niOOO0i49 <= niOOO0i50;
		END IF;
		if (now = 0 ns) then
			niOOO0i49 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN niOOO0i50 <= niOOO0i49;
		END IF;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN niOOO0O47 <= niOOO0O48;
		END IF;
		if (now = 0 ns) then
			niOOO0O47 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN niOOO0O48 <= niOOO0O47;
		END IF;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN niOOO1l53 <= niOOO1l54;
		END IF;
		if (now = 0 ns) then
			niOOO1l53 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN niOOO1l54 <= niOOO1l53;
		END IF;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN niOOO1O51 <= niOOO1O52;
		END IF;
		if (now = 0 ns) then
			niOOO1O51 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN niOOO1O52 <= niOOO1O51;
		END IF;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN niOOOOO45 <= niOOOOO46;
		END IF;
		if (now = 0 ns) then
			niOOOOO45 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN niOOOOO46 <= niOOOOO45;
		END IF;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl1010l11 <= nl1010l12;
		END IF;
		if (now = 0 ns) then
			nl1010l11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl1010l12 <= nl1010l11;
		END IF;
	END PROCESS;
	wire_nl1010l12_w_lg_w_lg_q111w112w(0) <= wire_nl1010l12_w_lg_q111w(0) AND rpmadatawidth;
	wire_nl1010l12_w_lg_q111w(0) <= nl1010l12 XOR nl1010l11;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl1010O10 <= nl1010O9;
		END IF;
	END PROCESS;
	wire_nl1010O10_w_lg_w_lg_q106w107w(0) <= wire_nl1010O10_w_lg_q106w(0) AND wire_w_rsync_comp_size_range105w(0);
	wire_nl1010O10_w_lg_q106w(0) <= nl1010O10 XOR nl1010O9;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl1010O9 <= nl1010O10;
		END IF;
		if (now = 0 ns) then
			nl1010O9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl1011i15 <= nl1011i16;
		END IF;
		if (now = 0 ns) then
			nl1011i15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl1011i16 <= nl1011i15;
		END IF;
	END PROCESS;
	wire_nl1011i16_w_lg_w_lg_q221w222w(0) <= NOT wire_nl1011i16_w_lg_q221w(0);
	wire_nl1011i16_w_lg_q221w(0) <= nl1011i16 XOR nl1011i15;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl1011O13 <= nl1011O14;
		END IF;
		if (now = 0 ns) then
			nl1011O13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl1011O14 <= nl1011O13;
		END IF;
	END PROCESS;
	wire_nl1011O14_w_lg_w_lg_q214w215w(0) <= wire_nl1011O14_w_lg_q214w(0) AND wire_nliOi_w_lg_w_o_range211w213w(0);
	wire_nl1011O14_w_lg_q214w(0) <= nl1011O14 XOR nl1011O13;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl101ii7 <= nl101ii8;
		END IF;
		if (now = 0 ns) then
			nl101ii7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl101ii8 <= nl101ii7;
		END IF;
	END PROCESS;
	wire_nl101ii8_w_lg_w_lg_q102w103w(0) <= wire_nl101ii8_w_lg_q102w(0) AND wire_w_rsync_comp_size_range101w(0);
	wire_nl101ii8_w_lg_q102w(0) <= nl101ii8 XOR nl101ii7;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl101iO5 <= nl101iO6;
		END IF;
		if (now = 0 ns) then
			nl101iO5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl101iO6 <= nl101iO5;
		END IF;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl101lO3 <= nl101lO4;
		END IF;
		if (now = 0 ns) then
			nl101lO3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl101lO4 <= nl101lO3;
		END IF;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl101OO1 <= nl101OO2;
		END IF;
		if (now = 0 ns) then
			nl101OO1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl101OO2 <= nl101OO1;
		END IF;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl1111i43 <= nl1111i44;
		END IF;
		if (now = 0 ns) then
			nl1111i43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl1111i44 <= nl1111i43;
		END IF;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl111ii41 <= nl111ii42;
		END IF;
		if (now = 0 ns) then
			nl111ii41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl111ii42 <= nl111ii41;
		END IF;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11l0l35 <= nl11l0l36;
		END IF;
		if (now = 0 ns) then
			nl11l0l35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11l0l36 <= nl11l0l35;
		END IF;
	END PROCESS;
	wire_nl11l0l36_w_lg_q296w(0) <= nl11l0l36 XOR nl11l0l35;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11l1l39 <= nl11l1l40;
		END IF;
		if (now = 0 ns) then
			nl11l1l39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11l1l40 <= nl11l1l39;
		END IF;
	END PROCESS;
	wire_nl11l1l40_w_lg_w_lg_q303w304w(0) <= wire_nl11l1l40_w_lg_q303w(0) AND wire_w_lg_w_lg_nl11lil298w302w(0);
	wire_nl11l1l40_w_lg_q303w(0) <= nl11l1l40 XOR nl11l1l39;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11l1O37 <= nl11l1O38;
		END IF;
		if (now = 0 ns) then
			nl11l1O37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11l1O38 <= nl11l1O37;
		END IF;
	END PROCESS;
	wire_nl11l1O38_w_lg_w_lg_q300w301w(0) <= NOT wire_nl11l1O38_w_lg_q300w(0);
	wire_nl11l1O38_w_lg_q300w(0) <= nl11l1O38 XOR nl11l1O37;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11liO33 <= nl11liO34;
		END IF;
		if (now = 0 ns) then
			nl11liO33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11liO34 <= nl11liO33;
		END IF;
	END PROCESS;
	wire_nl11liO34_w_lg_w_lg_q291w292w(0) <= wire_nl11liO34_w_lg_q291w(0) AND wire_w_lg_nl11OiO290w(0);
	wire_nl11liO34_w_lg_q291w(0) <= nl11liO34 XOR nl11liO33;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11lli31 <= nl11lli32;
		END IF;
		if (now = 0 ns) then
			nl11lli31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11lli32 <= nl11lli31;
		END IF;
	END PROCESS;
	wire_nl11lli32_w_lg_q288w(0) <= nl11lli32 XOR nl11lli31;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11lOl29 <= nl11lOl30;
		END IF;
		if (now = 0 ns) then
			nl11lOl29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11lOl30 <= nl11lOl29;
		END IF;
	END PROCESS;
	wire_nl11lOl30_w_lg_w_lg_q279w280w(0) <= wire_nl11lOl30_w_lg_q279w(0) AND wire_n1ill_w_lg_w_lg_nll10l275w278w(0);
	wire_nl11lOl30_w_lg_q279w(0) <= nl11lOl30 XOR nl11lOl29;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11lOO27 <= nl11lOO28;
		END IF;
		if (now = 0 ns) then
			nl11lOO27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11lOO28 <= nl11lOO27;
		END IF;
	END PROCESS;
	wire_nl11lOO28_w_lg_q277w(0) <= nl11lOO28 XOR nl11lOO27;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11O0O25 <= nl11O0O26;
		END IF;
		if (now = 0 ns) then
			nl11O0O25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11O0O26 <= nl11O0O25;
		END IF;
	END PROCESS;
	wire_nl11O0O26_w_lg_w_lg_q264w265w(0) <= NOT wire_nl11O0O26_w_lg_q264w(0);
	wire_nl11O0O26_w_lg_q264w(0) <= nl11O0O26 XOR nl11O0O25;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11Oli23 <= nl11Oli24;
		END IF;
		if (now = 0 ns) then
			nl11Oli23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11Oli24 <= nl11Oli23;
		END IF;
	END PROCESS;
	wire_nl11Oli24_w_lg_w_lg_q257w258w(0) <= NOT wire_nl11Oli24_w_lg_q257w(0);
	wire_nl11Oli24_w_lg_q257w(0) <= nl11Oli24 XOR nl11Oli23;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11OlO21 <= nl11OlO22;
		END IF;
		if (now = 0 ns) then
			nl11OlO21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11OlO22 <= nl11OlO21;
		END IF;
	END PROCESS;
	wire_nl11OlO22_w_lg_w_lg_q242w243w(0) <= wire_nl11OlO22_w_lg_q242w(0) AND wire_nliOi_w_lg_w_lg_w_o_range235w237w241w(0);
	wire_nl11OlO22_w_lg_q242w(0) <= nl11OlO22 XOR nl11OlO21;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11OOi19 <= nl11OOi20;
		END IF;
		if (now = 0 ns) then
			nl11OOi19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11OOi20 <= nl11OOi19;
		END IF;
	END PROCESS;
	wire_nl11OOi20_w_lg_w_lg_q239w240w(0) <= NOT wire_nl11OOi20_w_lg_q239w(0);
	wire_nl11OOi20_w_lg_q239w(0) <= nl11OOi20 XOR nl11OOi19;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11OOO17 <= nl11OOO18;
		END IF;
		if (now = 0 ns) then
			nl11OOO17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rx_wr_clk)
	BEGIN
		IF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN nl11OOO18 <= nl11OOO17;
		END IF;
	END PROCESS;
	wire_nl11OOO18_w_lg_w_lg_q228w229w(0) <= wire_nl11OOO18_w_lg_q228w(0) AND wire_nliOi_w_lg_w_o_range225w227w(0);
	wire_nl11OOO18_w_lg_q228w(0) <= nl11OOO18 XOR nl11OOO17;
	PROCESS (clk_2, wire_n1ill_CLRN)
	BEGIN
		IF (wire_n1ill_CLRN = '0') THEN
				n1i0i <= '0';
				n1i0O <= '0';
				n1i1O <= '0';
				n1iii <= '0';
				n1iil <= '0';
				n1iiO <= '0';
				n1ili <= '0';
				n1ilO <= '0';
				nli0iO <= '0';
				nlilOO <= '0';
				nliO0i <= '0';
				nliO0l <= '0';
				nliO0O <= '0';
				nliO1i <= '0';
				nliOii <= '0';
				nliOil <= '0';
				nliOiO <= '0';
				nliOli <= '0';
				nliOll <= '0';
				nliOlO <= '0';
				nliOOi <= '0';
				nliOOl <= '0';
				nliOOO <= '0';
				nll00i <= '0';
				nll00l <= '0';
				nll00O <= '0';
				nll01i <= '0';
				nll01l <= '0';
				nll01O <= '0';
				nll0ii <= '0';
				nll0il <= '0';
				nll0iO <= '0';
				nll0li <= '0';
				nll0ll <= '0';
				nll0lO <= '0';
				nll0Oi <= '0';
				nll0Ol <= '0';
				nll0OO <= '0';
				nll10i <= '0';
				nll10l <= '0';
				nll10O <= '0';
				nll11i <= '0';
				nll11l <= '0';
				nll11O <= '0';
				nll1ii <= '0';
				nll1il <= '0';
				nll1iO <= '0';
				nll1li <= '0';
				nll1ll <= '0';
				nll1lO <= '0';
				nll1Oi <= '0';
				nll1Ol <= '0';
				nll1OO <= '0';
				nlli0i <= '0';
				nlli0l <= '0';
				nlli0O <= '0';
				nlli1i <= '0';
				nlli1l <= '0';
				nlli1O <= '0';
				nlliii <= '0';
				nlliil <= '0';
				nlliiO <= '0';
				nllili <= '0';
				nllill <= '0';
				nllilO <= '0';
				nlliOi <= '0';
				nlliOl <= '0';
				nlliOO <= '0';
				nlll0i <= '0';
				nlll0l <= '0';
				nlll0O <= '0';
				nlll1i <= '0';
				nlll1l <= '0';
				nlll1O <= '0';
				nlllii <= '0';
				nlllil <= '0';
				nllliO <= '0';
				nlllli <= '0';
				nlllll <= '0';
				nllllO <= '0';
				nlllOi <= '0';
				nlllOl <= '0';
				nlO10Ol <= '0';
				nlO10OO <= '0';
				nlO1ili <= '0';
				nlOl0O <= '0';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
				n1i0i <= wire_n1iOi_dataout;
				n1i0O <= wire_n1iOl_dataout;
				n1i1O <= wire_n1i0l_dataout;
				n1iii <= n1iil;
				n1iil <= n1iiO;
				n1iiO <= n1ili;
				n1ili <= n1ilO;
				n1ilO <= wire_n1liO_dataout;
				nli0iO <= dec_data_valid(0);
				nlilOO <= dec_data_valid(1);
				nliO0i <= wire_n10Ol_dataout;
				nliO0l <= nliOiO;
				nliO0O <= nliOli;
				nliO1i <= wire_nlOlii_dataout;
				nliOii <= nliOll;
				nliOil <= nliOlO;
				nliOiO <= ovr_undflow(0);
				nliOli <= ovr_undflow(1);
				nliOll <= ovr_undflow(2);
				nliOlO <= ovr_undflow(3);
				nliOOi <= (nliOOl AND (niOOOll OR (wire_w_lg_rsync_comp_porn632w(0) AND (nl11l1i OR nl11iOO))));
				nliOOl <= nl11iii;
				nliOOO <= (nll11i AND (niOOOOl OR (wire_w_lg_rsync_comp_porn626w(0) AND (nl11O1l OR nl101il))));
				nll00i <= disp_val_delay(1);
				nll00l <= nll0ii;
				nll00O <= nll0il;
				nll01i <= nll01O;
				nll01l <= nll00i;
				nll01O <= disp_val_delay(0);
				nll0ii <= disp_err_delay(0);
				nll0il <= disp_err_delay(1);
				nll0iO <= nll0ll;
				nll0li <= nll0lO;
				nll0ll <= wire_n000i_dataout;
				nll0lO <= wire_n000l_dataout;
				nll0Oi <= wire_nlOlil_dataout;
				nll0Ol <= wire_nlOliO_dataout;
				nll0OO <= wire_nlOlli_dataout;
				nll10i <= nl11iii;
				nll10l <= nl11ili;
				nll10O <= nll1il;
				nll11i <= nl11ili;
				nll11l <= nl110Ol;
				nll11O <= nl11i1O;
				nll1ii <= nll1iO;
				nll1il <= wire_nli1l_o;
				nll1iO <= wire_niO1l_o;
				nll1li <= (nl101il AND nll1lO);
				nll1ll <= (nl11i0i AND nll1Oi);
				nll1lO <= (nl11O0i AND nll1Ol);
				nll1Oi <= (nl11ilO AND nll1OO);
				nll1Ol <= nl11O0i;
				nll1OO <= nl11ilO;
				nlli0i <= wire_nlOlOl_dataout;
				nlli0l <= wire_nlOlOO_dataout;
				nlli0O <= wire_nlOO1i_dataout;
				nlli1i <= wire_nlOlll_dataout;
				nlli1l <= wire_nlOllO_dataout;
				nlli1O <= wire_nlOlOi_dataout;
				nlliii <= wire_nlOO1l_dataout;
				nlliil <= wire_nlOO1O_dataout;
				nlliiO <= wire_nlOO0i_dataout;
				nllili <= wire_nlOO0l_dataout;
				nllill <= wire_nlOO0O_dataout;
				nllilO <= wire_nlOOii_dataout;
				nlliOi <= wire_nlOOil_dataout;
				nlliOl <= wire_nlOOiO_dataout;
				nlliOO <= wire_nlOOli_dataout;
				nlll0i <= wire_nlOOOl_dataout;
				nlll0l <= wire_nlOOOO_dataout;
				nlll0O <= wire_n111i_dataout;
				nlll1i <= wire_nlOOll_dataout;
				nlll1l <= wire_nlOOlO_dataout;
				nlll1O <= wire_nlOOOi_dataout;
				nlllii <= wire_n111l_dataout;
				nlllil <= wire_n111O_dataout;
				nllliO <= wire_n110i_dataout;
				nlllli <= wire_n110l_dataout;
				nlllll <= wire_n110O_dataout;
				nllllO <= wire_n11ii_dataout;
				nlllOi <= wire_n11il_dataout;
				nlllOl <= wire_n11iO_dataout;
				nlO10Ol <= nlO10OO;
				nlO10OO <= wire_w_lg_niOOO0l650w(0);
				nlO1ili <= wire_nlO1iil_dataout;
				nlOl0O <= n1i1O;
		END IF;
	END PROCESS;
	wire_n1ill_CLRN <= ((nl111ii42 XOR nl111ii41) AND wire_w_lg_soft_reset607w(0));
	wire_n1ill_w_lg_w_lg_nll10l275w278w(0) <= wire_n1ill_w_lg_nll10l275w(0) AND wire_nl11lOO28_w_lg_q277w(0);
	wire_n1ill_w_lg_w_lg_n1ili661w662w(0) <= wire_n1ill_w_lg_n1ili661w(0) AND n1ilO;
	wire_n1ill_w_lg_n1iil670w(0) <= n1iil AND wire_n1ill_w_lg_n1iii669w(0);
	wire_n1ill_w_lg_nliOOi312w(0) <= nliOOi AND wire_w_lg_nl11iOl311w(0);
	wire_n1ill_w_lg_nliOOO284w(0) <= nliOOO AND wire_w_lg_nl11lOi283w(0);
	wire_n1ill_w_lg_nll10i308w(0) <= nll10i AND wire_w_lg_nl11l1i307w(0);
	wire_n1ill_w_lg_nll10l275w(0) <= nll10l AND wire_w_lg_w_lg_rsync_comp_porn273w274w(0);
	wire_n1ill_w_lg_nll11l494w(0) <= nll11l AND wire_w_lg_nl1100l493w(0);
	wire_n1ill_w_lg_nll11O482w(0) <= nll11O AND wire_w_lg_nl110li481w(0);
	wire_n1ill_w_lg_n1i0i4636w(0) <= NOT n1i0i;
	wire_n1ill_w_lg_n1iii669w(0) <= NOT n1iii;
	wire_n1ill_w_lg_n1iil658w(0) <= NOT n1iil;
	wire_n1ill_w_lg_n1iiO656w(0) <= NOT n1iiO;
	wire_n1ill_w_lg_n1ili661w(0) <= NOT n1ili;
	wire_n1ill_w_lg_n1ilO602w(0) <= NOT n1ilO;
	wire_n1ill_w_lg_nll0ll513w(0) <= NOT nll0ll;
	wire_n1ill_w_lg_nll0lO536w(0) <= NOT nll0lO;
	PROCESS (rx_rd_clk, wire_nl011l_PRN, wire_nl011l_CLRN)
	BEGIN
		IF (wire_nl011l_PRN = '0') THEN
				niOiil <= '1';
				nl011i <= '1';
				nl011O <= '1';
				nl1OOO <= '1';
		ELSIF (wire_nl011l_CLRN = '0') THEN
				niOiil <= '0';
				nl011i <= '0';
				nl011O <= '0';
				nl1OOO <= '0';
		ELSIF (rx_rd_clk = '1' AND rx_rd_clk'event) THEN
				niOiil <= wire_nl010l_dataout;
				nl011i <= nl011O;
				nl011O <= wire_w_lg_niOOO0l650w(0);
				nl1OOO <= wire_nl01il_dataout;
		END IF;
	END PROCESS;
	wire_nl011l_CLRN <= ((niOOO1O52 XOR niOOO1O51) AND wire_nli01l_w_lg_dataout653w(0));
	wire_nl011l_PRN <= (niOOO1l54 XOR niOOO1l53);
	PROCESS (rx_rd_clk, wire_nli01O_PRN)
	BEGIN
		IF (wire_nli01O_PRN = '0') THEN
				nli00i <= '1';
				nli1iO <= '1';
		ELSIF (rx_rd_clk = '1' AND rx_rd_clk'event) THEN
				nli00i <= niOOOii;
				nli1iO <= nli00i;
		END IF;
	END PROCESS;
	wire_nli01O_PRN <= ((niOOO0O48 XOR niOOO0O47) AND wire_w_lg_nl101ll641w(0));
	PROCESS (rx_wr_clk, nl101ll)
	BEGIN
		IF (nl101ll = '1') THEN
				nli00l <= '1';
				nli0il <= '1';
		ELSIF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN
				nli00l <= nli0il;
				nli0il <= niOOOii;
		END IF;
	END PROCESS;
	PROCESS (rx_wr_clk, wire_nli1ii_PRN, wire_nli00O_dataout)
	BEGIN
		IF (wire_nli1ii_PRN = '0') THEN
				niiO0i <= '1';
				niiO0l <= '1';
				niiO0O <= '1';
				niiO1O <= '1';
				niiOii <= '1';
				niiOil <= '1';
				niiOiO <= '1';
				niiOli <= '1';
				niiOll <= '1';
				niiOlO <= '1';
				niiOOi <= '1';
				niiOOl <= '1';
				niiOOO <= '1';
				nil00i <= '1';
				nil00l <= '1';
				nil00O <= '1';
				nil01i <= '1';
				nil01l <= '1';
				nil01O <= '1';
				nil0ii <= '1';
				nil0il <= '1';
				nil0iO <= '1';
				nil0li <= '1';
				nil0ll <= '1';
				nil0lO <= '1';
				nil0Oi <= '1';
				nil0Ol <= '1';
				nil0OO <= '1';
				nil10i <= '1';
				nil10l <= '1';
				nil10O <= '1';
				nil11i <= '1';
				nil11l <= '1';
				nil11O <= '1';
				nil1ii <= '1';
				nil1il <= '1';
				nil1iO <= '1';
				nil1li <= '1';
				nil1ll <= '1';
				nil1lO <= '1';
				nil1Oi <= '1';
				nil1Ol <= '1';
				nil1OO <= '1';
				nili0i <= '1';
				nili0l <= '1';
				nili0O <= '1';
				nili1i <= '1';
				nili1l <= '1';
				nili1O <= '1';
				niliii <= '1';
				niliil <= '1';
				niliiO <= '1';
				nilili <= '1';
				nilill <= '1';
				nililO <= '1';
				niliOi <= '1';
				niliOl <= '1';
				niliOO <= '1';
				nill0i <= '1';
				nill0l <= '1';
				nill0O <= '1';
				nill1i <= '1';
				nill1l <= '1';
				nill1O <= '1';
				nillii <= '1';
				nillil <= '1';
				nilliO <= '1';
				nillli <= '1';
				nillll <= '1';
				nilllO <= '1';
				nillOi <= '1';
				nillOl <= '1';
				nillOO <= '1';
				nilO0i <= '1';
				nilO0l <= '1';
				nilO0O <= '1';
				nilO1i <= '1';
				nilO1l <= '1';
				nilO1O <= '1';
				nilOii <= '1';
				nilOil <= '1';
				nilOiO <= '1';
				nilOli <= '1';
				nilOll <= '1';
				nilOlO <= '1';
				nilOOi <= '1';
				nilOOl <= '1';
				nilOOO <= '1';
				niO00i <= '1';
				niO00l <= '1';
				niO00O <= '1';
				niO01i <= '1';
				niO01l <= '1';
				niO01O <= '1';
				niO0ii <= '1';
				niO0il <= '1';
				niO0iO <= '1';
				niO0li <= '1';
				niO0ll <= '1';
				niO0lO <= '1';
				niO0Oi <= '1';
				niO0Ol <= '1';
				niO0OO <= '1';
				niO10i <= '1';
				niO10l <= '1';
				niO10O <= '1';
				niO11i <= '1';
				niO11l <= '1';
				niO11O <= '1';
				niO1ii <= '1';
				niO1il <= '1';
				niO1iO <= '1';
				niO1li <= '1';
				niO1ll <= '1';
				niO1lO <= '1';
				niO1Oi <= '1';
				niO1Ol <= '1';
				niO1OO <= '1';
				niOi0i <= '1';
				niOi0l <= '1';
				niOi0O <= '1';
				niOi1i <= '1';
				niOi1l <= '1';
				niOi1O <= '1';
				niOiii <= '1';
				nl000i <= '1';
				nl000l <= '1';
				nl000O <= '1';
				nl001i <= '1';
				nl001l <= '1';
				nl001O <= '1';
				nl00ii <= '1';
				nl00il <= '1';
				nl00iO <= '1';
				nl00li <= '1';
				nl00ll <= '1';
				nl00lO <= '1';
				nl00Oi <= '1';
				nl00Ol <= '1';
				nl00OO <= '1';
				nl010i <= '1';
				nl01li <= '1';
				nl01ll <= '1';
				nl01lO <= '1';
				nl01Oi <= '1';
				nl01Ol <= '1';
				nl01OO <= '1';
				nl0i0i <= '1';
				nl0i0l <= '1';
				nl0i0O <= '1';
				nl0i1i <= '1';
				nl0i1l <= '1';
				nl0i1O <= '1';
				nl0iii <= '1';
				nl0iil <= '1';
				nl0iiO <= '1';
				nl0ili <= '1';
				nl0ill <= '1';
				nl0ilO <= '1';
				nl0iOi <= '1';
				nl0iOl <= '1';
				nl0iOO <= '1';
				nl0l0i <= '1';
				nl0l0l <= '1';
				nl0l0O <= '1';
				nl0l1i <= '1';
				nl0l1l <= '1';
				nl0l1O <= '1';
				nl0lii <= '1';
				nl0lil <= '1';
				nl0liO <= '1';
				nl0lli <= '1';
				nl0lll <= '1';
				nl0llO <= '1';
				nl0lOi <= '1';
				nl0lOl <= '1';
				nl0lOO <= '1';
				nl0O0i <= '1';
				nl0O0l <= '1';
				nl0O0O <= '1';
				nl0O1i <= '1';
				nl0O1l <= '1';
				nl0O1O <= '1';
				nl0Oii <= '1';
				nl0Oil <= '1';
				nl0OiO <= '1';
				nl0Oli <= '1';
				nl0Oll <= '1';
				nl0OlO <= '1';
				nl0OOi <= '1';
				nl0OOl <= '1';
				nl0OOO <= '1';
				nli10i <= '1';
				nli10l <= '1';
				nli10O <= '1';
				nli11i <= '1';
				nli11l <= '1';
				nli11O <= '1';
				nli1il <= '1';
				nlO1i1O <= '1';
		ELSIF (wire_nli00O_dataout = '1') THEN
				niiO0i <= '0';
				niiO0l <= '0';
				niiO0O <= '0';
				niiO1O <= '0';
				niiOii <= '0';
				niiOil <= '0';
				niiOiO <= '0';
				niiOli <= '0';
				niiOll <= '0';
				niiOlO <= '0';
				niiOOi <= '0';
				niiOOl <= '0';
				niiOOO <= '0';
				nil00i <= '0';
				nil00l <= '0';
				nil00O <= '0';
				nil01i <= '0';
				nil01l <= '0';
				nil01O <= '0';
				nil0ii <= '0';
				nil0il <= '0';
				nil0iO <= '0';
				nil0li <= '0';
				nil0ll <= '0';
				nil0lO <= '0';
				nil0Oi <= '0';
				nil0Ol <= '0';
				nil0OO <= '0';
				nil10i <= '0';
				nil10l <= '0';
				nil10O <= '0';
				nil11i <= '0';
				nil11l <= '0';
				nil11O <= '0';
				nil1ii <= '0';
				nil1il <= '0';
				nil1iO <= '0';
				nil1li <= '0';
				nil1ll <= '0';
				nil1lO <= '0';
				nil1Oi <= '0';
				nil1Ol <= '0';
				nil1OO <= '0';
				nili0i <= '0';
				nili0l <= '0';
				nili0O <= '0';
				nili1i <= '0';
				nili1l <= '0';
				nili1O <= '0';
				niliii <= '0';
				niliil <= '0';
				niliiO <= '0';
				nilili <= '0';
				nilill <= '0';
				nililO <= '0';
				niliOi <= '0';
				niliOl <= '0';
				niliOO <= '0';
				nill0i <= '0';
				nill0l <= '0';
				nill0O <= '0';
				nill1i <= '0';
				nill1l <= '0';
				nill1O <= '0';
				nillii <= '0';
				nillil <= '0';
				nilliO <= '0';
				nillli <= '0';
				nillll <= '0';
				nilllO <= '0';
				nillOi <= '0';
				nillOl <= '0';
				nillOO <= '0';
				nilO0i <= '0';
				nilO0l <= '0';
				nilO0O <= '0';
				nilO1i <= '0';
				nilO1l <= '0';
				nilO1O <= '0';
				nilOii <= '0';
				nilOil <= '0';
				nilOiO <= '0';
				nilOli <= '0';
				nilOll <= '0';
				nilOlO <= '0';
				nilOOi <= '0';
				nilOOl <= '0';
				nilOOO <= '0';
				niO00i <= '0';
				niO00l <= '0';
				niO00O <= '0';
				niO01i <= '0';
				niO01l <= '0';
				niO01O <= '0';
				niO0ii <= '0';
				niO0il <= '0';
				niO0iO <= '0';
				niO0li <= '0';
				niO0ll <= '0';
				niO0lO <= '0';
				niO0Oi <= '0';
				niO0Ol <= '0';
				niO0OO <= '0';
				niO10i <= '0';
				niO10l <= '0';
				niO10O <= '0';
				niO11i <= '0';
				niO11l <= '0';
				niO11O <= '0';
				niO1ii <= '0';
				niO1il <= '0';
				niO1iO <= '0';
				niO1li <= '0';
				niO1ll <= '0';
				niO1lO <= '0';
				niO1Oi <= '0';
				niO1Ol <= '0';
				niO1OO <= '0';
				niOi0i <= '0';
				niOi0l <= '0';
				niOi0O <= '0';
				niOi1i <= '0';
				niOi1l <= '0';
				niOi1O <= '0';
				niOiii <= '0';
				nl000i <= '0';
				nl000l <= '0';
				nl000O <= '0';
				nl001i <= '0';
				nl001l <= '0';
				nl001O <= '0';
				nl00ii <= '0';
				nl00il <= '0';
				nl00iO <= '0';
				nl00li <= '0';
				nl00ll <= '0';
				nl00lO <= '0';
				nl00Oi <= '0';
				nl00Ol <= '0';
				nl00OO <= '0';
				nl010i <= '0';
				nl01li <= '0';
				nl01ll <= '0';
				nl01lO <= '0';
				nl01Oi <= '0';
				nl01Ol <= '0';
				nl01OO <= '0';
				nl0i0i <= '0';
				nl0i0l <= '0';
				nl0i0O <= '0';
				nl0i1i <= '0';
				nl0i1l <= '0';
				nl0i1O <= '0';
				nl0iii <= '0';
				nl0iil <= '0';
				nl0iiO <= '0';
				nl0ili <= '0';
				nl0ill <= '0';
				nl0ilO <= '0';
				nl0iOi <= '0';
				nl0iOl <= '0';
				nl0iOO <= '0';
				nl0l0i <= '0';
				nl0l0l <= '0';
				nl0l0O <= '0';
				nl0l1i <= '0';
				nl0l1l <= '0';
				nl0l1O <= '0';
				nl0lii <= '0';
				nl0lil <= '0';
				nl0liO <= '0';
				nl0lli <= '0';
				nl0lll <= '0';
				nl0llO <= '0';
				nl0lOi <= '0';
				nl0lOl <= '0';
				nl0lOO <= '0';
				nl0O0i <= '0';
				nl0O0l <= '0';
				nl0O0O <= '0';
				nl0O1i <= '0';
				nl0O1l <= '0';
				nl0O1O <= '0';
				nl0Oii <= '0';
				nl0Oil <= '0';
				nl0OiO <= '0';
				nl0Oli <= '0';
				nl0Oll <= '0';
				nl0OlO <= '0';
				nl0OOi <= '0';
				nl0OOl <= '0';
				nl0OOO <= '0';
				nli10i <= '0';
				nli10l <= '0';
				nli10O <= '0';
				nli11i <= '0';
				nli11l <= '0';
				nli11O <= '0';
				nli1il <= '0';
				nlO1i1O <= '0';
		ELSIF (rx_wr_clk = '1' AND rx_wr_clk'event) THEN
				niiO0i <= wire_ni1liO_dataout;
				niiO0l <= wire_niOl0O_dataout;
				niiO0O <= wire_niOlii_dataout;
				niiO1O <= wire_nlO1ill_dataout;
				niiOii <= wire_niOlil_dataout;
				niiOil <= wire_niOliO_dataout;
				niiOiO <= wire_niOiiO_dataout;
				niiOli <= nillOl;
				niiOll <= nillOO;
				niiOlO <= nilO1i;
				niiOOi <= nilO1l;
				niiOOl <= nilO1O;
				niiOOO <= nilO0i;
				nil00i <= niO1il;
				nil00l <= niO1iO;
				nil00O <= niO1li;
				nil01i <= niO10l;
				nil01l <= niO10O;
				nil01O <= niO1ii;
				nil0ii <= niO1ll;
				nil0il <= niO1lO;
				nil0iO <= niO1Oi;
				nil0li <= niO1Ol;
				nil0ll <= niO1OO;
				nil0lO <= niO01i;
				nil0Oi <= niO01l;
				nil0Ol <= niO01O;
				nil0OO <= niO00i;
				nil10i <= nilOil;
				nil10l <= nilOiO;
				nil10O <= nilOli;
				nil11i <= nilO0l;
				nil11l <= nilO0O;
				nil11O <= nilOii;
				nil1ii <= nilOll;
				nil1il <= nilOlO;
				nil1iO <= nilOOi;
				nil1li <= nilOOl;
				nil1ll <= nilOOO;
				nil1lO <= niO11i;
				nil1Oi <= niO11l;
				nil1Ol <= niO11O;
				nil1OO <= niO10i;
				nili0i <= niO0il;
				nili0l <= niO0iO;
				nili0O <= niO0li;
				nili1i <= niO00l;
				nili1l <= niO00O;
				nili1O <= niO0ii;
				niliii <= niO0ll;
				niliil <= niO0lO;
				niliiO <= niO0Oi;
				nilili <= niO0Ol;
				nilill <= niO0OO;
				nililO <= niOi1i;
				niliOi <= wire_niOlOl_dataout;
				niliOl <= wire_niOlOO_dataout;
				niliOO <= wire_niOO1i_dataout;
				nill0i <= wire_niOO0l_dataout;
				nill0l <= wire_niOO0O_dataout;
				nill0O <= wire_niOOii_dataout;
				nill1i <= wire_niOO1l_dataout;
				nill1l <= wire_niOO1O_dataout;
				nill1O <= wire_niOO0i_dataout;
				nillii <= wire_niOOil_dataout;
				nillil <= wire_niOOiO_dataout;
				nilliO <= wire_niOOli_dataout;
				nillli <= wire_niOOll_dataout;
				nillll <= wire_niOOlO_dataout;
				nilllO <= wire_niOOOi_dataout;
				nillOi <= wire_niOOOl_dataout;
				nillOl <= wire_niOOOO_dataout;
				nillOO <= wire_nl111i_dataout;
				nilO0i <= wire_nl110l_dataout;
				nilO0l <= wire_nl110O_dataout;
				nilO0O <= wire_nl11ii_dataout;
				nilO1i <= wire_nl111l_dataout;
				nilO1l <= wire_nl111O_dataout;
				nilO1O <= wire_nl110i_dataout;
				nilOii <= wire_nl11il_dataout;
				nilOil <= wire_nl11iO_dataout;
				nilOiO <= wire_nl11li_dataout;
				nilOli <= wire_nl11ll_dataout;
				nilOll <= wire_nl11lO_dataout;
				nilOlO <= wire_nl11Oi_dataout;
				nilOOi <= wire_nl11Ol_dataout;
				nilOOl <= wire_nl11OO_dataout;
				nilOOO <= wire_nl101i_dataout;
				niO00i <= wire_nl1i0l_dataout;
				niO00l <= wire_nl1i0O_dataout;
				niO00O <= wire_nl1iii_dataout;
				niO01i <= wire_nl1i1l_dataout;
				niO01l <= wire_nl1i1O_dataout;
				niO01O <= wire_nl1i0i_dataout;
				niO0ii <= wire_nl1iil_dataout;
				niO0il <= wire_nl1iiO_dataout;
				niO0iO <= wire_nl1ili_dataout;
				niO0li <= wire_nl1ill_dataout;
				niO0ll <= wire_nl1ilO_dataout;
				niO0lO <= wire_nl1iOi_dataout;
				niO0Oi <= wire_nl1iOl_dataout;
				niO0Ol <= wire_nl1iOO_dataout;
				niO0OO <= wire_nl1l1i_dataout;
				niO10i <= wire_nl100l_dataout;
				niO10l <= wire_nl100O_dataout;
				niO10O <= wire_nl10ii_dataout;
				niO11i <= wire_nl101l_dataout;
				niO11l <= wire_nl101O_dataout;
				niO11O <= wire_nl100i_dataout;
				niO1ii <= wire_nl10il_dataout;
				niO1il <= wire_nl10iO_dataout;
				niO1iO <= wire_nl10li_dataout;
				niO1li <= wire_nl10ll_dataout;
				niO1ll <= wire_nl10lO_dataout;
				niO1lO <= wire_nl10Oi_dataout;
				niO1Oi <= wire_nl10Ol_dataout;
				niO1Ol <= wire_nl10OO_dataout;
				niO1OO <= wire_nl1i1i_dataout;
				niOi0i <= wire_niOl1O_dataout;
				niOi0l <= niOi0O;
				niOi0O <= niOiii;
				niOi1i <= wire_nl1l1l_dataout;
				niOi1l <= wire_nl1l1O_dataout;
				niOi1O <= wire_nl1l0i_dataout;
				niOiii <= bytordplden;
				nl000i <= wire_nli0li_dataout;
				nl000l <= wire_nli0ll_dataout;
				nl000O <= wire_nli0lO_dataout;
				nl001i <= pld_wr_dis;
				nl001l <= nliO1i;
				nl001O <= nliO1O;
				nl00ii <= wire_nli0Oi_dataout;
				nl00il <= wire_nli0Ol_dataout;
				nl00iO <= wire_nli0OO_dataout;
				nl00li <= wire_nlii1i_dataout;
				nl00ll <= wire_nlii1l_dataout;
				nl00lO <= wire_nlii1O_dataout;
				nl00Oi <= wire_nlii0i_dataout;
				nl00Ol <= wire_nlii0l_dataout;
				nl00OO <= wire_nlii0O_dataout;
				nl010i <= wire_nli1li_dataout;
				nl01li <= wire_nli1Oi_dataout;
				nl01ll <= nl01lO;
				nl01lO <= wire_w_lg_niOOO0l650w(0);
				nl01Oi <= (nl01OO XOR nl01Ol);
				nl01Ol <= nl01OO;
				nl01OO <= nl001i;
				nl0i0i <= wire_nliili_dataout;
				nl0i0l <= wire_nliill_dataout;
				nl0i0O <= wire_nliilO_dataout;
				nl0i1i <= wire_nliiii_dataout;
				nl0i1l <= wire_nliiil_dataout;
				nl0i1O <= wire_nliiiO_dataout;
				nl0iii <= wire_nliiOi_dataout;
				nl0iil <= wire_nliiOl_dataout;
				nl0iiO <= wire_nliiOO_dataout;
				nl0ili <= wire_nlil1i_dataout;
				nl0ill <= wire_nlil1l_dataout;
				nl0ilO <= wire_nlil1O_dataout;
				nl0iOi <= wire_nlil0i_dataout;
				nl0iOl <= wire_nlil0l_dataout;
				nl0iOO <= wire_nlil0O_dataout;
				nl0l0i <= wire_nlilli_dataout;
				nl0l0l <= wire_nlilll_dataout;
				nl0l0O <= nlO01O;
				nl0l1i <= wire_nlilii_dataout;
				nl0l1l <= wire_nlilil_dataout;
				nl0l1O <= wire_nliliO_dataout;
				nl0lii <= nlO00i;
				nl0lil <= nlO00l;
				nl0liO <= nlO00O;
				nl0lli <= nlO0ii;
				nl0lll <= nlO0il;
				nl0llO <= nlO0iO;
				nl0lOi <= nlO0li;
				nl0lOl <= nlO0ll;
				nl0lOO <= nlO0lO;
				nl0O0i <= nlOi1i;
				nl0O0l <= nlOi1l;
				nl0O0O <= nlOi1O;
				nl0O1i <= nlO0Oi;
				nl0O1l <= nlO0Ol;
				nl0O1O <= nlO0OO;
				nl0Oii <= nlOi0i;
				nl0Oil <= nlOi0l;
				nl0OiO <= nlOi0O;
				nl0Oli <= nlOiii;
				nl0Oll <= nlOiil;
				nl0OlO <= nlOiiO;
				nl0OOi <= nlOili;
				nl0OOl <= nlOill;
				nl0OOO <= nlOilO;
				nli10i <= nlOl1i;
				nli10l <= nlOl1l;
				nli10O <= nlOl1O;
				nli11i <= nlOiOi;
				nli11l <= nlOiOl;
				nli11O <= nlOiOO;
				nli1il <= nlOl0l;
				nlO1i1O <= niiO1O;
		END IF;
	END PROCESS;
	wire_nli1ii_PRN <= (niOOO0i50 XOR niOOO0i49);
	wire_nli1ii_w_lg_niiO0l6511w(0) <= NOT niiO0l;
	wire_nli1ii_w_lg_niiO0O6509w(0) <= NOT niiO0O;
	wire_nli1ii_w_lg_niiOii3801w(0) <= NOT niiOii;
	wire_nli1ii_w_lg_niiOil6507w(0) <= NOT niiOil;
	wire_nli1ii_w_lg_niOi0i600w(0) <= NOT niOi0i;
	wire_nli1ii_w_lg_niOi0l676w(0) <= NOT niOi0l;
	wire_nli1ii_w_lg_nl01Oi645w(0) <= NOT nl01Oi;
	wire_nli1ii_w_lg_nlO1i1O604w(0) <= NOT nlO1i1O;
	PROCESS (clk_2, wire_nlO01i_PRN, wire_nlO01i_CLRN)
	BEGIN
		IF (wire_nlO01i_PRN = '0') THEN
				nliO1l <= '1';
				nlllOO <= '1';
				nllO0i <= '1';
				nllO0l <= '1';
				nllO0O <= '1';
				nllO1i <= '1';
				nllO1l <= '1';
				nllO1O <= '1';
				nllOii <= '1';
				nllOil <= '1';
				nllOiO <= '1';
				nllOli <= '1';
				nllOll <= '1';
				nllOlO <= '1';
				nllOOi <= '1';
				nllOOl <= '1';
				nllOOO <= '1';
				nlO01l <= '1';
				nlO10i <= '1';
				nlO10l <= '1';
				nlO10O <= '1';
				nlO11i <= '1';
				nlO11l <= '1';
				nlO11O <= '1';
				nlO1ii <= '1';
				nlO1il <= '1';
				nlO1iO <= '1';
				nlO1li <= '1';
				nlO1ll <= '1';
				nlO1lO <= '1';
				nlO1Oi <= '1';
				nlO1Ol <= '1';
				nlO1OO <= '1';
		ELSIF (wire_nlO01i_CLRN = '0') THEN
				nliO1l <= '0';
				nlllOO <= '0';
				nllO0i <= '0';
				nllO0l <= '0';
				nllO0O <= '0';
				nllO1i <= '0';
				nllO1l <= '0';
				nllO1O <= '0';
				nllOii <= '0';
				nllOil <= '0';
				nllOiO <= '0';
				nllOli <= '0';
				nllOll <= '0';
				nllOlO <= '0';
				nllOOi <= '0';
				nllOOl <= '0';
				nllOOO <= '0';
				nlO01l <= '0';
				nlO10i <= '0';
				nlO10l <= '0';
				nlO10O <= '0';
				nlO11i <= '0';
				nlO11l <= '0';
				nlO11O <= '0';
				nlO1ii <= '0';
				nlO1il <= '0';
				nlO1iO <= '0';
				nlO1li <= '0';
				nlO1ll <= '0';
				nlO1lO <= '0';
				nlO1Oi <= '0';
				nlO1Ol <= '0';
				nlO1OO <= '0';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
			IF (nl1111l = '1') THEN
				nliO1l <= nl1111O;
				nlllOO <= wire_n1lOi_dataout;
				nllO0i <= wire_n1O1l_dataout;
				nllO0l <= wire_n1O1O_dataout;
				nllO0O <= wire_n1O0i_dataout;
				nllO1i <= wire_n1lOl_dataout;
				nllO1l <= wire_n1lOO_dataout;
				nllO1O <= wire_n1O1i_dataout;
				nllOii <= wire_n1O0l_dataout;
				nllOil <= wire_n1O0O_dataout;
				nllOiO <= wire_n1Oii_dataout;
				nllOli <= wire_n01Oi_dataout;
				nllOll <= wire_n01ll_dataout;
				nllOlO <= wire_n011O_dataout;
				nllOOi <= wire_n010l_dataout;
				nllOOl <= wire_n010O_dataout;
				nllOOO <= wire_n01iO_dataout;
				nlO01l <= wire_n01li_dataout;
				nlO10i <= wire_n1Oll_dataout;
				nlO10l <= wire_n1OlO_dataout;
				nlO10O <= wire_n1OOi_dataout;
				nlO11i <= wire_n1Oil_dataout;
				nlO11l <= wire_n1OiO_dataout;
				nlO11O <= wire_n1Oli_dataout;
				nlO1ii <= wire_n1OOl_dataout;
				nlO1il <= wire_n1OOO_dataout;
				nlO1iO <= wire_n011i_dataout;
				nlO1li <= wire_n011l_dataout;
				nlO1ll <= wire_n01Ol_dataout;
				nlO1lO <= wire_n01lO_dataout;
				nlO1Oi <= wire_n010i_dataout;
				nlO1Ol <= wire_n01ii_dataout;
				nlO1OO <= wire_n01il_dataout;
			END IF;
		END IF;
	END PROCESS;
	wire_nlO01i_CLRN <= ((nl1111i44 XOR nl1111i43) AND wire_w_lg_soft_reset607w(0));
	wire_nlO01i_PRN <= (niOOOOO46 XOR niOOOOO45);
	PROCESS (clk_2, wire_nlO1i1i_PRN, wire_nlO1i1i_CLRN)
	BEGIN
		IF (wire_nlO1i1i_PRN = '0') THEN
				nlO1i1l <= '1';
		ELSIF (wire_nlO1i1i_CLRN = '0') THEN
				nlO1i1l <= '0';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
				nlO1i1l <= wire_nlO1i0i_dataout;
		END IF;
	END PROCESS;
	wire_nlO1i1i_CLRN <= (niOlO1i56 XOR niOlO1i55);
	wire_nlO1i1i_PRN <= ((niOllOO58 XOR niOllOO57) AND wire_w_lg_soft_reset607w(0));
	wire_nlO1i1i_w_lg_nlO1i1l613w(0) <= NOT nlO1i1l;
	PROCESS (clk_2, soft_reset)
	BEGIN
		IF (soft_reset = '1') THEN
				nliO1O <= '0';
				nlO00i <= '0';
				nlO00l <= '0';
				nlO00O <= '0';
				nlO01O <= '0';
				nlO0ii <= '0';
				nlO0il <= '0';
				nlO0iO <= '0';
				nlO0li <= '0';
				nlO0ll <= '0';
				nlO0lO <= '0';
				nlO0Oi <= '0';
				nlO0Ol <= '0';
				nlO0OO <= '0';
				nlOi0i <= '0';
				nlOi0l <= '0';
				nlOi0O <= '0';
				nlOi1i <= '0';
				nlOi1l <= '0';
				nlOi1O <= '0';
				nlOiii <= '0';
				nlOiil <= '0';
				nlOiiO <= '0';
				nlOili <= '0';
				nlOill <= '0';
				nlOilO <= '0';
				nlOiOi <= '0';
				nlOiOl <= '0';
				nlOiOO <= '0';
				nlOl0l <= '0';
				nlOl1i <= '0';
				nlOl1l <= '0';
				nlOl1O <= '0';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
			IF (nl1110i = '1') THEN
				nliO1O <= nl1111O;
				nlO00i <= wire_n1lOl_dataout;
				nlO00l <= wire_n1lOO_dataout;
				nlO00O <= wire_n1O1i_dataout;
				nlO01O <= wire_n1lOi_dataout;
				nlO0ii <= wire_n1O1l_dataout;
				nlO0il <= wire_n1O1O_dataout;
				nlO0iO <= wire_n1O0i_dataout;
				nlO0li <= wire_n1O0l_dataout;
				nlO0ll <= wire_n1O0O_dataout;
				nlO0lO <= wire_n1Oii_dataout;
				nlO0Oi <= wire_n01Oi_dataout;
				nlO0Ol <= wire_n01ll_dataout;
				nlO0OO <= wire_n011O_dataout;
				nlOi0i <= wire_n1Oil_dataout;
				nlOi0l <= wire_n1OiO_dataout;
				nlOi0O <= wire_n1Oli_dataout;
				nlOi1i <= wire_n010l_dataout;
				nlOi1l <= wire_n010O_dataout;
				nlOi1O <= wire_n01iO_dataout;
				nlOiii <= wire_n1Oll_dataout;
				nlOiil <= wire_n1OlO_dataout;
				nlOiiO <= wire_n1OOi_dataout;
				nlOili <= wire_n1OOl_dataout;
				nlOill <= wire_n1OOO_dataout;
				nlOilO <= wire_n011i_dataout;
				nlOiOi <= wire_n011l_dataout;
				nlOiOl <= wire_n01Ol_dataout;
				nlOiOO <= wire_n01lO_dataout;
				nlOl0l <= wire_n01li_dataout;
				nlOl1i <= wire_n010i_dataout;
				nlOl1l <= wire_n01ii_dataout;
				nlOl1O <= wire_n01il_dataout;
			END IF;
		END IF;
	END PROCESS;
	wire_n0000i_dataout <= wire_n0illl_dataout WHEN niOOliO = '1'  ELSE wire_n0i1il_o;
	wire_n0000l_dataout <= wire_n0illO_dataout WHEN niOOliO = '1'  ELSE wire_n0i1iO_o;
	wire_n0000O_dataout <= wire_n0ilOi_dataout WHEN niOOliO = '1'  ELSE wire_n0i1li_o;
	wire_n0001i_dataout <= wire_n0ilil_dataout WHEN niOOliO = '1'  ELSE wire_n0i10l_o;
	wire_n0001l_dataout <= wire_n0iliO_dataout WHEN niOOliO = '1'  ELSE wire_n0i10O_o;
	wire_n0001O_dataout <= wire_n0illi_dataout WHEN niOOliO = '1'  ELSE wire_n0i1ii_o;
	wire_n000i_dataout <= sync_resync_pre(0) WHEN nl101Ol = '1'  ELSE sync_resync_delay(0);
	wire_n000ii_dataout <= wire_n0ilOl_dataout WHEN niOOliO = '1'  ELSE wire_n0i1ll_o;
	wire_n000il_dataout <= wire_n0ilOO_dataout WHEN niOOliO = '1'  ELSE wire_n0i1lO_o;
	wire_n000iO_dataout <= wire_n0iO1i_dataout WHEN niOOliO = '1'  ELSE wire_n0i1Oi_o;
	wire_n000l_dataout <= sync_resync_pre(1) WHEN nl101Ol = '1'  ELSE sync_resync_delay(1);
	wire_n000li_dataout <= wire_n0iO1l_dataout WHEN niOOliO = '1'  ELSE wire_n0i1Ol_o;
	wire_n000ll_dataout <= wire_n0iO1O_dataout WHEN niOOliO = '1'  ELSE wire_n0i1OO_o;
	wire_n000lO_dataout <= wire_n0iO0i_dataout WHEN niOOliO = '1'  ELSE wire_n0i01i_o;
	wire_n000O_dataout <= wire_ni01i_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_rs(0);
	wire_n000Oi_dataout <= wire_n0iO0l_dataout WHEN niOOliO = '1'  ELSE wire_n0i01l_o;
	wire_n000Ol_dataout <= wire_n0iOii_dataout WHEN niOOliO = '1'  ELSE wire_n0i01O_o;
	wire_n000OO_dataout <= wire_n0iOil_dataout WHEN niOOliO = '1'  ELSE wire_n0i00i_o;
	wire_n0010i_dataout <= nill0l WHEN niOOliO = '1'  ELSE wire_n00Oil_o;
	wire_n0010l_dataout <= nill0O WHEN niOOliO = '1'  ELSE wire_n00OiO_o;
	wire_n0010O_dataout <= nillii WHEN niOOliO = '1'  ELSE wire_n00Oli_o;
	wire_n0011i_dataout <= nill1l WHEN niOOliO = '1'  ELSE wire_n00O0l_o;
	wire_n0011l_dataout <= nill1O WHEN niOOliO = '1'  ELSE wire_n00O0O_o;
	wire_n0011O_dataout <= nill0i WHEN niOOliO = '1'  ELSE wire_n00Oii_o;
	wire_n001ii_dataout <= nillil WHEN niOOliO = '1'  ELSE wire_n00Oll_o;
	wire_n001il_dataout <= nilliO WHEN niOOliO = '1'  ELSE wire_n00OlO_o;
	wire_n001iO_dataout <= nillli WHEN niOOliO = '1'  ELSE wire_n00OOi_o;
	wire_n001l_dataout <= wire_nli1l_o AND NOT((wire_w_lg_rsync_sm_dis1w(0) AND wire_nlilOi_w_lg_dataout523w(0)));
	wire_n001li_dataout <= nillll WHEN niOOliO = '1'  ELSE wire_n00OOl_o;
	wire_n001ll_dataout <= nilllO WHEN niOOliO = '1'  ELSE wire_n00OOO_o;
	wire_n001lO_dataout <= nillOi WHEN niOOliO = '1'  ELSE wire_n0i11i_o;
	wire_n001Oi_dataout <= wire_n0il0l_dataout WHEN niOOliO = '1'  ELSE wire_n0i11l_o;
	wire_n001Ol_dataout <= wire_n0il0O_dataout WHEN niOOliO = '1'  ELSE wire_n0i11O_o;
	wire_n001OO_dataout <= wire_n0ilii_dataout WHEN niOOliO = '1'  ELSE wire_n0i10i_o;
	wire_n00i_dataout <= wire_nlO1O0O_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(14);
	wire_n00i0i_dataout <= wire_n0iOlO_dataout WHEN niOOliO = '1'  ELSE wire_n0i0il_o;
	wire_n00i0l_dataout <= wire_n0iOOi_dataout WHEN niOOliO = '1'  ELSE wire_n0i0iO_o;
	wire_n00i0O_dataout <= wire_n0iOOl_dataout WHEN niOOliO = '1'  ELSE wire_n0i0li_o;
	wire_n00i1i_dataout <= wire_n0iOiO_dataout WHEN niOOliO = '1'  ELSE wire_n0i00l_o;
	wire_n00i1l_dataout <= wire_n0iOli_dataout WHEN niOOliO = '1'  ELSE wire_n0i00O_o;
	wire_n00i1O_dataout <= wire_n0iOll_dataout WHEN niOOliO = '1'  ELSE wire_n0i0ii_o;
	wire_n00ii_dataout <= wire_ni01l_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_rs(1);
	wire_n00iii_dataout <= wire_n0iOOO_dataout WHEN niOOliO = '1'  ELSE wire_n0i0ll_o;
	wire_n00iil_dataout <= wire_n0l11i_dataout WHEN niOOliO = '1'  ELSE wire_n0i0lO_o;
	wire_n00iiO_dataout <= wire_n0l11l_o WHEN niOOliO = '1'  ELSE wire_n0i0Oi_o;
	wire_n00il_dataout <= wire_ni01O_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_rs(2);
	wire_n00ili_dataout <= wire_n0l11O_dataout WHEN niOOliO = '1'  ELSE wire_n0i0Ol_o;
	wire_n00ill_dataout <= wire_n0l10i_dataout WHEN niOOliO = '1'  ELSE wire_n0i0OO_o;
	wire_n00ilO_dataout <= wire_n0l10l_dataout WHEN niOOliO = '1'  ELSE wire_n0ii1i_o;
	wire_n00iO_dataout <= wire_ni00i_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_rs(3);
	wire_n00iOi_dataout <= wire_n0l10O_dataout WHEN niOOliO = '1'  ELSE wire_n0ii1l_o;
	wire_n00iOl_dataout <= wire_n0l1ii_dataout WHEN niOOliO = '1'  ELSE wire_n0ii1O_o;
	wire_n00iOO_dataout <= wire_n0l1li_dataout WHEN niOOliO = '1'  ELSE wire_n0ii0i_o;
	wire_n00l_dataout <= wire_nlO1Oii_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(15);
	wire_n00l0i_dataout <= wire_n0l1Ol_dataout WHEN niOOliO = '1'  ELSE wire_n0iiil_o;
	wire_n00l0l_dataout <= wire_n0l1OO_dataout WHEN niOOliO = '1'  ELSE wire_n0iiiO_o;
	wire_n00l0O_dataout <= wire_n0l01i_dataout WHEN niOOliO = '1'  ELSE wire_n0iili_o;
	wire_n00l1i_dataout <= wire_n0l1ll_dataout WHEN niOOliO = '1'  ELSE wire_n0ii0l_o;
	wire_n00l1l_dataout <= wire_n0l1lO_dataout WHEN niOOliO = '1'  ELSE wire_n0ii0O_o;
	wire_n00l1O_dataout <= wire_n0l1Oi_dataout WHEN niOOliO = '1'  ELSE wire_n0iiii_o;
	wire_n00li_dataout <= wire_ni00l_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_rs(4);
	wire_n00lii_dataout <= wire_n0l01l_dataout WHEN niOOliO = '1'  ELSE wire_n0iill_o;
	wire_n00lil_dataout <= wire_n0l01O_dataout WHEN niOOliO = '1'  ELSE wire_n0iilO_o;
	wire_n00liO_dataout <= wire_n0l00i_dataout WHEN niOOliO = '1'  ELSE wire_n0iiOi_o;
	wire_n00ll_dataout <= wire_ni00O_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_rs(5);
	wire_n00lli_dataout <= wire_n0l00l_o WHEN niOOliO = '1'  ELSE wire_n0iiOl_o;
	wire_n00lll_dataout <= wire_n0l00O_dataout WHEN niOOliO = '1'  ELSE wire_n0iiOO_o;
	wire_n00llO_dataout <= wire_n0l0ii_dataout WHEN niOOliO = '1'  ELSE wire_n0il1i_o;
	wire_n00lO_dataout <= wire_ni0ii_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_rs(6);
	wire_n00lOi_dataout <= wire_n0l0il_dataout WHEN niOOliO = '1'  ELSE wire_n0il1l_o;
	wire_n00lOl_dataout <= wire_n0l0iO_dataout WHEN niOOliO = '1'  ELSE wire_n0il1O_o;
	wire_n00lOO_dataout <= wire_n0l0li_dataout WHEN niOOliO = '1'  ELSE wire_n0il0i_o;
	wire_n00O_dataout <= wire_nlO1Oil_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(16);
	wire_n00Oi_dataout <= wire_ni0il_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_rs(7);
	wire_n00Ol_dataout <= wire_ni0iO_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_control_rs;
	wire_n00OO_dataout <= wire_ni0li_dataout WHEN rendec_data_sel_rx = '1'  ELSE (rx_control_rs AND wire_w_lg_nl111ll574w(0));
	wire_n0100i_dataout <= wire_nl1iOi_dataout AND NOT(niOlOii);
	wire_n0100l_dataout <= wire_nl1iOl_dataout AND NOT(niOlOii);
	wire_n0100O_dataout <= wire_nl1iOO_dataout AND NOT(niOlOii);
	wire_n0101i_dataout <= wire_nl1ili_dataout AND NOT(niOlOii);
	wire_n0101l_dataout <= wire_nl1ill_dataout AND NOT(niOlOii);
	wire_n0101O_dataout <= wire_nl1ilO_dataout AND NOT(niOlOii);
	wire_n010i_dataout <= wire_n0ilO_dataout WHEN endec_rx = '1'  ELSE wire_n01OO_dataout;
	wire_n010ii_dataout <= wire_nl1l1i_dataout AND NOT(niOlOii);
	wire_n010il_dataout <= wire_nl1l1l_dataout AND NOT(niOlOii);
	wire_n010iO_dataout <= rbytordpadval(0) WHEN niOlOil = '1'  ELSE wire_niOOOO_dataout;
	wire_n010l_dataout <= wire_n0iOi_dataout WHEN endec_rx = '1'  ELSE ovr_undflow(0);
	wire_n010li_dataout <= rbytordpadval(1) WHEN niOlOil = '1'  ELSE wire_nl111i_dataout;
	wire_n010ll_dataout <= rbytordpadval(2) WHEN niOlOil = '1'  ELSE wire_nl111l_dataout;
	wire_n010lO_dataout <= rbytordpadval(3) WHEN niOlOil = '1'  ELSE wire_nl111O_dataout;
	wire_n010O_dataout <= wire_n0iOl_dataout WHEN endec_rx = '1'  ELSE ovr_undflow(1);
	wire_n010Oi_dataout <= rbytordpadval(4) WHEN niOlOil = '1'  ELSE wire_nl110i_dataout;
	wire_n010Ol_dataout <= rbytordpadval(5) WHEN niOlOil = '1'  ELSE wire_nl110l_dataout;
	wire_n010OO_dataout <= rbytordpadval(6) WHEN niOlOil = '1'  ELSE wire_nl110O_dataout;
	wire_n0110i_dataout <= wire_nl10Oi_dataout AND NOT(niOlOii);
	wire_n0110l_dataout <= wire_nl10Ol_dataout AND NOT(niOlOii);
	wire_n0110O_dataout <= wire_nl10OO_dataout AND NOT(niOlOii);
	wire_n0111i_dataout <= wire_nl10li_dataout AND NOT(niOlOii);
	wire_n0111l_dataout <= wire_nl10ll_dataout AND NOT(niOlOii);
	wire_n0111O_dataout <= wire_nl10lO_dataout AND NOT(niOlOii);
	wire_n011i_dataout <= wire_n0iiO_dataout WHEN endec_rx = '1'  ELSE tenb_data(18);
	wire_n011ii_dataout <= wire_nl1i1i_dataout AND NOT(niOlOii);
	wire_n011il_dataout <= wire_nl1i1l_dataout AND NOT(niOlOii);
	wire_n011iO_dataout <= wire_nl1i1O_dataout AND NOT(niOlOii);
	wire_n011l_dataout <= wire_n0ili_dataout WHEN endec_rx = '1'  ELSE tenb_data(19);
	wire_n011li_dataout <= wire_nl1i0i_dataout AND NOT(niOlOii);
	wire_n011ll_dataout <= wire_nl1i0l_dataout AND NOT(niOlOii);
	wire_n011lO_dataout <= wire_nl1i0O_dataout AND NOT(niOlOii);
	wire_n011O_dataout <= wire_n0ill_dataout WHEN endec_rx = '1'  ELSE wire_n001l_dataout;
	wire_n011Oi_dataout <= wire_nl1iii_dataout AND NOT(niOlOii);
	wire_n011Ol_dataout <= wire_nl1iil_dataout AND NOT(niOlOii);
	wire_n011OO_dataout <= wire_nl1iiO_dataout AND NOT(niOlOii);
	wire_n01i_dataout <= wire_nlO1O1O_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(11);
	wire_n01i0i_dataout <= wire_niOOiO_dataout WHEN niOlOil = '1'  ELSE wire_nl11li_dataout;
	wire_n01i0l_dataout <= wire_nl11ll_dataout AND NOT(niOlOil);
	wire_n01i0O_dataout <= wire_nl11lO_dataout AND NOT(niOlOil);
	wire_n01i1i_dataout <= rbytordpadval(7) WHEN niOlOil = '1'  ELSE wire_nl11ii_dataout;
	wire_n01i1l_dataout <= rbytordpadval(8) WHEN niOlOil = '1'  ELSE wire_nl11il_dataout;
	wire_n01i1O_dataout <= rbytordpadval(9) WHEN niOlOil = '1'  ELSE wire_nl11iO_dataout;
	wire_n01ii_dataout <= wire_n0iOO_dataout WHEN endec_rx = '1'  ELSE ovr_undflow(2);
	wire_n01iii_dataout <= wire_nl11Oi_dataout AND NOT(niOlOil);
	wire_n01iil_dataout <= wire_nl11Ol_dataout AND NOT(niOlOil);
	wire_n01iiO_dataout <= wire_nl11OO_dataout AND NOT(niOlOil);
	wire_n01il_dataout <= wire_n0l1i_dataout WHEN endec_rx = '1'  ELSE ovr_undflow(3);
	wire_n01ili_dataout <= wire_nl101i_dataout AND NOT(niOlOil);
	wire_n01ill_dataout <= wire_nl101l_dataout AND NOT(niOlOil);
	wire_n01ilO_dataout <= wire_nl101O_dataout AND NOT(niOlOil);
	wire_n01iO_dataout <= wire_n0l1l_dataout WHEN endec_rx = '1'  ELSE disp_val_delay(0);
	wire_n01iOi_dataout <= wire_nl100i_dataout AND NOT(niOlOil);
	wire_n01iOl_dataout <= wire_nl100l_dataout AND NOT(niOlOil);
	wire_n01iOO_dataout <= wire_nl100O_dataout AND NOT(niOlOil);
	wire_n01l_dataout <= wire_nlO1O0i_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(12);
	wire_n01l0i_dataout <= wire_nl10li_dataout AND NOT(niOlOil);
	wire_n01l0l_dataout <= wire_nl10ll_dataout AND NOT(niOlOil);
	wire_n01l0O_dataout <= wire_nl10lO_dataout AND NOT(niOlOil);
	wire_n01l1i_dataout <= wire_nl10ii_dataout AND NOT(niOlOil);
	wire_n01l1l_dataout <= wire_nl10il_dataout AND NOT(niOlOil);
	wire_n01l1O_dataout <= wire_nl10iO_dataout AND NOT(niOlOil);
	wire_n01li_dataout <= wire_n0l1O_dataout WHEN endec_rx = '1'  ELSE disp_val_delay(1);
	wire_n01lii_dataout <= wire_nl10Oi_dataout AND NOT(niOlOil);
	wire_n01lil_dataout <= wire_nl10Ol_dataout AND NOT(niOlOil);
	wire_n01liO_dataout <= wire_nl10OO_dataout AND NOT(niOlOil);
	wire_n01ll_dataout <= wire_n0l0i_dataout WHEN endec_rx = '1'  ELSE disp_err_delay(0);
	wire_n01lli_dataout <= wire_nl1i1i_dataout AND NOT(niOlOil);
	wire_n01lll_dataout <= wire_nl1i1l_dataout AND NOT(niOlOil);
	wire_n01llO_dataout <= wire_nl1i1O_dataout AND NOT(niOlOil);
	wire_n01lO_dataout <= wire_n0l0l_dataout WHEN endec_rx = '1'  ELSE disp_err_delay(1);
	wire_n01lOi_dataout <= wire_nl1i0i_dataout AND NOT(niOlOil);
	wire_n01lOl_dataout <= wire_nl1i0l_dataout AND NOT(niOlOil);
	wire_n01lOO_dataout <= wire_nl1i0O_dataout AND NOT(niOlOil);
	wire_n01O_dataout <= wire_nlO1O0l_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(13);
	wire_n01O0i_dataout <= wire_nl1ili_dataout AND NOT(niOlOil);
	wire_n01O0l_dataout <= wire_nl1ill_dataout AND NOT(niOlOil);
	wire_n01O0O_dataout <= wire_nl1ilO_dataout AND NOT(niOlOil);
	wire_n01O1i_dataout <= wire_nl1iii_dataout AND NOT(niOlOil);
	wire_n01O1l_dataout <= wire_nl1iil_dataout AND NOT(niOlOil);
	wire_n01O1O_dataout <= wire_nl1iiO_dataout AND NOT(niOlOil);
	wire_n01Oi_dataout <= wire_n0l0O_dataout WHEN endec_rx = '1'  ELSE wire_n000i_dataout;
	wire_n01Oii_dataout <= wire_nl1iOi_dataout AND NOT(niOlOil);
	wire_n01Oil_dataout <= wire_nl1iOl_dataout AND NOT(niOlOil);
	wire_n01OiO_dataout <= wire_nl1iOO_dataout AND NOT(niOlOil);
	wire_n01Ol_dataout <= wire_n0lii_dataout WHEN endec_rx = '1'  ELSE wire_n000l_dataout;
	wire_n01Oli_dataout <= wire_nl1l1i_dataout AND NOT(niOlOil);
	wire_n01Oll_dataout <= wire_nl1l1l_dataout AND NOT(niOlOil);
	wire_n01OlO_dataout <= niliOi WHEN niOOliO = '1'  ELSE wire_n00O1i_o;
	wire_n01OO_dataout <= wire_niO1l_o AND NOT((wire_w_lg_rsync_sm_dis1w(0) AND wire_nlilOl_w_lg_dataout545w(0)));
	wire_n01OOi_dataout <= niliOl WHEN niOOliO = '1'  ELSE wire_n00O1l_o;
	wire_n01OOl_dataout <= niliOO WHEN niOOliO = '1'  ELSE wire_n00O1O_o;
	wire_n01OOO_dataout <= nill1i WHEN niOOliO = '1'  ELSE wire_n00O0i_o;
	wire_n0i_dataout <= wire_nlO0i0O_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(59);
	wire_n0i0i_dataout <= wire_n0lOi_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_dt(11);
	wire_n0i0l_dataout <= wire_n0lOl_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_dt(12);
	wire_n0i0O_dataout <= wire_n0lOO_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_dt(13);
	wire_n0i1i_dataout <= wire_n0lli_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_dt(8);
	wire_n0i1l_dataout <= wire_n0lll_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_dt(9);
	wire_n0i1O_dataout <= wire_n0llO_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_dt(10);
	wire_n0ii_dataout <= wire_nlO1OiO_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(17);
	wire_n0iii_dataout <= wire_n0O1i_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_dt(14);
	wire_n0iil_dataout <= wire_n0O1l_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_data_dt(15);
	wire_n0iiO_dataout <= wire_n0O1O_dataout WHEN rendec_data_sel_rx = '1'  ELSE rx_control_dt(1);
	wire_n0il_dataout <= wire_nlO1Oli_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(18);
	wire_n0il0l_dataout <= rbytordpadval(0) WHEN wire_n0iO0O_o(2) = '1'  ELSE nillOl;
	wire_n0il0O_dataout <= rbytordpadval(1) WHEN wire_n0iO0O_o(2) = '1'  ELSE nillOO;
	wire_n0ili_dataout <= wire_n0O0i_dataout WHEN rendec_data_sel_rx = '1'  ELSE wire_nli_dataout;
	wire_n0ilii_dataout <= rbytordpadval(2) WHEN wire_n0iO0O_o(2) = '1'  ELSE nilO1i;
	wire_n0ilil_dataout <= rbytordpadval(3) WHEN wire_n0iO0O_o(2) = '1'  ELSE nilO1l;
	wire_n0iliO_dataout <= rbytordpadval(4) WHEN wire_n0iO0O_o(2) = '1'  ELSE nilO1O;
	wire_n0ill_dataout <= wire_ni0ll_dataout WHEN rendec_data_sel_rx = '1'  ELSE nll10O;
	wire_n0illi_dataout <= rbytordpadval(5) WHEN wire_n0iO0O_o(2) = '1'  ELSE nilO0i;
	wire_n0illl_dataout <= rbytordpadval(6) WHEN wire_n0iO0O_o(2) = '1'  ELSE nilO0l;
	wire_n0illO_dataout <= rbytordpadval(7) WHEN wire_n0iO0O_o(2) = '1'  ELSE nilO0O;
	wire_n0ilO_dataout <= wire_n0O0l_dataout WHEN rendec_data_sel_rx = '1'  ELSE nll1ii;
	wire_n0ilOi_dataout <= rbytordpadval(8) WHEN wire_n0iO0O_o(2) = '1'  ELSE nilOii;
	wire_n0ilOl_dataout <= rbytordpadval(9) WHEN wire_n0iO0O_o(2) = '1'  ELSE nilOil;
	wire_n0ilOO_dataout <= nillil WHEN wire_n0iO0O_o(2) = '1'  ELSE nilOiO;
	wire_n0iO_dataout <= wire_nlO1Oll_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(19);
	wire_n0iO0i_dataout <= nilOOi AND NOT(wire_n0iO0O_o(2));
	wire_n0iO0l_dataout <= nilOOl AND NOT(wire_n0iO0O_o(2));
	wire_n0iO1i_dataout <= nilOli AND NOT(wire_n0iO0O_o(2));
	wire_n0iO1l_dataout <= nilOll AND NOT(wire_n0iO0O_o(2));
	wire_n0iO1O_dataout <= nilOlO AND NOT(wire_n0iO0O_o(2));
	wire_n0iOi_dataout <= ovr_undflow(0) WHEN rendec_data_sel_rx = '1'  ELSE nliO0l;
	wire_n0iOii_dataout <= rbytordpadval(0) WHEN niOlOiO = '1'  ELSE nilOOO;
	wire_n0iOil_dataout <= rbytordpadval(1) WHEN niOlOiO = '1'  ELSE niO11i;
	wire_n0iOiO_dataout <= rbytordpadval(2) WHEN niOlOiO = '1'  ELSE niO11l;
	wire_n0iOl_dataout <= ovr_undflow(1) WHEN rendec_data_sel_rx = '1'  ELSE nliO0O;
	wire_n0iOli_dataout <= rbytordpadval(3) WHEN niOlOiO = '1'  ELSE niO11O;
	wire_n0iOll_dataout <= rbytordpadval(4) WHEN niOlOiO = '1'  ELSE niO10i;
	wire_n0iOlO_dataout <= rbytordpadval(5) WHEN niOlOiO = '1'  ELSE niO10l;
	wire_n0iOO_dataout <= ovr_undflow(2) WHEN rendec_data_sel_rx = '1'  ELSE nliOii;
	wire_n0iOOi_dataout <= rbytordpadval(6) WHEN niOlOiO = '1'  ELSE niO10O;
	wire_n0iOOl_dataout <= rbytordpadval(7) WHEN niOlOiO = '1'  ELSE niO1ii;
	wire_n0iOOO_dataout <= rbytordpadval(8) WHEN niOlOiO = '1'  ELSE niO1il;
	wire_n0l_dataout <= wire_nlO0iii_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(60);
	wire_n0l00i_dataout <= rbytordpadval(9) WHEN niOlOli = '1'  ELSE niO0li;
	wire_n0l00O_dataout <= niO0lO AND NOT(niOlOli);
	wire_n0l01i_dataout <= rbytordpadval(6) WHEN niOlOli = '1'  ELSE niO0ii;
	wire_n0l01l_dataout <= rbytordpadval(7) WHEN niOlOli = '1'  ELSE niO0il;
	wire_n0l01O_dataout <= rbytordpadval(8) WHEN niOlOli = '1'  ELSE niO0iO;
	wire_n0l0i_dataout <= disp_err_delay(0) WHEN rendec_data_sel_rx = '1'  ELSE nll00l;
	wire_n0l0ii_dataout <= niO0Oi AND NOT(niOlOli);
	wire_n0l0il_dataout <= niO0Ol AND NOT(niOlOli);
	wire_n0l0iO_dataout <= niO0OO AND NOT(niOlOli);
	wire_n0l0l_dataout <= disp_err_delay(1) WHEN rendec_data_sel_rx = '1'  ELSE nll00O;
	wire_n0l0li_dataout <= niOi1i AND NOT(niOlOli);
	wire_n0l0O_dataout <= wire_n000i_dataout WHEN rendec_data_sel_rx = '1'  ELSE nll0iO;
	wire_n0l0Oi_dataout <= wire_niOlOl_dataout WHEN niOOliO = '1'  ELSE wire_n0O01l_o;
	wire_n0l0Ol_dataout <= wire_niOlOO_dataout WHEN niOOliO = '1'  ELSE wire_n0O01O_o;
	wire_n0l0OO_dataout <= wire_niOO1i_dataout WHEN niOOliO = '1'  ELSE wire_n0O00i_o;
	wire_n0l10i_dataout <= niO1lO AND NOT(niOlOiO);
	wire_n0l10l_dataout <= niO1Oi AND NOT(niOlOiO);
	wire_n0l10O_dataout <= niO1Ol AND NOT(niOlOiO);
	wire_n0l11i_dataout <= rbytordpadval(9) WHEN niOlOiO = '1'  ELSE niO1iO;
	wire_n0l11O_dataout <= niO1ll AND NOT(niOlOiO);
	wire_n0l1i_dataout <= ovr_undflow(3) WHEN rendec_data_sel_rx = '1'  ELSE nliOil;
	wire_n0l1ii_dataout <= niO1OO AND NOT(niOlOiO);
	wire_n0l1l_dataout <= disp_val_delay(0) WHEN rendec_data_sel_rx = '1'  ELSE nll01i;
	wire_n0l1li_dataout <= rbytordpadval(0) WHEN niOlOli = '1'  ELSE niO01i;
	wire_n0l1ll_dataout <= rbytordpadval(1) WHEN niOlOli = '1'  ELSE niO01l;
	wire_n0l1lO_dataout <= rbytordpadval(2) WHEN niOlOli = '1'  ELSE niO01O;
	wire_n0l1O_dataout <= disp_val_delay(1) WHEN rendec_data_sel_rx = '1'  ELSE nll01l;
	wire_n0l1Oi_dataout <= rbytordpadval(3) WHEN niOlOli = '1'  ELSE niO00i;
	wire_n0l1Ol_dataout <= rbytordpadval(4) WHEN niOlOli = '1'  ELSE niO00l;
	wire_n0l1OO_dataout <= rbytordpadval(5) WHEN niOlOli = '1'  ELSE niO00O;
	wire_n0li_dataout <= wire_nlO1OlO_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(20);
	wire_n0li0i_dataout <= wire_niOO0l_dataout WHEN niOOliO = '1'  ELSE wire_n0O0il_o;
	wire_n0li0l_dataout <= wire_niOO0O_dataout WHEN niOOliO = '1'  ELSE wire_n0O0iO_o;
	wire_n0li0O_dataout <= wire_niOOii_dataout WHEN niOOliO = '1'  ELSE wire_n0O0li_o;
	wire_n0li1i_dataout <= wire_niOO1l_dataout WHEN niOOliO = '1'  ELSE wire_n0O00l_o;
	wire_n0li1l_dataout <= wire_niOO1O_dataout WHEN niOOliO = '1'  ELSE wire_n0O00O_o;
	wire_n0li1O_dataout <= wire_niOO0i_dataout WHEN niOOliO = '1'  ELSE wire_n0O0ii_o;
	wire_n0lii_dataout <= wire_n000l_dataout WHEN rendec_data_sel_rx = '1'  ELSE nll0li;
	wire_n0liii_dataout <= wire_niOOil_dataout WHEN niOOliO = '1'  ELSE wire_n0O0ll_o;
	wire_n0liil_dataout <= wire_niOOiO_dataout WHEN niOOliO = '1'  ELSE wire_n0O0lO_o;
	wire_n0liiO_dataout <= wire_niOOli_dataout WHEN niOOliO = '1'  ELSE wire_n0O0Oi_o;
	wire_n0lili_dataout <= wire_niOOll_dataout WHEN niOOliO = '1'  ELSE wire_n0O0Ol_o;
	wire_n0lill_dataout <= wire_niOOlO_dataout WHEN niOOliO = '1'  ELSE wire_n0O0OO_o;
	wire_n0lilO_dataout <= wire_niOOOi_dataout WHEN niOOliO = '1'  ELSE wire_n0Oi1i_o;
	wire_n0liOi_dataout <= wire_niOOOl_dataout WHEN niOOliO = '1'  ELSE wire_n0Oi1l_o;
	wire_n0liOl_dataout <= wire_ni110O_dataout WHEN niOOliO = '1'  ELSE wire_n0Oi1O_o;
	wire_n0liOO_dataout <= wire_ni11ii_dataout WHEN niOOliO = '1'  ELSE wire_n0Oi0i_o;
	wire_n0ll_dataout <= wire_nlO1OOi_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(21);
	wire_n0ll0i_dataout <= wire_ni11ll_dataout WHEN niOOliO = '1'  ELSE wire_n0Oiil_o;
	wire_n0ll0l_dataout <= wire_ni11lO_dataout WHEN niOOliO = '1'  ELSE wire_n0OiiO_o;
	wire_n0ll0O_dataout <= wire_ni11Oi_dataout WHEN niOOliO = '1'  ELSE wire_n0Oili_o;
	wire_n0ll1i_dataout <= wire_ni11il_dataout WHEN niOOliO = '1'  ELSE wire_n0Oi0l_o;
	wire_n0ll1l_dataout <= wire_ni11iO_dataout WHEN niOOliO = '1'  ELSE wire_n0Oi0O_o;
	wire_n0ll1O_dataout <= wire_ni11li_dataout WHEN niOOliO = '1'  ELSE wire_n0Oiii_o;
	wire_n0lli_dataout <= wire_ni10i_dataout WHEN wire_nlilOl_w_lg_dataout545w(0) = '1'  ELSE wire_n0O0O_dataout;
	wire_n0llii_dataout <= wire_ni11Ol_dataout WHEN niOOliO = '1'  ELSE wire_n0Oill_o;
	wire_n0llil_dataout <= wire_ni11OO_dataout WHEN niOOliO = '1'  ELSE wire_n0OilO_o;
	wire_n0lliO_dataout <= wire_ni101i_dataout WHEN niOOliO = '1'  ELSE wire_n0OiOi_o;
	wire_n0lll_dataout <= wire_ni10l_dataout WHEN wire_nlilOl_w_lg_dataout545w(0) = '1'  ELSE wire_n0Oii_dataout;
	wire_n0llli_dataout <= wire_ni101l_dataout WHEN niOOliO = '1'  ELSE wire_n0OiOl_o;
	wire_n0llll_dataout <= wire_ni101O_dataout WHEN niOOliO = '1'  ELSE wire_n0OiOO_o;
	wire_n0lllO_dataout <= wire_ni100i_dataout WHEN niOOliO = '1'  ELSE wire_n0Ol1i_o;
	wire_n0llO_dataout <= wire_ni10O_dataout WHEN wire_nlilOl_w_lg_dataout545w(0) = '1'  ELSE wire_n0Oil_dataout;
	wire_n0llOi_dataout <= wire_ni100l_dataout WHEN niOOliO = '1'  ELSE wire_n0Ol1l_o;
	wire_n0llOl_dataout <= wire_ni100O_dataout WHEN niOOliO = '1'  ELSE wire_n0Ol1O_o;
	wire_n0llOO_dataout <= wire_ni10ii_dataout WHEN niOOliO = '1'  ELSE wire_n0Ol0i_o;
	wire_n0lO_dataout <= wire_nlO1OOl_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(22);
	wire_n0lO0i_dataout <= wire_ni10ll_dataout WHEN niOOliO = '1'  ELSE wire_n0Olil_o;
	wire_n0lO0l_dataout <= wire_ni10lO_dataout WHEN niOOliO = '1'  ELSE wire_n0OliO_o;
	wire_n0lO0O_dataout <= wire_ni10Oi_dataout WHEN niOOliO = '1'  ELSE wire_n0Olli_o;
	wire_n0lO1i_dataout <= wire_ni10il_dataout WHEN niOOliO = '1'  ELSE wire_n0Ol0l_o;
	wire_n0lO1l_dataout <= wire_ni10iO_dataout WHEN niOOliO = '1'  ELSE wire_n0Ol0O_o;
	wire_n0lO1O_dataout <= wire_ni10li_dataout WHEN niOOliO = '1'  ELSE wire_n0Olii_o;
	wire_n0lOi_dataout <= wire_ni1ii_dataout WHEN wire_nlilOl_w_lg_dataout545w(0) = '1'  ELSE wire_n0OiO_dataout;
	wire_n0lOii_dataout <= wire_ni10Ol_dataout WHEN niOOliO = '1'  ELSE wire_n0Olll_o;
	wire_n0lOil_dataout <= wire_ni10OO_dataout WHEN niOOliO = '1'  ELSE wire_n0OllO_o;
	wire_n0lOiO_dataout <= wire_ni1i1i_dataout WHEN niOOliO = '1'  ELSE wire_n0OlOi_o;
	wire_n0lOl_dataout <= wire_ni1il_dataout WHEN wire_nlilOl_w_lg_dataout545w(0) = '1'  ELSE wire_n0Oli_dataout;
	wire_n0lOli_dataout <= wire_ni1i1l_o WHEN niOOliO = '1'  ELSE wire_n0OlOl_o;
	wire_n0lOll_dataout <= wire_ni1i1O_dataout WHEN niOOliO = '1'  ELSE wire_n0OlOO_o;
	wire_n0lOlO_dataout <= wire_ni1i0i_dataout WHEN niOOliO = '1'  ELSE wire_n0OO1i_o;
	wire_n0lOO_dataout <= wire_ni1iO_dataout WHEN wire_nlilOl_w_lg_dataout545w(0) = '1'  ELSE wire_n0Oll_dataout;
	wire_n0lOOi_dataout <= wire_ni1i0l_dataout WHEN niOOliO = '1'  ELSE wire_n0OO1l_o;
	wire_n0lOOl_dataout <= wire_ni1i0O_dataout WHEN niOOliO = '1'  ELSE wire_n0OO1O_o;
	wire_n0lOOO_dataout <= wire_ni1iii_dataout WHEN niOOliO = '1'  ELSE wire_n0OO0i_o;
	wire_n0O_dataout <= wire_nlO0iil_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(61);
	wire_n0O01i_dataout <= wire_ni1lil_dataout WHEN niOOliO = '1'  ELSE wire_ni110l_o;
	wire_n0O0i_dataout <= wire_ni1Oi_dataout WHEN wire_nlilOl_w_lg_dataout545w(0) = '1'  ELSE wire_nli_dataout;
	wire_n0O0l_dataout <= wire_ni1Ol_dataout WHEN wire_nlilOl_w_lg_dataout545w(0) = '1'  ELSE wire_niO1l_o;
	wire_n0O0O_dataout <= rclkcmpinsertpad WHEN nl111lO = '1'  ELSE rx_data_dt(8);
	wire_n0O10i_dataout <= wire_ni1ill_dataout WHEN niOOliO = '1'  ELSE wire_n0OOil_o;
	wire_n0O10l_dataout <= wire_ni1ilO_dataout WHEN niOOliO = '1'  ELSE wire_n0OOiO_o;
	wire_n0O10O_dataout <= wire_ni1iOi_dataout WHEN niOOliO = '1'  ELSE wire_n0OOli_o;
	wire_n0O11i_dataout <= wire_ni1iil_dataout WHEN niOOliO = '1'  ELSE wire_n0OO0l_o;
	wire_n0O11l_dataout <= wire_ni1iiO_dataout WHEN niOOliO = '1'  ELSE wire_n0OO0O_o;
	wire_n0O11O_dataout <= wire_ni1ili_dataout WHEN niOOliO = '1'  ELSE wire_n0OOii_o;
	wire_n0O1i_dataout <= wire_ni1li_dataout WHEN wire_nlilOl_w_lg_dataout545w(0) = '1'  ELSE wire_n0OlO_dataout;
	wire_n0O1ii_dataout <= wire_ni1iOl_dataout WHEN niOOliO = '1'  ELSE wire_n0OOll_o;
	wire_n0O1il_dataout <= wire_ni1iOO_dataout WHEN niOOliO = '1'  ELSE wire_n0OOlO_o;
	wire_n0O1iO_dataout <= wire_ni1l1i_dataout WHEN niOOliO = '1'  ELSE wire_n0OOOi_o;
	wire_n0O1l_dataout <= wire_ni1ll_dataout WHEN wire_nlilOl_w_lg_dataout545w(0) = '1'  ELSE wire_n0OOi_dataout;
	wire_n0O1li_dataout <= wire_ni1l1l_dataout WHEN niOOliO = '1'  ELSE wire_n0OOOl_o;
	wire_n0O1ll_dataout <= wire_ni1l1O_o WHEN niOOliO = '1'  ELSE wire_n0OOOO_o;
	wire_n0O1lO_dataout <= wire_ni1l0i_dataout WHEN niOOliO = '1'  ELSE wire_ni111i_o;
	wire_n0O1O_dataout <= wire_ni1lO_dataout WHEN wire_nlilOl_w_lg_dataout545w(0) = '1'  ELSE wire_n0OOl_dataout;
	wire_n0O1Oi_dataout <= wire_ni1l0l_dataout WHEN niOOliO = '1'  ELSE wire_ni111l_o;
	wire_n0O1Ol_dataout <= wire_ni1l0O_dataout WHEN niOOliO = '1'  ELSE wire_ni111O_o;
	wire_n0O1OO_dataout <= wire_ni1lii_dataout WHEN niOOliO = '1'  ELSE wire_ni110i_o;
	wire_n0Oi_dataout <= wire_nlO1OOO_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(23);
	wire_n0Oii_dataout <= rx_data_dt(9) OR nl111lO;
	wire_n0Oil_dataout <= rx_data_dt(10) OR nl111lO;
	wire_n0OiO_dataout <= wire_w_lg_rclkcmpinsertpad522w(0) WHEN nl111lO = '1'  ELSE rx_data_dt(11);
	wire_n0Ol_dataout <= wire_nlO011i_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(24);
	wire_n0Oli_dataout <= rx_data_dt(12) OR nl111lO;
	wire_n0Oll_dataout <= rx_data_dt(13) OR nl111lO;
	wire_n0OlO_dataout <= rx_data_dt(14) OR nl111lO;
	wire_n0OO_dataout <= wire_nlO011l_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(25);
	wire_n0OOi_dataout <= rx_data_dt(15) OR nl111lO;
	wire_n0OOl_dataout <= rx_control_dt(1) OR nl111lO;
	wire_n1000i_dataout <= wire_nl1l1l_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n1000l_dataout <= niliOi WHEN niOlO0O = '1'  ELSE wire_n1i1iO_dataout;
	wire_n1000O_dataout <= niliOl WHEN niOlO0O = '1'  ELSE wire_n1i1li_dataout;
	wire_n1001i_dataout <= wire_nl1iOl_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n1001l_dataout <= wire_nl1iOO_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n1001O_dataout <= wire_nl1l1i_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n100ii_dataout <= niliOO WHEN niOlO0O = '1'  ELSE wire_n1i1ll_dataout;
	wire_n100il_dataout <= nill1i WHEN niOlO0O = '1'  ELSE wire_n1i1lO_dataout;
	wire_n100iO_dataout <= nill1l WHEN niOlO0O = '1'  ELSE wire_n1i1Oi_dataout;
	wire_n100li_dataout <= nill1O WHEN niOlO0O = '1'  ELSE wire_n1i1Ol_dataout;
	wire_n100ll_dataout <= nill0i WHEN niOlO0O = '1'  ELSE wire_n1i1OO_dataout;
	wire_n100lO_dataout <= nill0l WHEN niOlO0O = '1'  ELSE wire_n1i01i_dataout;
	wire_n100Oi_dataout <= nill0O WHEN niOlO0O = '1'  ELSE wire_n1i01l_dataout;
	wire_n100Ol_dataout <= nillii WHEN niOlO0O = '1'  ELSE wire_n1i01O_dataout;
	wire_n100OO_dataout <= nillil WHEN niOlO0O = '1'  ELSE wire_n1i00i_dataout;
	wire_n1010i_dataout <= wire_nl1i1l_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n1010l_dataout <= wire_nl1i1O_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n1010O_dataout <= wire_nl1i0i_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n1011i_dataout <= wire_nl10Ol_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n1011l_dataout <= wire_nl10OO_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n1011O_dataout <= wire_nl1i1i_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n101ii_dataout <= wire_nl1i0l_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n101il_dataout <= wire_nl1i0O_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n101iO_dataout <= wire_nl1iii_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n101li_dataout <= wire_nl1iil_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n101ll_dataout <= wire_nl1iiO_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n101lO_dataout <= wire_nl1ili_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n101Oi_dataout <= wire_nl1ill_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n101Ol_dataout <= wire_nl1ilO_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n101OO_dataout <= wire_nl1iOi_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n10i_dataout <= wire_nlO0i1O_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(56);
	wire_n10i0i_dataout <= nilllO WHEN niOlO0O = '1'  ELSE wire_n1i0il_dataout;
	wire_n10i0l_dataout <= nillOi WHEN niOlO0O = '1'  ELSE wire_n1i0iO_dataout;
	wire_n10i0O_dataout <= wire_n1iOOi_dataout WHEN niOlO0O = '1'  ELSE wire_n1i0li_dataout;
	wire_n10i1i_dataout <= nilliO WHEN niOlO0O = '1'  ELSE wire_n1i00l_dataout;
	wire_n10i1l_dataout <= nillli WHEN niOlO0O = '1'  ELSE wire_n1i00O_dataout;
	wire_n10i1O_dataout <= nillll WHEN niOlO0O = '1'  ELSE wire_n1i0ii_dataout;
	wire_n10iii_dataout <= wire_n1iOOl_dataout WHEN niOlO0O = '1'  ELSE wire_n1i0ll_dataout;
	wire_n10iil_dataout <= wire_n1iOOO_dataout WHEN niOlO0O = '1'  ELSE wire_n1i0lO_dataout;
	wire_n10iiO_dataout <= wire_n1l11i_dataout WHEN niOlO0O = '1'  ELSE wire_n1i0Oi_dataout;
	wire_n10ili_dataout <= wire_n1l11l_dataout WHEN niOlO0O = '1'  ELSE wire_n1i0Ol_dataout;
	wire_n10ill_dataout <= wire_n1l11O_dataout WHEN niOlO0O = '1'  ELSE wire_n1i0OO_dataout;
	wire_n10ilO_dataout <= wire_n1l10i_dataout WHEN niOlO0O = '1'  ELSE wire_n1ii1i_dataout;
	wire_n10iOi_dataout <= wire_n1l10l_dataout WHEN niOlO0O = '1'  ELSE wire_n1ii1l_dataout;
	wire_n10iOl_dataout <= wire_n1l10O_dataout WHEN niOlO0O = '1'  ELSE wire_n1ii1O_dataout;
	wire_n10iOO_dataout <= wire_n1l1ii_dataout WHEN niOlO0O = '1'  ELSE wire_n1ii0i_dataout;
	wire_n10l_dataout <= wire_nlO1lii_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(0);
	wire_n10l0i_dataout <= wire_n1l1ll_dataout WHEN niOlO0O = '1'  ELSE wire_n1iiil_dataout;
	wire_n10l0l_dataout <= wire_n1l1lO_dataout WHEN niOlO0O = '1'  ELSE wire_n1iiiO_dataout;
	wire_n10l0O_dataout <= wire_n1l1Oi_dataout WHEN niOlO0O = '1'  ELSE wire_n1iili_dataout;
	wire_n10l1i_dataout <= wire_n1l1il_dataout WHEN niOlO0O = '1'  ELSE wire_n1ii0l_dataout;
	wire_n10l1l_dataout <= wire_n1l1iO_dataout WHEN niOlO0O = '1'  ELSE wire_n1ii0O_dataout;
	wire_n10l1O_dataout <= wire_n1l1li_dataout WHEN niOlO0O = '1'  ELSE wire_n1iiii_dataout;
	wire_n10lii_dataout <= wire_n1l1Ol_dataout WHEN niOlO0O = '1'  ELSE wire_n1iill_dataout;
	wire_n10lil_dataout <= wire_n1l1OO_dataout WHEN niOlO0O = '1'  ELSE wire_n1iilO_dataout;
	wire_n10liO_dataout <= wire_n1l01i_dataout WHEN niOlO0O = '1'  ELSE wire_n1iiOi_dataout;
	wire_n10lli_dataout <= wire_n1l01l_dataout WHEN niOlO0O = '1'  ELSE wire_n1iiOl_dataout;
	wire_n10lll_dataout <= wire_n1l01O_dataout WHEN niOlO0O = '1'  ELSE wire_n1iiOO_dataout;
	wire_n10llO_dataout <= wire_n1l00i_dataout WHEN niOlO0O = '1'  ELSE wire_n1il1i_dataout;
	wire_n10lOi_dataout <= wire_n1l00l_dataout WHEN niOlO0O = '1'  ELSE wire_n1il1l_dataout;
	wire_n10lOl_dataout <= wire_n1l00O_dataout WHEN niOlO0O = '1'  ELSE wire_n1il1O_dataout;
	wire_n10lOO_dataout <= wire_n1l0ii_dataout WHEN niOlO0O = '1'  ELSE wire_n1il0i_dataout;
	wire_n10O_dataout <= wire_nlO1lil_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(1);
	wire_n10O0i_dataout <= wire_n1l0ll_dataout WHEN niOlO0O = '1'  ELSE wire_n1ilil_dataout;
	wire_n10O0l_dataout <= wire_n1l0lO_dataout WHEN niOlO0O = '1'  ELSE wire_n1iliO_dataout;
	wire_n10O0O_dataout <= wire_n1l0Oi_dataout WHEN niOlO0O = '1'  ELSE wire_n1illi_dataout;
	wire_n10O1i_dataout <= wire_n1l0il_dataout WHEN niOlO0O = '1'  ELSE wire_n1il0l_dataout;
	wire_n10O1l_dataout <= wire_n1l0iO_dataout WHEN niOlO0O = '1'  ELSE wire_n1il0O_dataout;
	wire_n10O1O_dataout <= wire_n1l0li_dataout WHEN niOlO0O = '1'  ELSE wire_n1ilii_dataout;
	wire_n10Oii_dataout <= wire_n1l0Ol_dataout WHEN niOlO0O = '1'  ELSE wire_n1illl_dataout;
	wire_n10Oil_dataout <= wire_n1l0OO_dataout WHEN niOlO0O = '1'  ELSE wire_n1illO_dataout;
	wire_n10OiO_dataout <= wire_n1li1i_dataout WHEN niOlO0O = '1'  ELSE wire_n1ilOi_dataout;
	wire_n10Ol_dataout <= wire_n1liO_dataout OR nliO0i;
	wire_n10Oli_dataout <= wire_n1li1l_dataout WHEN niOlO0O = '1'  ELSE wire_n1ilOl_dataout;
	wire_n10Oll_dataout <= wire_n1li1O_dataout WHEN niOlO0O = '1'  ELSE wire_n1ilOO_dataout;
	wire_n10OlO_dataout <= wire_n1li0i_dataout WHEN niOlO0O = '1'  ELSE wire_n1iO1i_dataout;
	wire_n10OOi_dataout <= wire_n1li0l_dataout WHEN niOlO0O = '1'  ELSE wire_n1iO1l_dataout;
	wire_n10OOl_dataout <= wire_n1li0O_dataout WHEN niOlO0O = '1'  ELSE wire_n1iO1O_dataout;
	wire_n10OOO_dataout <= wire_n1liii_dataout WHEN niOlO0O = '1'  ELSE wire_n1iO0i_dataout;
	wire_n1100i_dataout <= wire_niOO1O_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl100l_dataout;
	wire_n1100l_dataout <= wire_niOO0i_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl100O_dataout;
	wire_n1100O_dataout <= wire_niOO0l_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl10ii_dataout;
	wire_n1101i_dataout <= wire_niOlOO_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl101l_dataout;
	wire_n1101l_dataout <= wire_niOO1i_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl101O_dataout;
	wire_n1101O_dataout <= wire_niOO1l_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl100i_dataout;
	wire_n110i_dataout <= wire_n01Ol_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO1ll;
	wire_n110ii_dataout <= wire_niOO0O_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl10il_dataout;
	wire_n110il_dataout <= wire_niOOii_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl10iO_dataout;
	wire_n110iO_dataout <= wire_niOOil_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl10li_dataout;
	wire_n110l_dataout <= wire_n01lO_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO1lO;
	wire_n110li_dataout <= wire_niOOiO_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl10ll_dataout;
	wire_n110ll_dataout <= wire_niOOli_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl10lO_dataout;
	wire_n110lO_dataout <= wire_niOOll_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl10Oi_dataout;
	wire_n110O_dataout <= wire_n010i_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO1Oi;
	wire_n110Oi_dataout <= wire_niOOlO_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl10Ol_dataout;
	wire_n110Ol_dataout <= wire_niOOOi_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl10OO_dataout;
	wire_n110OO_dataout <= wire_niOOOl_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1i1i_dataout;
	wire_n1110i_dataout <= niO00O WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl110l_dataout;
	wire_n1110l_dataout <= niO0ii WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl110O_dataout;
	wire_n1110O_dataout <= niO0il WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl11ii_dataout;
	wire_n1111i_dataout <= niO01O WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl111l_dataout;
	wire_n1111l_dataout <= niO00i WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl111O_dataout;
	wire_n1111O_dataout <= niO00l WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl110i_dataout;
	wire_n111i_dataout <= wire_n1OOO_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO1il;
	wire_n111ii_dataout <= niO0iO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl11il_dataout;
	wire_n111il_dataout <= niO0li WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl11iO_dataout;
	wire_n111iO_dataout <= niO0ll WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl11li_dataout;
	wire_n111l_dataout <= wire_n011i_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO1iO;
	wire_n111li_dataout <= niO0lO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl11ll_dataout;
	wire_n111ll_dataout <= niO0Oi WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl11lO_dataout;
	wire_n111lO_dataout <= niO0Ol WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl11Oi_dataout;
	wire_n111O_dataout <= wire_n011l_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO1li;
	wire_n111Oi_dataout <= niO0OO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl11Ol_dataout;
	wire_n111Ol_dataout <= niOi1i WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl11OO_dataout;
	wire_n111OO_dataout <= wire_niOlOl_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl101i_dataout;
	wire_n11i_dataout <= wire_nlO1lOO_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(8);
	wire_n11i0i_dataout <= wire_nl111O_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1i0l_dataout;
	wire_n11i0l_dataout <= wire_nl110i_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1i0O_dataout;
	wire_n11i0O_dataout <= wire_nl110l_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1iii_dataout;
	wire_n11i1i_dataout <= wire_niOOOO_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1i1l_dataout;
	wire_n11i1l_dataout <= wire_nl111i_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1i1O_dataout;
	wire_n11i1O_dataout <= wire_nl111l_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1i0i_dataout;
	wire_n11ii_dataout <= wire_n01ii_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO1Ol;
	wire_n11iii_dataout <= wire_nl110O_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1iil_dataout;
	wire_n11iil_dataout <= wire_nl11ii_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1iiO_dataout;
	wire_n11iiO_dataout <= wire_nl11il_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1ili_dataout;
	wire_n11il_dataout <= wire_n01il_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO1OO;
	wire_n11ili_dataout <= wire_nl11iO_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1ill_dataout;
	wire_n11ill_dataout <= wire_nl11li_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1ilO_dataout;
	wire_n11ilO_dataout <= wire_nl11ll_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1iOi_dataout;
	wire_n11iO_dataout <= wire_n01li_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO01l;
	wire_n11iOi_dataout <= wire_nl11lO_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1iOl_dataout;
	wire_n11iOl_dataout <= wire_nl11Oi_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1iOO_dataout;
	wire_n11iOO_dataout <= wire_nl11Ol_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1l1i_dataout;
	wire_n11l_dataout <= wire_nlO011i_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(24);
	wire_n11l0i_dataout <= wire_nl111l_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11l0l_dataout <= wire_nl111O_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11l0O_dataout <= wire_nl110i_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11l1i_dataout <= wire_nl11OO_dataout WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl1l1l_dataout;
	wire_n11l1l_dataout <= wire_niOOOO_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11l1O_dataout <= wire_nl111i_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11lii_dataout <= wire_nl110l_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11lil_dataout <= wire_nl110O_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11liO_dataout <= wire_nl11ii_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11lli_dataout <= wire_nl11il_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11lll_dataout <= wire_nl11iO_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11llO_dataout <= wire_nl11li_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11lOi_dataout <= wire_nl11ll_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11lOl_dataout <= wire_nl11lO_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11lOO_dataout <= wire_nl11Oi_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11O_dataout <= wire_nlO001l_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(40);
	wire_n11O0i_dataout <= rbytordpadval(1) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE wire_nl101l_dataout;
	wire_n11O0l_dataout <= rbytordpadval(2) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE wire_nl101O_dataout;
	wire_n11O0O_dataout <= rbytordpadval(3) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE wire_nl100i_dataout;
	wire_n11O1i_dataout <= wire_nl11Ol_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11O1l_dataout <= wire_nl11OO_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11O1O_dataout <= rbytordpadval(0) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE wire_nl101i_dataout;
	wire_n11Oii_dataout <= rbytordpadval(4) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE wire_nl100l_dataout;
	wire_n11Oil_dataout <= rbytordpadval(5) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE wire_nl100O_dataout;
	wire_n11OiO_dataout <= rbytordpadval(6) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE wire_nl10ii_dataout;
	wire_n11Oli_dataout <= rbytordpadval(7) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE wire_nl10il_dataout;
	wire_n11Oll_dataout <= rbytordpadval(8) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE wire_nl10iO_dataout;
	wire_n11OlO_dataout <= rbytordpadval(9) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE wire_nl10li_dataout;
	wire_n11OOi_dataout <= wire_niOOiO_dataout WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE wire_nl10ll_dataout;
	wire_n11OOl_dataout <= wire_nl10lO_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n11OOO_dataout <= wire_nl10Oi_dataout AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_n1i_dataout <= wire_nlO0i1O_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(56);
	wire_n1i00i_dataout <= nil10l WHEN niOlOii = '1'  ELSE nillil;
	wire_n1i00l_dataout <= nil10O WHEN niOlOii = '1'  ELSE nilliO;
	wire_n1i00O_dataout <= nil1ii WHEN niOlOii = '1'  ELSE nillli;
	wire_n1i01i_dataout <= nil11l WHEN niOlOii = '1'  ELSE nill0l;
	wire_n1i01l_dataout <= nil11O WHEN niOlOii = '1'  ELSE nill0O;
	wire_n1i01O_dataout <= nil10i WHEN niOlOii = '1'  ELSE nillii;
	wire_n1i0ii_dataout <= nil1il WHEN niOlOii = '1'  ELSE nillll;
	wire_n1i0il_dataout <= nil1iO WHEN niOlOii = '1'  ELSE nilllO;
	wire_n1i0iO_dataout <= nil1li WHEN niOlOii = '1'  ELSE nillOi;
	wire_n1i0l_dataout <= gen2ngen1 WHEN rindv_rx = '1'  ELSE gen2ngen1_bundle;
	wire_n1i0li_dataout <= niliOi WHEN niOlOii = '1'  ELSE nillOl;
	wire_n1i0ll_dataout <= niliOl WHEN niOlOii = '1'  ELSE nillOO;
	wire_n1i0lO_dataout <= niliOO WHEN niOlOii = '1'  ELSE nilO1i;
	wire_n1i0Oi_dataout <= nill1i WHEN niOlOii = '1'  ELSE nilO1l;
	wire_n1i0Ol_dataout <= nill1l WHEN niOlOii = '1'  ELSE nilO1O;
	wire_n1i0OO_dataout <= nill1O WHEN niOlOii = '1'  ELSE nilO0i;
	wire_n1i10i_dataout <= wire_n1lill_dataout WHEN niOlO0O = '1'  ELSE wire_n1iOil_dataout;
	wire_n1i10l_dataout <= wire_n1lilO_dataout WHEN niOlO0O = '1'  ELSE wire_n1iOiO_dataout;
	wire_n1i10O_dataout <= wire_n1liOi_dataout WHEN niOlO0O = '1'  ELSE wire_n1iOli_dataout;
	wire_n1i11i_dataout <= wire_n1liil_dataout WHEN niOlO0O = '1'  ELSE wire_n1iO0l_dataout;
	wire_n1i11l_dataout <= wire_n1liiO_dataout WHEN niOlO0O = '1'  ELSE wire_n1iO0O_dataout;
	wire_n1i11O_dataout <= wire_n1lili_dataout WHEN niOlO0O = '1'  ELSE wire_n1iOii_dataout;
	wire_n1i1ii_dataout <= wire_n1liOl_dataout WHEN niOlO0O = '1'  ELSE wire_n1iOll_dataout;
	wire_n1i1il_dataout <= wire_n1liOO_dataout WHEN niOlO0O = '1'  ELSE wire_n1iOlO_dataout;
	wire_n1i1iO_dataout <= niiOli WHEN niOlOii = '1'  ELSE niliOi;
	wire_n1i1li_dataout <= niiOll WHEN niOlOii = '1'  ELSE niliOl;
	wire_n1i1ll_dataout <= niiOlO WHEN niOlOii = '1'  ELSE niliOO;
	wire_n1i1lO_dataout <= niiOOi WHEN niOlOii = '1'  ELSE nill1i;
	wire_n1i1Oi_dataout <= niiOOl WHEN niOlOii = '1'  ELSE nill1l;
	wire_n1i1Ol_dataout <= niiOOO WHEN niOlOii = '1'  ELSE nill1O;
	wire_n1i1OO_dataout <= nil11i WHEN niOlOii = '1'  ELSE nill0i;
	wire_n1ii_dataout <= wire_nlO1liO_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(2);
	wire_n1ii0i_dataout <= nillii WHEN niOlOii = '1'  ELSE nilOil;
	wire_n1ii0l_dataout <= nillil WHEN niOlOii = '1'  ELSE nilOiO;
	wire_n1ii0O_dataout <= nilliO WHEN niOlOii = '1'  ELSE nilOli;
	wire_n1ii1i_dataout <= nill0i WHEN niOlOii = '1'  ELSE nilO0l;
	wire_n1ii1l_dataout <= nill0l WHEN niOlOii = '1'  ELSE nilO0O;
	wire_n1ii1O_dataout <= nill0O WHEN niOlOii = '1'  ELSE nilOii;
	wire_n1iiii_dataout <= nillli WHEN niOlOii = '1'  ELSE nilOll;
	wire_n1iiil_dataout <= nillll WHEN niOlOii = '1'  ELSE nilOlO;
	wire_n1iiiO_dataout <= nilllO WHEN niOlOii = '1'  ELSE nilOOi;
	wire_n1iili_dataout <= nillOi WHEN niOlOii = '1'  ELSE nilOOl;
	wire_n1iill_dataout <= nilOOO AND NOT(niOlOii);
	wire_n1iilO_dataout <= niO11i AND NOT(niOlOii);
	wire_n1iiOi_dataout <= niO11l AND NOT(niOlOii);
	wire_n1iiOl_dataout <= niO11O AND NOT(niOlOii);
	wire_n1iiOO_dataout <= niO10i AND NOT(niOlOii);
	wire_n1il_dataout <= wire_nlO1lli_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(3);
	wire_n1il0i_dataout <= niO1il AND NOT(niOlOii);
	wire_n1il0l_dataout <= niO1iO AND NOT(niOlOii);
	wire_n1il0O_dataout <= niO1li AND NOT(niOlOii);
	wire_n1il1i_dataout <= niO10l AND NOT(niOlOii);
	wire_n1il1l_dataout <= niO10O AND NOT(niOlOii);
	wire_n1il1O_dataout <= niO1ii AND NOT(niOlOii);
	wire_n1ilii_dataout <= niO1ll AND NOT(niOlOii);
	wire_n1ilil_dataout <= niO1lO AND NOT(niOlOii);
	wire_n1iliO_dataout <= niO1Oi AND NOT(niOlOii);
	wire_n1illi_dataout <= niO1Ol AND NOT(niOlOii);
	wire_n1illl_dataout <= niO1OO AND NOT(niOlOii);
	wire_n1illO_dataout <= niO01i AND NOT(niOlOii);
	wire_n1ilOi_dataout <= niO01l AND NOT(niOlOii);
	wire_n1ilOl_dataout <= niO01O AND NOT(niOlOii);
	wire_n1ilOO_dataout <= niO00i AND NOT(niOlOii);
	wire_n1iO_dataout <= wire_nlO1lll_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(4);
	wire_n1iO0i_dataout <= niO0il AND NOT(niOlOii);
	wire_n1iO0l_dataout <= niO0iO AND NOT(niOlOii);
	wire_n1iO0O_dataout <= niO0li AND NOT(niOlOii);
	wire_n1iO1i_dataout <= niO00l AND NOT(niOlOii);
	wire_n1iO1l_dataout <= niO00O AND NOT(niOlOii);
	wire_n1iO1O_dataout <= niO0ii AND NOT(niOlOii);
	wire_n1iOi_dataout <= wire_n1l0O_dataout WHEN rbytordplden = '1'  ELSE wire_n1iOO_dataout;
	wire_n1iOii_dataout <= niO0ll AND NOT(niOlOii);
	wire_n1iOil_dataout <= niO0lO AND NOT(niOlOii);
	wire_n1iOiO_dataout <= niO0Oi AND NOT(niOlOii);
	wire_n1iOl_dataout <= wire_n1lii_dataout WHEN rbytordplden = '1'  ELSE wire_n1l1i_dataout;
	wire_n1iOli_dataout <= niO0Ol AND NOT(niOlOii);
	wire_n1iOll_dataout <= niO0OO AND NOT(niOlOii);
	wire_n1iOlO_dataout <= niOi1i AND NOT(niOlOii);
	wire_n1iOO_dataout <= n1i0i WHEN nl111iO = '1'  ELSE wire_n1l1l_dataout;
	wire_n1iOOi_dataout <= rbytordpadval(0) WHEN niOlOil = '1'  ELSE nillOl;
	wire_n1iOOl_dataout <= rbytordpadval(1) WHEN niOlOil = '1'  ELSE nillOO;
	wire_n1iOOO_dataout <= rbytordpadval(2) WHEN niOlOil = '1'  ELSE nilO1i;
	wire_n1l_dataout <= wire_nlO0i0i_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(57);
	wire_n1l00i_dataout <= niO10l AND NOT(niOlOil);
	wire_n1l00l_dataout <= niO10O AND NOT(niOlOil);
	wire_n1l00O_dataout <= niO1ii AND NOT(niOlOil);
	wire_n1l01i_dataout <= niO11l AND NOT(niOlOil);
	wire_n1l01l_dataout <= niO11O AND NOT(niOlOil);
	wire_n1l01O_dataout <= niO10i AND NOT(niOlOil);
	wire_n1l0ii_dataout <= niO1il AND NOT(niOlOil);
	wire_n1l0il_dataout <= niO1iO AND NOT(niOlOil);
	wire_n1l0iO_dataout <= niO1li AND NOT(niOlOil);
	wire_n1l0li_dataout <= niO1ll AND NOT(niOlOil);
	wire_n1l0ll_dataout <= niO1lO AND NOT(niOlOil);
	wire_n1l0lO_dataout <= niO1Oi AND NOT(niOlOil);
	wire_n1l0O_dataout <= n1i0i WHEN nl111li = '1'  ELSE wire_n1l1l_dataout;
	wire_n1l0Oi_dataout <= niO1Ol AND NOT(niOlOil);
	wire_n1l0Ol_dataout <= niO1OO AND NOT(niOlOil);
	wire_n1l0OO_dataout <= niO01i AND NOT(niOlOil);
	wire_n1l10i_dataout <= rbytordpadval(6) WHEN niOlOil = '1'  ELSE nilO0l;
	wire_n1l10l_dataout <= rbytordpadval(7) WHEN niOlOil = '1'  ELSE nilO0O;
	wire_n1l10O_dataout <= rbytordpadval(8) WHEN niOlOil = '1'  ELSE nilOii;
	wire_n1l11i_dataout <= rbytordpadval(3) WHEN niOlOil = '1'  ELSE nilO1l;
	wire_n1l11l_dataout <= rbytordpadval(4) WHEN niOlOil = '1'  ELSE nilO1O;
	wire_n1l11O_dataout <= rbytordpadval(5) WHEN niOlOil = '1'  ELSE nilO0i;
	wire_n1l1i_dataout <= wire_n1l1O_dataout OR nl111iO;
	wire_n1l1ii_dataout <= rbytordpadval(9) WHEN niOlOil = '1'  ELSE nilOil;
	wire_n1l1il_dataout <= nillil WHEN niOlOil = '1'  ELSE nilOiO;
	wire_n1l1iO_dataout <= nilOli AND NOT(niOlOil);
	wire_n1l1l_dataout <= n1i0i OR nl111il;
	wire_n1l1li_dataout <= nilOll AND NOT(niOlOil);
	wire_n1l1ll_dataout <= nilOlO AND NOT(niOlOil);
	wire_n1l1lO_dataout <= nilOOi AND NOT(niOlOil);
	wire_n1l1O_dataout <= n1i0O AND NOT(nl111il);
	wire_n1l1Oi_dataout <= nilOOl AND NOT(niOlOil);
	wire_n1l1Ol_dataout <= nilOOO AND NOT(niOlOil);
	wire_n1l1OO_dataout <= niO11i AND NOT(niOlOil);
	wire_n1li_dataout <= wire_nlO1llO_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(5);
	wire_n1li0i_dataout <= niO00l AND NOT(niOlOil);
	wire_n1li0l_dataout <= niO00O AND NOT(niOlOil);
	wire_n1li0O_dataout <= niO0ii AND NOT(niOlOil);
	wire_n1li1i_dataout <= niO01l AND NOT(niOlOil);
	wire_n1li1l_dataout <= niO01O AND NOT(niOlOil);
	wire_n1li1O_dataout <= niO00i AND NOT(niOlOil);
	wire_n1lii_dataout <= wire_n1l1O_dataout OR nl111li;
	wire_n1liii_dataout <= niO0il AND NOT(niOlOil);
	wire_n1liil_dataout <= niO0iO AND NOT(niOlOil);
	wire_n1liiO_dataout <= niO0li AND NOT(niOlOil);
	wire_n1lili_dataout <= niO0ll AND NOT(niOlOil);
	wire_n1lill_dataout <= niO0lO AND NOT(niOlOil);
	wire_n1lilO_dataout <= niO0Oi AND NOT(niOlOil);
	wire_n1liO_dataout <= (sync_resync_delay(0) OR sync_resync_delay(1)) WHEN rwa_6g_en = '1'  ELSE wire_n1lli_dataout;
	wire_n1liOi_dataout <= niO0Ol AND NOT(niOlOil);
	wire_n1liOl_dataout <= niO0OO AND NOT(niOlOil);
	wire_n1liOO_dataout <= niOi1i AND NOT(niOlOil);
	wire_n1ll_dataout <= wire_nlO1lOi_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(6);
	wire_n1ll0i_dataout <= wire_niOO1l_dataout WHEN niOlO0O = '1'  ELSE wire_n1Oiil_dataout;
	wire_n1ll0l_dataout <= wire_niOO1O_dataout WHEN niOlO0O = '1'  ELSE wire_n1OiiO_dataout;
	wire_n1ll0O_dataout <= wire_niOO0i_dataout WHEN niOlO0O = '1'  ELSE wire_n1Oili_dataout;
	wire_n1ll1i_dataout <= wire_niOlOl_dataout WHEN niOlO0O = '1'  ELSE wire_n1Oi0l_dataout;
	wire_n1ll1l_dataout <= wire_niOlOO_dataout WHEN niOlO0O = '1'  ELSE wire_n1Oi0O_dataout;
	wire_n1ll1O_dataout <= wire_niOO1i_dataout WHEN niOlO0O = '1'  ELSE wire_n1Oiii_dataout;
	wire_n1lli_dataout <= wire_n1lll_dataout WHEN rsync_sm_dis = '1'  ELSE dec_data_valid_pre(0);
	wire_n1llii_dataout <= wire_niOO0l_dataout WHEN niOlO0O = '1'  ELSE wire_n1Oill_dataout;
	wire_n1llil_dataout <= wire_niOO0O_dataout WHEN niOlO0O = '1'  ELSE wire_n1OilO_dataout;
	wire_n1lliO_dataout <= wire_niOOii_dataout WHEN niOlO0O = '1'  ELSE wire_n1OiOi_dataout;
	wire_n1lll_dataout <= sync_resync_delay(0) WHEN rpmadatawidth = '1'  ELSE sync_resync_pre(0);
	wire_n1llli_dataout <= wire_niOOil_dataout WHEN niOlO0O = '1'  ELSE wire_n1OiOl_dataout;
	wire_n1llll_dataout <= wire_niOOiO_dataout WHEN niOlO0O = '1'  ELSE wire_n1OiOO_dataout;
	wire_n1lllO_dataout <= wire_niOOli_dataout WHEN niOlO0O = '1'  ELSE wire_n1Ol1i_dataout;
	wire_n1llOi_dataout <= wire_niOOll_dataout WHEN niOlO0O = '1'  ELSE wire_n1Ol1l_dataout;
	wire_n1llOl_dataout <= wire_niOOlO_dataout WHEN niOlO0O = '1'  ELSE wire_n1Ol1O_dataout;
	wire_n1llOO_dataout <= wire_niOOOi_dataout WHEN niOlO0O = '1'  ELSE wire_n1Ol0i_dataout;
	wire_n1lO_dataout <= wire_nlO1lOl_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(7);
	wire_n1lO0i_dataout <= wire_n010ll_dataout WHEN niOlO0O = '1'  ELSE wire_n1Olil_dataout;
	wire_n1lO0l_dataout <= wire_n010lO_dataout WHEN niOlO0O = '1'  ELSE wire_n1OliO_dataout;
	wire_n1lO0O_dataout <= wire_n010Oi_dataout WHEN niOlO0O = '1'  ELSE wire_n1Olli_dataout;
	wire_n1lO1i_dataout <= wire_niOOOl_dataout WHEN niOlO0O = '1'  ELSE wire_n1Ol0l_dataout;
	wire_n1lO1l_dataout <= wire_n010iO_dataout WHEN niOlO0O = '1'  ELSE wire_n1Ol0O_dataout;
	wire_n1lO1O_dataout <= wire_n010li_dataout WHEN niOlO0O = '1'  ELSE wire_n1Olii_dataout;
	wire_n1lOi_dataout <= wire_n000O_dataout WHEN endec_rx = '1'  ELSE tenb_data(0);
	wire_n1lOii_dataout <= wire_n010Ol_dataout WHEN niOlO0O = '1'  ELSE wire_n1Olll_dataout;
	wire_n1lOil_dataout <= wire_n010OO_dataout WHEN niOlO0O = '1'  ELSE wire_n1OllO_dataout;
	wire_n1lOiO_dataout <= wire_n01i1i_dataout WHEN niOlO0O = '1'  ELSE wire_n1OlOi_dataout;
	wire_n1lOl_dataout <= wire_n00ii_dataout WHEN endec_rx = '1'  ELSE tenb_data(1);
	wire_n1lOli_dataout <= wire_n01i1l_dataout WHEN niOlO0O = '1'  ELSE wire_n1OlOl_dataout;
	wire_n1lOll_dataout <= wire_n01i1O_dataout WHEN niOlO0O = '1'  ELSE wire_n1OlOO_dataout;
	wire_n1lOlO_dataout <= wire_n01i0i_dataout WHEN niOlO0O = '1'  ELSE wire_n1OO1i_dataout;
	wire_n1lOO_dataout <= wire_n00il_dataout WHEN endec_rx = '1'  ELSE tenb_data(2);
	wire_n1lOOi_dataout <= wire_n01i0l_dataout WHEN niOlO0O = '1'  ELSE wire_n1OO1l_dataout;
	wire_n1lOOl_dataout <= wire_n01i0O_dataout WHEN niOlO0O = '1'  ELSE wire_n1OO1O_dataout;
	wire_n1lOOO_dataout <= wire_n01iii_dataout WHEN niOlO0O = '1'  ELSE wire_n1OO0i_dataout;
	wire_n1O_dataout <= wire_nlO0i0l_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(58);
	wire_n1O00i_dataout <= wire_n01lll_dataout WHEN niOlO0O = '1'  ELSE wire_n011il_dataout;
	wire_n1O00l_dataout <= wire_n01llO_dataout WHEN niOlO0O = '1'  ELSE wire_n011iO_dataout;
	wire_n1O00O_dataout <= wire_n01lOi_dataout WHEN niOlO0O = '1'  ELSE wire_n011li_dataout;
	wire_n1O01i_dataout <= wire_n01lil_dataout WHEN niOlO0O = '1'  ELSE wire_n0110l_dataout;
	wire_n1O01l_dataout <= wire_n01liO_dataout WHEN niOlO0O = '1'  ELSE wire_n0110O_dataout;
	wire_n1O01O_dataout <= wire_n01lli_dataout WHEN niOlO0O = '1'  ELSE wire_n011ii_dataout;
	wire_n1O0i_dataout <= wire_n00lO_dataout WHEN endec_rx = '1'  ELSE tenb_data(6);
	wire_n1O0ii_dataout <= wire_n01lOl_dataout WHEN niOlO0O = '1'  ELSE wire_n011ll_dataout;
	wire_n1O0il_dataout <= wire_n01lOO_dataout WHEN niOlO0O = '1'  ELSE wire_n011lO_dataout;
	wire_n1O0iO_dataout <= wire_n01O1i_dataout WHEN niOlO0O = '1'  ELSE wire_n011Oi_dataout;
	wire_n1O0l_dataout <= wire_n00Oi_dataout WHEN endec_rx = '1'  ELSE tenb_data(7);
	wire_n1O0li_dataout <= wire_n01O1l_dataout WHEN niOlO0O = '1'  ELSE wire_n011Ol_dataout;
	wire_n1O0ll_dataout <= wire_n01O1O_dataout WHEN niOlO0O = '1'  ELSE wire_n011OO_dataout;
	wire_n1O0lO_dataout <= wire_n01O0i_dataout WHEN niOlO0O = '1'  ELSE wire_n0101i_dataout;
	wire_n1O0O_dataout <= wire_n00Ol_dataout WHEN endec_rx = '1'  ELSE tenb_data(8);
	wire_n1O0Oi_dataout <= wire_n01O0l_dataout WHEN niOlO0O = '1'  ELSE wire_n0101l_dataout;
	wire_n1O0Ol_dataout <= wire_n01O0O_dataout WHEN niOlO0O = '1'  ELSE wire_n0101O_dataout;
	wire_n1O0OO_dataout <= wire_n01Oii_dataout WHEN niOlO0O = '1'  ELSE wire_n0100i_dataout;
	wire_n1O10i_dataout <= wire_n01ill_dataout WHEN niOlO0O = '1'  ELSE wire_n1OOil_dataout;
	wire_n1O10l_dataout <= wire_n01ilO_dataout WHEN niOlO0O = '1'  ELSE wire_n1OOiO_dataout;
	wire_n1O10O_dataout <= wire_n01iOi_dataout WHEN niOlO0O = '1'  ELSE wire_n1OOli_dataout;
	wire_n1O11i_dataout <= wire_n01iil_dataout WHEN niOlO0O = '1'  ELSE wire_n1OO0l_dataout;
	wire_n1O11l_dataout <= wire_n01iiO_dataout WHEN niOlO0O = '1'  ELSE wire_n1OO0O_dataout;
	wire_n1O11O_dataout <= wire_n01ili_dataout WHEN niOlO0O = '1'  ELSE wire_n1OOii_dataout;
	wire_n1O1i_dataout <= wire_n00iO_dataout WHEN endec_rx = '1'  ELSE tenb_data(3);
	wire_n1O1ii_dataout <= wire_n01iOl_dataout WHEN niOlO0O = '1'  ELSE wire_n1OOll_dataout;
	wire_n1O1il_dataout <= wire_n01iOO_dataout WHEN niOlO0O = '1'  ELSE wire_n1OOlO_dataout;
	wire_n1O1iO_dataout <= wire_n01l1i_dataout WHEN niOlO0O = '1'  ELSE wire_n1OOOi_dataout;
	wire_n1O1l_dataout <= wire_n00li_dataout WHEN endec_rx = '1'  ELSE tenb_data(4);
	wire_n1O1li_dataout <= wire_n01l1l_dataout WHEN niOlO0O = '1'  ELSE wire_n1OOOl_dataout;
	wire_n1O1ll_dataout <= wire_n01l1O_dataout WHEN niOlO0O = '1'  ELSE wire_n1OOOO_dataout;
	wire_n1O1lO_dataout <= wire_n01l0i_dataout WHEN niOlO0O = '1'  ELSE wire_n0111i_dataout;
	wire_n1O1O_dataout <= wire_n00ll_dataout WHEN endec_rx = '1'  ELSE tenb_data(5);
	wire_n1O1Oi_dataout <= wire_n01l0l_dataout WHEN niOlO0O = '1'  ELSE wire_n0111l_dataout;
	wire_n1O1Ol_dataout <= wire_n01l0O_dataout WHEN niOlO0O = '1'  ELSE wire_n0111O_dataout;
	wire_n1O1OO_dataout <= wire_n01lii_dataout WHEN niOlO0O = '1'  ELSE wire_n0110i_dataout;
	wire_n1Oi_dataout <= wire_nlO1lOO_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(8);
	wire_n1Oi0i_dataout <= wire_n01Oll_dataout WHEN niOlO0O = '1'  ELSE wire_n010il_dataout;
	wire_n1Oi0l_dataout <= nillOl WHEN niOlOii = '1'  ELSE wire_niOlOl_dataout;
	wire_n1Oi0O_dataout <= nillOO WHEN niOlOii = '1'  ELSE wire_niOlOO_dataout;
	wire_n1Oi1i_dataout <= wire_n01Oil_dataout WHEN niOlO0O = '1'  ELSE wire_n0100l_dataout;
	wire_n1Oi1l_dataout <= wire_n01OiO_dataout WHEN niOlO0O = '1'  ELSE wire_n0100O_dataout;
	wire_n1Oi1O_dataout <= wire_n01Oli_dataout WHEN niOlO0O = '1'  ELSE wire_n010ii_dataout;
	wire_n1Oii_dataout <= wire_n00OO_dataout WHEN endec_rx = '1'  ELSE tenb_data(9);
	wire_n1Oiii_dataout <= nilO1i WHEN niOlOii = '1'  ELSE wire_niOO1i_dataout;
	wire_n1Oiil_dataout <= nilO1l WHEN niOlOii = '1'  ELSE wire_niOO1l_dataout;
	wire_n1OiiO_dataout <= nilO1O WHEN niOlOii = '1'  ELSE wire_niOO1O_dataout;
	wire_n1Oil_dataout <= wire_n0i1i_dataout WHEN endec_rx = '1'  ELSE tenb_data(10);
	wire_n1Oili_dataout <= nilO0i WHEN niOlOii = '1'  ELSE wire_niOO0i_dataout;
	wire_n1Oill_dataout <= nilO0l WHEN niOlOii = '1'  ELSE wire_niOO0l_dataout;
	wire_n1OilO_dataout <= nilO0O WHEN niOlOii = '1'  ELSE wire_niOO0O_dataout;
	wire_n1OiO_dataout <= wire_n0i1l_dataout WHEN endec_rx = '1'  ELSE tenb_data(11);
	wire_n1OiOi_dataout <= nilOii WHEN niOlOii = '1'  ELSE wire_niOOii_dataout;
	wire_n1OiOl_dataout <= nilOil WHEN niOlOii = '1'  ELSE wire_niOOil_dataout;
	wire_n1OiOO_dataout <= nilOiO WHEN niOlOii = '1'  ELSE wire_niOOiO_dataout;
	wire_n1Ol_dataout <= wire_nlO1O1i_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(9);
	wire_n1Ol0i_dataout <= nilOOi WHEN niOlOii = '1'  ELSE wire_niOOOi_dataout;
	wire_n1Ol0l_dataout <= nilOOl WHEN niOlOii = '1'  ELSE wire_niOOOl_dataout;
	wire_n1Ol0O_dataout <= wire_niOlOl_dataout WHEN niOlOii = '1'  ELSE wire_niOOOO_dataout;
	wire_n1Ol1i_dataout <= nilOli WHEN niOlOii = '1'  ELSE wire_niOOli_dataout;
	wire_n1Ol1l_dataout <= nilOll WHEN niOlOii = '1'  ELSE wire_niOOll_dataout;
	wire_n1Ol1O_dataout <= nilOlO WHEN niOlOii = '1'  ELSE wire_niOOlO_dataout;
	wire_n1Oli_dataout <= wire_n0i1O_dataout WHEN endec_rx = '1'  ELSE tenb_data(12);
	wire_n1Olii_dataout <= wire_niOlOO_dataout WHEN niOlOii = '1'  ELSE wire_nl111i_dataout;
	wire_n1Olil_dataout <= wire_niOO1i_dataout WHEN niOlOii = '1'  ELSE wire_nl111l_dataout;
	wire_n1OliO_dataout <= wire_niOO1l_dataout WHEN niOlOii = '1'  ELSE wire_nl111O_dataout;
	wire_n1Oll_dataout <= wire_n0i0i_dataout WHEN endec_rx = '1'  ELSE tenb_data(13);
	wire_n1Olli_dataout <= wire_niOO1O_dataout WHEN niOlOii = '1'  ELSE wire_nl110i_dataout;
	wire_n1Olll_dataout <= wire_niOO0i_dataout WHEN niOlOii = '1'  ELSE wire_nl110l_dataout;
	wire_n1OllO_dataout <= wire_niOO0l_dataout WHEN niOlOii = '1'  ELSE wire_nl110O_dataout;
	wire_n1OlO_dataout <= wire_n0i0l_dataout WHEN endec_rx = '1'  ELSE tenb_data(14);
	wire_n1OlOi_dataout <= wire_niOO0O_dataout WHEN niOlOii = '1'  ELSE wire_nl11ii_dataout;
	wire_n1OlOl_dataout <= wire_niOOii_dataout WHEN niOlOii = '1'  ELSE wire_nl11il_dataout;
	wire_n1OlOO_dataout <= wire_niOOil_dataout WHEN niOlOii = '1'  ELSE wire_nl11iO_dataout;
	wire_n1OO_dataout <= wire_nlO1O1l_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(10);
	wire_n1OO0i_dataout <= wire_niOOlO_dataout WHEN niOlOii = '1'  ELSE wire_nl11Oi_dataout;
	wire_n1OO0l_dataout <= wire_niOOOi_dataout WHEN niOlOii = '1'  ELSE wire_nl11Ol_dataout;
	wire_n1OO0O_dataout <= wire_niOOOl_dataout WHEN niOlOii = '1'  ELSE wire_nl11OO_dataout;
	wire_n1OO1i_dataout <= wire_niOOiO_dataout WHEN niOlOii = '1'  ELSE wire_nl11li_dataout;
	wire_n1OO1l_dataout <= wire_niOOli_dataout WHEN niOlOii = '1'  ELSE wire_nl11ll_dataout;
	wire_n1OO1O_dataout <= wire_niOOll_dataout WHEN niOlOii = '1'  ELSE wire_nl11lO_dataout;
	wire_n1OOi_dataout <= wire_n0i0O_dataout WHEN endec_rx = '1'  ELSE tenb_data(15);
	wire_n1OOii_dataout <= wire_nl101i_dataout AND NOT(niOlOii);
	wire_n1OOil_dataout <= wire_nl101l_dataout AND NOT(niOlOii);
	wire_n1OOiO_dataout <= wire_nl101O_dataout AND NOT(niOlOii);
	wire_n1OOl_dataout <= wire_n0iii_dataout WHEN endec_rx = '1'  ELSE tenb_data(16);
	wire_n1OOli_dataout <= wire_nl100i_dataout AND NOT(niOlOii);
	wire_n1OOll_dataout <= wire_nl100l_dataout AND NOT(niOlOii);
	wire_n1OOlO_dataout <= wire_nl100O_dataout AND NOT(niOlOii);
	wire_n1OOO_dataout <= wire_n0iil_dataout WHEN endec_rx = '1'  ELSE tenb_data(17);
	wire_n1OOOi_dataout <= wire_nl10ii_dataout AND NOT(niOlOii);
	wire_n1OOOl_dataout <= wire_nl10il_dataout AND NOT(niOlOii);
	wire_n1OOOO_dataout <= wire_nl10iO_dataout AND NOT(niOlOii);
	wire_ni000l_dataout <= (niOO1Oi AND wire_ni00iO_dataout) WHEN rwa_6g_en = '1'  ELSE (niOi1l AND (niOO01i AND niOO1Oi));
	wire_ni001l_dataout <= niOO1li OR rbytord_6g_mask_en;
	wire_ni00i_dataout <= wire_niiOi_dataout WHEN wire_nlilOi_w_lg_dataout523w(0) = '1'  ELSE wire_ni0OO_dataout;
	wire_ni00iO_dataout <= niOO1Ol OR rbytord_6g_mask_en;
	wire_ni00l_dataout <= wire_niiOl_dataout WHEN wire_nlilOi_w_lg_dataout523w(0) = '1'  ELSE wire_nii1i_dataout;
	wire_ni00li_dataout <= wire_ni00ll_dataout AND rwa_6g_en;
	wire_ni00ll_dataout <= (niOO1OO AND wire_ni00Ol_dataout) WHEN rdwidth = '1'  ELSE (wire_ni0iiO_dataout AND niOO1OO);
	wire_ni00O_dataout <= wire_niiOO_dataout WHEN wire_nlilOi_w_lg_dataout523w(0) = '1'  ELSE wire_nii1l_dataout;
	wire_ni00Ol_dataout <= niOO01i OR rbytord_6g_mask_en;
	wire_ni00OO_dataout <= wire_ni0i1O_dataout WHEN rwa_6g_en = '1'  ELSE (niOi1O AND (niOO01O AND niOOill));
	wire_ni010i_dataout <= wire_ni01il_dataout WHEN rwa_6g_en = '1'  ELSE (niOi1O AND (niOO1li AND niOO1ii));
	wire_ni011l_dataout <= niOO10i OR rbytord_6g_mask_en;
	wire_ni01i_dataout <= wire_niili_dataout WHEN wire_nlilOi_w_lg_dataout523w(0) = '1'  ELSE wire_ni0lO_dataout;
	wire_ni01il_dataout <= (wire_nl1l0i_dataout AND (niOO1ii AND wire_ni01ll_dataout)) AND rdwidth;
	wire_ni01l_dataout <= wire_niill_dataout WHEN wire_nlilOi_w_lg_dataout523w(0) = '1'  ELSE wire_ni0Oi_dataout;
	wire_ni01ll_dataout <= (niOO1iO OR niOO1il) OR rbytord_6g_mask_en;
	wire_ni01O_dataout <= wire_niilO_dataout WHEN wire_nlilOi_w_lg_dataout523w(0) = '1'  ELSE wire_ni0Ol_dataout;
	wire_ni01Oi_dataout <= wire_ni01Ol_dataout AND rwa_6g_en;
	wire_ni01Ol_dataout <= (wire_nl1l0i_dataout AND (wire_ni001l_dataout AND (niOO0ll OR niOO0li))) AND rdwidth;
	wire_ni0i_dataout <= wire_nlO010O_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(29);
	wire_ni0i0l_dataout <= niOO01l OR rbytord_6g_mask_en;
	wire_ni0i0O_dataout <= wire_ni0iii_dataout AND rwa_6g_en;
	wire_ni0i1O_dataout <= (niOOill AND wire_ni0i0l_dataout) AND rdwidth;
	wire_ni0ii_dataout <= wire_nil1i_dataout WHEN wire_nlilOi_w_lg_dataout523w(0) = '1'  ELSE wire_nii1O_dataout;
	wire_ni0iii_dataout <= (wire_ni0iiO_dataout AND niOOili) AND rdwidth;
	wire_ni0iiO_dataout <= niOO01O OR rbytord_6g_mask_en;
	wire_ni0il_dataout <= wire_nil1l_dataout WHEN wire_nlilOi_w_lg_dataout523w(0) = '1'  ELSE wire_nii0i_dataout;
	wire_ni0ili_dataout <= (niOO00i AND wire_ni0iOl_dataout) WHEN rwa_6g_en = '1'  ELSE (niOi1O AND (niOO0ii AND niOO00i));
	wire_ni0iO_dataout <= wire_nil1O_dataout WHEN wire_nlilOi_w_lg_dataout523w(0) = '1'  ELSE wire_nii0l_dataout;
	wire_ni0iOl_dataout <= niOO00l OR rbytord_6g_mask_en;
	wire_ni0iOO_dataout <= wire_ni0l1i_dataout AND rwa_6g_en;
	wire_ni0l_dataout <= wire_nlO01ii_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(30);
	wire_ni0l0i_dataout <= niOO0ii OR rbytord_6g_mask_en;
	wire_ni0l0l_dataout <= wire_ni0lil_dataout WHEN rwa_6g_en = '1'  ELSE (wire_nl1l1O_dataout AND (niOO0iO AND niOOl1O));
	wire_ni0l1i_dataout <= (niOO00O AND wire_ni0l0i_dataout) WHEN rdwidth = '1'  ELSE (wire_ni0lOl_dataout AND niOO00O);
	wire_ni0li_dataout <= wire_nil0i_dataout WHEN wire_nlilOi_w_lg_dataout523w(0) = '1'  ELSE wire_niO_dataout;
	wire_ni0lil_dataout <= (niOOl1O AND wire_ni0lli_dataout) AND rdwidth;
	wire_ni0ll_dataout <= wire_nil0l_dataout WHEN wire_nlilOi_w_lg_dataout523w(0) = '1'  ELSE wire_nli1l_o;
	wire_ni0lli_dataout <= niOO0il OR rbytord_6g_mask_en;
	wire_ni0lll_dataout <= wire_ni0llO_dataout AND rwa_6g_en;
	wire_ni0llO_dataout <= (wire_ni0lOl_dataout AND niOOl1l) AND rdwidth;
	wire_ni0lO_dataout <= rclkcmpinsertpad WHEN nl111Oi = '1'  ELSE rx_data_dt(0);
	wire_ni0lOl_dataout <= niOO0iO OR rbytord_6g_mask_en;
	wire_ni0lOO_dataout <= (wire_nl1l1O_dataout AND (niOO0Ol AND (wire_w_lg_rbytordplden683w(0) OR (wire_w_lg_niOO0ll758w(0) AND wire_w_lg_niOO0li759w(0))))) WHEN rwa_6g_en = '1'  ELSE (wire_nl1l1O_dataout AND ((wire_w_lg_rbytordplden683w(0) OR (wire_w_lg_niOO0Oi752w(0) AND wire_w_lg_niOO0lO753w(0))) AND niOO0Ol));
	wire_ni0O_dataout <= wire_nlO01il_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(31);
	wire_ni0Oi_dataout <= rx_data_dt(1) OR nl111Oi;
	wire_ni0Ol_dataout <= rx_data_dt(2) OR nl111Oi;
	wire_ni0Oli_dataout <= (wire_nl1l1O_dataout AND (niOO0OO AND (niOOi0i OR niOOi1O))) AND rwa_6g_en;
	wire_ni0OO_dataout <= wire_w_lg_rclkcmpinsertpad522w(0) WHEN nl111Oi = '1'  ELSE rx_data_dt(3);
	wire_ni0OOl_dataout <= wire_nii10l_dataout WHEN rwa_6g_en = '1'  ELSE (wire_nl1l0i_dataout AND (niOO0OO AND niOOi0l));
	wire_ni100i_dataout <= wire_nl11Oi_dataout AND NOT(wire_n0iO0O_o(2));
	wire_ni100l_dataout <= wire_nl11Ol_dataout AND NOT(wire_n0iO0O_o(2));
	wire_ni100O_dataout <= wire_nl11OO_dataout AND NOT(wire_n0iO0O_o(2));
	wire_ni101i_dataout <= wire_niOOiO_dataout WHEN wire_n0iO0O_o(2) = '1'  ELSE wire_nl11li_dataout;
	wire_ni101l_dataout <= wire_nl11ll_dataout AND NOT(wire_n0iO0O_o(2));
	wire_ni101O_dataout <= wire_nl11lO_dataout AND NOT(wire_n0iO0O_o(2));
	wire_ni10i_dataout <= rx_data_dt(8) AND NOT(nl111Ol);
	wire_ni10ii_dataout <= rbytordpadval(0) WHEN niOlOiO = '1'  ELSE wire_nl101i_dataout;
	wire_ni10il_dataout <= rbytordpadval(1) WHEN niOlOiO = '1'  ELSE wire_nl101l_dataout;
	wire_ni10iO_dataout <= rbytordpadval(2) WHEN niOlOiO = '1'  ELSE wire_nl101O_dataout;
	wire_ni10l_dataout <= rrx_pipe_enable WHEN nl111Ol = '1'  ELSE rx_data_dt(9);
	wire_ni10li_dataout <= rbytordpadval(3) WHEN niOlOiO = '1'  ELSE wire_nl100i_dataout;
	wire_ni10ll_dataout <= rbytordpadval(4) WHEN niOlOiO = '1'  ELSE wire_nl100l_dataout;
	wire_ni10lO_dataout <= rbytordpadval(5) WHEN niOlOiO = '1'  ELSE wire_nl100O_dataout;
	wire_ni10O_dataout <= rx_data_dt(10) OR nl111Ol;
	wire_ni10Oi_dataout <= rbytordpadval(6) WHEN niOlOiO = '1'  ELSE wire_nl10ii_dataout;
	wire_ni10Ol_dataout <= rbytordpadval(7) WHEN niOlOiO = '1'  ELSE wire_nl10il_dataout;
	wire_ni10OO_dataout <= rbytordpadval(8) WHEN niOlOiO = '1'  ELSE wire_nl10iO_dataout;
	wire_ni110O_dataout <= rbytordpadval(0) WHEN wire_n0iO0O_o(2) = '1'  ELSE wire_niOOOO_dataout;
	wire_ni11ii_dataout <= rbytordpadval(1) WHEN wire_n0iO0O_o(2) = '1'  ELSE wire_nl111i_dataout;
	wire_ni11il_dataout <= rbytordpadval(2) WHEN wire_n0iO0O_o(2) = '1'  ELSE wire_nl111l_dataout;
	wire_ni11iO_dataout <= rbytordpadval(3) WHEN wire_n0iO0O_o(2) = '1'  ELSE wire_nl111O_dataout;
	wire_ni11li_dataout <= rbytordpadval(4) WHEN wire_n0iO0O_o(2) = '1'  ELSE wire_nl110i_dataout;
	wire_ni11ll_dataout <= rbytordpadval(5) WHEN wire_n0iO0O_o(2) = '1'  ELSE wire_nl110l_dataout;
	wire_ni11lO_dataout <= rbytordpadval(6) WHEN wire_n0iO0O_o(2) = '1'  ELSE wire_nl110O_dataout;
	wire_ni11Oi_dataout <= rbytordpadval(7) WHEN wire_n0iO0O_o(2) = '1'  ELSE wire_nl11ii_dataout;
	wire_ni11Ol_dataout <= rbytordpadval(8) WHEN wire_n0iO0O_o(2) = '1'  ELSE wire_nl11il_dataout;
	wire_ni11OO_dataout <= rbytordpadval(9) WHEN wire_n0iO0O_o(2) = '1'  ELSE wire_nl11iO_dataout;
	wire_ni1i_dataout <= wire_nlO011O_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(26);
	wire_ni1i0i_dataout <= wire_nl10Oi_dataout AND NOT(niOlOiO);
	wire_ni1i0l_dataout <= wire_nl10Ol_dataout AND NOT(niOlOiO);
	wire_ni1i0O_dataout <= wire_nl10OO_dataout AND NOT(niOlOiO);
	wire_ni1i1i_dataout <= rbytordpadval(9) WHEN niOlOiO = '1'  ELSE wire_nl10li_dataout;
	wire_ni1i1O_dataout <= wire_nl10lO_dataout AND NOT(niOlOiO);
	wire_ni1ii_dataout <= rx_data_dt(11) OR nl111Ol;
	wire_ni1iii_dataout <= wire_nl1i1i_dataout AND NOT(niOlOiO);
	wire_ni1iil_dataout <= rbytordpadval(0) WHEN niOlOli = '1'  ELSE wire_nl1i1l_dataout;
	wire_ni1iiO_dataout <= rbytordpadval(1) WHEN niOlOli = '1'  ELSE wire_nl1i1O_dataout;
	wire_ni1il_dataout <= rx_data_dt(12) OR nl111Ol;
	wire_ni1ili_dataout <= rbytordpadval(2) WHEN niOlOli = '1'  ELSE wire_nl1i0i_dataout;
	wire_ni1ill_dataout <= rbytordpadval(3) WHEN niOlOli = '1'  ELSE wire_nl1i0l_dataout;
	wire_ni1ilO_dataout <= rbytordpadval(4) WHEN niOlOli = '1'  ELSE wire_nl1i0O_dataout;
	wire_ni1iO_dataout <= rrx_pipe_enable WHEN nl111Ol = '1'  ELSE rx_data_dt(13);
	wire_ni1iOi_dataout <= rbytordpadval(5) WHEN niOlOli = '1'  ELSE wire_nl1iii_dataout;
	wire_ni1iOl_dataout <= rbytordpadval(6) WHEN niOlOli = '1'  ELSE wire_nl1iil_dataout;
	wire_ni1iOO_dataout <= rbytordpadval(7) WHEN niOlOli = '1'  ELSE wire_nl1iiO_dataout;
	wire_ni1l_dataout <= wire_nlO010i_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(27);
	wire_ni1l0i_dataout <= wire_nl1iOi_dataout AND NOT(niOlOli);
	wire_ni1l0l_dataout <= wire_nl1iOl_dataout AND NOT(niOlOli);
	wire_ni1l0O_dataout <= wire_nl1iOO_dataout AND NOT(niOlOli);
	wire_ni1l1i_dataout <= rbytordpadval(8) WHEN niOlOli = '1'  ELSE wire_nl1ili_dataout;
	wire_ni1l1l_dataout <= rbytordpadval(9) WHEN niOlOli = '1'  ELSE wire_nl1ill_dataout;
	wire_ni1li_dataout <= rrx_pipe_enable WHEN nl111Ol = '1'  ELSE rx_data_dt(14);
	wire_ni1lii_dataout <= wire_nl1l1i_dataout AND NOT(niOlOli);
	wire_ni1lil_dataout <= wire_nl1l1l_dataout AND NOT(niOlOli);
	wire_ni1liO_dataout <= wire_ni1lOi_o AND NOT(niOOlli);
	wire_ni1liO_w_lg_dataout678w(0) <= NOT wire_ni1liO_dataout;
	wire_ni1ll_dataout <= rx_data_dt(15) OR nl111Ol;
	wire_ni1lli_dataout <= wire_ni1lOl_o AND NOT(niOOlli);
	wire_ni1lli_w_lg_w_lg_w_lg_dataout679w680w681w(0) <= wire_ni1lli_w_lg_w_lg_dataout679w680w(0) OR wire_ni1llO_dataout;
	wire_ni1lli_w_lg_w_lg_dataout679w680w(0) <= wire_ni1lli_w_lg_dataout679w(0) OR wire_ni1lll_dataout;
	wire_ni1lli_w_lg_dataout679w(0) <= wire_ni1lli_dataout OR wire_ni1liO_dataout;
	wire_ni1lll_dataout <= wire_ni1lOO_o AND NOT(niOOlli);
	wire_ni1lll_w_lg_dataout3799w(0) <= NOT wire_ni1lll_dataout;
	wire_ni1llO_dataout <= wire_ni1O1i_o AND NOT(niOOlli);
	wire_ni1lO_dataout <= rx_control_dt(1) OR nl111Ol;
	wire_ni1O_dataout <= wire_nlO010l_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(28);
	wire_ni1O1l_dataout <= (wire_nl1l1O_dataout AND (niOlOll AND wire_ni1Oil_dataout)) WHEN rwa_6g_en = '1'  ELSE (niOi1l AND (niOO10i AND niOlOll));
	wire_ni1Oi_dataout <= wire_ni1OO_dataout WHEN nl111Ol = '1'  ELSE wire_nli_dataout;
	wire_ni1Oil_dataout <= (niOlOOO OR niOlOOl) OR rbytord_6g_mask_en;
	wire_ni1Ol_dataout <= wire_niO1l_o AND NOT(nl111Ol);
	wire_ni1Oli_dataout <= wire_ni1Oll_dataout AND rwa_6g_en;
	wire_ni1Oll_dataout <= (wire_nl1l1O_dataout AND (niOO11i AND wire_ni011l_dataout)) WHEN rdwidth = '1'  ELSE (wire_nl1l1O_dataout AND (wire_ni001l_dataout AND niOO11i));
	wire_ni1OO_dataout <= wire_nli_dataout OR rrx_pipe_enable;
	wire_nii_dataout <= wire_nlO0iiO_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(62);
	wire_nii01l_dataout <= (wire_nl1l1O_dataout AND (niOOiOi AND (wire_w_lg_rbytordplden683w(0) OR wire_w_lg_niOOili724w(0)))) WHEN rwa_6g_en = '1'  ELSE (wire_nl1l1O_dataout AND (niOOiOi AND (wire_w_lg_rbytordplden683w(0) OR wire_w_lg_niOOill720w(0))));
	wire_nii0i_dataout <= rx_data_dt(7) OR nl111Oi;
	wire_nii0iO_dataout <= (wire_nl1l1O_dataout AND (niOOilO AND niOOiOl)) AND rwa_6g_en;
	wire_nii0l_dataout <= rx_control_dt(0) OR nl111Oi;
	wire_nii0lO_dataout <= wire_niii1i_dataout WHEN rwa_6g_en = '1'  ELSE (wire_nl1l0i_dataout AND (niOOilO AND niOOl1i));
	wire_nii10l_dataout <= (wire_nl1l0i_dataout AND (niOOi0l AND (wire_w_lg_rbytordplden683w(0) OR (wire_w_lg_niOOi0i735w(0) AND wire_w_lg_niOOi1O736w(0))))) AND rdwidth;
	wire_nii1i_dataout <= rx_data_dt(4) OR nl111Oi;
	wire_nii1l_dataout <= rx_data_dt(5) OR nl111Oi;
	wire_nii1li_dataout <= wire_nii1ll_dataout AND rwa_6g_en;
	wire_nii1ll_dataout <= (wire_nl1l0i_dataout AND ((wire_w_lg_rbytordplden683w(0) OR (wire_w_lg_niOOiiO728w(0) AND wire_w_lg_niOOiil729w(0))) AND (niOOiii OR niOOi0O))) AND rdwidth;
	wire_nii1O_dataout <= rx_data_dt(6) OR nl111Oi;
	wire_niii_dataout <= wire_nlO01iO_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(32);
	wire_niii0l_dataout <= wire_niii0O_dataout AND rwa_6g_en;
	wire_niii0O_dataout <= (wire_nl1l0i_dataout AND ((wire_w_lg_rbytordplden683w(0) OR wire_w_lg_niOOl1i706w(0)) AND niOOiOO)) AND rdwidth;
	wire_niii1i_dataout <= (wire_nl1l0i_dataout AND (niOOl1i AND (wire_w_lg_rbytordplden683w(0) OR wire_w_lg_niOOiOl710w(0)))) AND rdwidth;
	wire_niiili_dataout <= (wire_nl1l1O_dataout AND (niOOl0l AND (wire_w_lg_rbytordplden683w(0) OR wire_w_lg_niOOl1l702w(0)))) WHEN rwa_6g_en = '1'  ELSE (wire_nl1l1O_dataout AND (niOOl0l AND (wire_w_lg_rbytordplden683w(0) OR wire_w_lg_niOOl1O698w(0))));
	wire_niil_dataout <= wire_nlO01li_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(33);
	wire_niil0l_dataout <= wire_niiliO_dataout WHEN rwa_6g_en = '1'  ELSE (wire_nl1l0i_dataout AND (niOOl0i AND niOOlil));
	wire_niil1l_dataout <= (wire_nl1l1O_dataout AND (niOOl0i AND niOOl0O)) AND rwa_6g_en;
	wire_niili_dataout <= rx_data_dt(0) AND NOT(nl111Ol);
	wire_niiliO_dataout <= (wire_nl1l0i_dataout AND (niOOlil AND (wire_w_lg_rbytordplden683w(0) OR wire_w_lg_niOOl0O688w(0)))) AND rdwidth;
	wire_niill_dataout <= rrx_pipe_enable WHEN nl111Ol = '1'  ELSE rx_data_dt(1);
	wire_niilO_dataout <= rx_data_dt(2) OR nl111Ol;
	wire_niilOi_dataout <= wire_niilOl_dataout AND rwa_6g_en;
	wire_niilOl_dataout <= (wire_nl1l0i_dataout AND ((wire_w_lg_rbytordplden683w(0) OR wire_w_lg_niOOlil684w(0)) AND niOOlii)) AND rdwidth;
	wire_niiO_dataout <= wire_nlO01ll_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(34);
	wire_niiOi_dataout <= rx_data_dt(3) OR nl111Ol;
	wire_niiOl_dataout <= rx_data_dt(4) OR nl111Ol;
	wire_niiOO_dataout <= rrx_pipe_enable WHEN nl111Ol = '1'  ELSE rx_data_dt(5);
	wire_nil_dataout <= wire_nlO0ili_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(63);
	wire_nil0i_dataout <= wire_nil0O_dataout WHEN nl111Ol = '1'  ELSE wire_niO_dataout;
	wire_nil0l_dataout <= wire_nli1l_o AND NOT(nl111Ol);
	wire_nil0O_dataout <= wire_niO_dataout OR rrx_pipe_enable;
	wire_nil1i_dataout <= rrx_pipe_enable WHEN nl111Ol = '1'  ELSE rx_data_dt(6);
	wire_nil1l_dataout <= rx_data_dt(7) OR nl111Ol;
	wire_nil1O_dataout <= rx_control_dt(0) OR nl111Ol;
	wire_nili_dataout <= wire_nlO01lO_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(35);
	wire_nill_dataout <= wire_nlO01Oi_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(36);
	wire_nilO_dataout <= wire_nlO01Ol_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(37);
	wire_niO_dataout <= invalid_code_delay(0) WHEN rinvalid_code_err_only = '1'  ELSE ((disp_err_delay(0) OR invalid_code_delay(0)) OR (NOT (nl101iO6 XOR nl101iO5)));
	wire_niO_w_lg_dataout512w(0) <= wire_niO_dataout AND wire_w_lg_w_lg_rsync_sm_dis1w511w(0);
	wire_niOi_dataout <= wire_nlO01OO_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(38);
	wire_niOiiO_dataout <= wire_niOili_dataout AND NOT(niiOiO);
	wire_niOili_dataout <= wire_niOill_dataout AND NOT(niOOlli);
	wire_niOill_dataout <= wire_niOilO_dataout AND (wire_ni1liO_w_lg_dataout678w(0) AND wire_ni1lli_w_lg_w_lg_w_lg_dataout679w680w681w(0));
	wire_niOilO_dataout <= n1i0O WHEN rwa_6g_en = '1'  ELSE wire_niOiOi_dataout;
	wire_niOiOi_dataout <= wire_niOiOl_dataout WHEN rbytord_s2gx = '1'  ELSE n1i0O;
	wire_niOiOl_dataout <= n1i0O WHEN rbytordplden = '1'  ELSE wire_niOiOO_dataout;
	wire_niOiOO_dataout <= n1i0O AND NOT(n1i0i);
	wire_niOl_dataout <= wire_nlO001i_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(39);
	wire_niOl0i_dataout <= niOi0i OR nl111li;
	wire_niOl0O_dataout <= wire_ni1liO_dataout WHEN niOOliO = '1'  ELSE wire_niOlli_dataout;
	wire_niOl1O_dataout <= wire_niOl0i_dataout AND NOT((wire_nli1ii_w_lg_niOi0l676w(0) AND niOi0O));
	wire_niOlii_dataout <= wire_ni1lli_dataout WHEN niOOliO = '1'  ELSE wire_niOlll_dataout;
	wire_niOlil_dataout <= wire_ni1lll_dataout WHEN niOOliO = '1'  ELSE wire_niOllO_dataout;
	wire_niOliO_dataout <= wire_ni1llO_dataout WHEN niOOliO = '1'  ELSE wire_niOlOi_dataout;
	wire_niOlli_dataout <= niiO0l AND NOT(niOOlli);
	wire_niOlll_dataout <= niiO0O AND NOT(niOOlli);
	wire_niOllO_dataout <= niiOii AND NOT(niOOlli);
	wire_niOlOi_dataout <= niiOil AND NOT(niOOlli);
	wire_niOlOl_dataout <= wire_nli0li_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl000i;
	wire_niOlOO_dataout <= wire_nli0ll_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl000l;
	wire_niOO_dataout <= wire_nlO001l_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(40);
	wire_niOO0i_dataout <= wire_nli0OO_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl00iO;
	wire_niOO0l_dataout <= wire_nlii1i_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl00li;
	wire_niOO0O_dataout <= wire_nlii1l_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl00ll;
	wire_niOO1i_dataout <= wire_nli0lO_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl000O;
	wire_niOO1l_dataout <= wire_nli0Oi_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl00ii;
	wire_niOO1O_dataout <= wire_nli0Ol_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl00il;
	wire_niOOii_dataout <= wire_nlii1O_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl00lO;
	wire_niOOil_dataout <= wire_nlii0i_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl00Oi;
	wire_niOOiO_dataout <= wire_nlii0l_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl00Ol;
	wire_niOOl_dataout <= (nl11i0i AND nll1ll) WHEN tenb_data(18) = '1'  ELSE (nl11i0i AND nll1OO);
	wire_niOOli_dataout <= wire_nlii0O_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl00OO;
	wire_niOOll_dataout <= wire_nliiii_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0i1i;
	wire_niOOlO_dataout <= wire_nliiil_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0i1l;
	wire_niOOOi_dataout <= wire_nliiiO_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0i1O;
	wire_niOOOl_dataout <= wire_nliili_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0i0i;
	wire_niOOOO_dataout <= wire_nliill_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0i0l;
	wire_nl010l_dataout <= wire_nl01ii_dataout WHEN rmaster_rx = '1'  ELSE wire_nl010O_dataout;
	wire_nl010O_dataout <= rd_enable_quad_up WHEN rmaster_up_rx = '1'  ELSE rd_enable_quad_down;
	wire_nl01ii_dataout <= nl1OOO WHEN rindv_rx = '1'  ELSE rd_enable_centrl;
	wire_nl01il_dataout <= (nl011i AND pld_re) WHEN rrxphfifopldctl_en = '1'  ELSE nl011i;
	wire_nl0i_dataout <= wire_nlO000O_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(44);
	wire_nl0l_dataout <= wire_nlO00ii_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(45);
	wire_nl0O_dataout <= wire_nlO00il_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(46);
	wire_nl100i_dataout <= nlO00O WHEN rrxpcsbypass_en = '1'  ELSE nl0liO;
	wire_nl100l_dataout <= nlO0ii WHEN rrxpcsbypass_en = '1'  ELSE nl0lli;
	wire_nl100O_dataout <= nlO0il WHEN rrxpcsbypass_en = '1'  ELSE nl0lll;
	wire_nl101i_dataout <= nlO01O WHEN rrxpcsbypass_en = '1'  ELSE nl0l0O;
	wire_nl101l_dataout <= nlO00i WHEN rrxpcsbypass_en = '1'  ELSE nl0lii;
	wire_nl101O_dataout <= nlO00l WHEN rrxpcsbypass_en = '1'  ELSE nl0lil;
	wire_nl10ii_dataout <= nlO0iO WHEN rrxpcsbypass_en = '1'  ELSE nl0llO;
	wire_nl10il_dataout <= nlO0li WHEN rrxpcsbypass_en = '1'  ELSE nl0lOi;
	wire_nl10iO_dataout <= nlO0ll WHEN rrxpcsbypass_en = '1'  ELSE nl0lOl;
	wire_nl10li_dataout <= nlO0lO WHEN rrxpcsbypass_en = '1'  ELSE nl0lOO;
	wire_nl10ll_dataout <= nlO0Oi WHEN rrxpcsbypass_en = '1'  ELSE nl0O1i;
	wire_nl10lO_dataout <= nlO0Ol WHEN rrxpcsbypass_en = '1'  ELSE nl0O1l;
	wire_nl10Oi_dataout <= nlO0OO WHEN rrxpcsbypass_en = '1'  ELSE nl0O1O;
	wire_nl10Ol_dataout <= nlOi1i WHEN rrxpcsbypass_en = '1'  ELSE nl0O0i;
	wire_nl10OO_dataout <= nlOi1l WHEN rrxpcsbypass_en = '1'  ELSE nl0O0l;
	wire_nl110i_dataout <= wire_nliiOO_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0iiO;
	wire_nl110l_dataout <= wire_nlil1i_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0ili;
	wire_nl110O_dataout <= wire_nlil1l_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0ill;
	wire_nl111i_dataout <= wire_nliilO_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0i0O;
	wire_nl111l_dataout <= wire_nliiOi_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0iii;
	wire_nl111O_dataout <= wire_nliiOl_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0iil;
	wire_nl11ii_dataout <= wire_nlil1O_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0ilO;
	wire_nl11il_dataout <= wire_nlil0i_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0iOi;
	wire_nl11iO_dataout <= wire_nlil0l_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0iOl;
	wire_nl11li_dataout <= wire_nlil0O_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0iOO;
	wire_nl11ll_dataout <= wire_nlilii_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0l1i;
	wire_nl11lO_dataout <= wire_nlilil_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0l1l;
	wire_nl11Oi_dataout <= wire_nliliO_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0l1O;
	wire_nl11Ol_dataout <= wire_nlilli_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0l0i;
	wire_nl11OO_dataout <= wire_nlilll_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0l0l;
	wire_nl1i_dataout <= wire_nlO001O_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(41);
	wire_nl1i0i_dataout <= nlOi0O WHEN rrxpcsbypass_en = '1'  ELSE nl0OiO;
	wire_nl1i0l_dataout <= nlOiii WHEN rrxpcsbypass_en = '1'  ELSE nl0Oli;
	wire_nl1i0O_dataout <= nlOiil WHEN rrxpcsbypass_en = '1'  ELSE nl0Oll;
	wire_nl1i1i_dataout <= nlOi1O WHEN rrxpcsbypass_en = '1'  ELSE nl0O0O;
	wire_nl1i1l_dataout <= nlOi0i WHEN rrxpcsbypass_en = '1'  ELSE nl0Oii;
	wire_nl1i1O_dataout <= nlOi0l WHEN rrxpcsbypass_en = '1'  ELSE nl0Oil;
	wire_nl1iii_dataout <= nlOiiO WHEN rrxpcsbypass_en = '1'  ELSE nl0OlO;
	wire_nl1iil_dataout <= nlOili WHEN rrxpcsbypass_en = '1'  ELSE nl0OOi;
	wire_nl1iiO_dataout <= nlOill WHEN rrxpcsbypass_en = '1'  ELSE nl0OOl;
	wire_nl1ili_dataout <= nlOilO WHEN rrxpcsbypass_en = '1'  ELSE nl0OOO;
	wire_nl1ill_dataout <= nlOiOi WHEN rrxpcsbypass_en = '1'  ELSE nli11i;
	wire_nl1ilO_dataout <= nlOiOl WHEN rrxpcsbypass_en = '1'  ELSE nli11l;
	wire_nl1iOi_dataout <= nlOiOO WHEN rrxpcsbypass_en = '1'  ELSE nli11O;
	wire_nl1iOl_dataout <= nlOl1i WHEN rrxpcsbypass_en = '1'  ELSE nli10i;
	wire_nl1iOO_dataout <= nlOl1l WHEN rrxpcsbypass_en = '1'  ELSE nli10l;
	wire_nl1l_dataout <= wire_nlO000i_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(42);
	wire_nl1l0i_dataout <= wire_nl1l0O_dataout AND NOT(niOOlOl);
	wire_nl1l0i_w_lg_dataout5769w(0) <= NOT wire_nl1l0i_dataout;
	wire_nl1l0l_dataout <= wire_nl1lii_dataout AND NOT(niOOlOi);
	wire_nl1l0O_dataout <= wire_nl1lil_dataout AND NOT(niOOlOi);
	wire_nl1l1i_dataout <= nlOl1O WHEN rrxpcsbypass_en = '1'  ELSE nli10O;
	wire_nl1l1l_dataout <= nlOl0l WHEN rrxpcsbypass_en = '1'  ELSE nli1il;
	wire_nl1l1O_dataout <= wire_nl1l0l_dataout AND NOT(niOOlOl);
	wire_nl1l1O_w_lg_dataout5768w(0) <= NOT wire_nl1l1O_dataout;
	wire_nl1lii_dataout <= wire_nl1liO_dataout AND NOT(niOOllO);
	wire_nl1lil_dataout <= nl001O WHEN niOOllO = '1'  ELSE wire_nl1lli_dataout;
	wire_nl1liO_dataout <= wire_nl1lll_dataout AND NOT(niOOlll);
	wire_nl1lli_dataout <= wire_nl1llO_dataout AND NOT(niOOlll);
	wire_nl1lll_dataout <= niOi0i WHEN rbytordplden = '1'  ELSE wire_nl1lOi_dataout;
	wire_nl1llO_dataout <= niOi0i WHEN rbytordplden = '1'  ELSE wire_nl1lOl_dataout;
	wire_nl1lOi_dataout <= (nl00Ol OR nl0iOO) WHEN rwa_6g_en = '1'  ELSE nl001l;
	wire_nl1lOl_dataout <= (nli11l OR nl0O1i) WHEN rwa_6g_en = '1'  ELSE nl001O;
	wire_nl1O_dataout <= wire_nlO000l_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(43);
	wire_nli_dataout <= invalid_code_delay(1) WHEN rinvalid_code_err_only = '1'  ELSE (disp_err_delay(1) OR invalid_code_delay(1));
	wire_nli_w_lg_dataout535w(0) <= wire_nli_dataout AND wire_w_lg_w_lg_rsync_sm_dis1w534w(0);
	wire_nli00O_dataout <= nli00l AND NOT(scan_mode);
	wire_nli00O_w_lg_dataout647w(0) <= NOT wire_nli00O_dataout;
	wire_nli01l_dataout <= nli1iO AND NOT(scan_mode);
	wire_nli01l_w_lg_dataout653w(0) <= NOT wire_nli01l_dataout;
	wire_nli0li_dataout <= wire_n1lOi_dataout WHEN niOOOil = '1'  ELSE nll0Oi;
	wire_nli0ll_dataout <= wire_n1lOl_dataout WHEN niOOOil = '1'  ELSE nll0Ol;
	wire_nli0lO_dataout <= wire_n1lOO_dataout WHEN niOOOil = '1'  ELSE nll0OO;
	wire_nli0Oi_dataout <= wire_n1O1i_dataout WHEN niOOOil = '1'  ELSE nlli1i;
	wire_nli0Ol_dataout <= wire_n1O1l_dataout WHEN niOOOil = '1'  ELSE nlli1l;
	wire_nli0OO_dataout <= wire_n1O1O_dataout WHEN niOOOil = '1'  ELSE nlli1O;
	wire_nli1li_dataout <= wire_nli1lO_dataout WHEN rmaster_rx = '1'  ELSE wire_nli1ll_dataout;
	wire_nli1ll_dataout <= wr_enable_quad_up WHEN rmaster_up_rx = '1'  ELSE wr_enable_quad_down;
	wire_nli1lO_dataout <= nl01li WHEN rindv_rx = '1'  ELSE wr_enable_centrl;
	wire_nli1Oi_dataout <= (nl01ll AND wire_nli1ii_w_lg_nl01Oi645w(0)) WHEN rrxphfifopldctl_en = '1'  ELSE nl01ll;
	wire_nlii_dataout <= wire_nlO00iO_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(47);
	wire_nlii0i_dataout <= wire_n1Oii_dataout WHEN niOOOil = '1'  ELSE nlliii;
	wire_nlii0l_dataout <= nlliil AND NOT(niOOOil);
	wire_nlii0O_dataout <= nlliiO AND NOT(niOOOil);
	wire_nlii1i_dataout <= wire_n1O0i_dataout WHEN niOOOil = '1'  ELSE nlli0i;
	wire_nlii1l_dataout <= wire_n1O0l_dataout WHEN niOOOil = '1'  ELSE nlli0l;
	wire_nlii1O_dataout <= wire_n1O0O_dataout WHEN niOOOil = '1'  ELSE nlli0O;
	wire_nliiii_dataout <= wire_n010i_dataout WHEN niOOOil = '1'  ELSE nllili;
	wire_nliiil_dataout <= nllill AND NOT(niOOOil);
	wire_nliiiO_dataout <= nllilO AND NOT(niOOOil);
	wire_nliili_dataout <= nlliOi AND NOT(niOOOil);
	wire_nliill_dataout <= wire_n1Oil_dataout WHEN niOOOil = '1'  ELSE nlliOl;
	wire_nliilO_dataout <= wire_n1OiO_dataout WHEN niOOOil = '1'  ELSE nlliOO;
	wire_nliiOi_dataout <= wire_n1Oli_dataout WHEN niOOOil = '1'  ELSE nlll1i;
	wire_nliiOl_dataout <= wire_n1Oll_dataout WHEN niOOOil = '1'  ELSE nlll1l;
	wire_nliiOO_dataout <= wire_n1OlO_dataout WHEN niOOOil = '1'  ELSE nlll1O;
	wire_nlil_dataout <= wire_nlO00li_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(48);
	wire_nlil0i_dataout <= wire_n011i_dataout WHEN niOOOil = '1'  ELSE nlllii;
	wire_nlil0l_dataout <= wire_n011l_dataout WHEN niOOOil = '1'  ELSE nlllil;
	wire_nlil0O_dataout <= nllliO AND NOT(niOOOil);
	wire_nlil1i_dataout <= wire_n1OOi_dataout WHEN niOOOil = '1'  ELSE nlll0i;
	wire_nlil1l_dataout <= wire_n1OOl_dataout WHEN niOOOil = '1'  ELSE nlll0l;
	wire_nlil1O_dataout <= wire_n1OOO_dataout WHEN niOOOil = '1'  ELSE nlll0O;
	wire_nlilii_dataout <= nlllli AND NOT(niOOOil);
	wire_nlilil_dataout <= wire_n010i_dataout WHEN niOOOil = '1'  ELSE nlllll;
	wire_nliliO_dataout <= nllllO AND NOT(niOOOil);
	wire_nlilli_dataout <= nlllOi AND NOT(niOOOil);
	wire_nlilll_dataout <= nlllOl AND NOT(niOOOil);
	wire_nlilOi_dataout <= dec_data_valid(0) WHEN nl101Ol = '1'  ELSE nli0iO;
	wire_nlilOi_w_lg_dataout523w(0) <= NOT wire_nlilOi_dataout;
	wire_nlilOl_dataout <= dec_data_valid(1) WHEN nl101Ol = '1'  ELSE nlilOO;
	wire_nlilOl_w_lg_dataout545w(0) <= NOT wire_nlilOl_dataout;
	wire_nliO_dataout <= wire_nlO00ll_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(49);
	wire_nliOl_dataout <= (nl101il AND nll1li) WHEN tenb_data(8) = '1'  ELSE (nl101il AND nll1Ol);
	wire_nlli_dataout <= wire_nlO00lO_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(50);
	wire_nlll_dataout <= wire_nlO00Oi_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(51);
	wire_nllO_dataout <= wire_nlO00Ol_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(52);
	wire_nlO0ill_dataout <= niliOi WHEN niOOliO = '1'  ELSE wire_nlOi0OO_dataout;
	wire_nlO0ilO_dataout <= niliOl WHEN niOOliO = '1'  ELSE wire_nlOii1i_dataout;
	wire_nlO0iOi_dataout <= niliOO WHEN niOOliO = '1'  ELSE wire_nlOii1l_dataout;
	wire_nlO0iOl_dataout <= nill1i WHEN niOOliO = '1'  ELSE wire_nlOii1O_dataout;
	wire_nlO0iOO_dataout <= nill1l WHEN niOOliO = '1'  ELSE wire_nlOii0i_dataout;
	wire_nlO0l0i_dataout <= nill0O WHEN niOOliO = '1'  ELSE wire_nlOiiil_dataout;
	wire_nlO0l0l_dataout <= nillii WHEN niOOliO = '1'  ELSE wire_nlOiiiO_dataout;
	wire_nlO0l0O_dataout <= nillil WHEN niOOliO = '1'  ELSE wire_nlOiili_dataout;
	wire_nlO0l1i_dataout <= nill1O WHEN niOOliO = '1'  ELSE wire_nlOii0l_dataout;
	wire_nlO0l1l_dataout <= nill0i WHEN niOOliO = '1'  ELSE wire_nlOii0O_dataout;
	wire_nlO0l1O_dataout <= nill0l WHEN niOOliO = '1'  ELSE wire_nlOiiii_dataout;
	wire_nlO0lii_dataout <= nilliO WHEN niOOliO = '1'  ELSE wire_nlOiill_dataout;
	wire_nlO0lil_dataout <= nillli WHEN niOOliO = '1'  ELSE wire_nlOiilO_dataout;
	wire_nlO0liO_dataout <= nillll WHEN niOOliO = '1'  ELSE wire_nlOiiOi_dataout;
	wire_nlO0lli_dataout <= nilllO WHEN niOOliO = '1'  ELSE wire_nlOiiOl_dataout;
	wire_nlO0lll_dataout <= nillOi WHEN niOOliO = '1'  ELSE wire_nlOiiOO_dataout;
	wire_nlO0llO_dataout <= wire_nlOl00l_dataout WHEN niOOliO = '1'  ELSE wire_nlOil1i_dataout;
	wire_nlO0lOi_dataout <= wire_nlOl00O_dataout WHEN niOOliO = '1'  ELSE wire_nlOil1l_dataout;
	wire_nlO0lOl_dataout <= wire_nlOl0ii_dataout WHEN niOOliO = '1'  ELSE wire_nlOil1O_dataout;
	wire_nlO0lOO_dataout <= wire_nlOl0il_dataout WHEN niOOliO = '1'  ELSE wire_nlOil0i_dataout;
	wire_nlO0O_dataout <= rxstatus_int(0) WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(67);
	wire_nlO0O0i_dataout <= wire_nlOl0lO_dataout WHEN niOOliO = '1'  ELSE wire_nlOilil_dataout;
	wire_nlO0O0l_dataout <= wire_nlOl0Oi_dataout WHEN niOOliO = '1'  ELSE wire_nlOiliO_dataout;
	wire_nlO0O0O_dataout <= wire_nlOl0Ol_dataout WHEN niOOliO = '1'  ELSE wire_nlOilli_dataout;
	wire_nlO0O1i_dataout <= wire_nlOl0iO_dataout WHEN niOOliO = '1'  ELSE wire_nlOil0l_dataout;
	wire_nlO0O1l_dataout <= wire_nlOl0li_dataout WHEN niOOliO = '1'  ELSE wire_nlOil0O_dataout;
	wire_nlO0O1O_dataout <= wire_nlOl0ll_dataout WHEN niOOliO = '1'  ELSE wire_nlOilii_dataout;
	wire_nlO0Oii_dataout <= wire_nlOl0OO_dataout WHEN niOOliO = '1'  ELSE wire_nlOilll_dataout;
	wire_nlO0Oil_dataout <= wire_nlOli1i_dataout WHEN niOOliO = '1'  ELSE wire_nlOillO_dataout;
	wire_nlO0OiO_dataout <= wire_nlOli1l_dataout WHEN niOOliO = '1'  ELSE wire_nlOilOi_dataout;
	wire_nlO0Oli_dataout <= wire_nlOli1O_dataout WHEN niOOliO = '1'  ELSE wire_nlOilOl_dataout;
	wire_nlO0Oll_dataout <= wire_nlOli0i_dataout WHEN niOOliO = '1'  ELSE wire_nlOilOO_dataout;
	wire_nlO0OlO_dataout <= wire_nlOli0l_dataout WHEN niOOliO = '1'  ELSE wire_nlOiO1i_dataout;
	wire_nlO0OOi_dataout <= wire_nlOli0O_dataout WHEN niOOliO = '1'  ELSE wire_nlOiO1l_dataout;
	wire_nlO0OOl_dataout <= wire_nlOliii_dataout WHEN niOOliO = '1'  ELSE wire_nlOiO1O_dataout;
	wire_nlO0OOO_dataout <= wire_nlOliil_dataout WHEN niOOliO = '1'  ELSE wire_nlOiO0i_dataout;
	wire_nlO1i0i_dataout <= wire_nlO1i0l_dataout AND nlO1ili;
	wire_nlO1i0l_dataout <= wire_nlO1iii_dataout WHEN rmaster_rx = '1'  ELSE wire_nlO1i0O_dataout;
	wire_nlO1i0O_dataout <= wire_w_lg_rx_we_in_quad_up4644w(0) WHEN rmaster_up_rx = '1'  ELSE wire_w_lg_rx_we_in_quad_down4643w(0);
	wire_nlO1iii_dataout <= wire_nlO1i1i_w_lg_nlO1i1l613w(0) WHEN rindv_rx = '1'  ELSE wire_w_lg_rx_we_in_centrl4642w(0);
	wire_nlO1iil_dataout <= wire_nlO1iiO_dataout AND nlO10Ol;
	wire_nlO1iiO_dataout <= nl010i OR nlO1ili;
	wire_nlO1ill_dataout <= wire_nlO1l1l_dataout WHEN (wire_w_lg_rwa_6g_en2w(0) AND rbytord_s2gx) = '1'  ELSE wire_nlO1ilO_dataout;
	wire_nlO1ilO_dataout <= wire_nlO1iOi_dataout AND NOT(niOlO1l);
	wire_nlO1iOi_dataout <= niiOiO OR niOlO1O;
	wire_nlO1l0i_dataout <= niiOiO OR (niOlO1O AND wire_n1ill_w_lg_n1i0i4636w(0));
	wire_nlO1l1l_dataout <= wire_nlO1ilO_dataout WHEN rbytordplden = '1'  ELSE wire_nlO1l1O_dataout;
	wire_nlO1l1O_dataout <= wire_nlO1l0i_dataout AND NOT(niOlO1l);
	wire_nlOi_dataout <= wire_nlO00OO_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(53);
	wire_nlOi00i_dataout <= wire_nlOlllO_dataout WHEN niOOliO = '1'  ELSE wire_nlOl1il_dataout;
	wire_nlOi00l_dataout <= wire_nlOllOi_dataout WHEN niOOliO = '1'  ELSE wire_nlOl1iO_dataout;
	wire_nlOi00O_dataout <= wire_nlOllOl_dataout WHEN niOOliO = '1'  ELSE wire_nlOl1li_dataout;
	wire_nlOi01i_dataout <= wire_nlOlliO_dataout WHEN niOOliO = '1'  ELSE wire_nlOl10l_dataout;
	wire_nlOi01l_dataout <= wire_nlOllli_dataout WHEN niOOliO = '1'  ELSE wire_nlOl10O_dataout;
	wire_nlOi01O_dataout <= wire_nlOllll_dataout WHEN niOOliO = '1'  ELSE wire_nlOl1ii_dataout;
	wire_nlOi0ii_dataout <= wire_nlOllOO_dataout WHEN niOOliO = '1'  ELSE wire_nlOl1ll_dataout;
	wire_nlOi0il_dataout <= wire_nlOlO1i_dataout WHEN niOOliO = '1'  ELSE wire_nlOl1lO_dataout;
	wire_nlOi0iO_dataout <= wire_nlOlO1l_dataout WHEN niOOliO = '1'  ELSE wire_nlOl1Oi_dataout;
	wire_nlOi0li_dataout <= wire_nlOlO1O_dataout WHEN niOOliO = '1'  ELSE wire_nlOl1Ol_dataout;
	wire_nlOi0ll_dataout <= wire_nlOlO0i_dataout WHEN niOOliO = '1'  ELSE wire_nlOl1OO_dataout;
	wire_nlOi0lO_dataout <= wire_nlOlO0l_dataout WHEN niOOliO = '1'  ELSE wire_nlOl01i_dataout;
	wire_nlOi0Oi_dataout <= wire_nlOlO0O_dataout WHEN niOOliO = '1'  ELSE wire_nlOl01l_dataout;
	wire_nlOi0Ol_dataout <= wire_nlOlOii_dataout WHEN niOOliO = '1'  ELSE wire_nlOl01O_dataout;
	wire_nlOi0OO_dataout <= nil1ll WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niliOi;
	wire_nlOi10i_dataout <= wire_nlOlilO_dataout WHEN niOOliO = '1'  ELSE wire_nlOiOil_dataout;
	wire_nlOi10l_dataout <= wire_nlOliOi_dataout WHEN niOOliO = '1'  ELSE wire_nlOiOiO_dataout;
	wire_nlOi10O_dataout <= wire_nlOliOl_dataout WHEN niOOliO = '1'  ELSE wire_nlOiOli_dataout;
	wire_nlOi11i_dataout <= wire_nlOliiO_dataout WHEN niOOliO = '1'  ELSE wire_nlOiO0l_dataout;
	wire_nlOi11l_dataout <= wire_nlOlili_dataout WHEN niOOliO = '1'  ELSE wire_nlOiO0O_dataout;
	wire_nlOi11O_dataout <= wire_nlOlill_dataout WHEN niOOliO = '1'  ELSE wire_nlOiOii_dataout;
	wire_nlOi1ii_dataout <= wire_nlOliOO_dataout WHEN niOOliO = '1'  ELSE wire_nlOiOll_dataout;
	wire_nlOi1il_dataout <= wire_nlOll1i_dataout WHEN niOOliO = '1'  ELSE wire_nlOiOlO_dataout;
	wire_nlOi1iO_dataout <= wire_nlOll1l_dataout WHEN niOOliO = '1'  ELSE wire_nlOiOOi_dataout;
	wire_nlOi1li_dataout <= wire_nlOll1O_dataout WHEN niOOliO = '1'  ELSE wire_nlOiOOl_dataout;
	wire_nlOi1ll_dataout <= wire_nlOll0i_dataout WHEN niOOliO = '1'  ELSE wire_nlOiOOO_dataout;
	wire_nlOi1lO_dataout <= wire_nlOll0l_dataout WHEN niOOliO = '1'  ELSE wire_nlOl11i_dataout;
	wire_nlOi1Oi_dataout <= wire_nlOll0O_dataout WHEN niOOliO = '1'  ELSE wire_nlOl11l_dataout;
	wire_nlOi1Ol_dataout <= wire_nlOllii_dataout WHEN niOOliO = '1'  ELSE wire_nlOl11O_dataout;
	wire_nlOi1OO_dataout <= wire_nlOllil_dataout WHEN niOOliO = '1'  ELSE wire_nlOl10i_dataout;
	wire_nlOii_dataout <= rxstatus_int(1) WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(68);
	wire_nlOii0i_dataout <= nil1OO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nill1l;
	wire_nlOii0l_dataout <= nil01i WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nill1O;
	wire_nlOii0O_dataout <= nil01l WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nill0i;
	wire_nlOii1i_dataout <= nil1lO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niliOl;
	wire_nlOii1l_dataout <= nil1Oi WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niliOO;
	wire_nlOii1O_dataout <= nil1Ol WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nill1i;
	wire_nlOiiii_dataout <= nil01O WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nill0l;
	wire_nlOiiil_dataout <= nil00i WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nill0O;
	wire_nlOiiiO_dataout <= nil00l WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nillii;
	wire_nlOiili_dataout <= nil00O WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nillil;
	wire_nlOiill_dataout <= nil0ii WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilliO;
	wire_nlOiilO_dataout <= nil0il WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nillli;
	wire_nlOiiOi_dataout <= nil0iO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nillll;
	wire_nlOiiOl_dataout <= nil0li WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilllO;
	wire_nlOiiOO_dataout <= nil0ll WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nillOi;
	wire_nlOil_dataout <= rxstatus_int(2) WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(69);
	wire_nlOil0i_dataout <= nil0OO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilO1l;
	wire_nlOil0l_dataout <= nili1i WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilO1O;
	wire_nlOil0O_dataout <= nili1l WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilO0i;
	wire_nlOil1i_dataout <= nil0lO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nillOl;
	wire_nlOil1l_dataout <= nil0Oi WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nillOO;
	wire_nlOil1O_dataout <= nil0Ol WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilO1i;
	wire_nlOilii_dataout <= nili1O WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilO0l;
	wire_nlOilil_dataout <= nili0i WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilO0O;
	wire_nlOiliO_dataout <= nili0l WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilOii;
	wire_nlOilli_dataout <= nili0O WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilOil;
	wire_nlOilll_dataout <= niliii WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilOiO;
	wire_nlOillO_dataout <= niliil WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilOli;
	wire_nlOilOi_dataout <= niliiO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilOll;
	wire_nlOilOl_dataout <= nilili WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilOlO;
	wire_nlOilOO_dataout <= nilill WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilOOi;
	wire_nlOiO_dataout <= rxvalid_int WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(66);
	wire_nlOiO0i_dataout <= niliOO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO11l;
	wire_nlOiO0l_dataout <= nill1i WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO11O;
	wire_nlOiO0O_dataout <= nill1l WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO10i;
	wire_nlOiO1i_dataout <= nililO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilOOl;
	wire_nlOiO1l_dataout <= niliOi WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE nilOOO;
	wire_nlOiO1O_dataout <= niliOl WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO11i;
	wire_nlOiOii_dataout <= nill1O WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO10l;
	wire_nlOiOil_dataout <= nill0i WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO10O;
	wire_nlOiOiO_dataout <= nill0l WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO1ii;
	wire_nlOiOli_dataout <= nill0O WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO1il;
	wire_nlOiOll_dataout <= nillii WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO1iO;
	wire_nlOiOlO_dataout <= nillil WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO1li;
	wire_nlOiOOi_dataout <= nilliO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO1ll;
	wire_nlOiOOl_dataout <= nillli WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO1lO;
	wire_nlOiOOO_dataout <= nillll WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO1Oi;
	wire_nlOl_dataout <= wire_nlO0i1i_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(54);
	wire_nlOl00l_dataout <= nillOl AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOl00O_dataout <= nillOO AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOl01i_dataout <= nilOlO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO0Ol;
	wire_nlOl01l_dataout <= nilOOi WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO0OO;
	wire_nlOl01O_dataout <= nilOOl WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niOi1i;
	wire_nlOl0ii_dataout <= nilO1i AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOl0il_dataout <= nilO1l AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOl0iO_dataout <= nilO1O AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOl0li_dataout <= nilO0i AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOl0ll_dataout <= nilO0l AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOl0lO_dataout <= nilO0O AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOl0Oi_dataout <= nilOii AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOl0Ol_dataout <= nilOil AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOl0OO_dataout <= nilOiO AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOl10i_dataout <= nillOO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO01l;
	wire_nlOl10l_dataout <= nilO1i WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO01O;
	wire_nlOl10O_dataout <= nilO1l WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO00i;
	wire_nlOl11i_dataout <= nilllO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO1Ol;
	wire_nlOl11l_dataout <= nillOi WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO1OO;
	wire_nlOl11O_dataout <= nillOl WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO01i;
	wire_nlOl1ii_dataout <= nilO1O WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO00l;
	wire_nlOl1il_dataout <= nilO0i WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO00O;
	wire_nlOl1iO_dataout <= nilO0l WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO0ii;
	wire_nlOl1li_dataout <= nilO0O WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO0il;
	wire_nlOl1ll_dataout <= nilOii WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO0iO;
	wire_nlOl1lO_dataout <= nilOil WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO0li;
	wire_nlOl1Oi_dataout <= nilOiO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO0ll;
	wire_nlOl1Ol_dataout <= nilOli WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO0lO;
	wire_nlOl1OO_dataout <= nilOll WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE niO0Oi;
	wire_nlOli_dataout <= phystatus_int WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(65);
	wire_nlOli0i_dataout <= nilOOi AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOli0l_dataout <= nilOOl AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOli0O_dataout <= rbytordpadval(0) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE nilOOO;
	wire_nlOli1i_dataout <= nilOli AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOli1l_dataout <= nilOll AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOli1O_dataout <= nilOlO AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOlii_dataout <= nl1111O WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nliO1l;
	wire_nlOliii_dataout <= rbytordpadval(1) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE niO11i;
	wire_nlOliil_dataout <= rbytordpadval(2) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE niO11l;
	wire_nlOliiO_dataout <= rbytordpadval(3) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE niO11O;
	wire_nlOlil_dataout <= wire_n1lOi_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlllOO;
	wire_nlOlili_dataout <= rbytordpadval(4) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE niO10i;
	wire_nlOlill_dataout <= rbytordpadval(5) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE niO10l;
	wire_nlOlilO_dataout <= rbytordpadval(6) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE niO10O;
	wire_nlOliO_dataout <= wire_n1lOl_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nllO1i;
	wire_nlOliOi_dataout <= rbytordpadval(7) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE niO1ii;
	wire_nlOliOl_dataout <= rbytordpadval(8) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE niO1il;
	wire_nlOliOO_dataout <= rbytordpadval(9) WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE niO1iO;
	wire_nlOll_dataout <= wire_nlO1ill_dataout WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(64);
	wire_nlOll0i_dataout <= niO1Oi AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOll0l_dataout <= niO1Ol AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOll0O_dataout <= niO1OO AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOll1i_dataout <= nillil WHEN wire_w_lg_niOlO0l3797w(0) = '1'  ELSE niO1li;
	wire_nlOll1l_dataout <= niO1ll AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOll1O_dataout <= niO1lO AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOlli_dataout <= wire_n1lOO_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nllO1l;
	wire_nlOllii_dataout <= niO01i AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOllil_dataout <= niO01l AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOlliO_dataout <= niO01O AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOlll_dataout <= wire_n1O1i_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nllO1O;
	wire_nlOllli_dataout <= niO00i AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOllll_dataout <= niO00l AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOlllO_dataout <= niO00O AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOllO_dataout <= wire_n1O1l_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nllO0i;
	wire_nlOllOi_dataout <= niO0ii AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOllOl_dataout <= niO0il AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOllOO_dataout <= niO0iO AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOlO_dataout <= wire_nlO001O_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(41);
	wire_nlOlO0i_dataout <= niO0Oi AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOlO0l_dataout <= niO0Ol AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOlO0O_dataout <= niO0OO AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOlO1i_dataout <= niO0li AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOlO1l_dataout <= niO0ll AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOlO1O_dataout <= niO0lO AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOlOi_dataout <= wire_n1O1O_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nllO0l;
	wire_nlOlOii_dataout <= niOi1i AND NOT(wire_w_lg_niOlO0l3797w(0));
	wire_nlOlOiO_dataout <= wire_niOlOl_dataout WHEN niOOliO = '1'  ELSE wire_nlOOlOi_dataout;
	wire_nlOlOl_dataout <= wire_n1O0i_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nllO0O;
	wire_nlOlOli_dataout <= wire_niOlOO_dataout WHEN niOOliO = '1'  ELSE wire_nlOOlOl_dataout;
	wire_nlOlOll_dataout <= wire_niOO1i_dataout WHEN niOOliO = '1'  ELSE wire_nlOOlOO_dataout;
	wire_nlOlOlO_dataout <= wire_niOO1l_dataout WHEN niOOliO = '1'  ELSE wire_nlOOO1i_dataout;
	wire_nlOlOO_dataout <= wire_n1O0l_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nllOii;
	wire_nlOlOOi_dataout <= wire_niOO1O_dataout WHEN niOOliO = '1'  ELSE wire_nlOOO1l_dataout;
	wire_nlOlOOl_dataout <= wire_niOO0i_dataout WHEN niOOliO = '1'  ELSE wire_nlOOO1O_dataout;
	wire_nlOlOOO_dataout <= wire_niOO0l_dataout WHEN niOOliO = '1'  ELSE wire_nlOOO0i_dataout;
	wire_nlOO_dataout <= wire_nlO0i1l_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(55);
	wire_nlOO00i_dataout <= wire_n11lll_dataout WHEN niOOliO = '1'  ELSE wire_n111il_dataout;
	wire_nlOO00l_dataout <= wire_n11llO_dataout WHEN niOOliO = '1'  ELSE wire_n111iO_dataout;
	wire_nlOO00O_dataout <= wire_n11lOi_dataout WHEN niOOliO = '1'  ELSE wire_n111li_dataout;
	wire_nlOO01i_dataout <= wire_n11lil_dataout WHEN niOOliO = '1'  ELSE wire_n1110l_dataout;
	wire_nlOO01l_dataout <= wire_n11liO_dataout WHEN niOOliO = '1'  ELSE wire_n1110O_dataout;
	wire_nlOO01O_dataout <= wire_n11lli_dataout WHEN niOOliO = '1'  ELSE wire_n111ii_dataout;
	wire_nlOO0i_dataout <= wire_n01ll_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nllOll;
	wire_nlOO0ii_dataout <= wire_n11lOl_dataout WHEN niOOliO = '1'  ELSE wire_n111ll_dataout;
	wire_nlOO0il_dataout <= wire_n11lOO_dataout WHEN niOOliO = '1'  ELSE wire_n111lO_dataout;
	wire_nlOO0iO_dataout <= wire_n11O1i_dataout WHEN niOOliO = '1'  ELSE wire_n111Oi_dataout;
	wire_nlOO0l_dataout <= wire_n011O_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nllOlO;
	wire_nlOO0li_dataout <= wire_n11O1l_dataout WHEN niOOliO = '1'  ELSE wire_n111Ol_dataout;
	wire_nlOO0ll_dataout <= wire_n11O1O_dataout WHEN niOOliO = '1'  ELSE wire_n111OO_dataout;
	wire_nlOO0lO_dataout <= wire_n11O0i_dataout WHEN niOOliO = '1'  ELSE wire_n1101i_dataout;
	wire_nlOO0O_dataout <= wire_n010l_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nllOOi;
	wire_nlOO0Oi_dataout <= wire_n11O0l_dataout WHEN niOOliO = '1'  ELSE wire_n1101l_dataout;
	wire_nlOO0Ol_dataout <= wire_n11O0O_dataout WHEN niOOliO = '1'  ELSE wire_n1101O_dataout;
	wire_nlOO0OO_dataout <= wire_n11Oii_dataout WHEN niOOliO = '1'  ELSE wire_n1100i_dataout;
	wire_nlOO10i_dataout <= wire_niOOiO_dataout WHEN niOOliO = '1'  ELSE wire_nlOOOil_dataout;
	wire_nlOO10l_dataout <= wire_niOOli_dataout WHEN niOOliO = '1'  ELSE wire_nlOOOiO_dataout;
	wire_nlOO10O_dataout <= wire_niOOll_dataout WHEN niOOliO = '1'  ELSE wire_nlOOOli_dataout;
	wire_nlOO11i_dataout <= wire_niOO0O_dataout WHEN niOOliO = '1'  ELSE wire_nlOOO0l_dataout;
	wire_nlOO11l_dataout <= wire_niOOii_dataout WHEN niOOliO = '1'  ELSE wire_nlOOO0O_dataout;
	wire_nlOO11O_dataout <= wire_niOOil_dataout WHEN niOOliO = '1'  ELSE wire_nlOOOii_dataout;
	wire_nlOO1i_dataout <= wire_n1O0O_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nllOil;
	wire_nlOO1ii_dataout <= wire_niOOlO_dataout WHEN niOOliO = '1'  ELSE wire_nlOOOll_dataout;
	wire_nlOO1il_dataout <= wire_niOOOi_dataout WHEN niOOliO = '1'  ELSE wire_nlOOOlO_dataout;
	wire_nlOO1iO_dataout <= wire_niOOOl_dataout WHEN niOOliO = '1'  ELSE wire_nlOOOOi_dataout;
	wire_nlOO1l_dataout <= wire_n1Oii_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nllOiO;
	wire_nlOO1li_dataout <= wire_n11l1l_dataout WHEN niOOliO = '1'  ELSE wire_nlOOOOl_dataout;
	wire_nlOO1ll_dataout <= wire_n11l1O_dataout WHEN niOOliO = '1'  ELSE wire_nlOOOOO_dataout;
	wire_nlOO1lO_dataout <= wire_n11l0i_dataout WHEN niOOliO = '1'  ELSE wire_n1111i_dataout;
	wire_nlOO1O_dataout <= wire_n01Oi_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nllOli;
	wire_nlOO1Oi_dataout <= wire_n11l0l_dataout WHEN niOOliO = '1'  ELSE wire_n1111l_dataout;
	wire_nlOO1Ol_dataout <= wire_n11l0O_dataout WHEN niOOliO = '1'  ELSE wire_n1111O_dataout;
	wire_nlOO1OO_dataout <= wire_n11lii_dataout WHEN niOOliO = '1'  ELSE wire_n1110i_dataout;
	wire_nlOOi_dataout <= wire_nlO0i0i_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(57);
	wire_nlOOi0i_dataout <= wire_n11Oll_dataout WHEN niOOliO = '1'  ELSE wire_n110il_dataout;
	wire_nlOOi0l_dataout <= wire_n11OlO_dataout WHEN niOOliO = '1'  ELSE wire_n110iO_dataout;
	wire_nlOOi0O_dataout <= wire_n11OOi_dataout WHEN niOOliO = '1'  ELSE wire_n110li_dataout;
	wire_nlOOi1i_dataout <= wire_n11Oil_dataout WHEN niOOliO = '1'  ELSE wire_n1100l_dataout;
	wire_nlOOi1l_dataout <= wire_n11OiO_dataout WHEN niOOliO = '1'  ELSE wire_n1100O_dataout;
	wire_nlOOi1O_dataout <= wire_n11Oli_dataout WHEN niOOliO = '1'  ELSE wire_n110ii_dataout;
	wire_nlOOii_dataout <= wire_n010O_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nllOOl;
	wire_nlOOiii_dataout <= wire_n11OOl_dataout WHEN niOOliO = '1'  ELSE wire_n110ll_dataout;
	wire_nlOOiil_dataout <= wire_n11OOO_dataout WHEN niOOliO = '1'  ELSE wire_n110lO_dataout;
	wire_nlOOiiO_dataout <= wire_n1011i_dataout WHEN niOOliO = '1'  ELSE wire_n110Oi_dataout;
	wire_nlOOil_dataout <= wire_n01iO_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nllOOO;
	wire_nlOOili_dataout <= wire_n1011l_dataout WHEN niOOliO = '1'  ELSE wire_n110Ol_dataout;
	wire_nlOOill_dataout <= wire_n1011O_dataout WHEN niOOliO = '1'  ELSE wire_n110OO_dataout;
	wire_nlOOilO_dataout <= wire_n1010i_dataout WHEN niOOliO = '1'  ELSE wire_n11i1i_dataout;
	wire_nlOOiO_dataout <= wire_n1Oil_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO11i;
	wire_nlOOiOi_dataout <= wire_n1010l_dataout WHEN niOOliO = '1'  ELSE wire_n11i1l_dataout;
	wire_nlOOiOl_dataout <= wire_n1010O_dataout WHEN niOOliO = '1'  ELSE wire_n11i1O_dataout;
	wire_nlOOiOO_dataout <= wire_n101ii_dataout WHEN niOOliO = '1'  ELSE wire_n11i0i_dataout;
	wire_nlOOl_dataout <= wire_nlO1O1i_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(9);
	wire_nlOOl0i_dataout <= wire_n101ll_dataout WHEN niOOliO = '1'  ELSE wire_n11iil_dataout;
	wire_nlOOl0l_dataout <= wire_n101lO_dataout WHEN niOOliO = '1'  ELSE wire_n11iiO_dataout;
	wire_nlOOl0O_dataout <= wire_n101Oi_dataout WHEN niOOliO = '1'  ELSE wire_n11ili_dataout;
	wire_nlOOl1i_dataout <= wire_n101il_dataout WHEN niOOliO = '1'  ELSE wire_n11i0l_dataout;
	wire_nlOOl1l_dataout <= wire_n101iO_dataout WHEN niOOliO = '1'  ELSE wire_n11i0O_dataout;
	wire_nlOOl1O_dataout <= wire_n101li_dataout WHEN niOOliO = '1'  ELSE wire_n11iii_dataout;
	wire_nlOOli_dataout <= wire_n1OiO_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO11l;
	wire_nlOOlii_dataout <= wire_n101Ol_dataout WHEN niOOliO = '1'  ELSE wire_n11ill_dataout;
	wire_nlOOlil_dataout <= wire_n101OO_dataout WHEN niOOliO = '1'  ELSE wire_n11ilO_dataout;
	wire_nlOOliO_dataout <= wire_n1001i_dataout WHEN niOOliO = '1'  ELSE wire_n11iOi_dataout;
	wire_nlOOll_dataout <= wire_n1Oli_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO11O;
	wire_nlOOlli_dataout <= wire_n1001l_dataout WHEN niOOliO = '1'  ELSE wire_n11iOl_dataout;
	wire_nlOOlll_dataout <= wire_n1001O_dataout WHEN niOOliO = '1'  ELSE wire_n11iOO_dataout;
	wire_nlOOllO_dataout <= wire_n1000i_dataout WHEN niOOliO = '1'  ELSE wire_n11l1i_dataout;
	wire_nlOOlO_dataout <= wire_n1Oll_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO10i;
	wire_nlOOlOi_dataout <= nilOOO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOlOl_dataout;
	wire_nlOOlOl_dataout <= niO11i WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOlOO_dataout;
	wire_nlOOlOO_dataout <= niO11l WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOO1i_dataout;
	wire_nlOOO_dataout <= wire_nlO011l_o WHEN rrxfifo_dis = '1'  ELSE wire_nl1000i_data_out(25);
	wire_nlOOO0i_dataout <= niO10O WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOO0l_dataout;
	wire_nlOOO0l_dataout <= niO1ii WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOO0O_dataout;
	wire_nlOOO0O_dataout <= niO1il WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOOii_dataout;
	wire_nlOOO1i_dataout <= niO11O WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOO1l_dataout;
	wire_nlOOO1l_dataout <= niO10i WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOO1O_dataout;
	wire_nlOOO1O_dataout <= niO10l WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOO0i_dataout;
	wire_nlOOOi_dataout <= wire_n1OlO_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO10l;
	wire_nlOOOii_dataout <= niO1iO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOOil_dataout;
	wire_nlOOOil_dataout <= niO1li WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOOiO_dataout;
	wire_nlOOOiO_dataout <= niO1ll WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOOli_dataout;
	wire_nlOOOl_dataout <= wire_n1OOi_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO10O;
	wire_nlOOOli_dataout <= niO1lO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOOll_dataout;
	wire_nlOOOll_dataout <= niO1Oi WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOOlO_dataout;
	wire_nlOOOlO_dataout <= niO1Ol WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOOOi_dataout;
	wire_nlOOOO_dataout <= wire_n1OOl_dataout WHEN wire_w_lg_nl1110l617w(0) = '1'  ELSE nlO1ii;
	wire_nlOOOOi_dataout <= niO1OO WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOOOl_dataout;
	wire_nlOOOOl_dataout <= niO01i WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_niOOOO_dataout;
	wire_nlOOOOO_dataout <= niO01l WHEN wire_w_lg_niOlO0i3798w(0) = '1'  ELSE wire_nl111i_dataout;
	wire_n0iO0O_i <= ( wire_ni1lli_dataout & wire_ni1liO_dataout);
	n0iO0O :  oper_decoder
	  GENERIC MAP (
		width_i => 2,
		width_o => 4
	  )
	  PORT MAP ( 
		i => wire_n0iO0O_i,
		o => wire_n0iO0O_o
	  );
	wire_n0l0lO_i <= ( wire_ni1llO_dataout & wire_ni1lll_dataout & wire_ni1lli_dataout & wire_ni1liO_dataout);
	n0l0lO :  oper_decoder
	  GENERIC MAP (
		width_i => 4,
		width_o => 16
	  )
	  PORT MAP ( 
		i => wire_n0l0lO_i,
		o => wire_n0l0lO_o
	  );
	wire_n0l1iO_i <= ( wire_ni1lll_dataout & wire_ni1lli_dataout & wire_ni1liO_dataout);
	n0l1iO :  oper_decoder
	  GENERIC MAP (
		width_i => 3,
		width_o => 8
	  )
	  PORT MAP ( 
		i => wire_n0l1iO_i,
		o => wire_n0l1iO_o
	  );
	wire_niOOi_w_lg_w_o_range432w434w(0) <= wire_niOOi_w_o_range432w(0) OR wire_niOOi_w_o_range433w(0);
	wire_niOOi_w_lg_w_o_range437w439w(0) <= wire_niOOi_w_o_range437w(0) OR wire_niOOi_w_o_range438w(0);
	wire_niOOi_w_lg_w_o_range441w443w(0) <= wire_niOOi_w_o_range441w(0) OR wire_niOOi_w_o_range442w(0);
	wire_niOOi_w_lg_w_o_range445w447w(0) <= wire_niOOi_w_o_range445w(0) OR wire_niOOi_w_o_range446w(0);
	wire_niOOi_w_lg_w_o_range449w451w(0) <= wire_niOOi_w_o_range449w(0) OR wire_niOOi_w_o_range450w(0);
	wire_niOOi_w_lg_w_o_range453w455w(0) <= wire_niOOi_w_o_range453w(0) OR wire_niOOi_w_o_range454w(0);
	wire_niOOi_w_lg_w_o_range457w459w(0) <= wire_niOOi_w_o_range457w(0) OR wire_niOOi_w_o_range458w(0);
	wire_niOOi_w_lg_w_o_range461w463w(0) <= wire_niOOi_w_o_range461w(0) OR wire_niOOi_w_o_range462w(0);
	wire_niOOi_w_lg_w_o_range465w467w(0) <= wire_niOOi_w_o_range465w(0) OR wire_niOOi_w_o_range466w(0);
	wire_niOOi_i <= ( rwa_6g_en & rpmadatawidth & rsync_comp_size(2 DOWNTO 0) & tenb_data(18));
	wire_niOOi_w_o_range433w(0) <= wire_niOOi_o(16);
	wire_niOOi_w_o_range432w(0) <= wire_niOOi_o(17);
	wire_niOOi_w_o_range438w(0) <= wire_niOOi_o(20);
	wire_niOOi_w_o_range437w(0) <= wire_niOOi_o(21);
	wire_niOOi_w_o_range442w(0) <= wire_niOOi_o(34);
	wire_niOOi_w_o_range441w(0) <= wire_niOOi_o(35);
	wire_niOOi_w_o_range446w(0) <= wire_niOOi_o(38);
	wire_niOOi_w_o_range445w(0) <= wire_niOOi_o(39);
	wire_niOOi_w_o_range450w(0) <= wire_niOOi_o(42);
	wire_niOOi_w_o_range449w(0) <= wire_niOOi_o(43);
	wire_niOOi_w_o_range454w(0) <= wire_niOOi_o(48);
	wire_niOOi_w_o_range453w(0) <= wire_niOOi_o(49);
	wire_niOOi_w_o_range458w(0) <= wire_niOOi_o(52);
	wire_niOOi_w_o_range457w(0) <= wire_niOOi_o(53);
	wire_niOOi_w_o_range462w(0) <= wire_niOOi_o(56);
	wire_niOOi_w_o_range461w(0) <= wire_niOOi_o(57);
	wire_niOOi_w_o_range466w(0) <= wire_niOOi_o(60);
	wire_niOOi_w_o_range465w(0) <= wire_niOOi_o(61);
	niOOi :  oper_decoder
	  GENERIC MAP (
		width_i => 6,
		width_o => 64
	  )
	  PORT MAP ( 
		i => wire_niOOi_i,
		o => wire_niOOi_o
	  );
	wire_nliOi_w_lg_w_lg_w_o_range217w219w223w(0) <= wire_nliOi_w_lg_w_o_range217w219w(0) OR wire_nl1011i16_w_lg_w_lg_q221w222w(0);
	wire_nliOi_w_lg_w_lg_w_o_range235w237w241w(0) <= wire_nliOi_w_lg_w_o_range235w237w(0) OR wire_nl11OOi20_w_lg_w_lg_q239w240w(0);
	wire_nliOi_w_lg_w_lg_w_o_range253w255w259w(0) <= wire_nliOi_w_lg_w_o_range253w255w(0) OR wire_nl11Oli24_w_lg_w_lg_q257w258w(0);
	wire_nliOi_w_lg_w_o_range206w208w(0) <= wire_nliOi_w_o_range206w(0) OR wire_nliOi_w_o_range207w(0);
	wire_nliOi_w_lg_w_o_range211w213w(0) <= wire_nliOi_w_o_range211w(0) OR wire_nliOi_w_o_range212w(0);
	wire_nliOi_w_lg_w_o_range217w219w(0) <= wire_nliOi_w_o_range217w(0) OR wire_nliOi_w_o_range218w(0);
	wire_nliOi_w_lg_w_o_range225w227w(0) <= wire_nliOi_w_o_range225w(0) OR wire_nliOi_w_o_range226w(0);
	wire_nliOi_w_lg_w_o_range231w233w(0) <= wire_nliOi_w_o_range231w(0) OR wire_nliOi_w_o_range232w(0);
	wire_nliOi_w_lg_w_o_range235w237w(0) <= wire_nliOi_w_o_range235w(0) OR wire_nliOi_w_o_range236w(0);
	wire_nliOi_w_lg_w_o_range245w247w(0) <= wire_nliOi_w_o_range245w(0) OR wire_nliOi_w_o_range246w(0);
	wire_nliOi_w_lg_w_o_range249w251w(0) <= wire_nliOi_w_o_range249w(0) OR wire_nliOi_w_o_range250w(0);
	wire_nliOi_w_lg_w_o_range253w255w(0) <= wire_nliOi_w_o_range253w(0) OR wire_nliOi_w_o_range254w(0);
	wire_nliOi_i <= ( rwa_6g_en & wire_nl1010l12_w_lg_w_lg_q111w112w & rsync_comp_size(2) & wire_nl1010O10_w_lg_w_lg_q106w107w & wire_nl101ii8_w_lg_w_lg_q102w103w & tenb_data(8));
	wire_nliOi_w_o_range207w(0) <= wire_nliOi_o(16);
	wire_nliOi_w_o_range206w(0) <= wire_nliOi_o(17);
	wire_nliOi_w_o_range212w(0) <= wire_nliOi_o(20);
	wire_nliOi_w_o_range211w(0) <= wire_nliOi_o(21);
	wire_nliOi_w_o_range218w(0) <= wire_nliOi_o(34);
	wire_nliOi_w_o_range217w(0) <= wire_nliOi_o(35);
	wire_nliOi_w_o_range226w(0) <= wire_nliOi_o(38);
	wire_nliOi_w_o_range225w(0) <= wire_nliOi_o(39);
	wire_nliOi_w_o_range232w(0) <= wire_nliOi_o(42);
	wire_nliOi_w_o_range231w(0) <= wire_nliOi_o(43);
	wire_nliOi_w_o_range236w(0) <= wire_nliOi_o(48);
	wire_nliOi_w_o_range235w(0) <= wire_nliOi_o(49);
	wire_nliOi_w_o_range246w(0) <= wire_nliOi_o(52);
	wire_nliOi_w_o_range245w(0) <= wire_nliOi_o(53);
	wire_nliOi_w_o_range250w(0) <= wire_nliOi_o(56);
	wire_nliOi_w_o_range249w(0) <= wire_nliOi_o(57);
	wire_nliOi_w_o_range254w(0) <= wire_nliOi_o(60);
	wire_nliOi_w_o_range253w(0) <= wire_nliOi_o(61);
	nliOi :  oper_decoder
	  GENERIC MAP (
		width_i => 6,
		width_o => 64
	  )
	  PORT MAP ( 
		i => wire_nliOi_i,
		o => wire_nliOi_o
	  );
	wire_n00O0i_data <= ( nill1i & niiOOi & nill1i & nil1Ol & nill1i & niiOOi & nill1i & nil0OO & nill1i & niiOOi & nill1i & nil1Ol & nill1i & niiOOi & nill1i & nill1i);
	wire_n00O0i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n00O0i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n00O0i_data,
		o => wire_n00O0i_o,
		sel => wire_n00O0i_sel
	  );
	wire_n00O0l_data <= ( nill1l & niiOOl & nill1l & nil1OO & nill1l & niiOOl & nill1l & nili1i & nill1l & niiOOl & nill1l & nil1OO & nill1l & niiOOl & nill1l & nill1l);
	wire_n00O0l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n00O0l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n00O0l_data,
		o => wire_n00O0l_o,
		sel => wire_n00O0l_sel
	  );
	wire_n00O0O_data <= ( nill1O & niiOOO & nill1O & nil01i & nill1O & niiOOO & nill1O & nili1l & nill1O & niiOOO & nill1O & nil01i & nill1O & niiOOO & nill1O & nill1O);
	wire_n00O0O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n00O0O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n00O0O_data,
		o => wire_n00O0O_o,
		sel => wire_n00O0O_sel
	  );
	wire_n00O1i_data <= ( niliOi & niiOli & niliOi & nil1ll & niliOi & niiOli & niliOi & nil0lO & niliOi & niiOli & niliOi & nil1ll & niliOi & niiOli & niliOi & niliOi);
	wire_n00O1i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n00O1i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n00O1i_data,
		o => wire_n00O1i_o,
		sel => wire_n00O1i_sel
	  );
	wire_n00O1l_data <= ( niliOl & niiOll & niliOl & nil1lO & niliOl & niiOll & niliOl & nil0Oi & niliOl & niiOll & niliOl & nil1lO & niliOl & niiOll & niliOl & niliOl);
	wire_n00O1l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n00O1l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n00O1l_data,
		o => wire_n00O1l_o,
		sel => wire_n00O1l_sel
	  );
	wire_n00O1O_data <= ( niliOO & niiOlO & niliOO & nil1Oi & niliOO & niiOlO & niliOO & nil0Ol & niliOO & niiOlO & niliOO & nil1Oi & niliOO & niiOlO & niliOO & niliOO);
	wire_n00O1O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n00O1O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n00O1O_data,
		o => wire_n00O1O_o,
		sel => wire_n00O1O_sel
	  );
	wire_n00Oii_data <= ( nill0i & nil11i & nill0i & nil01l & nill0i & nil11i & nill0i & nili1O & nill0i & nil11i & nill0i & nil01l & nill0i & nil11i & nill0i & nill0i);
	wire_n00Oii_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n00Oii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n00Oii_data,
		o => wire_n00Oii_o,
		sel => wire_n00Oii_sel
	  );
	wire_n00Oil_data <= ( nill0l & nil11l & nill0l & nil01O & nill0l & nil11l & nill0l & nili0i & nill0l & nil11l & nill0l & nil01O & nill0l & nil11l & nill0l & nill0l);
	wire_n00Oil_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n00Oil :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n00Oil_data,
		o => wire_n00Oil_o,
		sel => wire_n00Oil_sel
	  );
	wire_n00OiO_data <= ( nill0O & nil11O & nill0O & nil00i & nill0O & nil11O & nill0O & nili0l & nill0O & nil11O & nill0O & nil00i & nill0O & nil11O & nill0O & nill0O);
	wire_n00OiO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n00OiO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n00OiO_data,
		o => wire_n00OiO_o,
		sel => wire_n00OiO_sel
	  );
	wire_n00Oli_data <= ( nillii & nil10i & nillii & nil00l & nillii & nil10i & nillii & nili0O & nillii & nil10i & nillii & nil00l & nillii & nil10i & nillii & nillii);
	wire_n00Oli_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n00Oli :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n00Oli_data,
		o => wire_n00Oli_o,
		sel => wire_n00Oli_sel
	  );
	wire_n00Oll_data <= ( nillil & nil10l & nillil & nil00O & nillil & nil10l & nillil & niliii & nillil & nil10l & nillil & nil00O & nillil & nil10l & nillil & nillil);
	wire_n00Oll_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n00Oll :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n00Oll_data,
		o => wire_n00Oll_o,
		sel => wire_n00Oll_sel
	  );
	wire_n00OlO_data <= ( nilliO & nil10O & nilliO & nil0ii & nilliO & nil10O & nilliO & niliil & nilliO & nil10O & nilliO & nil0ii & nilliO & nil10O & nilliO & nilliO);
	wire_n00OlO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n00OlO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n00OlO_data,
		o => wire_n00OlO_o,
		sel => wire_n00OlO_sel
	  );
	wire_n00OOi_data <= ( nillli & nil1ii & nillli & nil0il & nillli & nil1ii & nillli & niliiO & nillli & nil1ii & nillli & nil0il & nillli & nil1ii & nillli & nillli);
	wire_n00OOi_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n00OOi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n00OOi_data,
		o => wire_n00OOi_o,
		sel => wire_n00OOi_sel
	  );
	wire_n00OOl_data <= ( nillll & nil1il & nillll & nil0iO & nillll & nil1il & nillll & nilili & nillll & nil1il & nillll & nil0iO & nillll & nil1il & nillll & nillll);
	wire_n00OOl_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n00OOl :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n00OOl_data,
		o => wire_n00OOl_o,
		sel => wire_n00OOl_sel
	  );
	wire_n00OOO_data <= ( nilllO & nil1iO & nilllO & nil0li & nilllO & nil1iO & nilllO & nilill & nilllO & nil1iO & nilllO & nil0li & nilllO & nil1iO & nilllO & nilllO);
	wire_n00OOO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n00OOO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n00OOO_data,
		o => wire_n00OOO_o,
		sel => wire_n00OOO_sel
	  );
	wire_n0i00i_data <= ( niO11i & nil0Oi & niO11i & niliOl & niO11i & nil0Oi & niO11i & nillOO & niO11i & nil0Oi & niO11i & niliOl & niO11i & nil0Oi & niO11i & niO11i);
	wire_n0i00i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i00i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i00i_data,
		o => wire_n0i00i_o,
		sel => wire_n0i00i_sel
	  );
	wire_n0i00l_data <= ( niO11l & nil0Ol & niO11l & niliOO & niO11l & nil0Ol & niO11l & nilO1i & niO11l & nil0Ol & niO11l & niliOO & niO11l & nil0Ol & niO11l & niO11l);
	wire_n0i00l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i00l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i00l_data,
		o => wire_n0i00l_o,
		sel => wire_n0i00l_sel
	  );
	wire_n0i00O_data <= ( niO11O & nil0OO & niO11O & nill1i & niO11O & nil0OO & niO11O & nilO1l & niO11O & nil0OO & niO11O & nill1i & niO11O & nil0OO & niO11O & niO11O);
	wire_n0i00O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i00O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i00O_data,
		o => wire_n0i00O_o,
		sel => wire_n0i00O_sel
	  );
	wire_n0i01i_data <= ( nilOOi & nil0li & nilOOi & nilill & nilOOi & nil0li & nilOOi & nilllO & nilOOi & nil0li & nilOOi & nilill & nilOOi & nil0li & nilOOi & nilOOi);
	wire_n0i01i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i01i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i01i_data,
		o => wire_n0i01i_o,
		sel => wire_n0i01i_sel
	  );
	wire_n0i01l_data <= ( nilOOl & nil0ll & nilOOl & nililO & nilOOl & nil0ll & nilOOl & nillOi & nilOOl & nil0ll & nilOOl & nililO & nilOOl & nil0ll & nilOOl & nilOOl);
	wire_n0i01l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i01l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i01l_data,
		o => wire_n0i01l_o,
		sel => wire_n0i01l_sel
	  );
	wire_n0i01O_data <= ( nilOOO & nil0lO & nilOOO & niliOi & nilOOO & nil0lO & nilOOO & nillOl & nilOOO & nil0lO & nilOOO & niliOi & nilOOO & nil0lO & nilOOO & nilOOO);
	wire_n0i01O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i01O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i01O_data,
		o => wire_n0i01O_o,
		sel => wire_n0i01O_sel
	  );
	wire_n0i0ii_data <= ( niO10i & nili1i & niO10i & nill1l & niO10i & nili1i & niO10i & nilO1O & niO10i & nili1i & niO10i & nill1l & niO10i & nili1i & niO10i & niO10i);
	wire_n0i0ii_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i0ii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i0ii_data,
		o => wire_n0i0ii_o,
		sel => wire_n0i0ii_sel
	  );
	wire_n0i0il_data <= ( niO10l & nili1l & niO10l & nill1O & niO10l & nili1l & niO10l & nilO0i & niO10l & nili1l & niO10l & nill1O & niO10l & nili1l & niO10l & niO10l);
	wire_n0i0il_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i0il :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i0il_data,
		o => wire_n0i0il_o,
		sel => wire_n0i0il_sel
	  );
	wire_n0i0iO_data <= ( niO10O & nili1O & niO10O & nill0i & niO10O & nili1O & niO10O & nilO0l & niO10O & nili1O & niO10O & nill0i & niO10O & nili1O & niO10O & niO10O);
	wire_n0i0iO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i0iO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i0iO_data,
		o => wire_n0i0iO_o,
		sel => wire_n0i0iO_sel
	  );
	wire_n0i0li_data <= ( niO1ii & nili0i & niO1ii & nill0l & niO1ii & nili0i & niO1ii & nilO0O & niO1ii & nili0i & niO1ii & nill0l & niO1ii & nili0i & niO1ii & niO1ii);
	wire_n0i0li_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i0li :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i0li_data,
		o => wire_n0i0li_o,
		sel => wire_n0i0li_sel
	  );
	wire_n0i0ll_data <= ( niO1il & nili0l & niO1il & nill0O & niO1il & nili0l & niO1il & nilOii & niO1il & nili0l & niO1il & nill0O & niO1il & nili0l & niO1il & niO1il);
	wire_n0i0ll_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i0ll :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i0ll_data,
		o => wire_n0i0ll_o,
		sel => wire_n0i0ll_sel
	  );
	wire_n0i0lO_data <= ( niO1iO & nili0O & niO1iO & nillii & niO1iO & nili0O & niO1iO & nilOil & niO1iO & nili0O & niO1iO & nillii & niO1iO & nili0O & niO1iO & niO1iO);
	wire_n0i0lO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i0lO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i0lO_data,
		o => wire_n0i0lO_o,
		sel => wire_n0i0lO_sel
	  );
	wire_n0i0Oi_data <= ( niO1li & niliii & niO1li & nillil & niO1li & niliii & niO1li & nilOiO & niO1li & niliii & niO1li & nillil & niO1li & niliii & niO1li & niO1li);
	wire_n0i0Oi_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i0Oi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i0Oi_data,
		o => wire_n0i0Oi_o,
		sel => wire_n0i0Oi_sel
	  );
	wire_n0i0Ol_data <= ( niO1ll & niliil & niO1ll & nilliO & niO1ll & niliil & niO1ll & nilOli & niO1ll & niliil & niO1ll & nilliO & niO1ll & niliil & niO1ll & niO1ll);
	wire_n0i0Ol_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i0Ol :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i0Ol_data,
		o => wire_n0i0Ol_o,
		sel => wire_n0i0Ol_sel
	  );
	wire_n0i0OO_data <= ( niO1lO & niliiO & niO1lO & nillli & niO1lO & niliiO & niO1lO & nilOll & niO1lO & niliiO & niO1lO & nillli & niO1lO & niliiO & niO1lO & niO1lO);
	wire_n0i0OO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i0OO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i0OO_data,
		o => wire_n0i0OO_o,
		sel => wire_n0i0OO_sel
	  );
	wire_n0i10i_data <= ( nilO1i & nil1Oi & nilO1i & nil0Ol & nilO1i & nil1Oi & nilO1i & niliOO & nilO1i & nil1Oi & nilO1i & nil0Ol & nilO1i & nil1Oi & nilO1i & nilO1i);
	wire_n0i10i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i10i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i10i_data,
		o => wire_n0i10i_o,
		sel => wire_n0i10i_sel
	  );
	wire_n0i10l_data <= ( nilO1l & nil1Ol & nilO1l & nil0OO & nilO1l & nil1Ol & nilO1l & nill1i & nilO1l & nil1Ol & nilO1l & nil0OO & nilO1l & nil1Ol & nilO1l & nilO1l);
	wire_n0i10l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i10l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i10l_data,
		o => wire_n0i10l_o,
		sel => wire_n0i10l_sel
	  );
	wire_n0i10O_data <= ( nilO1O & nil1OO & nilO1O & nili1i & nilO1O & nil1OO & nilO1O & nill1l & nilO1O & nil1OO & nilO1O & nili1i & nilO1O & nil1OO & nilO1O & nilO1O);
	wire_n0i10O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i10O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i10O_data,
		o => wire_n0i10O_o,
		sel => wire_n0i10O_sel
	  );
	wire_n0i11i_data <= ( nillOi & nil1li & nillOi & nil0ll & nillOi & nil1li & nillOi & nililO & nillOi & nil1li & nillOi & nil0ll & nillOi & nil1li & nillOi & nillOi);
	wire_n0i11i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i11i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i11i_data,
		o => wire_n0i11i_o,
		sel => wire_n0i11i_sel
	  );
	wire_n0i11l_data <= ( nillOl & nil1ll & nillOl & nil0lO & nillOl & nil1ll & nillOl & niliOi & nillOl & nil1ll & nillOl & nil0lO & nillOl & nil1ll & nillOl & nillOl);
	wire_n0i11l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i11l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i11l_data,
		o => wire_n0i11l_o,
		sel => wire_n0i11l_sel
	  );
	wire_n0i11O_data <= ( nillOO & nil1lO & nillOO & nil0Oi & nillOO & nil1lO & nillOO & niliOl & nillOO & nil1lO & nillOO & nil0Oi & nillOO & nil1lO & nillOO & nillOO);
	wire_n0i11O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i11O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i11O_data,
		o => wire_n0i11O_o,
		sel => wire_n0i11O_sel
	  );
	wire_n0i1ii_data <= ( nilO0i & nil01i & nilO0i & nili1l & nilO0i & nil01i & nilO0i & nill1O & nilO0i & nil01i & nilO0i & nili1l & nilO0i & nil01i & nilO0i & nilO0i);
	wire_n0i1ii_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i1ii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i1ii_data,
		o => wire_n0i1ii_o,
		sel => wire_n0i1ii_sel
	  );
	wire_n0i1il_data <= ( nilO0l & nil01l & nilO0l & nili1O & nilO0l & nil01l & nilO0l & nill0i & nilO0l & nil01l & nilO0l & nili1O & nilO0l & nil01l & nilO0l & nilO0l);
	wire_n0i1il_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i1il :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i1il_data,
		o => wire_n0i1il_o,
		sel => wire_n0i1il_sel
	  );
	wire_n0i1iO_data <= ( nilO0O & nil01O & nilO0O & nili0i & nilO0O & nil01O & nilO0O & nill0l & nilO0O & nil01O & nilO0O & nili0i & nilO0O & nil01O & nilO0O & nilO0O);
	wire_n0i1iO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i1iO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i1iO_data,
		o => wire_n0i1iO_o,
		sel => wire_n0i1iO_sel
	  );
	wire_n0i1li_data <= ( nilOii & nil00i & nilOii & nili0l & nilOii & nil00i & nilOii & nill0O & nilOii & nil00i & nilOii & nili0l & nilOii & nil00i & nilOii & nilOii);
	wire_n0i1li_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i1li :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i1li_data,
		o => wire_n0i1li_o,
		sel => wire_n0i1li_sel
	  );
	wire_n0i1ll_data <= ( nilOil & nil00l & nilOil & nili0O & nilOil & nil00l & nilOil & nillii & nilOil & nil00l & nilOil & nili0O & nilOil & nil00l & nilOil & nilOil);
	wire_n0i1ll_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i1ll :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i1ll_data,
		o => wire_n0i1ll_o,
		sel => wire_n0i1ll_sel
	  );
	wire_n0i1lO_data <= ( nilOiO & nil00O & nilOiO & niliii & nilOiO & nil00O & nilOiO & nillil & nilOiO & nil00O & nilOiO & niliii & nilOiO & nil00O & nilOiO & nilOiO);
	wire_n0i1lO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i1lO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i1lO_data,
		o => wire_n0i1lO_o,
		sel => wire_n0i1lO_sel
	  );
	wire_n0i1Oi_data <= ( nilOli & nil0ii & nilOli & niliil & nilOli & nil0ii & nilOli & nilliO & nilOli & nil0ii & nilOli & niliil & nilOli & nil0ii & nilOli & nilOli);
	wire_n0i1Oi_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i1Oi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i1Oi_data,
		o => wire_n0i1Oi_o,
		sel => wire_n0i1Oi_sel
	  );
	wire_n0i1Ol_data <= ( nilOll & nil0il & nilOll & niliiO & nilOll & nil0il & nilOll & nillli & nilOll & nil0il & nilOll & niliiO & nilOll & nil0il & nilOll & nilOll);
	wire_n0i1Ol_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i1Ol :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i1Ol_data,
		o => wire_n0i1Ol_o,
		sel => wire_n0i1Ol_sel
	  );
	wire_n0i1OO_data <= ( nilOlO & nil0iO & nilOlO & nilili & nilOlO & nil0iO & nilOlO & nillll & nilOlO & nil0iO & nilOlO & nilili & nilOlO & nil0iO & nilOlO & nilOlO);
	wire_n0i1OO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0i1OO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0i1OO_data,
		o => wire_n0i1OO_o,
		sel => wire_n0i1OO_sel
	  );
	wire_n0ii0i_data <= ( niO01i & niliOi & niO01i & nillOl & niO01i & niliOi & niO01i & nilOOO & niO01i & niliOi & niO01i & nillOl & niO01i & niliOi & niO01i & niO01i);
	wire_n0ii0i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0ii0i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0ii0i_data,
		o => wire_n0ii0i_o,
		sel => wire_n0ii0i_sel
	  );
	wire_n0ii0l_data <= ( niO01l & niliOl & niO01l & nillOO & niO01l & niliOl & niO01l & niO11i & niO01l & niliOl & niO01l & nillOO & niO01l & niliOl & niO01l & niO01l);
	wire_n0ii0l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0ii0l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0ii0l_data,
		o => wire_n0ii0l_o,
		sel => wire_n0ii0l_sel
	  );
	wire_n0ii0O_data <= ( niO01O & niliOO & niO01O & nilO1i & niO01O & niliOO & niO01O & niO11l & niO01O & niliOO & niO01O & nilO1i & niO01O & niliOO & niO01O & niO01O);
	wire_n0ii0O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0ii0O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0ii0O_data,
		o => wire_n0ii0O_o,
		sel => wire_n0ii0O_sel
	  );
	wire_n0ii1i_data <= ( niO1Oi & nilili & niO1Oi & nillll & niO1Oi & nilili & niO1Oi & nilOlO & niO1Oi & nilili & niO1Oi & nillll & niO1Oi & nilili & niO1Oi & niO1Oi);
	wire_n0ii1i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0ii1i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0ii1i_data,
		o => wire_n0ii1i_o,
		sel => wire_n0ii1i_sel
	  );
	wire_n0ii1l_data <= ( niO1Ol & nilill & niO1Ol & nilllO & niO1Ol & nilill & niO1Ol & nilOOi & niO1Ol & nilill & niO1Ol & nilllO & niO1Ol & nilill & niO1Ol & niO1Ol);
	wire_n0ii1l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0ii1l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0ii1l_data,
		o => wire_n0ii1l_o,
		sel => wire_n0ii1l_sel
	  );
	wire_n0ii1O_data <= ( niO1OO & nililO & niO1OO & nillOi & niO1OO & nililO & niO1OO & nilOOl & niO1OO & nililO & niO1OO & nillOi & niO1OO & nililO & niO1OO & niO1OO);
	wire_n0ii1O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0ii1O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0ii1O_data,
		o => wire_n0ii1O_o,
		sel => wire_n0ii1O_sel
	  );
	wire_n0iiii_data <= ( niO00i & nill1i & niO00i & nilO1l & niO00i & nill1i & niO00i & niO11O & niO00i & nill1i & niO00i & nilO1l & niO00i & nill1i & niO00i & niO00i);
	wire_n0iiii_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0iiii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0iiii_data,
		o => wire_n0iiii_o,
		sel => wire_n0iiii_sel
	  );
	wire_n0iiil_data <= ( niO00l & nill1l & niO00l & nilO1O & niO00l & nill1l & niO00l & niO10i & niO00l & nill1l & niO00l & nilO1O & niO00l & nill1l & niO00l & niO00l);
	wire_n0iiil_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0iiil :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0iiil_data,
		o => wire_n0iiil_o,
		sel => wire_n0iiil_sel
	  );
	wire_n0iiiO_data <= ( niO00O & nill1O & niO00O & nilO0i & niO00O & nill1O & niO00O & niO10l & niO00O & nill1O & niO00O & nilO0i & niO00O & nill1O & niO00O & niO00O);
	wire_n0iiiO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0iiiO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0iiiO_data,
		o => wire_n0iiiO_o,
		sel => wire_n0iiiO_sel
	  );
	wire_n0iili_data <= ( niO0ii & nill0i & niO0ii & nilO0l & niO0ii & nill0i & niO0ii & niO10O & niO0ii & nill0i & niO0ii & nilO0l & niO0ii & nill0i & niO0ii & niO0ii);
	wire_n0iili_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0iili :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0iili_data,
		o => wire_n0iili_o,
		sel => wire_n0iili_sel
	  );
	wire_n0iill_data <= ( niO0il & nill0l & niO0il & nilO0O & niO0il & nill0l & niO0il & niO1ii & niO0il & nill0l & niO0il & nilO0O & niO0il & nill0l & niO0il & niO0il);
	wire_n0iill_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0iill :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0iill_data,
		o => wire_n0iill_o,
		sel => wire_n0iill_sel
	  );
	wire_n0iilO_data <= ( niO0iO & nill0O & niO0iO & nilOii & niO0iO & nill0O & niO0iO & niO1il & niO0iO & nill0O & niO0iO & nilOii & niO0iO & nill0O & niO0iO & niO0iO);
	wire_n0iilO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0iilO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0iilO_data,
		o => wire_n0iilO_o,
		sel => wire_n0iilO_sel
	  );
	wire_n0iiOi_data <= ( niO0li & nillii & niO0li & nilOil & niO0li & nillii & niO0li & niO1iO & niO0li & nillii & niO0li & nilOil & niO0li & nillii & niO0li & niO0li);
	wire_n0iiOi_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0iiOi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0iiOi_data,
		o => wire_n0iiOi_o,
		sel => wire_n0iiOi_sel
	  );
	wire_n0iiOl_data <= ( niO0ll & nillil & niO0ll & nilOiO & niO0ll & nillil & niO0ll & niO1li & niO0ll & nillil & niO0ll & nilOiO & niO0ll & nillil & niO0ll & niO0ll);
	wire_n0iiOl_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0iiOl :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0iiOl_data,
		o => wire_n0iiOl_o,
		sel => wire_n0iiOl_sel
	  );
	wire_n0iiOO_data <= ( niO0lO & nilliO & niO0lO & nilOli & niO0lO & nilliO & niO0lO & niO1ll & niO0lO & nilliO & niO0lO & nilOli & niO0lO & nilliO & niO0lO & niO0lO);
	wire_n0iiOO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0iiOO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0iiOO_data,
		o => wire_n0iiOO_o,
		sel => wire_n0iiOO_sel
	  );
	wire_n0il0i_data <= ( niOi1i & nillOi & niOi1i & nilOOl & niOi1i & nillOi & niOi1i & niO1OO & niOi1i & nillOi & niOi1i & nilOOl & niOi1i & nillOi & niOi1i & niOi1i);
	wire_n0il0i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0il0i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0il0i_data,
		o => wire_n0il0i_o,
		sel => wire_n0il0i_sel
	  );
	wire_n0il1i_data <= ( niO0Oi & nillli & niO0Oi & nilOll & niO0Oi & nillli & niO0Oi & niO1lO & niO0Oi & nillli & niO0Oi & nilOll & niO0Oi & nillli & niO0Oi & niO0Oi);
	wire_n0il1i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0il1i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0il1i_data,
		o => wire_n0il1i_o,
		sel => wire_n0il1i_sel
	  );
	wire_n0il1l_data <= ( niO0Ol & nillll & niO0Ol & nilOlO & niO0Ol & nillll & niO0Ol & niO1Oi & niO0Ol & nillll & niO0Ol & nilOlO & niO0Ol & nillll & niO0Ol & niO0Ol);
	wire_n0il1l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0il1l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0il1l_data,
		o => wire_n0il1l_o,
		sel => wire_n0il1l_sel
	  );
	wire_n0il1O_data <= ( niO0OO & nilllO & niO0OO & nilOOi & niO0OO & nilllO & niO0OO & niO1Ol & niO0OO & nilllO & niO0OO & nilOOi & niO0OO & nilllO & niO0OO & niO0OO);
	wire_n0il1O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0il1O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0il1O_data,
		o => wire_n0il1O_o,
		sel => wire_n0il1O_sel
	  );
	wire_n0l00l_data <= ( niO0ll & nillil & niO0ll & nilOiO & niO0ll & nillil & niO0ll & niO1li & niO0ll & nillil & niO0ll & nilOiO & niO0ll & nillil & niO0ll & niO0ll);
	wire_n0l00l_sel <= ( wire_ni1llO_dataout & wire_ni1lll_dataout & wire_ni1lli_dataout & wire_ni1liO_dataout);
	n0l00l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0l00l_data,
		o => wire_n0l00l_o,
		sel => wire_n0l00l_sel
	  );
	wire_n0l11l_data <= ( niO1li & nillil & niO1li & nilOiO & niO1li & nillil & niO1li & niO1li);
	wire_n0l11l_sel <= ( wire_ni1lll_dataout & wire_ni1lli_dataout & wire_ni1liO_dataout);
	n0l11l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0l11l_data,
		o => wire_n0l11l_o,
		sel => wire_n0l11l_sel
	  );
	wire_n0O00i_data <= ( wire_niOO1i_dataout & nilO1i & wire_niOO1i_dataout & niO11l & wire_niOO1i_dataout & nilO1i & wire_niOO1i_dataout & niO01O & wire_niOO1i_dataout & nilO1i & wire_niOO1i_dataout & niO11l & wire_niOO1i_dataout & nilO1i & wire_niOO1i_dataout & wire_niOO1i_dataout);
	wire_n0O00i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0O00i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0O00i_data,
		o => wire_n0O00i_o,
		sel => wire_n0O00i_sel
	  );
	wire_n0O00l_data <= ( wire_niOO1l_dataout & nilO1l & wire_niOO1l_dataout & niO11O & wire_niOO1l_dataout & nilO1l & wire_niOO1l_dataout & niO00i & wire_niOO1l_dataout & nilO1l & wire_niOO1l_dataout & niO11O & wire_niOO1l_dataout & nilO1l & wire_niOO1l_dataout & wire_niOO1l_dataout);
	wire_n0O00l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0O00l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0O00l_data,
		o => wire_n0O00l_o,
		sel => wire_n0O00l_sel
	  );
	wire_n0O00O_data <= ( wire_niOO1O_dataout & nilO1O & wire_niOO1O_dataout & niO10i & wire_niOO1O_dataout & nilO1O & wire_niOO1O_dataout & niO00l & wire_niOO1O_dataout & nilO1O & wire_niOO1O_dataout & niO10i & wire_niOO1O_dataout & nilO1O & wire_niOO1O_dataout & wire_niOO1O_dataout);
	wire_n0O00O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0O00O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0O00O_data,
		o => wire_n0O00O_o,
		sel => wire_n0O00O_sel
	  );
	wire_n0O01l_data <= ( wire_niOlOl_dataout & nillOl & wire_niOlOl_dataout & nilOOO & wire_niOlOl_dataout & nillOl & wire_niOlOl_dataout & niO01i & wire_niOlOl_dataout & nillOl & wire_niOlOl_dataout & nilOOO & wire_niOlOl_dataout & nillOl & wire_niOlOl_dataout & wire_niOlOl_dataout);
	wire_n0O01l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0O01l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0O01l_data,
		o => wire_n0O01l_o,
		sel => wire_n0O01l_sel
	  );
	wire_n0O01O_data <= ( wire_niOlOO_dataout & nillOO & wire_niOlOO_dataout & niO11i & wire_niOlOO_dataout & nillOO & wire_niOlOO_dataout & niO01l & wire_niOlOO_dataout & nillOO & wire_niOlOO_dataout & niO11i & wire_niOlOO_dataout & nillOO & wire_niOlOO_dataout & wire_niOlOO_dataout);
	wire_n0O01O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0O01O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0O01O_data,
		o => wire_n0O01O_o,
		sel => wire_n0O01O_sel
	  );
	wire_n0O0ii_data <= ( wire_niOO0i_dataout & nilO0i & wire_niOO0i_dataout & niO10l & wire_niOO0i_dataout & nilO0i & wire_niOO0i_dataout & niO00O & wire_niOO0i_dataout & nilO0i & wire_niOO0i_dataout & niO10l & wire_niOO0i_dataout & nilO0i & wire_niOO0i_dataout & wire_niOO0i_dataout);
	wire_n0O0ii_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0O0ii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0O0ii_data,
		o => wire_n0O0ii_o,
		sel => wire_n0O0ii_sel
	  );
	wire_n0O0il_data <= ( wire_niOO0l_dataout & nilO0l & wire_niOO0l_dataout & niO10O & wire_niOO0l_dataout & nilO0l & wire_niOO0l_dataout & niO0ii & wire_niOO0l_dataout & nilO0l & wire_niOO0l_dataout & niO10O & wire_niOO0l_dataout & nilO0l & wire_niOO0l_dataout & wire_niOO0l_dataout);
	wire_n0O0il_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0O0il :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0O0il_data,
		o => wire_n0O0il_o,
		sel => wire_n0O0il_sel
	  );
	wire_n0O0iO_data <= ( wire_niOO0O_dataout & nilO0O & wire_niOO0O_dataout & niO1ii & wire_niOO0O_dataout & nilO0O & wire_niOO0O_dataout & niO0il & wire_niOO0O_dataout & nilO0O & wire_niOO0O_dataout & niO1ii & wire_niOO0O_dataout & nilO0O & wire_niOO0O_dataout & wire_niOO0O_dataout);
	wire_n0O0iO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0O0iO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0O0iO_data,
		o => wire_n0O0iO_o,
		sel => wire_n0O0iO_sel
	  );
	wire_n0O0li_data <= ( wire_niOOii_dataout & nilOii & wire_niOOii_dataout & niO1il & wire_niOOii_dataout & nilOii & wire_niOOii_dataout & niO0iO & wire_niOOii_dataout & nilOii & wire_niOOii_dataout & niO1il & wire_niOOii_dataout & nilOii & wire_niOOii_dataout & wire_niOOii_dataout);
	wire_n0O0li_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0O0li :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0O0li_data,
		o => wire_n0O0li_o,
		sel => wire_n0O0li_sel
	  );
	wire_n0O0ll_data <= ( wire_niOOil_dataout & nilOil & wire_niOOil_dataout & niO1iO & wire_niOOil_dataout & nilOil & wire_niOOil_dataout & niO0li & wire_niOOil_dataout & nilOil & wire_niOOil_dataout & niO1iO & wire_niOOil_dataout & nilOil & wire_niOOil_dataout & wire_niOOil_dataout);
	wire_n0O0ll_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0O0ll :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0O0ll_data,
		o => wire_n0O0ll_o,
		sel => wire_n0O0ll_sel
	  );
	wire_n0O0lO_data <= ( wire_niOOiO_dataout & nilOiO & wire_niOOiO_dataout & niO1li & wire_niOOiO_dataout & nilOiO & wire_niOOiO_dataout & niO0ll & wire_niOOiO_dataout & nilOiO & wire_niOOiO_dataout & niO1li & wire_niOOiO_dataout & nilOiO & wire_niOOiO_dataout & wire_niOOiO_dataout);
	wire_n0O0lO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0O0lO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0O0lO_data,
		o => wire_n0O0lO_o,
		sel => wire_n0O0lO_sel
	  );
	wire_n0O0Oi_data <= ( wire_niOOli_dataout & nilOli & wire_niOOli_dataout & niO1ll & wire_niOOli_dataout & nilOli & wire_niOOli_dataout & niO0lO & wire_niOOli_dataout & nilOli & wire_niOOli_dataout & niO1ll & wire_niOOli_dataout & nilOli & wire_niOOli_dataout & wire_niOOli_dataout);
	wire_n0O0Oi_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0O0Oi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0O0Oi_data,
		o => wire_n0O0Oi_o,
		sel => wire_n0O0Oi_sel
	  );
	wire_n0O0Ol_data <= ( wire_niOOll_dataout & nilOll & wire_niOOll_dataout & niO1lO & wire_niOOll_dataout & nilOll & wire_niOOll_dataout & niO0Oi & wire_niOOll_dataout & nilOll & wire_niOOll_dataout & niO1lO & wire_niOOll_dataout & nilOll & wire_niOOll_dataout & wire_niOOll_dataout);
	wire_n0O0Ol_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0O0Ol :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0O0Ol_data,
		o => wire_n0O0Ol_o,
		sel => wire_n0O0Ol_sel
	  );
	wire_n0O0OO_data <= ( wire_niOOlO_dataout & nilOlO & wire_niOOlO_dataout & niO1Oi & wire_niOOlO_dataout & nilOlO & wire_niOOlO_dataout & niO0Ol & wire_niOOlO_dataout & nilOlO & wire_niOOlO_dataout & niO1Oi & wire_niOOlO_dataout & nilOlO & wire_niOOlO_dataout & wire_niOOlO_dataout);
	wire_n0O0OO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0O0OO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0O0OO_data,
		o => wire_n0O0OO_o,
		sel => wire_n0O0OO_sel
	  );
	wire_n0Oi0i_data <= ( wire_nl111i_dataout & niO11i & wire_nl111i_dataout & niO01l & wire_nl111i_dataout & niO11i & wire_nl111i_dataout & wire_niOlOO_dataout & wire_nl111i_dataout & niO11i & wire_nl111i_dataout & niO01l & wire_nl111i_dataout & niO11i & wire_nl111i_dataout & wire_nl111i_dataout);
	wire_n0Oi0i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Oi0i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Oi0i_data,
		o => wire_n0Oi0i_o,
		sel => wire_n0Oi0i_sel
	  );
	wire_n0Oi0l_data <= ( wire_nl111l_dataout & niO11l & wire_nl111l_dataout & niO01O & wire_nl111l_dataout & niO11l & wire_nl111l_dataout & wire_niOO1i_dataout & wire_nl111l_dataout & niO11l & wire_nl111l_dataout & niO01O & wire_nl111l_dataout & niO11l & wire_nl111l_dataout & wire_nl111l_dataout);
	wire_n0Oi0l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Oi0l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Oi0l_data,
		o => wire_n0Oi0l_o,
		sel => wire_n0Oi0l_sel
	  );
	wire_n0Oi0O_data <= ( wire_nl111O_dataout & niO11O & wire_nl111O_dataout & niO00i & wire_nl111O_dataout & niO11O & wire_nl111O_dataout & wire_niOO1l_dataout & wire_nl111O_dataout & niO11O & wire_nl111O_dataout & niO00i & wire_nl111O_dataout & niO11O & wire_nl111O_dataout & wire_nl111O_dataout);
	wire_n0Oi0O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Oi0O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Oi0O_data,
		o => wire_n0Oi0O_o,
		sel => wire_n0Oi0O_sel
	  );
	wire_n0Oi1i_data <= ( wire_niOOOi_dataout & nilOOi & wire_niOOOi_dataout & niO1Ol & wire_niOOOi_dataout & nilOOi & wire_niOOOi_dataout & niO0OO & wire_niOOOi_dataout & nilOOi & wire_niOOOi_dataout & niO1Ol & wire_niOOOi_dataout & nilOOi & wire_niOOOi_dataout & wire_niOOOi_dataout);
	wire_n0Oi1i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Oi1i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Oi1i_data,
		o => wire_n0Oi1i_o,
		sel => wire_n0Oi1i_sel
	  );
	wire_n0Oi1l_data <= ( wire_niOOOl_dataout & nilOOl & wire_niOOOl_dataout & niO1OO & wire_niOOOl_dataout & nilOOl & wire_niOOOl_dataout & niOi1i & wire_niOOOl_dataout & nilOOl & wire_niOOOl_dataout & niO1OO & wire_niOOOl_dataout & nilOOl & wire_niOOOl_dataout & wire_niOOOl_dataout);
	wire_n0Oi1l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Oi1l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Oi1l_data,
		o => wire_n0Oi1l_o,
		sel => wire_n0Oi1l_sel
	  );
	wire_n0Oi1O_data <= ( wire_niOOOO_dataout & nilOOO & wire_niOOOO_dataout & niO01i & wire_niOOOO_dataout & nilOOO & wire_niOOOO_dataout & wire_niOlOl_dataout & wire_niOOOO_dataout & nilOOO & wire_niOOOO_dataout & niO01i & wire_niOOOO_dataout & nilOOO & wire_niOOOO_dataout & wire_niOOOO_dataout);
	wire_n0Oi1O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Oi1O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Oi1O_data,
		o => wire_n0Oi1O_o,
		sel => wire_n0Oi1O_sel
	  );
	wire_n0Oiii_data <= ( wire_nl110i_dataout & niO10i & wire_nl110i_dataout & niO00l & wire_nl110i_dataout & niO10i & wire_nl110i_dataout & wire_niOO1O_dataout & wire_nl110i_dataout & niO10i & wire_nl110i_dataout & niO00l & wire_nl110i_dataout & niO10i & wire_nl110i_dataout & wire_nl110i_dataout);
	wire_n0Oiii_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Oiii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Oiii_data,
		o => wire_n0Oiii_o,
		sel => wire_n0Oiii_sel
	  );
	wire_n0Oiil_data <= ( wire_nl110l_dataout & niO10l & wire_nl110l_dataout & niO00O & wire_nl110l_dataout & niO10l & wire_nl110l_dataout & wire_niOO0i_dataout & wire_nl110l_dataout & niO10l & wire_nl110l_dataout & niO00O & wire_nl110l_dataout & niO10l & wire_nl110l_dataout & wire_nl110l_dataout);
	wire_n0Oiil_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Oiil :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Oiil_data,
		o => wire_n0Oiil_o,
		sel => wire_n0Oiil_sel
	  );
	wire_n0OiiO_data <= ( wire_nl110O_dataout & niO10O & wire_nl110O_dataout & niO0ii & wire_nl110O_dataout & niO10O & wire_nl110O_dataout & wire_niOO0l_dataout & wire_nl110O_dataout & niO10O & wire_nl110O_dataout & niO0ii & wire_nl110O_dataout & niO10O & wire_nl110O_dataout & wire_nl110O_dataout);
	wire_n0OiiO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OiiO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OiiO_data,
		o => wire_n0OiiO_o,
		sel => wire_n0OiiO_sel
	  );
	wire_n0Oili_data <= ( wire_nl11ii_dataout & niO1ii & wire_nl11ii_dataout & niO0il & wire_nl11ii_dataout & niO1ii & wire_nl11ii_dataout & wire_niOO0O_dataout & wire_nl11ii_dataout & niO1ii & wire_nl11ii_dataout & niO0il & wire_nl11ii_dataout & niO1ii & wire_nl11ii_dataout & wire_nl11ii_dataout);
	wire_n0Oili_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Oili :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Oili_data,
		o => wire_n0Oili_o,
		sel => wire_n0Oili_sel
	  );
	wire_n0Oill_data <= ( wire_nl11il_dataout & niO1il & wire_nl11il_dataout & niO0iO & wire_nl11il_dataout & niO1il & wire_nl11il_dataout & wire_niOOii_dataout & wire_nl11il_dataout & niO1il & wire_nl11il_dataout & niO0iO & wire_nl11il_dataout & niO1il & wire_nl11il_dataout & wire_nl11il_dataout);
	wire_n0Oill_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Oill :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Oill_data,
		o => wire_n0Oill_o,
		sel => wire_n0Oill_sel
	  );
	wire_n0OilO_data <= ( wire_nl11iO_dataout & niO1iO & wire_nl11iO_dataout & niO0li & wire_nl11iO_dataout & niO1iO & wire_nl11iO_dataout & wire_niOOil_dataout & wire_nl11iO_dataout & niO1iO & wire_nl11iO_dataout & niO0li & wire_nl11iO_dataout & niO1iO & wire_nl11iO_dataout & wire_nl11iO_dataout);
	wire_n0OilO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OilO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OilO_data,
		o => wire_n0OilO_o,
		sel => wire_n0OilO_sel
	  );
	wire_n0OiOi_data <= ( wire_nl11li_dataout & niO1li & wire_nl11li_dataout & niO0ll & wire_nl11li_dataout & niO1li & wire_nl11li_dataout & wire_niOOiO_dataout & wire_nl11li_dataout & niO1li & wire_nl11li_dataout & niO0ll & wire_nl11li_dataout & niO1li & wire_nl11li_dataout & wire_nl11li_dataout);
	wire_n0OiOi_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OiOi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OiOi_data,
		o => wire_n0OiOi_o,
		sel => wire_n0OiOi_sel
	  );
	wire_n0OiOl_data <= ( wire_nl11ll_dataout & niO1ll & wire_nl11ll_dataout & niO0lO & wire_nl11ll_dataout & niO1ll & wire_nl11ll_dataout & wire_niOOli_dataout & wire_nl11ll_dataout & niO1ll & wire_nl11ll_dataout & niO0lO & wire_nl11ll_dataout & niO1ll & wire_nl11ll_dataout & wire_nl11ll_dataout);
	wire_n0OiOl_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OiOl :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OiOl_data,
		o => wire_n0OiOl_o,
		sel => wire_n0OiOl_sel
	  );
	wire_n0OiOO_data <= ( wire_nl11lO_dataout & niO1lO & wire_nl11lO_dataout & niO0Oi & wire_nl11lO_dataout & niO1lO & wire_nl11lO_dataout & wire_niOOll_dataout & wire_nl11lO_dataout & niO1lO & wire_nl11lO_dataout & niO0Oi & wire_nl11lO_dataout & niO1lO & wire_nl11lO_dataout & wire_nl11lO_dataout);
	wire_n0OiOO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OiOO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OiOO_data,
		o => wire_n0OiOO_o,
		sel => wire_n0OiOO_sel
	  );
	wire_n0Ol0i_data <= ( wire_nl101i_dataout & niO01i & wire_nl101i_dataout & wire_niOlOl_dataout & wire_nl101i_dataout & niO01i & wire_nl101i_dataout & wire_niOOOO_dataout & wire_nl101i_dataout & niO01i & wire_nl101i_dataout & wire_niOlOl_dataout & wire_nl101i_dataout & niO01i & wire_nl101i_dataout & wire_nl101i_dataout);
	wire_n0Ol0i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Ol0i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Ol0i_data,
		o => wire_n0Ol0i_o,
		sel => wire_n0Ol0i_sel
	  );
	wire_n0Ol0l_data <= ( wire_nl101l_dataout & niO01l & wire_nl101l_dataout & wire_niOlOO_dataout & wire_nl101l_dataout & niO01l & wire_nl101l_dataout & wire_nl111i_dataout & wire_nl101l_dataout & niO01l & wire_nl101l_dataout & wire_niOlOO_dataout & wire_nl101l_dataout & niO01l & wire_nl101l_dataout & wire_nl101l_dataout);
	wire_n0Ol0l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Ol0l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Ol0l_data,
		o => wire_n0Ol0l_o,
		sel => wire_n0Ol0l_sel
	  );
	wire_n0Ol0O_data <= ( wire_nl101O_dataout & niO01O & wire_nl101O_dataout & wire_niOO1i_dataout & wire_nl101O_dataout & niO01O & wire_nl101O_dataout & wire_nl111l_dataout & wire_nl101O_dataout & niO01O & wire_nl101O_dataout & wire_niOO1i_dataout & wire_nl101O_dataout & niO01O & wire_nl101O_dataout & wire_nl101O_dataout);
	wire_n0Ol0O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Ol0O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Ol0O_data,
		o => wire_n0Ol0O_o,
		sel => wire_n0Ol0O_sel
	  );
	wire_n0Ol1i_data <= ( wire_nl11Oi_dataout & niO1Oi & wire_nl11Oi_dataout & niO0Ol & wire_nl11Oi_dataout & niO1Oi & wire_nl11Oi_dataout & wire_niOOlO_dataout & wire_nl11Oi_dataout & niO1Oi & wire_nl11Oi_dataout & niO0Ol & wire_nl11Oi_dataout & niO1Oi & wire_nl11Oi_dataout & wire_nl11Oi_dataout);
	wire_n0Ol1i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Ol1i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Ol1i_data,
		o => wire_n0Ol1i_o,
		sel => wire_n0Ol1i_sel
	  );
	wire_n0Ol1l_data <= ( wire_nl11Ol_dataout & niO1Ol & wire_nl11Ol_dataout & niO0OO & wire_nl11Ol_dataout & niO1Ol & wire_nl11Ol_dataout & wire_niOOOi_dataout & wire_nl11Ol_dataout & niO1Ol & wire_nl11Ol_dataout & niO0OO & wire_nl11Ol_dataout & niO1Ol & wire_nl11Ol_dataout & wire_nl11Ol_dataout);
	wire_n0Ol1l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Ol1l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Ol1l_data,
		o => wire_n0Ol1l_o,
		sel => wire_n0Ol1l_sel
	  );
	wire_n0Ol1O_data <= ( wire_nl11OO_dataout & niO1OO & wire_nl11OO_dataout & niOi1i & wire_nl11OO_dataout & niO1OO & wire_nl11OO_dataout & wire_niOOOl_dataout & wire_nl11OO_dataout & niO1OO & wire_nl11OO_dataout & niOi1i & wire_nl11OO_dataout & niO1OO & wire_nl11OO_dataout & wire_nl11OO_dataout);
	wire_n0Ol1O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Ol1O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Ol1O_data,
		o => wire_n0Ol1O_o,
		sel => wire_n0Ol1O_sel
	  );
	wire_n0Olii_data <= ( wire_nl100i_dataout & niO00i & wire_nl100i_dataout & wire_niOO1l_dataout & wire_nl100i_dataout & niO00i & wire_nl100i_dataout & wire_nl111O_dataout & wire_nl100i_dataout & niO00i & wire_nl100i_dataout & wire_niOO1l_dataout & wire_nl100i_dataout & niO00i & wire_nl100i_dataout & wire_nl100i_dataout);
	wire_n0Olii_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Olii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Olii_data,
		o => wire_n0Olii_o,
		sel => wire_n0Olii_sel
	  );
	wire_n0Olil_data <= ( wire_nl100l_dataout & niO00l & wire_nl100l_dataout & wire_niOO1O_dataout & wire_nl100l_dataout & niO00l & wire_nl100l_dataout & wire_nl110i_dataout & wire_nl100l_dataout & niO00l & wire_nl100l_dataout & wire_niOO1O_dataout & wire_nl100l_dataout & niO00l & wire_nl100l_dataout & wire_nl100l_dataout);
	wire_n0Olil_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Olil :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Olil_data,
		o => wire_n0Olil_o,
		sel => wire_n0Olil_sel
	  );
	wire_n0OliO_data <= ( wire_nl100O_dataout & niO00O & wire_nl100O_dataout & wire_niOO0i_dataout & wire_nl100O_dataout & niO00O & wire_nl100O_dataout & wire_nl110l_dataout & wire_nl100O_dataout & niO00O & wire_nl100O_dataout & wire_niOO0i_dataout & wire_nl100O_dataout & niO00O & wire_nl100O_dataout & wire_nl100O_dataout);
	wire_n0OliO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OliO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OliO_data,
		o => wire_n0OliO_o,
		sel => wire_n0OliO_sel
	  );
	wire_n0Olli_data <= ( wire_nl10ii_dataout & niO0ii & wire_nl10ii_dataout & wire_niOO0l_dataout & wire_nl10ii_dataout & niO0ii & wire_nl10ii_dataout & wire_nl110O_dataout & wire_nl10ii_dataout & niO0ii & wire_nl10ii_dataout & wire_niOO0l_dataout & wire_nl10ii_dataout & niO0ii & wire_nl10ii_dataout & wire_nl10ii_dataout);
	wire_n0Olli_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Olli :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Olli_data,
		o => wire_n0Olli_o,
		sel => wire_n0Olli_sel
	  );
	wire_n0Olll_data <= ( wire_nl10il_dataout & niO0il & wire_nl10il_dataout & wire_niOO0O_dataout & wire_nl10il_dataout & niO0il & wire_nl10il_dataout & wire_nl11ii_dataout & wire_nl10il_dataout & niO0il & wire_nl10il_dataout & wire_niOO0O_dataout & wire_nl10il_dataout & niO0il & wire_nl10il_dataout & wire_nl10il_dataout);
	wire_n0Olll_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0Olll :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Olll_data,
		o => wire_n0Olll_o,
		sel => wire_n0Olll_sel
	  );
	wire_n0OllO_data <= ( wire_nl10iO_dataout & niO0iO & wire_nl10iO_dataout & wire_niOOii_dataout & wire_nl10iO_dataout & niO0iO & wire_nl10iO_dataout & wire_nl11il_dataout & wire_nl10iO_dataout & niO0iO & wire_nl10iO_dataout & wire_niOOii_dataout & wire_nl10iO_dataout & niO0iO & wire_nl10iO_dataout & wire_nl10iO_dataout);
	wire_n0OllO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OllO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OllO_data,
		o => wire_n0OllO_o,
		sel => wire_n0OllO_sel
	  );
	wire_n0OlOi_data <= ( wire_nl10li_dataout & niO0li & wire_nl10li_dataout & wire_niOOil_dataout & wire_nl10li_dataout & niO0li & wire_nl10li_dataout & wire_nl11iO_dataout & wire_nl10li_dataout & niO0li & wire_nl10li_dataout & wire_niOOil_dataout & wire_nl10li_dataout & niO0li & wire_nl10li_dataout & wire_nl10li_dataout);
	wire_n0OlOi_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OlOi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OlOi_data,
		o => wire_n0OlOi_o,
		sel => wire_n0OlOi_sel
	  );
	wire_n0OlOl_data <= ( wire_nl10ll_dataout & niO0ll & wire_nl10ll_dataout & wire_niOOiO_dataout & wire_nl10ll_dataout & niO0ll & wire_nl10ll_dataout & wire_nl11li_dataout & wire_nl10ll_dataout & niO0ll & wire_nl10ll_dataout & wire_niOOiO_dataout & wire_nl10ll_dataout & niO0ll & wire_nl10ll_dataout & wire_nl10ll_dataout);
	wire_n0OlOl_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OlOl :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OlOl_data,
		o => wire_n0OlOl_o,
		sel => wire_n0OlOl_sel
	  );
	wire_n0OlOO_data <= ( wire_nl10lO_dataout & niO0lO & wire_nl10lO_dataout & wire_niOOli_dataout & wire_nl10lO_dataout & niO0lO & wire_nl10lO_dataout & wire_nl11ll_dataout & wire_nl10lO_dataout & niO0lO & wire_nl10lO_dataout & wire_niOOli_dataout & wire_nl10lO_dataout & niO0lO & wire_nl10lO_dataout & wire_nl10lO_dataout);
	wire_n0OlOO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OlOO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OlOO_data,
		o => wire_n0OlOO_o,
		sel => wire_n0OlOO_sel
	  );
	wire_n0OO0i_data <= ( wire_nl1i1i_dataout & niOi1i & wire_nl1i1i_dataout & wire_niOOOl_dataout & wire_nl1i1i_dataout & niOi1i & wire_nl1i1i_dataout & wire_nl11OO_dataout & wire_nl1i1i_dataout & niOi1i & wire_nl1i1i_dataout & wire_niOOOl_dataout & wire_nl1i1i_dataout & niOi1i & wire_nl1i1i_dataout & wire_nl1i1i_dataout);
	wire_n0OO0i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OO0i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OO0i_data,
		o => wire_n0OO0i_o,
		sel => wire_n0OO0i_sel
	  );
	wire_n0OO0l_data <= ( wire_nl1i1l_dataout & wire_niOlOl_dataout & wire_nl1i1l_dataout & wire_niOOOO_dataout & wire_nl1i1l_dataout & wire_niOlOl_dataout & wire_nl1i1l_dataout & wire_nl101i_dataout & wire_nl1i1l_dataout & wire_niOlOl_dataout & wire_nl1i1l_dataout & wire_niOOOO_dataout & wire_nl1i1l_dataout & wire_niOlOl_dataout & wire_nl1i1l_dataout & wire_nl1i1l_dataout);
	wire_n0OO0l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OO0l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OO0l_data,
		o => wire_n0OO0l_o,
		sel => wire_n0OO0l_sel
	  );
	wire_n0OO0O_data <= ( wire_nl1i1O_dataout & wire_niOlOO_dataout & wire_nl1i1O_dataout & wire_nl111i_dataout & wire_nl1i1O_dataout & wire_niOlOO_dataout & wire_nl1i1O_dataout & wire_nl101l_dataout & wire_nl1i1O_dataout & wire_niOlOO_dataout & wire_nl1i1O_dataout & wire_nl111i_dataout & wire_nl1i1O_dataout & wire_niOlOO_dataout & wire_nl1i1O_dataout & wire_nl1i1O_dataout);
	wire_n0OO0O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OO0O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OO0O_data,
		o => wire_n0OO0O_o,
		sel => wire_n0OO0O_sel
	  );
	wire_n0OO1i_data <= ( wire_nl10Oi_dataout & niO0Oi & wire_nl10Oi_dataout & wire_niOOll_dataout & wire_nl10Oi_dataout & niO0Oi & wire_nl10Oi_dataout & wire_nl11lO_dataout & wire_nl10Oi_dataout & niO0Oi & wire_nl10Oi_dataout & wire_niOOll_dataout & wire_nl10Oi_dataout & niO0Oi & wire_nl10Oi_dataout & wire_nl10Oi_dataout);
	wire_n0OO1i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OO1i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OO1i_data,
		o => wire_n0OO1i_o,
		sel => wire_n0OO1i_sel
	  );
	wire_n0OO1l_data <= ( wire_nl10Ol_dataout & niO0Ol & wire_nl10Ol_dataout & wire_niOOlO_dataout & wire_nl10Ol_dataout & niO0Ol & wire_nl10Ol_dataout & wire_nl11Oi_dataout & wire_nl10Ol_dataout & niO0Ol & wire_nl10Ol_dataout & wire_niOOlO_dataout & wire_nl10Ol_dataout & niO0Ol & wire_nl10Ol_dataout & wire_nl10Ol_dataout);
	wire_n0OO1l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OO1l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OO1l_data,
		o => wire_n0OO1l_o,
		sel => wire_n0OO1l_sel
	  );
	wire_n0OO1O_data <= ( wire_nl10OO_dataout & niO0OO & wire_nl10OO_dataout & wire_niOOOi_dataout & wire_nl10OO_dataout & niO0OO & wire_nl10OO_dataout & wire_nl11Ol_dataout & wire_nl10OO_dataout & niO0OO & wire_nl10OO_dataout & wire_niOOOi_dataout & wire_nl10OO_dataout & niO0OO & wire_nl10OO_dataout & wire_nl10OO_dataout);
	wire_n0OO1O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OO1O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OO1O_data,
		o => wire_n0OO1O_o,
		sel => wire_n0OO1O_sel
	  );
	wire_n0OOii_data <= ( wire_nl1i0i_dataout & wire_niOO1i_dataout & wire_nl1i0i_dataout & wire_nl111l_dataout & wire_nl1i0i_dataout & wire_niOO1i_dataout & wire_nl1i0i_dataout & wire_nl101O_dataout & wire_nl1i0i_dataout & wire_niOO1i_dataout & wire_nl1i0i_dataout & wire_nl111l_dataout & wire_nl1i0i_dataout & wire_niOO1i_dataout & wire_nl1i0i_dataout & wire_nl1i0i_dataout);
	wire_n0OOii_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OOii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OOii_data,
		o => wire_n0OOii_o,
		sel => wire_n0OOii_sel
	  );
	wire_n0OOil_data <= ( wire_nl1i0l_dataout & wire_niOO1l_dataout & wire_nl1i0l_dataout & wire_nl111O_dataout & wire_nl1i0l_dataout & wire_niOO1l_dataout & wire_nl1i0l_dataout & wire_nl100i_dataout & wire_nl1i0l_dataout & wire_niOO1l_dataout & wire_nl1i0l_dataout & wire_nl111O_dataout & wire_nl1i0l_dataout & wire_niOO1l_dataout & wire_nl1i0l_dataout & wire_nl1i0l_dataout);
	wire_n0OOil_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OOil :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OOil_data,
		o => wire_n0OOil_o,
		sel => wire_n0OOil_sel
	  );
	wire_n0OOiO_data <= ( wire_nl1i0O_dataout & wire_niOO1O_dataout & wire_nl1i0O_dataout & wire_nl110i_dataout & wire_nl1i0O_dataout & wire_niOO1O_dataout & wire_nl1i0O_dataout & wire_nl100l_dataout & wire_nl1i0O_dataout & wire_niOO1O_dataout & wire_nl1i0O_dataout & wire_nl110i_dataout & wire_nl1i0O_dataout & wire_niOO1O_dataout & wire_nl1i0O_dataout & wire_nl1i0O_dataout);
	wire_n0OOiO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OOiO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OOiO_data,
		o => wire_n0OOiO_o,
		sel => wire_n0OOiO_sel
	  );
	wire_n0OOli_data <= ( wire_nl1iii_dataout & wire_niOO0i_dataout & wire_nl1iii_dataout & wire_nl110l_dataout & wire_nl1iii_dataout & wire_niOO0i_dataout & wire_nl1iii_dataout & wire_nl100O_dataout & wire_nl1iii_dataout & wire_niOO0i_dataout & wire_nl1iii_dataout & wire_nl110l_dataout & wire_nl1iii_dataout & wire_niOO0i_dataout & wire_nl1iii_dataout & wire_nl1iii_dataout);
	wire_n0OOli_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OOli :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OOli_data,
		o => wire_n0OOli_o,
		sel => wire_n0OOli_sel
	  );
	wire_n0OOll_data <= ( wire_nl1iil_dataout & wire_niOO0l_dataout & wire_nl1iil_dataout & wire_nl110O_dataout & wire_nl1iil_dataout & wire_niOO0l_dataout & wire_nl1iil_dataout & wire_nl10ii_dataout & wire_nl1iil_dataout & wire_niOO0l_dataout & wire_nl1iil_dataout & wire_nl110O_dataout & wire_nl1iil_dataout & wire_niOO0l_dataout & wire_nl1iil_dataout & wire_nl1iil_dataout);
	wire_n0OOll_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OOll :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OOll_data,
		o => wire_n0OOll_o,
		sel => wire_n0OOll_sel
	  );
	wire_n0OOlO_data <= ( wire_nl1iiO_dataout & wire_niOO0O_dataout & wire_nl1iiO_dataout & wire_nl11ii_dataout & wire_nl1iiO_dataout & wire_niOO0O_dataout & wire_nl1iiO_dataout & wire_nl10il_dataout & wire_nl1iiO_dataout & wire_niOO0O_dataout & wire_nl1iiO_dataout & wire_nl11ii_dataout & wire_nl1iiO_dataout & wire_niOO0O_dataout & wire_nl1iiO_dataout & wire_nl1iiO_dataout);
	wire_n0OOlO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OOlO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OOlO_data,
		o => wire_n0OOlO_o,
		sel => wire_n0OOlO_sel
	  );
	wire_n0OOOi_data <= ( wire_nl1ili_dataout & wire_niOOii_dataout & wire_nl1ili_dataout & wire_nl11il_dataout & wire_nl1ili_dataout & wire_niOOii_dataout & wire_nl1ili_dataout & wire_nl10iO_dataout & wire_nl1ili_dataout & wire_niOOii_dataout & wire_nl1ili_dataout & wire_nl11il_dataout & wire_nl1ili_dataout & wire_niOOii_dataout & wire_nl1ili_dataout & wire_nl1ili_dataout);
	wire_n0OOOi_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OOOi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OOOi_data,
		o => wire_n0OOOi_o,
		sel => wire_n0OOOi_sel
	  );
	wire_n0OOOl_data <= ( wire_nl1ill_dataout & wire_niOOil_dataout & wire_nl1ill_dataout & wire_nl11iO_dataout & wire_nl1ill_dataout & wire_niOOil_dataout & wire_nl1ill_dataout & wire_nl10li_dataout & wire_nl1ill_dataout & wire_niOOil_dataout & wire_nl1ill_dataout & wire_nl11iO_dataout & wire_nl1ill_dataout & wire_niOOil_dataout & wire_nl1ill_dataout & wire_nl1ill_dataout);
	wire_n0OOOl_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OOOl :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OOOl_data,
		o => wire_n0OOOl_o,
		sel => wire_n0OOOl_sel
	  );
	wire_n0OOOO_data <= ( wire_nl1ilO_dataout & wire_niOOiO_dataout & wire_nl1ilO_dataout & wire_nl11li_dataout & wire_nl1ilO_dataout & wire_niOOiO_dataout & wire_nl1ilO_dataout & wire_nl10ll_dataout & wire_nl1ilO_dataout & wire_niOOiO_dataout & wire_nl1ilO_dataout & wire_nl11li_dataout & wire_nl1ilO_dataout & wire_niOOiO_dataout & wire_nl1ilO_dataout & wire_nl1ilO_dataout);
	wire_n0OOOO_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	n0OOOO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OOOO_data,
		o => wire_n0OOOO_o,
		sel => wire_n0OOOO_sel
	  );
	wire_ni110i_data <= ( wire_nl1l1i_dataout & wire_niOOOi_dataout & wire_nl1l1i_dataout & wire_nl11Ol_dataout & wire_nl1l1i_dataout & wire_niOOOi_dataout & wire_nl1l1i_dataout & wire_nl10OO_dataout & wire_nl1l1i_dataout & wire_niOOOi_dataout & wire_nl1l1i_dataout & wire_nl11Ol_dataout & wire_nl1l1i_dataout & wire_niOOOi_dataout & wire_nl1l1i_dataout & wire_nl1l1i_dataout);
	wire_ni110i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	ni110i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni110i_data,
		o => wire_ni110i_o,
		sel => wire_ni110i_sel
	  );
	wire_ni110l_data <= ( wire_nl1l1l_dataout & wire_niOOOl_dataout & wire_nl1l1l_dataout & wire_nl11OO_dataout & wire_nl1l1l_dataout & wire_niOOOl_dataout & wire_nl1l1l_dataout & wire_nl1i1i_dataout & wire_nl1l1l_dataout & wire_niOOOl_dataout & wire_nl1l1l_dataout & wire_nl11OO_dataout & wire_nl1l1l_dataout & wire_niOOOl_dataout & wire_nl1l1l_dataout & wire_nl1l1l_dataout);
	wire_ni110l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	ni110l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni110l_data,
		o => wire_ni110l_o,
		sel => wire_ni110l_sel
	  );
	wire_ni111i_data <= ( wire_nl1iOi_dataout & wire_niOOli_dataout & wire_nl1iOi_dataout & wire_nl11ll_dataout & wire_nl1iOi_dataout & wire_niOOli_dataout & wire_nl1iOi_dataout & wire_nl10lO_dataout & wire_nl1iOi_dataout & wire_niOOli_dataout & wire_nl1iOi_dataout & wire_nl11ll_dataout & wire_nl1iOi_dataout & wire_niOOli_dataout & wire_nl1iOi_dataout & wire_nl1iOi_dataout);
	wire_ni111i_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	ni111i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni111i_data,
		o => wire_ni111i_o,
		sel => wire_ni111i_sel
	  );
	wire_ni111l_data <= ( wire_nl1iOl_dataout & wire_niOOll_dataout & wire_nl1iOl_dataout & wire_nl11lO_dataout & wire_nl1iOl_dataout & wire_niOOll_dataout & wire_nl1iOl_dataout & wire_nl10Oi_dataout & wire_nl1iOl_dataout & wire_niOOll_dataout & wire_nl1iOl_dataout & wire_nl11lO_dataout & wire_nl1iOl_dataout & wire_niOOll_dataout & wire_nl1iOl_dataout & wire_nl1iOl_dataout);
	wire_ni111l_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	ni111l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni111l_data,
		o => wire_ni111l_o,
		sel => wire_ni111l_sel
	  );
	wire_ni111O_data <= ( wire_nl1iOO_dataout & wire_niOOlO_dataout & wire_nl1iOO_dataout & wire_nl11Oi_dataout & wire_nl1iOO_dataout & wire_niOOlO_dataout & wire_nl1iOO_dataout & wire_nl10Ol_dataout & wire_nl1iOO_dataout & wire_niOOlO_dataout & wire_nl1iOO_dataout & wire_nl11Oi_dataout & wire_nl1iOO_dataout & wire_niOOlO_dataout & wire_nl1iOO_dataout & wire_nl1iOO_dataout);
	wire_ni111O_sel <= ( niiOil & niiOii & niiO0O & niiO0l);
	ni111O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni111O_data,
		o => wire_ni111O_o,
		sel => wire_ni111O_sel
	  );
	wire_ni1i1l_data <= ( wire_nl10ll_dataout & wire_niOOiO_dataout & wire_nl10ll_dataout & wire_nl11li_dataout & wire_nl10ll_dataout & wire_niOOiO_dataout & wire_nl10ll_dataout & wire_nl10ll_dataout);
	wire_ni1i1l_sel <= ( wire_ni1lll_dataout & wire_ni1lli_dataout & wire_ni1liO_dataout);
	ni1i1l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_ni1i1l_data,
		o => wire_ni1i1l_o,
		sel => wire_ni1i1l_sel
	  );
	wire_ni1l1O_data <= ( wire_nl1ilO_dataout & wire_niOOiO_dataout & wire_nl1ilO_dataout & wire_nl11li_dataout & wire_nl1ilO_dataout & wire_niOOiO_dataout & wire_nl1ilO_dataout & wire_nl10ll_dataout & wire_nl1ilO_dataout & wire_niOOiO_dataout & wire_nl1ilO_dataout & wire_nl11li_dataout & wire_nl1ilO_dataout & wire_niOOiO_dataout & wire_nl1ilO_dataout & wire_nl1ilO_dataout);
	wire_ni1l1O_sel <= ( wire_ni1llO_dataout & wire_ni1lll_dataout & wire_ni1lli_dataout & wire_ni1liO_dataout);
	ni1l1O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni1l1O_data,
		o => wire_ni1l1O_o,
		sel => wire_ni1l1O_sel
	  );
	wire_ni1lOi_data <= ( wire_ni1O1l_dataout & wire_ni000l_dataout & wire_ni0ili_dataout & "0" & wire_ni0lOO_dataout & wire_nii01l_dataout & wire_niiili_dataout & "0");
	wire_ni1lOi_sel <= ( rbytord_2sym_en & rbytorden(1 DOWNTO 0));
	ni1lOi :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_ni1lOi_data,
		o => wire_ni1lOi_o,
		sel => wire_ni1lOi_sel
	  );
	wire_ni1lOl_data <= ( wire_ni1Oli_dataout & wire_ni00li_dataout & wire_ni0iOO_dataout & "0" & wire_ni0Oli_dataout & wire_nii0iO_dataout & wire_niil1l_dataout & "0");
	wire_ni1lOl_sel <= ( rbytord_2sym_en & rbytorden(1 DOWNTO 0));
	ni1lOl :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_ni1lOl_data,
		o => wire_ni1lOl_o,
		sel => wire_ni1lOl_sel
	  );
	wire_ni1lOO_data <= ( wire_ni010i_dataout & wire_ni00OO_dataout & wire_ni0l0l_dataout & "0" & wire_ni0OOl_dataout & wire_nii0lO_dataout & wire_niil0l_dataout & "0");
	wire_ni1lOO_sel <= ( rbytord_2sym_en & rbytorden(1 DOWNTO 0));
	ni1lOO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_ni1lOO_data,
		o => wire_ni1lOO_o,
		sel => wire_ni1lOO_sel
	  );
	wire_ni1O1i_data <= ( wire_ni01Oi_dataout & wire_ni0i0O_dataout & wire_ni0lll_dataout & "0" & wire_nii1li_dataout & wire_niii0l_dataout & wire_niilOi_dataout & "0");
	wire_ni1O1i_sel <= ( rbytord_2sym_en & rbytorden(1 DOWNTO 0));
	ni1O1i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_ni1O1i_data,
		o => wire_ni1O1i_o,
		sel => wire_ni1O1i_sel
	  );
	wire_nlO000i_data <= ( wire_n00iiO_dataout & wire_n0lOli_dataout & wire_n10O1l_dataout & wire_n1O1Oi_dataout & wire_nlOi1il_dataout & wire_nlOOi0O_dataout & wire_nl10ll_dataout & wire_nl10ll_dataout);
	wire_nlO000i_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO000i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO000i_data,
		o => wire_nlO000i_o,
		sel => wire_nlO000i_sel
	  );
	wire_nlO000l_data <= ( wire_n00ili_dataout & wire_n0lOll_dataout & wire_n10O1O_dataout & wire_n1O1Ol_dataout & wire_nlOi1iO_dataout & wire_nlOOiii_dataout & wire_nl10lO_dataout & wire_nl10lO_dataout);
	wire_nlO000l_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO000l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO000l_data,
		o => wire_nlO000l_o,
		sel => wire_nlO000l_sel
	  );
	wire_nlO000O_data <= ( wire_n00ill_dataout & wire_n0lOlO_dataout & wire_n10O0i_dataout & wire_n1O1OO_dataout & wire_nlOi1li_dataout & wire_nlOOiil_dataout & wire_nl10Oi_dataout & wire_nl10Oi_dataout);
	wire_nlO000O_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO000O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO000O_data,
		o => wire_nlO000O_o,
		sel => wire_nlO000O_sel
	  );
	wire_nlO001i_data <= ( wire_n00i0O_dataout & wire_n0lOii_dataout & wire_n10lOl_dataout & wire_n1O1li_dataout & wire_nlOi10l_dataout & wire_nlOOi1O_dataout & wire_nl10il_dataout & wire_nl10il_dataout);
	wire_nlO001i_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO001i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO001i_data,
		o => wire_nlO001i_o,
		sel => wire_nlO001i_sel
	  );
	wire_nlO001l_data <= ( wire_n00iii_dataout & wire_n0lOil_dataout & wire_n10lOO_dataout & wire_n1O1ll_dataout & wire_nlOi10O_dataout & wire_nlOOi0i_dataout & wire_nl10iO_dataout & wire_nl10iO_dataout);
	wire_nlO001l_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO001l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO001l_data,
		o => wire_nlO001l_o,
		sel => wire_nlO001l_sel
	  );
	wire_nlO001O_data <= ( wire_n00iil_dataout & wire_n0lOiO_dataout & wire_n10O1i_dataout & wire_n1O1lO_dataout & wire_nlOi1ii_dataout & wire_nlOOi0l_dataout & wire_nl10li_dataout & wire_nl10li_dataout);
	wire_nlO001O_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO001O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO001O_data,
		o => wire_nlO001O_o,
		sel => wire_nlO001O_sel
	  );
	wire_nlO00ii_data <= ( wire_n00ilO_dataout & wire_n0lOOi_dataout & wire_n10O0l_dataout & wire_n1O01i_dataout & wire_nlOi1ll_dataout & wire_nlOOiiO_dataout & wire_nl10Ol_dataout & wire_nl10Ol_dataout);
	wire_nlO00ii_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO00ii :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO00ii_data,
		o => wire_nlO00ii_o,
		sel => wire_nlO00ii_sel
	  );
	wire_nlO00il_data <= ( wire_n00iOi_dataout & wire_n0lOOl_dataout & wire_n10O0O_dataout & wire_n1O01l_dataout & wire_nlOi1lO_dataout & wire_nlOOili_dataout & wire_nl10OO_dataout & wire_nl10OO_dataout);
	wire_nlO00il_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO00il :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO00il_data,
		o => wire_nlO00il_o,
		sel => wire_nlO00il_sel
	  );
	wire_nlO00iO_data <= ( wire_n00iOl_dataout & wire_n0lOOO_dataout & wire_n10Oii_dataout & wire_n1O01O_dataout & wire_nlOi1Oi_dataout & wire_nlOOill_dataout & wire_nl1i1i_dataout & wire_nl1i1i_dataout);
	wire_nlO00iO_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO00iO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO00iO_data,
		o => wire_nlO00iO_o,
		sel => wire_nlO00iO_sel
	  );
	wire_nlO00li_data <= ( wire_n00iOO_dataout & wire_n0O11i_dataout & wire_n10Oil_dataout & wire_n1O00i_dataout & wire_nlOi1Ol_dataout & wire_nlOOilO_dataout & wire_nl1i1l_dataout & wire_nl1i1l_dataout);
	wire_nlO00li_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO00li :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO00li_data,
		o => wire_nlO00li_o,
		sel => wire_nlO00li_sel
	  );
	wire_nlO00ll_data <= ( wire_n00l1i_dataout & wire_n0O11l_dataout & wire_n10OiO_dataout & wire_n1O00l_dataout & wire_nlOi1OO_dataout & wire_nlOOiOi_dataout & wire_nl1i1O_dataout & wire_nl1i1O_dataout);
	wire_nlO00ll_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO00ll :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO00ll_data,
		o => wire_nlO00ll_o,
		sel => wire_nlO00ll_sel
	  );
	wire_nlO00lO_data <= ( wire_n00l1l_dataout & wire_n0O11O_dataout & wire_n10Oli_dataout & wire_n1O00O_dataout & wire_nlOi01i_dataout & wire_nlOOiOl_dataout & wire_nl1i0i_dataout & wire_nl1i0i_dataout);
	wire_nlO00lO_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO00lO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO00lO_data,
		o => wire_nlO00lO_o,
		sel => wire_nlO00lO_sel
	  );
	wire_nlO00Oi_data <= ( wire_n00l1O_dataout & wire_n0O10i_dataout & wire_n10Oll_dataout & wire_n1O0ii_dataout & wire_nlOi01l_dataout & wire_nlOOiOO_dataout & wire_nl1i0l_dataout & wire_nl1i0l_dataout);
	wire_nlO00Oi_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO00Oi :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO00Oi_data,
		o => wire_nlO00Oi_o,
		sel => wire_nlO00Oi_sel
	  );
	wire_nlO00Ol_data <= ( wire_n00l0i_dataout & wire_n0O10l_dataout & wire_n10OlO_dataout & wire_n1O0il_dataout & wire_nlOi01O_dataout & wire_nlOOl1i_dataout & wire_nl1i0O_dataout & wire_nl1i0O_dataout);
	wire_nlO00Ol_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO00Ol :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO00Ol_data,
		o => wire_nlO00Ol_o,
		sel => wire_nlO00Ol_sel
	  );
	wire_nlO00OO_data <= ( wire_n00l0l_dataout & wire_n0O10O_dataout & wire_n10OOi_dataout & wire_n1O0iO_dataout & wire_nlOi00i_dataout & wire_nlOOl1l_dataout & wire_nl1iii_dataout & wire_nl1iii_dataout);
	wire_nlO00OO_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO00OO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO00OO_data,
		o => wire_nlO00OO_o,
		sel => wire_nlO00OO_sel
	  );
	wire_nlO010i_data <= ( wire_n000iO_dataout & wire_n0llli_dataout & wire_n10l1l_dataout & wire_n1lOOi_dataout & wire_nlO0Oil_dataout & wire_nlOO00O_dataout & wire_nl11ll_dataout & wire_nl11ll_dataout);
	wire_nlO010i_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO010i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO010i_data,
		o => wire_nlO010i_o,
		sel => wire_nlO010i_sel
	  );
	wire_nlO010l_data <= ( wire_n000li_dataout & wire_n0llll_dataout & wire_n10l1O_dataout & wire_n1lOOl_dataout & wire_nlO0OiO_dataout & wire_nlOO0ii_dataout & wire_nl11lO_dataout & wire_nl11lO_dataout);
	wire_nlO010l_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO010l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO010l_data,
		o => wire_nlO010l_o,
		sel => wire_nlO010l_sel
	  );
	wire_nlO010O_data <= ( wire_n000ll_dataout & wire_n0lllO_dataout & wire_n10l0i_dataout & wire_n1lOOO_dataout & wire_nlO0Oli_dataout & wire_nlOO0il_dataout & wire_nl11Oi_dataout & wire_nl11Oi_dataout);
	wire_nlO010O_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO010O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO010O_data,
		o => wire_nlO010O_o,
		sel => wire_nlO010O_sel
	  );
	wire_nlO011i_data <= ( wire_n0000O_dataout & wire_n0llii_dataout & wire_n10iOl_dataout & wire_n1lOli_dataout & wire_nlO0O0l_dataout & wire_nlOO01O_dataout & wire_nl11il_dataout & wire_nl11il_dataout);
	wire_nlO011i_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO011i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO011i_data,
		o => wire_nlO011i_o,
		sel => wire_nlO011i_sel
	  );
	wire_nlO011l_data <= ( wire_n000ii_dataout & wire_n0llil_dataout & wire_n10iOO_dataout & wire_n1lOll_dataout & wire_nlO0O0O_dataout & wire_nlOO00i_dataout & wire_nl11iO_dataout & wire_nl11iO_dataout);
	wire_nlO011l_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO011l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO011l_data,
		o => wire_nlO011l_o,
		sel => wire_nlO011l_sel
	  );
	wire_nlO011O_data <= ( wire_n000il_dataout & wire_n0lliO_dataout & wire_n10l1i_dataout & wire_n1lOlO_dataout & wire_nlO0Oii_dataout & wire_nlOO00l_dataout & wire_nl11li_dataout & wire_nl11li_dataout);
	wire_nlO011O_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO011O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO011O_data,
		o => wire_nlO011O_o,
		sel => wire_nlO011O_sel
	  );
	wire_nlO01ii_data <= ( wire_n000lO_dataout & wire_n0llOi_dataout & wire_n10l0l_dataout & wire_n1O11i_dataout & wire_nlO0Oll_dataout & wire_nlOO0iO_dataout & wire_nl11Ol_dataout & wire_nl11Ol_dataout);
	wire_nlO01ii_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO01ii :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO01ii_data,
		o => wire_nlO01ii_o,
		sel => wire_nlO01ii_sel
	  );
	wire_nlO01il_data <= ( wire_n000Oi_dataout & wire_n0llOl_dataout & wire_n10l0O_dataout & wire_n1O11l_dataout & wire_nlO0OlO_dataout & wire_nlOO0li_dataout & wire_nl11OO_dataout & wire_nl11OO_dataout);
	wire_nlO01il_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO01il :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO01il_data,
		o => wire_nlO01il_o,
		sel => wire_nlO01il_sel
	  );
	wire_nlO01iO_data <= ( wire_n000Ol_dataout & wire_n0llOO_dataout & wire_n10lii_dataout & wire_n1O11O_dataout & wire_nlO0OOi_dataout & wire_nlOO0ll_dataout & wire_nl101i_dataout & wire_nl101i_dataout);
	wire_nlO01iO_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO01iO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO01iO_data,
		o => wire_nlO01iO_o,
		sel => wire_nlO01iO_sel
	  );
	wire_nlO01li_data <= ( wire_n000OO_dataout & wire_n0lO1i_dataout & wire_n10lil_dataout & wire_n1O10i_dataout & wire_nlO0OOl_dataout & wire_nlOO0lO_dataout & wire_nl101l_dataout & wire_nl101l_dataout);
	wire_nlO01li_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO01li :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO01li_data,
		o => wire_nlO01li_o,
		sel => wire_nlO01li_sel
	  );
	wire_nlO01ll_data <= ( wire_n00i1i_dataout & wire_n0lO1l_dataout & wire_n10liO_dataout & wire_n1O10l_dataout & wire_nlO0OOO_dataout & wire_nlOO0Oi_dataout & wire_nl101O_dataout & wire_nl101O_dataout);
	wire_nlO01ll_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO01ll :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO01ll_data,
		o => wire_nlO01ll_o,
		sel => wire_nlO01ll_sel
	  );
	wire_nlO01lO_data <= ( wire_n00i1l_dataout & wire_n0lO1O_dataout & wire_n10lli_dataout & wire_n1O10O_dataout & wire_nlOi11i_dataout & wire_nlOO0Ol_dataout & wire_nl100i_dataout & wire_nl100i_dataout);
	wire_nlO01lO_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO01lO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO01lO_data,
		o => wire_nlO01lO_o,
		sel => wire_nlO01lO_sel
	  );
	wire_nlO01Oi_data <= ( wire_n00i1O_dataout & wire_n0lO0i_dataout & wire_n10lll_dataout & wire_n1O1ii_dataout & wire_nlOi11l_dataout & wire_nlOO0OO_dataout & wire_nl100l_dataout & wire_nl100l_dataout);
	wire_nlO01Oi_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO01Oi :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO01Oi_data,
		o => wire_nlO01Oi_o,
		sel => wire_nlO01Oi_sel
	  );
	wire_nlO01Ol_data <= ( wire_n00i0i_dataout & wire_n0lO0l_dataout & wire_n10llO_dataout & wire_n1O1il_dataout & wire_nlOi11O_dataout & wire_nlOOi1i_dataout & wire_nl100O_dataout & wire_nl100O_dataout);
	wire_nlO01Ol_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO01Ol :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO01Ol_data,
		o => wire_nlO01Ol_o,
		sel => wire_nlO01Ol_sel
	  );
	wire_nlO01OO_data <= ( wire_n00i0l_dataout & wire_n0lO0O_dataout & wire_n10lOi_dataout & wire_n1O1iO_dataout & wire_nlOi10i_dataout & wire_nlOOi1l_dataout & wire_nl10ii_dataout & wire_nl10ii_dataout);
	wire_nlO01OO_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO01OO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO01OO_data,
		o => wire_nlO01OO_o,
		sel => wire_nlO01OO_sel
	  );
	wire_nlO0i0i_data <= ( wire_n00liO_dataout & wire_n0O1li_dataout & wire_n1i11l_dataout & wire_n1O0Oi_dataout & wire_nlOi0il_dataout & wire_nlOOl0O_dataout & wire_nl1ill_dataout & wire_nl1ill_dataout);
	wire_nlO0i0i_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO0i0i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO0i0i_data,
		o => wire_nlO0i0i_o,
		sel => wire_nlO0i0i_sel
	  );
	wire_nlO0i0l_data <= ( wire_n00lli_dataout & wire_n0O1ll_dataout & wire_n1i11O_dataout & wire_n1O0Ol_dataout & wire_nlOi0iO_dataout & wire_nlOOlii_dataout & wire_nl1ilO_dataout & wire_nl1ilO_dataout);
	wire_nlO0i0l_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO0i0l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO0i0l_data,
		o => wire_nlO0i0l_o,
		sel => wire_nlO0i0l_sel
	  );
	wire_nlO0i0O_data <= ( wire_n00lll_dataout & wire_n0O1lO_dataout & wire_n1i10i_dataout & wire_n1O0OO_dataout & wire_nlOi0li_dataout & wire_nlOOlil_dataout & wire_nl1iOi_dataout & wire_nl1iOi_dataout);
	wire_nlO0i0O_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO0i0O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO0i0O_data,
		o => wire_nlO0i0O_o,
		sel => wire_nlO0i0O_sel
	  );
	wire_nlO0i1i_data <= ( wire_n00l0O_dataout & wire_n0O1ii_dataout & wire_n10OOl_dataout & wire_n1O0li_dataout & wire_nlOi00l_dataout & wire_nlOOl1O_dataout & wire_nl1iil_dataout & wire_nl1iil_dataout);
	wire_nlO0i1i_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO0i1i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO0i1i_data,
		o => wire_nlO0i1i_o,
		sel => wire_nlO0i1i_sel
	  );
	wire_nlO0i1l_data <= ( wire_n00lii_dataout & wire_n0O1il_dataout & wire_n10OOO_dataout & wire_n1O0ll_dataout & wire_nlOi00O_dataout & wire_nlOOl0i_dataout & wire_nl1iiO_dataout & wire_nl1iiO_dataout);
	wire_nlO0i1l_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO0i1l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO0i1l_data,
		o => wire_nlO0i1l_o,
		sel => wire_nlO0i1l_sel
	  );
	wire_nlO0i1O_data <= ( wire_n00lil_dataout & wire_n0O1iO_dataout & wire_n1i11i_dataout & wire_n1O0lO_dataout & wire_nlOi0ii_dataout & wire_nlOOl0l_dataout & wire_nl1ili_dataout & wire_nl1ili_dataout);
	wire_nlO0i1O_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO0i1O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO0i1O_data,
		o => wire_nlO0i1O_o,
		sel => wire_nlO0i1O_sel
	  );
	wire_nlO0iii_data <= ( wire_n00llO_dataout & wire_n0O1Oi_dataout & wire_n1i10l_dataout & wire_n1Oi1i_dataout & wire_nlOi0ll_dataout & wire_nlOOliO_dataout & wire_nl1iOl_dataout & wire_nl1iOl_dataout);
	wire_nlO0iii_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO0iii :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO0iii_data,
		o => wire_nlO0iii_o,
		sel => wire_nlO0iii_sel
	  );
	wire_nlO0iil_data <= ( wire_n00lOi_dataout & wire_n0O1Ol_dataout & wire_n1i10O_dataout & wire_n1Oi1l_dataout & wire_nlOi0lO_dataout & wire_nlOOlli_dataout & wire_nl1iOO_dataout & wire_nl1iOO_dataout);
	wire_nlO0iil_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO0iil :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO0iil_data,
		o => wire_nlO0iil_o,
		sel => wire_nlO0iil_sel
	  );
	wire_nlO0iiO_data <= ( wire_n00lOl_dataout & wire_n0O1OO_dataout & wire_n1i1ii_dataout & wire_n1Oi1O_dataout & wire_nlOi0Oi_dataout & wire_nlOOlll_dataout & wire_nl1l1i_dataout & wire_nl1l1i_dataout);
	wire_nlO0iiO_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO0iiO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO0iiO_data,
		o => wire_nlO0iiO_o,
		sel => wire_nlO0iiO_sel
	  );
	wire_nlO0ili_data <= ( wire_n00lOO_dataout & wire_n0O01i_dataout & wire_n1i1il_dataout & wire_n1Oi0i_dataout & wire_nlOi0Ol_dataout & wire_nlOOllO_dataout & wire_nl1l1l_dataout & wire_nl1l1l_dataout);
	wire_nlO0ili_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO0ili :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO0ili_data,
		o => wire_nlO0ili_o,
		sel => wire_nlO0ili_sel
	  );
	wire_nlO1lii_data <= ( wire_n01OlO_dataout & wire_n0l0Oi_dataout & wire_n1000l_dataout & wire_n1ll1i_dataout & wire_nlO0ill_dataout & wire_nlOlOiO_dataout & wire_niOlOl_dataout & wire_niOlOl_dataout);
	wire_nlO1lii_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1lii :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1lii_data,
		o => wire_nlO1lii_o,
		sel => wire_nlO1lii_sel
	  );
	wire_nlO1lil_data <= ( wire_n01OOi_dataout & wire_n0l0Ol_dataout & wire_n1000O_dataout & wire_n1ll1l_dataout & wire_nlO0ilO_dataout & wire_nlOlOli_dataout & wire_niOlOO_dataout & wire_niOlOO_dataout);
	wire_nlO1lil_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1lil :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1lil_data,
		o => wire_nlO1lil_o,
		sel => wire_nlO1lil_sel
	  );
	wire_nlO1liO_data <= ( wire_n01OOl_dataout & wire_n0l0OO_dataout & wire_n100ii_dataout & wire_n1ll1O_dataout & wire_nlO0iOi_dataout & wire_nlOlOll_dataout & wire_niOO1i_dataout & wire_niOO1i_dataout);
	wire_nlO1liO_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1liO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1liO_data,
		o => wire_nlO1liO_o,
		sel => wire_nlO1liO_sel
	  );
	wire_nlO1lli_data <= ( wire_n01OOO_dataout & wire_n0li1i_dataout & wire_n100il_dataout & wire_n1ll0i_dataout & wire_nlO0iOl_dataout & wire_nlOlOlO_dataout & wire_niOO1l_dataout & wire_niOO1l_dataout);
	wire_nlO1lli_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1lli :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1lli_data,
		o => wire_nlO1lli_o,
		sel => wire_nlO1lli_sel
	  );
	wire_nlO1lll_data <= ( wire_n0011i_dataout & wire_n0li1l_dataout & wire_n100iO_dataout & wire_n1ll0l_dataout & wire_nlO0iOO_dataout & wire_nlOlOOi_dataout & wire_niOO1O_dataout & wire_niOO1O_dataout);
	wire_nlO1lll_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1lll :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1lll_data,
		o => wire_nlO1lll_o,
		sel => wire_nlO1lll_sel
	  );
	wire_nlO1llO_data <= ( wire_n0011l_dataout & wire_n0li1O_dataout & wire_n100li_dataout & wire_n1ll0O_dataout & wire_nlO0l1i_dataout & wire_nlOlOOl_dataout & wire_niOO0i_dataout & wire_niOO0i_dataout);
	wire_nlO1llO_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1llO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1llO_data,
		o => wire_nlO1llO_o,
		sel => wire_nlO1llO_sel
	  );
	wire_nlO1lOi_data <= ( wire_n0011O_dataout & wire_n0li0i_dataout & wire_n100ll_dataout & wire_n1llii_dataout & wire_nlO0l1l_dataout & wire_nlOlOOO_dataout & wire_niOO0l_dataout & wire_niOO0l_dataout);
	wire_nlO1lOi_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1lOi :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1lOi_data,
		o => wire_nlO1lOi_o,
		sel => wire_nlO1lOi_sel
	  );
	wire_nlO1lOl_data <= ( wire_n0010i_dataout & wire_n0li0l_dataout & wire_n100lO_dataout & wire_n1llil_dataout & wire_nlO0l1O_dataout & wire_nlOO11i_dataout & wire_niOO0O_dataout & wire_niOO0O_dataout);
	wire_nlO1lOl_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1lOl :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1lOl_data,
		o => wire_nlO1lOl_o,
		sel => wire_nlO1lOl_sel
	  );
	wire_nlO1lOO_data <= ( wire_n0010l_dataout & wire_n0li0O_dataout & wire_n100Oi_dataout & wire_n1lliO_dataout & wire_nlO0l0i_dataout & wire_nlOO11l_dataout & wire_niOOii_dataout & wire_niOOii_dataout);
	wire_nlO1lOO_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1lOO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1lOO_data,
		o => wire_nlO1lOO_o,
		sel => wire_nlO1lOO_sel
	  );
	wire_nlO1O0i_data <= ( wire_n001iO_dataout & wire_n0lili_dataout & wire_n10i1l_dataout & wire_n1llOi_dataout & wire_nlO0lil_dataout & wire_nlOO10O_dataout & wire_niOOll_dataout & wire_niOOll_dataout);
	wire_nlO1O0i_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1O0i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1O0i_data,
		o => wire_nlO1O0i_o,
		sel => wire_nlO1O0i_sel
	  );
	wire_nlO1O0l_data <= ( wire_n001li_dataout & wire_n0lill_dataout & wire_n10i1O_dataout & wire_n1llOl_dataout & wire_nlO0liO_dataout & wire_nlOO1ii_dataout & wire_niOOlO_dataout & wire_niOOlO_dataout);
	wire_nlO1O0l_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1O0l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1O0l_data,
		o => wire_nlO1O0l_o,
		sel => wire_nlO1O0l_sel
	  );
	wire_nlO1O0O_data <= ( wire_n001ll_dataout & wire_n0lilO_dataout & wire_n10i0i_dataout & wire_n1llOO_dataout & wire_nlO0lli_dataout & wire_nlOO1il_dataout & wire_niOOOi_dataout & wire_niOOOi_dataout);
	wire_nlO1O0O_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1O0O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1O0O_data,
		o => wire_nlO1O0O_o,
		sel => wire_nlO1O0O_sel
	  );
	wire_nlO1O1i_data <= ( wire_n0010O_dataout & wire_n0liii_dataout & wire_n100Ol_dataout & wire_n1llli_dataout & wire_nlO0l0l_dataout & wire_nlOO11O_dataout & wire_niOOil_dataout & wire_niOOil_dataout);
	wire_nlO1O1i_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1O1i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1O1i_data,
		o => wire_nlO1O1i_o,
		sel => wire_nlO1O1i_sel
	  );
	wire_nlO1O1l_data <= ( wire_n001ii_dataout & wire_n0liil_dataout & wire_n100OO_dataout & wire_n1llll_dataout & wire_nlO0l0O_dataout & wire_nlOO10i_dataout & wire_niOOiO_dataout & wire_niOOiO_dataout);
	wire_nlO1O1l_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1O1l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1O1l_data,
		o => wire_nlO1O1l_o,
		sel => wire_nlO1O1l_sel
	  );
	wire_nlO1O1O_data <= ( wire_n001il_dataout & wire_n0liiO_dataout & wire_n10i1i_dataout & wire_n1lllO_dataout & wire_nlO0lii_dataout & wire_nlOO10l_dataout & wire_niOOli_dataout & wire_niOOli_dataout);
	wire_nlO1O1O_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1O1O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1O1O_data,
		o => wire_nlO1O1O_o,
		sel => wire_nlO1O1O_sel
	  );
	wire_nlO1Oii_data <= ( wire_n001lO_dataout & wire_n0liOi_dataout & wire_n10i0l_dataout & wire_n1lO1i_dataout & wire_nlO0lll_dataout & wire_nlOO1iO_dataout & wire_niOOOl_dataout & wire_niOOOl_dataout);
	wire_nlO1Oii_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1Oii :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1Oii_data,
		o => wire_nlO1Oii_o,
		sel => wire_nlO1Oii_sel
	  );
	wire_nlO1Oil_data <= ( wire_n001Oi_dataout & wire_n0liOl_dataout & wire_n10i0O_dataout & wire_n1lO1l_dataout & wire_nlO0llO_dataout & wire_nlOO1li_dataout & wire_niOOOO_dataout & wire_niOOOO_dataout);
	wire_nlO1Oil_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1Oil :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1Oil_data,
		o => wire_nlO1Oil_o,
		sel => wire_nlO1Oil_sel
	  );
	wire_nlO1OiO_data <= ( wire_n001Ol_dataout & wire_n0liOO_dataout & wire_n10iii_dataout & wire_n1lO1O_dataout & wire_nlO0lOi_dataout & wire_nlOO1ll_dataout & wire_nl111i_dataout & wire_nl111i_dataout);
	wire_nlO1OiO_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1OiO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1OiO_data,
		o => wire_nlO1OiO_o,
		sel => wire_nlO1OiO_sel
	  );
	wire_nlO1Oli_data <= ( wire_n001OO_dataout & wire_n0ll1i_dataout & wire_n10iil_dataout & wire_n1lO0i_dataout & wire_nlO0lOl_dataout & wire_nlOO1lO_dataout & wire_nl111l_dataout & wire_nl111l_dataout);
	wire_nlO1Oli_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1Oli :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1Oli_data,
		o => wire_nlO1Oli_o,
		sel => wire_nlO1Oli_sel
	  );
	wire_nlO1Oll_data <= ( wire_n0001i_dataout & wire_n0ll1l_dataout & wire_n10iiO_dataout & wire_n1lO0l_dataout & wire_nlO0lOO_dataout & wire_nlOO1Oi_dataout & wire_nl111O_dataout & wire_nl111O_dataout);
	wire_nlO1Oll_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1Oll :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1Oll_data,
		o => wire_nlO1Oll_o,
		sel => wire_nlO1Oll_sel
	  );
	wire_nlO1OlO_data <= ( wire_n0001l_dataout & wire_n0ll1O_dataout & wire_n10ili_dataout & wire_n1lO0O_dataout & wire_nlO0O1i_dataout & wire_nlOO1Ol_dataout & wire_nl110i_dataout & wire_nl110i_dataout);
	wire_nlO1OlO_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1OlO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1OlO_data,
		o => wire_nlO1OlO_o,
		sel => wire_nlO1OlO_sel
	  );
	wire_nlO1OOi_data <= ( wire_n0001O_dataout & wire_n0ll0i_dataout & wire_n10ill_dataout & wire_n1lOii_dataout & wire_nlO0O1l_dataout & wire_nlOO1OO_dataout & wire_nl110l_dataout & wire_nl110l_dataout);
	wire_nlO1OOi_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1OOi :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1OOi_data,
		o => wire_nlO1OOi_o,
		sel => wire_nlO1OOi_sel
	  );
	wire_nlO1OOl_data <= ( wire_n0000i_dataout & wire_n0ll0l_dataout & wire_n10ilO_dataout & wire_n1lOil_dataout & wire_nlO0O1O_dataout & wire_nlOO01i_dataout & wire_nl110O_dataout & wire_nl110O_dataout);
	wire_nlO1OOl_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1OOl :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1OOl_data,
		o => wire_nlO1OOl_o,
		sel => wire_nlO1OOl_sel
	  );
	wire_nlO1OOO_data <= ( wire_n0000l_dataout & wire_n0ll0O_dataout & wire_n10iOi_dataout & wire_n1lOiO_dataout & wire_nlO0O0i_dataout & wire_nlOO01l_dataout & wire_nl11ii_dataout & wire_nl11ii_dataout);
	wire_nlO1OOO_sel <= ( rwa_6g_en & rdwidth & rbytord_2sym_en);
	nlO1OOO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlO1OOO_data,
		o => wire_nlO1OOO_o,
		sel => wire_nlO1OOO_sel
	  );
	wire_niO1l_data <= ( wire_niOOl_dataout & wire_n1ill_w_lg_nll11l494w & nl110Ol & nl11iii & wire_w_lg_nl110lO485w & wire_n1ill_w_lg_nll11O482w & nl11i1O & nl11ili & wire_w_lg_nl11iiO473w & wire_w_lg_nl110lO470w);
	wire_niO1l_sel <= ( nl110Oi & wire_niOOi_w_lg_w_o_range465w467w & wire_niOOi_w_lg_w_o_range461w463w & wire_niOOi_w_lg_w_o_range457w459w & wire_niOOi_w_lg_w_o_range453w455w & wire_niOOi_w_lg_w_o_range449w451w & wire_niOOi_w_lg_w_o_range445w447w & wire_niOOi_w_lg_w_o_range441w443w & wire_niOOi_w_lg_w_o_range437w439w & wire_niOOi_w_lg_w_o_range432w434w);
	niO1l :  oper_selector
	  GENERIC MAP (
		width_data => 10,
		width_sel => 10
	  )
	  PORT MAP ( 
		data => wire_niO1l_data,
		o => wire_niO1l_o,
		sel => wire_niO1l_sel
	  );
	wire_nli1l_data <= ( wire_nliOl_dataout & wire_n1ill_w_lg_nliOOi312w & wire_n1ill_w_lg_nll10i308w & wire_nl11l1l40_w_lg_w_lg_q303w304w & wire_nl11liO34_w_lg_w_lg_q291w292w & wire_n1ill_w_lg_nliOOO284w & wire_nl11lOl30_w_lg_w_lg_q279w280w & wire_w_lg_nl11O0i271w & nl11O0l & wire_w_lg_w_lg_nl11OiO262w266w);
	wire_nli1l_sel <= ( nl1010i & wire_nliOi_w_lg_w_lg_w_o_range253w255w259w & wire_nliOi_w_lg_w_o_range249w251w & wire_nliOi_w_lg_w_o_range245w247w & wire_nl11OlO22_w_lg_w_lg_q242w243w & wire_nliOi_w_lg_w_o_range231w233w & wire_nl11OOO18_w_lg_w_lg_q228w229w & wire_nliOi_w_lg_w_lg_w_o_range217w219w223w & wire_nl1011O14_w_lg_w_lg_q214w215w & wire_nliOi_w_lg_w_o_range206w208w);
	nli1l :  oper_selector
	  GENERIC MAP (
		width_data => 10,
		width_sel => 10
	  )
	  PORT MAP ( 
		data => wire_nli1l_data,
		o => wire_nli1l_o,
		sel => wire_nli1l_sel
	  );
	wire_nl1000i_din <= ( rxstatus_int(2 DOWNTO 0) & rxvalid_int & phystatus_int & wire_nlO1ill_dataout & wire_nlO0ili_o & wire_nlO0iiO_o & wire_nlO0iil_o & wire_nlO0iii_o & wire_nlO0i0O_o & wire_nlO0i0l_o & wire_nlO0i0i_o & wire_nlO0i1O_o & wire_nlO0i1l_o & wire_nlO0i1i_o & wire_nlO00OO_o & wire_nlO00Ol_o & wire_nlO00Oi_o & wire_nlO00lO_o & wire_nlO00ll_o & wire_nlO00li_o & wire_nlO00iO_o & wire_nlO00il_o & wire_nlO00ii_o & wire_nlO000O_o & wire_nlO000l_o & wire_nlO000i_o & wire_nlO001O_o & wire_nlO001l_o & wire_nlO001i_o & wire_nlO01OO_o & wire_nlO01Ol_o & wire_nlO01Oi_o & wire_nlO01lO_o & wire_nlO01ll_o & wire_nlO01li_o & wire_nlO01iO_o & wire_nlO01il_o & wire_nlO01ii_o & wire_nlO010O_o & wire_nlO010l_o & wire_nlO010i_o & wire_nlO011O_o & wire_nlO011l_o & wire_nlO011i_o & wire_nlO1OOO_o & wire_nlO1OOl_o & wire_nlO1OOi_o & wire_nlO1OlO_o & wire_nlO1Oll_o & wire_nlO1Oli_o & wire_nlO1OiO_o & wire_nlO1Oil_o & wire_nlO1Oii_o & wire_nlO1O0O_o & wire_nlO1O0l_o & wire_nlO1O0i_o & wire_nlO1O1O_o & wire_nlO1O1l_o & wire_nlO1O1i_o & wire_nlO1lOO_o & wire_nlO1lOl_o & wire_nlO1lOi_o & wire_nlO1llO_o & wire_nlO1lll_o & wire_nlO1lli_o & wire_nlO1liO_o & wire_nlO1lil_o & wire_nlO1lii_o);
	wire_nl1000i_pcs_wrapback_in <= ( pcs_wrapback_in(69 DOWNTO 0));
	nl1000i :  stratixiv_hssi_rx_digis_ph_fifo
	  PORT MAP ( 
		data_out => wire_nl1000i_data_out,
		din => wire_nl1000i_din,
		en => wire_vcc,
		lowlatency_en => rrxfifo_lowlatency_en,
		pcs_wrapback_in => wire_nl1000i_pcs_wrapback_in,
		ph_fifo_empty => wire_nl1000i_ph_fifo_empty,
		ph_fifo_full => wire_nl1000i_ph_fifo_full,
		rauto_speed_ena => rauto_speed_ena,
		rd_clk => rx_rd_clk,
		re => niOiil,
		reset_pc_ptrs => reset_pc_ptrs,
		reset_pc_ptrs_centrl => reset_pc_ptrs_centrl,
		reset_pc_ptrs_quad_down => reset_pc_ptrs_quad_down,
		reset_pc_ptrs_quad_up => reset_pc_ptrs_quad_up,
		rindv_rx => rindv_rx,
		rmaster_rx => rmaster_rx,
		rmaster_up_rx => rmaster_up_rx,
		rpcs_wrapback_en => rpcs_wrapback_en,
		rphfifo_regmode_rx => rphfifo_regmode_rx,
		rptr_bin => wire_nl1000i_rptr_bin,
		rst_rclk => wire_nli01l_dataout,
		rst_wclk => wire_nli00O_dataout,
		scan_mode => scan_mode,
		we => nl010i,
		wptr_bin => wire_nl1000i_wptr_bin,
		wr_clk => rx_wr_clk
	  );

 END RTL; --stratixiv_hssi_rx_digi_rx_ctrl
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

--synthesis_resources = lut 99 mux21 139 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_rx_digi_dec_chnl_top IS 
	 PORT 
	 ( 
		 cascaded_8b10b_en	:	IN  STD_LOGIC;
		 clk_2	:	IN  STD_LOGIC;
		 data_in	:	IN  STD_LOGIC_VECTOR (31 DOWNTO 0);
		 data_in_valid	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 dec_ctl	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 dec_data	:	OUT  STD_LOGIC_VECTOR (15 DOWNTO 0);
		 dec_data_valid	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 disp_err_delay	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 disp_val_delay	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 invalid_code_delay	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 ovr_undflow	:	OUT  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 polinv	:	IN  STD_LOGIC;
		 r8b10b_dec_ibm_en	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 renpolinv	:	IN  STD_LOGIC;
		 rerr_flags_sel	:	IN  STD_LOGIC;
		 rlb_data	:	OUT  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 rrxpcsbypass_en	:	IN  STD_LOGIC;
		 rst	:	IN  STD_LOGIC;
		 sync_resync_delay	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 tenb_data	:	OUT  STD_LOGIC_VECTOR (19 DOWNTO 0)
	 ); 
 END stratixiv_hssi_rx_digi_dec_chnl_top;

 ARCHITECTURE RTL OF stratixiv_hssi_rx_digi_dec_chnl_top IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 n0l01O43	:	STD_LOGIC := '0';
	 SIGNAL	 n0l01O44	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0l01O44_w_lg_q176w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0l0li41	:	STD_LOGIC := '0';
	 SIGNAL	 n0l0li42	:	STD_LOGIC := '0';
	 SIGNAL	 n0l0lO39	:	STD_LOGIC := '0';
	 SIGNAL	 n0l0lO40	:	STD_LOGIC := '0';
	 SIGNAL	 n0li0l35	:	STD_LOGIC := '0';
	 SIGNAL	 n0li0l36	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0li0l36_w_lg_w_lg_q148w149w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0li0l36_w_lg_q148w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0li1i37	:	STD_LOGIC := '0';
	 SIGNAL	 n0li1i38	:	STD_LOGIC := '0';
	 SIGNAL	 n0liiO33	:	STD_LOGIC := '0';
	 SIGNAL	 n0liiO34	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0liiO34_w_lg_w_lg_q142w143w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0liiO34_w_lg_q142w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0liOi31	:	STD_LOGIC := '0';
	 SIGNAL	 n0liOi32	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0liOi32_w_lg_w_lg_q136w137w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0liOi32_w_lg_q136w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0ll0l27	:	STD_LOGIC := '0';
	 SIGNAL	 n0ll0l28	:	STD_LOGIC := '0';
	 SIGNAL	 n0ll1i29	:	STD_LOGIC := '0';
	 SIGNAL	 n0ll1i30	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0ll1i30_w_lg_w_lg_q131w132w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0ll1i30_w_lg_q131w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0llii25	:	STD_LOGIC := '0';
	 SIGNAL	 n0llii26	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0llii26_w_lg_w_lg_q118w119w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0llii26_w_lg_q118w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0llll23	:	STD_LOGIC := '0';
	 SIGNAL	 n0llll24	:	STD_LOGIC := '0';
	 SIGNAL	 n0llOi21	:	STD_LOGIC := '0';
	 SIGNAL	 n0llOi22	:	STD_LOGIC := '0';
	 SIGNAL	 n0lO0l17	:	STD_LOGIC := '0';
	 SIGNAL	 n0lO0l18	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0lO0l18_w_lg_w_lg_q94w95w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lO0l18_w_lg_q94w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0lO1O19	:	STD_LOGIC := '0';
	 SIGNAL	 n0lO1O20	:	STD_LOGIC := '0';
	 SIGNAL	 n0lOiO15	:	STD_LOGIC := '0';
	 SIGNAL	 n0lOiO16	:	STD_LOGIC := '0';
	 SIGNAL	 n0lOOO13	:	STD_LOGIC := '0';
	 SIGNAL	 n0lOOO14	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0lOOO14_w_lg_w_lg_q78w79w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lOOO14_w_lg_q78w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O00l1	:	STD_LOGIC := '0';
	 SIGNAL	 n0O00l2	:	STD_LOGIC := '0';
	 SIGNAL	 n0O01i5	:	STD_LOGIC := '0';
	 SIGNAL	 n0O01i6	:	STD_LOGIC := '0';
	 SIGNAL	 n0O01O3	:	STD_LOGIC := '0';
	 SIGNAL	 n0O01O4	:	STD_LOGIC := '0';
	 SIGNAL	 n0O10i11	:	STD_LOGIC := '0';
	 SIGNAL	 n0O10i12	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O10i12_w_lg_w_lg_q72w73w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O10i12_w_lg_q72w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O1ii10	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0O1ii10_w_lg_w_lg_q67w68w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O1ii10_w_lg_q67w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0O1ii9	:	STD_LOGIC := '0';
	 SIGNAL	 n0O1ll7	:	STD_LOGIC := '0';
	 SIGNAL	 n0O1ll8	:	STD_LOGIC := '0';
	 SIGNAL	n00O	:	STD_LOGIC := '0';
	 SIGNAL	n0Oi	:	STD_LOGIC := '0';
	 SIGNAL	ni1i	:	STD_LOGIC := '0';
	 SIGNAL	ni1l	:	STD_LOGIC := '0';
	 SIGNAL	ni1O	:	STD_LOGIC := '0';
	 SIGNAL	niiO	:	STD_LOGIC := '0';
	 SIGNAL	nili	:	STD_LOGIC := '0';
	 SIGNAL	nilO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nill_CLRN	:	STD_LOGIC;
	 SIGNAL	n00i	:	STD_LOGIC := '0';
	 SIGNAL	n00l	:	STD_LOGIC := '0';
	 SIGNAL	n01i	:	STD_LOGIC := '0';
	 SIGNAL	n01l	:	STD_LOGIC := '0';
	 SIGNAL	n01O	:	STD_LOGIC := '0';
	 SIGNAL	n0Ol	:	STD_LOGIC := '0';
	 SIGNAL	n0OO	:	STD_LOGIC := '0';
	 SIGNAL	n10i	:	STD_LOGIC := '0';
	 SIGNAL	n10l	:	STD_LOGIC := '0';
	 SIGNAL	n10O	:	STD_LOGIC := '0';
	 SIGNAL	n11i	:	STD_LOGIC := '0';
	 SIGNAL	n11l	:	STD_LOGIC := '0';
	 SIGNAL	n11O	:	STD_LOGIC := '0';
	 SIGNAL	n1ii	:	STD_LOGIC := '0';
	 SIGNAL	n1il	:	STD_LOGIC := '0';
	 SIGNAL	n1iO	:	STD_LOGIC := '0';
	 SIGNAL	n1li	:	STD_LOGIC := '0';
	 SIGNAL	n1ll	:	STD_LOGIC := '0';
	 SIGNAL	n1lO	:	STD_LOGIC := '0';
	 SIGNAL	n1Oi	:	STD_LOGIC := '0';
	 SIGNAL	n1Ol	:	STD_LOGIC := '0';
	 SIGNAL	n1OO	:	STD_LOGIC := '0';
	 SIGNAL	ni	:	STD_LOGIC := '0';
	 SIGNAL	ni0i	:	STD_LOGIC := '0';
	 SIGNAL	ni0l	:	STD_LOGIC := '0';
	 SIGNAL	ni0O	:	STD_LOGIC := '0';
	 SIGNAL	niii	:	STD_LOGIC := '0';
	 SIGNAL	niil	:	STD_LOGIC := '0';
	 SIGNAL	niOi	:	STD_LOGIC := '0';
	 SIGNAL	niOl	:	STD_LOGIC := '0';
	 SIGNAL	niOO	:	STD_LOGIC := '0';
	 SIGNAL	nl0i	:	STD_LOGIC := '0';
	 SIGNAL	nl0O	:	STD_LOGIC := '0';
	 SIGNAL	nl1i	:	STD_LOGIC := '0';
	 SIGNAL	nl1l	:	STD_LOGIC := '0';
	 SIGNAL	nl1O	:	STD_LOGIC := '0';
	 SIGNAL	nlO0l	:	STD_LOGIC := '0';
	 SIGNAL	nlO0O	:	STD_LOGIC := '0';
	 SIGNAL	nlOii	:	STD_LOGIC := '0';
	 SIGNAL	nlOil	:	STD_LOGIC := '0';
	 SIGNAL	nlOiO	:	STD_LOGIC := '0';
	 SIGNAL	nlOli	:	STD_LOGIC := '0';
	 SIGNAL	nlOll	:	STD_LOGIC := '0';
	 SIGNAL	nlOlO	:	STD_LOGIC := '0';
	 SIGNAL	nlOOi	:	STD_LOGIC := '0';
	 SIGNAL	nlOOl	:	STD_LOGIC := '0';
	 SIGNAL	nlOOO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlO_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nlO_w_lg_nl1O97w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO_w_lg_nl1O64w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n000i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0i_w_lg_w_lg_dataout363w1002w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0i_w_lg_w_lg_dataout363w997w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0i_w_lg_w_lg_dataout363w990w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0i_w_lg_w_lg_dataout363w987w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0i_w_lg_w_lg_dataout363w890w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0i_w_lg_w_lg_dataout363w885w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0i_w_lg_w_lg_dataout363w870w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0i_w_lg_w_lg_dataout363w867w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0i_w_lg_dataout874w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0i_w_lg_dataout893w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0i_w_lg_dataout896w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0i_w_lg_dataout363w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0l_w_lg_w_lg_dataout90w975w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l_w_lg_w_lg_dataout90w91w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l_w_lg_dataout1003w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l_w_lg_dataout998w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l_w_lg_dataout991w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l_w_lg_dataout988w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l_w_lg_dataout891w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l_w_lg_dataout886w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l_w_lg_dataout871w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l_w_lg_dataout868w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l_w_lg_dataout875w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l_w_lg_dataout894w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l_w_lg_dataout897w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l_w_lg_dataout846w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0l_w_lg_dataout90w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0liO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0liO_w_lg_dataout308w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0lli_w_lg_dataout345w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lli_w_lg_dataout319w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lli_w_lg_dataout316w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lli_w_lg_dataout296w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lli_w_lg_dataout298w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0lll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0lll_w_lg_w_lg_dataout299w344w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lll_w_lg_w_lg_dataout299w318w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lll_w_lg_w_lg_dataout299w315w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lll_w_lg_dataout295w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lll_w_lg_dataout299w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lll_w_lg_dataout326w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0llO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0llO_w_lg_dataout293w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0lOi_w_lg_w_lg_dataout292w294w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lOi_w_lg_w_lg_dataout292w335w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lOi_w_lg_dataout334w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lOi_w_lg_dataout292w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0lOi_w_lg_dataout325w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0O_w_lg_w_lg_dataout364w783w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O_w_lg_w_lg_dataout364w777w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O_w_lg_w_lg_dataout364w717w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O_w_lg_w_lg_dataout364w823w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O_w_lg_dataout847w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O_w_lg_dataout800w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O_w_lg_dataout794w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O_w_lg_dataout720w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0O_w_lg_dataout364w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n10il_w_lg_dataout381w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n10iO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n10iO_w_lg_dataout418w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10iO_w_lg_dataout392w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10iO_w_lg_dataout389w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10iO_w_lg_dataout369w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10iO_w_lg_dataout371w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n10li_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n10li_w_lg_w_lg_dataout372w417w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10li_w_lg_w_lg_dataout372w391w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10li_w_lg_w_lg_dataout372w388w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10li_w_lg_dataout368w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10li_w_lg_dataout372w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10li_w_lg_dataout399w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n10ll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n10ll_w_lg_dataout366w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n10lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n10lO_w_lg_w_lg_dataout365w367w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10lO_w_lg_w_lg_dataout365w408w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10lO_w_lg_dataout407w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10lO_w_lg_dataout365w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10lO_w_lg_dataout398w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n111i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1i_w_lg_w_lg_dataout511w513w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_w_lg_dataout430w542w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_dataout650w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_dataout645w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_dataout631w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_dataout628w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_dataout634w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_dataout653w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_dataout459w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_dataout656w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_dataout429w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_dataout452w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_dataout477w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_dataout511w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_dataout430w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i_w_lg_dataout508w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1l_w_lg_dataout361w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1l1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1l1i_w_lg_dataout356w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1l1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1l1l_w_lg_dataout358w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1l1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1l1O_w_lg_w_lg_dataout354w355w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l1O_w_lg_dataout359w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l1O_w_lg_dataout354w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1O_w_lg_w_lg_dataout362w873w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O_w_lg_w_lg_dataout362w856w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O_w_lg_dataout857w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O_w_lg_dataout362w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni0lOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0lOl_w_lg_dataout160w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni0lOl_w_lg_dataout128w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni10i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni10i_w_lg_w_lg_dataout281w282w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni10i_w_lg_dataout286w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni10i_w_lg_dataout281w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni11iO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni11iO_w_lg_w_lg_dataout104w971w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni11iO_w_lg_dataout104w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni11l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni11l_w_lg_dataout283w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni11O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni11O_w_lg_dataout285w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nii_w_lg_w_lg_dataout351w784w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_w_lg_dataout351w778w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_w_lg_dataout351w853w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_w_lg_w_lg_dataout351w780w781w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_w785w791w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w810w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_w_lg_dataout797w798w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_dataout824w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_dataout848w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_dataout801w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_dataout795w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_dataout721w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_dataout854w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_dataout737w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_dataout351w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_w_lg_w_lg_dataout351w778w779w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_w_lg_dataout795w796w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_w_lg_dataout351w780w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_w_lg_w_lg_w_lg_dataout351w778w779w782w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_w_lg_w_lg_dataout795w796w799w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w785w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_w_lg_w_lg_w_lg_dataout795w796w799w802w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nii_w_lg_dataout797w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nil_w_lg_w_lg_dataout347w831w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nil_w_lg_w_lg_dataout347w904w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nil_w_lg_dataout738w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nil_w_lg_dataout114w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nil_w_lg_dataout347w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niO_w_lg_w_lg_dataout348w727w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO_w_lg_w_lg_dataout348w750w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO_w_lg_w_lg_dataout348w908w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO_w_lg_w_lg_dataout348w765w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO_w_lg_w_lg_dataout348w742w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO_w_lg_dataout739w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO_w_lg_dataout115w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO_w_lg_dataout753w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO_w_lg_dataout909w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO_w_lg_dataout723w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO_w_lg_dataout746w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO_w_lg_dataout771w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO_w_lg_dataout348w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO_w_lg_w_lg_dataout348w788w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO_w_lg_dataout807w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niO00l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niO00l_w_lg_dataout60w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl110O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl110O_w_lg_w_lg_dataout171w680w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl110O_w_lg_dataout171w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli_w_lg_w_lg_dataout349w761w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli_w_lg_w_lg_dataout349w921w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli_w_lg_w_lg_dataout349w918w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli_w_lg_w_lg_dataout349w940w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli_w_lg_w_lg_dataout349w935w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli_w_lg_dataout924w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli_w_lg_dataout943w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli_w_lg_dataout740w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli_w_lg_dataout754w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli_w_lg_dataout946w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli_w_lg_dataout724w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli_w_lg_dataout747w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli_w_lg_dataout772w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli_w_lg_dataout760w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli_w_lg_dataout349w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli_w_lg_w_lg_dataout760w762w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlii_w_lg_dataout288w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlil_w_lg_w_lg_dataout289w582w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlil_w_lg_w_lg_dataout289w565w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlil_w_lg_dataout566w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlil_w_lg_dataout289w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nliO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliO_w_lg_w_lg_dataout290w711w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO_w_lg_w_lg_dataout290w706w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO_w_lg_w_lg_dataout290w699w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO_w_lg_w_lg_dataout290w696w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO_w_lg_w_lg_dataout290w599w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO_w_lg_w_lg_dataout290w594w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO_w_lg_w_lg_dataout290w579w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO_w_lg_w_lg_dataout290w576w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO_w_lg_dataout583w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO_w_lg_dataout602w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO_w_lg_dataout605w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO_w_lg_dataout290w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nll_w_lg_w_lg_dataout806w808w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll_w_lg_w_lg_dataout726w837w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll_w_lg_dataout922w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll_w_lg_dataout919w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll_w_lg_dataout941w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll_w_lg_dataout936w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll_w_lg_dataout925w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll_w_lg_dataout944w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll_w_lg_dataout755w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll_w_lg_dataout947w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll_w_lg_dataout725w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll_w_lg_dataout748w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll_w_lg_dataout773w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll_w_lg_dataout806w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll_w_lg_dataout726w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll_w_lg_dataout803w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlli_w_lg_w_lg_dataout157w684w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlli_w_lg_w_lg_dataout157w158w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlli_w_lg_dataout712w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlli_w_lg_dataout707w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlli_w_lg_dataout700w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlli_w_lg_dataout697w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlli_w_lg_dataout600w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlli_w_lg_dataout595w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlli_w_lg_dataout580w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlli_w_lg_dataout577w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlli_w_lg_dataout584w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlli_w_lg_dataout603w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlli_w_lg_dataout606w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlli_w_lg_dataout555w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlli_w_lg_dataout157w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nllii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlll_w_lg_w_lg_dataout291w488w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlll_w_lg_w_lg_dataout291w482w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlll_w_lg_w_lg_dataout291w421w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlll_w_lg_w_lg_dataout291w528w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlll_w_lg_dataout556w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlll_w_lg_dataout505w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlll_w_lg_dataout499w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlll_w_lg_dataout424w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlll_w_lg_dataout291w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nllli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllO_w_lg_w_lg_dataout278w489w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_w_lg_dataout278w483w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_w_lg_dataout278w562w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_w_lg_w_lg_dataout278w485w486w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_w490w496w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w515w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_w_lg_dataout502w503w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_dataout529w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_dataout557w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_dataout506w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_dataout500w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_dataout425w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_dataout563w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_dataout441w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_dataout278w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_w_lg_w_lg_dataout278w483w484w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_w_lg_dataout500w501w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_w_lg_dataout278w485w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_w_lg_w_lg_w_lg_dataout278w483w484w487w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_w_lg_w_lg_dataout500w501w504w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w490w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_w_lg_w_lg_w_lg_dataout500w501w504w507w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_dataout502w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO01l_w_lg_dataout62w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOi_w_lg_w_lg_dataout174w177w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOi_w_lg_w_lg_dataout274w536w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOi_w_lg_w_lg_dataout274w613w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOi_w_lg_dataout442w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOi_w_lg_dataout174w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOi_w_lg_dataout274w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOl_w_lg_w_lg_dataout275w431w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_w_lg_dataout275w454w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_w_lg_dataout275w617w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_w_lg_dataout275w469w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_w_lg_dataout275w446w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_dataout178w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_dataout443w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_dataout457w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_dataout618w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_dataout427w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_dataout450w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_dataout475w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_dataout275w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_w_lg_dataout275w493w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_dataout512w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlOlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOO_w_lg_w_lg_dataout276w649w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_dataout276w644w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_dataout276w630w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_dataout276w627w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_dataout276w465w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_dataout633w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_dataout652w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_dataout444w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_dataout458w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_dataout655w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_dataout428w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_dataout451w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_dataout476w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_dataout464w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_dataout276w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOO_w_lg_w_lg_dataout464w466w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlOO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_w_lg_n0llli116w120w121w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n0l00O179w180w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i00i789w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i00O786w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i0ii804w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i0il763w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0illi494w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0illO491w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ilOi509w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ilOl467w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0liil145w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0lilO664w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0lilO139w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0lOOl81w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O11O955w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O11O75w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O1Ol53w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_r8b10b_dec_ibm_en_range481w792w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_r8b10b_dec_ibm_en_range481w497w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_r8b10b_dec_ibm_en_range481w811w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_r8b10b_dec_ibm_en_range481w516w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i0il757w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i0ll768w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i0lO774w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i1ll830w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0il1l535w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ilOl461w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iO1l472w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iO1O478w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iOii405w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l10i332w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l11l353w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l1Ol280w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rst8w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_w_lg_w140w144w146w150w151w152w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_w140w144w146w150w151w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w80w82w83w84w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w140w144w146w150w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w80w82w83w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w140w144w146w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w80w82w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w140w144w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w80w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w140w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_w_lg_n0O1li65w69w70w74w76w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_n0ll0i129w133w134w138w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_n0O1li65w69w70w74w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_n0ll0i129w133w134w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_n0O1li65w69w70w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n0i00O787w790w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n0i0ii805w809w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n0illO492w495w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n0ilOi510w514w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n0ll0i129w133w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n0llli116w120w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n0lOil92w96w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n0O1li65w69w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i00O787w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i01l956w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i01l814w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i01O815w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i0ii805w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i1Oi841w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0i1Ol840w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0il0i546w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0il0l545w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ilil665w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ilil519w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0iliO520w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0illO492w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ilOi510w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l00O179w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0il169w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0iO170w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0l0OO159w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0li0i523w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ll0i521w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ll0i129w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0ll1O522w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0llli116w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0lO1i102w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0lO1l103w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0lOil92w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0lOlO818w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O1iO817w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O1li816w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O1li65w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0O1OO54w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  n00OiO :	STD_LOGIC;
	 SIGNAL  n00Oli :	STD_LOGIC;
	 SIGNAL  n00Oll :	STD_LOGIC;
	 SIGNAL  n00OlO :	STD_LOGIC;
	 SIGNAL  n00OOi :	STD_LOGIC;
	 SIGNAL  n00OOl :	STD_LOGIC;
	 SIGNAL  n00OOO :	STD_LOGIC;
	 SIGNAL  n0i00i :	STD_LOGIC;
	 SIGNAL  n0i00l :	STD_LOGIC;
	 SIGNAL  n0i00O :	STD_LOGIC;
	 SIGNAL  n0i01i :	STD_LOGIC;
	 SIGNAL  n0i01l :	STD_LOGIC;
	 SIGNAL  n0i01O :	STD_LOGIC;
	 SIGNAL  n0i0ii :	STD_LOGIC;
	 SIGNAL  n0i0il :	STD_LOGIC;
	 SIGNAL  n0i0iO :	STD_LOGIC;
	 SIGNAL  n0i0li :	STD_LOGIC;
	 SIGNAL  n0i0ll :	STD_LOGIC;
	 SIGNAL  n0i0lO :	STD_LOGIC;
	 SIGNAL  n0i0Oi :	STD_LOGIC;
	 SIGNAL  n0i0Ol :	STD_LOGIC;
	 SIGNAL  n0i0OO :	STD_LOGIC;
	 SIGNAL  n0i10i :	STD_LOGIC;
	 SIGNAL  n0i10l :	STD_LOGIC;
	 SIGNAL  n0i10O :	STD_LOGIC;
	 SIGNAL  n0i11i :	STD_LOGIC;
	 SIGNAL  n0i11l :	STD_LOGIC;
	 SIGNAL  n0i11O :	STD_LOGIC;
	 SIGNAL  n0i1ii :	STD_LOGIC;
	 SIGNAL  n0i1il :	STD_LOGIC;
	 SIGNAL  n0i1iO :	STD_LOGIC;
	 SIGNAL  n0i1li :	STD_LOGIC;
	 SIGNAL  n0i1ll :	STD_LOGIC;
	 SIGNAL  n0i1lO :	STD_LOGIC;
	 SIGNAL  n0i1Oi :	STD_LOGIC;
	 SIGNAL  n0i1Ol :	STD_LOGIC;
	 SIGNAL  n0i1OO :	STD_LOGIC;
	 SIGNAL  n0ii0i :	STD_LOGIC;
	 SIGNAL  n0ii0l :	STD_LOGIC;
	 SIGNAL  n0ii0O :	STD_LOGIC;
	 SIGNAL  n0ii1i :	STD_LOGIC;
	 SIGNAL  n0ii1l :	STD_LOGIC;
	 SIGNAL  n0ii1O :	STD_LOGIC;
	 SIGNAL  n0iiii :	STD_LOGIC;
	 SIGNAL  n0iiil :	STD_LOGIC;
	 SIGNAL  n0iiiO :	STD_LOGIC;
	 SIGNAL  n0iili :	STD_LOGIC;
	 SIGNAL  n0iill :	STD_LOGIC;
	 SIGNAL  n0iilO :	STD_LOGIC;
	 SIGNAL  n0iiOi :	STD_LOGIC;
	 SIGNAL  n0iiOl :	STD_LOGIC;
	 SIGNAL  n0iiOO :	STD_LOGIC;
	 SIGNAL  n0il0i :	STD_LOGIC;
	 SIGNAL  n0il0l :	STD_LOGIC;
	 SIGNAL  n0il0O :	STD_LOGIC;
	 SIGNAL  n0il1i :	STD_LOGIC;
	 SIGNAL  n0il1l :	STD_LOGIC;
	 SIGNAL  n0il1O :	STD_LOGIC;
	 SIGNAL  n0ilii :	STD_LOGIC;
	 SIGNAL  n0ilil :	STD_LOGIC;
	 SIGNAL  n0iliO :	STD_LOGIC;
	 SIGNAL  n0illi :	STD_LOGIC;
	 SIGNAL  n0illl :	STD_LOGIC;
	 SIGNAL  n0illO :	STD_LOGIC;
	 SIGNAL  n0ilOi :	STD_LOGIC;
	 SIGNAL  n0ilOl :	STD_LOGIC;
	 SIGNAL  n0ilOO :	STD_LOGIC;
	 SIGNAL  n0iO0i :	STD_LOGIC;
	 SIGNAL  n0iO0l :	STD_LOGIC;
	 SIGNAL  n0iO0O :	STD_LOGIC;
	 SIGNAL  n0iO1i :	STD_LOGIC;
	 SIGNAL  n0iO1l :	STD_LOGIC;
	 SIGNAL  n0iO1O :	STD_LOGIC;
	 SIGNAL  n0iOii :	STD_LOGIC;
	 SIGNAL  n0iOil :	STD_LOGIC;
	 SIGNAL  n0iOiO :	STD_LOGIC;
	 SIGNAL  n0iOli :	STD_LOGIC;
	 SIGNAL  n0iOll :	STD_LOGIC;
	 SIGNAL  n0iOlO :	STD_LOGIC;
	 SIGNAL  n0iOOi :	STD_LOGIC;
	 SIGNAL  n0iOOl :	STD_LOGIC;
	 SIGNAL  n0iOOO :	STD_LOGIC;
	 SIGNAL  n0l00l :	STD_LOGIC;
	 SIGNAL  n0l00O :	STD_LOGIC;
	 SIGNAL  n0l01i :	STD_LOGIC;
	 SIGNAL  n0l01l :	STD_LOGIC;
	 SIGNAL  n0l0ii :	STD_LOGIC;
	 SIGNAL  n0l0il :	STD_LOGIC;
	 SIGNAL  n0l0iO :	STD_LOGIC;
	 SIGNAL  n0l0Ol :	STD_LOGIC;
	 SIGNAL  n0l0OO :	STD_LOGIC;
	 SIGNAL  n0l10i :	STD_LOGIC;
	 SIGNAL  n0l10l :	STD_LOGIC;
	 SIGNAL  n0l10O :	STD_LOGIC;
	 SIGNAL  n0l11i :	STD_LOGIC;
	 SIGNAL  n0l11l :	STD_LOGIC;
	 SIGNAL  n0l11O :	STD_LOGIC;
	 SIGNAL  n0l1ii :	STD_LOGIC;
	 SIGNAL  n0l1il :	STD_LOGIC;
	 SIGNAL  n0l1iO :	STD_LOGIC;
	 SIGNAL  n0l1li :	STD_LOGIC;
	 SIGNAL  n0l1ll :	STD_LOGIC;
	 SIGNAL  n0l1lO :	STD_LOGIC;
	 SIGNAL  n0l1Oi :	STD_LOGIC;
	 SIGNAL  n0l1Ol :	STD_LOGIC;
	 SIGNAL  n0l1OO :	STD_LOGIC;
	 SIGNAL  n0li0i :	STD_LOGIC;
	 SIGNAL  n0li1O :	STD_LOGIC;
	 SIGNAL  n0liii :	STD_LOGIC;
	 SIGNAL  n0liil :	STD_LOGIC;
	 SIGNAL  n0lill :	STD_LOGIC;
	 SIGNAL  n0lilO :	STD_LOGIC;
	 SIGNAL  n0liOO :	STD_LOGIC;
	 SIGNAL  n0ll0i :	STD_LOGIC;
	 SIGNAL  n0ll1O :	STD_LOGIC;
	 SIGNAL  n0lliO :	STD_LOGIC;
	 SIGNAL  n0llli :	STD_LOGIC;
	 SIGNAL  n0llOO :	STD_LOGIC;
	 SIGNAL  n0lO1i :	STD_LOGIC;
	 SIGNAL  n0lO1l :	STD_LOGIC;
	 SIGNAL  n0lOii :	STD_LOGIC;
	 SIGNAL  n0lOil :	STD_LOGIC;
	 SIGNAL  n0lOll :	STD_LOGIC;
	 SIGNAL  n0lOlO :	STD_LOGIC;
	 SIGNAL  n0lOOi :	STD_LOGIC;
	 SIGNAL  n0lOOl :	STD_LOGIC;
	 SIGNAL  n0O00i :	STD_LOGIC;
	 SIGNAL  n0O01l :	STD_LOGIC;
	 SIGNAL  n0O10O :	STD_LOGIC;
	 SIGNAL  n0O11l :	STD_LOGIC;
	 SIGNAL  n0O11O :	STD_LOGIC;
	 SIGNAL  n0O1iO :	STD_LOGIC;
	 SIGNAL  n0O1li :	STD_LOGIC;
	 SIGNAL  n0O1Oi :	STD_LOGIC;
	 SIGNAL  n0O1Ol :	STD_LOGIC;
	 SIGNAL  n0O1OO :	STD_LOGIC;
	 SIGNAL  wire_w_r8b10b_dec_ibm_en_range481w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_w_lg_w_lg_w_lg_n0llli116w120w121w(0) <= wire_w_lg_w_lg_n0llli116w120w(0) AND wire_ni11iO_dataout;
	wire_w_lg_w_lg_n0l00O179w180w(0) <= wire_w_lg_n0l00O179w(0) AND wire_nl110O_dataout;
	wire_w_lg_n0i00i789w(0) <= n0i00i AND wire_niO_w_lg_w_lg_dataout348w788w(0);
	wire_w_lg_n0i00O786w(0) <= n0i00O AND n0i00i;
	wire_w_lg_n0i0ii804w(0) <= n0i0ii AND wire_nll_w_lg_dataout803w(0);
	wire_w_lg_n0i0il763w(0) <= n0i0il AND wire_nli_w_lg_w_lg_dataout760w762w(0);
	wire_w_lg_n0illi494w(0) <= n0illi AND wire_nlOl_w_lg_w_lg_dataout275w493w(0);
	wire_w_lg_n0illO491w(0) <= n0illO AND n0illi;
	wire_w_lg_n0ilOi509w(0) <= n0ilOi AND wire_n1i_w_lg_dataout508w(0);
	wire_w_lg_n0ilOl467w(0) <= n0ilOl AND wire_nlOO_w_lg_w_lg_dataout464w466w(0);
	wire_w_lg_n0liil145w(0) <= n0liil AND n0liii;
	wire_w_lg_n0lilO664w(0) <= n0lilO AND n0ii0O;
	wire_w_lg_n0lilO139w(0) <= n0lilO AND n0lill;
	wire_w_lg_n0lOOl81w(0) <= n0lOOl AND n0lOOi;
	wire_w_lg_n0O11O955w(0) <= n0O11O AND n00OOO;
	wire_w_lg_n0O11O75w(0) <= n0O11O AND n0O11l;
	wire_w_lg_n0O1Ol53w(0) <= n0O1Ol AND n0O1Oi;
	wire_w_lg_w_r8b10b_dec_ibm_en_range481w792w(0) <= wire_w_r8b10b_dec_ibm_en_range481w(0) AND wire_nii_w_lg_w785w791w(0);
	wire_w_lg_w_r8b10b_dec_ibm_en_range481w497w(0) <= wire_w_r8b10b_dec_ibm_en_range481w(0) AND wire_nllO_w_lg_w490w496w(0);
	wire_w_lg_w_r8b10b_dec_ibm_en_range481w811w(0) <= wire_w_r8b10b_dec_ibm_en_range481w(0) AND wire_nii_w810w(0);
	wire_w_lg_w_r8b10b_dec_ibm_en_range481w516w(0) <= wire_w_r8b10b_dec_ibm_en_range481w(0) AND wire_nllO_w515w(0);
	wire_w_lg_n0i0il757w(0) <= NOT n0i0il;
	wire_w_lg_n0i0ll768w(0) <= NOT n0i0ll;
	wire_w_lg_n0i0lO774w(0) <= NOT n0i0lO;
	wire_w_lg_n0i1ll830w(0) <= NOT n0i1ll;
	wire_w_lg_n0il1l535w(0) <= NOT n0il1l;
	wire_w_lg_n0ilOl461w(0) <= NOT n0ilOl;
	wire_w_lg_n0iO1l472w(0) <= NOT n0iO1l;
	wire_w_lg_n0iO1O478w(0) <= NOT n0iO1O;
	wire_w_lg_n0iOii405w(0) <= NOT n0iOii;
	wire_w_lg_n0l10i332w(0) <= NOT n0l10i;
	wire_w_lg_n0l11l353w(0) <= NOT n0l11l;
	wire_w_lg_n0l1Ol280w(0) <= NOT n0l1Ol;
	wire_w_lg_rst8w(0) <= NOT rst;
	wire_w_lg_w_lg_w_lg_w_lg_w_lg_w140w144w146w150w151w152w(0) <= wire_w_lg_w_lg_w_lg_w_lg_w140w144w146w150w151w(0) OR n0li1O;
	wire_w_lg_w_lg_w_lg_w_lg_w140w144w146w150w151w(0) <= wire_w_lg_w_lg_w_lg_w140w144w146w150w(0) OR n0li0i;
	wire_w_lg_w_lg_w_lg_w80w82w83w84w(0) <= wire_w_lg_w_lg_w80w82w83w(0) OR n0lOll;
	wire_w_lg_w_lg_w_lg_w140w144w146w150w(0) <= wire_w_lg_w_lg_w140w144w146w(0) OR wire_n0li0l36_w_lg_w_lg_q148w149w(0);
	wire_w_lg_w_lg_w80w82w83w(0) <= wire_w_lg_w80w82w(0) OR n0lOlO;
	wire_w_lg_w_lg_w140w144w146w(0) <= wire_w_lg_w140w144w(0) OR wire_w_lg_n0liil145w(0);
	wire_w_lg_w80w82w(0) <= wire_w80w(0) OR wire_w_lg_n0lOOl81w(0);
	wire_w_lg_w140w144w(0) <= wire_w140w(0) OR wire_n0liiO34_w_lg_w_lg_q142w143w(0);
	wire_w80w(0) <= wire_w_lg_w_lg_w_lg_w_lg_w_lg_n0O1li65w69w70w74w76w(0) OR wire_n0lOOO14_w_lg_w_lg_q78w79w(0);
	wire_w140w(0) <= wire_w_lg_w_lg_w_lg_w_lg_n0ll0i129w133w134w138w(0) OR wire_w_lg_n0lilO139w(0);
	wire_w_lg_w_lg_w_lg_w_lg_w_lg_n0O1li65w69w70w74w76w(0) <= wire_w_lg_w_lg_w_lg_w_lg_n0O1li65w69w70w74w(0) OR wire_w_lg_n0O11O75w(0);
	wire_w_lg_w_lg_w_lg_w_lg_n0ll0i129w133w134w138w(0) <= wire_w_lg_w_lg_w_lg_n0ll0i129w133w134w(0) OR wire_n0liOi32_w_lg_w_lg_q136w137w(0);
	wire_w_lg_w_lg_w_lg_w_lg_n0O1li65w69w70w74w(0) <= wire_w_lg_w_lg_w_lg_n0O1li65w69w70w(0) OR wire_n0O10i12_w_lg_w_lg_q72w73w(0);
	wire_w_lg_w_lg_w_lg_n0ll0i129w133w134w(0) <= wire_w_lg_w_lg_n0ll0i129w133w(0) OR n0liOO;
	wire_w_lg_w_lg_w_lg_n0O1li65w69w70w(0) <= wire_w_lg_w_lg_n0O1li65w69w(0) OR n0O10O;
	wire_w_lg_w_lg_n0i00O787w790w(0) <= wire_w_lg_n0i00O787w(0) OR wire_w_lg_n0i00i789w(0);
	wire_w_lg_w_lg_n0i0ii805w809w(0) <= wire_w_lg_n0i0ii805w(0) OR wire_nll_w_lg_w_lg_dataout806w808w(0);
	wire_w_lg_w_lg_n0illO492w495w(0) <= wire_w_lg_n0illO492w(0) OR wire_w_lg_n0illi494w(0);
	wire_w_lg_w_lg_n0ilOi510w514w(0) <= wire_w_lg_n0ilOi510w(0) OR wire_n1i_w_lg_w_lg_dataout511w513w(0);
	wire_w_lg_w_lg_n0ll0i129w133w(0) <= wire_w_lg_n0ll0i129w(0) OR wire_n0ll1i30_w_lg_w_lg_q131w132w(0);
	wire_w_lg_w_lg_n0llli116w120w(0) <= wire_w_lg_n0llli116w(0) OR wire_n0llii26_w_lg_w_lg_q118w119w(0);
	wire_w_lg_w_lg_n0lOil92w96w(0) <= wire_w_lg_n0lOil92w(0) OR wire_n0lO0l18_w_lg_w_lg_q94w95w(0);
	wire_w_lg_w_lg_n0O1li65w69w(0) <= wire_w_lg_n0O1li65w(0) OR wire_n0O1ii10_w_lg_w_lg_q67w68w(0);
	wire_w_lg_n0i00O787w(0) <= n0i00O OR wire_w_lg_n0i00O786w(0);
	wire_w_lg_n0i01l956w(0) <= n0i01l OR wire_w_lg_n0O11O955w(0);
	wire_w_lg_n0i01l814w(0) <= n0i01l OR n0i01i;
	wire_w_lg_n0i01O815w(0) <= n0i01O OR wire_w_lg_n0i01l814w(0);
	wire_w_lg_n0i0ii805w(0) <= n0i0ii OR wire_w_lg_n0i0ii804w(0);
	wire_w_lg_n0i1Oi841w(0) <= n0i1Oi OR wire_w_lg_n0i1Ol840w(0);
	wire_w_lg_n0i1Ol840w(0) <= n0i1Ol OR n0i1ll;
	wire_w_lg_n0il0i546w(0) <= n0il0i OR wire_w_lg_n0il0l545w(0);
	wire_w_lg_n0il0l545w(0) <= n0il0l OR n0il1l;
	wire_w_lg_n0ilil665w(0) <= n0ilil OR wire_w_lg_n0lilO664w(0);
	wire_w_lg_n0ilil519w(0) <= n0ilil OR n0ilii;
	wire_w_lg_n0iliO520w(0) <= n0iliO OR wire_w_lg_n0ilil519w(0);
	wire_w_lg_n0illO492w(0) <= n0illO OR wire_w_lg_n0illO491w(0);
	wire_w_lg_n0ilOi510w(0) <= n0ilOi OR wire_w_lg_n0ilOi509w(0);
	wire_w_lg_n0l00O179w(0) <= n0l00O OR wire_nlOl_w_lg_dataout178w(0);
	wire_w_lg_n0l0il169w(0) <= n0l0il OR n0l0ii;
	wire_w_lg_n0l0iO170w(0) <= n0l0iO OR wire_w_lg_n0l0il169w(0);
	wire_w_lg_n0l0OO159w(0) <= n0l0OO OR wire_nlli_w_lg_w_lg_dataout157w158w(0);
	wire_w_lg_n0li0i523w(0) <= n0li0i OR wire_w_lg_n0ll1O522w(0);
	wire_w_lg_n0ll0i521w(0) <= n0ll0i OR n0liOO;
	wire_w_lg_n0ll0i129w(0) <= n0ll0i OR n0ll1O;
	wire_w_lg_n0ll1O522w(0) <= n0ll1O OR wire_w_lg_n0ll0i521w(0);
	wire_w_lg_n0llli116w(0) <= n0llli OR wire_niO_w_lg_dataout115w(0);
	wire_w_lg_n0lO1i102w(0) <= n0lO1i OR n0llOO;
	wire_w_lg_n0lO1l103w(0) <= n0lO1l OR wire_w_lg_n0lO1i102w(0);
	wire_w_lg_n0lOil92w(0) <= n0lOil OR wire_n0l_w_lg_w_lg_dataout90w91w(0);
	wire_w_lg_n0lOlO818w(0) <= n0lOlO OR wire_w_lg_n0O1iO817w(0);
	wire_w_lg_n0O1iO817w(0) <= n0O1iO OR wire_w_lg_n0O1li816w(0);
	wire_w_lg_n0O1li816w(0) <= n0O1li OR n0O10O;
	wire_w_lg_n0O1li65w(0) <= n0O1li OR n0O1iO;
	wire_w_lg_n0O1OO54w(0) <= n0O1OO OR wire_w_lg_n0O1Ol53w(0);
	dec_ctl <= ( n0Oi & n00O);
	dec_data <= ( nl1l & nl1i & niOO & niOl & niOi & nilO & nili & niiO & niil & niii & ni0O & ni0l & ni0i & ni1O & ni1l & ni1i);
	dec_data_valid <= ( n0OO & n0Ol);
	disp_err_delay <= ( n01O & n01l);
	disp_val_delay <= ( n01i & n1OO);
	invalid_code_delay <= ( n00l & n00i);
	n00OiO <= (wire_n1O_dataout AND wire_n1l_dataout);
	n00Oli <= wire_n1O_w_lg_w_lg_dataout362w873w(0);
	n00Oll <= wire_n1O_w_lg_dataout857w(0);
	n00OlO <= wire_n1O_w_lg_w_lg_dataout362w856w(0);
	n00OOi <= (n0lOOl AND n00OOO);
	n00OOl <= (wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_w_lg_dataout363w(0) AND wire_n1O_w_lg_w_lg_dataout362w873w(0)));
	n00OOO <= wire_nii_w_lg_dataout737w(0);
	n0i00i <= (wire_nll_w_lg_dataout726w(0) AND wire_nli_w_lg_dataout349w(0));
	n0i00l <= ((((((wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_w_lg_dataout363w(0) AND (wire_n1O_dataout AND wire_n1l_dataout))) OR (wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_dataout AND n0i1iO))) OR (wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_dataout AND n0i1il))) OR wire_n0l_w_lg_dataout868w(0)) OR wire_n0l_w_lg_dataout871w(0)) OR wire_n0l_w_lg_dataout875w(0));
	n0i00O <= wire_niO_w_lg_w_lg_dataout348w727w(0);
	n0i01i <= (n0i11i AND n0lOOi);
	n0i01l <= ((n0i11i AND n00OOO) OR (n0i1lO AND n00OOO));
	n0i01O <= (n0i11i AND n0O11l);
	n0i0ii <= wire_niO_w_lg_dataout723w(0);
	n0i0il <= (wire_nii_w_lg_dataout848w(0) OR (wire_nii_w_lg_dataout351w(0) AND (wire_n0O_w_lg_dataout364w(0) AND (wire_n0l_w_lg_dataout90w(0) AND wire_n0i_w_lg_dataout363w(0)))));
	n0i0iO <= wire_nii_w_lg_w_lg_dataout351w853w(0);
	n0i0li <= wire_nii_w_lg_dataout854w(0);
	n0i0ll <= ((((wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_dataout AND n0i10O)) OR wire_n0l_w_lg_dataout891w(0)) OR wire_n0l_w_lg_dataout894w(0)) OR wire_n0l_w_lg_dataout897w(0));
	n0i0lO <= ((((wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_w_lg_dataout363w(0) AND wire_n1O_w_lg_w_lg_dataout362w856w(0))) OR (wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_w_lg_dataout363w(0) AND wire_n1O_w_lg_dataout857w(0)))) OR (wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_dataout AND n0i1ii))) OR wire_n0l_w_lg_dataout886w(0));
	n0i0Oi <= (wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_w_lg_dataout363w(0) AND wire_n1O_w_lg_w_lg_dataout362w873w(0)));
	n0i0Ol <= (wire_n0l_dataout AND (wire_n0i_dataout AND (wire_n1O_dataout AND wire_n1l_dataout)));
	n0i0OO <= (wire_nlil_dataout AND wire_nlii_dataout);
	n0i10i <= wire_niO_w_lg_dataout909w(0);
	n0i10l <= wire_niO_w_lg_w_lg_dataout348w908w(0);
	n0i10O <= (wire_n1O_dataout AND wire_n1l_dataout);
	n0i11i <= (wire_n0l_dataout AND (wire_n0i_dataout AND (wire_n1O_dataout AND wire_n1l_dataout)));
	n0i11l <= wire_niO_w_lg_dataout723w(0);
	n0i11O <= wire_niO_w_lg_w_lg_dataout348w727w(0);
	n0i1ii <= wire_n1O_w_lg_w_lg_dataout362w873w(0);
	n0i1il <= wire_n1O_w_lg_dataout857w(0);
	n0i1iO <= wire_n1O_w_lg_w_lg_dataout362w856w(0);
	n0i1li <= ((((wire_nll_w_lg_dataout726w(0) AND (wire_nli_dataout AND n0i11l)) OR wire_nll_w_lg_dataout941w(0)) OR wire_nll_w_lg_dataout944w(0)) OR wire_nll_w_lg_dataout947w(0));
	n0i1ll <= (wire_ni11iO_w_lg_w_lg_dataout104w971w(0) OR (wire_ni11iO_dataout AND n0O11l));
	n0i1lO <= ((((wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_dataout AND n00OiO)) OR wire_n0l_w_lg_dataout1003w(0)) OR wire_n0l_w_lg_dataout894w(0)) OR wire_n0l_w_lg_dataout897w(0));
	n0i1Oi <= (wire_nii_w_lg_dataout351w(0) AND (wire_n0O_w_lg_dataout364w(0) AND (wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_w_lg_dataout363w(0) AND (wire_n1O_dataout AND wire_n1l_dataout)))));
	n0i1Ol <= (wire_nii_dataout AND (wire_n0O_dataout AND wire_n0l_w_lg_dataout875w(0)));
	n0i1OO <= wire_nll_w_lg_dataout725w(0);
	n0ii0i <= (n0liil AND n0ii0O);
	n0ii0l <= (wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_w_lg_dataout290w(0) AND wire_nlil_w_lg_w_lg_dataout289w582w(0)));
	n0ii0O <= wire_nllO_w_lg_dataout441w(0);
	n0ii1i <= wire_nlil_w_lg_w_lg_dataout289w582w(0);
	n0ii1l <= wire_nlil_w_lg_dataout566w(0);
	n0ii1O <= wire_nlil_w_lg_w_lg_dataout289w565w(0);
	n0iiii <= (wire_nlli_dataout AND (wire_nliO_dataout AND (wire_nlil_dataout AND wire_nlii_dataout)));
	n0iiil <= wire_nlOl_w_lg_dataout427w(0);
	n0iiiO <= wire_nlOl_w_lg_w_lg_dataout275w431w(0);
	n0iili <= wire_nlOl_w_lg_dataout618w(0);
	n0iill <= wire_nlOl_w_lg_w_lg_dataout275w617w(0);
	n0iilO <= (wire_nlil_dataout AND wire_nlii_dataout);
	n0iiOi <= wire_nlil_w_lg_w_lg_dataout289w582w(0);
	n0iiOl <= wire_nlil_w_lg_dataout566w(0);
	n0iiOO <= wire_nlil_w_lg_w_lg_dataout289w565w(0);
	n0il0i <= (wire_nllO_w_lg_dataout278w(0) AND (wire_nlll_w_lg_dataout291w(0) AND (wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_w_lg_dataout290w(0) AND (wire_nlil_dataout AND wire_nlii_dataout)))));
	n0il0l <= (wire_nllO_dataout AND (wire_nlll_dataout AND wire_nlli_w_lg_dataout584w(0)));
	n0il0O <= wire_n1i_w_lg_dataout429w(0);
	n0il1i <= ((((wire_n1i_w_lg_dataout430w(0) AND (wire_nlOO_dataout AND n0iiil)) OR wire_n1i_w_lg_dataout650w(0)) OR wire_n1i_w_lg_dataout653w(0)) OR wire_n1i_w_lg_dataout656w(0));
	n0il1l <= (wire_nl110O_w_lg_w_lg_dataout171w680w(0) OR (wire_nl110O_dataout AND n0lill));
	n0il1O <= ((((wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_dataout AND n0i0OO)) OR wire_nlli_w_lg_dataout712w(0)) OR wire_nlli_w_lg_dataout603w(0)) OR wire_nlli_w_lg_dataout606w(0));
	n0ilii <= (n0iiii AND n0liii);
	n0ilil <= ((n0iiii AND n0ii0O) OR (n0il1O AND n0ii0O));
	n0iliO <= (n0iiii AND n0lill);
	n0illi <= (wire_n1i_w_lg_dataout430w(0) AND wire_nlOO_w_lg_dataout276w(0));
	n0illl <= ((((((wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_w_lg_dataout290w(0) AND (wire_nlil_dataout AND wire_nlii_dataout))) OR (wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_dataout AND n0iiOO))) OR (wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_dataout AND n0iiOl))) OR wire_nlli_w_lg_dataout577w(0)) OR wire_nlli_w_lg_dataout580w(0)) OR wire_nlli_w_lg_dataout584w(0));
	n0illO <= wire_nlOl_w_lg_w_lg_dataout275w431w(0);
	n0ilOi <= wire_nlOl_w_lg_dataout427w(0);
	n0ilOl <= (wire_nllO_w_lg_dataout557w(0) OR (wire_nllO_w_lg_dataout278w(0) AND (wire_nlll_w_lg_dataout291w(0) AND (wire_nlli_w_lg_dataout157w(0) AND wire_nliO_w_lg_dataout290w(0)))));
	n0ilOO <= wire_nllO_w_lg_w_lg_dataout278w562w(0);
	n0iO0i <= (wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_w_lg_dataout290w(0) AND wire_nlil_w_lg_w_lg_dataout289w582w(0)));
	n0iO0l <= (wire_nlli_dataout AND (wire_nliO_dataout AND (wire_nlil_dataout AND wire_nlii_dataout)));
	n0iO0O <= wire_n10lO_w_lg_w_lg_dataout365w367w(0);
	n0iO1i <= wire_nllO_w_lg_dataout563w(0);
	n0iO1l <= ((((wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_dataout AND n0iilO)) OR wire_nlli_w_lg_dataout600w(0)) OR wire_nlli_w_lg_dataout603w(0)) OR wire_nlli_w_lg_dataout606w(0));
	n0iO1O <= ((((wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_w_lg_dataout290w(0) AND wire_nlil_w_lg_w_lg_dataout289w565w(0))) OR (wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_w_lg_dataout290w(0) AND wire_nlil_w_lg_dataout566w(0)))) OR (wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_dataout AND n0iiOi))) OR wire_nlli_w_lg_dataout595w(0));
	n0iOii <= (wire_n10ll_dataout AND wire_n10li_dataout);
	n0iOil <= (wire_n10ll_w_lg_dataout366w(0) AND wire_n10li_w_lg_dataout372w(0));
	n0iOiO <= (((wire_n10il_w_lg_dataout381w(0) AND ((((((wire_n10iO_w_lg_dataout371w(0) AND (wire_n10li_w_lg_dataout372w(0) AND (wire_n10lO_dataout AND wire_n10ll_dataout))) OR (wire_n10iO_w_lg_dataout371w(0) AND (wire_n10li_dataout AND n0iOlO))) OR (wire_n10iO_w_lg_dataout371w(0) AND (wire_n10li_dataout AND n0iOll))) OR wire_n10iO_w_lg_dataout389w(0)) OR wire_n10iO_w_lg_dataout392w(0)) OR wire_n10iO_w_lg_dataout369w(0))) OR (wire_n10il_dataout AND n0iOli)) AND wire_n10li_w_lg_dataout399w(0));
	n0iOli <= ((((wire_n10iO_w_lg_dataout371w(0) AND (wire_n10li_w_lg_dataout372w(0) AND wire_n10lO_w_lg_dataout407w(0))) OR (wire_n10iO_w_lg_dataout371w(0) AND (wire_n10li_w_lg_dataout372w(0) AND wire_n10lO_w_lg_w_lg_dataout365w408w(0)))) OR (wire_n10iO_w_lg_dataout371w(0) AND (wire_n10li_dataout AND n0iO0O))) OR wire_n10iO_w_lg_dataout418w(0));
	n0iOll <= wire_n10lO_w_lg_w_lg_dataout365w408w(0);
	n0iOlO <= wire_n10lO_w_lg_dataout407w(0);
	n0iOOi <= (wire_n10il_dataout AND ((wire_n10lO_dataout XOR wire_n10ll_dataout) AND (wire_n10li_dataout XOR wire_n10iO_dataout)));
	n0iOOl <= (wire_n10il_dataout AND (wire_n10iO_w_lg_dataout371w(0) AND (wire_n10li_w_lg_dataout372w(0) AND (wire_n10lO_dataout AND wire_n10ll_dataout))));
	n0iOOO <= (wire_n1l1O_w_lg_w_lg_dataout354w355w(0) AND wire_n1l1i_w_lg_dataout356w(0));
	n0l00l <= ((((((wire_n1i_w_lg_dataout430w(0) AND (wire_nlOO_w_lg_dataout276w(0) AND wire_nlOl_w_lg_dataout427w(0))) OR (wire_n1i_w_lg_dataout430w(0) AND (wire_nlOO_dataout AND n0iill))) OR (wire_n1i_w_lg_dataout430w(0) AND (wire_nlOO_dataout AND n0iili))) OR wire_n1i_w_lg_dataout628w(0)) OR wire_n1i_w_lg_dataout631w(0)) OR wire_n1i_w_lg_dataout634w(0));
	n0l00O <= (n0il1i OR n0il0O);
	n0l01i <= (wire_n10il_w_lg_dataout381w(0) AND n0iOli);
	n0l01l <= (wire_n10il_dataout AND wire_n10iO_w_lg_dataout369w(0));
	n0l0ii <= (wire_n1i_w_lg_dataout430w(0) AND (wire_nlOO_w_lg_dataout276w(0) AND wire_nlOl_w_lg_w_lg_dataout275w431w(0)));
	n0l0il <= ((((wire_n1i_w_lg_dataout430w(0) AND (wire_nlOO_w_lg_dataout276w(0) AND wire_nlOl_w_lg_w_lg_dataout275w617w(0))) OR (wire_n1i_w_lg_dataout430w(0) AND (wire_nlOO_w_lg_dataout276w(0) AND wire_nlOl_w_lg_dataout618w(0)))) OR (wire_n1i_w_lg_dataout430w(0) AND (wire_nlOO_dataout AND n0iiiO))) OR wire_n1i_w_lg_dataout645w(0));
	n0l0iO <= (wire_nlOl_w_lg_dataout275w(0) AND wire_nlOi_w_lg_w_lg_dataout274w613w(0));
	n0l0Ol <= (n0il1O AND n0lill);
	n0l0OO <= (((wire_w_lg_n0ilil665w(0) OR (n0il1O AND n0liii)) OR n0ilii) OR n0iliO);
	n0l10i <= (wire_n0llO_dataout AND wire_n0lll_dataout);
	n0l10l <= (wire_n0llO_w_lg_dataout293w(0) AND wire_n0lll_w_lg_dataout299w(0));
	n0l10O <= (((wire_n0liO_w_lg_dataout308w(0) AND ((((((wire_n0lli_w_lg_dataout298w(0) AND (wire_n0lll_w_lg_dataout299w(0) AND (wire_n0lOi_dataout AND wire_n0llO_dataout))) OR (wire_n0lli_w_lg_dataout298w(0) AND (wire_n0lll_dataout AND n0l1iO))) OR (wire_n0lli_w_lg_dataout298w(0) AND (wire_n0lll_dataout AND n0l1il))) OR wire_n0lli_w_lg_dataout316w(0)) OR wire_n0lli_w_lg_dataout319w(0)) OR wire_n0lli_w_lg_dataout296w(0))) OR (wire_n0liO_dataout AND n0l1ii)) AND wire_n0lll_w_lg_dataout326w(0));
	n0l11i <= (wire_nii_w_lg_dataout351w(0) AND n0l01l);
	n0l11l <= (wire_niO_dataout XOR wire_nil_dataout);
	n0l11O <= wire_n0lOi_w_lg_w_lg_dataout292w294w(0);
	n0l1ii <= ((((wire_n0lli_w_lg_dataout298w(0) AND (wire_n0lll_w_lg_dataout299w(0) AND wire_n0lOi_w_lg_dataout334w(0))) OR (wire_n0lli_w_lg_dataout298w(0) AND (wire_n0lll_w_lg_dataout299w(0) AND wire_n0lOi_w_lg_w_lg_dataout292w335w(0)))) OR (wire_n0lli_w_lg_dataout298w(0) AND (wire_n0lll_dataout AND n0l11O))) OR wire_n0lli_w_lg_dataout345w(0));
	n0l1il <= wire_n0lOi_w_lg_w_lg_dataout292w335w(0);
	n0l1iO <= wire_n0lOi_w_lg_dataout334w(0);
	n0l1li <= (wire_n0liO_dataout AND ((wire_n0lOi_dataout XOR wire_n0llO_dataout) AND (wire_n0lll_dataout XOR wire_n0lli_dataout)));
	n0l1ll <= (wire_n0liO_dataout AND (wire_n0lli_w_lg_dataout298w(0) AND (wire_n0lll_w_lg_dataout299w(0) AND (wire_n0lOi_dataout AND wire_n0llO_dataout))));
	n0l1lO <= (wire_ni10i_w_lg_w_lg_dataout281w282w(0) AND wire_ni11l_w_lg_dataout283w(0));
	n0l1Oi <= (wire_nllO_w_lg_dataout278w(0) AND n0O1OO);
	n0l1Ol <= (wire_nlOl_dataout XOR wire_nlOi_dataout);
	n0l1OO <= (wire_n1l1O_w_lg_dataout359w(0) AND wire_n1l1i_w_lg_dataout356w(0));
	n0li0i <= (n0ii0l AND n0ii0O);
	n0li1O <= (wire_nlli_dataout AND n0ii0i);
	n0liii <= (wire_nllO_w_lg_w_lg_dataout278w562w(0) OR wire_nllO_w_lg_dataout563w(0));
	n0liil <= ((((wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_w_lg_dataout290w(0) AND wire_nlil_w_lg_w_lg_dataout289w565w(0))) OR (wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_w_lg_dataout290w(0) AND wire_nlil_w_lg_dataout566w(0)))) OR (wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_dataout AND n0ii1i))) OR wire_nlli_w_lg_dataout707w(0));
	n0lill <= (wire_nllO_w_lg_dataout278w(0) AND wire_nlll_w_lg_dataout291w(0));
	n0lilO <= ((((((wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_w_lg_dataout290w(0) AND (wire_nlil_dataout AND wire_nlii_dataout))) OR (wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_dataout AND n0ii1O))) OR (wire_nlli_w_lg_dataout157w(0) AND (wire_nliO_dataout AND n0ii1l))) OR wire_nlli_w_lg_dataout697w(0)) OR wire_nlli_w_lg_dataout700w(0)) OR wire_nlli_w_lg_dataout584w(0));
	n0liOO <= (n0liil AND n0lill);
	n0ll0i <= (n0ii0l AND n0lill);
	n0ll1O <= (n0ii0l AND n0liii);
	n0lliO <= ((((((wire_nll_w_lg_dataout726w(0) AND (wire_nli_w_lg_dataout349w(0) AND wire_niO_w_lg_dataout723w(0))) OR (wire_nll_w_lg_dataout726w(0) AND (wire_nli_dataout AND n0i10l))) OR (wire_nll_w_lg_dataout726w(0) AND (wire_nli_dataout AND n0i10i))) OR wire_nll_w_lg_dataout919w(0)) OR wire_nll_w_lg_dataout922w(0)) OR wire_nll_w_lg_dataout925w(0));
	n0llli <= (n0i1li OR n0i1OO);
	n0llOO <= (wire_nll_w_lg_dataout726w(0) AND (wire_nli_w_lg_dataout349w(0) AND wire_niO_w_lg_w_lg_dataout348w727w(0)));
	n0lO1i <= ((((wire_nll_w_lg_dataout726w(0) AND (wire_nli_w_lg_dataout349w(0) AND wire_niO_w_lg_w_lg_dataout348w908w(0))) OR (wire_nll_w_lg_dataout726w(0) AND (wire_nli_w_lg_dataout349w(0) AND wire_niO_w_lg_dataout909w(0)))) OR (wire_nll_w_lg_dataout726w(0) AND (wire_nli_dataout AND n0i11O))) OR wire_nll_w_lg_dataout936w(0));
	n0lO1l <= (wire_niO_w_lg_dataout348w(0) AND wire_nil_w_lg_w_lg_dataout347w904w(0));
	n0lOii <= (n0i1lO AND n0O11l);
	n0lOil <= (((wire_w_lg_n0i01l956w(0) OR (n0i1lO AND n0lOOi)) OR n0i01i) OR n0i01O);
	n0lOll <= (wire_n0l_dataout AND n00OOi);
	n0lOlO <= (n00OOl AND n00OOO);
	n0lOOi <= (wire_nii_w_lg_w_lg_dataout351w853w(0) OR wire_nii_w_lg_dataout854w(0));
	n0lOOl <= ((((wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_w_lg_dataout363w(0) AND wire_n1O_w_lg_w_lg_dataout362w856w(0))) OR (wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_w_lg_dataout363w(0) AND wire_n1O_w_lg_dataout857w(0)))) OR (wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_dataout AND n00Oli))) OR wire_n0l_w_lg_dataout998w(0));
	n0O00i <= ((renpolinv OR rerr_flags_sel) OR (NOT (n0O00l2 XOR n0O00l1)));
	n0O01l <= '1';
	n0O10O <= (n0lOOl AND n0O11l);
	n0O11l <= (wire_nii_w_lg_dataout351w(0) AND wire_n0O_w_lg_dataout364w(0));
	n0O11O <= ((((((wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_w_lg_dataout363w(0) AND (wire_n1O_dataout AND wire_n1l_dataout))) OR (wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_dataout AND n00OlO))) OR (wire_n0l_w_lg_dataout90w(0) AND (wire_n0i_dataout AND n00Oll))) OR wire_n0l_w_lg_dataout988w(0)) OR wire_n0l_w_lg_dataout991w(0)) OR wire_n0l_w_lg_dataout875w(0));
	n0O1iO <= (n00OOl AND n0lOOi);
	n0O1li <= (n00OOl AND n0O11l);
	n0O1Oi <= (wire_ni10i_w_lg_dataout286w(0) AND wire_ni11l_w_lg_dataout283w(0));
	n0O1Ol <= (wire_n0liO_w_lg_dataout308w(0) AND n0l1ii);
	n0O1OO <= (wire_n0liO_dataout AND wire_n0lli_w_lg_dataout296w(0));
	ovr_undflow <= ( n1lO & n1ll & n1li & n1iO);
	rlb_data <= ( wire_n1i_dataout & wire_nlOO_dataout & wire_nlOl_dataout & wire_nlOi_dataout & wire_nllO_dataout & wire_nlll_dataout & wire_nlli_dataout & wire_nliO_dataout & wire_nlil_dataout & wire_nlii_dataout & wire_nll_dataout & wire_nli_dataout & wire_niO_dataout & wire_nil_dataout & wire_nii_dataout & wire_n0O_dataout & wire_n0l_dataout & wire_n0i_dataout & wire_n1O_dataout & wire_n1l_dataout);
	sync_resync_delay <= ( n1Ol & n1Oi);
	tenb_data <= ( wire_nlO0i_dataout & wire_nlO1O_dataout & wire_nlO1l_dataout & wire_nlO1i_dataout & wire_nllOO_dataout & wire_nllOl_dataout & wire_nllOi_dataout & wire_nlllO_dataout & wire_nllll_dataout & wire_nllli_dataout & wire_nlliO_dataout & wire_nllil_dataout & wire_nllii_dataout & wire_nll0O_dataout & wire_nll0l_dataout & wire_nll0i_dataout & wire_nll1O_dataout & wire_nll1l_dataout & wire_nll1i_dataout & wire_nliOO_dataout);
	wire_w_r8b10b_dec_ibm_en_range481w(0) <= r8b10b_dec_ibm_en(1);
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0l01O43 <= n0l01O44;
		END IF;
		if (now = 0 ns) then
			n0l01O43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0l01O44 <= n0l01O43;
		END IF;
	END PROCESS;
	wire_n0l01O44_w_lg_q176w(0) <= n0l01O44 XOR n0l01O43;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0l0li41 <= n0l0li42;
		END IF;
		if (now = 0 ns) then
			n0l0li41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0l0li42 <= n0l0li41;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0l0lO39 <= n0l0lO40;
		END IF;
		if (now = 0 ns) then
			n0l0lO39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0l0lO40 <= n0l0lO39;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0li0l35 <= n0li0l36;
		END IF;
		if (now = 0 ns) then
			n0li0l35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0li0l36 <= n0li0l35;
		END IF;
	END PROCESS;
	wire_n0li0l36_w_lg_w_lg_q148w149w(0) <= NOT wire_n0li0l36_w_lg_q148w(0);
	wire_n0li0l36_w_lg_q148w(0) <= n0li0l36 XOR n0li0l35;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0li1i37 <= n0li1i38;
		END IF;
		if (now = 0 ns) then
			n0li1i37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0li1i38 <= n0li1i37;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0liiO33 <= n0liiO34;
		END IF;
		if (now = 0 ns) then
			n0liiO33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0liiO34 <= n0liiO33;
		END IF;
	END PROCESS;
	wire_n0liiO34_w_lg_w_lg_q142w143w(0) <= NOT wire_n0liiO34_w_lg_q142w(0);
	wire_n0liiO34_w_lg_q142w(0) <= n0liiO34 XOR n0liiO33;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0liOi31 <= n0liOi32;
		END IF;
		if (now = 0 ns) then
			n0liOi31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0liOi32 <= n0liOi31;
		END IF;
	END PROCESS;
	wire_n0liOi32_w_lg_w_lg_q136w137w(0) <= NOT wire_n0liOi32_w_lg_q136w(0);
	wire_n0liOi32_w_lg_q136w(0) <= n0liOi32 XOR n0liOi31;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0ll0l27 <= n0ll0l28;
		END IF;
		if (now = 0 ns) then
			n0ll0l27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0ll0l28 <= n0ll0l27;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0ll1i29 <= n0ll1i30;
		END IF;
		if (now = 0 ns) then
			n0ll1i29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0ll1i30 <= n0ll1i29;
		END IF;
	END PROCESS;
	wire_n0ll1i30_w_lg_w_lg_q131w132w(0) <= NOT wire_n0ll1i30_w_lg_q131w(0);
	wire_n0ll1i30_w_lg_q131w(0) <= n0ll1i30 XOR n0ll1i29;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0llii25 <= n0llii26;
		END IF;
		if (now = 0 ns) then
			n0llii25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0llii26 <= n0llii25;
		END IF;
	END PROCESS;
	wire_n0llii26_w_lg_w_lg_q118w119w(0) <= NOT wire_n0llii26_w_lg_q118w(0);
	wire_n0llii26_w_lg_q118w(0) <= n0llii26 XOR n0llii25;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0llll23 <= n0llll24;
		END IF;
		if (now = 0 ns) then
			n0llll23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0llll24 <= n0llll23;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0llOi21 <= n0llOi22;
		END IF;
		if (now = 0 ns) then
			n0llOi21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0llOi22 <= n0llOi21;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0lO0l17 <= n0lO0l18;
		END IF;
		if (now = 0 ns) then
			n0lO0l17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0lO0l18 <= n0lO0l17;
		END IF;
	END PROCESS;
	wire_n0lO0l18_w_lg_w_lg_q94w95w(0) <= NOT wire_n0lO0l18_w_lg_q94w(0);
	wire_n0lO0l18_w_lg_q94w(0) <= n0lO0l18 XOR n0lO0l17;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0lO1O19 <= n0lO1O20;
		END IF;
		if (now = 0 ns) then
			n0lO1O19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0lO1O20 <= n0lO1O19;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0lOiO15 <= n0lOiO16;
		END IF;
		if (now = 0 ns) then
			n0lOiO15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0lOiO16 <= n0lOiO15;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0lOOO13 <= n0lOOO14;
		END IF;
		if (now = 0 ns) then
			n0lOOO13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0lOOO14 <= n0lOOO13;
		END IF;
	END PROCESS;
	wire_n0lOOO14_w_lg_w_lg_q78w79w(0) <= NOT wire_n0lOOO14_w_lg_q78w(0);
	wire_n0lOOO14_w_lg_q78w(0) <= n0lOOO14 XOR n0lOOO13;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O00l1 <= n0O00l2;
		END IF;
		if (now = 0 ns) then
			n0O00l1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O00l2 <= n0O00l1;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O01i5 <= n0O01i6;
		END IF;
		if (now = 0 ns) then
			n0O01i5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O01i6 <= n0O01i5;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O01O3 <= n0O01O4;
		END IF;
		if (now = 0 ns) then
			n0O01O3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O01O4 <= n0O01O3;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O10i11 <= n0O10i12;
		END IF;
		if (now = 0 ns) then
			n0O10i11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O10i12 <= n0O10i11;
		END IF;
	END PROCESS;
	wire_n0O10i12_w_lg_w_lg_q72w73w(0) <= NOT wire_n0O10i12_w_lg_q72w(0);
	wire_n0O10i12_w_lg_q72w(0) <= n0O10i12 XOR n0O10i11;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O1ii10 <= n0O1ii9;
		END IF;
	END PROCESS;
	wire_n0O1ii10_w_lg_w_lg_q67w68w(0) <= NOT wire_n0O1ii10_w_lg_q67w(0);
	wire_n0O1ii10_w_lg_q67w(0) <= n0O1ii10 XOR n0O1ii9;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O1ii9 <= n0O1ii10;
		END IF;
		if (now = 0 ns) then
			n0O1ii9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O1ll7 <= n0O1ll8;
		END IF;
		if (now = 0 ns) then
			n0O1ll7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0O1ll8 <= n0O1ll7;
		END IF;
	END PROCESS;
	PROCESS (clk_2, rst, wire_nill_CLRN)
	BEGIN
		IF (rst = '1') THEN
				n00O <= '1';
				n0Oi <= '1';
				ni1i <= '1';
				ni1l <= '1';
				ni1O <= '1';
				niiO <= '1';
				nili <= '1';
				nilO <= '1';
		ELSIF (wire_nill_CLRN = '0') THEN
				n00O <= '0';
				n0Oi <= '0';
				ni1i <= '0';
				ni1l <= '0';
				ni1O <= '0';
				niiO <= '0';
				nili <= '0';
				nilO <= '0';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
				n00O <= (n0l01l OR (n0l01i AND n0l1OO));
				n0Oi <= (wire_w_lg_n0O1OO54w(0) OR (NOT (n0O1ll8 XOR n0O1ll7)));
				ni1i <= wire_nlOllO_dataout;
				ni1l <= wire_nlOlll_dataout;
				ni1O <= wire_nlOlli_dataout;
				niiO <= wire_n01Oi_dataout;
				nili <= wire_n01lO_dataout;
				nilO <= wire_n01ll_dataout;
		END IF;
		if (now = 0 ns) then
			n00O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0Oi <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni1i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni1l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni1O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			niiO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nili <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nilO <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nill_CLRN <= (n0O01i6 XOR n0O01i5);
	PROCESS (clk_2, wire_nlO_CLRN)
	BEGIN
		IF (wire_nlO_CLRN = '0') THEN
				n00i <= '0';
				n00l <= '0';
				n01i <= '0';
				n01l <= '0';
				n01O <= '0';
				n0Ol <= '0';
				n0OO <= '0';
				n10i <= '0';
				n10l <= '0';
				n10O <= '0';
				n11i <= '0';
				n11l <= '0';
				n11O <= '0';
				n1ii <= '0';
				n1il <= '0';
				n1iO <= '0';
				n1li <= '0';
				n1ll <= '0';
				n1lO <= '0';
				n1Oi <= '0';
				n1Ol <= '0';
				n1OO <= '0';
				ni <= '0';
				ni0i <= '0';
				ni0l <= '0';
				ni0O <= '0';
				niii <= '0';
				niil <= '0';
				niOi <= '0';
				niOl <= '0';
				niOO <= '0';
				nl0i <= '0';
				nl0O <= '0';
				nl1i <= '0';
				nl1l <= '0';
				nl1O <= '0';
				nlO0l <= '0';
				nlO0O <= '0';
				nlOii <= '0';
				nlOil <= '0';
				nlOiO <= '0';
				nlOli <= '0';
				nlOll <= '0';
				nlOlO <= '0';
				nlOOi <= '0';
				nlOOl <= '0';
				nlOOO <= '0';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
				n00i <= wire_n0lO_dataout;
				n00l <= wire_n0ll_dataout;
				n01i <= wire_n0ii_dataout;
				n01l <= wire_n0li_dataout;
				n01O <= wire_n0iO_dataout;
				n0Ol <= data_in_valid(0);
				n0OO <= data_in_valid(1);
				n10i <= data_in(21);
				n10l <= data_in(22);
				n10O <= data_in(23);
				n11i <= data_in(18);
				n11l <= data_in(19);
				n11O <= data_in(20);
				n1ii <= data_in(24);
				n1il <= data_in(25);
				n1iO <= data_in(14);
				n1li <= data_in(15);
				n1ll <= data_in(30);
				n1lO <= data_in(31);
				n1Oi <= data_in(11);
				n1Ol <= data_in(27);
				n1OO <= wire_n0il_dataout;
				ni <= (renpolinv AND polinv);
				ni0i <= wire_nlOliO_dataout;
				ni0l <= wire_nlOlil_dataout;
				ni0O <= wire_n1i0i_dataout;
				niii <= wire_n1i1O_dataout;
				niil <= wire_n1i1l_dataout;
				niOi <= wire_n01li_dataout;
				niOl <= wire_n01iO_dataout;
				niOO <= wire_n0O0l_dataout;
				nl0i <= ni;
				nl0O <= data_in(0);
				nl1i <= wire_n0O0i_dataout;
				nl1l <= wire_n0O1O_dataout;
				nl1O <= wire_nl0l_dataout;
				nlO0l <= data_in(1);
				nlO0O <= data_in(2);
				nlOii <= data_in(3);
				nlOil <= data_in(4);
				nlOiO <= data_in(5);
				nlOli <= data_in(6);
				nlOll <= data_in(7);
				nlOlO <= data_in(8);
				nlOOi <= data_in(9);
				nlOOl <= data_in(16);
				nlOOO <= data_in(17);
		END IF;
	END PROCESS;
	wire_nlO_CLRN <= ((n0O01O4 XOR n0O01O3) AND wire_w_lg_rst8w(0));
	wire_nlO_w_lg_nl1O97w(0) <= nl1O AND wire_w_lg_w_lg_n0lOil92w96w(0);
	wire_nlO_w_lg_nl1O64w(0) <= NOT nl1O;
	wire_n000i_dataout <= wire_n00OO_dataout WHEN n0l1li = '1'  ELSE wire_n00iO_dataout;
	wire_n000l_dataout <= wire_n0i1i_dataout WHEN n0l1li = '1'  ELSE wire_n00li_dataout;
	wire_n000O_dataout <= wire_n0i1i_dataout WHEN n0l1li = '1'  ELSE wire_n00ll_dataout;
	wire_n001i_dataout <= wire_n000O_dataout AND NOT(n0l1ll);
	wire_n001l_dataout <= wire_n00ii_dataout AND NOT(n0l1ll);
	wire_n001O_dataout <= wire_n00il_dataout AND NOT(n0l1ll);
	wire_n00ii_dataout <= wire_n0i1i_dataout WHEN n0l1li = '1'  ELSE wire_n00lO_dataout;
	wire_n00il_dataout <= wire_n0i1i_dataout WHEN n0l1li = '1'  ELSE wire_n00Oi_dataout;
	wire_n00iO_dataout <= wire_nlll_dataout WHEN n0l10O = '1'  ELSE n0O1Ol;
	wire_n00li_dataout <= wire_nlli_dataout WHEN n0l10O = '1'  ELSE wire_n0lli_w_lg_dataout298w(0);
	wire_n00ll_dataout <= wire_nliO_dataout WHEN n0l10O = '1'  ELSE wire_n0lll_w_lg_dataout299w(0);
	wire_n00lO_dataout <= wire_nlil_dataout WHEN n0l10O = '1'  ELSE wire_n0llO_w_lg_dataout293w(0);
	wire_n00Oi_dataout <= wire_nlii_dataout WHEN n0l10O = '1'  ELSE wire_n0lOi_w_lg_dataout292w(0);
	wire_n00OO_dataout <= wire_n0i1l_dataout AND NOT(n0l10l);
	wire_n01iO_dataout <= wire_n01Ol_dataout OR n0O1OO;
	wire_n01li_dataout <= wire_n01OO_dataout OR n0O1OO;
	wire_n01ll_dataout <= wire_n001i_dataout OR n0O1OO;
	wire_n01lO_dataout <= wire_n001l_dataout AND NOT(n0O1OO);
	wire_n01Oi_dataout <= wire_n001O_dataout AND NOT(n0O1OO);
	wire_n01Ol_dataout <= wire_n000i_dataout OR n0l1ll;
	wire_n01OO_dataout <= wire_n000l_dataout OR n0l1ll;
	wire_n0i_dataout <= (NOT data_in(2)) WHEN nl0i = '1'  ELSE data_in(2);
	wire_n0i_w_lg_w_lg_dataout363w1002w(0) <= wire_n0i_w_lg_dataout363w(0) AND n00OiO;
	wire_n0i_w_lg_w_lg_dataout363w997w(0) <= wire_n0i_w_lg_dataout363w(0) AND n00Oli;
	wire_n0i_w_lg_w_lg_dataout363w990w(0) <= wire_n0i_w_lg_dataout363w(0) AND n00Oll;
	wire_n0i_w_lg_w_lg_dataout363w987w(0) <= wire_n0i_w_lg_dataout363w(0) AND n00OlO;
	wire_n0i_w_lg_w_lg_dataout363w890w(0) <= wire_n0i_w_lg_dataout363w(0) AND n0i10O;
	wire_n0i_w_lg_w_lg_dataout363w885w(0) <= wire_n0i_w_lg_dataout363w(0) AND n0i1ii;
	wire_n0i_w_lg_w_lg_dataout363w870w(0) <= wire_n0i_w_lg_dataout363w(0) AND n0i1il;
	wire_n0i_w_lg_w_lg_dataout363w867w(0) <= wire_n0i_w_lg_dataout363w(0) AND n0i1iO;
	wire_n0i_w_lg_dataout874w(0) <= wire_n0i_dataout AND wire_n1O_w_lg_w_lg_dataout362w873w(0);
	wire_n0i_w_lg_dataout893w(0) <= wire_n0i_dataout AND wire_n1O_w_lg_w_lg_dataout362w856w(0);
	wire_n0i_w_lg_dataout896w(0) <= wire_n0i_dataout AND wire_n1O_w_lg_dataout857w(0);
	wire_n0i_w_lg_dataout363w(0) <= NOT wire_n0i_dataout;
	wire_n0i1i_dataout <= wire_w_lg_n0l10i332w(0) AND NOT(n0l10l);
	wire_n0i1l_dataout <= (NOT (wire_n0llO_dataout AND wire_n0lll_w_lg_dataout299w(0))) OR n0l10i;
	wire_n0ii_dataout <= wire_nl0lll_dataout WHEN n0O00i = '1'  ELSE data_in(29);
	wire_n0il_dataout <= wire_ni0lOl_dataout WHEN n0O00i = '1'  ELSE data_in(13);
	wire_n0iO_dataout <= ((((((wire_ni0lOl_w_lg_dataout128w(0) AND wire_w_lg_w_lg_w_lg_w_lg_w_lg_w140w144w146w150w151w152w(0)) AND (n0li1i38 XOR n0li1i37)) OR (wire_ni0lOl_w_lg_dataout160w(0) AND (n0l0lO40 XOR n0l0lO39))) OR (NOT (n0l0li42 XOR n0l0li41))) OR (wire_w_lg_n0l0iO170w(0) AND wire_nl110O_w_lg_dataout171w(0))) OR wire_w_lg_w_lg_n0l00O179w180w(0)) WHEN n0O00i = '1'  ELSE data_in(28);
	wire_n0l_dataout <= (NOT data_in(3)) WHEN nl0i = '1'  ELSE data_in(3);
	wire_n0l_w_lg_w_lg_dataout90w975w(0) <= wire_n0l_w_lg_dataout90w(0) AND n00OOi;
	wire_n0l_w_lg_w_lg_dataout90w91w(0) <= wire_n0l_w_lg_dataout90w(0) AND n0lOii;
	wire_n0l_w_lg_dataout1003w(0) <= wire_n0l_dataout AND wire_n0i_w_lg_w_lg_dataout363w1002w(0);
	wire_n0l_w_lg_dataout998w(0) <= wire_n0l_dataout AND wire_n0i_w_lg_w_lg_dataout363w997w(0);
	wire_n0l_w_lg_dataout991w(0) <= wire_n0l_dataout AND wire_n0i_w_lg_w_lg_dataout363w990w(0);
	wire_n0l_w_lg_dataout988w(0) <= wire_n0l_dataout AND wire_n0i_w_lg_w_lg_dataout363w987w(0);
	wire_n0l_w_lg_dataout891w(0) <= wire_n0l_dataout AND wire_n0i_w_lg_w_lg_dataout363w890w(0);
	wire_n0l_w_lg_dataout886w(0) <= wire_n0l_dataout AND wire_n0i_w_lg_w_lg_dataout363w885w(0);
	wire_n0l_w_lg_dataout871w(0) <= wire_n0l_dataout AND wire_n0i_w_lg_w_lg_dataout363w870w(0);
	wire_n0l_w_lg_dataout868w(0) <= wire_n0l_dataout AND wire_n0i_w_lg_w_lg_dataout363w867w(0);
	wire_n0l_w_lg_dataout875w(0) <= wire_n0l_dataout AND wire_n0i_w_lg_dataout874w(0);
	wire_n0l_w_lg_dataout894w(0) <= wire_n0l_dataout AND wire_n0i_w_lg_dataout893w(0);
	wire_n0l_w_lg_dataout897w(0) <= wire_n0l_dataout AND wire_n0i_w_lg_dataout896w(0);
	wire_n0l_w_lg_dataout846w(0) <= wire_n0l_dataout AND wire_n0i_dataout;
	wire_n0l_w_lg_dataout90w(0) <= NOT wire_n0l_dataout;
	wire_n0li_dataout <= ((((((wire_nlO_w_lg_nl1O64w(0) AND (wire_w_lg_w_lg_w_lg_w80w82w83w84w(0) OR (NOT (n0lOiO16 XOR n0lOiO15)))) OR (wire_nlO_w_lg_nl1O97w(0) AND (n0lO1O20 XOR n0lO1O19))) OR ((wire_w_lg_n0lO1l103w(0) AND wire_ni11iO_w_lg_dataout104w(0)) AND (n0llOi22 XOR n0llOi21))) OR (NOT (n0llll24 XOR n0llll23))) OR wire_w_lg_w_lg_w_lg_n0llli116w120w121w(0)) OR (NOT (n0ll0l28 XOR n0ll0l27))) WHEN n0O00i = '1'  ELSE data_in(12);
	wire_n0liO_dataout <= wire_nlll_dataout WHEN wire_nllO_dataout = '1'  ELSE wire_nlll_w_lg_dataout291w(0);
	wire_n0liO_w_lg_dataout308w(0) <= NOT wire_n0liO_dataout;
	wire_n0ll_dataout <= wire_nlO01l_w_lg_dataout62w(0) WHEN n0O00i = '1'  ELSE data_in(26);
	wire_n0lli_dataout <= wire_nlli_dataout WHEN wire_nllO_dataout = '1'  ELSE wire_nlli_w_lg_dataout157w(0);
	wire_n0lli_w_lg_dataout345w(0) <= wire_n0lli_dataout AND wire_n0lll_w_lg_w_lg_dataout299w344w(0);
	wire_n0lli_w_lg_dataout319w(0) <= wire_n0lli_dataout AND wire_n0lll_w_lg_w_lg_dataout299w318w(0);
	wire_n0lli_w_lg_dataout316w(0) <= wire_n0lli_dataout AND wire_n0lll_w_lg_w_lg_dataout299w315w(0);
	wire_n0lli_w_lg_dataout296w(0) <= wire_n0lli_dataout AND wire_n0lll_w_lg_dataout295w(0);
	wire_n0lli_w_lg_dataout298w(0) <= NOT wire_n0lli_dataout;
	wire_n0lll_dataout <= wire_nliO_dataout WHEN wire_nllO_dataout = '1'  ELSE wire_nliO_w_lg_dataout290w(0);
	wire_n0lll_w_lg_w_lg_dataout299w344w(0) <= wire_n0lll_w_lg_dataout299w(0) AND n0l11O;
	wire_n0lll_w_lg_w_lg_dataout299w318w(0) <= wire_n0lll_w_lg_dataout299w(0) AND n0l1il;
	wire_n0lll_w_lg_w_lg_dataout299w315w(0) <= wire_n0lll_w_lg_dataout299w(0) AND n0l1iO;
	wire_n0lll_w_lg_dataout295w(0) <= wire_n0lll_dataout AND wire_n0lOi_w_lg_w_lg_dataout292w294w(0);
	wire_n0lll_w_lg_dataout299w(0) <= NOT wire_n0lll_dataout;
	wire_n0lll_w_lg_dataout326w(0) <= wire_n0lll_dataout OR wire_n0lOi_w_lg_dataout325w(0);
	wire_n0llO_dataout <= wire_nlil_dataout WHEN wire_nllO_dataout = '1'  ELSE wire_nlil_w_lg_dataout289w(0);
	wire_n0llO_w_lg_dataout293w(0) <= NOT wire_n0llO_dataout;
	wire_n0lO_dataout <= wire_niO00l_w_lg_dataout60w(0) WHEN n0O00i = '1'  ELSE data_in(10);
	wire_n0lOi_dataout <= wire_nlii_dataout WHEN wire_nllO_dataout = '1'  ELSE wire_nlii_w_lg_dataout288w(0);
	wire_n0lOi_w_lg_w_lg_dataout292w294w(0) <= wire_n0lOi_w_lg_dataout292w(0) AND wire_n0llO_w_lg_dataout293w(0);
	wire_n0lOi_w_lg_w_lg_dataout292w335w(0) <= wire_n0lOi_w_lg_dataout292w(0) AND wire_n0llO_dataout;
	wire_n0lOi_w_lg_dataout334w(0) <= wire_n0lOi_dataout AND wire_n0llO_w_lg_dataout293w(0);
	wire_n0lOi_w_lg_dataout292w(0) <= NOT wire_n0lOi_dataout;
	wire_n0lOi_w_lg_dataout325w(0) <= wire_n0lOi_dataout OR wire_n0llO_dataout;
	wire_n0O_dataout <= (NOT data_in(4)) WHEN nl0i = '1'  ELSE data_in(4);
	wire_n0O_w_lg_w_lg_dataout364w783w(0) <= wire_n0O_w_lg_dataout364w(0) AND wire_n0l_w_lg_dataout90w(0);
	wire_n0O_w_lg_w_lg_dataout364w777w(0) <= wire_n0O_w_lg_dataout364w(0) AND n0i00l;
	wire_n0O_w_lg_w_lg_dataout364w717w(0) <= wire_n0O_w_lg_dataout364w(0) AND n0i0lO;
	wire_n0O_w_lg_w_lg_dataout364w823w(0) <= wire_n0O_w_lg_dataout364w(0) AND n0lOOl;
	wire_n0O_w_lg_dataout847w(0) <= wire_n0O_dataout AND wire_n0l_w_lg_dataout846w(0);
	wire_n0O_w_lg_dataout800w(0) <= wire_n0O_dataout AND wire_n0l_dataout;
	wire_n0O_w_lg_dataout794w(0) <= wire_n0O_dataout AND n0i00l;
	wire_n0O_w_lg_dataout720w(0) <= wire_n0O_dataout AND n0i0ll;
	wire_n0O_w_lg_dataout364w(0) <= NOT wire_n0O_dataout;
	wire_n0O0i_dataout <= wire_n0Oii_dataout AND NOT(n0l1lO);
	wire_n0O0l_dataout <= wire_n0Oil_dataout AND NOT(n0l1lO);
	wire_n0O0O_dataout <= wire_n0OiO_dataout OR n0O1Oi;
	wire_n0O1O_dataout <= wire_n0O0O_dataout AND NOT(n0l1lO);
	wire_n0Oii_dataout <= wire_n0Oli_dataout OR n0O1Oi;
	wire_n0Oil_dataout <= wire_n0Oll_dataout OR n0O1Oi;
	wire_n0OiO_dataout <= wire_ni11l_dataout WHEN wire_w_lg_n0l1Ol280w(0) = '1'  ELSE wire_n0OlO_dataout;
	wire_n0Oli_dataout <= wire_ni11O_dataout WHEN wire_w_lg_n0l1Ol280w(0) = '1'  ELSE wire_n0OOi_dataout;
	wire_n0Oll_dataout <= wire_ni10i_dataout WHEN wire_w_lg_n0l1Ol280w(0) = '1'  ELSE wire_n0OOl_dataout;
	wire_n0OlO_dataout <= wire_nlOO_w_lg_dataout276w(0) WHEN n0l1Oi = '1'  ELSE wire_nlOO_dataout;
	wire_n0OOi_dataout <= wire_nlOl_w_lg_dataout275w(0) WHEN n0l1Oi = '1'  ELSE wire_nlOl_dataout;
	wire_n0OOl_dataout <= wire_nlOi_w_lg_dataout274w(0) WHEN n0l1Oi = '1'  ELSE wire_nlOi_dataout;
	wire_n10il_dataout <= wire_n0O_dataout WHEN wire_nii_dataout = '1'  ELSE wire_n0O_w_lg_dataout364w(0);
	wire_n10il_w_lg_dataout381w(0) <= NOT wire_n10il_dataout;
	wire_n10iO_dataout <= wire_n0l_dataout WHEN wire_nii_dataout = '1'  ELSE wire_n0l_w_lg_dataout90w(0);
	wire_n10iO_w_lg_dataout418w(0) <= wire_n10iO_dataout AND wire_n10li_w_lg_w_lg_dataout372w417w(0);
	wire_n10iO_w_lg_dataout392w(0) <= wire_n10iO_dataout AND wire_n10li_w_lg_w_lg_dataout372w391w(0);
	wire_n10iO_w_lg_dataout389w(0) <= wire_n10iO_dataout AND wire_n10li_w_lg_w_lg_dataout372w388w(0);
	wire_n10iO_w_lg_dataout369w(0) <= wire_n10iO_dataout AND wire_n10li_w_lg_dataout368w(0);
	wire_n10iO_w_lg_dataout371w(0) <= NOT wire_n10iO_dataout;
	wire_n10li_dataout <= wire_n0i_dataout WHEN wire_nii_dataout = '1'  ELSE wire_n0i_w_lg_dataout363w(0);
	wire_n10li_w_lg_w_lg_dataout372w417w(0) <= wire_n10li_w_lg_dataout372w(0) AND n0iO0O;
	wire_n10li_w_lg_w_lg_dataout372w391w(0) <= wire_n10li_w_lg_dataout372w(0) AND n0iOll;
	wire_n10li_w_lg_w_lg_dataout372w388w(0) <= wire_n10li_w_lg_dataout372w(0) AND n0iOlO;
	wire_n10li_w_lg_dataout368w(0) <= wire_n10li_dataout AND wire_n10lO_w_lg_w_lg_dataout365w367w(0);
	wire_n10li_w_lg_dataout372w(0) <= NOT wire_n10li_dataout;
	wire_n10li_w_lg_dataout399w(0) <= wire_n10li_dataout OR wire_n10lO_w_lg_dataout398w(0);
	wire_n10ll_dataout <= wire_n1O_dataout WHEN wire_nii_dataout = '1'  ELSE wire_n1O_w_lg_dataout362w(0);
	wire_n10ll_w_lg_dataout366w(0) <= NOT wire_n10ll_dataout;
	wire_n10lO_dataout <= wire_n1l_dataout WHEN wire_nii_dataout = '1'  ELSE wire_n1l_w_lg_dataout361w(0);
	wire_n10lO_w_lg_w_lg_dataout365w367w(0) <= wire_n10lO_w_lg_dataout365w(0) AND wire_n10ll_w_lg_dataout366w(0);
	wire_n10lO_w_lg_w_lg_dataout365w408w(0) <= wire_n10lO_w_lg_dataout365w(0) AND wire_n10ll_dataout;
	wire_n10lO_w_lg_dataout407w(0) <= wire_n10lO_dataout AND wire_n10ll_w_lg_dataout366w(0);
	wire_n10lO_w_lg_dataout365w(0) <= NOT wire_n10lO_dataout;
	wire_n10lO_w_lg_dataout398w(0) <= wire_n10lO_dataout OR wire_n10ll_dataout;
	wire_n111i_dataout <= (NOT (wire_n10ll_dataout AND wire_n10li_w_lg_dataout372w(0))) OR n0iOii;
	wire_n1i_dataout <= (NOT data_in(25)) WHEN nl0i = '1'  ELSE data_in(25);
	wire_n1i_w_lg_w_lg_dataout511w513w(0) <= wire_n1i_w_lg_dataout511w(0) AND wire_nlOl_w_lg_dataout512w(0);
	wire_n1i_w_lg_w_lg_dataout430w542w(0) <= wire_n1i_w_lg_dataout430w(0) AND n0il1i;
	wire_n1i_w_lg_dataout650w(0) <= wire_n1i_dataout AND wire_nlOO_w_lg_w_lg_dataout276w649w(0);
	wire_n1i_w_lg_dataout645w(0) <= wire_n1i_dataout AND wire_nlOO_w_lg_w_lg_dataout276w644w(0);
	wire_n1i_w_lg_dataout631w(0) <= wire_n1i_dataout AND wire_nlOO_w_lg_w_lg_dataout276w630w(0);
	wire_n1i_w_lg_dataout628w(0) <= wire_n1i_dataout AND wire_nlOO_w_lg_w_lg_dataout276w627w(0);
	wire_n1i_w_lg_dataout634w(0) <= wire_n1i_dataout AND wire_nlOO_w_lg_dataout633w(0);
	wire_n1i_w_lg_dataout653w(0) <= wire_n1i_dataout AND wire_nlOO_w_lg_dataout652w(0);
	wire_n1i_w_lg_dataout459w(0) <= wire_n1i_dataout AND wire_nlOO_w_lg_dataout458w(0);
	wire_n1i_w_lg_dataout656w(0) <= wire_n1i_dataout AND wire_nlOO_w_lg_dataout655w(0);
	wire_n1i_w_lg_dataout429w(0) <= wire_n1i_dataout AND wire_nlOO_w_lg_dataout428w(0);
	wire_n1i_w_lg_dataout452w(0) <= wire_n1i_dataout AND wire_nlOO_w_lg_dataout451w(0);
	wire_n1i_w_lg_dataout477w(0) <= wire_n1i_dataout AND wire_nlOO_w_lg_dataout476w(0);
	wire_n1i_w_lg_dataout511w(0) <= wire_n1i_dataout AND wire_nlOO_dataout;
	wire_n1i_w_lg_dataout430w(0) <= NOT wire_n1i_dataout;
	wire_n1i_w_lg_dataout508w(0) <= wire_n1i_dataout OR wire_nlOO_dataout;
	wire_n1i0i_dataout <= wire_n1iii_dataout AND NOT(n0iOOO);
	wire_n1i0l_dataout <= wire_n1iil_dataout OR n0l1OO;
	wire_n1i0O_dataout <= wire_n1iiO_dataout OR n0l1OO;
	wire_n1i1l_dataout <= wire_n1i0l_dataout AND NOT(n0iOOO);
	wire_n1i1O_dataout <= wire_n1i0O_dataout AND NOT(n0iOOO);
	wire_n1iii_dataout <= wire_n1ili_dataout OR n0l1OO;
	wire_n1iil_dataout <= wire_n1l1i_dataout WHEN wire_w_lg_n0l11l353w(0) = '1'  ELSE wire_n1ill_dataout;
	wire_n1iiO_dataout <= wire_n1l1l_dataout WHEN wire_w_lg_n0l11l353w(0) = '1'  ELSE wire_n1ilO_dataout;
	wire_n1ili_dataout <= wire_n1l1O_dataout WHEN wire_w_lg_n0l11l353w(0) = '1'  ELSE wire_n1iOi_dataout;
	wire_n1ill_dataout <= wire_nli_w_lg_dataout349w(0) WHEN n0l11i = '1'  ELSE wire_nli_dataout;
	wire_n1ilO_dataout <= wire_niO_w_lg_dataout348w(0) WHEN n0l11i = '1'  ELSE wire_niO_dataout;
	wire_n1iOi_dataout <= wire_nil_w_lg_dataout347w(0) WHEN n0l11i = '1'  ELSE wire_nil_dataout;
	wire_n1l_dataout <= (NOT data_in(0)) WHEN nl0i = '1'  ELSE data_in(0);
	wire_n1l_w_lg_dataout361w(0) <= NOT wire_n1l_dataout;
	wire_n1l1i_dataout <= wire_nli_w_lg_dataout349w(0) WHEN wire_nll_dataout = '1'  ELSE wire_nli_dataout;
	wire_n1l1i_w_lg_dataout356w(0) <= NOT wire_n1l1i_dataout;
	wire_n1l1l_dataout <= wire_niO_w_lg_dataout348w(0) WHEN wire_nll_dataout = '1'  ELSE wire_niO_dataout;
	wire_n1l1l_w_lg_dataout358w(0) <= NOT wire_n1l1l_dataout;
	wire_n1l1O_dataout <= wire_nil_w_lg_dataout347w(0) WHEN wire_nll_dataout = '1'  ELSE wire_nil_dataout;
	wire_n1l1O_w_lg_w_lg_dataout354w355w(0) <= wire_n1l1O_w_lg_dataout354w(0) AND wire_n1l1l_dataout;
	wire_n1l1O_w_lg_dataout359w(0) <= wire_n1l1O_dataout AND wire_n1l1l_w_lg_dataout358w(0);
	wire_n1l1O_w_lg_dataout354w(0) <= NOT wire_n1l1O_dataout;
	wire_n1O_dataout <= (NOT data_in(1)) WHEN nl0i = '1'  ELSE data_in(1);
	wire_n1O_w_lg_w_lg_dataout362w873w(0) <= wire_n1O_w_lg_dataout362w(0) AND wire_n1l_w_lg_dataout361w(0);
	wire_n1O_w_lg_w_lg_dataout362w856w(0) <= wire_n1O_w_lg_dataout362w(0) AND wire_n1l_dataout;
	wire_n1O_w_lg_dataout857w(0) <= wire_n1O_dataout AND wire_n1l_w_lg_dataout361w(0);
	wire_n1O_w_lg_dataout362w(0) <= NOT wire_n1O_dataout;
	wire_ni0lOl_dataout <= wire_ni11iO_dataout WHEN ((wire_niO_dataout XOR wire_nil_dataout) AND n0lliO) = '1'  ELSE (n0llli OR n0lO1l);
	wire_ni0lOl_w_lg_dataout160w(0) <= wire_ni0lOl_dataout AND wire_w_lg_n0l0OO159w(0);
	wire_ni0lOl_w_lg_dataout128w(0) <= NOT wire_ni0lOl_dataout;
	wire_ni10i_dataout <= wire_nlOi_w_lg_dataout274w(0) WHEN wire_n1i_dataout = '1'  ELSE wire_nlOi_dataout;
	wire_ni10i_w_lg_w_lg_dataout281w282w(0) <= wire_ni10i_w_lg_dataout281w(0) AND wire_ni11O_dataout;
	wire_ni10i_w_lg_dataout286w(0) <= wire_ni10i_dataout AND wire_ni11O_w_lg_dataout285w(0);
	wire_ni10i_w_lg_dataout281w(0) <= NOT wire_ni10i_dataout;
	wire_ni11iO_dataout <= nl1O WHEN ((wire_n0l_w_lg_w_lg_dataout90w975w(0) OR (wire_n0l_dataout AND n0lOii)) OR (n0O11O AND n0lOOi)) = '1'  ELSE (n0lOil OR n0lOll);
	wire_ni11iO_w_lg_w_lg_dataout104w971w(0) <= wire_ni11iO_w_lg_dataout104w(0) AND n00OOO;
	wire_ni11iO_w_lg_dataout104w(0) <= NOT wire_ni11iO_dataout;
	wire_ni11l_dataout <= wire_nlOO_w_lg_dataout276w(0) WHEN wire_n1i_dataout = '1'  ELSE wire_nlOO_dataout;
	wire_ni11l_w_lg_dataout283w(0) <= NOT wire_ni11l_dataout;
	wire_ni11O_dataout <= wire_nlOl_w_lg_dataout275w(0) WHEN wire_n1i_dataout = '1'  ELSE wire_nlOl_dataout;
	wire_ni11O_w_lg_dataout285w(0) <= NOT wire_ni11O_dataout;
	wire_nii_dataout <= (NOT data_in(5)) WHEN nl0i = '1'  ELSE data_in(5);
	wire_nii_w_lg_w_lg_dataout351w784w(0) <= wire_nii_w_lg_dataout351w(0) AND wire_n0O_w_lg_w_lg_dataout364w783w(0);
	wire_nii_w_lg_w_lg_dataout351w778w(0) <= wire_nii_w_lg_dataout351w(0) AND wire_n0O_w_lg_w_lg_dataout364w777w(0);
	wire_nii_w_lg_w_lg_dataout351w853w(0) <= wire_nii_w_lg_dataout351w(0) AND wire_n0O_dataout;
	wire_nii_w_lg_w_lg_w_lg_dataout351w780w781w(0) <= wire_nii_w_lg_w_lg_dataout351w780w(0) AND n0i0lO;
	wire_nii_w_lg_w785w791w(0) <= wire_nii_w785w(0) AND wire_w_lg_w_lg_n0i00O787w790w(0);
	wire_nii_w810w(0) <= wire_nii_w_lg_w_lg_w_lg_w_lg_dataout795w796w799w802w(0) AND wire_w_lg_w_lg_n0i0ii805w809w(0);
	wire_nii_w_lg_w_lg_dataout797w798w(0) <= wire_nii_w_lg_dataout797w(0) AND n0i0ll;
	wire_nii_w_lg_dataout824w(0) <= wire_nii_dataout AND wire_n0O_w_lg_w_lg_dataout364w823w(0);
	wire_nii_w_lg_dataout848w(0) <= wire_nii_dataout AND wire_n0O_w_lg_dataout847w(0);
	wire_nii_w_lg_dataout801w(0) <= wire_nii_dataout AND wire_n0O_w_lg_dataout800w(0);
	wire_nii_w_lg_dataout795w(0) <= wire_nii_dataout AND wire_n0O_w_lg_dataout794w(0);
	wire_nii_w_lg_dataout721w(0) <= wire_nii_dataout AND wire_n0O_w_lg_dataout720w(0);
	wire_nii_w_lg_dataout854w(0) <= wire_nii_dataout AND wire_n0O_w_lg_dataout364w(0);
	wire_nii_w_lg_dataout737w(0) <= wire_nii_dataout AND wire_n0O_dataout;
	wire_nii_w_lg_dataout351w(0) <= NOT wire_nii_dataout;
	wire_nii_w_lg_w_lg_w_lg_dataout351w778w779w(0) <= wire_nii_w_lg_w_lg_dataout351w778w(0) OR n0i0Oi;
	wire_nii_w_lg_w_lg_dataout795w796w(0) <= wire_nii_w_lg_dataout795w(0) OR n0i0Ol;
	wire_nii_w_lg_w_lg_dataout351w780w(0) <= wire_nii_w_lg_dataout351w(0) OR wire_n0O_w_lg_dataout364w(0);
	wire_nii_w_lg_w_lg_w_lg_w_lg_dataout351w778w779w782w(0) <= wire_nii_w_lg_w_lg_w_lg_dataout351w778w779w(0) OR wire_nii_w_lg_w_lg_w_lg_dataout351w780w781w(0);
	wire_nii_w_lg_w_lg_w_lg_dataout795w796w799w(0) <= wire_nii_w_lg_w_lg_dataout795w796w(0) OR wire_nii_w_lg_w_lg_dataout797w798w(0);
	wire_nii_w785w(0) <= wire_nii_w_lg_w_lg_w_lg_w_lg_dataout351w778w779w782w(0) OR wire_nii_w_lg_w_lg_dataout351w784w(0);
	wire_nii_w_lg_w_lg_w_lg_w_lg_dataout795w796w799w802w(0) <= wire_nii_w_lg_w_lg_w_lg_dataout795w796w799w(0) OR wire_nii_w_lg_dataout801w(0);
	wire_nii_w_lg_dataout797w(0) <= wire_nii_dataout OR wire_n0O_dataout;
	wire_nil_dataout <= (NOT data_in(6)) WHEN nl0i = '1'  ELSE data_in(6);
	wire_nil_w_lg_w_lg_dataout347w831w(0) <= wire_nil_w_lg_dataout347w(0) AND n0i1li;
	wire_nil_w_lg_w_lg_dataout347w904w(0) <= wire_nil_w_lg_dataout347w(0) AND n0lliO;
	wire_nil_w_lg_dataout738w(0) <= wire_nil_dataout AND wire_nii_w_lg_dataout737w(0);
	wire_nil_w_lg_dataout114w(0) <= wire_nil_dataout AND n0lliO;
	wire_nil_w_lg_dataout347w(0) <= NOT wire_nil_dataout;
	wire_niO_dataout <= (NOT data_in(7)) WHEN nl0i = '1'  ELSE data_in(7);
	wire_niO_w_lg_w_lg_dataout348w727w(0) <= wire_niO_w_lg_dataout348w(0) AND wire_nil_w_lg_dataout347w(0);
	wire_niO_w_lg_w_lg_dataout348w750w(0) <= wire_niO_w_lg_dataout348w(0) AND wire_nii_dataout;
	wire_niO_w_lg_w_lg_dataout348w908w(0) <= wire_niO_w_lg_dataout348w(0) AND wire_nil_dataout;
	wire_niO_w_lg_w_lg_dataout348w765w(0) <= wire_niO_w_lg_dataout348w(0) AND n0i0iO;
	wire_niO_w_lg_w_lg_dataout348w742w(0) <= wire_niO_w_lg_dataout348w(0) AND n0i0li;
	wire_niO_w_lg_dataout739w(0) <= wire_niO_dataout AND wire_nil_w_lg_dataout738w(0);
	wire_niO_w_lg_dataout115w(0) <= wire_niO_dataout AND wire_nil_w_lg_dataout114w(0);
	wire_niO_w_lg_dataout753w(0) <= wire_niO_dataout AND wire_nii_w_lg_dataout351w(0);
	wire_niO_w_lg_dataout909w(0) <= wire_niO_dataout AND wire_nil_w_lg_dataout347w(0);
	wire_niO_w_lg_dataout723w(0) <= wire_niO_dataout AND wire_nil_dataout;
	wire_niO_w_lg_dataout746w(0) <= wire_niO_dataout AND n0i0iO;
	wire_niO_w_lg_dataout771w(0) <= wire_niO_dataout AND n0i0li;
	wire_niO_w_lg_dataout348w(0) <= NOT wire_niO_dataout;
	wire_niO_w_lg_w_lg_dataout348w788w(0) <= wire_niO_w_lg_dataout348w(0) OR wire_nil_w_lg_dataout347w(0);
	wire_niO_w_lg_dataout807w(0) <= wire_niO_dataout OR wire_nil_dataout;
	wire_niO00l_dataout <= ((NOT (wire_w_lg_n0i01O815w(0) OR wire_w_lg_n0lOlO818w(0))) AND (NOT (((n0i1OO OR n0llOO) OR ((NOT (((n0i1Ol OR n0i1Oi) OR wire_nii_w_lg_dataout824w(0)) OR (wire_nii_w_lg_dataout351w(0) AND (wire_n0O_dataout AND n0i1lO)))) AND (wire_w_lg_n0i1ll830w(0) AND (wire_nil_w_lg_w_lg_dataout347w831w(0) OR (wire_nil_dataout AND n0lO1i))))) OR ((wire_nll_w_lg_w_lg_dataout726w837w(0) OR (wire_nll_dataout AND n0lO1i)) AND wire_w_lg_n0i1Oi841w(0))))) WHEN ((NOT r8b10b_dec_ibm_en(0)) AND (NOT r8b10b_dec_ibm_en(1))) = '1'  ELSE (NOT ((((((((((((((n0i0Ol OR n0i0Oi) OR (wire_nii_w_lg_dataout351w(0) AND wire_n0O_w_lg_w_lg_dataout364w717w(0))) OR wire_nii_w_lg_dataout721w(0)) OR (wire_nll_w_lg_dataout725w(0) OR (wire_nll_w_lg_dataout726w(0) AND (wire_nli_w_lg_dataout349w(0) AND wire_niO_w_lg_w_lg_dataout348w727w(0))))) OR (wire_nli_w_lg_dataout349w(0) AND (wire_niO_w_lg_dataout348w(0) AND (wire_nil_w_lg_dataout347w(0) AND (wire_nii_w_lg_dataout351w(0) AND wire_n0O_w_lg_dataout364w(0)))))) OR wire_nli_w_lg_dataout740w(0)) OR (wire_nll_w_lg_dataout726w(0) AND (wire_nli_w_lg_dataout349w(0) AND wire_niO_w_lg_w_lg_dataout348w742w(0)))) OR wire_nll_w_lg_dataout748w(0)) OR (((wire_nll_w_lg_dataout726w(0) AND (wire_nli_w_lg_dataout349w(0) AND wire_niO_w_lg_w_lg_dataout348w750w(0))) OR wire_nll_w_lg_dataout755w(0)) AND wire_w_lg_n0i0il757w(0))) OR wire_w_lg_n0i0il763w(0)) OR ((wire_nll_w_lg_dataout726w(0) AND (wire_nli_w_lg_dataout349w(0) AND wire_niO_w_lg_w_lg_dataout348w765w(0))) AND wire_w_lg_n0i0ll768w(0))) OR (wire_nll_w_lg_dataout773w(0) AND wire_w_lg_n0i0lO774w(0))) OR wire_w_lg_w_r8b10b_dec_ibm_en_range481w792w(0)) OR wire_w_lg_w_r8b10b_dec_ibm_en_range481w811w(0)));
	wire_niO00l_w_lg_dataout60w(0) <= NOT wire_niO00l_dataout;
	wire_nl0l_dataout <= wire_nl0lll_dataout WHEN cascaded_8b10b_en = '1'  ELSE wire_ni0lOl_dataout;
	wire_nl0lll_dataout <= wire_nl110O_dataout WHEN ((wire_nlOl_dataout XOR wire_nlOi_dataout) AND n0l00l) = '1'  ELSE (n0l00O OR n0l0iO);
	wire_nl110O_dataout <= wire_ni0lOl_dataout WHEN ((wire_nlli_w_lg_w_lg_dataout157w684w(0) OR (wire_nlli_dataout AND n0l0Ol)) OR (n0lilO AND n0liii)) = '1'  ELSE (n0l0OO OR n0li1O);
	wire_nl110O_w_lg_w_lg_dataout171w680w(0) <= wire_nl110O_w_lg_dataout171w(0) AND n0ii0O;
	wire_nl110O_w_lg_dataout171w(0) <= NOT wire_nl110O_dataout;
	wire_nli_dataout <= (NOT data_in(8)) WHEN nl0i = '1'  ELSE data_in(8);
	wire_nli_w_lg_w_lg_dataout349w761w(0) <= wire_nli_w_lg_dataout349w(0) AND n0i00O;
	wire_nli_w_lg_w_lg_dataout349w921w(0) <= wire_nli_w_lg_dataout349w(0) AND n0i10i;
	wire_nli_w_lg_w_lg_dataout349w918w(0) <= wire_nli_w_lg_dataout349w(0) AND n0i10l;
	wire_nli_w_lg_w_lg_dataout349w940w(0) <= wire_nli_w_lg_dataout349w(0) AND n0i11l;
	wire_nli_w_lg_w_lg_dataout349w935w(0) <= wire_nli_w_lg_dataout349w(0) AND n0i11O;
	wire_nli_w_lg_dataout924w(0) <= wire_nli_dataout AND wire_niO_w_lg_w_lg_dataout348w727w(0);
	wire_nli_w_lg_dataout943w(0) <= wire_nli_dataout AND wire_niO_w_lg_w_lg_dataout348w908w(0);
	wire_nli_w_lg_dataout740w(0) <= wire_nli_dataout AND wire_niO_w_lg_dataout739w(0);
	wire_nli_w_lg_dataout754w(0) <= wire_nli_dataout AND wire_niO_w_lg_dataout753w(0);
	wire_nli_w_lg_dataout946w(0) <= wire_nli_dataout AND wire_niO_w_lg_dataout909w(0);
	wire_nli_w_lg_dataout724w(0) <= wire_nli_dataout AND wire_niO_w_lg_dataout723w(0);
	wire_nli_w_lg_dataout747w(0) <= wire_nli_dataout AND wire_niO_w_lg_dataout746w(0);
	wire_nli_w_lg_dataout772w(0) <= wire_nli_dataout AND wire_niO_w_lg_dataout771w(0);
	wire_nli_w_lg_dataout760w(0) <= wire_nli_dataout AND n0i0ii;
	wire_nli_w_lg_dataout349w(0) <= NOT wire_nli_dataout;
	wire_nli_w_lg_w_lg_dataout760w762w(0) <= wire_nli_w_lg_dataout760w(0) OR wire_nli_w_lg_w_lg_dataout349w761w(0);
	wire_nlii_dataout <= (NOT data_in(16)) WHEN nl0i = '1'  ELSE data_in(16);
	wire_nlii_w_lg_dataout288w(0) <= NOT wire_nlii_dataout;
	wire_nlil_dataout <= (NOT data_in(17)) WHEN nl0i = '1'  ELSE data_in(17);
	wire_nlil_w_lg_w_lg_dataout289w582w(0) <= wire_nlil_w_lg_dataout289w(0) AND wire_nlii_w_lg_dataout288w(0);
	wire_nlil_w_lg_w_lg_dataout289w565w(0) <= wire_nlil_w_lg_dataout289w(0) AND wire_nlii_dataout;
	wire_nlil_w_lg_dataout566w(0) <= wire_nlil_dataout AND wire_nlii_w_lg_dataout288w(0);
	wire_nlil_w_lg_dataout289w(0) <= NOT wire_nlil_dataout;
	wire_nliO_dataout <= (NOT data_in(18)) WHEN nl0i = '1'  ELSE data_in(18);
	wire_nliO_w_lg_w_lg_dataout290w711w(0) <= wire_nliO_w_lg_dataout290w(0) AND n0i0OO;
	wire_nliO_w_lg_w_lg_dataout290w706w(0) <= wire_nliO_w_lg_dataout290w(0) AND n0ii1i;
	wire_nliO_w_lg_w_lg_dataout290w699w(0) <= wire_nliO_w_lg_dataout290w(0) AND n0ii1l;
	wire_nliO_w_lg_w_lg_dataout290w696w(0) <= wire_nliO_w_lg_dataout290w(0) AND n0ii1O;
	wire_nliO_w_lg_w_lg_dataout290w599w(0) <= wire_nliO_w_lg_dataout290w(0) AND n0iilO;
	wire_nliO_w_lg_w_lg_dataout290w594w(0) <= wire_nliO_w_lg_dataout290w(0) AND n0iiOi;
	wire_nliO_w_lg_w_lg_dataout290w579w(0) <= wire_nliO_w_lg_dataout290w(0) AND n0iiOl;
	wire_nliO_w_lg_w_lg_dataout290w576w(0) <= wire_nliO_w_lg_dataout290w(0) AND n0iiOO;
	wire_nliO_w_lg_dataout583w(0) <= wire_nliO_dataout AND wire_nlil_w_lg_w_lg_dataout289w582w(0);
	wire_nliO_w_lg_dataout602w(0) <= wire_nliO_dataout AND wire_nlil_w_lg_w_lg_dataout289w565w(0);
	wire_nliO_w_lg_dataout605w(0) <= wire_nliO_dataout AND wire_nlil_w_lg_dataout566w(0);
	wire_nliO_w_lg_dataout290w(0) <= NOT wire_nliO_dataout;
	wire_nliOO_dataout <= data_in(0) WHEN rrxpcsbypass_en = '1'  ELSE nl0O;
	wire_nll_dataout <= (NOT data_in(9)) WHEN nl0i = '1'  ELSE data_in(9);
	wire_nll_w_lg_w_lg_dataout806w808w(0) <= wire_nll_w_lg_dataout806w(0) AND wire_niO_w_lg_dataout807w(0);
	wire_nll_w_lg_w_lg_dataout726w837w(0) <= wire_nll_w_lg_dataout726w(0) AND n0i1li;
	wire_nll_w_lg_dataout922w(0) <= wire_nll_dataout AND wire_nli_w_lg_w_lg_dataout349w921w(0);
	wire_nll_w_lg_dataout919w(0) <= wire_nll_dataout AND wire_nli_w_lg_w_lg_dataout349w918w(0);
	wire_nll_w_lg_dataout941w(0) <= wire_nll_dataout AND wire_nli_w_lg_w_lg_dataout349w940w(0);
	wire_nll_w_lg_dataout936w(0) <= wire_nll_dataout AND wire_nli_w_lg_w_lg_dataout349w935w(0);
	wire_nll_w_lg_dataout925w(0) <= wire_nll_dataout AND wire_nli_w_lg_dataout924w(0);
	wire_nll_w_lg_dataout944w(0) <= wire_nll_dataout AND wire_nli_w_lg_dataout943w(0);
	wire_nll_w_lg_dataout755w(0) <= wire_nll_dataout AND wire_nli_w_lg_dataout754w(0);
	wire_nll_w_lg_dataout947w(0) <= wire_nll_dataout AND wire_nli_w_lg_dataout946w(0);
	wire_nll_w_lg_dataout725w(0) <= wire_nll_dataout AND wire_nli_w_lg_dataout724w(0);
	wire_nll_w_lg_dataout748w(0) <= wire_nll_dataout AND wire_nli_w_lg_dataout747w(0);
	wire_nll_w_lg_dataout773w(0) <= wire_nll_dataout AND wire_nli_w_lg_dataout772w(0);
	wire_nll_w_lg_dataout806w(0) <= wire_nll_dataout AND wire_nli_dataout;
	wire_nll_w_lg_dataout726w(0) <= NOT wire_nll_dataout;
	wire_nll_w_lg_dataout803w(0) <= wire_nll_dataout OR wire_nli_dataout;
	wire_nll0i_dataout <= data_in(4) WHEN rrxpcsbypass_en = '1'  ELSE nlOil;
	wire_nll0l_dataout <= data_in(5) WHEN rrxpcsbypass_en = '1'  ELSE nlOiO;
	wire_nll0O_dataout <= data_in(6) WHEN rrxpcsbypass_en = '1'  ELSE nlOli;
	wire_nll1i_dataout <= data_in(1) WHEN rrxpcsbypass_en = '1'  ELSE nlO0l;
	wire_nll1l_dataout <= data_in(2) WHEN rrxpcsbypass_en = '1'  ELSE nlO0O;
	wire_nll1O_dataout <= data_in(3) WHEN rrxpcsbypass_en = '1'  ELSE nlOii;
	wire_nlli_dataout <= (NOT data_in(19)) WHEN nl0i = '1'  ELSE data_in(19);
	wire_nlli_w_lg_w_lg_dataout157w684w(0) <= wire_nlli_w_lg_dataout157w(0) AND n0ii0i;
	wire_nlli_w_lg_w_lg_dataout157w158w(0) <= wire_nlli_w_lg_dataout157w(0) AND n0l0Ol;
	wire_nlli_w_lg_dataout712w(0) <= wire_nlli_dataout AND wire_nliO_w_lg_w_lg_dataout290w711w(0);
	wire_nlli_w_lg_dataout707w(0) <= wire_nlli_dataout AND wire_nliO_w_lg_w_lg_dataout290w706w(0);
	wire_nlli_w_lg_dataout700w(0) <= wire_nlli_dataout AND wire_nliO_w_lg_w_lg_dataout290w699w(0);
	wire_nlli_w_lg_dataout697w(0) <= wire_nlli_dataout AND wire_nliO_w_lg_w_lg_dataout290w696w(0);
	wire_nlli_w_lg_dataout600w(0) <= wire_nlli_dataout AND wire_nliO_w_lg_w_lg_dataout290w599w(0);
	wire_nlli_w_lg_dataout595w(0) <= wire_nlli_dataout AND wire_nliO_w_lg_w_lg_dataout290w594w(0);
	wire_nlli_w_lg_dataout580w(0) <= wire_nlli_dataout AND wire_nliO_w_lg_w_lg_dataout290w579w(0);
	wire_nlli_w_lg_dataout577w(0) <= wire_nlli_dataout AND wire_nliO_w_lg_w_lg_dataout290w576w(0);
	wire_nlli_w_lg_dataout584w(0) <= wire_nlli_dataout AND wire_nliO_w_lg_dataout583w(0);
	wire_nlli_w_lg_dataout603w(0) <= wire_nlli_dataout AND wire_nliO_w_lg_dataout602w(0);
	wire_nlli_w_lg_dataout606w(0) <= wire_nlli_dataout AND wire_nliO_w_lg_dataout605w(0);
	wire_nlli_w_lg_dataout555w(0) <= wire_nlli_dataout AND wire_nliO_dataout;
	wire_nlli_w_lg_dataout157w(0) <= NOT wire_nlli_dataout;
	wire_nllii_dataout <= data_in(7) WHEN rrxpcsbypass_en = '1'  ELSE nlOll;
	wire_nllil_dataout <= data_in(8) WHEN rrxpcsbypass_en = '1'  ELSE nlOlO;
	wire_nlliO_dataout <= data_in(9) WHEN rrxpcsbypass_en = '1'  ELSE nlOOi;
	wire_nlll_dataout <= (NOT data_in(20)) WHEN nl0i = '1'  ELSE data_in(20);
	wire_nlll_w_lg_w_lg_dataout291w488w(0) <= wire_nlll_w_lg_dataout291w(0) AND wire_nlli_w_lg_dataout157w(0);
	wire_nlll_w_lg_w_lg_dataout291w482w(0) <= wire_nlll_w_lg_dataout291w(0) AND n0illl;
	wire_nlll_w_lg_w_lg_dataout291w421w(0) <= wire_nlll_w_lg_dataout291w(0) AND n0iO1O;
	wire_nlll_w_lg_w_lg_dataout291w528w(0) <= wire_nlll_w_lg_dataout291w(0) AND n0liil;
	wire_nlll_w_lg_dataout556w(0) <= wire_nlll_dataout AND wire_nlli_w_lg_dataout555w(0);
	wire_nlll_w_lg_dataout505w(0) <= wire_nlll_dataout AND wire_nlli_dataout;
	wire_nlll_w_lg_dataout499w(0) <= wire_nlll_dataout AND n0illl;
	wire_nlll_w_lg_dataout424w(0) <= wire_nlll_dataout AND n0iO1l;
	wire_nlll_w_lg_dataout291w(0) <= NOT wire_nlll_dataout;
	wire_nllli_dataout <= data_in(16) WHEN rrxpcsbypass_en = '1'  ELSE nlOOl;
	wire_nllll_dataout <= data_in(17) WHEN rrxpcsbypass_en = '1'  ELSE nlOOO;
	wire_nlllO_dataout <= data_in(18) WHEN rrxpcsbypass_en = '1'  ELSE n11i;
	wire_nllO_dataout <= (NOT data_in(21)) WHEN nl0i = '1'  ELSE data_in(21);
	wire_nllO_w_lg_w_lg_dataout278w489w(0) <= wire_nllO_w_lg_dataout278w(0) AND wire_nlll_w_lg_w_lg_dataout291w488w(0);
	wire_nllO_w_lg_w_lg_dataout278w483w(0) <= wire_nllO_w_lg_dataout278w(0) AND wire_nlll_w_lg_w_lg_dataout291w482w(0);
	wire_nllO_w_lg_w_lg_dataout278w562w(0) <= wire_nllO_w_lg_dataout278w(0) AND wire_nlll_dataout;
	wire_nllO_w_lg_w_lg_w_lg_dataout278w485w486w(0) <= wire_nllO_w_lg_w_lg_dataout278w485w(0) AND n0iO1O;
	wire_nllO_w_lg_w490w496w(0) <= wire_nllO_w490w(0) AND wire_w_lg_w_lg_n0illO492w495w(0);
	wire_nllO_w515w(0) <= wire_nllO_w_lg_w_lg_w_lg_w_lg_dataout500w501w504w507w(0) AND wire_w_lg_w_lg_n0ilOi510w514w(0);
	wire_nllO_w_lg_w_lg_dataout502w503w(0) <= wire_nllO_w_lg_dataout502w(0) AND n0iO1l;
	wire_nllO_w_lg_dataout529w(0) <= wire_nllO_dataout AND wire_nlll_w_lg_w_lg_dataout291w528w(0);
	wire_nllO_w_lg_dataout557w(0) <= wire_nllO_dataout AND wire_nlll_w_lg_dataout556w(0);
	wire_nllO_w_lg_dataout506w(0) <= wire_nllO_dataout AND wire_nlll_w_lg_dataout505w(0);
	wire_nllO_w_lg_dataout500w(0) <= wire_nllO_dataout AND wire_nlll_w_lg_dataout499w(0);
	wire_nllO_w_lg_dataout425w(0) <= wire_nllO_dataout AND wire_nlll_w_lg_dataout424w(0);
	wire_nllO_w_lg_dataout563w(0) <= wire_nllO_dataout AND wire_nlll_w_lg_dataout291w(0);
	wire_nllO_w_lg_dataout441w(0) <= wire_nllO_dataout AND wire_nlll_dataout;
	wire_nllO_w_lg_dataout278w(0) <= NOT wire_nllO_dataout;
	wire_nllO_w_lg_w_lg_w_lg_dataout278w483w484w(0) <= wire_nllO_w_lg_w_lg_dataout278w483w(0) OR n0iO0i;
	wire_nllO_w_lg_w_lg_dataout500w501w(0) <= wire_nllO_w_lg_dataout500w(0) OR n0iO0l;
	wire_nllO_w_lg_w_lg_dataout278w485w(0) <= wire_nllO_w_lg_dataout278w(0) OR wire_nlll_w_lg_dataout291w(0);
	wire_nllO_w_lg_w_lg_w_lg_w_lg_dataout278w483w484w487w(0) <= wire_nllO_w_lg_w_lg_w_lg_dataout278w483w484w(0) OR wire_nllO_w_lg_w_lg_w_lg_dataout278w485w486w(0);
	wire_nllO_w_lg_w_lg_w_lg_dataout500w501w504w(0) <= wire_nllO_w_lg_w_lg_dataout500w501w(0) OR wire_nllO_w_lg_w_lg_dataout502w503w(0);
	wire_nllO_w490w(0) <= wire_nllO_w_lg_w_lg_w_lg_w_lg_dataout278w483w484w487w(0) OR wire_nllO_w_lg_w_lg_dataout278w489w(0);
	wire_nllO_w_lg_w_lg_w_lg_w_lg_dataout500w501w504w507w(0) <= wire_nllO_w_lg_w_lg_w_lg_dataout500w501w504w(0) OR wire_nllO_w_lg_dataout506w(0);
	wire_nllO_w_lg_dataout502w(0) <= wire_nllO_dataout OR wire_nlll_dataout;
	wire_nllOi_dataout <= data_in(19) WHEN rrxpcsbypass_en = '1'  ELSE n11l;
	wire_nllOl_dataout <= data_in(20) WHEN rrxpcsbypass_en = '1'  ELSE n11O;
	wire_nllOO_dataout <= data_in(21) WHEN rrxpcsbypass_en = '1'  ELSE n10i;
	wire_nlO01l_dataout <= ((NOT (wire_w_lg_n0iliO520w(0) OR wire_w_lg_n0li0i523w(0))) AND (NOT (((n0il0O OR n0l0ii) OR ((NOT (((n0il0l OR n0il0i) OR wire_nllO_w_lg_dataout529w(0)) OR (wire_nllO_w_lg_dataout278w(0) AND (wire_nlll_dataout AND n0il1O)))) AND (wire_w_lg_n0il1l535w(0) AND (wire_nlOi_w_lg_w_lg_dataout274w536w(0) OR (wire_nlOi_dataout AND n0l0il))))) OR ((wire_n1i_w_lg_w_lg_dataout430w542w(0) OR (wire_n1i_dataout AND n0l0il)) AND wire_w_lg_n0il0i546w(0))))) WHEN ((NOT r8b10b_dec_ibm_en(0)) AND (NOT r8b10b_dec_ibm_en(1))) = '1'  ELSE (NOT ((((((((((((((n0iO0l OR n0iO0i) OR (wire_nllO_w_lg_dataout278w(0) AND wire_nlll_w_lg_w_lg_dataout291w421w(0))) OR wire_nllO_w_lg_dataout425w(0)) OR (wire_n1i_w_lg_dataout429w(0) OR (wire_n1i_w_lg_dataout430w(0) AND (wire_nlOO_w_lg_dataout276w(0) AND wire_nlOl_w_lg_w_lg_dataout275w431w(0))))) OR (wire_nlOO_w_lg_dataout276w(0) AND (wire_nlOl_w_lg_dataout275w(0) AND (wire_nlOi_w_lg_dataout274w(0) AND (wire_nllO_w_lg_dataout278w(0) AND wire_nlll_w_lg_dataout291w(0)))))) OR wire_nlOO_w_lg_dataout444w(0)) OR (wire_n1i_w_lg_dataout430w(0) AND (wire_nlOO_w_lg_dataout276w(0) AND wire_nlOl_w_lg_w_lg_dataout275w446w(0)))) OR wire_n1i_w_lg_dataout452w(0)) OR (((wire_n1i_w_lg_dataout430w(0) AND (wire_nlOO_w_lg_dataout276w(0) AND wire_nlOl_w_lg_w_lg_dataout275w454w(0))) OR wire_n1i_w_lg_dataout459w(0)) AND wire_w_lg_n0ilOl461w(0))) OR wire_w_lg_n0ilOl467w(0)) OR ((wire_n1i_w_lg_dataout430w(0) AND (wire_nlOO_w_lg_dataout276w(0) AND wire_nlOl_w_lg_w_lg_dataout275w469w(0))) AND wire_w_lg_n0iO1l472w(0))) OR (wire_n1i_w_lg_dataout477w(0) AND wire_w_lg_n0iO1O478w(0))) OR wire_w_lg_w_r8b10b_dec_ibm_en_range481w497w(0)) OR wire_w_lg_w_r8b10b_dec_ibm_en_range481w516w(0)));
	wire_nlO01l_w_lg_dataout62w(0) <= NOT wire_nlO01l_dataout;
	wire_nlO0i_dataout <= data_in(25) WHEN rrxpcsbypass_en = '1'  ELSE n1il;
	wire_nlO1i_dataout <= data_in(22) WHEN rrxpcsbypass_en = '1'  ELSE n10l;
	wire_nlO1l_dataout <= data_in(23) WHEN rrxpcsbypass_en = '1'  ELSE n10O;
	wire_nlO1O_dataout <= data_in(24) WHEN rrxpcsbypass_en = '1'  ELSE n1ii;
	wire_nlOi_dataout <= (NOT data_in(22)) WHEN nl0i = '1'  ELSE data_in(22);
	wire_nlOi_w_lg_w_lg_dataout174w177w(0) <= wire_nlOi_w_lg_dataout174w(0) AND wire_n0l01O44_w_lg_q176w(0);
	wire_nlOi_w_lg_w_lg_dataout274w536w(0) <= wire_nlOi_w_lg_dataout274w(0) AND n0il1i;
	wire_nlOi_w_lg_w_lg_dataout274w613w(0) <= wire_nlOi_w_lg_dataout274w(0) AND n0l00l;
	wire_nlOi_w_lg_dataout442w(0) <= wire_nlOi_dataout AND wire_nllO_w_lg_dataout441w(0);
	wire_nlOi_w_lg_dataout174w(0) <= wire_nlOi_dataout AND n0l00l;
	wire_nlOi_w_lg_dataout274w(0) <= NOT wire_nlOi_dataout;
	wire_nlOl_dataout <= (NOT data_in(23)) WHEN nl0i = '1'  ELSE data_in(23);
	wire_nlOl_w_lg_w_lg_dataout275w431w(0) <= wire_nlOl_w_lg_dataout275w(0) AND wire_nlOi_w_lg_dataout274w(0);
	wire_nlOl_w_lg_w_lg_dataout275w454w(0) <= wire_nlOl_w_lg_dataout275w(0) AND wire_nllO_dataout;
	wire_nlOl_w_lg_w_lg_dataout275w617w(0) <= wire_nlOl_w_lg_dataout275w(0) AND wire_nlOi_dataout;
	wire_nlOl_w_lg_w_lg_dataout275w469w(0) <= wire_nlOl_w_lg_dataout275w(0) AND n0ilOO;
	wire_nlOl_w_lg_w_lg_dataout275w446w(0) <= wire_nlOl_w_lg_dataout275w(0) AND n0iO1i;
	wire_nlOl_w_lg_dataout178w(0) <= wire_nlOl_dataout AND wire_nlOi_w_lg_w_lg_dataout174w177w(0);
	wire_nlOl_w_lg_dataout443w(0) <= wire_nlOl_dataout AND wire_nlOi_w_lg_dataout442w(0);
	wire_nlOl_w_lg_dataout457w(0) <= wire_nlOl_dataout AND wire_nllO_w_lg_dataout278w(0);
	wire_nlOl_w_lg_dataout618w(0) <= wire_nlOl_dataout AND wire_nlOi_w_lg_dataout274w(0);
	wire_nlOl_w_lg_dataout427w(0) <= wire_nlOl_dataout AND wire_nlOi_dataout;
	wire_nlOl_w_lg_dataout450w(0) <= wire_nlOl_dataout AND n0ilOO;
	wire_nlOl_w_lg_dataout475w(0) <= wire_nlOl_dataout AND n0iO1i;
	wire_nlOl_w_lg_dataout275w(0) <= NOT wire_nlOl_dataout;
	wire_nlOl_w_lg_w_lg_dataout275w493w(0) <= wire_nlOl_w_lg_dataout275w(0) OR wire_nlOi_w_lg_dataout274w(0);
	wire_nlOl_w_lg_dataout512w(0) <= wire_nlOl_dataout OR wire_nlOi_dataout;
	wire_nlOlil_dataout <= wire_nlOlOi_dataout OR n0l01l;
	wire_nlOliO_dataout <= wire_nlOlOl_dataout OR n0l01l;
	wire_nlOlli_dataout <= wire_nlOlOO_dataout OR n0l01l;
	wire_nlOlll_dataout <= wire_nlOO1i_dataout AND NOT(n0l01l);
	wire_nlOllO_dataout <= wire_nlOO1l_dataout AND NOT(n0l01l);
	wire_nlOlOi_dataout <= wire_nlOO1O_dataout OR n0iOOl;
	wire_nlOlOl_dataout <= wire_nlOO0i_dataout OR n0iOOl;
	wire_nlOlOO_dataout <= wire_nlOO0l_dataout AND NOT(n0iOOl);
	wire_nlOO_dataout <= (NOT data_in(24)) WHEN nl0i = '1'  ELSE data_in(24);
	wire_nlOO_w_lg_w_lg_dataout276w649w(0) <= wire_nlOO_w_lg_dataout276w(0) AND n0iiil;
	wire_nlOO_w_lg_w_lg_dataout276w644w(0) <= wire_nlOO_w_lg_dataout276w(0) AND n0iiiO;
	wire_nlOO_w_lg_w_lg_dataout276w630w(0) <= wire_nlOO_w_lg_dataout276w(0) AND n0iili;
	wire_nlOO_w_lg_w_lg_dataout276w627w(0) <= wire_nlOO_w_lg_dataout276w(0) AND n0iill;
	wire_nlOO_w_lg_w_lg_dataout276w465w(0) <= wire_nlOO_w_lg_dataout276w(0) AND n0illO;
	wire_nlOO_w_lg_dataout633w(0) <= wire_nlOO_dataout AND wire_nlOl_w_lg_w_lg_dataout275w431w(0);
	wire_nlOO_w_lg_dataout652w(0) <= wire_nlOO_dataout AND wire_nlOl_w_lg_w_lg_dataout275w617w(0);
	wire_nlOO_w_lg_dataout444w(0) <= wire_nlOO_dataout AND wire_nlOl_w_lg_dataout443w(0);
	wire_nlOO_w_lg_dataout458w(0) <= wire_nlOO_dataout AND wire_nlOl_w_lg_dataout457w(0);
	wire_nlOO_w_lg_dataout655w(0) <= wire_nlOO_dataout AND wire_nlOl_w_lg_dataout618w(0);
	wire_nlOO_w_lg_dataout428w(0) <= wire_nlOO_dataout AND wire_nlOl_w_lg_dataout427w(0);
	wire_nlOO_w_lg_dataout451w(0) <= wire_nlOO_dataout AND wire_nlOl_w_lg_dataout450w(0);
	wire_nlOO_w_lg_dataout476w(0) <= wire_nlOO_dataout AND wire_nlOl_w_lg_dataout475w(0);
	wire_nlOO_w_lg_dataout464w(0) <= wire_nlOO_dataout AND n0ilOi;
	wire_nlOO_w_lg_dataout276w(0) <= NOT wire_nlOO_dataout;
	wire_nlOO_w_lg_w_lg_dataout464w466w(0) <= wire_nlOO_w_lg_dataout464w(0) OR wire_nlOO_w_lg_w_lg_dataout276w465w(0);
	wire_nlOO0i_dataout <= wire_nlOOOO_dataout WHEN n0iOOi = '1'  ELSE wire_nlOOiO_dataout;
	wire_nlOO0l_dataout <= wire_nlOOOO_dataout WHEN n0iOOi = '1'  ELSE wire_nlOOli_dataout;
	wire_nlOO0O_dataout <= wire_nlOOOO_dataout WHEN n0iOOi = '1'  ELSE wire_nlOOll_dataout;
	wire_nlOO1i_dataout <= wire_nlOO0O_dataout AND NOT(n0iOOl);
	wire_nlOO1l_dataout <= wire_nlOOii_dataout AND NOT(n0iOOl);
	wire_nlOO1O_dataout <= wire_nlOOOl_dataout WHEN n0iOOi = '1'  ELSE wire_nlOOil_dataout;
	wire_nlOOii_dataout <= wire_nlOOOO_dataout WHEN n0iOOi = '1'  ELSE wire_nlOOlO_dataout;
	wire_nlOOil_dataout <= wire_n0O_dataout WHEN n0iOiO = '1'  ELSE n0l01i;
	wire_nlOOiO_dataout <= wire_n0l_dataout WHEN n0iOiO = '1'  ELSE wire_n10iO_w_lg_dataout371w(0);
	wire_nlOOli_dataout <= wire_n0i_dataout WHEN n0iOiO = '1'  ELSE wire_n10li_w_lg_dataout372w(0);
	wire_nlOOll_dataout <= wire_n1O_dataout WHEN n0iOiO = '1'  ELSE wire_n10ll_w_lg_dataout366w(0);
	wire_nlOOlO_dataout <= wire_n1l_dataout WHEN n0iOiO = '1'  ELSE wire_n10lO_w_lg_dataout365w(0);
	wire_nlOOOl_dataout <= wire_n111i_dataout AND NOT(n0iOil);
	wire_nlOOOO_dataout <= wire_w_lg_n0iOii405w(0) AND NOT(n0iOil);

 END RTL; --stratixiv_hssi_rx_digi_dec_chnl_top
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 135 mux21 124 oper_add 1 stratixiv_hssi_rx_digis_ram16x14_syn 1 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_rx_digi_dskw_fifo IS 
	 PORT 
	 ( 
		 align_det_sync	:	OUT  STD_LOGIC;
		 audi	:	OUT  STD_LOGIC_VECTOR (13 DOWNTO 0);
		 audi_pre	:	OUT  STD_LOGIC_VECTOR (13 DOWNTO 0);
		 clk_1	:	IN  STD_LOGIC;
		 en_dskw_gp	:	IN  STD_LOGIC;
		 en_dskw_qd	:	IN  STD_LOGIC;
		 fifo_rst_rd_gp	:	IN  STD_LOGIC;
		 fifo_rst_rd_qd	:	IN  STD_LOGIC;
		 rcvd_clk	:	IN  STD_LOGIC;
		 rd_align	:	OUT  STD_LOGIC;
		 rdskchrp	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 rdskposdisp	:	IN  STD_LOGIC;
		 sel_gp_md	:	IN  STD_LOGIC;
		 soft_reset	:	IN  STD_LOGIC;
		 sudi	:	IN  STD_LOGIC_VECTOR (13 DOWNTO 0)
	 ); 
 END stratixiv_hssi_rx_digi_dskw_fifo;

 ARCHITECTURE RTL OF stratixiv_hssi_rx_digi_dskw_fifo IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 n100l17	:	STD_LOGIC := '0';
	 SIGNAL	 n100l18	:	STD_LOGIC := '0';
	 SIGNAL	 n101i21	:	STD_LOGIC := '0';
	 SIGNAL	 n101i22	:	STD_LOGIC := '0';
	 SIGNAL	 n101O19	:	STD_LOGIC := '0';
	 SIGNAL	 n101O20	:	STD_LOGIC := '0';
	 SIGNAL	 n10iO15	:	STD_LOGIC := '0';
	 SIGNAL	 n10iO16	:	STD_LOGIC := '0';
	 SIGNAL	 n10lO13	:	STD_LOGIC := '0';
	 SIGNAL	 n10lO14	:	STD_LOGIC := '0';
	 SIGNAL	 n10Ol11	:	STD_LOGIC := '0';
	 SIGNAL	 n10Ol12	:	STD_LOGIC := '0';
	 SIGNAL	 n10OO10	:	STD_LOGIC := '0';
	 SIGNAL  wire_n10OO10_w_lg_w_lg_q39w40w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n10OO10_w_lg_q39w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n10OO9	:	STD_LOGIC := '0';
	 SIGNAL	 n110i33	:	STD_LOGIC := '0';
	 SIGNAL	 n110i34	:	STD_LOGIC := '0';
	 SIGNAL	 n110O31	:	STD_LOGIC := '0';
	 SIGNAL	 n110O32	:	STD_LOGIC := '0';
	 SIGNAL	 n111l35	:	STD_LOGIC := '0';
	 SIGNAL	 n111l36	:	STD_LOGIC := '0';
	 SIGNAL	 n11il29	:	STD_LOGIC := '0';
	 SIGNAL	 n11il30	:	STD_LOGIC := '0';
	 SIGNAL	 n11li27	:	STD_LOGIC := '0';
	 SIGNAL	 n11li28	:	STD_LOGIC := '0';
	 SIGNAL	 n11lO25	:	STD_LOGIC := '0';
	 SIGNAL	 n11lO26	:	STD_LOGIC := '0';
	 SIGNAL	 n11Ol23	:	STD_LOGIC := '0';
	 SIGNAL	 n11Ol24	:	STD_LOGIC := '0';
	 SIGNAL	 n1i0l3	:	STD_LOGIC := '0';
	 SIGNAL	 n1i0l4	:	STD_LOGIC := '0';
	 SIGNAL	 n1i1i7	:	STD_LOGIC := '0';
	 SIGNAL	 n1i1i8	:	STD_LOGIC := '0';
	 SIGNAL  wire_n1i1i8_w_lg_w_lg_q36w37w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1i1i8_w_lg_q36w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n1i1O5	:	STD_LOGIC := '0';
	 SIGNAL	 n1i1O6	:	STD_LOGIC := '0';
	 SIGNAL	 n1ili1	:	STD_LOGIC := '0';
	 SIGNAL	 n1ili2	:	STD_LOGIC := '0';
	 SIGNAL	 nlOO0l47	:	STD_LOGIC := '0';
	 SIGNAL	 nlOO0l48	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOii45	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOii46	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOiO43	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOiO44	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOll41	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOll42	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOOi39	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOOi40	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOOO37	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOOO38	:	STD_LOGIC := '0';
	 SIGNAL	ni00l	:	STD_LOGIC := '0';
	 SIGNAL	ni10i	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni00i_PRN	:	STD_LOGIC;
	 SIGNAL	n0Oi	:	STD_LOGIC := '0';
	 SIGNAL	ni0l	:	STD_LOGIC := '0';
	 SIGNAL	ni0O	:	STD_LOGIC := '0';
	 SIGNAL	niii	:	STD_LOGIC := '0';
	 SIGNAL	niiO	:	STD_LOGIC := '0';
	 SIGNAL	nlliO	:	STD_LOGIC := '0';
	 SIGNAL	nllli	:	STD_LOGIC := '0';
	 SIGNAL	nllll	:	STD_LOGIC := '0';
	 SIGNAL	nlllO	:	STD_LOGIC := '0';
	 SIGNAL	nllOi	:	STD_LOGIC := '0';
	 SIGNAL	nllOl	:	STD_LOGIC := '0';
	 SIGNAL	nllOO	:	STD_LOGIC := '0';
	 SIGNAL	nlO0i	:	STD_LOGIC := '0';
	 SIGNAL	nlO0l	:	STD_LOGIC := '0';
	 SIGNAL	nlO0O	:	STD_LOGIC := '0';
	 SIGNAL	nlO1i	:	STD_LOGIC := '0';
	 SIGNAL	nlO1l	:	STD_LOGIC := '0';
	 SIGNAL	nlO1O	:	STD_LOGIC := '0';
	 SIGNAL	nlOii	:	STD_LOGIC := '0';
	 SIGNAL	nlOil	:	STD_LOGIC := '0';
	 SIGNAL	nlOiO	:	STD_LOGIC := '0';
	 SIGNAL	wire_niil_PRN	:	STD_LOGIC;
	 SIGNAL  wire_niil_w_lg_nlOiO60w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niil_w_lg_n0Oi337w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niil_w_lg_ni0l335w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niil_w_lg_ni0O333w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niil_w_lg_niii332w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	ni00O	:	STD_LOGIC := '0';
	 SIGNAL	ni01i	:	STD_LOGIC := '0';
	 SIGNAL	ni01l	:	STD_LOGIC := '0';
	 SIGNAL	ni01O	:	STD_LOGIC := '0';
	 SIGNAL	ni0ii	:	STD_LOGIC := '0';
	 SIGNAL	ni0il	:	STD_LOGIC := '0';
	 SIGNAL	ni0iO	:	STD_LOGIC := '0';
	 SIGNAL	ni0li	:	STD_LOGIC := '0';
	 SIGNAL	ni0ll	:	STD_LOGIC := '0';
	 SIGNAL	ni0lO	:	STD_LOGIC := '0';
	 SIGNAL	ni0Oi	:	STD_LOGIC := '0';
	 SIGNAL	ni0Ol	:	STD_LOGIC := '0';
	 SIGNAL	ni0OO	:	STD_LOGIC := '0';
	 SIGNAL	ni10l	:	STD_LOGIC := '0';
	 SIGNAL	ni10O	:	STD_LOGIC := '0';
	 SIGNAL	ni11l	:	STD_LOGIC := '0';
	 SIGNAL	ni11O	:	STD_LOGIC := '0';
	 SIGNAL	ni1ii	:	STD_LOGIC := '0';
	 SIGNAL	ni1il	:	STD_LOGIC := '0';
	 SIGNAL	ni1iO	:	STD_LOGIC := '0';
	 SIGNAL	ni1li	:	STD_LOGIC := '0';
	 SIGNAL	ni1ll	:	STD_LOGIC := '0';
	 SIGNAL	ni1lO	:	STD_LOGIC := '0';
	 SIGNAL	ni1Oi	:	STD_LOGIC := '0';
	 SIGNAL	ni1Ol	:	STD_LOGIC := '0';
	 SIGNAL	ni1OO	:	STD_LOGIC := '0';
	 SIGNAL	nii0i	:	STD_LOGIC := '0';
	 SIGNAL	nii0l	:	STD_LOGIC := '0';
	 SIGNAL	nii0O	:	STD_LOGIC := '0';
	 SIGNAL	nii1i	:	STD_LOGIC := '0';
	 SIGNAL	nii1l	:	STD_LOGIC := '0';
	 SIGNAL	nii1O	:	STD_LOGIC := '0';
	 SIGNAL	nl0ll	:	STD_LOGIC := '0';
	 SIGNAL	nl0lO	:	STD_LOGIC := '0';
	 SIGNAL	nl0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nl0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nl0OO	:	STD_LOGIC := '0';
	 SIGNAL	nli0i	:	STD_LOGIC := '0';
	 SIGNAL	nli0l	:	STD_LOGIC := '0';
	 SIGNAL	nli0O	:	STD_LOGIC := '0';
	 SIGNAL	nli1i	:	STD_LOGIC := '0';
	 SIGNAL	nli1l	:	STD_LOGIC := '0';
	 SIGNAL	nli1O	:	STD_LOGIC := '0';
	 SIGNAL	nliii	:	STD_LOGIC := '0';
	 SIGNAL	nliil	:	STD_LOGIC := '0';
	 SIGNAL	nliiO	:	STD_LOGIC := '0';
	 SIGNAL	nlili	:	STD_LOGIC := '0';
	 SIGNAL	nlill	:	STD_LOGIC := '0';
	 SIGNAL	nlilO	:	STD_LOGIC := '0';
	 SIGNAL	nliOi	:	STD_LOGIC := '0';
	 SIGNAL	nliOl	:	STD_LOGIC := '0';
	 SIGNAL	nliOO	:	STD_LOGIC := '0';
	 SIGNAL	nll0i	:	STD_LOGIC := '0';
	 SIGNAL	nll0l	:	STD_LOGIC := '0';
	 SIGNAL	nll0O	:	STD_LOGIC := '0';
	 SIGNAL	nll1i	:	STD_LOGIC := '0';
	 SIGNAL	nll1l	:	STD_LOGIC := '0';
	 SIGNAL	nll1O	:	STD_LOGIC := '0';
	 SIGNAL	nllii	:	STD_LOGIC := '0';
	 SIGNAL	nlOi	:	STD_LOGIC := '0';
	 SIGNAL	wire_nllO_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nllO_w_lg_nll0i250w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_nll0O249w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_nliiO252w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_nliOl271w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_nll1i281w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_nll1l288w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO_w_lg_nll1O295w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	ni	:	STD_LOGIC := '0';
	 SIGNAL	nlil	:	STD_LOGIC := '0';
	 SIGNAL	nll	:	STD_LOGIC := '0';
	 SIGNAL	nllil	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlO_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nlO_w_lg_nll61w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO_w_lg_nll63w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO_w_lg_nlil62w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO_w_lg_nll58w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0l_w_lg_dataout220w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1i_w_lg_dataout200w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1O_w_lg_dataout210w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nil_w_lg_dataout233w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nO_w_lg_dataout97w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlii_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nlii_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_gnd	:	STD_LOGIC;
	 SIGNAL  wire_nlii_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1iOi_addr_rd1	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1iOi_addr_rd2	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1iOi_addr_wr	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1iOi_data_in	:	STD_LOGIC_VECTOR (13 DOWNTO 0);
	 SIGNAL  wire_n1iOi_data_out1	:	STD_LOGIC_VECTOR (13 DOWNTO 0);
	 SIGNAL  wire_n1iOi_data_out2	:	STD_LOGIC_VECTOR (13 DOWNTO 0);
	 SIGNAL  wire_n1iOi_rst_l	:	STD_LOGIC;
	 SIGNAL  wire_vcc	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_n1i1l54w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_soft_reset2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  n10ii :	STD_LOGIC;
	 SIGNAL  n10il :	STD_LOGIC;
	 SIGNAL  n10li :	STD_LOGIC;
	 SIGNAL  n10ll :	STD_LOGIC;
	 SIGNAL  n1i0i :	STD_LOGIC;
	 SIGNAL  n1i1l :	STD_LOGIC;
	 SIGNAL  n1iii :	STD_LOGIC;
	 SIGNAL  n1iil :	STD_LOGIC;
	 SIGNAL  n1iiO :	STD_LOGIC;
	 SIGNAL  wire_w_rdskchrp_range21w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rdskchrp_range11w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rdskchrp_range7w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rdskchrp_range5w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rdskchrp_range3w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_sudi_range141w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_sudi_range149w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_sudi_range161w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_sudi_range177w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 COMPONENT  stratixiv_hssi_rx_digis_ram16x14_syn
	 GENERIC 
	 (
		ram_width	:	NATURAL;
		read_access_time	:	NATURAL;
		write_access_time	:	NATURAL
	 );
	 PORT
	 ( 
		addr_rd1	:	IN STD_LOGIC_VECTOR(15 DOWNTO 0);
		addr_rd2	:	IN STD_LOGIC_VECTOR(15 DOWNTO 0);
		addr_wr	:	IN STD_LOGIC_VECTOR(15 DOWNTO 0);
		clk	:	IN STD_LOGIC;
		data_in	:	IN STD_LOGIC_VECTOR(13 DOWNTO 0);
		data_out1	:	OUT STD_LOGIC_VECTOR(13 DOWNTO 0);
		data_out2	:	OUT STD_LOGIC_VECTOR(13 DOWNTO 0);
		re_l	:	IN STD_LOGIC;
		rst_l	:	IN STD_LOGIC;
		we	:	IN STD_LOGIC
	 ); 
	 END COMPONENT;
 BEGIN

	wire_gnd <= '0';
	wire_vcc <= '1';
	wire_w_lg_n1i1l54w(0) <= NOT n1i1l;
	wire_w_lg_soft_reset2w(0) <= NOT soft_reset;
	align_det_sync <= nlOi;
	audi <= ( nllii & nll0O & nll0l & nll0i & nll1O & nll1l & nll1i & nliOO & nliOl & nliOi & nlilO & nlill & nlili & nliiO);
	audi_pre <= ( nliil & nliii & nli0O & nli0l & nli0i & nli1O & nli1l & nli1i & nl0OO & nl0Ol & nl0Oi & nl0lO & nl0ll & nii0O);
	n10ii <= (((((((((((wire_nllO_w_lg_nll0O249w(0) AND wire_nllO_w_lg_nll0i250w(0)) AND (NOT (wire_n1i_dataout XOR nliiO))) AND (NOT (wire_n1l_dataout XOR nlili))) AND (NOT (wire_n1O_dataout XOR nlill))) AND (NOT (wire_n0i_dataout XOR nlilO))) AND (NOT (wire_n0l_dataout XOR nliOi))) AND (NOT (wire_n0O_dataout XOR nliOl))) AND (NOT (wire_nii_dataout XOR nliOO))) AND (NOT (wire_nil_dataout XOR nll1i))) AND (NOT (wire_niO_dataout XOR nll1l))) AND (NOT (wire_nli_dataout XOR nll1O)));
	n10il <= (((((((((((wire_nllO_w_lg_nll0O249w(0) AND wire_nllO_w_lg_nll0i250w(0)) AND (NOT (wire_nllO_w_lg_nliiO252w(0) XOR (NOT (nlOOOi40 XOR nlOOOi39))))) AND (NOT (nlili XOR rdskchrp(1)))) AND (NOT (nlill XOR rdskchrp(2)))) AND (NOT (nlilO XOR rdskchrp(3)))) AND (NOT (nliOi XOR rdskchrp(4)))) AND (NOT (wire_nllO_w_lg_nliOl271w(0) XOR (NOT (nlOOll42 XOR nlOOll41))))) AND (NOT (nliOO XOR rdskchrp(6)))) AND (NOT (wire_nllO_w_lg_nll1i281w(0) XOR (NOT (nlOOiO44 XOR nlOOiO43))))) AND (NOT (wire_nllO_w_lg_nll1l288w(0) XOR (NOT (nlOOii46 XOR nlOOii45))))) AND (NOT (wire_nllO_w_lg_nll1O295w(0) XOR (NOT (nlOO0l48 XOR nlOO0l47)))));
	n10li <= (n1i0i OR nlOiO);
	n10ll <= ((wire_nlO_w_lg_nll61w(0) OR wire_nlO_w_lg_nll63w(0)) OR (NOT (n10lO14 XOR n10lO13)));
	n1i0i <= (nll AND ((n1iil OR n1iii) OR (NOT (n1i0l4 XOR n1i0l3))));
	n1i1l <= (((wire_niil_w_lg_niii332w(0) AND wire_niil_w_lg_ni0O333w(0)) AND wire_niil_w_lg_ni0l335w(0)) AND wire_niil_w_lg_n0Oi337w(0));
	n1iii <= (((((((((((((NOT sudi(10)) AND (NOT sudi(12))) AND (NOT (wire_n1i_w_lg_dataout200w(0) XOR (NOT (n11il30 XOR n11il29))))) AND (NOT (wire_n1l_dataout XOR sudi(1)))) AND (NOT (wire_n1O_w_lg_dataout210w(0) XOR (NOT (n110O32 XOR n110O31))))) AND (NOT (wire_n0i_dataout XOR sudi(3)))) AND (NOT (wire_n0l_w_lg_dataout220w(0) XOR (NOT (n110i34 XOR n110i33))))) AND (NOT (wire_n0O_dataout XOR sudi(5)))) AND (NOT (wire_nii_dataout XOR sudi(6)))) AND (NOT (wire_nil_w_lg_dataout233w(0) XOR (NOT (n111l36 XOR n111l35))))) AND (NOT (wire_niO_dataout XOR sudi(8)))) AND (NOT (wire_nli_dataout XOR sudi(9)))) AND (nlOOOO38 XOR nlOOOO37));
	n1iil <= (((((((((((((NOT sudi(10)) AND (NOT sudi(12))) AND (NOT (sudi(0) XOR rdskchrp(0)))) AND (NOT (sudi(1) XOR rdskchrp(1)))) AND (NOT (sudi(2) XOR rdskchrp(2)))) AND (NOT ((sudi(3) XOR rdskchrp(3)) XOR (NOT (n101O20 XOR n101O19))))) AND (NOT ((sudi(4) XOR rdskchrp(4)) XOR (NOT (n101i22 XOR n101i21))))) AND (NOT (sudi(5) XOR rdskchrp(5)))) AND (NOT (sudi(6) XOR rdskchrp(6)))) AND (NOT ((sudi(7) XOR rdskchrp(7)) XOR (NOT (n11Ol24 XOR n11Ol23))))) AND (NOT (sudi(8) XOR rdskchrp(8)))) AND (NOT ((sudi(9) XOR rdskchrp(9)) XOR (NOT (n11lO26 XOR n11lO25))))) AND (n11li28 XOR n11li27));
	n1iiO <= '1';
	rd_align <= ((n10il OR n10ii) OR (NOT (n100l18 XOR n100l17)));
	wire_w_rdskchrp_range21w(0) <= rdskchrp(0);
	wire_w_rdskchrp_range11w(0) <= rdskchrp(5);
	wire_w_rdskchrp_range7w(0) <= rdskchrp(7);
	wire_w_rdskchrp_range5w(0) <= rdskchrp(8);
	wire_w_rdskchrp_range3w(0) <= rdskchrp(9);
	wire_w_sudi_range141w(0) <= sudi(0);
	wire_w_sudi_range149w(0) <= sudi(2);
	wire_w_sudi_range161w(0) <= sudi(4);
	wire_w_sudi_range177w(0) <= sudi(7);
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n100l17 <= n100l18;
		END IF;
		if (now = 0 ns) then
			n100l17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n100l18 <= n100l17;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n101i21 <= n101i22;
		END IF;
		if (now = 0 ns) then
			n101i21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n101i22 <= n101i21;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n101O19 <= n101O20;
		END IF;
		if (now = 0 ns) then
			n101O19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n101O20 <= n101O19;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n10iO15 <= n10iO16;
		END IF;
		if (now = 0 ns) then
			n10iO15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n10iO16 <= n10iO15;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n10lO13 <= n10lO14;
		END IF;
		if (now = 0 ns) then
			n10lO13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n10lO14 <= n10lO13;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n10Ol11 <= n10Ol12;
		END IF;
		if (now = 0 ns) then
			n10Ol11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n10Ol12 <= n10Ol11;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n10OO10 <= n10OO9;
		END IF;
	END PROCESS;
	wire_n10OO10_w_lg_w_lg_q39w40w(0) <= wire_n10OO10_w_lg_q39w(0) AND niii;
	wire_n10OO10_w_lg_q39w(0) <= n10OO10 XOR n10OO9;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n10OO9 <= n10OO10;
		END IF;
		if (now = 0 ns) then
			n10OO9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n110i33 <= n110i34;
		END IF;
		if (now = 0 ns) then
			n110i33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n110i34 <= n110i33;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n110O31 <= n110O32;
		END IF;
		if (now = 0 ns) then
			n110O31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n110O32 <= n110O31;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n111l35 <= n111l36;
		END IF;
		if (now = 0 ns) then
			n111l35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n111l36 <= n111l35;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n11il29 <= n11il30;
		END IF;
		if (now = 0 ns) then
			n11il29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n11il30 <= n11il29;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n11li27 <= n11li28;
		END IF;
		if (now = 0 ns) then
			n11li27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n11li28 <= n11li27;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n11lO25 <= n11lO26;
		END IF;
		if (now = 0 ns) then
			n11lO25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n11lO26 <= n11lO25;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n11Ol23 <= n11Ol24;
		END IF;
		if (now = 0 ns) then
			n11Ol23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n11Ol24 <= n11Ol23;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n1i0l3 <= n1i0l4;
		END IF;
		if (now = 0 ns) then
			n1i0l3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n1i0l4 <= n1i0l3;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n1i1i7 <= n1i1i8;
		END IF;
		if (now = 0 ns) then
			n1i1i7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n1i1i8 <= n1i1i7;
		END IF;
	END PROCESS;
	wire_n1i1i8_w_lg_w_lg_q36w37w(0) <= wire_n1i1i8_w_lg_q36w(0) AND ni0O;
	wire_n1i1i8_w_lg_q36w(0) <= n1i1i8 XOR n1i1i7;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n1i1O5 <= n1i1O6;
		END IF;
		if (now = 0 ns) then
			n1i1O5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n1i1O6 <= n1i1O5;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n1ili1 <= n1ili2;
		END IF;
		if (now = 0 ns) then
			n1ili1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN n1ili2 <= n1ili1;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlOO0l47 <= nlOO0l48;
		END IF;
		if (now = 0 ns) then
			nlOO0l47 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlOO0l48 <= nlOO0l47;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlOOii45 <= nlOOii46;
		END IF;
		if (now = 0 ns) then
			nlOOii45 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlOOii46 <= nlOOii45;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlOOiO43 <= nlOOiO44;
		END IF;
		if (now = 0 ns) then
			nlOOiO43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlOOiO44 <= nlOOiO43;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlOOll41 <= nlOOll42;
		END IF;
		if (now = 0 ns) then
			nlOOll41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlOOll42 <= nlOOll41;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlOOOi39 <= nlOOOi40;
		END IF;
		if (now = 0 ns) then
			nlOOOi39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlOOOi40 <= nlOOOi39;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlOOOO37 <= nlOOOO38;
		END IF;
		if (now = 0 ns) then
			nlOOOO37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlOOOO38 <= nlOOOO37;
		END IF;
	END PROCESS;
	PROCESS (clk_1, wire_ni00i_PRN)
	BEGIN
		IF (wire_ni00i_PRN = '0') THEN
				ni00l <= '1';
				ni10i <= '1';
		ELSIF (clk_1 = '1' AND clk_1'event) THEN
				ni00l <= wire_nilil_dataout;
				ni10i <= wire_niiil_dataout;
		END IF;
		if (now = 0 ns) then
			ni00l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni10i <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_ni00i_PRN <= ((n10iO16 XOR n10iO15) AND wire_w_lg_soft_reset2w(0));
	PROCESS (rcvd_clk, wire_niil_PRN, soft_reset)
	BEGIN
		IF (wire_niil_PRN = '0') THEN
				n0Oi <= '1';
				ni0l <= '1';
				ni0O <= '1';
				niii <= '1';
				niiO <= '1';
				nlliO <= '1';
				nllli <= '1';
				nllll <= '1';
				nlllO <= '1';
				nllOi <= '1';
				nllOl <= '1';
				nllOO <= '1';
				nlO0i <= '1';
				nlO0l <= '1';
				nlO0O <= '1';
				nlO1i <= '1';
				nlO1l <= '1';
				nlO1O <= '1';
				nlOii <= '1';
				nlOil <= '1';
				nlOiO <= '1';
		ELSIF (soft_reset = '1') THEN
				n0Oi <= '0';
				ni0l <= '0';
				ni0O <= '0';
				niii <= '0';
				niiO <= '0';
				nlliO <= '0';
				nllli <= '0';
				nllll <= '0';
				nlllO <= '0';
				nllOi <= '0';
				nllOl <= '0';
				nllOO <= '0';
				nlO0i <= '0';
				nlO0l <= '0';
				nlO0O <= '0';
				nlO1i <= '0';
				nlO1l <= '0';
				nlO1O <= '0';
				nlOii <= '0';
				nlOil <= '0';
				nlOiO <= '0';
		ELSIF (rcvd_clk = '1' AND rcvd_clk'event) THEN
				n0Oi <= wire_nili_dataout;
				ni0l <= wire_nill_dataout;
				ni0O <= wire_nilO_dataout;
				niii <= wire_niOi_dataout;
				niiO <= wire_nliO_dataout;
				nlliO <= wire_nlOll_dataout;
				nllli <= wire_nlOlO_dataout;
				nllll <= wire_nlOOi_dataout;
				nlllO <= wire_nlOOl_dataout;
				nllOi <= wire_nlOOO_dataout;
				nllOl <= wire_n11i_dataout;
				nllOO <= wire_n11l_dataout;
				nlO0i <= wire_n10O_dataout;
				nlO0l <= wire_n1ii_dataout;
				nlO0O <= wire_n1il_dataout;
				nlO1i <= wire_n11O_dataout;
				nlO1l <= wire_n10i_dataout;
				nlO1O <= wire_n10l_dataout;
				nlOii <= wire_n1iO_dataout;
				nlOil <= wire_n1li_dataout;
				nlOiO <= wire_n0Ol_dataout;
		END IF;
	END PROCESS;
	wire_niil_PRN <= (n10Ol12 XOR n10Ol11);
	wire_niil_w_lg_nlOiO60w(0) <= nlOiO AND nlOil;
	wire_niil_w_lg_n0Oi337w(0) <= NOT n0Oi;
	wire_niil_w_lg_ni0l335w(0) <= NOT ni0l;
	wire_niil_w_lg_ni0O333w(0) <= NOT ni0O;
	wire_niil_w_lg_niii332w(0) <= NOT niii;
	PROCESS (clk_1, wire_nllO_CLRN)
	BEGIN
		IF (wire_nllO_CLRN = '0') THEN
				ni00O <= '0';
				ni01i <= '0';
				ni01l <= '0';
				ni01O <= '0';
				ni0ii <= '0';
				ni0il <= '0';
				ni0iO <= '0';
				ni0li <= '0';
				ni0ll <= '0';
				ni0lO <= '0';
				ni0Oi <= '0';
				ni0Ol <= '0';
				ni0OO <= '0';
				ni10l <= '0';
				ni10O <= '0';
				ni11l <= '0';
				ni11O <= '0';
				ni1ii <= '0';
				ni1il <= '0';
				ni1iO <= '0';
				ni1li <= '0';
				ni1ll <= '0';
				ni1lO <= '0';
				ni1Oi <= '0';
				ni1Ol <= '0';
				ni1OO <= '0';
				nii0i <= '0';
				nii0l <= '0';
				nii0O <= '0';
				nii1i <= '0';
				nii1l <= '0';
				nii1O <= '0';
				nl0ll <= '0';
				nl0lO <= '0';
				nl0Oi <= '0';
				nl0Ol <= '0';
				nl0OO <= '0';
				nli0i <= '0';
				nli0l <= '0';
				nli0O <= '0';
				nli1i <= '0';
				nli1l <= '0';
				nli1O <= '0';
				nliii <= '0';
				nliil <= '0';
				nliiO <= '0';
				nlili <= '0';
				nlill <= '0';
				nlilO <= '0';
				nliOi <= '0';
				nliOl <= '0';
				nliOO <= '0';
				nll0i <= '0';
				nll0l <= '0';
				nll0O <= '0';
				nll1i <= '0';
				nll1l <= '0';
				nll1O <= '0';
				nllii <= '0';
				nlOi <= '0';
		ELSIF (clk_1 = '1' AND clk_1'event) THEN
				ni00O <= wire_niliO_dataout;
				ni01i <= wire_nil0l_dataout;
				ni01l <= wire_nil0O_dataout;
				ni01O <= wire_nilii_dataout;
				ni0ii <= wire_nilli_dataout;
				ni0il <= wire_nilll_dataout;
				ni0iO <= wire_nillO_dataout;
				ni0li <= wire_nilOi_dataout;
				ni0ll <= wire_nilOl_dataout;
				ni0lO <= wire_nilOO_dataout;
				ni0Oi <= wire_niO1i_dataout;
				ni0Ol <= wire_niO1l_dataout;
				ni0OO <= wire_niO1O_dataout;
				ni10l <= wire_niiiO_dataout;
				ni10O <= wire_niili_dataout;
				ni11l <= niiO;
				ni11O <= wire_niiii_dataout;
				ni1ii <= wire_niill_dataout;
				ni1il <= wire_niilO_dataout;
				ni1iO <= wire_niiOi_dataout;
				ni1li <= wire_niiOl_dataout;
				ni1ll <= wire_niiOO_dataout;
				ni1lO <= wire_nil1i_dataout;
				ni1Oi <= wire_nil1l_dataout;
				ni1Ol <= wire_nil1O_dataout;
				ni1OO <= wire_nil0i_dataout;
				nii0i <= wire_niOii_dataout;
				nii0l <= wire_niOil_dataout;
				nii0O <= wire_n1iOi_data_out2(0);
				nii1i <= wire_niO0i_dataout;
				nii1l <= wire_niO0l_dataout;
				nii1O <= wire_niO0O_dataout;
				nl0ll <= wire_n1iOi_data_out2(1);
				nl0lO <= wire_n1iOi_data_out2(2);
				nl0Oi <= wire_n1iOi_data_out2(3);
				nl0Ol <= wire_n1iOi_data_out2(4);
				nl0OO <= wire_n1iOi_data_out2(5);
				nli0i <= wire_n1iOi_data_out2(9);
				nli0l <= wire_n1iOi_data_out2(10);
				nli0O <= wire_n1iOi_data_out2(11);
				nli1i <= wire_n1iOi_data_out2(6);
				nli1l <= wire_n1iOi_data_out2(7);
				nli1O <= wire_n1iOi_data_out2(8);
				nliii <= wire_n1iOi_data_out2(12);
				nliil <= wire_n1iOi_data_out2(13);
				nliiO <= wire_n1iOi_data_out1(0);
				nlili <= wire_n1iOi_data_out1(1);
				nlill <= wire_n1iOi_data_out1(2);
				nlilO <= wire_n1iOi_data_out1(3);
				nliOi <= wire_n1iOi_data_out1(4);
				nliOl <= wire_n1iOi_data_out1(5);
				nliOO <= wire_n1iOi_data_out1(6);
				nll0i <= wire_n1iOi_data_out1(10);
				nll0l <= wire_n1iOi_data_out1(11);
				nll0O <= wire_n1iOi_data_out1(12);
				nll1i <= wire_n1iOi_data_out1(7);
				nll1l <= wire_n1iOi_data_out1(8);
				nll1O <= wire_n1iOi_data_out1(9);
				nllii <= wire_n1iOi_data_out1(13);
				nlOi <= ni11l;
		END IF;
	END PROCESS;
	wire_nllO_CLRN <= ((n1i1O6 XOR n1i1O5) AND wire_w_lg_soft_reset2w(0));
	wire_nllO_w_lg_nll0i250w(0) <= NOT nll0i;
	wire_nllO_w_lg_nll0O249w(0) <= NOT nll0O;
	wire_nllO_w_lg_nliiO252w(0) <= nliiO XOR wire_w_rdskchrp_range21w(0);
	wire_nllO_w_lg_nliOl271w(0) <= nliOl XOR wire_w_rdskchrp_range11w(0);
	wire_nllO_w_lg_nll1i281w(0) <= nll1i XOR wire_w_rdskchrp_range7w(0);
	wire_nllO_w_lg_nll1l288w(0) <= nll1l XOR wire_w_rdskchrp_range5w(0);
	wire_nllO_w_lg_nll1O295w(0) <= nll1O XOR wire_w_rdskchrp_range3w(0);
	PROCESS (rcvd_clk, soft_reset, wire_nlO_CLRN)
	BEGIN
		IF (soft_reset = '1') THEN
				ni <= '1';
				nlil <= '1';
				nll <= '1';
				nllil <= '1';
		ELSIF (wire_nlO_CLRN = '0') THEN
				ni <= '0';
				nlil <= '0';
				nll <= '0';
				nllil <= '0';
		ELSIF (rcvd_clk = '1' AND rcvd_clk'event) THEN
				ni <= wire_nO_dataout;
				nlil <= nll;
				nll <= ni;
				nllil <= wire_nlOli_dataout;
		END IF;
		if (now = 0 ns) then
			ni <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlil <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nllil <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nlO_CLRN <= (n1ili2 XOR n1ili1);
	wire_nlO_w_lg_nll61w(0) <= nll AND wire_niil_w_lg_nlOiO60w(0);
	wire_nlO_w_lg_nll63w(0) <= nll AND wire_nlO_w_lg_nlil62w(0);
	wire_nlO_w_lg_nlil62w(0) <= NOT nlil;
	wire_nlO_w_lg_nll58w(0) <= NOT nll;
	wire_n00i_dataout <= nllOO WHEN n10li = '1'  ELSE nlO1i;
	wire_n00l_dataout <= nlO1i WHEN n10li = '1'  ELSE nlO1l;
	wire_n00O_dataout <= nlO1l WHEN n10li = '1'  ELSE nlO1O;
	wire_n01i_dataout <= nlllO WHEN n10li = '1'  ELSE nllOi;
	wire_n01l_dataout <= nllOi WHEN n10li = '1'  ELSE nllOl;
	wire_n01O_dataout <= nllOl WHEN n10li = '1'  ELSE nllOO;
	wire_n0i_dataout <= rdskchrp(3) WHEN rdskposdisp = '1'  ELSE (NOT rdskchrp(3));
	wire_n0ii_dataout <= nlO1O WHEN n10li = '1'  ELSE nlO0i;
	wire_n0il_dataout <= nlO0i WHEN n10li = '1'  ELSE nlO0l;
	wire_n0iO_dataout <= nlO0l WHEN n10li = '1'  ELSE nlO0O;
	wire_n0l_dataout <= rdskchrp(4) WHEN rdskposdisp = '1'  ELSE (NOT rdskchrp(4));
	wire_n0l_w_lg_dataout220w(0) <= wire_n0l_dataout XOR wire_w_sudi_range161w(0);
	wire_n0li_dataout <= nlO0O WHEN n10li = '1'  ELSE nlOii;
	wire_n0ll_dataout <= nlOii WHEN n10li = '1'  ELSE nlOil;
	wire_n0O_dataout <= rdskchrp(5) WHEN rdskposdisp = '1'  ELSE (NOT rdskchrp(5));
	wire_n0Ol_dataout <= wire_n0OO_dataout AND NOT(n10ll);
	wire_n0OO_dataout <= nlOiO OR n1i0i;
	wire_n10i_dataout <= wire_n00l_dataout AND NOT(n10ll);
	wire_n10l_dataout <= wire_n00O_dataout AND NOT(n10ll);
	wire_n10O_dataout <= wire_n0ii_dataout AND NOT(n10ll);
	wire_n11i_dataout <= wire_n01l_dataout AND NOT(n10ll);
	wire_n11l_dataout <= wire_n01O_dataout AND NOT(n10ll);
	wire_n11O_dataout <= wire_n00i_dataout AND NOT(n10ll);
	wire_n1i_dataout <= rdskchrp(0) WHEN rdskposdisp = '1'  ELSE (NOT rdskchrp(0));
	wire_n1i_w_lg_dataout200w(0) <= wire_n1i_dataout XOR wire_w_sudi_range141w(0);
	wire_n1ii_dataout <= wire_n0il_dataout AND NOT(n10ll);
	wire_n1il_dataout <= wire_n0iO_dataout AND NOT(n10ll);
	wire_n1iO_dataout <= wire_n0li_dataout AND NOT(n10ll);
	wire_n1l_dataout <= rdskchrp(1) WHEN rdskposdisp = '1'  ELSE (NOT rdskchrp(1));
	wire_n1li_dataout <= wire_n0ll_dataout AND NOT(n10ll);
	wire_n1ll_dataout <= nlOil WHEN n10li = '1'  ELSE nllil;
	wire_n1lO_dataout <= nllil WHEN n10li = '1'  ELSE nlliO;
	wire_n1O_dataout <= rdskchrp(2) WHEN rdskposdisp = '1'  ELSE (NOT rdskchrp(2));
	wire_n1O_w_lg_dataout210w(0) <= wire_n1O_dataout XOR wire_w_sudi_range149w(0);
	wire_n1Oi_dataout <= nlliO WHEN n10li = '1'  ELSE nllli;
	wire_n1Ol_dataout <= nllli WHEN n10li = '1'  ELSE nllll;
	wire_n1OO_dataout <= nllll WHEN n10li = '1'  ELSE nlllO;
	wire_nii_dataout <= rdskchrp(6) WHEN rdskposdisp = '1'  ELSE (NOT rdskchrp(6));
	wire_niiii_dataout <= wire_niOiO_dataout AND NOT(wire_nl_dataout);
	wire_niiil_dataout <= wire_niOli_dataout OR wire_nl_dataout;
	wire_niiiO_dataout <= wire_niOll_dataout AND NOT(wire_nl_dataout);
	wire_niili_dataout <= wire_niOlO_dataout AND NOT(wire_nl_dataout);
	wire_niill_dataout <= wire_niOOi_dataout AND NOT(wire_nl_dataout);
	wire_niilO_dataout <= wire_niOOl_dataout AND NOT(wire_nl_dataout);
	wire_niiOi_dataout <= wire_niOOO_dataout AND NOT(wire_nl_dataout);
	wire_niiOl_dataout <= wire_nl11i_dataout AND NOT(wire_nl_dataout);
	wire_niiOO_dataout <= wire_nl11l_dataout AND NOT(wire_nl_dataout);
	wire_nil_dataout <= rdskchrp(7) WHEN rdskposdisp = '1'  ELSE (NOT rdskchrp(7));
	wire_nil_w_lg_dataout233w(0) <= wire_nil_dataout XOR wire_w_sudi_range177w(0);
	wire_nil0i_dataout <= wire_nl10O_dataout AND NOT(wire_nl_dataout);
	wire_nil0l_dataout <= wire_nl1ii_dataout AND NOT(wire_nl_dataout);
	wire_nil0O_dataout <= wire_nl1il_dataout AND NOT(wire_nl_dataout);
	wire_nil1i_dataout <= wire_nl11O_dataout AND NOT(wire_nl_dataout);
	wire_nil1l_dataout <= wire_nl10i_dataout AND NOT(wire_nl_dataout);
	wire_nil1O_dataout <= wire_nl10l_dataout AND NOT(wire_nl_dataout);
	wire_nili_dataout <= wire_niOl_dataout AND NOT(wire_nlO_w_lg_nll58w(0));
	wire_nilii_dataout <= wire_nl1iO_dataout AND NOT(wire_nl_dataout);
	wire_nilil_dataout <= wire_nl1li_dataout OR wire_nl_dataout;
	wire_niliO_dataout <= wire_nl1ll_dataout AND NOT(wire_nl_dataout);
	wire_nill_dataout <= wire_niOO_dataout AND NOT(wire_nlO_w_lg_nll58w(0));
	wire_nilli_dataout <= wire_nl1lO_dataout AND NOT(wire_nl_dataout);
	wire_nilll_dataout <= wire_nl1Oi_dataout AND NOT(wire_nl_dataout);
	wire_nillO_dataout <= wire_nl1Ol_dataout AND NOT(wire_nl_dataout);
	wire_nilO_dataout <= wire_nl1i_dataout AND NOT(wire_nlO_w_lg_nll58w(0));
	wire_nilOi_dataout <= wire_nl1OO_dataout AND NOT(wire_nl_dataout);
	wire_nilOl_dataout <= wire_nl01i_dataout AND NOT(wire_nl_dataout);
	wire_nilOO_dataout <= wire_nl01l_dataout AND NOT(wire_nl_dataout);
	wire_niO_dataout <= rdskchrp(8) WHEN rdskposdisp = '1'  ELSE (NOT rdskchrp(8));
	wire_niO0i_dataout <= wire_nl00O_dataout AND NOT(wire_nl_dataout);
	wire_niO0l_dataout <= wire_nl0ii_dataout AND NOT(wire_nl_dataout);
	wire_niO0O_dataout <= wire_nl0il_dataout AND NOT(wire_nl_dataout);
	wire_niO1i_dataout <= wire_nl01O_dataout AND NOT(wire_nl_dataout);
	wire_niO1l_dataout <= wire_nl00i_dataout AND NOT(wire_nl_dataout);
	wire_niO1O_dataout <= wire_nl00l_dataout AND NOT(wire_nl_dataout);
	wire_niOi_dataout <= wire_nl1l_dataout AND NOT(wire_nlO_w_lg_nll58w(0));
	wire_niOii_dataout <= wire_nl0iO_dataout AND NOT(wire_nl_dataout);
	wire_niOil_dataout <= wire_nl0li_dataout AND NOT(wire_nl_dataout);
	wire_niOiO_dataout <= ni01O AND wire_nO_w_lg_dataout97w(0);
	wire_niOl_dataout <= wire_nl1O_dataout OR n1i0i;
	wire_niOli_dataout <= ni11O OR NOT(wire_nO_w_lg_dataout97w(0));
	wire_niOll_dataout <= ni10i AND wire_nO_w_lg_dataout97w(0);
	wire_niOlO_dataout <= ni10l AND wire_nO_w_lg_dataout97w(0);
	wire_niOO_dataout <= wire_nl0i_dataout AND NOT(n1i0i);
	wire_niOOi_dataout <= ni10O AND wire_nO_w_lg_dataout97w(0);
	wire_niOOl_dataout <= ni1ii AND wire_nO_w_lg_dataout97w(0);
	wire_niOOO_dataout <= ni1il AND wire_nO_w_lg_dataout97w(0);
	wire_nl_dataout <= fifo_rst_rd_gp WHEN sel_gp_md = '1'  ELSE fifo_rst_rd_qd;
	wire_nl00i_dataout <= ni0Oi AND wire_nO_w_lg_dataout97w(0);
	wire_nl00l_dataout <= ni0Ol AND wire_nO_w_lg_dataout97w(0);
	wire_nl00O_dataout <= ni0OO AND wire_nO_w_lg_dataout97w(0);
	wire_nl01i_dataout <= ni0li AND wire_nO_w_lg_dataout97w(0);
	wire_nl01l_dataout <= ni0ll AND wire_nO_w_lg_dataout97w(0);
	wire_nl01O_dataout <= ni0lO AND wire_nO_w_lg_dataout97w(0);
	wire_nl0i_dataout <= wire_nlii_o(2) WHEN wire_w_lg_n1i1l54w(0) = '1'  ELSE ni0l;
	wire_nl0ii_dataout <= nii1i AND wire_nO_w_lg_dataout97w(0);
	wire_nl0il_dataout <= nii1l AND wire_nO_w_lg_dataout97w(0);
	wire_nl0iO_dataout <= nii1O AND wire_nO_w_lg_dataout97w(0);
	wire_nl0l_dataout <= wire_nlii_o(3) WHEN wire_w_lg_n1i1l54w(0) = '1'  ELSE ni0O;
	wire_nl0li_dataout <= nii0i AND wire_nO_w_lg_dataout97w(0);
	wire_nl0O_dataout <= wire_nlii_o(4) WHEN wire_w_lg_n1i1l54w(0) = '1'  ELSE niii;
	wire_nl10i_dataout <= ni1lO AND wire_nO_w_lg_dataout97w(0);
	wire_nl10l_dataout <= ni1Oi AND wire_nO_w_lg_dataout97w(0);
	wire_nl10O_dataout <= ni1Ol AND wire_nO_w_lg_dataout97w(0);
	wire_nl11i_dataout <= ni1iO AND wire_nO_w_lg_dataout97w(0);
	wire_nl11l_dataout <= ni1li AND wire_nO_w_lg_dataout97w(0);
	wire_nl11O_dataout <= ni1ll AND wire_nO_w_lg_dataout97w(0);
	wire_nl1i_dataout <= wire_nl0l_dataout AND NOT(n1i0i);
	wire_nl1ii_dataout <= ni1OO AND wire_nO_w_lg_dataout97w(0);
	wire_nl1il_dataout <= ni01i AND wire_nO_w_lg_dataout97w(0);
	wire_nl1iO_dataout <= ni01l AND wire_nO_w_lg_dataout97w(0);
	wire_nl1l_dataout <= wire_nl0O_dataout OR n1i0i;
	wire_nl1li_dataout <= nii0l OR NOT(wire_nO_w_lg_dataout97w(0));
	wire_nl1ll_dataout <= ni00l AND wire_nO_w_lg_dataout97w(0);
	wire_nl1lO_dataout <= ni00O AND wire_nO_w_lg_dataout97w(0);
	wire_nl1O_dataout <= wire_nlii_o(1) WHEN wire_w_lg_n1i1l54w(0) = '1'  ELSE n0Oi;
	wire_nl1Oi_dataout <= ni0ii AND wire_nO_w_lg_dataout97w(0);
	wire_nl1Ol_dataout <= ni0il AND wire_nO_w_lg_dataout97w(0);
	wire_nl1OO_dataout <= ni0iO AND wire_nO_w_lg_dataout97w(0);
	wire_nli_dataout <= rdskchrp(9) WHEN rdskposdisp = '1'  ELSE (NOT rdskchrp(9));
	wire_nliO_dataout <= wire_nlli_dataout OR n1i0i;
	wire_nlli_dataout <= niiO AND NOT(n1i1l);
	wire_nlOli_dataout <= wire_n1ll_dataout OR n10ll;
	wire_nlOll_dataout <= wire_n1lO_dataout AND NOT(n10ll);
	wire_nlOlO_dataout <= wire_n1Oi_dataout AND NOT(n10ll);
	wire_nlOOi_dataout <= wire_n1Ol_dataout AND NOT(n10ll);
	wire_nlOOl_dataout <= wire_n1OO_dataout AND NOT(n10ll);
	wire_nlOOO_dataout <= wire_n01i_dataout AND NOT(n10ll);
	wire_nO_dataout <= en_dskw_gp WHEN sel_gp_md = '1'  ELSE en_dskw_qd;
	wire_nO_w_lg_dataout97w(0) <= NOT wire_nO_dataout;
	wire_nlii_a <= ( wire_n10OO10_w_lg_w_lg_q39w40w & wire_n1i1i8_w_lg_w_lg_q36w37w & ni0l & n0Oi & "1");
	wire_nlii_b <= ( "1" & "1" & "1" & "0" & "1");
	nlii :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_nlii_a,
		b => wire_nlii_b,
		cin => wire_gnd,
		o => wire_nlii_o
	  );
	wire_n1iOi_addr_rd1 <= ( nii0l & nii0i & nii1O & nii1l & nii1i & ni0OO & ni0Ol & ni0Oi & ni0lO & ni0ll & ni0li & ni0iO & ni0il & ni0ii & ni00O & ni00l);
	wire_n1iOi_addr_rd2 <= ( ni01O & ni01l & ni01i & ni1OO & ni1Ol & ni1Oi & ni1lO & ni1ll & ni1li & ni1iO & ni1il & ni1ii & ni10O & ni10l & ni10i & ni11O);
	wire_n1iOi_addr_wr <= ( nlOil & nlOii & nlO0O & nlO0l & nlO0i & nlO1O & nlO1l & nlO1i & nllOO & nllOl & nllOi & nlllO & nllll & nllli & nlliO & nllil);
	wire_n1iOi_data_in <= ( sudi(13 DOWNTO 0));
	wire_n1iOi_rst_l <= wire_w_lg_soft_reset2w(0);
	n1iOi :  stratixiv_hssi_rx_digis_ram16x14_syn
	  GENERIC MAP (
		ram_width => 14,
		read_access_time => 0,
		write_access_time => 0
	  )
	  PORT MAP ( 
		addr_rd1 => wire_n1iOi_addr_rd1,
		addr_rd2 => wire_n1iOi_addr_rd2,
		addr_wr => wire_n1iOi_addr_wr,
		clk => rcvd_clk,
		data_in => wire_n1iOi_data_in,
		data_out1 => wire_n1iOi_data_out1,
		data_out2 => wire_n1iOi_data_out2,
		re_l => wire_gnd,
		rst_l => wire_n1iOi_rst_l,
		we => wire_vcc
	  );

 END RTL; --stratixiv_hssi_rx_digi_dskw_fifo
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 162 mux21 158 oper_add 7 oper_less_than 17 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_rx_digi_freqdet IS 
	 PORT 
	 ( 
		 eidle_exit	:	IN  STD_LOGIC;
		 fref	:	IN  STD_LOGIC;
		 freq_lock	:	OUT  STD_LOGIC;
		 fvcobyn	:	IN  STD_LOGIC;
		 gen2ngen1_bundle	:	IN  STD_LOGIC;
		 gen2ngen1_indv	:	IN  STD_LOGIC;
		 hard_reset	:	IN  STD_LOGIC;
		 pd	:	IN  STD_LOGIC;
		 ppm_cnt_latch	:	OUT  STD_LOGIC_VECTOR (7 DOWNTO 0);
		 ppm_cnt_reset	:	IN  STD_LOGIC;
		 ppmsel	:	IN  STD_LOGIC_VECTOR (5 DOWNTO 0);
		 rauto_speed_ena	:	IN  STD_LOGIC;
		 rforcehigh	:	IN  STD_LOGIC;
		 rforcelow	:	IN  STD_LOGIC;
		 rindv_rx	:	IN  STD_LOGIC;
		 rppm_gen1_2xcnt_en	:	IN  STD_LOGIC;
		 rppm_post_eidle_del	:	IN  STD_LOGIC;
		 scan_mode	:	IN  STD_LOGIC
	 ); 
 END stratixiv_hssi_rx_digi_freqdet;

 ARCHITECTURE RTL OF stratixiv_hssi_rx_digi_freqdet IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 nlll0O57	:	STD_LOGIC := '0';
	 SIGNAL	 nlll0O58	:	STD_LOGIC := '0';
	 SIGNAL	 nllOOi55	:	STD_LOGIC := '0';
	 SIGNAL	 nllOOi56	:	STD_LOGIC := '0';
	 SIGNAL	 nlO00i21	:	STD_LOGIC := '0';
	 SIGNAL	 nlO00i22	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO00i22_w_lg_w_lg_q87w88w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO00i22_w_lg_q87w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO00l19	:	STD_LOGIC := '0';
	 SIGNAL	 nlO00l20	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO00l20_w_lg_w_lg_q84w85w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO00l20_w_lg_q84w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO00O17	:	STD_LOGIC := '0';
	 SIGNAL	 nlO00O18	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO00O18_w_lg_w_lg_q78w79w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO00O18_w_lg_q78w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO01i27	:	STD_LOGIC := '0';
	 SIGNAL	 nlO01i28	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO01i28_w_lg_w_lg_q168w169w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO01i28_w_lg_q168w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO01l25	:	STD_LOGIC := '0';
	 SIGNAL	 nlO01l26	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO01l26_w_lg_w_lg_q165w166w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO01l26_w_lg_q165w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO01O23	:	STD_LOGIC := '0';
	 SIGNAL	 nlO01O24	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO01O24_w_lg_w_lg_q108w109w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO01O24_w_lg_q108w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO0ii15	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0ii16	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO0ii16_w_lg_w_lg_q72w73w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0ii16_w_lg_q72w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO0iO13	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0iO14	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0ll11	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0ll12	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0Oi10	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0Oi9	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0Ol7	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0Ol8	:	STD_LOGIC := '0';
	 SIGNAL	 nlO10i47	:	STD_LOGIC := '0';
	 SIGNAL	 nlO10i48	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO10i48_w_lg_w_lg_q355w356w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO10i48_w_lg_q355w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO10l45	:	STD_LOGIC := '0';
	 SIGNAL	 nlO10l46	:	STD_LOGIC := '0';
	 SIGNAL	 nlO10O43	:	STD_LOGIC := '0';
	 SIGNAL	 nlO10O44	:	STD_LOGIC := '0';
	 SIGNAL	 nlO11i53	:	STD_LOGIC := '0';
	 SIGNAL	 nlO11i54	:	STD_LOGIC := '0';
	 SIGNAL	 nlO11l51	:	STD_LOGIC := '0';
	 SIGNAL	 nlO11l52	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO11l52_w_lg_w_lg_q434w435w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO11l52_w_lg_q434w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO11O49	:	STD_LOGIC := '0';
	 SIGNAL	 nlO11O50	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO11O50_w_lg_w_lg_q431w432w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO11O50_w_lg_q431w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO1ii41	:	STD_LOGIC := '0';
	 SIGNAL	 nlO1ii42	:	STD_LOGIC := '0';
	 SIGNAL	 nlO1li39	:	STD_LOGIC := '0';
	 SIGNAL	 nlO1li40	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO1li40_w_lg_w_lg_q266w267w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1li40_w_lg_q266w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO1ll37	:	STD_LOGIC := '0';
	 SIGNAL	 nlO1ll38	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO1ll38_w_lg_w_lg_q261w262w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1ll38_w_lg_q261w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO1lO35	:	STD_LOGIC := '0';
	 SIGNAL	 nlO1lO36	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO1lO36_w_lg_w_lg_q255w256w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1lO36_w_lg_q255w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO1Oi33	:	STD_LOGIC := '0';
	 SIGNAL	 nlO1Oi34	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO1Oi34_w_lg_w_lg_q219w220w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1Oi34_w_lg_q219w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO1Ol31	:	STD_LOGIC := '0';
	 SIGNAL	 nlO1Ol32	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO1Ol32_w_lg_w_lg_q182w183w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1Ol32_w_lg_q182w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlO1OO29	:	STD_LOGIC := '0';
	 SIGNAL	 nlO1OO30	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO1OO30_w_lg_w_lg_q177w178w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1OO30_w_lg_q177w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlOi0l3	:	STD_LOGIC := '0';
	 SIGNAL	 nlOi0l4	:	STD_LOGIC := '0';
	 SIGNAL	 nlOi1l5	:	STD_LOGIC := '0';
	 SIGNAL	 nlOi1l6	:	STD_LOGIC := '0';
	 SIGNAL	 nlOiil1	:	STD_LOGIC := '0';
	 SIGNAL	 nlOiil2	:	STD_LOGIC := '0';
	 SIGNAL	n0lOO	:	STD_LOGIC := '0';
	 SIGNAL	n1i	:	STD_LOGIC := '0';
	 SIGNAL	nii	:	STD_LOGIC := '0';
	 SIGNAL	wire_n0O_CLRN	:	STD_LOGIC;
	 SIGNAL	n10iO	:	STD_LOGIC := '0';
	 SIGNAL	n1ilO	:	STD_LOGIC := '0';
	 SIGNAL	wire_n1ill_CLRN	:	STD_LOGIC;
	 SIGNAL	n0lOi	:	STD_LOGIC := '0';
	 SIGNAL	ni00O	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni00l_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_ni00l_w_lg_w_lg_n0lOi8w9w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni00l_w_lg_n0lOi512w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni00l_w_lg_n0lOi8w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni00l_w_lg_w_lg_w_lg_n0lOi1w2w3w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni00l_w_lg_w_lg_n0lOi1w2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni00l_w_lg_n0lOi1w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nl0lO	:	STD_LOGIC := '0';
	 SIGNAL	ni00i	:	STD_LOGIC := '0';
	 SIGNAL	ni01i	:	STD_LOGIC := '0';
	 SIGNAL	ni01l	:	STD_LOGIC := '0';
	 SIGNAL	ni01O	:	STD_LOGIC := '0';
	 SIGNAL	ni10i	:	STD_LOGIC := '0';
	 SIGNAL	ni10l	:	STD_LOGIC := '0';
	 SIGNAL	ni10O	:	STD_LOGIC := '0';
	 SIGNAL	ni11O	:	STD_LOGIC := '0';
	 SIGNAL	ni1ii	:	STD_LOGIC := '0';
	 SIGNAL	ni1il	:	STD_LOGIC := '0';
	 SIGNAL	ni1iO	:	STD_LOGIC := '0';
	 SIGNAL	ni1li	:	STD_LOGIC := '0';
	 SIGNAL	ni1ll	:	STD_LOGIC := '0';
	 SIGNAL	ni1lO	:	STD_LOGIC := '0';
	 SIGNAL	ni1Oi	:	STD_LOGIC := '0';
	 SIGNAL	ni1Ol	:	STD_LOGIC := '0';
	 SIGNAL	ni1OO	:	STD_LOGIC := '0';
	 SIGNAL	nl00O	:	STD_LOGIC := '0';
	 SIGNAL	nl01l	:	STD_LOGIC := '0';
	 SIGNAL	nl0Ol	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl0Oi_w_lg_ni00i1130w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Oi_w_lg_ni01i1135w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Oi_w_lg_ni01l1133w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Oi_w_lg_ni01O1131w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Oi_w_lg_ni1ll1145w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Oi_w_lg_ni1lO1143w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Oi_w_lg_ni1Oi1141w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Oi_w_lg_ni1Ol1139w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Oi_w_lg_ni1OO1137w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n00ii	:	STD_LOGIC := '0';
	 SIGNAL	n00il	:	STD_LOGIC := '0';
	 SIGNAL	n00iO	:	STD_LOGIC := '0';
	 SIGNAL	n00li	:	STD_LOGIC := '0';
	 SIGNAL	n00ll	:	STD_LOGIC := '0';
	 SIGNAL	n00lO	:	STD_LOGIC := '0';
	 SIGNAL	n00Oi	:	STD_LOGIC := '0';
	 SIGNAL	n00Ol	:	STD_LOGIC := '0';
	 SIGNAL	n0lli	:	STD_LOGIC := '0';
	 SIGNAL	n0lll	:	STD_LOGIC := '0';
	 SIGNAL	n0llO	:	STD_LOGIC := '0';
	 SIGNAL	n100i	:	STD_LOGIC := '0';
	 SIGNAL	n100l	:	STD_LOGIC := '0';
	 SIGNAL	n100O	:	STD_LOGIC := '0';
	 SIGNAL	n101l	:	STD_LOGIC := '0';
	 SIGNAL	n101O	:	STD_LOGIC := '0';
	 SIGNAL	n10ii	:	STD_LOGIC := '0';
	 SIGNAL	n10il	:	STD_LOGIC := '0';
	 SIGNAL	n1iOi	:	STD_LOGIC := '0';
	 SIGNAL	n1iOO	:	STD_LOGIC := '0';
	 SIGNAL	niiOl	:	STD_LOGIC := '0';
	 SIGNAL	niiOO	:	STD_LOGIC := '0';
	 SIGNAL	nil0i	:	STD_LOGIC := '0';
	 SIGNAL	nil0l	:	STD_LOGIC := '0';
	 SIGNAL	nil0O	:	STD_LOGIC := '0';
	 SIGNAL	nil1i	:	STD_LOGIC := '0';
	 SIGNAL	nil1l	:	STD_LOGIC := '0';
	 SIGNAL	nil1O	:	STD_LOGIC := '0';
	 SIGNAL	nilii	:	STD_LOGIC := '0';
	 SIGNAL	nilil	:	STD_LOGIC := '0';
	 SIGNAL	niliO	:	STD_LOGIC := '0';
	 SIGNAL	nilli	:	STD_LOGIC := '0';
	 SIGNAL	nilll	:	STD_LOGIC := '0';
	 SIGNAL	nillO	:	STD_LOGIC := '0';
	 SIGNAL	nilOi	:	STD_LOGIC := '0';
	 SIGNAL	nilOl	:	STD_LOGIC := '0';
	 SIGNAL	nilOO	:	STD_LOGIC := '0';
	 SIGNAL	niO1i	:	STD_LOGIC := '0';
	 SIGNAL	nl01i	:	STD_LOGIC := '0';
	 SIGNAL	nl0ii	:	STD_LOGIC := '0';
	 SIGNAL	nl0il	:	STD_LOGIC := '0';
	 SIGNAL	nl0iO	:	STD_LOGIC := '0';
	 SIGNAL	nl0li	:	STD_LOGIC := '0';
	 SIGNAL	nl1iO	:	STD_LOGIC := '0';
	 SIGNAL	nl1li	:	STD_LOGIC := '0';
	 SIGNAL	nli1i	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl0OO_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nl0OO_w_lg_n0lli15w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OO_w_lg_n0lll10w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OO_w_lg_n0llO511w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OO_w_lg_nl0iO515w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OO_w_lg_nl1li697w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nli1O	:	STD_LOGIC := '0';
	 SIGNAL	nliil	:	STD_LOGIC := '0';
	 SIGNAL	wire_nliii_PRN	:	STD_LOGIC;
	 SIGNAL	nliiO	:	STD_LOGIC := '0';
	 SIGNAL	nlilO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlill_PRN	:	STD_LOGIC;
	 SIGNAL	nlli	:	STD_LOGIC := '0';
	 SIGNAL	wire_nliO_CLRN	:	STD_LOGIC;
	 SIGNAL	nlii	:	STD_LOGIC := '0';
	 SIGNAL	nlil	:	STD_LOGIC := '0';
	 SIGNAL	nliOi	:	STD_LOGIC := '0';
	 SIGNAL	nll0i	:	STD_LOGIC := '0';
	 SIGNAL	nll0l	:	STD_LOGIC := '0';
	 SIGNAL	nll0O	:	STD_LOGIC := '0';
	 SIGNAL	nll1l	:	STD_LOGIC := '0';
	 SIGNAL	nll1O	:	STD_LOGIC := '0';
	 SIGNAL	nllii	:	STD_LOGIC := '0';
	 SIGNAL	nllil	:	STD_LOGIC := '0';
	 SIGNAL	nlliO	:	STD_LOGIC := '0';
	 SIGNAL	nllli	:	STD_LOGIC := '0';
	 SIGNAL	nllll	:	STD_LOGIC := '0';
	 SIGNAL	nlllO	:	STD_LOGIC := '0';
	 SIGNAL	nllO	:	STD_LOGIC := '0';
	 SIGNAL	nllOi	:	STD_LOGIC := '0';
	 SIGNAL	nllOl	:	STD_LOGIC := '0';
	 SIGNAL	nllOO	:	STD_LOGIC := '0';
	 SIGNAL	nlO0i	:	STD_LOGIC := '0';
	 SIGNAL	nlO0l	:	STD_LOGIC := '0';
	 SIGNAL	nlO1i	:	STD_LOGIC := '0';
	 SIGNAL	nlO1l	:	STD_LOGIC := '0';
	 SIGNAL	nlO1O	:	STD_LOGIC := '0';
	 SIGNAL	nlOi	:	STD_LOGIC := '0';
	 SIGNAL	nlOO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlOl_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nlOl_PRN	:	STD_LOGIC;
	 SIGNAL  wire_nlOl_w_lg_w_lg_w_lg_w_lg_w1102w1104w1106w1108w1109w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_w_lg_w_lg_w1102w1104w1106w1108w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_w_lg_w1102w1104w1106w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_w1102w1104w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w1102w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_w_lg_w_lg_w_lg_nlO0i1094w1096w1098w1100w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_w_lg_w_lg_nlO0i1094w1096w1098w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_w_lg_nlO0i1094w1096w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_nll0i1114w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_nll0l1112w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_nll1O1116w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_nllil1110w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_nlllO1107w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_nllOi1105w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_nllOl1103w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_nllOO1101w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_nlO0i1094w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_nlO0l31w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_nlO1i1099w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_nlO1l1097w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOl_w_lg_nlO1O1095w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0i_w_lg_dataout18w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0l_w_lg_dataout22w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli0O_w_lg_dataout509w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlili_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlili_w_lg_dataout507w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nliOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nliOl_w_lg_dataout328w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0liO_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n0liO_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_gnd	:	STD_LOGIC;
	 SIGNAL  wire_n0liO_o	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n0OOO_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0OOO_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0OOO_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niiOi_a	:	STD_LOGIC_VECTOR (16 DOWNTO 0);
	 SIGNAL  wire_niiOi_b	:	STD_LOGIC_VECTOR (16 DOWNTO 0);
	 SIGNAL  wire_niiOi_o	:	STD_LOGIC_VECTOR (16 DOWNTO 0);
	 SIGNAL  wire_nl0i_a	:	STD_LOGIC_VECTOR (17 DOWNTO 0);
	 SIGNAL  wire_nl0i_b	:	STD_LOGIC_VECTOR (17 DOWNTO 0);
	 SIGNAL  wire_nl0i_o	:	STD_LOGIC_VECTOR (17 DOWNTO 0);
	 SIGNAL  wire_nl0i_w_o_range218w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1il_a	:	STD_LOGIC_VECTOR (16 DOWNTO 0);
	 SIGNAL  wire_nl1il_b	:	STD_LOGIC_VECTOR (16 DOWNTO 0);
	 SIGNAL  wire_nl1il_o	:	STD_LOGIC_VECTOR (16 DOWNTO 0);
	 SIGNAL  wire_nl1l_a	:	STD_LOGIC_VECTOR (16 DOWNTO 0);
	 SIGNAL  wire_nl1l_b	:	STD_LOGIC_VECTOR (16 DOWNTO 0);
	 SIGNAL  wire_nl1l_o	:	STD_LOGIC_VECTOR (16 DOWNTO 0);
	 SIGNAL  wire_nli0l_a	:	STD_LOGIC_VECTOR (12 DOWNTO 0);
	 SIGNAL  wire_nli0l_b	:	STD_LOGIC_VECTOR (12 DOWNTO 0);
	 SIGNAL  wire_nli0l_o	:	STD_LOGIC_VECTOR (12 DOWNTO 0);
	 SIGNAL  wire_nli0l_w_o_range430w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n000l_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n000l_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_vcc	:	STD_LOGIC;
	 SIGNAL  wire_n000l_o	:	STD_LOGIC;
	 SIGNAL  wire_n001l_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n001l_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n001l_o	:	STD_LOGIC;
	 SIGNAL  wire_n010l_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n010l_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n010l_o	:	STD_LOGIC;
	 SIGNAL  wire_n011i_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n011i_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n011i_o	:	STD_LOGIC;
	 SIGNAL  wire_n01iO_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n01iO_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n01iO_o	:	STD_LOGIC;
	 SIGNAL  wire_n01Oi_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n01Oi_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n01Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_n1liO_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n1liO_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n1liO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1lOl_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n1lOl_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n1lOl_o	:	STD_LOGIC;
	 SIGNAL  wire_n1O1O_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n1O1O_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n1O1O_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oil_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n1Oil_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n1Oil_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OlO_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n1OlO_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n1OlO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0l_a	:	STD_LOGIC_VECTOR (16 DOWNTO 0);
	 SIGNAL  wire_nl0l_b	:	STD_LOGIC_VECTOR (16 DOWNTO 0);
	 SIGNAL  wire_nl0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O_a	:	STD_LOGIC_VECTOR (17 DOWNTO 0);
	 SIGNAL  wire_nl1O_b	:	STD_LOGIC_VECTOR (17 DOWNTO 0);
	 SIGNAL  wire_nl1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1Ol_a	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1Ol_b	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1OO_a	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1OO_b	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nli0i_a	:	STD_LOGIC_VECTOR (16 DOWNTO 0);
	 SIGNAL  wire_nli0i_b	:	STD_LOGIC_VECTOR (16 DOWNTO 0);
	 SIGNAL  wire_nli0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nli1l_a	:	STD_LOGIC_VECTOR (16 DOWNTO 0);
	 SIGNAL  wire_nli1l_b	:	STD_LOGIC_VECTOR (16 DOWNTO 0);
	 SIGNAL  wire_nli1l_o	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_lg_nlO0li105w691w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlO0li105w617w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_ppmsel_range1162w1184w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlO0li105w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlO0OO20w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOiii721w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rppm_post_eidle_del136w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_ppmsel_range1164w1165w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  nlllii :	STD_LOGIC;
	 SIGNAL  nlllil :	STD_LOGIC;
	 SIGNAL  nllliO :	STD_LOGIC;
	 SIGNAL  nlllli :	STD_LOGIC;
	 SIGNAL  nlllll :	STD_LOGIC;
	 SIGNAL  nllllO :	STD_LOGIC;
	 SIGNAL  nlllOi :	STD_LOGIC;
	 SIGNAL  nlllOl :	STD_LOGIC;
	 SIGNAL  nlllOO :	STD_LOGIC;
	 SIGNAL  nllO0i :	STD_LOGIC;
	 SIGNAL  nllO0l :	STD_LOGIC;
	 SIGNAL  nllO0O :	STD_LOGIC;
	 SIGNAL  nllO1i :	STD_LOGIC;
	 SIGNAL  nllO1l :	STD_LOGIC;
	 SIGNAL  nllO1O :	STD_LOGIC;
	 SIGNAL  nllOii :	STD_LOGIC;
	 SIGNAL  nllOil :	STD_LOGIC;
	 SIGNAL  nllOiO :	STD_LOGIC;
	 SIGNAL  nllOli :	STD_LOGIC;
	 SIGNAL  nllOll :	STD_LOGIC;
	 SIGNAL  nllOlO :	STD_LOGIC;
	 SIGNAL  nllOOl :	STD_LOGIC;
	 SIGNAL  nllOOO :	STD_LOGIC;
	 SIGNAL  nlO0il :	STD_LOGIC;
	 SIGNAL  nlO0li :	STD_LOGIC;
	 SIGNAL  nlO0OO :	STD_LOGIC;
	 SIGNAL  nlO1iO :	STD_LOGIC;
	 SIGNAL  nlOi0i :	STD_LOGIC;
	 SIGNAL  nlOi1i :	STD_LOGIC;
	 SIGNAL  nlOi1O :	STD_LOGIC;
	 SIGNAL  nlOiii :	STD_LOGIC;
	 SIGNAL  wire_w_ppmsel_range1162w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_ppmsel_range1164w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_gnd <= '0';
	wire_vcc <= '1';
	wire_w_lg_w_lg_nlO0li105w691w(0) <= wire_w_lg_nlO0li105w(0) AND ni01O;
	wire_w_lg_w_lg_nlO0li105w617w(0) <= wire_w_lg_nlO0li105w(0) AND nilOl;
	wire_w_lg_w_ppmsel_range1162w1184w(0) <= wire_w_ppmsel_range1162w(0) AND wire_w_lg_w_ppmsel_range1164w1165w(0);
	wire_w_lg_nlO0li105w(0) <= NOT nlO0li;
	wire_w_lg_nlO0OO20w(0) <= NOT nlO0OO;
	wire_w_lg_nlOiii721w(0) <= NOT nlOiii;
	wire_w_lg_rppm_post_eidle_del136w(0) <= NOT rppm_post_eidle_del;
	wire_w_lg_w_ppmsel_range1164w1165w(0) <= NOT wire_w_ppmsel_range1164w(0);
	freq_lock <= wire_n11Oi_dataout;
	nlllii <= (nlOi0i AND nlllil);
	nlllil <= (((((ppmsel(0) AND ppmsel(1)) AND ppmsel(2)) AND ppmsel(3)) AND ppmsel(4)) AND ppmsel(5));
	nllliO <= (nlOi0i AND nlllli);
	nlllli <= (((((ppmsel(0) AND ppmsel(1)) AND (NOT ppmsel(2))) AND (NOT ppmsel(3))) AND (NOT ppmsel(4))) AND (NOT ppmsel(5)));
	nlllll <= (nlOi0i AND nllllO);
	nllllO <= ((((wire_w_lg_w_ppmsel_range1162w1184w(0) AND (NOT ppmsel(2))) AND (NOT ppmsel(3))) AND (NOT ppmsel(4))) AND (NOT ppmsel(5)));
	nlllOi <= (nlOi0i AND nlllOl);
	nlllOl <= ((((((NOT ppmsel(0)) AND ppmsel(1)) AND (NOT ppmsel(2))) AND (NOT ppmsel(3))) AND (NOT ppmsel(4))) AND (NOT ppmsel(5)));
	nlllOO <= (nlOi0i AND nllO1i);
	nllO0i <= (nlOi0i AND nllO0l);
	nllO0l <= ((((((NOT ppmsel(0)) AND wire_w_lg_w_ppmsel_range1164w1165w(0)) AND (NOT ppmsel(2))) AND ppmsel(3)) AND (NOT ppmsel(4))) AND (NOT ppmsel(5)));
	nllO0O <= (nlOi0i AND nllOii);
	nllO1i <= ((((((NOT ppmsel(0)) AND wire_w_lg_w_ppmsel_range1164w1165w(0)) AND ppmsel(2)) AND (NOT ppmsel(3))) AND (NOT ppmsel(4))) AND (NOT ppmsel(5)));
	nllO1l <= (nlOi0i AND nllO1O);
	nllO1O <= ((((wire_w_lg_w_ppmsel_range1162w1184w(0) AND (NOT ppmsel(2))) AND ppmsel(3)) AND (NOT ppmsel(4))) AND (NOT ppmsel(5)));
	nllOii <= ((((((NOT ppmsel(0)) AND wire_w_lg_w_ppmsel_range1164w1165w(0)) AND (NOT ppmsel(2))) AND (NOT ppmsel(3))) AND ppmsel(4)) AND (NOT ppmsel(5)));
	nllOil <= (nlOi0i AND nllOiO);
	nllOiO <= ((((((NOT ppmsel(0)) AND wire_w_lg_w_ppmsel_range1164w1165w(0)) AND (NOT ppmsel(2))) AND (NOT ppmsel(3))) AND (NOT ppmsel(4))) AND ppmsel(5));
	nllOli <= (((((((n00Oi AND n00lO) AND n00ll) AND n00li) AND n00iO) AND n00il) AND n00ii) AND n1iOi);
	nllOll <= (wire_nl0OO_w_lg_nl1li697w(0) AND n00Ol);
	nllOlO <= (nllOOl OR nl1li);
	nllOOl <= (nli1i AND nl0ii);
	nllOOO <= ((((((((((((((((wire_nl0Oi_w_lg_ni00i1130w(0) AND wire_nl0Oi_w_lg_ni01O1131w(0)) AND wire_nl0Oi_w_lg_ni01l1133w(0)) AND wire_nl0Oi_w_lg_ni01i1135w(0)) AND wire_nl0Oi_w_lg_ni1OO1137w(0)) AND wire_nl0Oi_w_lg_ni1Ol1139w(0)) AND wire_nl0Oi_w_lg_ni1Oi1141w(0)) AND wire_nl0Oi_w_lg_ni1lO1143w(0)) AND wire_nl0Oi_w_lg_ni1ll1145w(0)) AND ni1li) AND ni1iO) AND ni1il) AND ni1ii) AND ni10O) AND ni10l) AND ni10i) AND ni11O);
	nlO0il <= (nlii AND wire_nlOl_w_lg_nlO0l31w(0));
	nlO0li <= ((nlO0OO AND rppm_gen1_2xcnt_en) AND (nlO0ll12 XOR nlO0ll11));
	nlO0OO <= (wire_n0i_w_lg_dataout18w(0) AND rauto_speed_ena);
	nlO1iO <= ((((((((wire_nlOl_w_lg_w_lg_w_lg_w_lg_w1102w1104w1106w1108w1109w(0) AND wire_nlOl_w_lg_nllil1110w(0)) AND wire_nlOl_w_lg_nll0l1112w(0)) AND wire_nlOl_w_lg_nll0i1114w(0)) AND wire_nlOl_w_lg_nll1O1116w(0)) AND (NOT (nll0O XOR wire_w_lg_rppm_post_eidle_del136w(0)))) AND (NOT (nllii XOR rppm_post_eidle_del))) AND (NOT (nlliO XOR wire_w_lg_rppm_post_eidle_del136w(0)))) AND (NOT (nllll XOR rppm_post_eidle_del)));
	nlOi0i <= (((wire_ni00l_w_lg_w_lg_n0lOi8w9w(0) AND wire_nl0OO_w_lg_n0lll10w(0)) AND (nlOi0l4 XOR nlOi0l3)) AND wire_nl0OO_w_lg_n0lli15w(0));
	nlOi1i <= '1';
	nlOi1O <= '0';
	nlOiii <= (wire_ni00l_w_lg_w_lg_w_lg_n0lOi1w2w3w(0) OR (NOT (nlOiil2 XOR nlOiil1)));
	ppm_cnt_latch <= ( n10il & n10ii & n100O & n100l & n100i & n101O & n101l & n1iOO);
	wire_w_ppmsel_range1162w(0) <= ppmsel(0);
	wire_w_ppmsel_range1164w(0) <= ppmsel(1);
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlll0O57 <= nlll0O58;
		END IF;
		if (now = 0 ns) then
			nlll0O57 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlll0O58 <= nlll0O57;
		END IF;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nllOOi55 <= nllOOi56;
		END IF;
		if (now = 0 ns) then
			nllOOi55 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nllOOi56 <= nllOOi55;
		END IF;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO00i21 <= nlO00i22;
		END IF;
		if (now = 0 ns) then
			nlO00i21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO00i22 <= nlO00i21;
		END IF;
	END PROCESS;
	wire_nlO00i22_w_lg_w_lg_q87w88w(0) <= wire_nlO00i22_w_lg_q87w(0) AND nllOO;
	wire_nlO00i22_w_lg_q87w(0) <= nlO00i22 XOR nlO00i21;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO00l19 <= nlO00l20;
		END IF;
		if (now = 0 ns) then
			nlO00l19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO00l20 <= nlO00l19;
		END IF;
	END PROCESS;
	wire_nlO00l20_w_lg_w_lg_q84w85w(0) <= wire_nlO00l20_w_lg_q84w(0) AND nllOl;
	wire_nlO00l20_w_lg_q84w(0) <= nlO00l20 XOR nlO00l19;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO00O17 <= nlO00O18;
		END IF;
		if (now = 0 ns) then
			nlO00O17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO00O18 <= nlO00O17;
		END IF;
	END PROCESS;
	wire_nlO00O18_w_lg_w_lg_q78w79w(0) <= wire_nlO00O18_w_lg_q78w(0) AND nllli;
	wire_nlO00O18_w_lg_q78w(0) <= nlO00O18 XOR nlO00O17;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO01i27 <= nlO01i28;
		END IF;
		if (now = 0 ns) then
			nlO01i27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO01i28 <= nlO01i27;
		END IF;
	END PROCESS;
	wire_nlO01i28_w_lg_w_lg_q168w169w(0) <= wire_nlO01i28_w_lg_q168w(0) AND nll0l;
	wire_nlO01i28_w_lg_q168w(0) <= nlO01i28 XOR nlO01i27;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO01l25 <= nlO01l26;
		END IF;
		if (now = 0 ns) then
			nlO01l25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO01l26 <= nlO01l25;
		END IF;
	END PROCESS;
	wire_nlO01l26_w_lg_w_lg_q165w166w(0) <= wire_nlO01l26_w_lg_q165w(0) AND nll0i;
	wire_nlO01l26_w_lg_q165w(0) <= nlO01l26 XOR nlO01l25;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO01O23 <= nlO01O24;
		END IF;
		if (now = 0 ns) then
			nlO01O23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO01O24 <= nlO01O23;
		END IF;
	END PROCESS;
	wire_nlO01O24_w_lg_w_lg_q108w109w(0) <= wire_nlO01O24_w_lg_q108w(0) AND nlO0li;
	wire_nlO01O24_w_lg_q108w(0) <= nlO01O24 XOR nlO01O23;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO0ii15 <= nlO0ii16;
		END IF;
		if (now = 0 ns) then
			nlO0ii15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO0ii16 <= nlO0ii15;
		END IF;
	END PROCESS;
	wire_nlO0ii16_w_lg_w_lg_q72w73w(0) <= wire_nlO0ii16_w_lg_q72w(0) AND nll0O;
	wire_nlO0ii16_w_lg_q72w(0) <= nlO0ii16 XOR nlO0ii15;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO0iO13 <= nlO0iO14;
		END IF;
		if (now = 0 ns) then
			nlO0iO13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO0iO14 <= nlO0iO13;
		END IF;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO0ll11 <= nlO0ll12;
		END IF;
		if (now = 0 ns) then
			nlO0ll11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO0ll12 <= nlO0ll11;
		END IF;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO0Oi10 <= nlO0Oi9;
		END IF;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO0Oi9 <= nlO0Oi10;
		END IF;
		if (now = 0 ns) then
			nlO0Oi9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO0Ol7 <= nlO0Ol8;
		END IF;
		if (now = 0 ns) then
			nlO0Ol7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO0Ol8 <= nlO0Ol7;
		END IF;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO10i47 <= nlO10i48;
		END IF;
		if (now = 0 ns) then
			nlO10i47 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO10i48 <= nlO10i47;
		END IF;
	END PROCESS;
	wire_nlO10i48_w_lg_w_lg_q355w356w(0) <= wire_nlO10i48_w_lg_q355w(0) AND wire_w_lg_nlO0li105w(0);
	wire_nlO10i48_w_lg_q355w(0) <= nlO10i48 XOR nlO10i47;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO10l45 <= nlO10l46;
		END IF;
		if (now = 0 ns) then
			nlO10l45 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO10l46 <= nlO10l45;
		END IF;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO10O43 <= nlO10O44;
		END IF;
		if (now = 0 ns) then
			nlO10O43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO10O44 <= nlO10O43;
		END IF;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO11i53 <= nlO11i54;
		END IF;
		if (now = 0 ns) then
			nlO11i53 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO11i54 <= nlO11i53;
		END IF;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO11l51 <= nlO11l52;
		END IF;
		if (now = 0 ns) then
			nlO11l51 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO11l52 <= nlO11l51;
		END IF;
	END PROCESS;
	wire_nlO11l52_w_lg_w_lg_q434w435w(0) <= wire_nlO11l52_w_lg_q434w(0) AND niiOl;
	wire_nlO11l52_w_lg_q434w(0) <= nlO11l52 XOR nlO11l51;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO11O49 <= nlO11O50;
		END IF;
		if (now = 0 ns) then
			nlO11O49 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO11O50 <= nlO11O49;
		END IF;
	END PROCESS;
	wire_nlO11O50_w_lg_w_lg_q431w432w(0) <= wire_nlO11O50_w_lg_q431w(0) AND wire_nli0l_w_o_range430w(0);
	wire_nlO11O50_w_lg_q431w(0) <= nlO11O50 XOR nlO11O49;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO1ii41 <= nlO1ii42;
		END IF;
		if (now = 0 ns) then
			nlO1ii41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO1ii42 <= nlO1ii41;
		END IF;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO1li39 <= nlO1li40;
		END IF;
		if (now = 0 ns) then
			nlO1li39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO1li40 <= nlO1li39;
		END IF;
	END PROCESS;
	wire_nlO1li40_w_lg_w_lg_q266w267w(0) <= wire_nlO1li40_w_lg_q266w(0) AND nlO0i;
	wire_nlO1li40_w_lg_q266w(0) <= nlO1li40 XOR nlO1li39;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO1ll37 <= nlO1ll38;
		END IF;
		if (now = 0 ns) then
			nlO1ll37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO1ll38 <= nlO1ll37;
		END IF;
	END PROCESS;
	wire_nlO1ll38_w_lg_w_lg_q261w262w(0) <= wire_nlO1ll38_w_lg_q261w(0) AND nlO1i;
	wire_nlO1ll38_w_lg_q261w(0) <= nlO1ll38 XOR nlO1ll37;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO1lO35 <= nlO1lO36;
		END IF;
		if (now = 0 ns) then
			nlO1lO35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO1lO36 <= nlO1lO35;
		END IF;
	END PROCESS;
	wire_nlO1lO36_w_lg_w_lg_q255w256w(0) <= wire_nlO1lO36_w_lg_q255w(0) AND nlllO;
	wire_nlO1lO36_w_lg_q255w(0) <= nlO1lO36 XOR nlO1lO35;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO1Oi33 <= nlO1Oi34;
		END IF;
		if (now = 0 ns) then
			nlO1Oi33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO1Oi34 <= nlO1Oi33;
		END IF;
	END PROCESS;
	wire_nlO1Oi34_w_lg_w_lg_q219w220w(0) <= wire_nlO1Oi34_w_lg_q219w(0) AND wire_nl0i_w_o_range218w(0);
	wire_nlO1Oi34_w_lg_q219w(0) <= nlO1Oi34 XOR nlO1Oi33;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO1Ol31 <= nlO1Ol32;
		END IF;
		if (now = 0 ns) then
			nlO1Ol31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO1Ol32 <= nlO1Ol31;
		END IF;
	END PROCESS;
	wire_nlO1Ol32_w_lg_w_lg_q182w183w(0) <= wire_nlO1Ol32_w_lg_q182w(0) AND nllOO;
	wire_nlO1Ol32_w_lg_q182w(0) <= nlO1Ol32 XOR nlO1Ol31;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO1OO29 <= nlO1OO30;
		END IF;
		if (now = 0 ns) then
			nlO1OO29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlO1OO30 <= nlO1OO29;
		END IF;
	END PROCESS;
	wire_nlO1OO30_w_lg_w_lg_q177w178w(0) <= wire_nlO1OO30_w_lg_q177w(0) AND nlllO;
	wire_nlO1OO30_w_lg_q177w(0) <= nlO1OO30 XOR nlO1OO29;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlOi0l3 <= nlOi0l4;
		END IF;
		if (now = 0 ns) then
			nlOi0l3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlOi0l4 <= nlOi0l3;
		END IF;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlOi1l5 <= nlOi1l6;
		END IF;
		if (now = 0 ns) then
			nlOi1l5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlOi1l6 <= nlOi1l5;
		END IF;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlOiil1 <= nlOiil2;
		END IF;
		if (now = 0 ns) then
			nlOiil1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref)
	BEGIN
		IF (fref = '1' AND fref'event) THEN nlOiil2 <= nlOiil1;
		END IF;
	END PROCESS;
	PROCESS (fvcobyn, wire_nli0O_dataout)
	BEGIN
		IF (wire_nli0O_dataout = '1') THEN
				n0lOO <= '1';
		ELSIF (fvcobyn = '1' AND fvcobyn'event) THEN
				n0lOO <= wire_ni0ii_dataout;
		END IF;
		if (now = 0 ns) then
			n0lOO <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (fref, hard_reset, wire_n0O_CLRN)
	BEGIN
		IF (hard_reset = '0') THEN
				n1i <= '1';
				nii <= '1';
		ELSIF (wire_n0O_CLRN = '0') THEN
				n1i <= '0';
				nii <= '0';
		ELSIF (fref = '1' AND fref'event) THEN
				n1i <= nii;
				nii <= nlOi1O;
		END IF;
		if (now = 0 ns) then
			n1i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nii <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_n0O_CLRN <= (nlOi1l6 XOR nlOi1l5);
	PROCESS (fref, wire_n1ill_CLRN)
	BEGIN
		IF (wire_n1ill_CLRN = '0') THEN
				n10iO <= '0';
				n1ilO <= '0';
		ELSIF (fref = '1' AND fref'event) THEN
			IF (nlOi0i = '1') THEN
				n10iO <= (nlllii OR ((((((((nllOil AND wire_n1O1O_o) OR (wire_n000l_o AND nllO0O)) OR (nllO0i AND wire_n1lOl_o)) OR (wire_n001l_o AND nllO1l)) OR (nlllOO AND wire_n1liO_o)) OR (wire_n01iO_o AND nlllOi)) OR (wire_n010l_o AND nlllll)) OR (wire_n011i_o AND nllliO)));
				n1ilO <= (((((((((nllOil AND wire_n000l_o) OR (nllO0O AND wire_n001l_o)) OR (nllO0i AND wire_n01Oi_o)) OR (nllO1l AND wire_n01iO_o)) OR (nlllOO AND wire_n010l_o)) OR (nlllOi AND wire_n011i_o)) OR (nlllll AND wire_n1OlO_o)) OR (nllliO AND wire_n1Oil_o)) OR nlllii);
			END IF;
		END IF;
	END PROCESS;
	wire_n1ill_CLRN <= ((nlll0O58 XOR nlll0O57) AND wire_nlili_w_lg_dataout507w(0));
	PROCESS (fref, wire_nlili_dataout, wire_ni00l_CLRN)
	BEGIN
		IF (wire_nlili_dataout = '1') THEN
				n0lOi <= '1';
				ni00O <= '1';
		ELSIF (wire_ni00l_CLRN = '0') THEN
				n0lOi <= '0';
				ni00O <= '0';
		ELSIF (fref = '1' AND fref'event) THEN
				n0lOi <= wire_n0O0l_dataout;
				ni00O <= wire_niO1l_dataout;
		END IF;
		if (now = 0 ns) then
			n0lOi <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni00O <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_ni00l_CLRN <= (nllOOi56 XOR nllOOi55);
	wire_ni00l_w_lg_w_lg_n0lOi8w9w(0) <= wire_ni00l_w_lg_n0lOi8w(0) AND n0llO;
	wire_ni00l_w_lg_n0lOi512w(0) <= n0lOi AND wire_nl0OO_w_lg_n0llO511w(0);
	wire_ni00l_w_lg_n0lOi8w(0) <= NOT n0lOi;
	wire_ni00l_w_lg_w_lg_w_lg_n0lOi1w2w3w(0) <= wire_ni00l_w_lg_w_lg_n0lOi1w2w(0) OR n0lli;
	wire_ni00l_w_lg_w_lg_n0lOi1w2w(0) <= wire_ni00l_w_lg_n0lOi1w(0) OR n0lll;
	wire_ni00l_w_lg_n0lOi1w(0) <= n0lOi OR n0llO;
	PROCESS (fvcobyn, wire_nli0O_dataout)
	BEGIN
		IF (wire_nli0O_dataout = '1') THEN
				nl0lO <= '0';
		ELSIF (fvcobyn = '1' AND fvcobyn'event) THEN
			IF (nllOOO = '1') THEN
				nl0lO <= nlOi1i;
			END IF;
		END IF;
	END PROCESS;
	PROCESS (fvcobyn, wire_nli0O_dataout)
	BEGIN
		IF (wire_nli0O_dataout = '1') THEN
				ni00i <= '0';
				ni01i <= '0';
				ni01l <= '0';
				ni01O <= '0';
				ni10i <= '0';
				ni10l <= '0';
				ni10O <= '0';
				ni11O <= '0';
				ni1ii <= '0';
				ni1il <= '0';
				ni1iO <= '0';
				ni1li <= '0';
				ni1ll <= '0';
				ni1lO <= '0';
				ni1Oi <= '0';
				ni1Ol <= '0';
				ni1OO <= '0';
				nl00O <= '0';
				nl01l <= '0';
				nl0Ol <= '0';
		ELSIF (fvcobyn = '1' AND fvcobyn'event) THEN
				ni00i <= wire_niiiO_dataout;
				ni01i <= wire_nii0O_dataout;
				ni01l <= wire_niiii_dataout;
				ni01O <= wire_niiil_dataout;
				ni10i <= wire_ni0iO_dataout;
				ni10l <= wire_ni0li_dataout;
				ni10O <= wire_ni0ll_dataout;
				ni11O <= wire_ni0il_dataout;
				ni1ii <= wire_ni0lO_dataout;
				ni1il <= wire_ni0Oi_dataout;
				ni1iO <= wire_ni0Ol_dataout;
				ni1li <= wire_ni0OO_dataout;
				ni1ll <= wire_nii1i_dataout;
				ni1lO <= wire_nii1l_dataout;
				ni1Oi <= wire_nii1O_dataout;
				ni1Ol <= wire_nii0i_dataout;
				ni1OO <= wire_nii0l_dataout;
				nl00O <= nl1iO;
				nl01l <= nl00O;
				nl0Ol <= wire_nli1l_o;
		END IF;
	END PROCESS;
	wire_nl0Oi_w_lg_ni00i1130w(0) <= NOT ni00i;
	wire_nl0Oi_w_lg_ni01i1135w(0) <= NOT ni01i;
	wire_nl0Oi_w_lg_ni01l1133w(0) <= NOT ni01l;
	wire_nl0Oi_w_lg_ni01O1131w(0) <= NOT ni01O;
	wire_nl0Oi_w_lg_ni1ll1145w(0) <= NOT ni1ll;
	wire_nl0Oi_w_lg_ni1lO1143w(0) <= NOT ni1lO;
	wire_nl0Oi_w_lg_ni1Oi1141w(0) <= NOT ni1Oi;
	wire_nl0Oi_w_lg_ni1Ol1139w(0) <= NOT ni1Ol;
	wire_nl0Oi_w_lg_ni1OO1137w(0) <= NOT ni1OO;
	PROCESS (fref, wire_nl0OO_CLRN)
	BEGIN
		IF (wire_nl0OO_CLRN = '0') THEN
				n00ii <= '0';
				n00il <= '0';
				n00iO <= '0';
				n00li <= '0';
				n00ll <= '0';
				n00lO <= '0';
				n00Oi <= '0';
				n00Ol <= '0';
				n0lli <= '0';
				n0lll <= '0';
				n0llO <= '0';
				n100i <= '0';
				n100l <= '0';
				n100O <= '0';
				n101l <= '0';
				n101O <= '0';
				n10ii <= '0';
				n10il <= '0';
				n1iOi <= '0';
				n1iOO <= '0';
				niiOl <= '0';
				niiOO <= '0';
				nil0i <= '0';
				nil0l <= '0';
				nil0O <= '0';
				nil1i <= '0';
				nil1l <= '0';
				nil1O <= '0';
				nilii <= '0';
				nilil <= '0';
				niliO <= '0';
				nilli <= '0';
				nilll <= '0';
				nillO <= '0';
				nilOi <= '0';
				nilOl <= '0';
				nilOO <= '0';
				niO1i <= '0';
				nl01i <= '0';
				nl0ii <= '0';
				nl0il <= '0';
				nl0iO <= '0';
				nl0li <= '0';
				nl1iO <= '0';
				nl1li <= '0';
				nli1i <= '0';
		ELSIF (fref = '1' AND fref'event) THEN
				n00ii <= wire_n0i1i_dataout;
				n00il <= wire_n0i1l_dataout;
				n00iO <= wire_n0i1O_dataout;
				n00li <= wire_n0i0i_dataout;
				n00ll <= wire_n0i0l_dataout;
				n00lO <= wire_n0i0O_dataout;
				n00Oi <= wire_n0iii_dataout;
				n00Ol <= wire_n0O1i_dataout;
				n0lli <= wire_n0O1l_dataout;
				n0lll <= wire_n0O1O_dataout;
				n0llO <= wire_n0O0i_dataout;
				n100i <= wire_n10Oi_dataout;
				n100l <= wire_n10Ol_dataout;
				n100O <= wire_n10OO_dataout;
				n101l <= wire_n10ll_dataout;
				n101O <= wire_n10lO_dataout;
				n10ii <= wire_n1i1i_dataout;
				n10il <= wire_n1i1l_dataout;
				n1iOi <= wire_n00OO_dataout;
				n1iOO <= wire_n10li_dataout;
				niiOl <= wire_niO1O_dataout;
				niiOO <= wire_niO0i_dataout;
				nil0i <= wire_niOil_dataout;
				nil0l <= wire_niOiO_dataout;
				nil0O <= wire_niOli_dataout;
				nil1i <= wire_niO0l_dataout;
				nil1l <= wire_niO0O_dataout;
				nil1O <= wire_niOii_dataout;
				nilii <= wire_niOll_dataout;
				nilil <= wire_niOlO_dataout;
				niliO <= wire_niOOi_dataout;
				nilli <= wire_niOOl_dataout;
				nilll <= wire_niOOO_dataout;
				nillO <= wire_nl11i_dataout;
				nilOi <= wire_nl11l_dataout;
				nilOl <= wire_nl11O_dataout;
				nilOO <= wire_nl10i_dataout;
				niO1i <= nl1iO;
				nl01i <= wire_nl00i_dataout;
				nl0ii <= nl0il;
				nl0il <= nl0Ol;
				nl0iO <= nl0li;
				nl0li <= nl0lO;
				nl1iO <= ((wire_nl1OO_o AND wire_nl1Ol_o) OR nllOOl);
				nl1li <= wire_nl01O_dataout;
				nli1i <= wire_nli0i_o;
		END IF;
	END PROCESS;
	wire_nl0OO_CLRN <= ((nlO11i54 XOR nlO11i53) AND wire_nlili_w_lg_dataout507w(0));
	wire_nl0OO_w_lg_n0lli15w(0) <= NOT n0lli;
	wire_nl0OO_w_lg_n0lll10w(0) <= NOT n0lll;
	wire_nl0OO_w_lg_n0llO511w(0) <= NOT n0llO;
	wire_nl0OO_w_lg_nl0iO515w(0) <= NOT nl0iO;
	wire_nl0OO_w_lg_nl1li697w(0) <= NOT nl1li;
	PROCESS (fvcobyn, wire_nliii_PRN)
	BEGIN
		IF (wire_nliii_PRN = '0') THEN
				nli1O <= '1';
				nliil <= '1';
		ELSIF (fvcobyn = '1' AND fvcobyn'event) THEN
				nli1O <= nliil;
				nliil <= pd;
		END IF;
		if (now = 0 ns) then
			nli1O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nliil <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nliii_PRN <= ((nlO10l46 XOR nlO10l45) AND wire_nliOl_w_lg_dataout328w(0));
	PROCESS (fref, wire_nlill_PRN)
	BEGIN
		IF (wire_nlill_PRN = '0') THEN
				nliiO <= '1';
				nlilO <= '1';
		ELSIF (fref = '1' AND fref'event) THEN
				nliiO <= nlilO;
				nlilO <= pd;
		END IF;
		if (now = 0 ns) then
			nliiO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlilO <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nlill_PRN <= ((nlO10O44 XOR nlO10O43) AND wire_nliOl_w_lg_dataout328w(0));
	PROCESS (fref, wire_n0l_dataout, wire_nliO_CLRN)
	BEGIN
		IF (wire_n0l_dataout = '1') THEN
				nlli <= '1';
		ELSIF (wire_nliO_CLRN = '0') THEN
				nlli <= '0';
		ELSIF (fref = '1' AND fref'event) THEN
				nlli <= (nlOi XOR nllO);
		END IF;
		if (now = 0 ns) then
			nlli <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nliO_CLRN <= (nlO0iO14 XOR nlO0iO13);
	PROCESS (fref, wire_nlOl_PRN, wire_nlOl_CLRN)
	BEGIN
		IF (wire_nlOl_PRN = '0') THEN
				nlii <= '1';
				nlil <= '1';
				nliOi <= '1';
				nll0i <= '1';
				nll0l <= '1';
				nll0O <= '1';
				nll1l <= '1';
				nll1O <= '1';
				nllii <= '1';
				nllil <= '1';
				nlliO <= '1';
				nllli <= '1';
				nllll <= '1';
				nlllO <= '1';
				nllO <= '1';
				nllOi <= '1';
				nllOl <= '1';
				nllOO <= '1';
				nlO0i <= '1';
				nlO0l <= '1';
				nlO1i <= '1';
				nlO1l <= '1';
				nlO1O <= '1';
				nlOi <= '1';
				nlOO <= '1';
		ELSIF (wire_nlOl_CLRN = '0') THEN
				nlii <= '0';
				nlil <= '0';
				nliOi <= '0';
				nll0i <= '0';
				nll0l <= '0';
				nll0O <= '0';
				nll1l <= '0';
				nll1O <= '0';
				nllii <= '0';
				nllil <= '0';
				nlliO <= '0';
				nllli <= '0';
				nllll <= '0';
				nlllO <= '0';
				nllO <= '0';
				nllOi <= '0';
				nllOl <= '0';
				nllOO <= '0';
				nlO0i <= '0';
				nlO0l <= '0';
				nlO1i <= '0';
				nlO1l <= '0';
				nlO1O <= '0';
				nlOi <= '0';
				nlOO <= '0';
		ELSIF (fref = '1' AND fref'event) THEN
				nlii <= nlil;
				nlil <= eidle_exit;
				nliOi <= wire_nlO0O_dataout;
				nll0i <= wire_nlOiO_dataout;
				nll0l <= wire_nlOli_dataout;
				nll0O <= wire_nlOll_dataout;
				nll1l <= wire_nlOii_dataout;
				nll1O <= wire_nlOil_dataout;
				nllii <= wire_nlOlO_dataout;
				nllil <= wire_nlOOi_dataout;
				nlliO <= wire_nlOOl_dataout;
				nllli <= wire_nlOOO_dataout;
				nllll <= wire_n11i_dataout;
				nlllO <= wire_n11l_dataout;
				nllO <= nlOi;
				nllOi <= wire_n11O_dataout;
				nllOl <= wire_n10i_dataout;
				nllOO <= wire_n10l_dataout;
				nlO0i <= wire_n1iO_dataout;
				nlO0l <= nlii;
				nlO1i <= wire_n10O_dataout;
				nlO1l <= wire_n1ii_dataout;
				nlO1O <= wire_n1il_dataout;
				nlOi <= nlOO;
				nlOO <= wire_w_lg_nlO0OO20w(0);
		END IF;
	END PROCESS;
	wire_nlOl_CLRN <= ((nlO0Ol8 XOR nlO0Ol7) AND wire_n0l_w_lg_dataout22w(0));
	wire_nlOl_PRN <= (nlO0Oi10 XOR nlO0Oi9);
	wire_nlOl_w_lg_w_lg_w_lg_w_lg_w1102w1104w1106w1108w1109w(0) <= wire_nlOl_w_lg_w_lg_w_lg_w1102w1104w1106w1108w(0) AND nllli;
	wire_nlOl_w_lg_w_lg_w_lg_w1102w1104w1106w1108w(0) <= wire_nlOl_w_lg_w_lg_w1102w1104w1106w(0) AND wire_nlOl_w_lg_nlllO1107w(0);
	wire_nlOl_w_lg_w_lg_w1102w1104w1106w(0) <= wire_nlOl_w_lg_w1102w1104w(0) AND wire_nlOl_w_lg_nllOi1105w(0);
	wire_nlOl_w_lg_w1102w1104w(0) <= wire_nlOl_w1102w(0) AND wire_nlOl_w_lg_nllOl1103w(0);
	wire_nlOl_w1102w(0) <= wire_nlOl_w_lg_w_lg_w_lg_w_lg_nlO0i1094w1096w1098w1100w(0) AND wire_nlOl_w_lg_nllOO1101w(0);
	wire_nlOl_w_lg_w_lg_w_lg_w_lg_nlO0i1094w1096w1098w1100w(0) <= wire_nlOl_w_lg_w_lg_w_lg_nlO0i1094w1096w1098w(0) AND wire_nlOl_w_lg_nlO1i1099w(0);
	wire_nlOl_w_lg_w_lg_w_lg_nlO0i1094w1096w1098w(0) <= wire_nlOl_w_lg_w_lg_nlO0i1094w1096w(0) AND wire_nlOl_w_lg_nlO1l1097w(0);
	wire_nlOl_w_lg_w_lg_nlO0i1094w1096w(0) <= wire_nlOl_w_lg_nlO0i1094w(0) AND wire_nlOl_w_lg_nlO1O1095w(0);
	wire_nlOl_w_lg_nll0i1114w(0) <= NOT nll0i;
	wire_nlOl_w_lg_nll0l1112w(0) <= NOT nll0l;
	wire_nlOl_w_lg_nll1O1116w(0) <= NOT nll1O;
	wire_nlOl_w_lg_nllil1110w(0) <= NOT nllil;
	wire_nlOl_w_lg_nlllO1107w(0) <= NOT nlllO;
	wire_nlOl_w_lg_nllOi1105w(0) <= NOT nllOi;
	wire_nlOl_w_lg_nllOl1103w(0) <= NOT nllOl;
	wire_nlOl_w_lg_nllOO1101w(0) <= NOT nllOO;
	wire_nlOl_w_lg_nlO0i1094w(0) <= NOT nlO0i;
	wire_nlOl_w_lg_nlO0l31w(0) <= NOT nlO0l;
	wire_nlOl_w_lg_nlO1i1099w(0) <= NOT nlO1i;
	wire_nlOl_w_lg_nlO1l1097w(0) <= NOT nlO1l;
	wire_nlOl_w_lg_nlO1O1095w(0) <= NOT nlO1O;
	wire_n00i_dataout <= wire_niii_dataout AND wire_nl0l_o;
	wire_n00l_dataout <= wire_niil_dataout AND wire_nl0l_o;
	wire_n00O_dataout <= wire_niiO_dataout AND wire_nl0l_o;
	wire_n00OO_dataout <= wire_n0iil_dataout AND NOT(wire_w_lg_nlOiii721w(0));
	wire_n01i_dataout <= wire_ni0i_dataout AND wire_nl0l_o;
	wire_n01l_dataout <= wire_ni0l_dataout AND wire_nl0l_o;
	wire_n01O_dataout <= wire_ni0O_dataout AND wire_nl0l_o;
	wire_n0i_dataout <= gen2ngen1_indv WHEN rindv_rx = '1'  ELSE gen2ngen1_bundle;
	wire_n0i_w_lg_dataout18w(0) <= NOT wire_n0i_dataout;
	wire_n0i0i_dataout <= wire_n0ilO_dataout AND NOT(wire_w_lg_nlOiii721w(0));
	wire_n0i0l_dataout <= wire_n0iOi_dataout AND NOT(wire_w_lg_nlOiii721w(0));
	wire_n0i0O_dataout <= wire_n0iOl_dataout AND NOT(wire_w_lg_nlOiii721w(0));
	wire_n0i1i_dataout <= wire_n0iiO_dataout AND NOT(wire_w_lg_nlOiii721w(0));
	wire_n0i1l_dataout <= wire_n0ili_dataout AND NOT(wire_w_lg_nlOiii721w(0));
	wire_n0i1O_dataout <= wire_n0ill_dataout AND NOT(wire_w_lg_nlOiii721w(0));
	wire_n0ii_dataout <= wire_nili_dataout AND wire_nl0l_o;
	wire_n0iii_dataout <= wire_n0iOO_dataout AND NOT(wire_w_lg_nlOiii721w(0));
	wire_n0iil_dataout <= wire_n0l1i_dataout OR nllOli;
	wire_n0iiO_dataout <= wire_n0l1l_dataout OR nllOli;
	wire_n0il_dataout <= wire_nill_dataout AND wire_nl0l_o;
	wire_n0ili_dataout <= wire_n0l1O_dataout OR nllOli;
	wire_n0ill_dataout <= wire_n0l0i_dataout OR nllOli;
	wire_n0ilO_dataout <= wire_n0l0l_dataout OR nllOli;
	wire_n0iO_dataout <= wire_nilO_dataout AND wire_nl0l_o;
	wire_n0iOi_dataout <= wire_n0l0O_dataout OR nllOli;
	wire_n0iOl_dataout <= wire_n0lii_dataout OR nllOli;
	wire_n0iOO_dataout <= wire_n0lil_dataout OR nllOli;
	wire_n0l_dataout <= n1i AND NOT(scan_mode);
	wire_n0l_w_lg_dataout22w(0) <= NOT wire_n0l_dataout;
	wire_n0l0i_dataout <= wire_n0liO_o(3) WHEN nl1li = '1'  ELSE n00iO;
	wire_n0l0l_dataout <= wire_n0liO_o(4) WHEN nl1li = '1'  ELSE n00li;
	wire_n0l0O_dataout <= wire_n0liO_o(5) WHEN nl1li = '1'  ELSE n00ll;
	wire_n0l1i_dataout <= wire_n0liO_o(0) WHEN nl1li = '1'  ELSE n1iOi;
	wire_n0l1l_dataout <= wire_n0liO_o(1) WHEN nl1li = '1'  ELSE n00ii;
	wire_n0l1O_dataout <= wire_n0liO_o(2) WHEN nl1li = '1'  ELSE n00il;
	wire_n0li_dataout <= wire_niOi_dataout AND wire_nl0l_o;
	wire_n0lii_dataout <= wire_n0liO_o(6) WHEN nl1li = '1'  ELSE n00lO;
	wire_n0lil_dataout <= wire_n0liO_o(7) WHEN nl1li = '1'  ELSE n00Oi;
	wire_n0ll_dataout <= wire_niOl_dataout AND wire_nl0l_o;
	wire_n0lO_dataout <= wire_niOO_dataout AND wire_nl0l_o;
	wire_n0O0i_dataout <= wire_n0Oil_dataout AND NOT(wire_w_lg_nlOiii721w(0));
	wire_n0O0l_dataout <= wire_n0OiO_dataout OR wire_w_lg_nlOiii721w(0);
	wire_n0O0O_dataout <= n0lli WHEN nllOlO = '1'  ELSE wire_n0Oll_dataout;
	wire_n0O1i_dataout <= wire_n0Oli_dataout AND NOT(wire_w_lg_nlOiii721w(0));
	wire_n0O1l_dataout <= wire_n0O0O_dataout AND NOT(wire_w_lg_nlOiii721w(0));
	wire_n0O1O_dataout <= wire_n0Oii_dataout AND NOT(wire_w_lg_nlOiii721w(0));
	wire_n0Oi_dataout <= wire_nl1i_dataout AND wire_nl0l_o;
	wire_n0Oii_dataout <= n0lll WHEN nllOlO = '1'  ELSE wire_n0OlO_dataout;
	wire_n0Oil_dataout <= n0llO WHEN nllOlO = '1'  ELSE wire_n0OOi_dataout;
	wire_n0OiO_dataout <= n0lOi WHEN nllOlO = '1'  ELSE wire_n0OOl_dataout;
	wire_n0Ol_dataout <= nlO1iO AND wire_nl1O_o;
	wire_n0Oli_dataout <= n00Ol OR nllOlO;
	wire_n0Oll_dataout <= wire_n0OOO_o(1) WHEN nllOll = '1'  ELSE n0lli;
	wire_n0OlO_dataout <= wire_n0OOO_o(2) WHEN nllOll = '1'  ELSE n0lll;
	wire_n0OO_dataout <= wire_nl1l_o(0) AND wire_nl1O_o;
	wire_n0OOi_dataout <= wire_n0OOO_o(3) WHEN nllOll = '1'  ELSE n0llO;
	wire_n0OOl_dataout <= wire_n0OOO_o(4) WHEN nllOll = '1'  ELSE n0lOi;
	wire_n101i_dataout <= n10iO WHEN nlO0li = '1'  ELSE n1ilO;
	wire_n10i_dataout <= wire_n0il_dataout AND NOT(nlO0il);
	wire_n10l_dataout <= wire_n0iO_dataout AND NOT(nlO0il);
	wire_n10li_dataout <= wire_n1i1O_dataout AND NOT(ppm_cnt_reset);
	wire_n10ll_dataout <= wire_n1i0i_dataout AND NOT(ppm_cnt_reset);
	wire_n10lO_dataout <= wire_n1i0l_dataout AND NOT(ppm_cnt_reset);
	wire_n10O_dataout <= wire_n0li_dataout AND NOT(nlO0il);
	wire_n10Oi_dataout <= wire_n1i0O_dataout AND NOT(ppm_cnt_reset);
	wire_n10Ol_dataout <= wire_n1iii_dataout AND NOT(ppm_cnt_reset);
	wire_n10OO_dataout <= wire_n1iil_dataout AND NOT(ppm_cnt_reset);
	wire_n11i_dataout <= wire_n00l_dataout AND NOT(nlO0il);
	wire_n11l_dataout <= wire_n00O_dataout AND NOT(nlO0il);
	wire_n11O_dataout <= wire_n0ii_dataout AND NOT(nlO0il);
	wire_n11Oi_dataout <= wire_n11Ol_dataout OR nll1l;
	wire_n11Ol_dataout <= wire_n11OO_dataout OR rforcehigh;
	wire_n11OO_dataout <= wire_n101i_dataout AND NOT(rforcelow);
	wire_n1i0i_dataout <= n00ii WHEN nlOi0i = '1'  ELSE n101l;
	wire_n1i0l_dataout <= n00il WHEN nlOi0i = '1'  ELSE n101O;
	wire_n1i0O_dataout <= n00iO WHEN nlOi0i = '1'  ELSE n100i;
	wire_n1i1i_dataout <= wire_n1iiO_dataout AND NOT(ppm_cnt_reset);
	wire_n1i1l_dataout <= wire_n1ili_dataout AND NOT(ppm_cnt_reset);
	wire_n1i1O_dataout <= n1iOi WHEN nlOi0i = '1'  ELSE n1iOO;
	wire_n1ii_dataout <= wire_n0ll_dataout AND NOT(nlO0il);
	wire_n1iii_dataout <= n00li WHEN nlOi0i = '1'  ELSE n100l;
	wire_n1iil_dataout <= n00ll WHEN nlOi0i = '1'  ELSE n100O;
	wire_n1iiO_dataout <= n00lO WHEN nlOi0i = '1'  ELSE n10ii;
	wire_n1il_dataout <= wire_n0lO_dataout AND NOT(nlO0il);
	wire_n1ili_dataout <= n00Oi WHEN nlOi0i = '1'  ELSE n10il;
	wire_n1iO_dataout <= wire_n0Oi_dataout AND NOT(nlO0il);
	wire_n1li_dataout <= wire_n0Ol_dataout AND wire_nl0l_o;
	wire_n1ll_dataout <= wire_nl1O_o AND wire_nl0l_o;
	wire_n1lO_dataout <= wire_n0OO_dataout AND wire_nl0l_o;
	wire_n1Oi_dataout <= wire_ni1i_dataout AND wire_nl0l_o;
	wire_n1Ol_dataout <= wire_ni1l_dataout AND wire_nl0l_o;
	wire_n1OO_dataout <= wire_ni1O_dataout AND wire_nl0l_o;
	wire_ni0i_dataout <= wire_nl1l_o(4) AND wire_nl1O_o;
	wire_ni0ii_dataout <= (NOT (wire_w_lg_w_lg_nlO0li105w691w(0) OR (nlO0li AND ni00i))) OR nl01l;
	wire_ni0il_dataout <= wire_niiOi_o(0) AND NOT(nl01l);
	wire_ni0iO_dataout <= wire_niiOi_o(1) AND NOT(nl01l);
	wire_ni0l_dataout <= wire_nl1l_o(5) AND wire_nl1O_o;
	wire_ni0li_dataout <= wire_niiOi_o(2) AND NOT(nl01l);
	wire_ni0ll_dataout <= wire_niiOi_o(3) AND NOT(nl01l);
	wire_ni0lO_dataout <= wire_niiOi_o(4) AND NOT(nl01l);
	wire_ni0O_dataout <= wire_nl1l_o(6) AND wire_nl1O_o;
	wire_ni0Oi_dataout <= wire_niiOi_o(5) AND NOT(nl01l);
	wire_ni0Ol_dataout <= wire_niiOi_o(6) AND NOT(nl01l);
	wire_ni0OO_dataout <= wire_niiOi_o(7) AND NOT(nl01l);
	wire_ni1i_dataout <= wire_nl1l_o(1) AND wire_nl1O_o;
	wire_ni1l_dataout <= wire_nl1l_o(2) AND wire_nl1O_o;
	wire_ni1O_dataout <= wire_nl1l_o(3) AND wire_nl1O_o;
	wire_nii0i_dataout <= wire_niiOi_o(11) AND NOT(nl01l);
	wire_nii0l_dataout <= wire_niiOi_o(12) AND NOT(nl01l);
	wire_nii0O_dataout <= wire_niiOi_o(13) AND NOT(nl01l);
	wire_nii1i_dataout <= wire_niiOi_o(8) AND NOT(nl01l);
	wire_nii1l_dataout <= wire_niiOi_o(9) AND NOT(nl01l);
	wire_nii1O_dataout <= wire_niiOi_o(10) AND NOT(nl01l);
	wire_niii_dataout <= wire_nl1l_o(7) AND wire_nl1O_o;
	wire_niiii_dataout <= wire_niiOi_o(14) AND NOT(nl01l);
	wire_niiil_dataout <= wire_niiOi_o(15) AND NOT(nl01l);
	wire_niiiO_dataout <= wire_niiOi_o(16) AND NOT(nl01l);
	wire_niil_dataout <= wire_nl1l_o(8) AND wire_nl1O_o;
	wire_niiO_dataout <= wire_nl1l_o(9) AND wire_nl1O_o;
	wire_nili_dataout <= wire_nl1l_o(10) AND wire_nl1O_o;
	wire_nill_dataout <= wire_nl1l_o(11) AND wire_nl1O_o;
	wire_nilO_dataout <= wire_nl1l_o(12) AND wire_nl1O_o;
	wire_niO0i_dataout <= wire_nl1il_o(1) AND NOT(niO1i);
	wire_niO0l_dataout <= wire_nl1il_o(2) AND NOT(niO1i);
	wire_niO0O_dataout <= wire_nl1il_o(3) AND NOT(niO1i);
	wire_niO1l_dataout <= (NOT (wire_w_lg_w_lg_nlO0li105w617w(0) OR (nlO0li AND nilOO))) OR niO1i;
	wire_niO1O_dataout <= wire_nl1il_o(0) AND NOT(niO1i);
	wire_niOi_dataout <= wire_nl1l_o(13) AND wire_nl1O_o;
	wire_niOii_dataout <= wire_nl1il_o(4) AND NOT(niO1i);
	wire_niOil_dataout <= wire_nl1il_o(5) AND NOT(niO1i);
	wire_niOiO_dataout <= wire_nl1il_o(6) AND NOT(niO1i);
	wire_niOl_dataout <= wire_nl1l_o(14) AND wire_nl1O_o;
	wire_niOli_dataout <= wire_nl1il_o(7) AND NOT(niO1i);
	wire_niOll_dataout <= wire_nl1il_o(8) AND NOT(niO1i);
	wire_niOlO_dataout <= wire_nl1il_o(9) AND NOT(niO1i);
	wire_niOO_dataout <= wire_nl1l_o(15) AND wire_nl1O_o;
	wire_niOOi_dataout <= wire_nl1il_o(10) AND NOT(niO1i);
	wire_niOOl_dataout <= wire_nl1il_o(11) AND NOT(niO1i);
	wire_niOOO_dataout <= wire_nl1il_o(12) AND NOT(niO1i);
	wire_nl00i_dataout <= wire_nl00l_dataout AND NOT(wire_nl0OO_w_lg_nl0iO515w(0));
	wire_nl00l_dataout <= (ni00O XOR n0lOO) AND ((wire_ni00l_w_lg_n0lOi512w(0) AND wire_nl0OO_w_lg_n0lll10w(0)) AND wire_nl0OO_w_lg_n0lli15w(0));
	wire_nl01O_dataout <= nl01i AND NOT(wire_nl0OO_w_lg_nl0iO515w(0));
	wire_nl10i_dataout <= wire_nl1il_o(16) AND NOT(niO1i);
	wire_nl11i_dataout <= wire_nl1il_o(13) AND NOT(niO1i);
	wire_nl11l_dataout <= wire_nl1il_o(14) AND NOT(niO1i);
	wire_nl11O_dataout <= wire_nl1il_o(15) AND NOT(niO1i);
	wire_nl1i_dataout <= wire_nl1l_o(16) AND wire_nl1O_o;
	wire_nli0O_dataout <= nli1O AND NOT(scan_mode);
	wire_nli0O_w_lg_dataout509w(0) <= NOT wire_nli0O_dataout;
	wire_nlili_dataout <= nliiO AND NOT(scan_mode);
	wire_nlili_w_lg_dataout507w(0) <= NOT wire_nlili_dataout;
	wire_nliOl_dataout <= (wire_n0l_dataout OR ((nlli OR nliOi) OR (NOT (nlO1ii42 XOR nlO1ii41)))) AND NOT(scan_mode);
	wire_nliOl_w_lg_dataout328w(0) <= NOT wire_nliOl_dataout;
	wire_nlO0O_dataout <= wire_n1li_dataout AND NOT(nlO0il);
	wire_nlOii_dataout <= wire_n1ll_dataout OR nlO0il;
	wire_nlOil_dataout <= wire_n1lO_dataout OR nlO0il;
	wire_nlOiO_dataout <= wire_n1Oi_dataout AND NOT(nlO0il);
	wire_nlOli_dataout <= wire_n1Ol_dataout AND NOT(nlO0il);
	wire_nlOll_dataout <= wire_n1OO_dataout AND NOT(nlO0il);
	wire_nlOlO_dataout <= wire_n01i_dataout AND NOT(nlO0il);
	wire_nlOOi_dataout <= wire_n01l_dataout AND NOT(nlO0il);
	wire_nlOOl_dataout <= wire_n01O_dataout AND NOT(nlO0il);
	wire_nlOOO_dataout <= wire_n00i_dataout AND NOT(nlO0il);
	wire_n0liO_a <= ( n00Oi & n00lO & n00ll & n00li & n00iO & n00il & n00ii & n1iOi);
	wire_n0liO_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	n0liO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8,
		width_o => 8
	  )
	  PORT MAP ( 
		a => wire_n0liO_a,
		b => wire_n0liO_b,
		cin => wire_gnd,
		o => wire_n0liO_o
	  );
	wire_n0OOO_a <= ( n0lOi & n0llO & n0lll & n0lli & "1");
	wire_n0OOO_b <= ( "1" & "1" & "1" & "0" & "1");
	n0OOO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_n0OOO_a,
		b => wire_n0OOO_b,
		cin => wire_gnd,
		o => wire_n0OOO_o
	  );
	wire_niiOi_a <= ( ni00i & ni01O & ni01l & ni01i & ni1OO & ni1Ol & ni1Oi & ni1lO & ni1ll & ni1li & ni1iO & ni1il & ni1ii & ni10O & ni10l & ni10i & ni11O);
	wire_niiOi_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	niiOi :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 17,
		width_b => 17,
		width_o => 17
	  )
	  PORT MAP ( 
		a => wire_niiOi_a,
		b => wire_niiOi_b,
		cin => wire_gnd,
		o => wire_niiOi_o
	  );
	wire_nl0i_a <= ( "0" & nlO0li & wire_w_lg_nlO0li105w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nlO01O24_w_lg_w_lg_q108w109w & wire_w_lg_nlO0li105w & wire_w_lg_nlO0li105w & "0" & "0" & "0" & "0" & "0");
	wire_nl0i_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & rppm_post_eidle_del & "1" & wire_w_lg_rppm_post_eidle_del136w & "0" & rppm_post_eidle_del & wire_w_lg_rppm_post_eidle_del136w & "0" & "0" & "0");
	wire_nl0i_w_o_range218w(0) <= wire_nl0i_o(9);
	nl0i :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 18,
		width_b => 18,
		width_o => 18
	  )
	  PORT MAP ( 
		a => wire_nl0i_a,
		b => wire_nl0i_b,
		cin => wire_gnd,
		o => wire_nl0i_o
	  );
	wire_nl1il_a <= ( nilOO & nilOl & nilOi & nillO & nilll & nilli & niliO & nilil & nilii & nil0O & nil0l & nil0i & nil1O & nil1l & nil1i & niiOO & niiOl);
	wire_nl1il_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	nl1il :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 17,
		width_b => 17,
		width_o => 17
	  )
	  PORT MAP ( 
		a => wire_nl1il_a,
		b => wire_nl1il_b,
		cin => wire_gnd,
		o => wire_nl1il_o
	  );
	wire_nl1l_a <= ( wire_nlO1li40_w_lg_w_lg_q266w267w & nlO1O & nlO1l & wire_nlO1ll38_w_lg_w_lg_q261w262w & nllOO & nllOl & nllOi & wire_nlO1lO36_w_lg_w_lg_q255w256w & nllll & nllli & nlliO & nllil & nllii & nll0O & nll0l & nll0i & nll1O);
	wire_nl1l_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	nl1l :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 17,
		width_b => 17,
		width_o => 17
	  )
	  PORT MAP ( 
		a => wire_nl1l_a,
		b => wire_nl1l_b,
		cin => wire_gnd,
		o => wire_nl1l_o
	  );
	wire_nli0l_a <= ( nlO0li & wire_nlO10i48_w_lg_w_lg_q355w356w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0");
	wire_nli0l_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	wire_nli0l_w_o_range430w(0) <= wire_nli0l_o(12);
	nli0l :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 13,
		width_b => 13,
		width_o => 13
	  )
	  PORT MAP ( 
		a => wire_nli0l_a,
		b => wire_nli0l_b,
		cin => wire_gnd,
		o => wire_nli0l_o
	  );
	wire_n000l_a <= ( n00Oi & n00lO & n00ll & n00li & n00iO & n00il & n00ii & n1iOi);
	wire_n000l_b <= ( "0" & "1" & "0" & "0" & "0" & "0" & "1" & "1");
	n000l :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8
	  )
	  PORT MAP ( 
		a => wire_n000l_a,
		b => wire_n000l_b,
		cin => wire_vcc,
		o => wire_n000l_o
	  );
	wire_n001l_a <= ( n00Oi & n00lO & n00ll & n00li & n00iO & n00il & n00ii & n1iOi);
	wire_n001l_b <= ( "0" & "0" & "1" & "0" & "0" & "0" & "1" & "0");
	n001l :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8
	  )
	  PORT MAP ( 
		a => wire_n001l_a,
		b => wire_n001l_b,
		cin => wire_vcc,
		o => wire_n001l_o
	  );
	wire_n010l_a <= ( n00Oi & n00lO & n00ll & n00li & n00iO & n00il & n00ii & n1iOi);
	wire_n010l_b <= ( "0" & "0" & "0" & "0" & "1" & "1" & "1" & "1");
	n010l :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8
	  )
	  PORT MAP ( 
		a => wire_n010l_a,
		b => wire_n010l_b,
		cin => wire_vcc,
		o => wire_n010l_o
	  );
	wire_n011i_a <= ( n00Oi & n00lO & n00ll & n00li & n00iO & n00il & n00ii & n1iOi);
	wire_n011i_b <= ( "0" & "0" & "0" & "0" & "1" & "0" & "1" & "0");
	n011i :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8
	  )
	  PORT MAP ( 
		a => wire_n011i_a,
		b => wire_n011i_b,
		cin => wire_vcc,
		o => wire_n011i_o
	  );
	wire_n01iO_a <= ( n00Oi & n00lO & n00ll & n00li & n00iO & n00il & n00ii & n1iOi);
	wire_n01iO_b <= ( "0" & "0" & "0" & "1" & "0" & "0" & "1" & "0");
	n01iO :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8
	  )
	  PORT MAP ( 
		a => wire_n01iO_a,
		b => wire_n01iO_b,
		cin => wire_vcc,
		o => wire_n01iO_o
	  );
	wire_n01Oi_a <= ( n00Oi & n00lO & n00ll & n00li & n00iO & n00il & n00ii & n1iOi);
	wire_n01Oi_b <= ( "0" & "0" & "0" & "1" & "0" & "1" & "0" & "1");
	n01Oi :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8
	  )
	  PORT MAP ( 
		a => wire_n01Oi_a,
		b => wire_n01Oi_b,
		cin => wire_vcc,
		o => wire_n01Oi_o
	  );
	wire_n1liO_a <= ( n00Oi & n00lO & n00ll & n00li & n00iO & n00il & n00ii & n1iOi);
	wire_n1liO_b <= ( "0" & "0" & "0" & "1" & "1" & "1" & "0" & "0");
	n1liO :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8
	  )
	  PORT MAP ( 
		a => wire_n1liO_a,
		b => wire_n1liO_b,
		cin => wire_vcc,
		o => wire_n1liO_o
	  );
	wire_n1lOl_a <= ( n00Oi & n00lO & n00ll & n00li & n00iO & n00il & n00ii & n1iOi);
	wire_n1lOl_b <= ( "0" & "0" & "1" & "0" & "1" & "0" & "0" & "1");
	n1lOl :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8
	  )
	  PORT MAP ( 
		a => wire_n1lOl_a,
		b => wire_n1lOl_b,
		cin => wire_vcc,
		o => wire_n1lOl_o
	  );
	wire_n1O1O_a <= ( n00Oi & n00lO & n00ll & n00li & n00iO & n00il & n00ii & n1iOi);
	wire_n1O1O_b <= ( "1" & "0" & "0" & "0" & "0" & "1" & "0" & "1");
	n1O1O :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8
	  )
	  PORT MAP ( 
		a => wire_n1O1O_a,
		b => wire_n1O1O_b,
		cin => wire_vcc,
		o => wire_n1O1O_o
	  );
	wire_n1Oil_a <= ( n00Oi & n00lO & n00ll & n00li & n00iO & n00il & n00ii & n1iOi);
	wire_n1Oil_b <= ( "0" & "0" & "0" & "0" & "0" & "1" & "1" & "0");
	n1Oil :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8
	  )
	  PORT MAP ( 
		a => wire_n1Oil_a,
		b => wire_n1Oil_b,
		cin => wire_vcc,
		o => wire_n1Oil_o
	  );
	wire_n1OlO_a <= ( n00Oi & n00lO & n00ll & n00li & n00iO & n00il & n00ii & n1iOi);
	wire_n1OlO_b <= ( "0" & "0" & "0" & "0" & "1" & "0" & "0" & "0");
	n1OlO :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8
	  )
	  PORT MAP ( 
		a => wire_n1OlO_a,
		b => wire_n1OlO_b,
		cin => wire_vcc,
		o => wire_n1OlO_o
	  );
	wire_nl0l_a <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0");
	wire_nl0l_b <= ( nlO0i & nlO1O & nlO1l & nlO1i & wire_nlO00i22_w_lg_w_lg_q87w88w & wire_nlO00l20_w_lg_w_lg_q84w85w & nllOi & nlllO & nllll & wire_nlO00O18_w_lg_w_lg_q78w79w & nlliO & nllil & nllii & wire_nlO0ii16_w_lg_w_lg_q72w73w & nll0l & nll0i & nll1O);
	nl0l :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 17,
		width_b => 17
	  )
	  PORT MAP ( 
		a => wire_nl0l_a,
		b => wire_nl0l_b,
		cin => wire_gnd,
		o => wire_nl0l_o
	  );
	wire_nl1O_a <= ( "0" & nlO0i & nlO1O & nlO1l & nlO1i & wire_nlO1Ol32_w_lg_w_lg_q182w183w & nllOl & nllOi & wire_nlO1OO30_w_lg_w_lg_q177w178w & nllll & nllli & nlliO & nllil & nllii & nll0O & wire_nlO01i28_w_lg_w_lg_q168w169w & wire_nlO01l26_w_lg_w_lg_q165w166w & nll1O);
	wire_nl1O_b <= ( wire_nl0i_o(17 DOWNTO 10) & wire_nlO1Oi34_w_lg_w_lg_q219w220w & wire_nl0i_o(8 DOWNTO 0));
	nl1O :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 18,
		width_b => 18
	  )
	  PORT MAP ( 
		a => wire_nl1O_a,
		b => wire_nl1O_b,
		cin => wire_gnd,
		o => wire_nl1O_o
	  );
	wire_nl1Ol_a <= ( n0lOi & n0llO & n0lll & n0lli);
	wire_nl1Ol_b <= ( "1" & "0" & "0" & "0");
	nl1Ol :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 4,
		width_b => 4
	  )
	  PORT MAP ( 
		a => wire_nl1Ol_a,
		b => wire_nl1Ol_b,
		cin => wire_gnd,
		o => wire_nl1Ol_o
	  );
	wire_nl1OO_a <= ( "0" & "0" & "0" & "0");
	wire_nl1OO_b <= ( n0lOi & n0llO & n0lll & n0lli);
	nl1OO :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 4,
		width_b => 4
	  )
	  PORT MAP ( 
		a => wire_nl1OO_a,
		b => wire_nl1OO_b,
		cin => wire_gnd,
		o => wire_nl1OO_o
	  );
	wire_nli0i_a <= ( wire_nlO11O50_w_lg_w_lg_q431w432w & wire_nli0l_o(11 DOWNTO 0) & "0" & "0" & "0" & "0");
	wire_nli0i_b <= ( nilOO & nilOl & nilOi & nillO & nilll & nilli & niliO & nilil & nilii & nil0O & nil0l & nil0i & nil1O & nil1l & nil1i & niiOO & wire_nlO11l52_w_lg_w_lg_q434w435w);
	nli0i :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 17,
		width_b => 17
	  )
	  PORT MAP ( 
		a => wire_nli0i_a,
		b => wire_nli0i_b,
		cin => wire_gnd,
		o => wire_nli0i_o
	  );
	wire_nli1l_a <= ( wire_nli0l_o(12 DOWNTO 0) & "0" & "0" & "0" & "0");
	wire_nli1l_b <= ( ni00i & ni01O & ni01l & ni01i & ni1OO & ni1Ol & ni1Oi & ni1lO & ni1ll & ni1li & ni1iO & ni1il & ni1ii & ni10O & ni10l & ni10i & ni11O);
	nli1l :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 17,
		width_b => 17
	  )
	  PORT MAP ( 
		a => wire_nli1l_a,
		b => wire_nli1l_b,
		cin => wire_gnd,
		o => wire_nli1l_o
	  );

 END RTL; --stratixiv_hssi_rx_digi_freqdet
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 177 mux21 115 oper_add 3 oper_decoder 3 oper_less_than 2 oper_mux 1 oper_selector 4 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_rx_digi_eii_module IS 
	 PORT 
	 ( 
		 eidleinfersel	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 eiosdetect_int	:	IN  STD_LOGIC;
		 gen2ngen1	:	IN  STD_LOGIC;
		 gen2ngen1_bundle	:	IN  STD_LOGIC;
		 inferred_rxvalid	:	IN  STD_LOGIC;
		 kcount	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 kflag	:	IN  STD_LOGIC;
		 pipe_loopbk	:	IN  STD_LOGIC;
		 rcvd_clk	:	IN  STD_LOGIC;
		 reidle_com_detect	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 reidleinferenable	:	IN  STD_LOGIC;
		 rgen1_sigdet_ena	:	IN  STD_LOGIC;
		 riei_eios_priority_dis	:	IN  STD_LOGIC;
		 rindv_rx	:	IN  STD_LOGIC;
		 rwait_count	:	IN  STD_LOGIC_VECTOR (7 DOWNTO 0);
		 rxelecidle_int	:	OUT  STD_LOGIC;
		 rxpcsrst	:	IN  STD_LOGIC;
		 signaldetect	:	IN  STD_LOGIC;
		 skposdetect	:	IN  STD_LOGIC;
		 sudi	:	IN  STD_LOGIC_VECTOR (15 DOWNTO 0);
		 syncstatus	:	IN  STD_LOGIC
	 ); 
 END stratixiv_hssi_rx_digi_eii_module;

 ARCHITECTURE RTL OF stratixiv_hssi_rx_digi_eii_module IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 niOi0l51	:	STD_LOGIC := '0';
	 SIGNAL	 niOi0l52	:	STD_LOGIC := '0';
	 SIGNAL	 niOi0O49	:	STD_LOGIC := '0';
	 SIGNAL	 niOi0O50	:	STD_LOGIC := '0';
	 SIGNAL	 nl000l23	:	STD_LOGIC := '0';
	 SIGNAL	 nl000l24	:	STD_LOGIC := '0';
	 SIGNAL	 nl001l25	:	STD_LOGIC := '0';
	 SIGNAL	 nl001l26	:	STD_LOGIC := '0';
	 SIGNAL	 nl00ii21	:	STD_LOGIC := '0';
	 SIGNAL	 nl00ii22	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl00ii22_w_lg_q95w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl00ll19	:	STD_LOGIC := '0';
	 SIGNAL	 nl00ll20	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl00ll20_w_lg_w_lg_q76w77w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl00ll20_w_lg_q76w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl00lO17	:	STD_LOGIC := '0';
	 SIGNAL	 nl00lO18	:	STD_LOGIC := '0';
	 SIGNAL	 nl00Oi15	:	STD_LOGIC := '0';
	 SIGNAL	 nl00Oi16	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl00Oi16_w_lg_w_lg_q39w40w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl00Oi16_w_lg_q39w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl00Ol13	:	STD_LOGIC := '0';
	 SIGNAL	 nl00Ol14	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl00Ol14_w_lg_w_lg_q30w31w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl00Ol14_w_lg_q30w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl011l37	:	STD_LOGIC := '0';
	 SIGNAL	 nl011l38	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl011l38_w_lg_w_lg_q208w209w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl011l38_w_lg_q208w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl01ii35	:	STD_LOGIC := '0';
	 SIGNAL	 nl01ii36	:	STD_LOGIC := '0';
	 SIGNAL	 nl01iO33	:	STD_LOGIC := '0';
	 SIGNAL	 nl01iO34	:	STD_LOGIC := '0';
	 SIGNAL	 nl01ll31	:	STD_LOGIC := '0';
	 SIGNAL	 nl01ll32	:	STD_LOGIC := '0';
	 SIGNAL	 nl01Oi29	:	STD_LOGIC := '0';
	 SIGNAL	 nl01Oi30	:	STD_LOGIC := '0';
	 SIGNAL	 nl01OO27	:	STD_LOGIC := '0';
	 SIGNAL	 nl01OO28	:	STD_LOGIC := '0';
	 SIGNAL	 nl0i0i10	:	STD_LOGIC := '0';
	 SIGNAL	 nl0i0i9	:	STD_LOGIC := '0';
	 SIGNAL	 nl0i0l7	:	STD_LOGIC := '0';
	 SIGNAL	 nl0i0l8	:	STD_LOGIC := '0';
	 SIGNAL	 nl0i1i11	:	STD_LOGIC := '0';
	 SIGNAL	 nl0i1i12	:	STD_LOGIC := '0';
	 SIGNAL	 nl0iii5	:	STD_LOGIC := '0';
	 SIGNAL	 nl0iii6	:	STD_LOGIC := '0';
	 SIGNAL	 nl0ili3	:	STD_LOGIC := '0';
	 SIGNAL	 nl0ili4	:	STD_LOGIC := '0';
	 SIGNAL	 nl0iOi1	:	STD_LOGIC := '0';
	 SIGNAL	 nl0iOi2	:	STD_LOGIC := '0';
	 SIGNAL	 nl1lOO47	:	STD_LOGIC := '0';
	 SIGNAL	 nl1lOO48	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl1lOO48_w_lg_w_lg_q239w240w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lOO48_w_lg_q239w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl1O1l45	:	STD_LOGIC := '0';
	 SIGNAL	 nl1O1l46	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl1O1l46_w_lg_q235w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl1Oii43	:	STD_LOGIC := '0';
	 SIGNAL	 nl1Oii44	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl1Oii44_w_lg_q227w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl1Oll41	:	STD_LOGIC := '0';
	 SIGNAL	 nl1Oll42	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl1Oll42_w_lg_w_lg_q218w219w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1Oll42_w_lg_q218w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl1OOl39	:	STD_LOGIC := '0';
	 SIGNAL	 nl1OOl40	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl1OOl40_w_lg_w_lg_q213w214w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1OOl40_w_lg_q213w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n0l	:	STD_LOGIC := '0';
	 SIGNAL	n0OlO	:	STD_LOGIC := '0';
	 SIGNAL	n0OOi	:	STD_LOGIC := '0';
	 SIGNAL	n0OOl	:	STD_LOGIC := '0';
	 SIGNAL	n0OOO	:	STD_LOGIC := '0';
	 SIGNAL	n1Ol	:	STD_LOGIC := '0';
	 SIGNAL	n1OlO	:	STD_LOGIC := '0';
	 SIGNAL	n1OO	:	STD_LOGIC := '0';
	 SIGNAL	ni00i	:	STD_LOGIC := '0';
	 SIGNAL	ni00l	:	STD_LOGIC := '0';
	 SIGNAL	ni00O	:	STD_LOGIC := '0';
	 SIGNAL	ni01i	:	STD_LOGIC := '0';
	 SIGNAL	ni01l	:	STD_LOGIC := '0';
	 SIGNAL	ni01O	:	STD_LOGIC := '0';
	 SIGNAL	ni0i	:	STD_LOGIC := '0';
	 SIGNAL	ni0il	:	STD_LOGIC := '0';
	 SIGNAL	ni0iO	:	STD_LOGIC := '0';
	 SIGNAL	ni0li	:	STD_LOGIC := '0';
	 SIGNAL	ni0ll	:	STD_LOGIC := '0';
	 SIGNAL	ni0lO	:	STD_LOGIC := '0';
	 SIGNAL	ni0Oi	:	STD_LOGIC := '0';
	 SIGNAL	ni0Ol	:	STD_LOGIC := '0';
	 SIGNAL	ni0OO	:	STD_LOGIC := '0';
	 SIGNAL	ni10i	:	STD_LOGIC := '0';
	 SIGNAL	ni10l	:	STD_LOGIC := '0';
	 SIGNAL	ni10O	:	STD_LOGIC := '0';
	 SIGNAL	ni11i	:	STD_LOGIC := '0';
	 SIGNAL	ni11l	:	STD_LOGIC := '0';
	 SIGNAL	ni11O	:	STD_LOGIC := '0';
	 SIGNAL	ni1ii	:	STD_LOGIC := '0';
	 SIGNAL	ni1il	:	STD_LOGIC := '0';
	 SIGNAL	ni1iO	:	STD_LOGIC := '0';
	 SIGNAL	ni1li	:	STD_LOGIC := '0';
	 SIGNAL	ni1ll	:	STD_LOGIC := '0';
	 SIGNAL	ni1lO	:	STD_LOGIC := '0';
	 SIGNAL	ni1Oi	:	STD_LOGIC := '0';
	 SIGNAL	ni1Ol	:	STD_LOGIC := '0';
	 SIGNAL	ni1OO	:	STD_LOGIC := '0';
	 SIGNAL	nii0i	:	STD_LOGIC := '0';
	 SIGNAL	nii0l	:	STD_LOGIC := '0';
	 SIGNAL	nii0O	:	STD_LOGIC := '0';
	 SIGNAL	nii1i	:	STD_LOGIC := '0';
	 SIGNAL	nii1l	:	STD_LOGIC := '0';
	 SIGNAL	nii1O	:	STD_LOGIC := '0';
	 SIGNAL	niiii	:	STD_LOGIC := '0';
	 SIGNAL	niiil	:	STD_LOGIC := '0';
	 SIGNAL	niiiO	:	STD_LOGIC := '0';
	 SIGNAL	niili	:	STD_LOGIC := '0';
	 SIGNAL	niill	:	STD_LOGIC := '0';
	 SIGNAL	niilO	:	STD_LOGIC := '0';
	 SIGNAL	niiOi	:	STD_LOGIC := '0';
	 SIGNAL	niiOl	:	STD_LOGIC := '0';
	 SIGNAL	niiOO	:	STD_LOGIC := '0';
	 SIGNAL	nil1i	:	STD_LOGIC := '0';
	 SIGNAL	nil1l	:	STD_LOGIC := '0';
	 SIGNAL	nil1O	:	STD_LOGIC := '0';
	 SIGNAL	nl	:	STD_LOGIC := '0';
	 SIGNAL	nl0l0O	:	STD_LOGIC := '0';
	 SIGNAL	nl0lli	:	STD_LOGIC := '0';
	 SIGNAL	nl0O0i	:	STD_LOGIC := '0';
	 SIGNAL	nl0O0l	:	STD_LOGIC := '0';
	 SIGNAL	nl0O0O	:	STD_LOGIC := '0';
	 SIGNAL	nl0O1i	:	STD_LOGIC := '0';
	 SIGNAL	nl0O1l	:	STD_LOGIC := '0';
	 SIGNAL	nl0O1O	:	STD_LOGIC := '0';
	 SIGNAL	nl0Oii	:	STD_LOGIC := '0';
	 SIGNAL	nl0Oil	:	STD_LOGIC := '0';
	 SIGNAL	nl0OiO	:	STD_LOGIC := '0';
	 SIGNAL	nl0Oli	:	STD_LOGIC := '0';
	 SIGNAL	nl0Oll	:	STD_LOGIC := '0';
	 SIGNAL	nl0OlO	:	STD_LOGIC := '0';
	 SIGNAL	nli0ll	:	STD_LOGIC := '0';
	 SIGNAL	nli0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nli0OO	:	STD_LOGIC := '0';
	 SIGNAL	nli10l	:	STD_LOGIC := '0';
	 SIGNAL	nli10O	:	STD_LOGIC := '0';
	 SIGNAL	nli1ii	:	STD_LOGIC := '0';
	 SIGNAL	nli1il	:	STD_LOGIC := '0';
	 SIGNAL	nli1iO	:	STD_LOGIC := '0';
	 SIGNAL	nli1li	:	STD_LOGIC := '0';
	 SIGNAL	nli1ll	:	STD_LOGIC := '0';
	 SIGNAL	nli1lO	:	STD_LOGIC := '0';
	 SIGNAL	nli1Oi	:	STD_LOGIC := '0';
	 SIGNAL	nlii0i	:	STD_LOGIC := '0';
	 SIGNAL	nlii0l	:	STD_LOGIC := '0';
	 SIGNAL	nlii0O	:	STD_LOGIC := '0';
	 SIGNAL	nlii1i	:	STD_LOGIC := '0';
	 SIGNAL	nlii1l	:	STD_LOGIC := '0';
	 SIGNAL	nlii1O	:	STD_LOGIC := '0';
	 SIGNAL	nliiii	:	STD_LOGIC := '0';
	 SIGNAL	nliiil	:	STD_LOGIC := '0';
	 SIGNAL	nliiiO	:	STD_LOGIC := '0';
	 SIGNAL	nliili	:	STD_LOGIC := '0';
	 SIGNAL	nliill	:	STD_LOGIC := '0';
	 SIGNAL	nliilO	:	STD_LOGIC := '0';
	 SIGNAL	nliiOi	:	STD_LOGIC := '0';
	 SIGNAL	nliiOl	:	STD_LOGIC := '0';
	 SIGNAL	nlil	:	STD_LOGIC := '0';
	 SIGNAL	nll	:	STD_LOGIC := '0';
	 SIGNAL	nlO	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w683w724w725w726w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w683w684w704w705w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w683w684w685w686w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w631w632w633w634w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w643w644w645w646w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w617w618w619w620w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w815w816w817w818w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w829w852w853w854w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w829w830w842w843w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w829w830w831w897w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w764w765w786w787w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w764w765w766w796w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w764w804w805w806w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w662w663w664w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w556w557w636w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w564w566w567w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w654w655w656w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w625w626w627w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w678w679w680w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w732w733w734w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w699w710w711w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w690w691w696w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w808w809w860w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w800w812w813w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w772w774w775w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w867w868w869w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w825w839w840w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w751w783w784w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w683w724w725w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w683w684w704w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w683w684w685w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w669w670w671w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w631w632w633w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w631w648w649w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w603w604w605w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w643w644w645w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w617w618w619w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w617w638w639w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w815w816w817w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w829w852w853w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w829w830w842w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w829w830w831w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w764w765w786w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w764w765w766w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w764w804w805w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w662w663w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w556w557w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w564w566w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w564w658w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w654w655w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w625w626w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w678w679w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w678w721w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w732w733w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w699w710w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w699w700w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w690w691w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w690w707w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w808w809w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w800w812w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w772w774w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w772w880w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w867w868w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w825w839w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w825w826w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w751w783w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w751w752w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w683w724w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w683w684w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w669w670w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w631w632w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w631w648w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w603w604w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w643w644w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w617w618w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w617w638w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w815w816w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w829w852w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w829w830w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w764w765w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w764w804w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w662w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w556w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w564w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w654w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w625w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w678w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w732w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w699w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w690w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w728w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w591w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w808w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w800w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w772w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w856w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w867w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w825w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w751w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w581w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w683w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w669w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w631w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w603w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w643w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w617w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w815w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w778w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w829w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w764w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i548w549w551w608w661w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i548w549w551w552w554w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i548w549w622w652w653w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i548w549w622w623w624w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w676w677w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w676w698w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w688w689w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i586w587w588w589w590w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w770w799w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w770w771w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w748w824w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w748w749w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w575w577w578w580w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w575w666w667w682w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w575w666w667w668w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w599w600w629w630w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w599w600w601w602w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w599w614w615w642w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w599w614w615w616w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i757w759w760w762w777w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i757w759w760w762w763w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i548w549w551w608w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i548w549w551w552w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i548w549w622w652w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i548w549w622w623w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w676w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w688w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i586w587w588w589w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w770w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w748w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w575w577w578w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w575w666w667w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w599w600w629w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w599w600w601w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w599w614w615w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_w_lg_nil1i757w759w760w762w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_nii0i548w549w551w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_nii0i548w549w622w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_nii0i586w674w675w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_nii0i586w587w588w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_nil1i744w746w747w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_nii0i574w575w577w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_nii0i574w575w666w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_nii0i574w599w600w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_nii0i574w599w614w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_nil1i757w759w760w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_nil1O221w233w236w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_nil1O221w225w228w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nii0i548w549w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nii0i586w674w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nii0i586w587w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1i744w746w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_ni0i23w24w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nii0i574w575w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nii0i574w599w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nii0l197w343w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nii0l197w339w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nii0l197w335w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nii0O200w344w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nii0O200w340w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nii0O200w336w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1i757w759w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1l222w286w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1l222w282w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1l222w278w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1l222w273w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1l222w269w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1l222w261w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1l222w257w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1l222w265w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1l222w253w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1l222w249w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1l222w244w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1l222w232w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1l222w224w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1O221w287w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1O221w283w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1O221w279w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1O221w274w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1O221w270w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1O221w262w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1O221w258w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1O221w266w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1O221w254w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1O221w250w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1O221w245w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1O221w233w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nil1O221w225w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nii0i548w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nii0i586w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nil1i744w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nlO9w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_n0l16w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_ni0i23w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_ni0il366w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_ni0iO198w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_ni0li568w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_ni0ll558w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_ni0lO565w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_ni0Oi555w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_ni0Ol553w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_ni0OO579w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nii0i574w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nii0l197w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nii0O200w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nii1i550w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nii1l576w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nii1O547w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_niiii755w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_niiil753w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_niiiO773w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_niili750w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_niill798w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_niilO769w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_niiOi761w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_niiOl745w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_niiOO758w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nil1i757w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nil1l222w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nil1O221w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nli0ll989w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nli0OO987w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nli1li907w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nlii0i982w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nlii1i985w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nlii1O983w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nlil911w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nlO9w10w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_n0l1088w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n01i	:	STD_LOGIC := '0';
	 SIGNAL	n0ll	:	STD_LOGIC := '0';
	 SIGNAL	n0lO	:	STD_LOGIC := '0';
	 SIGNAL	n0Oi	:	STD_LOGIC := '0';
	 SIGNAL	n0Ol	:	STD_LOGIC := '0';
	 SIGNAL	n0OO	:	STD_LOGIC := '0';
	 SIGNAL	ni1i	:	STD_LOGIC := '0';
	 SIGNAL	ni1O	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni1l_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_ni1l_w_lg_n0ll115w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_n0Oi125w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1l_w_lg_ni1i138w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nliO0i	:	STD_LOGIC := '0';
	 SIGNAL	nliO0l	:	STD_LOGIC := '0';
	 SIGNAL	nliO0O	:	STD_LOGIC := '0';
	 SIGNAL	nliO1l	:	STD_LOGIC := '0';
	 SIGNAL	nliO1O	:	STD_LOGIC := '0';
	 SIGNAL	nliOii	:	STD_LOGIC := '0';
	 SIGNAL	nliOil	:	STD_LOGIC := '0';
	 SIGNAL	nliOiO	:	STD_LOGIC := '0';
	 SIGNAL	nliOli	:	STD_LOGIC := '0';
	 SIGNAL	nliOll	:	STD_LOGIC := '0';
	 SIGNAL	nliOOi	:	STD_LOGIC := '0';
	 SIGNAL	wire_nliOlO_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nliOlO_PRN	:	STD_LOGIC;
	 SIGNAL	n0li	:	STD_LOGIC := '0';
	 SIGNAL	ni0ii	:	STD_LOGIC := '0';
	 SIGNAL	nl0lOO	:	STD_LOGIC := '0';
	 SIGNAL	nliO	:	STD_LOGIC := '0';
	 SIGNAL	nll10i	:	STD_LOGIC := '0';
	 SIGNAL	nlll	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlli_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nlli_PRN	:	STD_LOGIC;
	 SIGNAL  wire_nlli_w_lg_nliO18w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n000i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n00O_a	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n00O_b	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_gnd	:	STD_LOGIC;
	 SIGNAL  wire_n00O_o	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl0O_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0O_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0O_o	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nliO1i_a	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nliO1i_b	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nliO1i_o	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nl0OOi_i	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl0OOi_o	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl0OOO_i	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl0OOO_o	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nli10i_i	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nli10i_o	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n0il_a	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n0il_b	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n0il_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0lOi_a	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl0lOi_b	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_vcc	:	STD_LOGIC;
	 SIGNAL  wire_nl0lOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0lil_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0lil_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0lil_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n000l_data	:	STD_LOGIC_VECTOR (26 DOWNTO 0);
	 SIGNAL  wire_n000l_o	:	STD_LOGIC;
	 SIGNAL  wire_n000l_sel	:	STD_LOGIC_VECTOR (26 DOWNTO 0);
	 SIGNAL  wire_n000O_data	:	STD_LOGIC_VECTOR (26 DOWNTO 0);
	 SIGNAL  wire_n000O_o	:	STD_LOGIC;
	 SIGNAL  wire_n000O_sel	:	STD_LOGIC_VECTOR (26 DOWNTO 0);
	 SIGNAL  wire_n01lO_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n01lO_o	:	STD_LOGIC;
	 SIGNAL  wire_n01lO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n1Oii_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n1Oii_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oii_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_w_lg_w97w98w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w97w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_w_sudi_range87w88w91w93w96w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_sudi_range87w88w91w93w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_riei_eios_priority_dis4w5w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_sudi_range87w88w91w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOO1O508w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOil368w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOli370w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl0iiO28w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_reidleinferenable365w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_riei_eios_priority_dis4w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rxpcsrst2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_sudi_range87w88w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_sudi_range89w90w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w284w288w289w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w284w288w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w284w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_w_lg_w263w267w271w275w276w280w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_w263w267w271w275w276w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w263w267w271w275w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w263w267w271w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w263w267w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w263w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_w_lg_w242w246w247w251w255w259w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_w242w246w247w251w255w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w242w246w247w251w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w242w246w247w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w242w246w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w242w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_w_lg_w216w220w229w230w237w241w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_w216w220w229w230w237w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w216w220w229w230w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w216w220w229w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w216w220w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w216w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_nl010i206w210w211w215w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_nl1OOi337w341w345w346w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_nl010i206w210w211w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_nl1OOi337w341w345w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nl010i206w210w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nl1OOi337w341w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl00li92w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl010i206w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl110l342w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl11ii338w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl11iO334w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1i0O285w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1iil281w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1ili277w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1iOi272w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1iOO268w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1l0i260w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1l0O256w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1l1l264w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1lil252w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1lli248w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1lOi243w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1O0l231w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1Oli223w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nl1OOi337w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  niOi0i :	STD_LOGIC;
	 SIGNAL  niOi1l :	STD_LOGIC;
	 SIGNAL  niOi1O :	STD_LOGIC;
	 SIGNAL  niOiii :	STD_LOGIC;
	 SIGNAL  niOiil :	STD_LOGIC;
	 SIGNAL  niOiiO :	STD_LOGIC;
	 SIGNAL  niOili :	STD_LOGIC;
	 SIGNAL  niOill :	STD_LOGIC;
	 SIGNAL  niOilO :	STD_LOGIC;
	 SIGNAL  niOiOi :	STD_LOGIC;
	 SIGNAL  niOiOl :	STD_LOGIC;
	 SIGNAL  niOiOO :	STD_LOGIC;
	 SIGNAL  niOl0i :	STD_LOGIC;
	 SIGNAL  niOl0l :	STD_LOGIC;
	 SIGNAL  niOl0O :	STD_LOGIC;
	 SIGNAL  niOl1i :	STD_LOGIC;
	 SIGNAL  niOl1l :	STD_LOGIC;
	 SIGNAL  niOl1O :	STD_LOGIC;
	 SIGNAL  niOlii :	STD_LOGIC;
	 SIGNAL  niOlil :	STD_LOGIC;
	 SIGNAL  niOliO :	STD_LOGIC;
	 SIGNAL  niOlli :	STD_LOGIC;
	 SIGNAL  niOlll :	STD_LOGIC;
	 SIGNAL  niOllO :	STD_LOGIC;
	 SIGNAL  niOlOi :	STD_LOGIC;
	 SIGNAL  niOlOl :	STD_LOGIC;
	 SIGNAL  niOlOO :	STD_LOGIC;
	 SIGNAL  niOO0i :	STD_LOGIC;
	 SIGNAL  niOO0l :	STD_LOGIC;
	 SIGNAL  niOO0O :	STD_LOGIC;
	 SIGNAL  niOO1i :	STD_LOGIC;
	 SIGNAL  niOO1l :	STD_LOGIC;
	 SIGNAL  niOO1O :	STD_LOGIC;
	 SIGNAL  niOOii :	STD_LOGIC;
	 SIGNAL  niOOil :	STD_LOGIC;
	 SIGNAL  niOOiO :	STD_LOGIC;
	 SIGNAL  niOOli :	STD_LOGIC;
	 SIGNAL  niOOll :	STD_LOGIC;
	 SIGNAL  niOOlO :	STD_LOGIC;
	 SIGNAL  niOOOi :	STD_LOGIC;
	 SIGNAL  niOOOl :	STD_LOGIC;
	 SIGNAL  niOOOO :	STD_LOGIC;
	 SIGNAL  nl000i :	STD_LOGIC;
	 SIGNAL  nl00iO :	STD_LOGIC;
	 SIGNAL  nl00li :	STD_LOGIC;
	 SIGNAL  nl00OO :	STD_LOGIC;
	 SIGNAL  nl010i :	STD_LOGIC;
	 SIGNAL  nl010l :	STD_LOGIC;
	 SIGNAL  nl010O :	STD_LOGIC;
	 SIGNAL  nl011i :	STD_LOGIC;
	 SIGNAL  nl0i0O :	STD_LOGIC;
	 SIGNAL  nl0i1O :	STD_LOGIC;
	 SIGNAL  nl0iiO :	STD_LOGIC;
	 SIGNAL  nl0ilO :	STD_LOGIC;
	 SIGNAL  nl100i :	STD_LOGIC;
	 SIGNAL  nl100l :	STD_LOGIC;
	 SIGNAL  nl100O :	STD_LOGIC;
	 SIGNAL  nl101i :	STD_LOGIC;
	 SIGNAL  nl101l :	STD_LOGIC;
	 SIGNAL  nl101O :	STD_LOGIC;
	 SIGNAL  nl10ii :	STD_LOGIC;
	 SIGNAL  nl10il :	STD_LOGIC;
	 SIGNAL  nl10iO :	STD_LOGIC;
	 SIGNAL  nl10li :	STD_LOGIC;
	 SIGNAL  nl10ll :	STD_LOGIC;
	 SIGNAL  nl10lO :	STD_LOGIC;
	 SIGNAL  nl10Oi :	STD_LOGIC;
	 SIGNAL  nl10Ol :	STD_LOGIC;
	 SIGNAL  nl10OO :	STD_LOGIC;
	 SIGNAL  nl110i :	STD_LOGIC;
	 SIGNAL  nl110l :	STD_LOGIC;
	 SIGNAL  nl110O :	STD_LOGIC;
	 SIGNAL  nl111i :	STD_LOGIC;
	 SIGNAL  nl111l :	STD_LOGIC;
	 SIGNAL  nl111O :	STD_LOGIC;
	 SIGNAL  nl11ii :	STD_LOGIC;
	 SIGNAL  nl11il :	STD_LOGIC;
	 SIGNAL  nl11iO :	STD_LOGIC;
	 SIGNAL  nl11li :	STD_LOGIC;
	 SIGNAL  nl11ll :	STD_LOGIC;
	 SIGNAL  nl11lO :	STD_LOGIC;
	 SIGNAL  nl11Oi :	STD_LOGIC;
	 SIGNAL  nl11Ol :	STD_LOGIC;
	 SIGNAL  nl11OO :	STD_LOGIC;
	 SIGNAL  nl1i0i :	STD_LOGIC;
	 SIGNAL  nl1i0l :	STD_LOGIC;
	 SIGNAL  nl1i0O :	STD_LOGIC;
	 SIGNAL  nl1i1i :	STD_LOGIC;
	 SIGNAL  nl1i1l :	STD_LOGIC;
	 SIGNAL  nl1i1O :	STD_LOGIC;
	 SIGNAL  nl1iii :	STD_LOGIC;
	 SIGNAL  nl1iil :	STD_LOGIC;
	 SIGNAL  nl1iiO :	STD_LOGIC;
	 SIGNAL  nl1ili :	STD_LOGIC;
	 SIGNAL  nl1ill :	STD_LOGIC;
	 SIGNAL  nl1ilO :	STD_LOGIC;
	 SIGNAL  nl1iOi :	STD_LOGIC;
	 SIGNAL  nl1iOl :	STD_LOGIC;
	 SIGNAL  nl1iOO :	STD_LOGIC;
	 SIGNAL  nl1l0i :	STD_LOGIC;
	 SIGNAL  nl1l0l :	STD_LOGIC;
	 SIGNAL  nl1l0O :	STD_LOGIC;
	 SIGNAL  nl1l1i :	STD_LOGIC;
	 SIGNAL  nl1l1l :	STD_LOGIC;
	 SIGNAL  nl1l1O :	STD_LOGIC;
	 SIGNAL  nl1lii :	STD_LOGIC;
	 SIGNAL  nl1lil :	STD_LOGIC;
	 SIGNAL  nl1liO :	STD_LOGIC;
	 SIGNAL  nl1lli :	STD_LOGIC;
	 SIGNAL  nl1lll :	STD_LOGIC;
	 SIGNAL  nl1llO :	STD_LOGIC;
	 SIGNAL  nl1lOi :	STD_LOGIC;
	 SIGNAL  nl1lOl :	STD_LOGIC;
	 SIGNAL  nl1O0i :	STD_LOGIC;
	 SIGNAL  nl1O0l :	STD_LOGIC;
	 SIGNAL  nl1O0O :	STD_LOGIC;
	 SIGNAL  nl1OiO :	STD_LOGIC;
	 SIGNAL  nl1Oli :	STD_LOGIC;
	 SIGNAL  nl1OOi :	STD_LOGIC;
	 SIGNAL  wire_w_rwait_count_range75w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rwait_count_range73w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rwait_count_range70w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_sudi_range87w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_sudi_range89w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_gnd <= '0';
	wire_vcc <= '1';
	wire_w_lg_w97w98w(0) <= wire_w97w(0) AND wire_n0il_o;
	wire_w97w(0) <= wire_w_lg_w_lg_w_lg_w_lg_w_sudi_range87w88w91w93w96w(0) AND nl0iiO;
	wire_w_lg_w_lg_w_lg_w_lg_w_sudi_range87w88w91w93w96w(0) <= wire_w_lg_w_lg_w_lg_w_sudi_range87w88w91w93w(0) AND wire_nl00ii22_w_lg_q95w(0);
	wire_w_lg_w_lg_w_lg_w_sudi_range87w88w91w93w(0) <= wire_w_lg_w_lg_w_sudi_range87w88w91w(0) AND wire_w_lg_nl00li92w(0);
	wire_w_lg_w_lg_riei_eios_priority_dis4w5w(0) <= wire_w_lg_riei_eios_priority_dis4w(0) AND eiosdetect_int;
	wire_w_lg_w_lg_w_sudi_range87w88w91w(0) <= wire_w_lg_w_sudi_range87w88w(0) AND wire_w_lg_w_sudi_range89w90w(0);
	wire_w_lg_niOO1O508w(0) <= NOT niOO1O;
	wire_w_lg_niOOil368w(0) <= NOT niOOil;
	wire_w_lg_niOOli370w(0) <= NOT niOOli;
	wire_w_lg_nl0iiO28w(0) <= NOT nl0iiO;
	wire_w_lg_reidleinferenable365w(0) <= NOT reidleinferenable;
	wire_w_lg_riei_eios_priority_dis4w(0) <= NOT riei_eios_priority_dis;
	wire_w_lg_rxpcsrst2w(0) <= NOT rxpcsrst;
	wire_w_lg_w_sudi_range87w88w(0) <= NOT wire_w_sudi_range87w(0);
	wire_w_lg_w_sudi_range89w90w(0) <= NOT wire_w_sudi_range89w(0);
	wire_w_lg_w_lg_w284w288w289w(0) <= wire_w_lg_w284w288w(0) OR nl1i0i;
	wire_w_lg_w284w288w(0) <= wire_w284w(0) OR wire_ni_w_lg_w_lg_nil1O221w287w(0);
	wire_w284w(0) <= wire_w_lg_w_lg_w_lg_w_lg_w_lg_w263w267w271w275w276w280w(0) OR wire_ni_w_lg_w_lg_nil1O221w283w(0);
	wire_w_lg_w_lg_w_lg_w_lg_w_lg_w263w267w271w275w276w280w(0) <= wire_w_lg_w_lg_w_lg_w_lg_w263w267w271w275w276w(0) OR wire_ni_w_lg_w_lg_nil1O221w279w(0);
	wire_w_lg_w_lg_w_lg_w_lg_w263w267w271w275w276w(0) <= wire_w_lg_w_lg_w_lg_w263w267w271w275w(0) OR nl1ill;
	wire_w_lg_w_lg_w_lg_w263w267w271w275w(0) <= wire_w_lg_w_lg_w263w267w271w(0) OR wire_ni_w_lg_w_lg_nil1O221w274w(0);
	wire_w_lg_w_lg_w263w267w271w(0) <= wire_w_lg_w263w267w(0) OR wire_ni_w_lg_w_lg_nil1O221w270w(0);
	wire_w_lg_w263w267w(0) <= wire_w263w(0) OR wire_ni_w_lg_w_lg_nil1O221w266w(0);
	wire_w263w(0) <= wire_w_lg_w_lg_w_lg_w_lg_w_lg_w242w246w247w251w255w259w(0) OR wire_ni_w_lg_w_lg_nil1O221w262w(0);
	wire_w_lg_w_lg_w_lg_w_lg_w_lg_w242w246w247w251w255w259w(0) <= wire_w_lg_w_lg_w_lg_w_lg_w242w246w247w251w255w(0) OR wire_ni_w_lg_w_lg_nil1O221w258w(0);
	wire_w_lg_w_lg_w_lg_w_lg_w242w246w247w251w255w(0) <= wire_w_lg_w_lg_w_lg_w242w246w247w251w(0) OR wire_ni_w_lg_w_lg_nil1O221w254w(0);
	wire_w_lg_w_lg_w_lg_w242w246w247w251w(0) <= wire_w_lg_w_lg_w242w246w247w(0) OR wire_ni_w_lg_w_lg_nil1O221w250w(0);
	wire_w_lg_w_lg_w242w246w247w(0) <= wire_w_lg_w242w246w(0) OR nl1lll;
	wire_w_lg_w242w246w(0) <= wire_w242w(0) OR wire_ni_w_lg_w_lg_nil1O221w245w(0);
	wire_w242w(0) <= wire_w_lg_w_lg_w_lg_w_lg_w_lg_w216w220w229w230w237w241w(0) OR nl1lOl;
	wire_w_lg_w_lg_w_lg_w_lg_w_lg_w216w220w229w230w237w241w(0) <= wire_w_lg_w_lg_w_lg_w_lg_w216w220w229w230w237w(0) OR wire_nl1lOO48_w_lg_w_lg_q239w240w(0);
	wire_w_lg_w_lg_w_lg_w_lg_w216w220w229w230w237w(0) <= wire_w_lg_w_lg_w_lg_w216w220w229w230w(0) OR wire_ni_w_lg_w_lg_w_lg_nil1O221w233w236w(0);
	wire_w_lg_w_lg_w_lg_w216w220w229w230w(0) <= wire_w_lg_w_lg_w216w220w229w(0) OR nl1O0O;
	wire_w_lg_w_lg_w216w220w229w(0) <= wire_w_lg_w216w220w(0) OR wire_ni_w_lg_w_lg_w_lg_nil1O221w225w228w(0);
	wire_w_lg_w216w220w(0) <= wire_w216w(0) OR wire_nl1Oll42_w_lg_w_lg_q218w219w(0);
	wire_w216w(0) <= wire_w_lg_w_lg_w_lg_w_lg_nl010i206w210w211w215w(0) OR nl1OOi;
	wire_w_lg_w_lg_w_lg_w_lg_nl010i206w210w211w215w(0) <= wire_w_lg_w_lg_w_lg_nl010i206w210w211w(0) OR wire_nl1OOl40_w_lg_w_lg_q213w214w(0);
	wire_w_lg_w_lg_w_lg_w_lg_nl1OOi337w341w345w346w(0) <= wire_w_lg_w_lg_w_lg_nl1OOi337w341w345w(0) OR nl1lOl;
	wire_w_lg_w_lg_w_lg_nl010i206w210w211w(0) <= wire_w_lg_w_lg_nl010i206w210w(0) OR nl011i;
	wire_w_lg_w_lg_w_lg_nl1OOi337w341w345w(0) <= wire_w_lg_w_lg_nl1OOi337w341w(0) OR wire_ni_w_lg_w_lg_nii0O200w344w(0);
	wire_w_lg_w_lg_nl010i206w210w(0) <= wire_w_lg_nl010i206w(0) OR wire_nl011l38_w_lg_w_lg_q208w209w(0);
	wire_w_lg_w_lg_nl1OOi337w341w(0) <= wire_w_lg_nl1OOi337w(0) OR wire_ni_w_lg_w_lg_nii0O200w340w(0);
	wire_w_lg_nl00li92w(0) <= nl00li OR nl00iO;
	wire_w_lg_nl010i206w(0) <= nl010i OR nl010O;
	wire_w_lg_nl110l342w(0) <= nl110l OR nl110i;
	wire_w_lg_nl11ii338w(0) <= nl11ii OR nl110O;
	wire_w_lg_nl11iO334w(0) <= nl11iO OR nl11il;
	wire_w_lg_nl1i0O285w(0) <= nl1i0O OR nl1i0l;
	wire_w_lg_nl1iil281w(0) <= nl1iil OR nl1iii;
	wire_w_lg_nl1ili277w(0) <= nl1ili OR nl1iiO;
	wire_w_lg_nl1iOi272w(0) <= nl1iOi OR nl1ilO;
	wire_w_lg_nl1iOO268w(0) <= nl1iOO OR nl1iOl;
	wire_w_lg_nl1l0i260w(0) <= nl1l0i OR nl1l1O;
	wire_w_lg_nl1l0O256w(0) <= nl1l0O OR nl1l0l;
	wire_w_lg_nl1l1l264w(0) <= nl1l1l OR nl1l1i;
	wire_w_lg_nl1lil252w(0) <= nl1lil OR nl1lii;
	wire_w_lg_nl1lli248w(0) <= nl1lli OR nl1liO;
	wire_w_lg_nl1lOi243w(0) <= nl1lOi OR nl1llO;
	wire_w_lg_nl1O0l231w(0) <= nl1O0l OR nl1O0i;
	wire_w_lg_nl1Oli223w(0) <= nl1Oli OR nl1OiO;
	wire_w_lg_nl1OOi337w(0) <= nl1OOi OR wire_ni_w_lg_w_lg_nii0O200w336w(0);
	niOi0i <= (nll10i OR niOiii);
	niOi1l <= ((wire_nli10i_o(6) OR wire_nli10i_o(2)) OR wire_nli10i_o(0));
	niOi1O <= (((((((((((((((wire_ni_w_lg_nlii0i982w(0) AND wire_ni_w_lg_nlii1O983w(0)) AND wire_ni_w_lg_nlii1i985w(0)) AND wire_ni_w_lg_nli0OO987w(0)) AND wire_ni_w_lg_nli0ll989w(0)) AND (NOT (nliO1l XOR nlii1l))) AND (NOT (nliO1O XOR nlii0l))) AND (NOT (nliO0i XOR nlii0O))) AND (NOT (nliO0l XOR nliiii))) AND (NOT (nliO0O XOR nliiil))) AND (NOT (nliOii XOR nliiiO))) AND (NOT (nliOil XOR nliili))) AND (NOT (nliOiO XOR nliill))) AND (NOT (nliOli XOR nliilO))) AND (NOT (nliOll XOR nliiOi))) AND (NOT (nliOOi XOR nliiOl)));
	niOiii <= (nl0OlO OR nl0lOO);
	niOiil <= (wire_ni_w_lg_w_lg_w808w809w860w(0) AND wire_ni_w_lg_niiii755w(0));
	niOiiO <= ((wire_ni_w_lg_w_lg_w764w804w805w(0) AND wire_ni_w_lg_niiil753w(0)) AND niiii);
	niOili <= ((wire_ni_w_lg_w772w774w(0) AND wire_ni_w_lg_niiil753w(0)) AND niiii);
	niOill <= (wire_ni_w_lg_w_lg_w_lg_w829w830w831w897w(0) AND wire_ni_w_lg_niiii755w(0));
	niOilO <= (wire_ni_w_lg_w_lg_w772w774w775w(0) AND wire_ni_w_lg_niiii755w(0));
	niOiOi <= ((wire_ni_w_lg_w_lg_w829w830w831w(0) AND wire_ni_w_lg_niiil753w(0)) AND niiii);
	niOiOl <= ((wire_ni_w_lg_w772w880w(0) AND wire_ni_w_lg_niiil753w(0)) AND wire_ni_w_lg_niiii755w(0));
	niOiOO <= (wire_ni_w_lg_w_lg_w_lg_w829w830w842w843w(0) AND niiii);
	niOl0i <= (wire_ni_w_lg_w_lg_w_lg_w829w852w853w854w(0) AND niiii);
	niOl0l <= (((wire_ni_w800w(0) AND wire_ni_w_lg_niiiO773w(0)) AND wire_ni_w_lg_niiil753w(0)) AND niiii);
	niOl0O <= (wire_ni_w_lg_w_lg_w_lg_w764w765w766w796w(0) AND wire_ni_w_lg_niiii755w(0));
	niOl1i <= (wire_ni_w_lg_w_lg_w_lg_w829w852w853w854w(0) AND wire_ni_w_lg_niiii755w(0));
	niOl1l <= (wire_ni_w_lg_w_lg_w867w868w869w(0) AND wire_ni_w_lg_niiii755w(0));
	niOl1O <= (((wire_ni_w856w(0) AND wire_ni_w_lg_niiiO773w(0)) AND wire_ni_w_lg_niiil753w(0)) AND wire_ni_w_lg_niiii755w(0));
	niOlii <= ((wire_ni_w_lg_w_lg_w764w765w766w(0) AND wire_ni_w_lg_niiil753w(0)) AND wire_ni_w_lg_niiii755w(0));
	niOlil <= ((wire_ni_w_lg_w751w752w(0) AND wire_ni_w_lg_niiil753w(0)) AND wire_ni_w_lg_niiii755w(0));
	niOliO <= (((((wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i548w549w551w608w(0) AND wire_ni_w_lg_ni0Ol553w(0)) AND wire_ni_w_lg_ni0Oi555w(0)) AND wire_ni_w_lg_ni0lO565w(0)) AND ni0ll) AND ni0li);
	niOlli <= ((wire_ni_w_lg_w_lg_w603w604w605w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND wire_ni_w_lg_ni0li568w(0));
	niOlll <= (((wire_ni_w591w(0) AND wire_ni_w_lg_ni0lO565w(0)) AND wire_ni_w_lg_ni0ll558w(0)) AND wire_ni_w_lg_ni0li568w(0));
	niOllO <= ((((wire_ni_w581w(0) AND wire_ni_w_lg_ni0Oi555w(0)) AND ni0lO) AND ni0ll) AND ni0li);
	niOlOi <= (wire_ni_w_lg_w_lg_w564w566w567w(0) AND wire_ni_w_lg_ni0li568w(0));
	niOlOl <= (wire_ni_w_lg_w_lg_w564w566w567w(0) AND wire_ni_w_lg_ni0li568w(0));
	niOlOO <= ((wire_ni_w_lg_w556w557w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND ni0li);
	niOO0i <= (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (niOlOl OR niOlOi)));
	niOO0l <= (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (niOO1i OR niOlOO)));
	niOO0O <= (niOOll AND wire_w_lg_niOOli370w(0));
	niOO1i <= ((wire_ni_w_lg_w556w557w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND ni0li);
	niOO1l <= ((((((((((((((((((((((((ni0ii OR ni00O) OR ni00l) OR ni00i) OR ni01O) OR ni01l) OR ni01i) OR ni1OO) OR ni1Ol) OR ni1Oi) OR ni1lO) OR ni1ll) OR ni1li) OR ni1iO) OR ni1il) OR ni1ii) OR ni10l) OR ni10i) OR ni11O) OR ni11l) OR ni11i) OR n0OOO) OR n0OOl) OR n0OOi) OR n1OlO);
	niOO1O <= ((((((((((((((((((((((((ni0ii OR ni00O) OR ni00l) OR ni00i) OR ni01O) OR ni01l) OR ni1Ol) OR ni1Oi) OR ni1lO) OR ni1ll) OR ni1li) OR ni1iO) OR ni1il) OR ni1ii) OR ni10O) OR ni10l) OR ni10i) OR ni11O) OR ni11l) OR ni11i) OR n0OOO) OR n0OOl) OR n0OOi) OR n0OlO) OR n1OlO);
	niOOii <= (niOOll AND niOOli);
	niOOil <= (ni0iO AND (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (niOlli OR niOliO))));
	niOOiO <= (wire_w_lg_reidleinferenable365w(0) OR wire_ni_w_lg_ni0il366w(0));
	niOOli <= ((((nl010i OR nl011i) OR nl1OOi) OR nl1O0O) OR nl1lll);
	niOOll <= ((((((nl010i OR nl011i) OR nl1OOi) OR nl1O0O) OR nl1lll) OR nl1ill) OR nl1i0i);
	niOOlO <= (((wire_w_lg_w_lg_w_lg_w_lg_nl1OOi337w341w345w346w(0) OR (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (nl111O OR nl111l)))) OR (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (nl111i OR niOOOO)))) OR (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (niOOOl OR niOOOi))));
	niOOOi <= (wire_ni_w_lg_w_lg_w_lg_w617w618w619w620w(0) AND wire_ni_w_lg_ni0li568w(0));
	niOOOl <= (wire_ni_w_lg_w_lg_w_lg_w617w618w619w620w(0) AND wire_ni_w_lg_ni0li568w(0));
	niOOOO <= (wire_ni_w_lg_w_lg_w_lg_w631w632w633w634w(0) AND wire_ni_w_lg_ni0li568w(0));
	nl000i <= (wire_w_lg_w97w98w(0) AND (nl000l24 XOR nl000l23));
	nl00iO <= (((((((((((NOT sudi(0)) AND (NOT sudi(1))) AND sudi(2)) AND sudi(3)) AND sudi(4)) AND sudi(5)) AND sudi(6)) AND (NOT sudi(7))) AND sudi(8)) AND (NOT sudi(9))) AND (nl01iO34 XOR nl01iO33));
	nl00li <= ((((((((((sudi(0) AND sudi(1)) AND (NOT sudi(2))) AND (NOT sudi(3))) AND (NOT sudi(4))) AND (NOT sudi(5))) AND (NOT sudi(6))) AND sudi(7)) AND (NOT sudi(8))) AND sudi(9)) AND (nl01ll32 XOR nl01ll31));
	nl00OO <= (wire_n1l_dataout AND wire_w_lg_nl0iiO28w(0));
	nl010i <= (wire_ni_w_lg_nil1O221w(0) AND (wire_ni_w_lg_nil1l222w(0) AND (niOiiO OR niOiil)));
	nl010l <= ((((wire_ni_w_lg_nii0l197w(0) AND wire_ni_w_lg_ni0iO198w(0)) AND wire_ni_w_lg_nii0O200w(0)) AND (nl01ii36 XOR nl01ii35)) OR nl010O);
	nl010O <= (ni0iO AND (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (niOllO OR niOlll))));
	nl011i <= (wire_ni_w_lg_nil1O221w(0) AND (wire_ni_w_lg_nil1l222w(0) AND (niOill OR niOili)));
	nl0i0O <= (wire_n1l_dataout AND wire_nlli_w_lg_nliO18w(0));
	nl0i1O <= ((NOT (n1Ol XOR reidle_com_detect(0))) AND (NOT (n1OO XOR reidle_com_detect(1))));
	nl0iiO <= ((((((((NOT (n01i XOR rwait_count(0))) AND (NOT (wire_ni1l_w_lg_n0ll115w(0) XOR (NOT (nl001l26 XOR nl001l25))))) AND (NOT (n0lO XOR rwait_count(2)))) AND (NOT (wire_ni1l_w_lg_n0Oi125w(0) XOR (NOT (nl01OO28 XOR nl01OO27))))) AND (NOT (n0Ol XOR rwait_count(4)))) AND (NOT (n0OO XOR rwait_count(5)))) AND (NOT (wire_ni1l_w_lg_ni1i138w(0) XOR (NOT (nl01Oi30 XOR nl01Oi29))))) AND (NOT (ni1O XOR rwait_count(7))));
	nl0ilO <= '1';
	nl100i <= ((wire_ni_w_lg_w699w700w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND wire_ni_w_lg_ni0li568w(0));
	nl100l <= ((wire_ni_w_lg_w690w707w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND wire_ni_w_lg_ni0li568w(0));
	nl100O <= (wire_ni_w_lg_w_lg_w_lg_w683w684w704w705w(0) AND ni0li);
	nl101i <= (wire_ni_w_lg_w_lg_w690w691w696w(0) AND wire_ni_w_lg_ni0li568w(0));
	nl101l <= ((wire_ni_w_lg_w_lg_w683w684w685w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND ni0li);
	nl101O <= ((wire_ni_w_lg_w_lg_w683w684w685w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND wire_ni_w_lg_ni0li568w(0));
	nl10ii <= (wire_ni_w_lg_w_lg_w_lg_w683w684w704w705w(0) AND wire_ni_w_lg_ni0li568w(0));
	nl10il <= (wire_ni_w_lg_w_lg_w699w710w711w(0) AND wire_ni_w_lg_ni0li568w(0));
	nl10iO <= ((wire_ni_w_lg_w_lg_w683w684w704w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND ni0li);
	nl10li <= ((wire_ni_w_lg_w699w710w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND ni0li);
	nl10ll <= ((wire_ni_w_lg_w678w721w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND wire_ni_w_lg_ni0li568w(0));
	nl10lO <= (((wire_ni_w_lg_w669w670w(0) AND wire_ni_w_lg_ni0lO565w(0)) AND ni0ll) AND ni0li);
	nl10Oi <= (((wire_ni_w728w(0) AND wire_ni_w_lg_ni0lO565w(0)) AND wire_ni_w_lg_ni0ll558w(0)) AND wire_ni_w_lg_ni0li568w(0));
	nl10Ol <= (wire_ni_w_lg_w_lg_w_lg_w683w724w725w726w(0) AND ni0li);
	nl10OO <= (wire_ni_w_lg_w_lg_w_lg_w683w724w725w726w(0) AND wire_ni_w_lg_ni0li568w(0));
	nl110i <= (wire_ni_w_lg_w_lg_w_lg_w643w644w645w646w(0) AND wire_ni_w_lg_ni0li568w(0));
	nl110l <= ((wire_ni_w_lg_w_lg_w617w638w639w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND ni0li);
	nl110O <= (wire_ni_w_lg_w_lg_w654w655w656w(0) AND wire_ni_w_lg_ni0li568w(0));
	nl111i <= (wire_ni_w_lg_w_lg_w625w626w627w(0) AND wire_ni_w_lg_ni0li568w(0));
	nl111l <= (wire_ni_w_lg_w_lg_w556w557w636w(0) AND wire_ni_w_lg_ni0li568w(0));
	nl111O <= (wire_ni_w_lg_w_lg_w556w557w636w(0) AND wire_ni_w_lg_ni0li568w(0));
	nl11ii <= ((wire_ni_w_lg_w_lg_w631w648w649w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND ni0li);
	nl11il <= (wire_ni_w_lg_w_lg_w662w663w664w(0) AND wire_ni_w_lg_ni0li568w(0));
	nl11iO <= ((wire_ni_w_lg_w564w658w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND ni0li);
	nl11li <= ((wire_ni_w_lg_nii0l197w(0) AND wire_ni_w_lg_ni0iO198w(0)) AND wire_ni_w_lg_nii0O200w(0));
	nl11ll <= (((((((((((wire_w_lg_w_lg_w284w288w289w(0) OR (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (nl1i1O OR nl1i1l)))) OR (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (nl1i1i OR nl10OO)))) OR (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (nl10Ol OR nl10Oi)))) OR (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (nl10lO OR nl10ll)))) OR (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (nl10li OR nl10iO)))) OR (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (nl10il OR nl10ii)))) OR (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (nl100O OR nl100l)))) OR (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (nl100i OR nl101O)))) OR (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (nl101l OR nl101i)))) OR (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (nl11OO OR nl11Ol)))) OR (wire_ni_w_lg_nii0O200w(0) AND (wire_ni_w_lg_nii0l197w(0) AND (nl11Oi OR nl11lO))));
	nl11lO <= (wire_ni_w_lg_w_lg_w678w679w680w(0) AND wire_ni_w_lg_ni0li568w(0));
	nl11Oi <= ((wire_ni_w_lg_w_lg_w669w670w671w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND ni0li);
	nl11Ol <= ((wire_ni_w_lg_w690w691w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND ni0li);
	nl11OO <= (wire_ni_w_lg_w_lg_w_lg_w683w684w685w686w(0) AND wire_ni_w_lg_ni0li568w(0));
	nl1i0i <= (wire_ni_w_lg_nil1O221w(0) AND (wire_ni_w_lg_nil1l222w(0) AND (niOlil OR niOlii)));
	nl1i0l <= ((((wire_ni_w778w(0) AND wire_ni_w_lg_niili750w(0)) AND wire_ni_w_lg_niiiO773w(0)) AND niiil) AND niiii);
	nl1i0O <= (wire_ni_w_lg_w_lg_w772w774w775w(0) AND niiii);
	nl1i1i <= (wire_ni_w_lg_w_lg_w732w733w734w(0) AND wire_ni_w_lg_ni0li568w(0));
	nl1i1l <= ((wire_ni_w_lg_w_lg_w683w724w725w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND ni0li);
	nl1i1O <= ((wire_ni_w_lg_w732w733w(0) AND wire_ni_w_lg_ni0ll558w(0)) AND ni0li);
	nl1iii <= (wire_ni_w_lg_w_lg_w_lg_w764w765w786w787w(0) AND wire_ni_w_lg_niiii755w(0));
	nl1iil <= (wire_ni_w_lg_w_lg_w751w783w784w(0) AND wire_ni_w_lg_niiii755w(0));
	nl1iiO <= ((wire_ni_w_lg_w_lg_w764w765w786w(0) AND wire_ni_w_lg_niiil753w(0)) AND niiii);
	nl1ili <= ((wire_ni_w_lg_w751w783w(0) AND wire_ni_w_lg_niiil753w(0)) AND niiii);
	nl1ill <= (wire_ni_w_lg_nil1O221w(0) AND (wire_ni_w_lg_nil1l222w(0) AND (niOl0O OR niOl0l)));
	nl1ilO <= ((wire_ni_w_lg_w808w809w(0) AND wire_ni_w_lg_niiil753w(0)) AND niiii);
	nl1iOi <= (wire_ni_w_lg_w_lg_w_lg_w764w804w805w806w(0) AND wire_ni_w_lg_niiii755w(0));
	nl1iOl <= (wire_ni_w_lg_w_lg_w_lg_w815w816w817w818w(0) AND wire_ni_w_lg_niiii755w(0));
	nl1iOO <= (wire_ni_w_lg_w_lg_w800w812w813w(0) AND wire_ni_w_lg_niiii755w(0));
	nl1l0i <= ((wire_ni_w_lg_w825w826w(0) AND wire_ni_w_lg_niiil753w(0)) AND wire_ni_w_lg_niiii755w(0));
	nl1l0l <= (((wire_ni_w_lg_w815w816w(0) AND wire_ni_w_lg_niiiO773w(0)) AND niiil) AND niiii);
	nl1l0O <= (((wire_ni_w800w(0) AND wire_ni_w_lg_niiiO773w(0)) AND niiil) AND niiii);
	nl1l1i <= ((wire_ni_w_lg_w_lg_w815w816w817w(0) AND wire_ni_w_lg_niiil753w(0)) AND niiii);
	nl1l1l <= ((wire_ni_w_lg_w800w812w(0) AND wire_ni_w_lg_niiil753w(0)) AND niiii);
	nl1l1O <= ((wire_ni_w_lg_w_lg_w829w830w831w(0) AND wire_ni_w_lg_niiil753w(0)) AND wire_ni_w_lg_niiii755w(0));
	nl1lii <= (wire_ni_w_lg_w_lg_w_lg_w829w830w842w843w(0) AND wire_ni_w_lg_niiii755w(0));
	nl1lil <= (wire_ni_w_lg_w_lg_w825w839w840w(0) AND wire_ni_w_lg_niiii755w(0));
	nl1liO <= ((wire_ni_w_lg_w_lg_w829w830w842w(0) AND wire_ni_w_lg_niiil753w(0)) AND niiii);
	nl1lli <= ((wire_ni_w_lg_w825w839w(0) AND wire_ni_w_lg_niiil753w(0)) AND niiii);
	nl1lll <= (wire_ni_w_lg_nil1O221w(0) AND (wire_ni_w_lg_nil1l222w(0) AND (niOl0i OR niOl1O)));
	nl1llO <= ((wire_ni_w_lg_w_lg_w764w804w805w(0) AND wire_ni_w_lg_niiil753w(0)) AND wire_ni_w_lg_niiii755w(0));
	nl1lOi <= (wire_ni_w_lg_w_lg_w808w809w860w(0) AND niiii);
	nl1lOl <= (wire_ni_w_lg_nil1O221w(0) AND (wire_ni_w_lg_nil1l222w(0) AND (niOl1l OR niOl1i)));
	nl1O0i <= ((wire_ni_w_lg_w_lg_w829w852w853w(0) AND wire_ni_w_lg_niiil753w(0)) AND niiii);
	nl1O0l <= ((wire_ni_w_lg_w867w868w(0) AND wire_ni_w_lg_niiil753w(0)) AND niiii);
	nl1O0O <= (wire_ni_w_lg_nil1O221w(0) AND (wire_ni_w_lg_nil1l222w(0) AND (niOiOO OR niOiOl)));
	nl1OiO <= (((wire_ni_w_lg_w829w852w(0) AND wire_ni_w_lg_niiiO773w(0)) AND niiil) AND niiii);
	nl1Oli <= (((wire_ni_w867w(0) AND wire_ni_w_lg_niiiO773w(0)) AND niiil) AND niiii);
	nl1OOi <= (wire_ni_w_lg_nil1O221w(0) AND (wire_ni_w_lg_nil1l222w(0) AND (niOiOi OR niOilO)));
	rxelecidle_int <= wire_n1l_dataout;
	wire_w_rwait_count_range75w(0) <= rwait_count(1);
	wire_w_rwait_count_range73w(0) <= rwait_count(3);
	wire_w_rwait_count_range70w(0) <= rwait_count(6);
	wire_w_sudi_range87w(0) <= sudi(10);
	wire_w_sudi_range89w(0) <= sudi(12);
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niOi0l51 <= niOi0l52;
		END IF;
		if (now = 0 ns) then
			niOi0l51 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niOi0l52 <= niOi0l51;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niOi0O49 <= niOi0O50;
		END IF;
		if (now = 0 ns) then
			niOi0O49 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niOi0O50 <= niOi0O49;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl000l23 <= nl000l24;
		END IF;
		if (now = 0 ns) then
			nl000l23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl000l24 <= nl000l23;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl001l25 <= nl001l26;
		END IF;
		if (now = 0 ns) then
			nl001l25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl001l26 <= nl001l25;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl00ii21 <= nl00ii22;
		END IF;
		if (now = 0 ns) then
			nl00ii21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl00ii22 <= nl00ii21;
		END IF;
	END PROCESS;
	wire_nl00ii22_w_lg_q95w(0) <= nl00ii22 XOR nl00ii21;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl00ll19 <= nl00ll20;
		END IF;
		if (now = 0 ns) then
			nl00ll19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl00ll20 <= nl00ll19;
		END IF;
	END PROCESS;
	wire_nl00ll20_w_lg_w_lg_q76w77w(0) <= wire_nl00ll20_w_lg_q76w(0) AND n1Ol;
	wire_nl00ll20_w_lg_q76w(0) <= nl00ll20 XOR nl00ll19;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl00lO17 <= nl00lO18;
		END IF;
		if (now = 0 ns) then
			nl00lO17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl00lO18 <= nl00lO17;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl00Oi15 <= nl00Oi16;
		END IF;
		if (now = 0 ns) then
			nl00Oi15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl00Oi16 <= nl00Oi15;
		END IF;
	END PROCESS;
	wire_nl00Oi16_w_lg_w_lg_q39w40w(0) <= wire_nl00Oi16_w_lg_q39w(0) AND ni1i;
	wire_nl00Oi16_w_lg_q39w(0) <= nl00Oi16 XOR nl00Oi15;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl00Ol13 <= nl00Ol14;
		END IF;
		if (now = 0 ns) then
			nl00Ol13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl00Ol14 <= nl00Ol13;
		END IF;
	END PROCESS;
	wire_nl00Ol14_w_lg_w_lg_q30w31w(0) <= wire_nl00Ol14_w_lg_q30w(0) AND n01i;
	wire_nl00Ol14_w_lg_q30w(0) <= nl00Ol14 XOR nl00Ol13;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl011l37 <= nl011l38;
		END IF;
		if (now = 0 ns) then
			nl011l37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl011l38 <= nl011l37;
		END IF;
	END PROCESS;
	wire_nl011l38_w_lg_w_lg_q208w209w(0) <= NOT wire_nl011l38_w_lg_q208w(0);
	wire_nl011l38_w_lg_q208w(0) <= nl011l38 XOR nl011l37;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl01ii35 <= nl01ii36;
		END IF;
		if (now = 0 ns) then
			nl01ii35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl01ii36 <= nl01ii35;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl01iO33 <= nl01iO34;
		END IF;
		if (now = 0 ns) then
			nl01iO33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl01iO34 <= nl01iO33;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl01ll31 <= nl01ll32;
		END IF;
		if (now = 0 ns) then
			nl01ll31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl01ll32 <= nl01ll31;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl01Oi29 <= nl01Oi30;
		END IF;
		if (now = 0 ns) then
			nl01Oi29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl01Oi30 <= nl01Oi29;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl01OO27 <= nl01OO28;
		END IF;
		if (now = 0 ns) then
			nl01OO27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl01OO28 <= nl01OO27;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl0i0i10 <= nl0i0i9;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl0i0i9 <= nl0i0i10;
		END IF;
		if (now = 0 ns) then
			nl0i0i9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl0i0l7 <= nl0i0l8;
		END IF;
		if (now = 0 ns) then
			nl0i0l7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl0i0l8 <= nl0i0l7;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl0i1i11 <= nl0i1i12;
		END IF;
		if (now = 0 ns) then
			nl0i1i11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl0i1i12 <= nl0i1i11;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl0iii5 <= nl0iii6;
		END IF;
		if (now = 0 ns) then
			nl0iii5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl0iii6 <= nl0iii5;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl0ili3 <= nl0ili4;
		END IF;
		if (now = 0 ns) then
			nl0ili3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl0ili4 <= nl0ili3;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl0iOi1 <= nl0iOi2;
		END IF;
		if (now = 0 ns) then
			nl0iOi1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl0iOi2 <= nl0iOi1;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl1lOO47 <= nl1lOO48;
		END IF;
		if (now = 0 ns) then
			nl1lOO47 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl1lOO48 <= nl1lOO47;
		END IF;
	END PROCESS;
	wire_nl1lOO48_w_lg_w_lg_q239w240w(0) <= NOT wire_nl1lOO48_w_lg_q239w(0);
	wire_nl1lOO48_w_lg_q239w(0) <= nl1lOO48 XOR nl1lOO47;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl1O1l45 <= nl1O1l46;
		END IF;
		if (now = 0 ns) then
			nl1O1l45 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl1O1l46 <= nl1O1l45;
		END IF;
	END PROCESS;
	wire_nl1O1l46_w_lg_q235w(0) <= nl1O1l46 XOR nl1O1l45;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl1Oii43 <= nl1Oii44;
		END IF;
		if (now = 0 ns) then
			nl1Oii43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl1Oii44 <= nl1Oii43;
		END IF;
	END PROCESS;
	wire_nl1Oii44_w_lg_q227w(0) <= nl1Oii44 XOR nl1Oii43;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl1Oll41 <= nl1Oll42;
		END IF;
		if (now = 0 ns) then
			nl1Oll41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl1Oll42 <= nl1Oll41;
		END IF;
	END PROCESS;
	wire_nl1Oll42_w_lg_w_lg_q218w219w(0) <= NOT wire_nl1Oll42_w_lg_q218w(0);
	wire_nl1Oll42_w_lg_q218w(0) <= nl1Oll42 XOR nl1Oll41;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl1OOl39 <= nl1OOl40;
		END IF;
		if (now = 0 ns) then
			nl1OOl39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nl1OOl40 <= nl1OOl39;
		END IF;
	END PROCESS;
	wire_nl1OOl40_w_lg_w_lg_q213w214w(0) <= NOT wire_nl1OOl40_w_lg_q213w(0);
	wire_nl1OOl40_w_lg_q213w(0) <= nl1OOl40 XOR nl1OOl39;
	PROCESS (rcvd_clk, wire_ni_CLRN)
	BEGIN
		IF (wire_ni_CLRN = '0') THEN
				n0l <= '0';
				n0OlO <= '0';
				n0OOi <= '0';
				n0OOl <= '0';
				n0OOO <= '0';
				n1Ol <= '0';
				n1OlO <= '0';
				n1OO <= '0';
				ni00i <= '0';
				ni00l <= '0';
				ni00O <= '0';
				ni01i <= '0';
				ni01l <= '0';
				ni01O <= '0';
				ni0i <= '0';
				ni0il <= '0';
				ni0iO <= '0';
				ni0li <= '0';
				ni0ll <= '0';
				ni0lO <= '0';
				ni0Oi <= '0';
				ni0Ol <= '0';
				ni0OO <= '0';
				ni10i <= '0';
				ni10l <= '0';
				ni10O <= '0';
				ni11i <= '0';
				ni11l <= '0';
				ni11O <= '0';
				ni1ii <= '0';
				ni1il <= '0';
				ni1iO <= '0';
				ni1li <= '0';
				ni1ll <= '0';
				ni1lO <= '0';
				ni1Oi <= '0';
				ni1Ol <= '0';
				ni1OO <= '0';
				nii0i <= '0';
				nii0l <= '0';
				nii0O <= '0';
				nii1i <= '0';
				nii1l <= '0';
				nii1O <= '0';
				niiii <= '0';
				niiil <= '0';
				niiiO <= '0';
				niili <= '0';
				niill <= '0';
				niilO <= '0';
				niiOi <= '0';
				niiOl <= '0';
				niiOO <= '0';
				nil1i <= '0';
				nil1l <= '0';
				nil1O <= '0';
				nl <= '0';
				nl0l0O <= '0';
				nl0lli <= '0';
				nl0O0i <= '0';
				nl0O0l <= '0';
				nl0O0O <= '0';
				nl0O1i <= '0';
				nl0O1l <= '0';
				nl0O1O <= '0';
				nl0Oii <= '0';
				nl0Oil <= '0';
				nl0OiO <= '0';
				nl0Oli <= '0';
				nl0Oll <= '0';
				nl0OlO <= '0';
				nli0ll <= '0';
				nli0Oi <= '0';
				nli0OO <= '0';
				nli10l <= '0';
				nli10O <= '0';
				nli1ii <= '0';
				nli1il <= '0';
				nli1iO <= '0';
				nli1li <= '0';
				nli1ll <= '0';
				nli1lO <= '0';
				nli1Oi <= '0';
				nlii0i <= '0';
				nlii0l <= '0';
				nlii0O <= '0';
				nlii1i <= '0';
				nlii1l <= '0';
				nlii1O <= '0';
				nliiii <= '0';
				nliiil <= '0';
				nliiiO <= '0';
				nliili <= '0';
				nliill <= '0';
				nliilO <= '0';
				nliiOi <= '0';
				nliiOl <= '0';
				nlil <= '0';
				nll <= '0';
				nlO <= '0';
		ELSIF (rcvd_clk = '1' AND rcvd_clk'event) THEN
				n0l <= nll;
				n0OlO <= wire_n1OiO_dataout;
				n0OOi <= wire_n1Oli_dataout;
				n0OOl <= wire_n1Oll_dataout;
				n0OOO <= wire_n1OOi_dataout;
				n1Ol <= wire_n01l_dataout;
				n1OlO <= wire_n1Oii_o;
				n1OO <= wire_n01O_dataout;
				ni00i <= wire_n001O_dataout;
				ni00l <= wire_n000i_dataout;
				ni00O <= wire_n000l_o;
				ni01i <= wire_n01OO_dataout;
				ni01l <= wire_n001i_dataout;
				ni01O <= wire_n001l_dataout;
				ni0i <= nl0i1O;
				ni0il <= syncstatus;
				ni0iO <= kflag;
				ni0li <= sudi(0);
				ni0ll <= sudi(1);
				ni0lO <= sudi(2);
				ni0Oi <= sudi(3);
				ni0Ol <= sudi(4);
				ni0OO <= sudi(5);
				ni10i <= wire_n011l_dataout;
				ni10l <= wire_n011O_dataout;
				ni10O <= wire_n010i_dataout;
				ni11i <= wire_n1OOl_dataout;
				ni11l <= wire_n1OOO_dataout;
				ni11O <= wire_n011i_dataout;
				ni1ii <= wire_n010l_dataout;
				ni1il <= wire_n010O_dataout;
				ni1iO <= wire_n01ii_dataout;
				ni1li <= wire_n01il_dataout;
				ni1ll <= wire_n01iO_dataout;
				ni1lO <= wire_n01li_dataout;
				ni1Oi <= wire_n01ll_dataout;
				ni1Ol <= wire_n01lO_o;
				ni1OO <= wire_n01Ol_dataout;
				nii0i <= sudi(9);
				nii0l <= sudi(10);
				nii0O <= sudi(12);
				nii1i <= sudi(6);
				nii1l <= sudi(7);
				nii1O <= sudi(8);
				niiii <= sudi(0);
				niiil <= sudi(1);
				niiiO <= sudi(2);
				niili <= sudi(3);
				niill <= sudi(4);
				niilO <= sudi(5);
				niiOi <= sudi(6);
				niiOl <= sudi(7);
				niiOO <= sudi(8);
				nil1i <= sudi(9);
				nil1l <= sudi(10);
				nil1O <= sudi(12);
				nl <= signaldetect;
				nl0l0O <= nl0lli;
				nl0lli <= wire_nl0lll_dataout;
				nl0O0i <= wire_nl0OOO_o(0);
				nl0O0l <= (wire_nli10i_o(6) OR wire_nli10i_o(5));
				nl0O0O <= ((wire_nli10i_o(2) OR wire_nli10i_o(0)) OR wire_nli10i_o(5));
				nl0O1i <= wire_nli10i_o(1);
				nl0O1l <= wire_nl0OOi_o(1);
				nl0O1O <= ((wire_nli10i_o(7) OR wire_nli10i_o(3)) OR wire_nli10i_o(1));
				nl0Oii <= niOi1l;
				nl0Oil <= niOi1l;
				nl0OiO <= niOi1l;
				nl0Oli <= niOi1l;
				nl0Oll <= wire_nli10i_o(6);
				nl0OlO <= (NOT (((NOT (nli1il XOR nli10l)) AND (NOT (nli1iO XOR nli10O))) AND (NOT (nli1li XOR nli1ii))));
				nli0ll <= wire_nliiOO_dataout;
				nli0Oi <= wire_nli0lO_dataout;
				nli0OO <= wire_nlil1i_dataout;
				nli10l <= nli1il;
				nli10O <= nli1iO;
				nli1ii <= nli1li;
				nli1il <= nli1ll;
				nli1iO <= nli1lO;
				nli1li <= nli1Oi;
				nli1ll <= eidleinfersel(0);
				nli1lO <= eidleinfersel(1);
				nli1Oi <= eidleinfersel(2);
				nlii0i <= wire_nlil0l_dataout;
				nlii0l <= wire_nlil0O_dataout;
				nlii0O <= wire_nlilii_dataout;
				nlii1i <= wire_nlil1l_dataout;
				nlii1l <= wire_nlil1O_dataout;
				nlii1O <= wire_nlil0i_dataout;
				nliiii <= wire_nlilil_dataout;
				nliiil <= wire_nliliO_dataout;
				nliiiO <= wire_nlilli_dataout;
				nliili <= wire_nlilll_dataout;
				nliill <= wire_nlillO_dataout;
				nliilO <= wire_nlilOi_dataout;
				nliiOi <= wire_nlilOl_dataout;
				nliiOl <= wire_nlilOO_dataout;
				nlil <= (wire_ni_w_lg_w_lg_ni0i23w24w(0) AND (nl0i1i12 XOR nl0i1i11));
				nll <= wire_nO_dataout;
				nlO <= nl;
		END IF;
	END PROCESS;
	wire_ni_CLRN <= ((nl0iOi2 XOR nl0iOi1) AND wire_w_lg_rxpcsrst2w(0));
	wire_ni_w_lg_w_lg_w_lg_w683w724w725w726w(0) <= wire_ni_w_lg_w_lg_w683w724w725w(0) AND ni0ll;
	wire_ni_w_lg_w_lg_w_lg_w683w684w704w705w(0) <= wire_ni_w_lg_w_lg_w683w684w704w(0) AND ni0ll;
	wire_ni_w_lg_w_lg_w_lg_w683w684w685w686w(0) <= wire_ni_w_lg_w_lg_w683w684w685w(0) AND ni0ll;
	wire_ni_w_lg_w_lg_w_lg_w631w632w633w634w(0) <= wire_ni_w_lg_w_lg_w631w632w633w(0) AND ni0ll;
	wire_ni_w_lg_w_lg_w_lg_w643w644w645w646w(0) <= wire_ni_w_lg_w_lg_w643w644w645w(0) AND ni0ll;
	wire_ni_w_lg_w_lg_w_lg_w617w618w619w620w(0) <= wire_ni_w_lg_w_lg_w617w618w619w(0) AND ni0ll;
	wire_ni_w_lg_w_lg_w_lg_w815w816w817w818w(0) <= wire_ni_w_lg_w_lg_w815w816w817w(0) AND niiil;
	wire_ni_w_lg_w_lg_w_lg_w829w852w853w854w(0) <= wire_ni_w_lg_w_lg_w829w852w853w(0) AND niiil;
	wire_ni_w_lg_w_lg_w_lg_w829w830w842w843w(0) <= wire_ni_w_lg_w_lg_w829w830w842w(0) AND niiil;
	wire_ni_w_lg_w_lg_w_lg_w829w830w831w897w(0) <= wire_ni_w_lg_w_lg_w829w830w831w(0) AND niiil;
	wire_ni_w_lg_w_lg_w_lg_w764w765w786w787w(0) <= wire_ni_w_lg_w_lg_w764w765w786w(0) AND niiil;
	wire_ni_w_lg_w_lg_w_lg_w764w765w766w796w(0) <= wire_ni_w_lg_w_lg_w764w765w766w(0) AND niiil;
	wire_ni_w_lg_w_lg_w_lg_w764w804w805w806w(0) <= wire_ni_w_lg_w_lg_w764w804w805w(0) AND niiil;
	wire_ni_w_lg_w_lg_w662w663w664w(0) <= wire_ni_w_lg_w662w663w(0) AND ni0ll;
	wire_ni_w_lg_w_lg_w556w557w636w(0) <= wire_ni_w_lg_w556w557w(0) AND ni0ll;
	wire_ni_w_lg_w_lg_w564w566w567w(0) <= wire_ni_w_lg_w564w566w(0) AND ni0ll;
	wire_ni_w_lg_w_lg_w654w655w656w(0) <= wire_ni_w_lg_w654w655w(0) AND ni0ll;
	wire_ni_w_lg_w_lg_w625w626w627w(0) <= wire_ni_w_lg_w625w626w(0) AND ni0ll;
	wire_ni_w_lg_w_lg_w678w679w680w(0) <= wire_ni_w_lg_w678w679w(0) AND ni0ll;
	wire_ni_w_lg_w_lg_w732w733w734w(0) <= wire_ni_w_lg_w732w733w(0) AND ni0ll;
	wire_ni_w_lg_w_lg_w699w710w711w(0) <= wire_ni_w_lg_w699w710w(0) AND ni0ll;
	wire_ni_w_lg_w_lg_w690w691w696w(0) <= wire_ni_w_lg_w690w691w(0) AND ni0ll;
	wire_ni_w_lg_w_lg_w808w809w860w(0) <= wire_ni_w_lg_w808w809w(0) AND niiil;
	wire_ni_w_lg_w_lg_w800w812w813w(0) <= wire_ni_w_lg_w800w812w(0) AND niiil;
	wire_ni_w_lg_w_lg_w772w774w775w(0) <= wire_ni_w_lg_w772w774w(0) AND niiil;
	wire_ni_w_lg_w_lg_w867w868w869w(0) <= wire_ni_w_lg_w867w868w(0) AND niiil;
	wire_ni_w_lg_w_lg_w825w839w840w(0) <= wire_ni_w_lg_w825w839w(0) AND niiil;
	wire_ni_w_lg_w_lg_w751w783w784w(0) <= wire_ni_w_lg_w751w783w(0) AND niiil;
	wire_ni_w_lg_w_lg_w683w724w725w(0) <= wire_ni_w_lg_w683w724w(0) AND ni0lO;
	wire_ni_w_lg_w_lg_w683w684w704w(0) <= wire_ni_w_lg_w683w684w(0) AND wire_ni_w_lg_ni0lO565w(0);
	wire_ni_w_lg_w_lg_w683w684w685w(0) <= wire_ni_w_lg_w683w684w(0) AND ni0lO;
	wire_ni_w_lg_w_lg_w669w670w671w(0) <= wire_ni_w_lg_w669w670w(0) AND ni0lO;
	wire_ni_w_lg_w_lg_w631w632w633w(0) <= wire_ni_w_lg_w631w632w(0) AND ni0lO;
	wire_ni_w_lg_w_lg_w631w648w649w(0) <= wire_ni_w_lg_w631w648w(0) AND ni0lO;
	wire_ni_w_lg_w_lg_w603w604w605w(0) <= wire_ni_w_lg_w603w604w(0) AND ni0lO;
	wire_ni_w_lg_w_lg_w643w644w645w(0) <= wire_ni_w_lg_w643w644w(0) AND wire_ni_w_lg_ni0lO565w(0);
	wire_ni_w_lg_w_lg_w617w618w619w(0) <= wire_ni_w_lg_w617w618w(0) AND ni0lO;
	wire_ni_w_lg_w_lg_w617w638w639w(0) <= wire_ni_w_lg_w617w638w(0) AND ni0lO;
	wire_ni_w_lg_w_lg_w815w816w817w(0) <= wire_ni_w_lg_w815w816w(0) AND niiiO;
	wire_ni_w_lg_w_lg_w829w852w853w(0) <= wire_ni_w_lg_w829w852w(0) AND niiiO;
	wire_ni_w_lg_w_lg_w829w830w842w(0) <= wire_ni_w_lg_w829w830w(0) AND wire_ni_w_lg_niiiO773w(0);
	wire_ni_w_lg_w_lg_w829w830w831w(0) <= wire_ni_w_lg_w829w830w(0) AND niiiO;
	wire_ni_w_lg_w_lg_w764w765w786w(0) <= wire_ni_w_lg_w764w765w(0) AND wire_ni_w_lg_niiiO773w(0);
	wire_ni_w_lg_w_lg_w764w765w766w(0) <= wire_ni_w_lg_w764w765w(0) AND niiiO;
	wire_ni_w_lg_w_lg_w764w804w805w(0) <= wire_ni_w_lg_w764w804w(0) AND wire_ni_w_lg_niiiO773w(0);
	wire_ni_w_lg_w662w663w(0) <= wire_ni_w662w(0) AND wire_ni_w_lg_ni0lO565w(0);
	wire_ni_w_lg_w556w557w(0) <= wire_ni_w556w(0) AND ni0lO;
	wire_ni_w_lg_w564w566w(0) <= wire_ni_w564w(0) AND wire_ni_w_lg_ni0lO565w(0);
	wire_ni_w_lg_w564w658w(0) <= wire_ni_w564w(0) AND ni0lO;
	wire_ni_w_lg_w654w655w(0) <= wire_ni_w654w(0) AND wire_ni_w_lg_ni0lO565w(0);
	wire_ni_w_lg_w625w626w(0) <= wire_ni_w625w(0) AND ni0lO;
	wire_ni_w_lg_w678w679w(0) <= wire_ni_w678w(0) AND wire_ni_w_lg_ni0lO565w(0);
	wire_ni_w_lg_w678w721w(0) <= wire_ni_w678w(0) AND ni0lO;
	wire_ni_w_lg_w732w733w(0) <= wire_ni_w732w(0) AND ni0lO;
	wire_ni_w_lg_w699w710w(0) <= wire_ni_w699w(0) AND wire_ni_w_lg_ni0lO565w(0);
	wire_ni_w_lg_w699w700w(0) <= wire_ni_w699w(0) AND ni0lO;
	wire_ni_w_lg_w690w691w(0) <= wire_ni_w690w(0) AND wire_ni_w_lg_ni0lO565w(0);
	wire_ni_w_lg_w690w707w(0) <= wire_ni_w690w(0) AND ni0lO;
	wire_ni_w_lg_w808w809w(0) <= wire_ni_w808w(0) AND niiiO;
	wire_ni_w_lg_w800w812w(0) <= wire_ni_w800w(0) AND niiiO;
	wire_ni_w_lg_w772w774w(0) <= wire_ni_w772w(0) AND wire_ni_w_lg_niiiO773w(0);
	wire_ni_w_lg_w772w880w(0) <= wire_ni_w772w(0) AND niiiO;
	wire_ni_w_lg_w867w868w(0) <= wire_ni_w867w(0) AND niiiO;
	wire_ni_w_lg_w825w839w(0) <= wire_ni_w825w(0) AND wire_ni_w_lg_niiiO773w(0);
	wire_ni_w_lg_w825w826w(0) <= wire_ni_w825w(0) AND niiiO;
	wire_ni_w_lg_w751w783w(0) <= wire_ni_w751w(0) AND wire_ni_w_lg_niiiO773w(0);
	wire_ni_w_lg_w751w752w(0) <= wire_ni_w751w(0) AND niiiO;
	wire_ni_w_lg_w683w724w(0) <= wire_ni_w683w(0) AND wire_ni_w_lg_ni0Oi555w(0);
	wire_ni_w_lg_w683w684w(0) <= wire_ni_w683w(0) AND ni0Oi;
	wire_ni_w_lg_w669w670w(0) <= wire_ni_w669w(0) AND wire_ni_w_lg_ni0Oi555w(0);
	wire_ni_w_lg_w631w632w(0) <= wire_ni_w631w(0) AND wire_ni_w_lg_ni0Oi555w(0);
	wire_ni_w_lg_w631w648w(0) <= wire_ni_w631w(0) AND ni0Oi;
	wire_ni_w_lg_w603w604w(0) <= wire_ni_w603w(0) AND ni0Oi;
	wire_ni_w_lg_w643w644w(0) <= wire_ni_w643w(0) AND wire_ni_w_lg_ni0Oi555w(0);
	wire_ni_w_lg_w617w618w(0) <= wire_ni_w617w(0) AND wire_ni_w_lg_ni0Oi555w(0);
	wire_ni_w_lg_w617w638w(0) <= wire_ni_w617w(0) AND ni0Oi;
	wire_ni_w_lg_w815w816w(0) <= wire_ni_w815w(0) AND niili;
	wire_ni_w_lg_w829w852w(0) <= wire_ni_w829w(0) AND wire_ni_w_lg_niili750w(0);
	wire_ni_w_lg_w829w830w(0) <= wire_ni_w829w(0) AND niili;
	wire_ni_w_lg_w764w765w(0) <= wire_ni_w764w(0) AND wire_ni_w_lg_niili750w(0);
	wire_ni_w_lg_w764w804w(0) <= wire_ni_w764w(0) AND niili;
	wire_ni_w662w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i548w549w551w608w661w(0) AND wire_ni_w_lg_ni0Oi555w(0);
	wire_ni_w556w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i548w549w551w552w554w(0) AND wire_ni_w_lg_ni0Oi555w(0);
	wire_ni_w564w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i548w549w551w552w554w(0) AND ni0Oi;
	wire_ni_w654w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i548w549w622w652w653w(0) AND wire_ni_w_lg_ni0Oi555w(0);
	wire_ni_w625w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i548w549w622w623w624w(0) AND wire_ni_w_lg_ni0Oi555w(0);
	wire_ni_w678w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w676w677w(0) AND ni0Oi;
	wire_ni_w732w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w676w698w(0) AND wire_ni_w_lg_ni0Oi555w(0);
	wire_ni_w699w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w676w698w(0) AND ni0Oi;
	wire_ni_w690w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w688w689w(0) AND wire_ni_w_lg_ni0Oi555w(0);
	wire_ni_w728w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w688w689w(0) AND ni0Oi;
	wire_ni_w591w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i586w587w588w589w590w(0) AND ni0Oi;
	wire_ni_w808w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w770w799w(0) AND wire_ni_w_lg_niili750w(0);
	wire_ni_w800w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w770w799w(0) AND niili;
	wire_ni_w772w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w770w771w(0) AND wire_ni_w_lg_niili750w(0);
	wire_ni_w856w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w770w771w(0) AND niili;
	wire_ni_w867w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w748w824w(0) AND wire_ni_w_lg_niili750w(0);
	wire_ni_w825w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w748w824w(0) AND niili;
	wire_ni_w751w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w748w749w(0) AND wire_ni_w_lg_niili750w(0);
	wire_ni_w581w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w575w577w578w580w(0) AND ni0Ol;
	wire_ni_w683w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w575w666w667w682w(0) AND ni0Ol;
	wire_ni_w669w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w575w666w667w668w(0) AND ni0Ol;
	wire_ni_w631w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w599w600w629w630w(0) AND wire_ni_w_lg_ni0Ol553w(0);
	wire_ni_w603w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w599w600w601w602w(0) AND ni0Ol;
	wire_ni_w643w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w599w614w615w642w(0) AND ni0Ol;
	wire_ni_w617w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w599w614w615w616w(0) AND wire_ni_w_lg_ni0Ol553w(0);
	wire_ni_w815w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i757w759w760w762w777w(0) AND wire_ni_w_lg_niill798w(0);
	wire_ni_w778w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i757w759w760w762w777w(0) AND niill;
	wire_ni_w829w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i757w759w760w762w763w(0) AND wire_ni_w_lg_niill798w(0);
	wire_ni_w764w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i757w759w760w762w763w(0) AND niill;
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i548w549w551w608w661w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i548w549w551w608w(0) AND ni0Ol;
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i548w549w551w552w554w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i548w549w551w552w(0) AND wire_ni_w_lg_ni0Ol553w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i548w549w622w652w653w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i548w549w622w652w(0) AND ni0Ol;
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i548w549w622w623w624w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i548w549w622w623w(0) AND wire_ni_w_lg_ni0Ol553w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w676w677w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w676w(0) AND wire_ni_w_lg_ni0Ol553w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w676w698w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w676w(0) AND ni0Ol;
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w688w689w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w688w(0) AND wire_ni_w_lg_ni0Ol553w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i586w587w588w589w590w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i586w587w588w589w(0) AND wire_ni_w_lg_ni0Ol553w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w770w799w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w770w(0) AND wire_ni_w_lg_niill798w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w770w771w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w770w(0) AND niill;
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w748w824w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w748w(0) AND wire_ni_w_lg_niill798w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w748w749w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w748w(0) AND niill;
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w575w577w578w580w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w575w577w578w(0) AND wire_ni_w_lg_ni0OO579w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w575w666w667w682w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w575w666w667w(0) AND wire_ni_w_lg_ni0OO579w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w575w666w667w668w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w575w666w667w(0) AND ni0OO;
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w599w600w629w630w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w599w600w629w(0) AND ni0OO;
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w599w600w601w602w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w599w600w601w(0) AND ni0OO;
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w599w614w615w642w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w599w614w615w(0) AND wire_ni_w_lg_ni0OO579w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nii0i574w599w614w615w616w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w599w614w615w(0) AND ni0OO;
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i757w759w760w762w777w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nil1i757w759w760w762w(0) AND wire_ni_w_lg_niilO769w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_w_lg_nil1i757w759w760w762w763w(0) <= wire_ni_w_lg_w_lg_w_lg_w_lg_nil1i757w759w760w762w(0) AND niilO;
	wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i548w549w551w608w(0) <= wire_ni_w_lg_w_lg_w_lg_nii0i548w549w551w(0) AND wire_ni_w_lg_ni0OO579w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i548w549w551w552w(0) <= wire_ni_w_lg_w_lg_w_lg_nii0i548w549w551w(0) AND ni0OO;
	wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i548w549w622w652w(0) <= wire_ni_w_lg_w_lg_w_lg_nii0i548w549w622w(0) AND wire_ni_w_lg_ni0OO579w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i548w549w622w623w(0) <= wire_ni_w_lg_w_lg_w_lg_nii0i548w549w622w(0) AND ni0OO;
	wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w676w(0) <= wire_ni_w_lg_w_lg_w_lg_nii0i586w674w675w(0) AND wire_ni_w_lg_ni0OO579w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i586w674w675w688w(0) <= wire_ni_w_lg_w_lg_w_lg_nii0i586w674w675w(0) AND ni0OO;
	wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i586w587w588w589w(0) <= wire_ni_w_lg_w_lg_w_lg_nii0i586w587w588w(0) AND ni0OO;
	wire_ni_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w770w(0) <= wire_ni_w_lg_w_lg_w_lg_nil1i744w746w747w(0) AND wire_ni_w_lg_niilO769w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_nil1i744w746w747w748w(0) <= wire_ni_w_lg_w_lg_w_lg_nil1i744w746w747w(0) AND niilO;
	wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w575w577w578w(0) <= wire_ni_w_lg_w_lg_w_lg_nii0i574w575w577w(0) AND nii1i;
	wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w575w666w667w(0) <= wire_ni_w_lg_w_lg_w_lg_nii0i574w575w666w(0) AND wire_ni_w_lg_nii1i550w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w599w600w629w(0) <= wire_ni_w_lg_w_lg_w_lg_nii0i574w599w600w(0) AND wire_ni_w_lg_nii1i550w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w599w600w601w(0) <= wire_ni_w_lg_w_lg_w_lg_nii0i574w599w600w(0) AND nii1i;
	wire_ni_w_lg_w_lg_w_lg_w_lg_nii0i574w599w614w615w(0) <= wire_ni_w_lg_w_lg_w_lg_nii0i574w599w614w(0) AND wire_ni_w_lg_nii1i550w(0);
	wire_ni_w_lg_w_lg_w_lg_w_lg_nil1i757w759w760w762w(0) <= wire_ni_w_lg_w_lg_w_lg_nil1i757w759w760w(0) AND wire_ni_w_lg_niiOi761w(0);
	wire_ni_w_lg_w_lg_w_lg_nii0i548w549w551w(0) <= wire_ni_w_lg_w_lg_nii0i548w549w(0) AND wire_ni_w_lg_nii1i550w(0);
	wire_ni_w_lg_w_lg_w_lg_nii0i548w549w622w(0) <= wire_ni_w_lg_w_lg_nii0i548w549w(0) AND nii1i;
	wire_ni_w_lg_w_lg_w_lg_nii0i586w674w675w(0) <= wire_ni_w_lg_w_lg_nii0i586w674w(0) AND nii1i;
	wire_ni_w_lg_w_lg_w_lg_nii0i586w587w588w(0) <= wire_ni_w_lg_w_lg_nii0i586w587w(0) AND wire_ni_w_lg_nii1i550w(0);
	wire_ni_w_lg_w_lg_w_lg_nil1i744w746w747w(0) <= wire_ni_w_lg_w_lg_nil1i744w746w(0) AND niiOi;
	wire_ni_w_lg_w_lg_w_lg_nii0i574w575w577w(0) <= wire_ni_w_lg_w_lg_nii0i574w575w(0) AND wire_ni_w_lg_nii1l576w(0);
	wire_ni_w_lg_w_lg_w_lg_nii0i574w575w666w(0) <= wire_ni_w_lg_w_lg_nii0i574w575w(0) AND nii1l;
	wire_ni_w_lg_w_lg_w_lg_nii0i574w599w600w(0) <= wire_ni_w_lg_w_lg_nii0i574w599w(0) AND wire_ni_w_lg_nii1l576w(0);
	wire_ni_w_lg_w_lg_w_lg_nii0i574w599w614w(0) <= wire_ni_w_lg_w_lg_nii0i574w599w(0) AND nii1l;
	wire_ni_w_lg_w_lg_w_lg_nil1i757w759w760w(0) <= wire_ni_w_lg_w_lg_nil1i757w759w(0) AND niiOl;
	wire_ni_w_lg_w_lg_w_lg_nil1O221w233w236w(0) <= wire_ni_w_lg_w_lg_nil1O221w233w(0) AND wire_nl1O1l46_w_lg_q235w(0);
	wire_ni_w_lg_w_lg_w_lg_nil1O221w225w228w(0) <= wire_ni_w_lg_w_lg_nil1O221w225w(0) AND wire_nl1Oii44_w_lg_q227w(0);
	wire_ni_w_lg_w_lg_nii0i548w549w(0) <= wire_ni_w_lg_nii0i548w(0) AND nii1l;
	wire_ni_w_lg_w_lg_nii0i586w674w(0) <= wire_ni_w_lg_nii0i586w(0) AND wire_ni_w_lg_nii1l576w(0);
	wire_ni_w_lg_w_lg_nii0i586w587w(0) <= wire_ni_w_lg_nii0i586w(0) AND nii1l;
	wire_ni_w_lg_w_lg_nil1i744w746w(0) <= wire_ni_w_lg_nil1i744w(0) AND wire_ni_w_lg_niiOl745w(0);
	wire_ni_w_lg_w_lg_ni0i23w24w(0) <= wire_ni_w_lg_ni0i23w(0) AND nl0i1O;
	wire_ni_w_lg_w_lg_nii0i574w575w(0) <= wire_ni_w_lg_nii0i574w(0) AND wire_ni_w_lg_nii1O547w(0);
	wire_ni_w_lg_w_lg_nii0i574w599w(0) <= wire_ni_w_lg_nii0i574w(0) AND nii1O;
	wire_ni_w_lg_w_lg_nii0l197w343w(0) <= wire_ni_w_lg_nii0l197w(0) AND wire_w_lg_nl110l342w(0);
	wire_ni_w_lg_w_lg_nii0l197w339w(0) <= wire_ni_w_lg_nii0l197w(0) AND wire_w_lg_nl11ii338w(0);
	wire_ni_w_lg_w_lg_nii0l197w335w(0) <= wire_ni_w_lg_nii0l197w(0) AND wire_w_lg_nl11iO334w(0);
	wire_ni_w_lg_w_lg_nii0O200w344w(0) <= wire_ni_w_lg_nii0O200w(0) AND wire_ni_w_lg_w_lg_nii0l197w343w(0);
	wire_ni_w_lg_w_lg_nii0O200w340w(0) <= wire_ni_w_lg_nii0O200w(0) AND wire_ni_w_lg_w_lg_nii0l197w339w(0);
	wire_ni_w_lg_w_lg_nii0O200w336w(0) <= wire_ni_w_lg_nii0O200w(0) AND wire_ni_w_lg_w_lg_nii0l197w335w(0);
	wire_ni_w_lg_w_lg_nil1i757w759w(0) <= wire_ni_w_lg_nil1i757w(0) AND wire_ni_w_lg_niiOO758w(0);
	wire_ni_w_lg_w_lg_nil1l222w286w(0) <= wire_ni_w_lg_nil1l222w(0) AND wire_w_lg_nl1i0O285w(0);
	wire_ni_w_lg_w_lg_nil1l222w282w(0) <= wire_ni_w_lg_nil1l222w(0) AND wire_w_lg_nl1iil281w(0);
	wire_ni_w_lg_w_lg_nil1l222w278w(0) <= wire_ni_w_lg_nil1l222w(0) AND wire_w_lg_nl1ili277w(0);
	wire_ni_w_lg_w_lg_nil1l222w273w(0) <= wire_ni_w_lg_nil1l222w(0) AND wire_w_lg_nl1iOi272w(0);
	wire_ni_w_lg_w_lg_nil1l222w269w(0) <= wire_ni_w_lg_nil1l222w(0) AND wire_w_lg_nl1iOO268w(0);
	wire_ni_w_lg_w_lg_nil1l222w261w(0) <= wire_ni_w_lg_nil1l222w(0) AND wire_w_lg_nl1l0i260w(0);
	wire_ni_w_lg_w_lg_nil1l222w257w(0) <= wire_ni_w_lg_nil1l222w(0) AND wire_w_lg_nl1l0O256w(0);
	wire_ni_w_lg_w_lg_nil1l222w265w(0) <= wire_ni_w_lg_nil1l222w(0) AND wire_w_lg_nl1l1l264w(0);
	wire_ni_w_lg_w_lg_nil1l222w253w(0) <= wire_ni_w_lg_nil1l222w(0) AND wire_w_lg_nl1lil252w(0);
	wire_ni_w_lg_w_lg_nil1l222w249w(0) <= wire_ni_w_lg_nil1l222w(0) AND wire_w_lg_nl1lli248w(0);
	wire_ni_w_lg_w_lg_nil1l222w244w(0) <= wire_ni_w_lg_nil1l222w(0) AND wire_w_lg_nl1lOi243w(0);
	wire_ni_w_lg_w_lg_nil1l222w232w(0) <= wire_ni_w_lg_nil1l222w(0) AND wire_w_lg_nl1O0l231w(0);
	wire_ni_w_lg_w_lg_nil1l222w224w(0) <= wire_ni_w_lg_nil1l222w(0) AND wire_w_lg_nl1Oli223w(0);
	wire_ni_w_lg_w_lg_nil1O221w287w(0) <= wire_ni_w_lg_nil1O221w(0) AND wire_ni_w_lg_w_lg_nil1l222w286w(0);
	wire_ni_w_lg_w_lg_nil1O221w283w(0) <= wire_ni_w_lg_nil1O221w(0) AND wire_ni_w_lg_w_lg_nil1l222w282w(0);
	wire_ni_w_lg_w_lg_nil1O221w279w(0) <= wire_ni_w_lg_nil1O221w(0) AND wire_ni_w_lg_w_lg_nil1l222w278w(0);
	wire_ni_w_lg_w_lg_nil1O221w274w(0) <= wire_ni_w_lg_nil1O221w(0) AND wire_ni_w_lg_w_lg_nil1l222w273w(0);
	wire_ni_w_lg_w_lg_nil1O221w270w(0) <= wire_ni_w_lg_nil1O221w(0) AND wire_ni_w_lg_w_lg_nil1l222w269w(0);
	wire_ni_w_lg_w_lg_nil1O221w262w(0) <= wire_ni_w_lg_nil1O221w(0) AND wire_ni_w_lg_w_lg_nil1l222w261w(0);
	wire_ni_w_lg_w_lg_nil1O221w258w(0) <= wire_ni_w_lg_nil1O221w(0) AND wire_ni_w_lg_w_lg_nil1l222w257w(0);
	wire_ni_w_lg_w_lg_nil1O221w266w(0) <= wire_ni_w_lg_nil1O221w(0) AND wire_ni_w_lg_w_lg_nil1l222w265w(0);
	wire_ni_w_lg_w_lg_nil1O221w254w(0) <= wire_ni_w_lg_nil1O221w(0) AND wire_ni_w_lg_w_lg_nil1l222w253w(0);
	wire_ni_w_lg_w_lg_nil1O221w250w(0) <= wire_ni_w_lg_nil1O221w(0) AND wire_ni_w_lg_w_lg_nil1l222w249w(0);
	wire_ni_w_lg_w_lg_nil1O221w245w(0) <= wire_ni_w_lg_nil1O221w(0) AND wire_ni_w_lg_w_lg_nil1l222w244w(0);
	wire_ni_w_lg_w_lg_nil1O221w233w(0) <= wire_ni_w_lg_nil1O221w(0) AND wire_ni_w_lg_w_lg_nil1l222w232w(0);
	wire_ni_w_lg_w_lg_nil1O221w225w(0) <= wire_ni_w_lg_nil1O221w(0) AND wire_ni_w_lg_w_lg_nil1l222w224w(0);
	wire_ni_w_lg_nii0i548w(0) <= nii0i AND wire_ni_w_lg_nii1O547w(0);
	wire_ni_w_lg_nii0i586w(0) <= nii0i AND nii1O;
	wire_ni_w_lg_nil1i744w(0) <= nil1i AND niiOO;
	wire_ni_w_lg_nlO9w(0) <= nlO AND nl0iiO;
	wire_ni_w_lg_n0l16w(0) <= NOT n0l;
	wire_ni_w_lg_ni0i23w(0) <= NOT ni0i;
	wire_ni_w_lg_ni0il366w(0) <= NOT ni0il;
	wire_ni_w_lg_ni0iO198w(0) <= NOT ni0iO;
	wire_ni_w_lg_ni0li568w(0) <= NOT ni0li;
	wire_ni_w_lg_ni0ll558w(0) <= NOT ni0ll;
	wire_ni_w_lg_ni0lO565w(0) <= NOT ni0lO;
	wire_ni_w_lg_ni0Oi555w(0) <= NOT ni0Oi;
	wire_ni_w_lg_ni0Ol553w(0) <= NOT ni0Ol;
	wire_ni_w_lg_ni0OO579w(0) <= NOT ni0OO;
	wire_ni_w_lg_nii0i574w(0) <= NOT nii0i;
	wire_ni_w_lg_nii0l197w(0) <= NOT nii0l;
	wire_ni_w_lg_nii0O200w(0) <= NOT nii0O;
	wire_ni_w_lg_nii1i550w(0) <= NOT nii1i;
	wire_ni_w_lg_nii1l576w(0) <= NOT nii1l;
	wire_ni_w_lg_nii1O547w(0) <= NOT nii1O;
	wire_ni_w_lg_niiii755w(0) <= NOT niiii;
	wire_ni_w_lg_niiil753w(0) <= NOT niiil;
	wire_ni_w_lg_niiiO773w(0) <= NOT niiiO;
	wire_ni_w_lg_niili750w(0) <= NOT niili;
	wire_ni_w_lg_niill798w(0) <= NOT niill;
	wire_ni_w_lg_niilO769w(0) <= NOT niilO;
	wire_ni_w_lg_niiOi761w(0) <= NOT niiOi;
	wire_ni_w_lg_niiOl745w(0) <= NOT niiOl;
	wire_ni_w_lg_niiOO758w(0) <= NOT niiOO;
	wire_ni_w_lg_nil1i757w(0) <= NOT nil1i;
	wire_ni_w_lg_nil1l222w(0) <= NOT nil1l;
	wire_ni_w_lg_nil1O221w(0) <= NOT nil1O;
	wire_ni_w_lg_nli0ll989w(0) <= NOT nli0ll;
	wire_ni_w_lg_nli0OO987w(0) <= NOT nli0OO;
	wire_ni_w_lg_nli1li907w(0) <= NOT nli1li;
	wire_ni_w_lg_nlii0i982w(0) <= NOT nlii0i;
	wire_ni_w_lg_nlii1i985w(0) <= NOT nlii1i;
	wire_ni_w_lg_nlii1O983w(0) <= NOT nlii1O;
	wire_ni_w_lg_nlil911w(0) <= NOT nlil;
	wire_ni_w_lg_w_lg_nlO9w10w(0) <= wire_ni_w_lg_nlO9w(0) OR nlil;
	wire_ni_w_lg_n0l1088w(0) <= n0l OR nl0l0O;
	PROCESS (rcvd_clk, wire_ni1l_CLRN, rxpcsrst, rwait_count(0), rwait_count(1), rwait_count(2), rwait_count(3), rwait_count(4), rwait_count(5), rwait_count(6), rwait_count(7))
	BEGIN
		IF (wire_ni1l_CLRN = '0') THEN
				n01i <= '0';
				n0ll <= '0';
				n0lO <= '0';
				n0Oi <= '0';
				n0Ol <= '0';
				n0OO <= '0';
				ni1i <= '0';
				ni1O <= '0';
		ELSIF (rxpcsrst = '1') THEN
				n01i <= rwait_count(0);
				n0ll <= rwait_count(1);
				n0lO <= rwait_count(2);
				n0Oi <= rwait_count(3);
				n0Ol <= rwait_count(4);
				n0OO <= rwait_count(5);
				ni1i <= rwait_count(6);
				ni1O <= rwait_count(7);
		ELSIF (rcvd_clk = '1' AND rcvd_clk'event) THEN
				n01i <= wire_ni0l_dataout;
				n0ll <= wire_ni0O_dataout;
				n0lO <= wire_niii_dataout;
				n0Oi <= wire_niil_dataout;
				n0Ol <= wire_niiO_dataout;
				n0OO <= wire_nili_dataout;
				ni1i <= wire_nill_dataout;
				ni1O <= wire_nilO_dataout;
		END IF;
	END PROCESS;
	wire_ni1l_CLRN <= (nl00lO18 XOR nl00lO17);
	wire_ni1l_w_lg_n0ll115w(0) <= n0ll XOR wire_w_rwait_count_range75w(0);
	wire_ni1l_w_lg_n0Oi125w(0) <= n0Oi XOR wire_w_rwait_count_range73w(0);
	wire_ni1l_w_lg_ni1i138w(0) <= ni1i XOR wire_w_rwait_count_range70w(0);
	PROCESS (rcvd_clk, wire_nliOlO_PRN, wire_nliOlO_CLRN)
	BEGIN
		IF (wire_nliOlO_PRN = '0') THEN
				nliO0i <= '1';
				nliO0l <= '1';
				nliO0O <= '1';
				nliO1l <= '1';
				nliO1O <= '1';
				nliOii <= '1';
				nliOil <= '1';
				nliOiO <= '1';
				nliOli <= '1';
				nliOll <= '1';
				nliOOi <= '1';
		ELSIF (wire_nliOlO_CLRN = '0') THEN
				nliO0i <= '0';
				nliO0l <= '0';
				nliO0O <= '0';
				nliO1l <= '0';
				nliO1O <= '0';
				nliOii <= '0';
				nliOil <= '0';
				nliOiO <= '0';
				nliOli <= '0';
				nliOll <= '0';
				nliOOi <= '0';
		ELSIF (rcvd_clk = '1' AND rcvd_clk'event) THEN
			IF (niOiii = '1') THEN
				nliO0i <= nl0O1O;
				nliO0l <= nl0O0i;
				nliO0O <= nl0O0l;
				nliO1l <= nl0O1i;
				nliO1O <= nl0O1l;
				nliOii <= nl0O0O;
				nliOil <= nl0Oii;
				nliOiO <= nl0Oil;
				nliOli <= nl0OiO;
				nliOll <= nl0Oli;
				nliOOi <= nl0Oll;
			END IF;
		END IF;
	END PROCESS;
	wire_nliOlO_CLRN <= ((niOi0O50 XOR niOi0O49) AND wire_w_lg_rxpcsrst2w(0));
	wire_nliOlO_PRN <= (niOi0l52 XOR niOi0l51);
	PROCESS (rcvd_clk, wire_nlli_PRN, wire_nlli_CLRN)
	BEGIN
		IF (wire_nlli_PRN = '0') THEN
				n0li <= '1';
				ni0ii <= '1';
				nl0lOO <= '1';
				nliO <= '1';
				nll10i <= '1';
				nlll <= '1';
		ELSIF (wire_nlli_CLRN = '0') THEN
				n0li <= '0';
				ni0ii <= '0';
				nl0lOO <= '0';
				nliO <= '0';
				nll10i <= '0';
				nlll <= '0';
		ELSIF (rcvd_clk = '1' AND rcvd_clk'event) THEN
				n0li <= nll10i;
				ni0ii <= wire_n000O_o;
				nl0lOO <= wire_nl0lii_dataout;
				nliO <= wire_n1l_dataout;
				nll10i <= wire_nliOOl_dataout;
				nlll <= wire_n0O_dataout;
		END IF;
		if (now = 0 ns) then
			n0li <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni0ii <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl0lOO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nliO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll10i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlll <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nlli_CLRN <= (nl0i0l8 XOR nl0i0l7);
	wire_nlli_PRN <= ((nl0i0i10 XOR nl0i0i9) AND wire_w_lg_rxpcsrst2w(0));
	wire_nlli_w_lg_nliO18w(0) <= NOT nliO;
	wire_n000i_dataout <= wire_n0O0i_dataout AND ni00O;
	wire_n001i_dataout <= wire_n0l0i_dataout AND ni01O;
	wire_n001l_dataout <= wire_n0liO_dataout AND ni00i;
	wire_n001O_dataout <= wire_n0lOl_dataout AND ni00l;
	wire_n00i_dataout <= wire_n00O_o(0) WHEN nl000i = '1'  ELSE n1Ol;
	wire_n00ii_dataout <= niOO0l AND NOT(niOOiO);
	wire_n00il_dataout <= wire_n0i0O_dataout AND NOT(niOOiO);
	wire_n00iO_dataout <= wire_n0iii_dataout OR niOOiO;
	wire_n00l_dataout <= wire_n00O_o(1) WHEN nl000i = '1'  ELSE n1OO;
	wire_n00li_dataout <= wire_n00lO_dataout AND NOT(niOOiO);
	wire_n00ll_dataout <= wire_n00Oi_dataout OR niOOiO;
	wire_n00lO_dataout <= niOOil AND NOT(niOO0i);
	wire_n00Oi_dataout <= wire_w_lg_niOOil368w(0) AND NOT(niOO0i);
	wire_n00Ol_dataout <= wire_n0i1O_dataout AND NOT(niOOiO);
	wire_n00OO_dataout <= niOO0i AND NOT(niOOiO);
	wire_n010i_dataout <= wire_n00OO_dataout AND ni1ii;
	wire_n010l_dataout <= wire_n00OO_dataout AND ni1il;
	wire_n010O_dataout <= wire_n00OO_dataout AND ni1iO;
	wire_n011i_dataout <= wire_n00ii_dataout AND ni10i;
	wire_n011l_dataout <= wire_n00ii_dataout AND ni10l;
	wire_n011O_dataout <= wire_n00Ol_dataout AND ni01i;
	wire_n01ii_dataout <= wire_n00OO_dataout AND ni1li;
	wire_n01il_dataout <= wire_n00OO_dataout AND ni1ll;
	wire_n01iO_dataout <= wire_n00OO_dataout AND ni1lO;
	wire_n01l_dataout <= wire_n00i_dataout AND NOT(nl0i0O);
	wire_n01li_dataout <= wire_n00OO_dataout AND ni1Oi;
	wire_n01ll_dataout <= wire_n00OO_dataout AND ni1Ol;
	wire_n01O_dataout <= wire_n00l_dataout AND NOT(nl0i0O);
	wire_n01Ol_dataout <= wire_n0iil_dataout AND ni01l;
	wire_n01OO_dataout <= wire_n0iiO_dataout AND ni01l;
	wire_n0i0i_dataout <= wire_n0i0O_dataout AND NOT(niOO0i);
	wire_n0i0l_dataout <= wire_n0iii_dataout AND NOT(niOO0i);
	wire_n0i0O_dataout <= niOOil AND NOT(niOO0l);
	wire_n0i1i_dataout <= wire_n0i0i_dataout AND NOT(niOOiO);
	wire_n0i1l_dataout <= wire_n0i0l_dataout OR niOOiO;
	wire_n0i1O_dataout <= niOO0l AND NOT(niOO0i);
	wire_n0iii_dataout <= wire_w_lg_niOOil368w(0) AND NOT(niOO0l);
	wire_n0iil_dataout <= wire_n0ilO_dataout AND NOT(niOOiO);
	wire_n0iiO_dataout <= niOOii AND NOT(niOOiO);
	wire_n0ili_dataout <= wire_n0iOi_dataout AND NOT(niOOiO);
	wire_n0ill_dataout <= wire_n0iOl_dataout OR niOOiO;
	wire_n0ilO_dataout <= niOO0O AND NOT(niOOii);
	wire_n0iOi_dataout <= wire_n0iOO_dataout AND NOT(niOOii);
	wire_n0iOl_dataout <= wire_n0l1i_dataout AND NOT(niOOii);
	wire_n0iOO_dataout <= niOOil AND NOT(niOO0O);
	wire_n0l0i_dataout <= niOOlO AND NOT(niOOiO);
	wire_n0l0l_dataout <= wire_n0lii_dataout AND NOT(niOOiO);
	wire_n0l0O_dataout <= wire_n0lil_dataout OR niOOiO;
	wire_n0l1i_dataout <= wire_w_lg_niOOil368w(0) AND NOT(niOO0O);
	wire_n0lii_dataout <= niOOil AND NOT(niOOlO);
	wire_n0lil_dataout <= wire_w_lg_niOOil368w(0) AND NOT(niOOlO);
	wire_n0liO_dataout <= nl11li AND NOT(niOOiO);
	wire_n0lli_dataout <= wire_n0llO_dataout AND NOT(niOOiO);
	wire_n0lll_dataout <= wire_n0lOi_dataout OR niOOiO;
	wire_n0llO_dataout <= niOOil AND NOT(nl11li);
	wire_n0lOi_dataout <= wire_w_lg_niOOil368w(0) AND NOT(nl11li);
	wire_n0lOl_dataout <= nl11ll AND NOT(niOOiO);
	wire_n0lOO_dataout <= wire_n0O1l_dataout AND NOT(niOOiO);
	wire_n0O_dataout <= wire_nii_dataout OR NOT(nlO);
	wire_n0O0i_dataout <= nl010l AND NOT(niOOiO);
	wire_n0O0l_dataout <= wire_n0Oii_dataout AND NOT(niOOiO);
	wire_n0O0O_dataout <= wire_n0Oil_dataout OR niOOiO;
	wire_n0O1i_dataout <= wire_n0O1O_dataout OR niOOiO;
	wire_n0O1l_dataout <= niOOil AND NOT(nl11ll);
	wire_n0O1O_dataout <= wire_w_lg_niOOil368w(0) AND NOT(nl11ll);
	wire_n0Oii_dataout <= niOOil AND NOT(nl010l);
	wire_n0Oil_dataout <= wire_w_lg_niOOil368w(0) AND NOT(nl010l);
	wire_n0OiO_dataout <= niOOil AND NOT(niOOiO);
	wire_n0Oli_dataout <= wire_w_lg_niOOil368w(0) OR niOOiO;
	wire_n1l_dataout <= wire_n1O_dataout WHEN reidleinferenable = '1'  ELSE nlll;
	wire_n1O_dataout <= nlll WHEN (wire_ni_w_lg_n0l16w(0) AND rgen1_sigdet_ena) = '1'  ELSE n0li;
	wire_n1OiO_dataout <= wire_n00ii_dataout AND n0OOi;
	wire_n1Oli_dataout <= wire_n00ii_dataout AND n0OOl;
	wire_n1Oll_dataout <= wire_n00ii_dataout AND n0OOO;
	wire_n1OOi_dataout <= wire_n00ii_dataout AND ni11i;
	wire_n1OOl_dataout <= wire_n00ii_dataout AND ni11l;
	wire_n1OOO_dataout <= wire_n00ii_dataout AND ni11O;
	wire_ni0l_dataout <= wire_nl0O_o(0) WHEN nl00OO = '1'  ELSE wire_niOi_dataout;
	wire_ni0O_dataout <= wire_nl0O_o(1) WHEN nl00OO = '1'  ELSE wire_niOl_dataout;
	wire_nii_dataout <= (NOT (wire_ni_w_lg_w_lg_nlO9w10w(0) OR (NOT (nl0iii6 XOR nl0iii5)))) WHEN nlll = '1'  ELSE (wire_w_lg_w_lg_riei_eios_priority_dis4w5w(0) AND (nl0ili4 XOR nl0ili3));
	wire_niii_dataout <= wire_nl0O_o(2) WHEN nl00OO = '1'  ELSE wire_niOO_dataout;
	wire_niil_dataout <= wire_nl0O_o(3) WHEN nl00OO = '1'  ELSE wire_nl1i_dataout;
	wire_niiO_dataout <= wire_nl0O_o(4) WHEN nl00OO = '1'  ELSE wire_nl1l_dataout;
	wire_nili_dataout <= wire_nl0O_o(5) WHEN nl00OO = '1'  ELSE wire_nl1O_dataout;
	wire_nill_dataout <= wire_nl0O_o(6) WHEN nl00OO = '1'  ELSE wire_nl0i_dataout;
	wire_nilO_dataout <= wire_nl0O_o(7) WHEN nl00OO = '1'  ELSE wire_nl0l_dataout;
	wire_niOi_dataout <= n01i AND wire_n1l_dataout;
	wire_niOl_dataout <= n0ll AND wire_n1l_dataout;
	wire_niOO_dataout <= n0lO AND wire_n1l_dataout;
	wire_nl0i_dataout <= ni1i AND wire_n1l_dataout;
	wire_nl0l_dataout <= ni1O AND wire_n1l_dataout;
	wire_nl0lii_dataout <= wire_nl0lil_o OR NOT(reidleinferenable);
	wire_nl0lll_dataout <= syncstatus WHEN (inferred_rxvalid AND (reidle_com_detect(0) AND reidle_com_detect(1))) = '1'  ELSE (inferred_rxvalid AND wire_nl0lOi_o);
	wire_nl1i_dataout <= n0Oi AND wire_n1l_dataout;
	wire_nl1l_dataout <= n0Ol AND wire_n1l_dataout;
	wire_nl1O_dataout <= n0OO AND wire_n1l_dataout;
	wire_nli0lO_dataout <= niOi1O AND NOT(niOi0i);
	wire_nliiOO_dataout <= wire_nliO1i_o(0) AND NOT(niOi0i);
	wire_nlil0i_dataout <= wire_nliO1i_o(4) AND NOT(niOi0i);
	wire_nlil0l_dataout <= wire_nliO1i_o(5) AND NOT(niOi0i);
	wire_nlil0O_dataout <= wire_nliO1i_o(6) AND NOT(niOi0i);
	wire_nlil1i_dataout <= wire_nliO1i_o(1) AND NOT(niOi0i);
	wire_nlil1l_dataout <= wire_nliO1i_o(2) AND NOT(niOi0i);
	wire_nlil1O_dataout <= wire_nliO1i_o(3) AND NOT(niOi0i);
	wire_nlilii_dataout <= wire_nliO1i_o(7) AND NOT(niOi0i);
	wire_nlilil_dataout <= wire_nliO1i_o(8) AND NOT(niOi0i);
	wire_nliliO_dataout <= wire_nliO1i_o(9) AND NOT(niOi0i);
	wire_nlilli_dataout <= wire_nliO1i_o(10) AND NOT(niOi0i);
	wire_nlilll_dataout <= wire_nliO1i_o(11) AND NOT(niOi0i);
	wire_nlillO_dataout <= wire_nliO1i_o(12) AND NOT(niOi0i);
	wire_nlilOi_dataout <= wire_nliO1i_o(13) AND NOT(niOi0i);
	wire_nlilOl_dataout <= wire_nliO1i_o(14) AND NOT(niOi0i);
	wire_nlilOO_dataout <= wire_nliO1i_o(15) AND NOT(niOi0i);
	wire_nliOOl_dataout <= wire_ni_w_lg_nlil911w(0) WHEN nll10i = '1'  ELSE ((eiosdetect_int AND (wire_w_lg_riei_eios_priority_dis4w(0) OR wire_ni_w_lg_nli1li907w(0))) OR nli0Oi);
	wire_nO_dataout <= gen2ngen1 WHEN rindv_rx = '1'  ELSE gen2ngen1_bundle;
	wire_n00O_a <= ( n1OO & n1Ol);
	wire_n00O_b <= ( "0" & "1");
	n00O :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 2,
		width_b => 2,
		width_o => 2
	  )
	  PORT MAP ( 
		a => wire_n00O_a,
		b => wire_n00O_b,
		cin => wire_gnd,
		o => wire_n00O_o
	  );
	wire_nl0O_a <= ( ni1O & wire_nl00Oi16_w_lg_w_lg_q39w40w & n0OO & n0Ol & n0Oi & n0lO & n0ll & wire_nl00Ol14_w_lg_w_lg_q30w31w);
	wire_nl0O_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	nl0O :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8,
		width_o => 8
	  )
	  PORT MAP ( 
		a => wire_nl0O_a,
		b => wire_nl0O_b,
		cin => wire_gnd,
		o => wire_nl0O_o
	  );
	wire_nliO1i_a <= ( nliiOl & nliiOi & nliilO & nliill & nliili & nliiiO & nliiil & nliiii & nlii0O & nlii0l & nlii0i & nlii1O & nlii1l & nlii1i & nli0OO & nli0ll);
	wire_nliO1i_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	nliO1i :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 16,
		width_b => 16,
		width_o => 16
	  )
	  PORT MAP ( 
		a => wire_nliO1i_a,
		b => wire_nliO1i_b,
		cin => wire_gnd,
		o => wire_nliO1i_o
	  );
	wire_nl0OOi_i <= ( nli1iO & nli1il);
	nl0OOi :  oper_decoder
	  GENERIC MAP (
		width_i => 2,
		width_o => 4
	  )
	  PORT MAP ( 
		i => wire_nl0OOi_i,
		o => wire_nl0OOi_o
	  );
	wire_nl0OOO_i <= ( n0l & nli1il);
	nl0OOO :  oper_decoder
	  GENERIC MAP (
		width_i => 2,
		width_o => 4
	  )
	  PORT MAP ( 
		i => wire_nl0OOO_i,
		o => wire_nl0OOO_o
	  );
	wire_nli10i_i <= ( n0l & nli1iO & nli1il);
	nli10i :  oper_decoder
	  GENERIC MAP (
		width_i => 3,
		width_o => 8
	  )
	  PORT MAP ( 
		i => wire_nli10i_i,
		o => wire_nli10i_o
	  );
	wire_n0il_a <= ( n1OO & wire_nl00ll20_w_lg_w_lg_q76w77w);
	wire_n0il_b <= ( reidle_com_detect(1 DOWNTO 0));
	n0il :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 2,
		width_b => 2
	  )
	  PORT MAP ( 
		a => wire_n0il_a,
		b => wire_n0il_b,
		cin => wire_gnd,
		o => wire_n0il_o
	  );
	wire_nl0lOi_a <= ( reidle_com_detect(1 DOWNTO 0));
	wire_nl0lOi_b <= ( kcount(1 DOWNTO 0));
	nl0lOi :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 2,
		width_b => 2
	  )
	  PORT MAP ( 
		a => wire_nl0lOi_a,
		b => wire_nl0lOi_b,
		cin => wire_vcc,
		o => wire_nl0lOi_o
	  );
	wire_nl0lil_data <= ( n1OlO & skposdetect & nl0l0O & wire_ni_w_lg_n0l1088w & "1" & "1" & "1" & "1");
	wire_nl0lil_sel <= ( nli1li & nli1iO & nli1il);
	nl0lil :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0lil_data,
		o => wire_nl0lil_o,
		sel => wire_nl0lil_sel
	  );
	wire_n000l_data <= ( wire_n0OiO_dataout & wire_n0O0l_dataout & wire_n0lOO_dataout & wire_n0lli_dataout & wire_n0l0l_dataout & wire_n0ili_dataout & wire_n0i1i_dataout & wire_n00li_dataout & wire_n00li_dataout & wire_n00li_dataout & wire_n00li_dataout & wire_n00li_dataout & wire_n00li_dataout & wire_n00li_dataout & wire_n00li_dataout & wire_n00li_dataout & wire_n00li_dataout & wire_n00il_dataout & wire_n00il_dataout & wire_n00il_dataout & wire_n00il_dataout & wire_n00il_dataout & wire_n00il_dataout & wire_n00il_dataout & wire_n00il_dataout & wire_n00il_dataout & wire_n0OiO_dataout);
	wire_n000l_sel <= ( ni0ii & ni00O & ni00l & ni00i & ni01O & ni01l & ni01i & ni1OO & ni1Ol & ni1Oi & ni1lO & ni1ll & ni1li & ni1iO & ni1il & ni1ii & ni10O & ni10l & ni10i & ni11O & ni11l & ni11i & n0OOO & n0OOl & n0OOi & n0OlO & n1OlO);
	n000l :  oper_selector
	  GENERIC MAP (
		width_data => 27,
		width_sel => 27
	  )
	  PORT MAP ( 
		data => wire_n000l_data,
		o => wire_n000l_o,
		sel => wire_n000l_sel
	  );
	wire_n000O_data <= ( wire_n0Oli_dataout & wire_n0O0O_dataout & wire_n0O1i_dataout & wire_n0lll_dataout & wire_n0l0O_dataout & wire_n0ill_dataout & wire_n0i1l_dataout & wire_n00ll_dataout & wire_n00ll_dataout & wire_n00ll_dataout & wire_n00ll_dataout & wire_n00ll_dataout & wire_n00ll_dataout & wire_n00ll_dataout & wire_n00ll_dataout & wire_n00ll_dataout & wire_n00ll_dataout & wire_n00iO_dataout & wire_n00iO_dataout & wire_n00iO_dataout & wire_n00iO_dataout & wire_n00iO_dataout & wire_n00iO_dataout & wire_n00iO_dataout & wire_n00iO_dataout & wire_n00iO_dataout & wire_n0Oli_dataout);
	wire_n000O_sel <= ( ni0ii & ni00O & ni00l & ni00i & ni01O & ni01l & ni01i & ni1OO & ni1Ol & ni1Oi & ni1lO & ni1ll & ni1li & ni1iO & ni1il & ni1ii & ni10O & ni10l & ni10i & ni11O & ni11l & ni11i & n0OOO & n0OOl & n0OOi & n0OlO & n1OlO);
	n000O :  oper_selector
	  GENERIC MAP (
		width_data => 27,
		width_sel => 27
	  )
	  PORT MAP ( 
		data => wire_n000O_data,
		o => wire_n000O_o,
		sel => wire_n000O_sel
	  );
	wire_n01lO_data <= ( "0" & wire_n00OO_dataout);
	wire_n01lO_sel <= ( niOO1O & wire_w_lg_niOO1O508w);
	n01lO :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_n01lO_data,
		o => wire_n01lO_o,
		sel => wire_n01lO_sel
	  );
	wire_n1Oii_data <= ( "0" & wire_n00OO_dataout & wire_n00ii_dataout);
	wire_n1Oii_sel <= ( niOO1l & ni10O & n0OlO);
	n1Oii :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n1Oii_data,
		o => wire_n1Oii_o,
		sel => wire_n1Oii_sel
	  );

 END RTL; --stratixiv_hssi_rx_digi_eii_module
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

--synthesis_resources = lut 14 mux21 120 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_rx_digi_pcs_channel_testbus IS 
	 PORT 
	 ( 
		 chnl_test_bus_out	:	OUT  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 rtest_bus_sel	:	IN  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 test_bus_in0	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 test_bus_in1	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 test_bus_in10	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 test_bus_in11	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 test_bus_in13	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 test_bus_in14	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 test_bus_in2	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 test_bus_in3	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 test_bus_in4	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 test_bus_in5	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 test_bus_in6	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 test_bus_in7	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0)
	 ); 
 END stratixiv_hssi_rx_digi_pcs_channel_testbus;

 ARCHITECTURE RTL OF stratixiv_hssi_rx_digi_pcs_channel_testbus IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 n000i1	:	STD_LOGIC := '0';
	 SIGNAL	 n000i2	:	STD_LOGIC := '0';
	 SIGNAL	 n001i3	:	STD_LOGIC := '0';
	 SIGNAL	 n001i4	:	STD_LOGIC := '0';
	 SIGNAL	 n010O13	:	STD_LOGIC := '0';
	 SIGNAL	 n010O14	:	STD_LOGIC := '0';
	 SIGNAL	 n01il11	:	STD_LOGIC := '0';
	 SIGNAL	 n01il12	:	STD_LOGIC := '0';
	 SIGNAL	 n01li10	:	STD_LOGIC := '0';
	 SIGNAL	 n01li9	:	STD_LOGIC := '0';
	 SIGNAL	 n01lO7	:	STD_LOGIC := '0';
	 SIGNAL	 n01lO8	:	STD_LOGIC := '0';
	 SIGNAL	 n01Ol5	:	STD_LOGIC := '0';
	 SIGNAL	 n01Ol6	:	STD_LOGIC := '0';
	 SIGNAL	wire_n00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_w_rtest_bus_sel_range132w146w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_rtest_bus_sel_range134w135w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  n000O :	STD_LOGIC;
	 SIGNAL  n001O :	STD_LOGIC;
	 SIGNAL  n00ii :	STD_LOGIC;
	 SIGNAL  n00il :	STD_LOGIC;
	 SIGNAL  n00iO :	STD_LOGIC;
	 SIGNAL  n00li :	STD_LOGIC;
	 SIGNAL  n00ll :	STD_LOGIC;
	 SIGNAL  n00lO :	STD_LOGIC;
	 SIGNAL  n00Oi :	STD_LOGIC;
	 SIGNAL  n00Ol :	STD_LOGIC;
	 SIGNAL  n00OO :	STD_LOGIC;
	 SIGNAL  n0i1i :	STD_LOGIC;
	 SIGNAL  n0i1l :	STD_LOGIC;
	 SIGNAL  wire_w_rtest_bus_sel_range132w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_rtest_bus_sel_range134w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_w_lg_w_rtest_bus_sel_range132w146w(0) <= wire_w_rtest_bus_sel_range132w(0) AND wire_w_lg_w_rtest_bus_sel_range134w135w(0);
	wire_w_lg_w_rtest_bus_sel_range134w135w(0) <= NOT wire_w_rtest_bus_sel_range134w(0);
	chnl_test_bus_out <= ( wire_nlili_dataout & wire_nliiO_dataout & wire_nliil_dataout & wire_nliii_dataout & wire_nli0O_dataout & wire_nli0l_dataout & wire_nli0i_dataout & wire_nli1O_dataout & wire_nli1l_dataout & wire_nli1i_dataout);
	n000O <= (((((NOT rtest_bus_sel(0)) AND wire_w_lg_w_rtest_bus_sel_range134w135w(0)) AND (NOT rtest_bus_sel(2))) AND (NOT rtest_bus_sel(3))) AND (n000i2 XOR n000i1));
	n00ii <= ((wire_w_lg_w_rtest_bus_sel_range132w146w(0) AND (NOT rtest_bus_sel(2))) AND (NOT rtest_bus_sel(3)));
	n00il <= (((((NOT rtest_bus_sel(0)) AND rtest_bus_sel(1)) AND (NOT rtest_bus_sel(2))) AND (NOT rtest_bus_sel(3))) AND (n001i4 XOR n001i3));
	n00iO <= (((rtest_bus_sel(0) AND rtest_bus_sel(1)) AND (NOT rtest_bus_sel(2))) AND (NOT rtest_bus_sel(3)));
	n00li <= (((((NOT rtest_bus_sel(0)) AND wire_w_lg_w_rtest_bus_sel_range134w135w(0)) AND rtest_bus_sel(2)) AND (NOT rtest_bus_sel(3))) AND (n01Ol6 XOR n01Ol5));
	n00ll <= ((wire_w_lg_w_rtest_bus_sel_range132w146w(0) AND rtest_bus_sel(2)) AND (NOT rtest_bus_sel(3)));
	n00lO <= ((((NOT rtest_bus_sel(0)) AND rtest_bus_sel(1)) AND rtest_bus_sel(2)) AND (NOT rtest_bus_sel(3)));
	n00Oi <= ((((rtest_bus_sel(0) AND rtest_bus_sel(1)) AND rtest_bus_sel(2)) AND (NOT rtest_bus_sel(3))) AND (n01lO8 XOR n01lO7));
	n00Ol <= (((((NOT rtest_bus_sel(0)) AND rtest_bus_sel(1)) AND (NOT rtest_bus_sel(2))) AND rtest_bus_sel(3)) AND (n01li10 XOR n01li9));
	n00OO <= ((((rtest_bus_sel(0) AND rtest_bus_sel(1)) AND (NOT rtest_bus_sel(2))) AND rtest_bus_sel(3)) AND (n01il12 XOR n01il11));
	n0i1i <= ((wire_w_lg_w_rtest_bus_sel_range132w146w(0) AND rtest_bus_sel(2)) AND rtest_bus_sel(3));
	n0i1l <= (((((NOT rtest_bus_sel(0)) AND rtest_bus_sel(1)) AND rtest_bus_sel(2)) AND rtest_bus_sel(3)) AND (n010O14 XOR n010O13));
	wire_w_rtest_bus_sel_range132w(0) <= rtest_bus_sel(0);
	wire_w_rtest_bus_sel_range134w(0) <= rtest_bus_sel(1);
	PROCESS (n001O)
	BEGIN
		IF (n001O = '1' AND n001O'event) THEN n000i1 <= n000i2;
		END IF;
		if (now = 0 ns) then
			n000i1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (n001O)
	BEGIN
		IF (n001O = '1' AND n001O'event) THEN n000i2 <= n000i1;
		END IF;
	END PROCESS;
	PROCESS (n001O)
	BEGIN
		IF (n001O = '1' AND n001O'event) THEN n001i3 <= n001i4;
		END IF;
		if (now = 0 ns) then
			n001i3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (n001O)
	BEGIN
		IF (n001O = '1' AND n001O'event) THEN n001i4 <= n001i3;
		END IF;
	END PROCESS;
	PROCESS (n001O)
	BEGIN
		IF (n001O = '1' AND n001O'event) THEN n010O13 <= n010O14;
		END IF;
		if (now = 0 ns) then
			n010O13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (n001O)
	BEGIN
		IF (n001O = '1' AND n001O'event) THEN n010O14 <= n010O13;
		END IF;
	END PROCESS;
	PROCESS (n001O)
	BEGIN
		IF (n001O = '1' AND n001O'event) THEN n01il11 <= n01il12;
		END IF;
		if (now = 0 ns) then
			n01il11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (n001O)
	BEGIN
		IF (n001O = '1' AND n001O'event) THEN n01il12 <= n01il11;
		END IF;
	END PROCESS;
	PROCESS (n001O)
	BEGIN
		IF (n001O = '1' AND n001O'event) THEN n01li10 <= n01li9;
		END IF;
	END PROCESS;
	PROCESS (n001O)
	BEGIN
		IF (n001O = '1' AND n001O'event) THEN n01li9 <= n01li10;
		END IF;
		if (now = 0 ns) then
			n01li9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (n001O)
	BEGIN
		IF (n001O = '1' AND n001O'event) THEN n01lO7 <= n01lO8;
		END IF;
		if (now = 0 ns) then
			n01lO7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (n001O)
	BEGIN
		IF (n001O = '1' AND n001O'event) THEN n01lO8 <= n01lO7;
		END IF;
	END PROCESS;
	PROCESS (n001O)
	BEGIN
		IF (n001O = '1' AND n001O'event) THEN n01Ol5 <= n01Ol6;
		END IF;
		if (now = 0 ns) then
			n01Ol5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (n001O)
	BEGIN
		IF (n001O = '1' AND n001O'event) THEN n01Ol6 <= n01Ol5;
		END IF;
	END PROCESS;
	wire_n00i_dataout <= test_bus_in6(3) WHEN n00lO = '1'  ELSE wire_n0Ol_dataout;
	wire_n00l_dataout <= test_bus_in6(4) WHEN n00lO = '1'  ELSE wire_n0OO_dataout;
	wire_n00O_dataout <= test_bus_in6(5) WHEN n00lO = '1'  ELSE wire_ni1i_dataout;
	wire_n01i_dataout <= test_bus_in6(0) WHEN n00lO = '1'  ELSE wire_n0ll_dataout;
	wire_n01l_dataout <= test_bus_in6(1) WHEN n00lO = '1'  ELSE wire_n0lO_dataout;
	wire_n01O_dataout <= test_bus_in6(2) WHEN n00lO = '1'  ELSE wire_n0Oi_dataout;
	wire_n0i_dataout <= test_bus_in13(8) WHEN n0i1i = '1'  ELSE wire_nl_dataout;
	wire_n0ii_dataout <= test_bus_in6(6) WHEN n00lO = '1'  ELSE wire_ni1l_dataout;
	wire_n0il_dataout <= test_bus_in6(7) WHEN n00lO = '1'  ELSE wire_ni1O_dataout;
	wire_n0iO_dataout <= test_bus_in6(8) WHEN n00lO = '1'  ELSE wire_ni0i_dataout;
	wire_n0l_dataout <= test_bus_in13(9) WHEN n0i1i = '1'  ELSE wire_nO_dataout;
	wire_n0li_dataout <= test_bus_in6(9) WHEN n00lO = '1'  ELSE wire_ni0l_dataout;
	wire_n0ll_dataout <= test_bus_in7(0) WHEN n00Oi = '1'  ELSE wire_ni0O_dataout;
	wire_n0lO_dataout <= test_bus_in7(1) WHEN n00Oi = '1'  ELSE wire_niii_dataout;
	wire_n0O_dataout <= test_bus_in14(0) WHEN n0i1l = '1'  ELSE test_bus_in0(0);
	wire_n0Oi_dataout <= test_bus_in7(2) WHEN n00Oi = '1'  ELSE wire_niil_dataout;
	wire_n0Ol_dataout <= test_bus_in7(3) WHEN n00Oi = '1'  ELSE wire_niiO_dataout;
	wire_n0OO_dataout <= test_bus_in7(4) WHEN n00Oi = '1'  ELSE wire_nili_dataout;
	wire_n10i_dataout <= test_bus_in4(8) WHEN n00li = '1'  ELSE wire_n1Ol_dataout;
	wire_n10l_dataout <= test_bus_in4(9) WHEN n00li = '1'  ELSE wire_n1OO_dataout;
	wire_n10O_dataout <= test_bus_in5(0) WHEN n00ll = '1'  ELSE wire_n01i_dataout;
	wire_n11i_dataout <= test_bus_in4(5) WHEN n00li = '1'  ELSE wire_n1ll_dataout;
	wire_n11l_dataout <= test_bus_in4(6) WHEN n00li = '1'  ELSE wire_n1lO_dataout;
	wire_n11O_dataout <= test_bus_in4(7) WHEN n00li = '1'  ELSE wire_n1Oi_dataout;
	wire_n1i_dataout <= test_bus_in13(5) WHEN n0i1i = '1'  ELSE wire_nll_dataout;
	wire_n1ii_dataout <= test_bus_in5(1) WHEN n00ll = '1'  ELSE wire_n01l_dataout;
	wire_n1il_dataout <= test_bus_in5(2) WHEN n00ll = '1'  ELSE wire_n01O_dataout;
	wire_n1iO_dataout <= test_bus_in5(3) WHEN n00ll = '1'  ELSE wire_n00i_dataout;
	wire_n1l_dataout <= test_bus_in13(6) WHEN n0i1i = '1'  ELSE wire_nlO_dataout;
	wire_n1li_dataout <= test_bus_in5(4) WHEN n00ll = '1'  ELSE wire_n00l_dataout;
	wire_n1ll_dataout <= test_bus_in5(5) WHEN n00ll = '1'  ELSE wire_n00O_dataout;
	wire_n1lO_dataout <= test_bus_in5(6) WHEN n00ll = '1'  ELSE wire_n0ii_dataout;
	wire_n1O_dataout <= test_bus_in13(7) WHEN n0i1i = '1'  ELSE wire_ni_dataout;
	wire_n1Oi_dataout <= test_bus_in5(7) WHEN n00ll = '1'  ELSE wire_n0il_dataout;
	wire_n1Ol_dataout <= test_bus_in5(8) WHEN n00ll = '1'  ELSE wire_n0iO_dataout;
	wire_n1OO_dataout <= test_bus_in5(9) WHEN n00ll = '1'  ELSE wire_n0li_dataout;
	wire_ni_dataout <= test_bus_in14(7) WHEN n0i1l = '1'  ELSE test_bus_in0(7);
	wire_ni0i_dataout <= test_bus_in7(8) WHEN n00Oi = '1'  ELSE wire_niOl_dataout;
	wire_ni0l_dataout <= test_bus_in7(9) WHEN n00Oi = '1'  ELSE wire_niOO_dataout;
	wire_ni0O_dataout <= test_bus_in10(0) WHEN n00Ol = '1'  ELSE wire_nl1i_dataout;
	wire_ni1i_dataout <= test_bus_in7(5) WHEN n00Oi = '1'  ELSE wire_nill_dataout;
	wire_ni1l_dataout <= test_bus_in7(6) WHEN n00Oi = '1'  ELSE wire_nilO_dataout;
	wire_ni1O_dataout <= test_bus_in7(7) WHEN n00Oi = '1'  ELSE wire_niOi_dataout;
	wire_nii_dataout <= test_bus_in14(1) WHEN n0i1l = '1'  ELSE test_bus_in0(1);
	wire_niii_dataout <= test_bus_in10(1) WHEN n00Ol = '1'  ELSE wire_nl1l_dataout;
	wire_niil_dataout <= test_bus_in10(2) WHEN n00Ol = '1'  ELSE wire_nl1O_dataout;
	wire_niiO_dataout <= test_bus_in10(3) WHEN n00Ol = '1'  ELSE wire_nl0i_dataout;
	wire_nil_dataout <= test_bus_in14(2) WHEN n0i1l = '1'  ELSE test_bus_in0(2);
	wire_nili_dataout <= test_bus_in10(4) WHEN n00Ol = '1'  ELSE wire_nl0l_dataout;
	wire_nill_dataout <= test_bus_in10(5) WHEN n00Ol = '1'  ELSE wire_nl0O_dataout;
	wire_nilO_dataout <= test_bus_in10(6) WHEN n00Ol = '1'  ELSE wire_nlii_dataout;
	wire_niO_dataout <= test_bus_in14(3) WHEN n0i1l = '1'  ELSE test_bus_in0(3);
	wire_niOi_dataout <= test_bus_in10(7) WHEN n00Ol = '1'  ELSE wire_nlil_dataout;
	wire_niOl_dataout <= test_bus_in10(8) WHEN n00Ol = '1'  ELSE wire_nliO_dataout;
	wire_niOO_dataout <= test_bus_in10(9) WHEN n00Ol = '1'  ELSE wire_nlli_dataout;
	wire_nl_dataout <= test_bus_in14(8) WHEN n0i1l = '1'  ELSE test_bus_in0(8);
	wire_nl0i_dataout <= test_bus_in11(3) WHEN n00OO = '1'  ELSE wire_nlOl_dataout;
	wire_nl0l_dataout <= test_bus_in11(4) WHEN n00OO = '1'  ELSE wire_nlOO_dataout;
	wire_nl0O_dataout <= test_bus_in11(5) WHEN n00OO = '1'  ELSE wire_n1i_dataout;
	wire_nl1i_dataout <= test_bus_in11(0) WHEN n00OO = '1'  ELSE wire_nlll_dataout;
	wire_nl1l_dataout <= test_bus_in11(1) WHEN n00OO = '1'  ELSE wire_nllO_dataout;
	wire_nl1O_dataout <= test_bus_in11(2) WHEN n00OO = '1'  ELSE wire_nlOi_dataout;
	wire_nli_dataout <= test_bus_in14(4) WHEN n0i1l = '1'  ELSE test_bus_in0(4);
	wire_nli0i_dataout <= test_bus_in0(3) WHEN n000O = '1'  ELSE wire_nliOl_dataout;
	wire_nli0l_dataout <= test_bus_in0(4) WHEN n000O = '1'  ELSE wire_nliOO_dataout;
	wire_nli0O_dataout <= test_bus_in0(5) WHEN n000O = '1'  ELSE wire_nll1i_dataout;
	wire_nli1i_dataout <= test_bus_in0(0) WHEN n000O = '1'  ELSE wire_nlill_dataout;
	wire_nli1l_dataout <= test_bus_in0(1) WHEN n000O = '1'  ELSE wire_nlilO_dataout;
	wire_nli1O_dataout <= test_bus_in0(2) WHEN n000O = '1'  ELSE wire_nliOi_dataout;
	wire_nlii_dataout <= test_bus_in11(6) WHEN n00OO = '1'  ELSE wire_n1l_dataout;
	wire_nliii_dataout <= test_bus_in0(6) WHEN n000O = '1'  ELSE wire_nll1l_dataout;
	wire_nliil_dataout <= test_bus_in0(7) WHEN n000O = '1'  ELSE wire_nll1O_dataout;
	wire_nliiO_dataout <= test_bus_in0(8) WHEN n000O = '1'  ELSE wire_nll0i_dataout;
	wire_nlil_dataout <= test_bus_in11(7) WHEN n00OO = '1'  ELSE wire_n1O_dataout;
	wire_nlili_dataout <= test_bus_in0(9) WHEN n000O = '1'  ELSE wire_nll0l_dataout;
	wire_nlill_dataout <= test_bus_in1(0) WHEN n00ii = '1'  ELSE wire_nll0O_dataout;
	wire_nlilO_dataout <= test_bus_in1(1) WHEN n00ii = '1'  ELSE wire_nllii_dataout;
	wire_nliO_dataout <= test_bus_in11(8) WHEN n00OO = '1'  ELSE wire_n0i_dataout;
	wire_nliOi_dataout <= test_bus_in1(2) WHEN n00ii = '1'  ELSE wire_nllil_dataout;
	wire_nliOl_dataout <= test_bus_in1(3) WHEN n00ii = '1'  ELSE wire_nlliO_dataout;
	wire_nliOO_dataout <= test_bus_in1(4) WHEN n00ii = '1'  ELSE wire_nllli_dataout;
	wire_nll_dataout <= test_bus_in14(5) WHEN n0i1l = '1'  ELSE test_bus_in0(5);
	wire_nll0i_dataout <= test_bus_in1(8) WHEN n00ii = '1'  ELSE wire_nllOl_dataout;
	wire_nll0l_dataout <= test_bus_in1(9) WHEN n00ii = '1'  ELSE wire_nllOO_dataout;
	wire_nll0O_dataout <= test_bus_in2(0) WHEN n00il = '1'  ELSE wire_nlO1i_dataout;
	wire_nll1i_dataout <= test_bus_in1(5) WHEN n00ii = '1'  ELSE wire_nllll_dataout;
	wire_nll1l_dataout <= test_bus_in1(6) WHEN n00ii = '1'  ELSE wire_nlllO_dataout;
	wire_nll1O_dataout <= test_bus_in1(7) WHEN n00ii = '1'  ELSE wire_nllOi_dataout;
	wire_nlli_dataout <= test_bus_in11(9) WHEN n00OO = '1'  ELSE wire_n0l_dataout;
	wire_nllii_dataout <= test_bus_in2(1) WHEN n00il = '1'  ELSE wire_nlO1l_dataout;
	wire_nllil_dataout <= test_bus_in2(2) WHEN n00il = '1'  ELSE wire_nlO1O_dataout;
	wire_nlliO_dataout <= test_bus_in2(3) WHEN n00il = '1'  ELSE wire_nlO0i_dataout;
	wire_nlll_dataout <= test_bus_in13(0) WHEN n0i1i = '1'  ELSE wire_n0O_dataout;
	wire_nllli_dataout <= test_bus_in2(4) WHEN n00il = '1'  ELSE wire_nlO0l_dataout;
	wire_nllll_dataout <= test_bus_in2(5) WHEN n00il = '1'  ELSE wire_nlO0O_dataout;
	wire_nlllO_dataout <= test_bus_in2(6) WHEN n00il = '1'  ELSE wire_nlOii_dataout;
	wire_nllO_dataout <= test_bus_in13(1) WHEN n0i1i = '1'  ELSE wire_nii_dataout;
	wire_nllOi_dataout <= test_bus_in2(7) WHEN n00il = '1'  ELSE wire_nlOil_dataout;
	wire_nllOl_dataout <= test_bus_in2(8) WHEN n00il = '1'  ELSE wire_nlOiO_dataout;
	wire_nllOO_dataout <= test_bus_in2(9) WHEN n00il = '1'  ELSE wire_nlOli_dataout;
	wire_nlO_dataout <= test_bus_in14(6) WHEN n0i1l = '1'  ELSE test_bus_in0(6);
	wire_nlO0i_dataout <= test_bus_in3(3) WHEN n00iO = '1'  ELSE wire_nlOOl_dataout;
	wire_nlO0l_dataout <= test_bus_in3(4) WHEN n00iO = '1'  ELSE wire_nlOOO_dataout;
	wire_nlO0O_dataout <= test_bus_in3(5) WHEN n00iO = '1'  ELSE wire_n11i_dataout;
	wire_nlO1i_dataout <= test_bus_in3(0) WHEN n00iO = '1'  ELSE wire_nlOll_dataout;
	wire_nlO1l_dataout <= test_bus_in3(1) WHEN n00iO = '1'  ELSE wire_nlOlO_dataout;
	wire_nlO1O_dataout <= test_bus_in3(2) WHEN n00iO = '1'  ELSE wire_nlOOi_dataout;
	wire_nlOi_dataout <= test_bus_in13(2) WHEN n0i1i = '1'  ELSE wire_nil_dataout;
	wire_nlOii_dataout <= test_bus_in3(6) WHEN n00iO = '1'  ELSE wire_n11l_dataout;
	wire_nlOil_dataout <= test_bus_in3(7) WHEN n00iO = '1'  ELSE wire_n11O_dataout;
	wire_nlOiO_dataout <= test_bus_in3(8) WHEN n00iO = '1'  ELSE wire_n10i_dataout;
	wire_nlOl_dataout <= test_bus_in13(3) WHEN n0i1i = '1'  ELSE wire_niO_dataout;
	wire_nlOli_dataout <= test_bus_in3(9) WHEN n00iO = '1'  ELSE wire_n10l_dataout;
	wire_nlOll_dataout <= test_bus_in4(0) WHEN n00li = '1'  ELSE wire_n10O_dataout;
	wire_nlOlO_dataout <= test_bus_in4(1) WHEN n00li = '1'  ELSE wire_n1ii_dataout;
	wire_nlOO_dataout <= test_bus_in13(4) WHEN n0i1i = '1'  ELSE wire_nli_dataout;
	wire_nlOOi_dataout <= test_bus_in4(2) WHEN n00li = '1'  ELSE wire_n1il_dataout;
	wire_nlOOl_dataout <= test_bus_in4(3) WHEN n00li = '1'  ELSE wire_n1iO_dataout;
	wire_nlOOO_dataout <= test_bus_in4(4) WHEN n00li = '1'  ELSE wire_n1li_dataout;
	wire_nO_dataout <= test_bus_in14(9) WHEN n0i1l = '1'  ELSE test_bus_in0(9);

 END RTL; --stratixiv_hssi_rx_digi_pcs_channel_testbus
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

--synthesis_resources = lut 18 mux21 19 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_rx_digi_iq_pipe_rx IS 
	 PORT 
	 ( 
		 clk_2_b_raw	:	IN  STD_LOGIC;
		 rd_enable_in_centrl	:	IN  STD_LOGIC;
		 rd_enable_in_pipe_quad_down	:	IN  STD_LOGIC;
		 rd_enable_in_pipe_quad_up	:	IN  STD_LOGIC;
		 rd_enable_out_pipe	:	OUT  STD_LOGIC;
		 reset_pc_ptrs_in_centrl	:	IN  STD_LOGIC;
		 reset_pc_ptrs_in_pipe_quad_down	:	IN  STD_LOGIC;
		 reset_pc_ptrs_in_pipe_quad_up	:	IN  STD_LOGIC;
		 reset_pc_ptrs_out_pipe	:	OUT  STD_LOGIC;
		 rfreerun_rx	:	IN  STD_LOGIC;
		 rmaster_rx	:	IN  STD_LOGIC;
		 rmaster_up_rx	:	IN  STD_LOGIC;
		 rpipeline_bypass_rx	:	IN  STD_LOGIC;
		 rx_div2_sync_in_centrl	:	IN  STD_LOGIC;
		 rx_div2_sync_in_pipe_quad_down	:	IN  STD_LOGIC;
		 rx_div2_sync_in_pipe_quad_up	:	IN  STD_LOGIC;
		 rx_div2_sync_out_pipe	:	OUT  STD_LOGIC;
		 rx_rd_clk_raw	:	IN  STD_LOGIC;
		 rx_we_in_centrl	:	IN  STD_LOGIC;
		 rx_we_in_pipe_quad_down	:	IN  STD_LOGIC;
		 rx_we_in_pipe_quad_up	:	IN  STD_LOGIC;
		 rx_we_out_pipe	:	OUT  STD_LOGIC;
		 rx_wr_clk_raw	:	IN  STD_LOGIC;
		 rxrst	:	IN  STD_LOGIC;
		 soft_reset_rclk1	:	IN  STD_LOGIC;
		 soft_reset_wclk1	:	IN  STD_LOGIC;
		 speed_change_in_centrl	:	IN  STD_LOGIC;
		 speed_change_in_pipe_quad_down	:	IN  STD_LOGIC;
		 speed_change_in_pipe_quad_up	:	IN  STD_LOGIC;
		 speed_change_out_pipe	:	OUT  STD_LOGIC;
		 wr_enable_in_centrl	:	IN  STD_LOGIC;
		 wr_enable_in_pipe_quad_down	:	IN  STD_LOGIC;
		 wr_enable_in_pipe_quad_up	:	IN  STD_LOGIC;
		 wr_enable_out_pipe	:	OUT  STD_LOGIC
	 ); 
 END stratixiv_hssi_rx_digi_iq_pipe_rx;

 ARCHITECTURE RTL OF stratixiv_hssi_rx_digi_iq_pipe_rx IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 n10i10	:	STD_LOGIC := '0';
	 SIGNAL	 n10i9	:	STD_LOGIC := '0';
	 SIGNAL	 n10l7	:	STD_LOGIC := '0';
	 SIGNAL	 n10l8	:	STD_LOGIC := '0';
	 SIGNAL	 n10O5	:	STD_LOGIC := '0';
	 SIGNAL	 n10O6	:	STD_LOGIC := '0';
	 SIGNAL	 n11O11	:	STD_LOGIC := '0';
	 SIGNAL	 n11O12	:	STD_LOGIC := '0';
	 SIGNAL	 n1il3	:	STD_LOGIC := '0';
	 SIGNAL	 n1il4	:	STD_LOGIC := '0';
	 SIGNAL	 n1ll1	:	STD_LOGIC := '0';
	 SIGNAL	 n1ll2	:	STD_LOGIC := '0';
	 SIGNAL	nlii	:	STD_LOGIC := '0';
	 SIGNAL	nO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl_CLRN	:	STD_LOGIC;
	 SIGNAL	nliO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlil_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nlil_PRN	:	STD_LOGIC;
	 SIGNAL	nlll	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlli_PRN	:	STD_LOGIC;
	 SIGNAL	nlOi	:	STD_LOGIC := '0';
	 SIGNAL	wire_nllO_CLRN	:	STD_LOGIC;
	 SIGNAL	ni	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlO_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOl_w_lg_dataout7w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_rmaster_rx5w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rxrst2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_soft_reset_rclk111w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_soft_reset_wclk18w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  n1iO :	STD_LOGIC;
 BEGIN

	wire_w_lg_rmaster_rx5w(0) <= NOT rmaster_rx;
	wire_w_lg_rxrst2w(0) <= NOT rxrst;
	wire_w_lg_soft_reset_rclk111w(0) <= NOT soft_reset_rclk1;
	wire_w_lg_soft_reset_wclk18w(0) <= NOT soft_reset_wclk1;
	n1iO <= '1';
	rd_enable_out_pipe <= wire_nl1O_dataout;
	reset_pc_ptrs_out_pipe <= wire_nl1l_dataout;
	rx_div2_sync_out_pipe <= wire_nl0O_dataout;
	rx_we_out_pipe <= wire_nl0l_dataout;
	speed_change_out_pipe <= wire_nl1i_dataout;
	wr_enable_out_pipe <= wire_nl0i_dataout;
	PROCESS (clk_2_b_raw)
	BEGIN
		IF (clk_2_b_raw = '1' AND clk_2_b_raw'event) THEN n10i10 <= n10i9;
		END IF;
	END PROCESS;
	PROCESS (clk_2_b_raw)
	BEGIN
		IF (clk_2_b_raw = '1' AND clk_2_b_raw'event) THEN n10i9 <= n10i10;
		END IF;
		if (now = 0 ns) then
			n10i9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2_b_raw)
	BEGIN
		IF (clk_2_b_raw = '1' AND clk_2_b_raw'event) THEN n10l7 <= n10l8;
		END IF;
		if (now = 0 ns) then
			n10l7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2_b_raw)
	BEGIN
		IF (clk_2_b_raw = '1' AND clk_2_b_raw'event) THEN n10l8 <= n10l7;
		END IF;
	END PROCESS;
	PROCESS (clk_2_b_raw)
	BEGIN
		IF (clk_2_b_raw = '1' AND clk_2_b_raw'event) THEN n10O5 <= n10O6;
		END IF;
		if (now = 0 ns) then
			n10O5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2_b_raw)
	BEGIN
		IF (clk_2_b_raw = '1' AND clk_2_b_raw'event) THEN n10O6 <= n10O5;
		END IF;
	END PROCESS;
	PROCESS (clk_2_b_raw)
	BEGIN
		IF (clk_2_b_raw = '1' AND clk_2_b_raw'event) THEN n11O11 <= n11O12;
		END IF;
		if (now = 0 ns) then
			n11O11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2_b_raw)
	BEGIN
		IF (clk_2_b_raw = '1' AND clk_2_b_raw'event) THEN n11O12 <= n11O11;
		END IF;
	END PROCESS;
	PROCESS (clk_2_b_raw)
	BEGIN
		IF (clk_2_b_raw = '1' AND clk_2_b_raw'event) THEN n1il3 <= n1il4;
		END IF;
		if (now = 0 ns) then
			n1il3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2_b_raw)
	BEGIN
		IF (clk_2_b_raw = '1' AND clk_2_b_raw'event) THEN n1il4 <= n1il3;
		END IF;
	END PROCESS;
	PROCESS (clk_2_b_raw)
	BEGIN
		IF (clk_2_b_raw = '1' AND clk_2_b_raw'event) THEN n1ll1 <= n1ll2;
		END IF;
		if (now = 0 ns) then
			n1ll1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2_b_raw)
	BEGIN
		IF (clk_2_b_raw = '1' AND clk_2_b_raw'event) THEN n1ll2 <= n1ll1;
		END IF;
	END PROCESS;
	PROCESS (clk_2_b_raw, wire_nl_CLRN)
	BEGIN
		IF (wire_nl_CLRN = '0') THEN
				nlii <= '0';
				nO <= '0';
		ELSIF (clk_2_b_raw = '1' AND clk_2_b_raw'event) THEN
				nlii <= wire_n1l_dataout;
				nO <= wire_nlOO_dataout;
		END IF;
	END PROCESS;
	wire_nl_CLRN <= ((n1ll2 XOR n1ll1) AND wire_w_lg_rxrst2w(0));
	PROCESS (rx_rd_clk_raw, wire_nlil_PRN, wire_nlil_CLRN)
	BEGIN
		IF (wire_nlil_PRN = '0') THEN
				nliO <= '1';
		ELSIF (wire_nlil_CLRN = '0') THEN
				nliO <= '0';
		ELSIF (rx_rd_clk_raw = '1' AND rx_rd_clk_raw'event) THEN
				nliO <= wire_n0i_dataout;
		END IF;
	END PROCESS;
	wire_nlil_CLRN <= ((n10i10 XOR n10i9) AND wire_w_lg_soft_reset_rclk111w(0));
	wire_nlil_PRN <= (n11O12 XOR n11O11);
	PROCESS (rx_wr_clk_raw, wire_nlli_PRN, soft_reset_wclk1)
	BEGIN
		IF (wire_nlli_PRN = '0') THEN
				nlll <= '1';
		ELSIF (soft_reset_wclk1 = '1') THEN
				nlll <= '0';
		ELSIF (rx_wr_clk_raw = '1' AND rx_wr_clk_raw'event) THEN
				nlll <= wire_n0O_dataout;
		END IF;
	END PROCESS;
	wire_nlli_PRN <= (n10l8 XOR n10l7);
	PROCESS (clk_2_b_raw, wire_nlOl_dataout, wire_nllO_CLRN)
	BEGIN
		IF (wire_nlOl_dataout = '1') THEN
				nlOi <= '1';
		ELSIF (wire_nllO_CLRN = '0') THEN
				nlOi <= '0';
		ELSIF (clk_2_b_raw = '1' AND clk_2_b_raw'event) THEN
				nlOi <= wire_nli_dataout;
		END IF;
		if (now = 0 ns) then
			nlOi <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nllO_CLRN <= (n10O6 XOR n10O5);
	PROCESS (clk_2_b_raw, rxrst, wire_nlO_CLRN)
	BEGIN
		IF (rxrst = '1') THEN
				ni <= '1';
		ELSIF (wire_nlO_CLRN = '0') THEN
				ni <= '0';
		ELSIF (clk_2_b_raw = '1' AND clk_2_b_raw'event) THEN
				ni <= wire_nil_dataout;
		END IF;
		if (now = 0 ns) then
			ni <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nlO_CLRN <= (n1il4 XOR n1il3);
	wire_n0i_dataout <= wire_n0l_dataout WHEN wire_w_lg_rmaster_rx5w(0) = '1'  ELSE rd_enable_in_centrl;
	wire_n0l_dataout <= rd_enable_in_pipe_quad_up WHEN rmaster_up_rx = '1'  ELSE rd_enable_in_pipe_quad_down;
	wire_n0O_dataout <= wire_nii_dataout WHEN wire_w_lg_rmaster_rx5w(0) = '1'  ELSE wr_enable_in_centrl;
	wire_n1i_dataout <= speed_change_in_pipe_quad_up WHEN rmaster_up_rx = '1'  ELSE speed_change_in_pipe_quad_down;
	wire_n1l_dataout <= wire_n1O_dataout WHEN wire_w_lg_rmaster_rx5w(0) = '1'  ELSE reset_pc_ptrs_in_centrl;
	wire_n1O_dataout <= reset_pc_ptrs_in_pipe_quad_up WHEN rmaster_up_rx = '1'  ELSE reset_pc_ptrs_in_pipe_quad_down;
	wire_nii_dataout <= wr_enable_in_pipe_quad_up WHEN rmaster_up_rx = '1'  ELSE wr_enable_in_pipe_quad_down;
	wire_nil_dataout <= wire_niO_dataout WHEN wire_w_lg_rmaster_rx5w(0) = '1'  ELSE rx_we_in_centrl;
	wire_niO_dataout <= rx_we_in_pipe_quad_up WHEN rmaster_up_rx = '1'  ELSE rx_we_in_pipe_quad_down;
	wire_nl0i_dataout <= wire_n0O_dataout WHEN rpipeline_bypass_rx = '1'  ELSE nlll;
	wire_nl0l_dataout <= wire_nil_dataout WHEN rpipeline_bypass_rx = '1'  ELSE ni;
	wire_nl0O_dataout <= wire_nli_dataout WHEN rpipeline_bypass_rx = '1'  ELSE nlOi;
	wire_nl1i_dataout <= wire_nlOO_dataout WHEN rpipeline_bypass_rx = '1'  ELSE nO;
	wire_nl1l_dataout <= wire_n1l_dataout WHEN rpipeline_bypass_rx = '1'  ELSE nlii;
	wire_nl1O_dataout <= wire_n0i_dataout WHEN rpipeline_bypass_rx = '1'  ELSE nliO;
	wire_nli_dataout <= wire_nll_dataout WHEN wire_w_lg_rmaster_rx5w(0) = '1'  ELSE rx_div2_sync_in_centrl;
	wire_nll_dataout <= rx_div2_sync_in_pipe_quad_up WHEN rmaster_up_rx = '1'  ELSE rx_div2_sync_in_pipe_quad_down;
	wire_nlOl_dataout <= rxrst AND NOT(rfreerun_rx);
	wire_nlOl_w_lg_dataout7w(0) <= NOT wire_nlOl_dataout;
	wire_nlOO_dataout <= wire_n1i_dataout WHEN wire_w_lg_rmaster_rx5w(0) = '1'  ELSE speed_change_in_centrl;

 END RTL; --stratixiv_hssi_rx_digi_iq_pipe_rx
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 122 mux21 276 oper_add 1 oper_decoder 1 oper_less_than 1 oper_mux 36 oper_selector 10 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_rx_digi_prbs_ver IS 
	 PORT 
	 ( 
		 cid_en	:	IN  STD_LOGIC;
		 data_in	:	IN  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 encdet_prbs	:	OUT  STD_LOGIC;
		 prbs_done	:	OUT  STD_LOGIC;
		 prbs_err	:	OUT  STD_LOGIC;
		 prbs_err_lt	:	OUT  STD_LOGIC;
		 rall_one_dect_only	:	IN  STD_LOGIC;
		 rcid_len	:	IN  STD_LOGIC_VECTOR (7 DOWNTO 0);
		 rcid_pattern	:	IN  STD_LOGIC;
		 rcvd_clk	:	IN  STD_LOGIC;
		 rpma_doublewidth_rx	:	IN  STD_LOGIC;
		 rpmadwidth_rx	:	IN  STD_LOGIC;
		 rprbs_clr_rslt_rx	:	IN  STD_LOGIC;
		 rprbs_en_rx	:	IN  STD_LOGIC;
		 rprbs_sel	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 scan_mode	:	IN  STD_LOGIC;
		 soft_reset	:	IN  STD_LOGIC;
		 sync_status	:	IN  STD_LOGIC;
		 verify_on	:	OUT  STD_LOGIC
	 ); 
 END stratixiv_hssi_rx_digi_prbs_ver;

 ARCHITECTURE RTL OF stratixiv_hssi_rx_digi_prbs_ver IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 nillOi49	:	STD_LOGIC := '0';
	 SIGNAL	 nillOi50	:	STD_LOGIC := '0';
	 SIGNAL  wire_nillOi50_w_lg_w_lg_q242w243w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nillOi50_w_lg_q242w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nillOl47	:	STD_LOGIC := '0';
	 SIGNAL	 nillOl48	:	STD_LOGIC := '0';
	 SIGNAL  wire_nillOl48_w_lg_w_lg_q239w240w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nillOl48_w_lg_q239w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nillOO45	:	STD_LOGIC := '0';
	 SIGNAL	 nillOO46	:	STD_LOGIC := '0';
	 SIGNAL  wire_nillOO46_w_lg_w_lg_q235w236w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nillOO46_w_lg_q235w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nilO1i43	:	STD_LOGIC := '0';
	 SIGNAL	 nilO1i44	:	STD_LOGIC := '0';
	 SIGNAL  wire_nilO1i44_w_lg_w_lg_q229w230w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nilO1i44_w_lg_q229w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nilO1O41	:	STD_LOGIC := '0';
	 SIGNAL	 nilO1O42	:	STD_LOGIC := '0';
	 SIGNAL  wire_nilO1O42_w_lg_w_lg_q221w223w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nilO1O42_w_lg_q221w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nilOiO39	:	STD_LOGIC := '0';
	 SIGNAL	 nilOiO40	:	STD_LOGIC := '0';
	 SIGNAL  wire_nilOiO40_w_lg_w_lg_q187w189w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nilOiO40_w_lg_q187w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niO00i21	:	STD_LOGIC := '0';
	 SIGNAL	 niO00i22	:	STD_LOGIC := '0';
	 SIGNAL  wire_niO00i22_w_lg_q110w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niO01l23	:	STD_LOGIC := '0';
	 SIGNAL	 niO01l24	:	STD_LOGIC := '0';
	 SIGNAL	 niO0iO19	:	STD_LOGIC := '0';
	 SIGNAL	 niO0iO20	:	STD_LOGIC := '0';
	 SIGNAL	 niO0ll17	:	STD_LOGIC := '0';
	 SIGNAL	 niO0ll18	:	STD_LOGIC := '0';
	 SIGNAL  wire_niO0ll18_w_lg_w_lg_q97w98w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO0ll18_w_lg_q97w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niO0lO15	:	STD_LOGIC := '0';
	 SIGNAL	 niO0lO16	:	STD_LOGIC := '0';
	 SIGNAL  wire_niO0lO16_w_lg_w_lg_q91w92w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO0lO16_w_lg_q91w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niO0Oi13	:	STD_LOGIC := '0';
	 SIGNAL	 niO0Oi14	:	STD_LOGIC := '0';
	 SIGNAL	 niO0OO11	:	STD_LOGIC := '0';
	 SIGNAL	 niO0OO12	:	STD_LOGIC := '0';
	 SIGNAL  wire_niO0OO12_w_lg_w_lg_q32w33w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO0OO12_w_lg_q32w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niO10i35	:	STD_LOGIC := '0';
	 SIGNAL	 niO10i36	:	STD_LOGIC := '0';
	 SIGNAL	 niO10l33	:	STD_LOGIC := '0';
	 SIGNAL	 niO10l34	:	STD_LOGIC := '0';
	 SIGNAL	 niO11i37	:	STD_LOGIC := '0';
	 SIGNAL	 niO11i38	:	STD_LOGIC := '0';
	 SIGNAL	 niO1li31	:	STD_LOGIC := '0';
	 SIGNAL	 niO1li32	:	STD_LOGIC := '0';
	 SIGNAL  wire_niO1li32_w_lg_w_lg_q159w160w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO1li32_w_lg_q159w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niO1ll29	:	STD_LOGIC := '0';
	 SIGNAL	 niO1ll30	:	STD_LOGIC := '0';
	 SIGNAL  wire_niO1ll30_w_lg_w_lg_q142w143w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO1ll30_w_lg_q142w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niO1lO27	:	STD_LOGIC := '0';
	 SIGNAL	 niO1lO28	:	STD_LOGIC := '0';
	 SIGNAL  wire_niO1lO28_w_lg_w_lg_q138w139w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO1lO28_w_lg_q138w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niO1Ol25	:	STD_LOGIC := '0';
	 SIGNAL	 niO1Ol26	:	STD_LOGIC := '0';
	 SIGNAL  wire_niO1Ol26_w_lg_w_lg_q125w126w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO1Ol26_w_lg_q125w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niOi0l3	:	STD_LOGIC := '0';
	 SIGNAL	 niOi0l4	:	STD_LOGIC := '0';
	 SIGNAL	 niOi1i10	:	STD_LOGIC := '0';
	 SIGNAL  wire_niOi1i10_w_lg_w_lg_q28w29w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOi1i10_w_lg_q28w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niOi1i9	:	STD_LOGIC := '0';
	 SIGNAL	 niOi1l7	:	STD_LOGIC := '0';
	 SIGNAL	 niOi1l8	:	STD_LOGIC := '0';
	 SIGNAL  wire_niOi1l8_w_lg_w_lg_q25w26w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOi1l8_w_lg_q25w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niOi1O5	:	STD_LOGIC := '0';
	 SIGNAL	 niOi1O6	:	STD_LOGIC := '0';
	 SIGNAL  wire_niOi1O6_w_lg_w_lg_q20w21w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOi1O6_w_lg_q20w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niOiii1	:	STD_LOGIC := '0';
	 SIGNAL	 niOiii2	:	STD_LOGIC := '0';
	 SIGNAL	n0i	:	STD_LOGIC := '0';
	 SIGNAL	n0l	:	STD_LOGIC := '0';
	 SIGNAL	n0O	:	STD_LOGIC := '0';
	 SIGNAL	nii	:	STD_LOGIC := '0';
	 SIGNAL	nil	:	STD_LOGIC := '0';
	 SIGNAL	niO	:	STD_LOGIC := '0';
	 SIGNAL	nl	:	STD_LOGIC := '0';
	 SIGNAL	nl0i	:	STD_LOGIC := '0';
	 SIGNAL	nl0l	:	STD_LOGIC := '0';
	 SIGNAL	nl0O	:	STD_LOGIC := '0';
	 SIGNAL	nl1i	:	STD_LOGIC := '0';
	 SIGNAL	nl1l	:	STD_LOGIC := '0';
	 SIGNAL	nl1O	:	STD_LOGIC := '0';
	 SIGNAL	nli	:	STD_LOGIC := '0';
	 SIGNAL	nlii	:	STD_LOGIC := '0';
	 SIGNAL	nlil	:	STD_LOGIC := '0';
	 SIGNAL	nliO	:	STD_LOGIC := '0';
	 SIGNAL	nll	:	STD_LOGIC := '0';
	 SIGNAL	nlO	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_ni_w_lg_w_lg_w_lg_nlO108w111w112w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_w_lg_nlO108w111w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nlO108w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nl0i2979w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nl0l2977w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nl0O2975w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nl1l2983w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nl1O2981w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nlii2973w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nlil2972w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni_w_lg_nll2606w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	niOi	:	STD_LOGIC := '0';
	 SIGNAL	nlliO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nilO_PRN	:	STD_LOGIC;
	 SIGNAL	niOO	:	STD_LOGIC := '0';
	 SIGNAL	nli0lO	:	STD_LOGIC := '0';
	 SIGNAL	nlii0O	:	STD_LOGIC := '0';
	 SIGNAL	nliOl	:	STD_LOGIC := '0';
	 SIGNAL	nll0il	:	STD_LOGIC := '0';
	 SIGNAL	nll0iO	:	STD_LOGIC := '0';
	 SIGNAL	nll0li	:	STD_LOGIC := '0';
	 SIGNAL	nll0ll	:	STD_LOGIC := '0';
	 SIGNAL	nll0lO	:	STD_LOGIC := '0';
	 SIGNAL	nll0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nll0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nll0OO	:	STD_LOGIC := '0';
	 SIGNAL	nlli0i	:	STD_LOGIC := '0';
	 SIGNAL	nlli0l	:	STD_LOGIC := '0';
	 SIGNAL	nlli0O	:	STD_LOGIC := '0';
	 SIGNAL	nlli1i	:	STD_LOGIC := '0';
	 SIGNAL	nlli1l	:	STD_LOGIC := '0';
	 SIGNAL	nlli1O	:	STD_LOGIC := '0';
	 SIGNAL	nlliii	:	STD_LOGIC := '0';
	 SIGNAL	nlliil	:	STD_LOGIC := '0';
	 SIGNAL	nlliiO	:	STD_LOGIC := '0';
	 SIGNAL	nllili	:	STD_LOGIC := '0';
	 SIGNAL	nllill	:	STD_LOGIC := '0';
	 SIGNAL	nllilO	:	STD_LOGIC := '0';
	 SIGNAL	nlliOi	:	STD_LOGIC := '0';
	 SIGNAL	nlliOl	:	STD_LOGIC := '0';
	 SIGNAL	nlliOO	:	STD_LOGIC := '0';
	 SIGNAL	nlll0i	:	STD_LOGIC := '0';
	 SIGNAL	nlll0l	:	STD_LOGIC := '0';
	 SIGNAL	nlll0O	:	STD_LOGIC := '0';
	 SIGNAL	nlll1i	:	STD_LOGIC := '0';
	 SIGNAL	nlll1l	:	STD_LOGIC := '0';
	 SIGNAL	nlll1O	:	STD_LOGIC := '0';
	 SIGNAL	nlllii	:	STD_LOGIC := '0';
	 SIGNAL	wire_nliOi_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_w_lg_w3441w3442w3443w3444w3445w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_w3441w3442w3443w3444w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w3441w3442w3443w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w3441w3442w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w3357w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w3441w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_w_lg_w3350w3352w3353w3355w3356w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_w_lg_w3436w3437w3438w3439w3440w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_w3306w3307w3308w3309w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_w3350w3352w3353w3355w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_w3436w3437w3438w3439w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w3306w3307w3308w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w3350w3352w3353w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w3436w3437w3438w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w3306w3307w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w3350w3352w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w3436w3437w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w3219w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w2989w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w3306w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w3350w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w3436w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_w_lg_nll0Ol3215w3222w3223w3224w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_w_lg_nll0Ol3215w3216w3217w3218w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlliii2965w2966w2987w2988w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_w_lg_nll0Ol3202w3203w3205w3206w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlliii2993w2994w2996w2997w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlliiO3302w3303w3304w3305w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlliOO3344w3346w3347w3348w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlll0i3430w3431w3433w3435w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_nll0Ol3215w3222w3223w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_nll0Ol3215w3216w3217w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_nlliii2965w2966w2987w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_nll0Ol3202w3203w3205w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_nlliii2993w2994w2996w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_nlliiO3302w3303w3304w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_nlliOO3344w3346w3347w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_w_lg_nlll0i3430w3431w3433w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_nll0Ol3215w3222w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_nll0Ol3215w3216w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_nlliii2965w2966w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_nll0Ol3202w3203w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_nlliii2993w2994w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_nlliiO3302w3303w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_nlliOO3344w3346w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_nlll0i3430w3431w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlii0O2954w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlii0O2944w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nll0Ol3215w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlliii2965w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nli0lO3213w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nll0il3211w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nll0iO3209w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nll0li3207w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nll0lO3204w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nll0Ol3202w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nll0OO3003w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlli0i2986w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlli0l2995w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlli1i2990w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlli1l3000w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlli1O2998w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlliii2993w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlliil3354w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlliiO3302w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nllili3351w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nllill3349w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlliOl3345w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlliOO3344w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlll0i3430w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlll1i3434w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlll1l3432w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_nlliii2127w2128w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_nlliOl1740w1741w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_nlliOO1669w1670w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_nlll0i1685w1686w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_nlll1i2573w2574w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_nlll1l2504w2505w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_w_lg_nlll1O1756w1757w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlli0l2436w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlli0O2370w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlli0O2339w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlli1l2531w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlli1O2059w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlli1O2462w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlliii2273w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlliii2127w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlliil2207w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlliiO2139w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nllili2557w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nllill2086w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nllill2488w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nllilO2017w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlliOi1948w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlliOl1740w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlliOl1879w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlliOO1669w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlll0i1685w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlll0i1825w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlll1i2573w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlll1i2032w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlll1l2504w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlll1l1963w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlll1O1756w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliOi_w_lg_nlll1O1894w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nli00O	:	STD_LOGIC := '0';
	 SIGNAL	nli0ii	:	STD_LOGIC := '0';
	 SIGNAL	nli0il	:	STD_LOGIC := '0';
	 SIGNAL	nli0iO	:	STD_LOGIC := '0';
	 SIGNAL	nli0li	:	STD_LOGIC := '0';
	 SIGNAL	nli0ll	:	STD_LOGIC := '0';
	 SIGNAL	nliiO	:	STD_LOGIC := '0';
	 SIGNAL	nlili	:	STD_LOGIC := '0';
	 SIGNAL	nlill	:	STD_LOGIC := '0';
	 SIGNAL	nlilO	:	STD_LOGIC := '0';
	 SIGNAL	nliOO	:	STD_LOGIC := '0';
	 SIGNAL	nll0i	:	STD_LOGIC := '0';
	 SIGNAL	nll1i	:	STD_LOGIC := '0';
	 SIGNAL	nll1l	:	STD_LOGIC := '0';
	 SIGNAL	nlllil	:	STD_LOGIC := '0';
	 SIGNAL  wire_nll1O_w_lg_nli0li2861w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll1O_w_lg_nli0li2856w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll1O_w_lg_nli0li2902w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll1O_w_lg_nli0li2886w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll1O_w_lg_nli0li2589w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll1O_w_lg_nll1l2599w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll1O_w_lg_w_lg_nli0li2856w2857w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll1O_w_lg_w_lg_nli0li2902w2903w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll1O_w_lg_w_lg_nli0li2886w2887w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nll0l	:	STD_LOGIC := '0';
	 SIGNAL	nllil	:	STD_LOGIC := '0';
	 SIGNAL	wire_nllii_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nllii_PRN	:	STD_LOGIC;
	 SIGNAL	wire_n00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nilii_w_lg_dataout2862w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nilii_w_lg_dataout2621w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nilii_w_lg_w_lg_dataout2862w2863w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nilil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nilil_w_lg_dataout2635w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nll0O_w_lg_dataout167w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nll1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllli_w_lg_dataout3262w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nllliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO1i_w_lg_dataout3255w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlO1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlO1l_w_lg_w_lg_w3259w3260w3261w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1l_w_lg_w3259w3260w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1l_w3259w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1l_w_lg_w_lg_w_lg_w_lg_dataout3254w3256w3257w3258w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1l_w_lg_w_lg_w_lg_dataout3254w3256w3257w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1l_w_lg_w_lg_dataout3254w3256w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO1l_w_lg_dataout3254w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlO1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1O_a	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_n1O_b	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_gnd	:	STD_LOGIC;
	 SIGNAL  wire_n1O_o	:	STD_LOGIC_VECTOR (8 DOWNTO 0);
	 SIGNAL  wire_nil0O_i	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nil0O_o	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nill_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nill_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nill_o	:	STD_LOGIC;
	 SIGNAL  wire_n100i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n100i_o	:	STD_LOGIC;
	 SIGNAL  wire_n100i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n100l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n100l_o	:	STD_LOGIC;
	 SIGNAL  wire_n100l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n100O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n100O_o	:	STD_LOGIC;
	 SIGNAL  wire_n100O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n101i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n101i_o	:	STD_LOGIC;
	 SIGNAL  wire_n101i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n101l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n101l_o	:	STD_LOGIC;
	 SIGNAL  wire_n101l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n101O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n101O_o	:	STD_LOGIC;
	 SIGNAL  wire_n101O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n10ii_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n10ii_o	:	STD_LOGIC;
	 SIGNAL  wire_n10ii_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n10il_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n10il_o	:	STD_LOGIC;
	 SIGNAL  wire_n10il_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n10iO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n10iO_o	:	STD_LOGIC;
	 SIGNAL  wire_n10iO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n10li_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n10li_o	:	STD_LOGIC;
	 SIGNAL  wire_n10li_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n10ll_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n10ll_o	:	STD_LOGIC;
	 SIGNAL  wire_n10ll_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n10lO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n10lO_o	:	STD_LOGIC;
	 SIGNAL  wire_n10lO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n110l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n110l_o	:	STD_LOGIC;
	 SIGNAL  wire_n110l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n110O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n110O_o	:	STD_LOGIC;
	 SIGNAL  wire_n110O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n11ii_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n11ii_o	:	STD_LOGIC;
	 SIGNAL  wire_n11ii_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n11il_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n11il_o	:	STD_LOGIC;
	 SIGNAL  wire_n11il_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n11iO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n11iO_o	:	STD_LOGIC;
	 SIGNAL  wire_n11iO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n11li_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n11li_o	:	STD_LOGIC;
	 SIGNAL  wire_n11li_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n11ll_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n11ll_o	:	STD_LOGIC;
	 SIGNAL  wire_n11ll_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n11lO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n11lO_o	:	STD_LOGIC;
	 SIGNAL  wire_n11lO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n11Oi_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n11Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_n11Oi_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n11Ol_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n11Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_n11Ol_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n11OO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_n11OO_o	:	STD_LOGIC;
	 SIGNAL  wire_n11OO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nii0i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nii0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nii0i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nii0l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nii0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nii0l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nii0O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nii0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nii0O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nii1O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nii1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nii1O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niiii_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_niiii_o	:	STD_LOGIC;
	 SIGNAL  wire_niiii_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niiiO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_niiiO_o	:	STD_LOGIC;
	 SIGNAL  wire_niiiO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niill_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_niill_o	:	STD_LOGIC;
	 SIGNAL  wire_niill_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_niilO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_niilO_o	:	STD_LOGIC;
	 SIGNAL  wire_niilO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nliiiO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nliiiO_o	:	STD_LOGIC;
	 SIGNAL  wire_nliiiO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nliili_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nliili_o	:	STD_LOGIC;
	 SIGNAL  wire_nliili_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nliill_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nliill_o	:	STD_LOGIC;
	 SIGNAL  wire_nliill_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nliilO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nliilO_o	:	STD_LOGIC;
	 SIGNAL  wire_nliilO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nliiOi_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nliiOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nliiOi_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n0ll_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0ll_o	:	STD_LOGIC;
	 SIGNAL  wire_n0ll_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0lO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0lO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0lO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0Oi_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oi_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0Ol_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_n0Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Ol_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_ni0iO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_ni0iO_o	:	STD_LOGIC;
	 SIGNAL  wire_ni0iO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_ni0lO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_ni0lO_o	:	STD_LOGIC;
	 SIGNAL  wire_ni0lO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl00i_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nl00i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00i_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nl0iO_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nl0iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0iO_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nl0OO_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nl0OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0OO_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nli0O_data	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nli0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nli0O_sel	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rpmadwidth_rx3059w3167w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOi0O113w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rpmadwidth_rx3110w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_sync_status2690w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_sync_status2674w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niil0O2953w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niilii2943w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niilll2631w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niilOl2627w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiO1i2625w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiO1O2623w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiOil2615w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiOll2612w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiOOi2610w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil10i2600w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nililO2595w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niliOi2594w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niliOl2593w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niliOO2592w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nill1i2591w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nill1l2590w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nill1O2588w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nillil256w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilliO254w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nillli252w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nillll250w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilllO248w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilO0i209w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilO0l207w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilO0O205w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilO1l226w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOii203w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOil201w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOli188w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOll183w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOlO181w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOOi179w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOOl185w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOOO222w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niO00O146w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niO1Oi128w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niO1OO117w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rall_one_dect_only477w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rpma_doublewidth_rx3060w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rpmadwidth_rx3059w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_soft_reset7w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_sync_status2690w2691w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_sync_status2674w2675w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niilli2830w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niilOi2828w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niilOO2814w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiO1l2812w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiOii2796w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiOli2788w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niiOlO2784w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil11O2779w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nil00O1614w1615w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nil0ii1543w1544w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nil0il1472w1473w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nil0iO1333w1334w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nil0li1263w1264w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nil0Ol1598w1599w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nil0OO1527w1528w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil00O1614w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil01l2170w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil0ii1543w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil0il1472w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil0iO1333w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil0iO1403w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil0li1263w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil0Ol1598w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil0OO1527w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil1Oi2155w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nili1i1932w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nili1l2001w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nili1O2070w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  niil0i :	STD_LOGIC;
	 SIGNAL  niil0l :	STD_LOGIC;
	 SIGNAL  niil0O :	STD_LOGIC;
	 SIGNAL  niil1l :	STD_LOGIC;
	 SIGNAL  niil1O :	STD_LOGIC;
	 SIGNAL  niilii :	STD_LOGIC;
	 SIGNAL  niilil :	STD_LOGIC;
	 SIGNAL  niiliO :	STD_LOGIC;
	 SIGNAL  niilli :	STD_LOGIC;
	 SIGNAL  niilll :	STD_LOGIC;
	 SIGNAL  niillO :	STD_LOGIC;
	 SIGNAL  niilOi :	STD_LOGIC;
	 SIGNAL  niilOl :	STD_LOGIC;
	 SIGNAL  niilOO :	STD_LOGIC;
	 SIGNAL  niiO0i :	STD_LOGIC;
	 SIGNAL  niiO0l :	STD_LOGIC;
	 SIGNAL  niiO0O :	STD_LOGIC;
	 SIGNAL  niiO1i :	STD_LOGIC;
	 SIGNAL  niiO1l :	STD_LOGIC;
	 SIGNAL  niiO1O :	STD_LOGIC;
	 SIGNAL  niiOii :	STD_LOGIC;
	 SIGNAL  niiOil :	STD_LOGIC;
	 SIGNAL  niiOiO :	STD_LOGIC;
	 SIGNAL  niiOli :	STD_LOGIC;
	 SIGNAL  niiOll :	STD_LOGIC;
	 SIGNAL  niiOlO :	STD_LOGIC;
	 SIGNAL  niiOOi :	STD_LOGIC;
	 SIGNAL  niiOOl :	STD_LOGIC;
	 SIGNAL  niiOOO :	STD_LOGIC;
	 SIGNAL  nil00i :	STD_LOGIC;
	 SIGNAL  nil00l :	STD_LOGIC;
	 SIGNAL  nil00O :	STD_LOGIC;
	 SIGNAL  nil01i :	STD_LOGIC;
	 SIGNAL  nil01l :	STD_LOGIC;
	 SIGNAL  nil01O :	STD_LOGIC;
	 SIGNAL  nil0ii :	STD_LOGIC;
	 SIGNAL  nil0il :	STD_LOGIC;
	 SIGNAL  nil0iO :	STD_LOGIC;
	 SIGNAL  nil0li :	STD_LOGIC;
	 SIGNAL  nil0ll :	STD_LOGIC;
	 SIGNAL  nil0lO :	STD_LOGIC;
	 SIGNAL  nil0Oi :	STD_LOGIC;
	 SIGNAL  nil0Ol :	STD_LOGIC;
	 SIGNAL  nil0OO :	STD_LOGIC;
	 SIGNAL  nil10i :	STD_LOGIC;
	 SIGNAL  nil10l :	STD_LOGIC;
	 SIGNAL  nil10O :	STD_LOGIC;
	 SIGNAL  nil11i :	STD_LOGIC;
	 SIGNAL  nil11l :	STD_LOGIC;
	 SIGNAL  nil11O :	STD_LOGIC;
	 SIGNAL  nil1ii :	STD_LOGIC;
	 SIGNAL  nil1il :	STD_LOGIC;
	 SIGNAL  nil1iO :	STD_LOGIC;
	 SIGNAL  nil1li :	STD_LOGIC;
	 SIGNAL  nil1ll :	STD_LOGIC;
	 SIGNAL  nil1lO :	STD_LOGIC;
	 SIGNAL  nil1Oi :	STD_LOGIC;
	 SIGNAL  nil1Ol :	STD_LOGIC;
	 SIGNAL  nil1OO :	STD_LOGIC;
	 SIGNAL  nili0i :	STD_LOGIC;
	 SIGNAL  nili0l :	STD_LOGIC;
	 SIGNAL  nili0O :	STD_LOGIC;
	 SIGNAL  nili1i :	STD_LOGIC;
	 SIGNAL  nili1l :	STD_LOGIC;
	 SIGNAL  nili1O :	STD_LOGIC;
	 SIGNAL  niliii :	STD_LOGIC;
	 SIGNAL  niliil :	STD_LOGIC;
	 SIGNAL  niliiO :	STD_LOGIC;
	 SIGNAL  nilili :	STD_LOGIC;
	 SIGNAL  nilill :	STD_LOGIC;
	 SIGNAL  nililO :	STD_LOGIC;
	 SIGNAL  niliOi :	STD_LOGIC;
	 SIGNAL  niliOl :	STD_LOGIC;
	 SIGNAL  niliOO :	STD_LOGIC;
	 SIGNAL  nill0i :	STD_LOGIC;
	 SIGNAL  nill0l :	STD_LOGIC;
	 SIGNAL  nill0O :	STD_LOGIC;
	 SIGNAL  nill1i :	STD_LOGIC;
	 SIGNAL  nill1l :	STD_LOGIC;
	 SIGNAL  nill1O :	STD_LOGIC;
	 SIGNAL  nillii :	STD_LOGIC;
	 SIGNAL  nillil :	STD_LOGIC;
	 SIGNAL  nilliO :	STD_LOGIC;
	 SIGNAL  nillli :	STD_LOGIC;
	 SIGNAL  nillll :	STD_LOGIC;
	 SIGNAL  nilllO :	STD_LOGIC;
	 SIGNAL  nilO0i :	STD_LOGIC;
	 SIGNAL  nilO0l :	STD_LOGIC;
	 SIGNAL  nilO0O :	STD_LOGIC;
	 SIGNAL  nilO1l :	STD_LOGIC;
	 SIGNAL  nilOii :	STD_LOGIC;
	 SIGNAL  nilOil :	STD_LOGIC;
	 SIGNAL  nilOli :	STD_LOGIC;
	 SIGNAL  nilOll :	STD_LOGIC;
	 SIGNAL  nilOlO :	STD_LOGIC;
	 SIGNAL  nilOOi :	STD_LOGIC;
	 SIGNAL  nilOOl :	STD_LOGIC;
	 SIGNAL  nilOOO :	STD_LOGIC;
	 SIGNAL  niO00O :	STD_LOGIC;
	 SIGNAL  niO01i :	STD_LOGIC;
	 SIGNAL  niO0ii :	STD_LOGIC;
	 SIGNAL  niO0il :	STD_LOGIC;
	 SIGNAL  niO0Ol :	STD_LOGIC;
	 SIGNAL  niO10O :	STD_LOGIC;
	 SIGNAL  niO11l :	STD_LOGIC;
	 SIGNAL  niO11O :	STD_LOGIC;
	 SIGNAL  niO1ii :	STD_LOGIC;
	 SIGNAL  niO1il :	STD_LOGIC;
	 SIGNAL  niO1iO :	STD_LOGIC;
	 SIGNAL  niO1Oi :	STD_LOGIC;
	 SIGNAL  niO1OO :	STD_LOGIC;
	 SIGNAL  niOi0i :	STD_LOGIC;
	 SIGNAL  niOi0O :	STD_LOGIC;
 BEGIN

	wire_gnd <= '0';
	wire_w_lg_w_lg_rpmadwidth_rx3059w3167w(0) <= wire_w_lg_rpmadwidth_rx3059w(0) AND rpma_doublewidth_rx;
	wire_w_lg_niOi0O113w(0) <= niOi0O AND wire_ni_w_lg_w_lg_w_lg_nlO108w111w112w(0);
	wire_w_lg_rpmadwidth_rx3110w(0) <= rpmadwidth_rx AND wire_w_lg_rpma_doublewidth_rx3060w(0);
	wire_w_lg_sync_status2690w(0) <= sync_status AND niil0O;
	wire_w_lg_sync_status2674w(0) <= sync_status AND niilii;
	wire_w_lg_niil0O2953w(0) <= NOT niil0O;
	wire_w_lg_niilii2943w(0) <= NOT niilii;
	wire_w_lg_niilll2631w(0) <= NOT niilll;
	wire_w_lg_niilOl2627w(0) <= NOT niilOl;
	wire_w_lg_niiO1i2625w(0) <= NOT niiO1i;
	wire_w_lg_niiO1O2623w(0) <= NOT niiO1O;
	wire_w_lg_niiOil2615w(0) <= NOT niiOil;
	wire_w_lg_niiOll2612w(0) <= NOT niiOll;
	wire_w_lg_niiOOi2610w(0) <= NOT niiOOi;
	wire_w_lg_nil10i2600w(0) <= NOT nil10i;
	wire_w_lg_nililO2595w(0) <= NOT nililO;
	wire_w_lg_niliOi2594w(0) <= NOT niliOi;
	wire_w_lg_niliOl2593w(0) <= NOT niliOl;
	wire_w_lg_niliOO2592w(0) <= NOT niliOO;
	wire_w_lg_nill1i2591w(0) <= NOT nill1i;
	wire_w_lg_nill1l2590w(0) <= NOT nill1l;
	wire_w_lg_nill1O2588w(0) <= NOT nill1O;
	wire_w_lg_nillil256w(0) <= NOT nillil;
	wire_w_lg_nilliO254w(0) <= NOT nilliO;
	wire_w_lg_nillli252w(0) <= NOT nillli;
	wire_w_lg_nillll250w(0) <= NOT nillll;
	wire_w_lg_nilllO248w(0) <= NOT nilllO;
	wire_w_lg_nilO0i209w(0) <= NOT nilO0i;
	wire_w_lg_nilO0l207w(0) <= NOT nilO0l;
	wire_w_lg_nilO0O205w(0) <= NOT nilO0O;
	wire_w_lg_nilO1l226w(0) <= NOT nilO1l;
	wire_w_lg_nilOii203w(0) <= NOT nilOii;
	wire_w_lg_nilOil201w(0) <= NOT nilOil;
	wire_w_lg_nilOli188w(0) <= NOT nilOli;
	wire_w_lg_nilOll183w(0) <= NOT nilOll;
	wire_w_lg_nilOlO181w(0) <= NOT nilOlO;
	wire_w_lg_nilOOi179w(0) <= NOT nilOOi;
	wire_w_lg_nilOOl185w(0) <= NOT nilOOl;
	wire_w_lg_nilOOO222w(0) <= NOT nilOOO;
	wire_w_lg_niO00O146w(0) <= NOT niO00O;
	wire_w_lg_niO1Oi128w(0) <= NOT niO1Oi;
	wire_w_lg_niO1OO117w(0) <= NOT niO1OO;
	wire_w_lg_rall_one_dect_only477w(0) <= NOT rall_one_dect_only;
	wire_w_lg_rpma_doublewidth_rx3060w(0) <= NOT rpma_doublewidth_rx;
	wire_w_lg_rpmadwidth_rx3059w(0) <= NOT rpmadwidth_rx;
	wire_w_lg_soft_reset7w(0) <= NOT soft_reset;
	wire_w_lg_w_lg_sync_status2690w2691w(0) <= wire_w_lg_sync_status2690w(0) OR nli0li;
	wire_w_lg_w_lg_sync_status2674w2675w(0) <= wire_w_lg_sync_status2674w(0) OR nli0li;
	wire_w_lg_niilli2830w(0) <= niilli OR nli00O;
	wire_w_lg_niilOi2828w(0) <= niilOi OR nli00O;
	wire_w_lg_niilOO2814w(0) <= niilOO OR nli00O;
	wire_w_lg_niiO1l2812w(0) <= niiO1l OR nli00O;
	wire_w_lg_niiOii2796w(0) <= niiOii OR nli00O;
	wire_w_lg_niiOli2788w(0) <= niiOli OR nli00O;
	wire_w_lg_niiOlO2784w(0) <= niiOlO OR nli00O;
	wire_w_lg_nil11O2779w(0) <= nil11O OR nli00O;
	wire_w_lg_w_lg_nil00O1614w1615w(0) <= wire_w_lg_nil00O1614w(0) XOR nlliOi;
	wire_w_lg_w_lg_nil0ii1543w1544w(0) <= wire_w_lg_nil0ii1543w(0) XOR nlliOl;
	wire_w_lg_w_lg_nil0il1472w1473w(0) <= wire_w_lg_nil0il1472w(0) XOR nlliOO;
	wire_w_lg_w_lg_nil0iO1333w1334w(0) <= wire_w_lg_nil0iO1333w(0) XOR nlliOi;
	wire_w_lg_w_lg_nil0li1263w1264w(0) <= wire_w_lg_nil0li1263w(0) XOR nlliOi;
	wire_w_lg_w_lg_nil0Ol1598w1599w(0) <= wire_w_lg_nil0Ol1598w(0) XOR nlliiO;
	wire_w_lg_w_lg_nil0OO1527w1528w(0) <= wire_w_lg_nil0OO1527w(0) XOR nllili;
	wire_w_lg_nil00O1614w(0) <= nil00O XOR nlliOl;
	wire_w_lg_nil01l2170w(0) <= nil01l XOR nlliOi;
	wire_w_lg_nil0ii1543w(0) <= nil0ii XOR nlliOO;
	wire_w_lg_nil0il1472w(0) <= nil0il XOR nlll1i;
	wire_w_lg_nil0iO1333w(0) <= nil0iO XOR nlliOl;
	wire_w_lg_nil0iO1403w(0) <= nil0iO XOR nlll1i;
	wire_w_lg_nil0li1263w(0) <= nil0li XOR nlliOO;
	wire_w_lg_nil0Ol1598w(0) <= nil0Ol XOR nllili;
	wire_w_lg_nil0OO1527w(0) <= nil0OO XOR nllill;
	wire_w_lg_nil1Oi2155w(0) <= nil1Oi XOR nlliiO;
	wire_w_lg_nili1i1932w(0) <= nili1i XOR nlliiO;
	wire_w_lg_nili1l2001w(0) <= nili1l XOR nlliil;
	wire_w_lg_nili1O2070w(0) <= nili1O XOR nlliii;
	encdet_prbs <= nlii0O;
	niil0i <= (wire_nlO1l_w_lg_w_lg_w3259w3260w3261w(0) AND wire_nllli_w_lg_dataout3262w(0));
	niil0l <= ((((wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlliii2993w2994w2996w2997w(0) AND wire_nliOi_w_lg_nlli1O2998w(0)) AND nlli1l) AND nlli1i) AND nll0OO);
	niil0O <= ((((((((((((((((((((NOT data_in(0)) AND (NOT data_in(1))) AND (NOT data_in(2))) AND (NOT data_in(3))) AND (NOT data_in(4))) AND (NOT data_in(5))) AND data_in(6)) AND (NOT data_in(7))) AND (NOT data_in(8))) AND (NOT data_in(9))) AND (NOT data_in(10))) AND (NOT data_in(11))) AND data_in(12)) AND data_in(13)) AND (NOT data_in(14))) AND (NOT data_in(15))) AND (NOT data_in(16))) AND (NOT data_in(17))) AND data_in(18)) AND (NOT data_in(19)));
	niil1l <= ((((((wire_nliOi_w_lg_w_lg_w_lg_w_lg_w3441w3442w3443w3444w3445w(0) AND wire_nliOi_w_lg_nlli0l2995w(0)) AND wire_nliOi_w_lg_nlli0i2986w(0)) AND wire_nliOi_w_lg_nlli1O2998w(0)) AND wire_nliOi_w_lg_nlli1l3000w(0)) AND wire_nliOi_w_lg_nlli1i2990w(0)) AND wire_nliOi_w_lg_nll0OO3003w(0));
	niil1O <= ((((((wire_nliOi_w3357w(0) AND wire_nliOi_w_lg_nlli0l2995w(0)) AND wire_nliOi_w_lg_nlli0i2986w(0)) AND wire_nliOi_w_lg_nlli1O2998w(0)) AND wire_nliOi_w_lg_nlli1l3000w(0)) AND wire_nliOi_w_lg_nlli1i2990w(0)) AND wire_nliOi_w_lg_nll0OO3003w(0));
	niilii <= ((((((((((((((((NOT data_in(0)) AND (NOT data_in(1))) AND (NOT data_in(2))) AND (NOT data_in(3))) AND (NOT data_in(4))) AND (NOT data_in(5))) AND data_in(6)) AND (NOT data_in(7))) AND (NOT data_in(10))) AND (NOT data_in(11))) AND (NOT data_in(12))) AND (NOT data_in(13))) AND data_in(14)) AND data_in(15)) AND (NOT data_in(16))) AND (NOT data_in(17)));
	niilil <= (wire_nilil_w_lg_dataout2635w(0) AND nlii0O);
	niiliO <= ((wire_nilil_dataout AND nli0li) OR nli0ll);
	niilli <= (nli0li AND wire_w_lg_niilll2631w(0));
	niilll <= ((((((((((((((((((((NOT (wire_nllli_dataout XOR data_in(0))) AND (NOT (wire_nllll_dataout XOR data_in(1)))) AND (NOT (wire_nlllO_dataout XOR data_in(2)))) AND (NOT (wire_nllOi_dataout XOR data_in(3)))) AND (NOT (wire_nllOl_dataout XOR data_in(4)))) AND (NOT (wire_nllOO_dataout XOR data_in(5)))) AND (NOT (wire_nlO1i_dataout XOR data_in(6)))) AND (NOT (wire_nlO1l_dataout XOR data_in(7)))) AND (NOT (wire_nlO1O_dataout XOR data_in(8)))) AND (NOT (wire_nlO0i_dataout XOR data_in(9)))) AND (NOT (wire_nlO0l_dataout XOR data_in(10)))) AND (NOT (wire_nlO0O_dataout XOR data_in(11)))) AND (NOT (wire_nlOii_dataout XOR data_in(12)))) AND (NOT (wire_nlOil_dataout XOR data_in(13)))) AND (NOT (wire_nlOiO_dataout XOR data_in(14)))) AND (NOT (wire_nlOli_dataout XOR data_in(15)))) AND (NOT (wire_nlOll_dataout XOR data_in(16)))) AND (NOT (wire_nlOlO_dataout XOR data_in(17)))) AND (NOT (wire_nlOOi_dataout XOR data_in(18)))) AND (NOT (wire_nlOOl_dataout XOR data_in(19))));
	niillO <= ((wire_nilil_dataout AND sync_status) OR nli0li);
	niilOi <= (nli0li AND wire_w_lg_niilOl2627w(0));
	niilOl <= ((((((((((((((((((((NOT (nll0OO XOR data_in(0))) AND (NOT (nlli1i XOR data_in(1)))) AND (NOT (nlli1l XOR data_in(2)))) AND (NOT (nlli1O XOR data_in(3)))) AND (NOT (nlli0i XOR data_in(4)))) AND (NOT (nlli0l XOR data_in(5)))) AND (NOT (nlli0O XOR data_in(6)))) AND (NOT (nlliii XOR data_in(7)))) AND (NOT (nlliil XOR data_in(8)))) AND (NOT (nlliiO XOR data_in(9)))) AND (NOT (nllili XOR data_in(10)))) AND (NOT (nllill XOR data_in(11)))) AND (NOT (nllilO XOR data_in(12)))) AND (NOT (nlliOi XOR data_in(13)))) AND (NOT (nlliOl XOR data_in(14)))) AND (NOT (nlliOO XOR data_in(15)))) AND (NOT (nlll1i XOR data_in(16)))) AND (NOT (nlll1l XOR data_in(17)))) AND (NOT (nlll1O XOR data_in(18)))) AND (NOT (nlll0i XOR data_in(19))));
	niilOO <= (nli0li AND wire_w_lg_niiO1i2625w(0));
	niiO0i <= (wire_nilii_w_lg_dataout2621w(0) AND nlii0O);
	niiO0l <= (((((((((nlliiO AND nlliil) AND nlliii) AND nlli0O) AND nlli0l) AND nlli0i) AND nlli1O) AND nlli1l) AND nlli1i) AND nll0OO);
	niiO0O <= ((wire_nliOi_w_lg_w_lg_w_lg_w3306w3307w3308w3309w(0) AND wire_nliOi_w_lg_nlli1i2990w(0)) AND wire_nliOi_w_lg_nll0OO3003w(0));
	niiO1i <= ((((((((((((((((NOT (wire_nllli_dataout XOR data_in(0))) AND (NOT (wire_nllll_dataout XOR data_in(1)))) AND (NOT (wire_nlllO_dataout XOR data_in(2)))) AND (NOT (wire_nllOi_dataout XOR data_in(3)))) AND (NOT (wire_nllOl_dataout XOR data_in(4)))) AND (NOT (wire_nllOO_dataout XOR data_in(5)))) AND (NOT (wire_nlO1i_dataout XOR data_in(6)))) AND (NOT (wire_nlO1l_dataout XOR data_in(7)))) AND (NOT (wire_nlO1O_dataout XOR data_in(10)))) AND (NOT (wire_nlO0i_dataout XOR data_in(11)))) AND (NOT (wire_nlO0l_dataout XOR data_in(12)))) AND (NOT (wire_nlO0O_dataout XOR data_in(13)))) AND (NOT (wire_nlOii_dataout XOR data_in(14)))) AND (NOT (wire_nlOil_dataout XOR data_in(15)))) AND (NOT (wire_nlOiO_dataout XOR data_in(16)))) AND (NOT (wire_nlOli_dataout XOR data_in(17))));
	niiO1l <= (nli0li AND wire_w_lg_niiO1O2623w(0));
	niiO1O <= ((((((((((((((((NOT (nll0OO XOR data_in(0))) AND (NOT (nlli1i XOR data_in(1)))) AND (NOT (nlli1l XOR data_in(2)))) AND (NOT (nlli1O XOR data_in(3)))) AND (NOT (nlli0i XOR data_in(4)))) AND (NOT (nlli0l XOR data_in(5)))) AND (NOT (nlli0O XOR data_in(6)))) AND (NOT (nlliii XOR data_in(7)))) AND (NOT (nlliil XOR data_in(10)))) AND (NOT (nlliiO XOR data_in(11)))) AND (NOT (nllili XOR data_in(12)))) AND (NOT (nllill XOR data_in(13)))) AND (NOT (nllilO XOR data_in(14)))) AND (NOT (nlliOi XOR data_in(15)))) AND (NOT (nlliOl XOR data_in(16)))) AND (NOT (nlliOO XOR data_in(17))));
	niiOii <= (nli0li AND wire_w_lg_niiOil2615w(0));
	niiOil <= ((((((((((NOT (nll0OO XOR data_in(0))) AND (NOT (nlli1i XOR data_in(1)))) AND (NOT (nlli1l XOR data_in(2)))) AND (NOT (nlli1O XOR data_in(3)))) AND (NOT (nlli0i XOR data_in(4)))) AND (NOT (nlli0l XOR data_in(5)))) AND (NOT (nlli0O XOR data_in(6)))) AND (NOT (nlliii XOR data_in(7)))) AND (NOT (nlliil XOR data_in(8)))) AND (NOT (nlliiO XOR data_in(9))));
	niiOiO <= (wire_nilii_dataout OR nli0li);
	niiOli <= (nli0li AND wire_w_lg_niiOll2612w(0));
	niiOll <= ((((((((NOT (wire_nllli_dataout XOR data_in(0))) AND (NOT (wire_nllll_dataout XOR data_in(1)))) AND (NOT (wire_nlllO_dataout XOR data_in(2)))) AND (NOT (wire_nllOi_dataout XOR data_in(3)))) AND (NOT (wire_nllOl_dataout XOR data_in(4)))) AND (NOT (wire_nllOO_dataout XOR data_in(5)))) AND (NOT (wire_nlO1i_dataout XOR data_in(6)))) AND (NOT (wire_nlO1l_dataout XOR data_in(7))));
	niiOlO <= (nli0li AND wire_w_lg_niiOOi2610w(0));
	niiOOi <= ((((((((NOT (nll0OO XOR data_in(0))) AND (NOT (nlli1i XOR data_in(1)))) AND (NOT (nlli1l XOR data_in(2)))) AND (NOT (nlli1O XOR data_in(3)))) AND (NOT (nlli0i XOR data_in(4)))) AND (NOT (nlli0l XOR data_in(5)))) AND (NOT (nlli0O XOR data_in(6)))) AND (NOT (nlliii XOR data_in(7))));
	niiOOl <= (((wire_nliOi_w_lg_w_lg_w_lg_w_lg_nll0Ol3215w3222w3223w3224w(0) AND wire_nliOi_w_lg_nll0iO3209w(0)) AND wire_nliOi_w_lg_nll0il3211w(0)) AND wire_nliOi_w_lg_nli0lO3213w(0));
	niiOOO <= ((((wire_nliOi_w_lg_w_lg_w_lg_w_lg_nll0Ol3202w3203w3205w3206w(0) AND wire_nliOi_w_lg_nll0li3207w(0)) AND wire_nliOi_w_lg_nll0iO3209w(0)) AND wire_nliOi_w_lg_nll0il3211w(0)) AND wire_nliOi_w_lg_nli0lO3213w(0));
	nil00i <= (nlll0O XOR nlll1i);
	nil00l <= (nlllii XOR nlll1l);
	nil00O <= (nlll1i XOR nlliOO);
	nil01i <= (nlll1O XOR nlliOi);
	nil01l <= (nlll0i XOR nlliOl);
	nil01O <= (nlll0l XOR nlliOO);
	nil0ii <= (nlll1l XOR nlll1i);
	nil0il <= (nlll1O XOR nlll1l);
	nil0iO <= (nil0li XOR nlll1l);
	nil0li <= (nlll0i XOR nlll1O);
	nil0ll <= (nlliOl XOR nlliOi);
	nil0lO <= (nlliOO XOR nlliOl);
	nil0Oi <= (nlliOO XOR nlliOi);
	nil0Ol <= (nllilO XOR nllill);
	nil0OO <= (nlliOi XOR nllilO);
	nil10i <= ((((((((NOT (nliO XOR nli0lO)) AND (NOT (n0i XOR nll0il))) AND (NOT (n0l XOR nll0iO))) AND (NOT (n0O XOR nll0li))) AND (NOT (nii XOR nll0ll))) AND (NOT (nil XOR nll0lO))) AND (NOT (niO XOR nll0Oi))) AND (NOT (nli XOR nll0Ol)));
	nil10l <= (nlliii XOR nlli1l);
	nil10O <= (nlliil XOR nlli1O);
	nil11i <= (nlO AND wire_ni_w_lg_nll2606w(0));
	nil11l <= ((wire_nliOi_w3219w(0) AND wire_nliOi_w_lg_nll0il3211w(0)) AND wire_nliOi_w_lg_nli0lO3213w(0));
	nil11O <= (nli0li AND wire_w_lg_nil10i2600w(0));
	nil1ii <= (nlliiO XOR nlli0i);
	nil1il <= (nllili XOR nlli0l);
	nil1iO <= (nllill XOR nlli0O);
	nil1li <= (nllilO XOR nlliii);
	nil1ll <= (nlliOi XOR nlliil);
	nil1lO <= (nlliOl XOR nlliiO);
	nil1Oi <= (nlliOO XOR nllili);
	nil1Ol <= (nlll1i XOR nllill);
	nil1OO <= (nlll1l XOR nllilO);
	nili0i <= (nlli0i XOR nlli1O);
	nili0l <= (nlli0l XOR nlli0i);
	nili0O <= (nlli0O XOR nlli0l);
	nili1i <= (nlli0l XOR nlli1l);
	nili1l <= (nlli0i XOR nlli1i);
	nili1O <= (nlli1O XOR nll0OO);
	niliii <= (nlliii XOR nlli0O);
	niliil <= (wire_n0li_dataout OR wire_n0iO_dataout);
	niliiO <= (nll1l AND nli0li);
	nilili <= (((((((((((((((((((((((wire_nil0O_o(31) OR wire_nil0O_o(30)) OR wire_nil0O_o(29)) OR wire_nil0O_o(28)) OR wire_nil0O_o(27)) OR wire_nil0O_o(26)) OR wire_nil0O_o(23)) OR wire_nil0O_o(22)) OR wire_nil0O_o(21)) OR wire_nil0O_o(20)) OR wire_nil0O_o(19)) OR wire_nil0O_o(18)) OR wire_nil0O_o(15)) OR wire_nil0O_o(14)) OR wire_nil0O_o(13)) OR wire_nil0O_o(12)) OR wire_nil0O_o(11)) OR wire_nil0O_o(10)) OR wire_nil0O_o(9)) OR wire_nil0O_o(7)) OR wire_nil0O_o(6)) OR wire_nil0O_o(5)) OR wire_nil0O_o(3)) OR wire_nil0O_o(1));
	nilill <= ((((((wire_nil0O_o(25) OR wire_nil0O_o(17)) OR wire_nil0O_o(16)) OR wire_nil0O_o(8)) OR wire_nil0O_o(2)) OR wire_nil0O_o(24)) OR wire_nil0O_o(4));
	nililO <= ((((wire_nil0O_o(25) OR wire_nil0O_o(8)) OR wire_nil0O_o(2)) OR wire_nil0O_o(0)) OR wire_nil0O_o(24));
	niliOi <= ((((((wire_nil0O_o(25) OR wire_nil0O_o(16)) OR wire_nil0O_o(8)) OR wire_nil0O_o(2)) OR wire_nil0O_o(0)) OR wire_nil0O_o(24)) OR wire_nil0O_o(4));
	niliOl <= (((((wire_nil0O_o(25) OR wire_nil0O_o(17)) OR wire_nil0O_o(8)) OR wire_nil0O_o(2)) OR wire_nil0O_o(0)) OR wire_nil0O_o(4));
	niliOO <= ((((((wire_nil0O_o(25) OR wire_nil0O_o(17)) OR wire_nil0O_o(16)) OR wire_nil0O_o(8)) OR wire_nil0O_o(2)) OR wire_nil0O_o(0)) OR wire_nil0O_o(4));
	nill0i <= (((((((((((((((((((data_in(0) AND data_in(1)) AND data_in(2)) AND (NOT data_in(3))) AND (NOT data_in(4))) AND (NOT data_in(5))) AND (NOT data_in(6))) AND (NOT data_in(7))) AND (NOT data_in(8))) AND (NOT data_in(9))) AND (NOT data_in(10))) AND (NOT data_in(11))) AND (NOT data_in(12))) AND (NOT data_in(13))) AND (NOT data_in(14))) AND (NOT data_in(15))) AND (NOT data_in(16))) AND (NOT data_in(17))) AND (NOT data_in(18))) AND (NOT data_in(19)));
	nill0l <= (((((((((((((((data_in(0) AND data_in(1)) AND data_in(2)) AND data_in(3)) AND data_in(4)) AND data_in(5)) AND data_in(6)) AND (NOT data_in(7))) AND (NOT data_in(10))) AND (NOT data_in(11))) AND (NOT data_in(12))) AND (NOT data_in(13))) AND (NOT data_in(14))) AND (NOT data_in(15))) AND (NOT data_in(16))) AND (NOT data_in(17)));
	nill0O <= ((((wire_w_lg_rpmadwidth_rx3059w(0) AND wire_w_lg_rpma_doublewidth_rx3060w(0)) AND (NOT rprbs_sel(0))) AND rprbs_sel(1)) AND (NOT rprbs_sel(2)));
	nill1i <= (((((wire_nil0O_o(17) OR wire_nil0O_o(16)) OR wire_nil0O_o(8)) OR wire_nil0O_o(2)) OR wire_nil0O_o(0)) OR wire_nil0O_o(4));
	nill1l <= ((((((wire_nil0O_o(17) OR wire_nil0O_o(16)) OR wire_nil0O_o(8)) OR wire_nil0O_o(2)) OR wire_nil0O_o(0)) OR wire_nil0O_o(24)) OR wire_nil0O_o(4));
	nill1O <= (((((((wire_nil0O_o(25) OR wire_nil0O_o(17)) OR wire_nil0O_o(16)) OR wire_nil0O_o(8)) OR wire_nil0O_o(2)) OR wire_nil0O_o(0)) OR wire_nil0O_o(24)) OR wire_nil0O_o(4));
	nillii <= (((wire_w_lg_rpmadwidth_rx3110w(0) AND (NOT rprbs_sel(0))) AND (NOT rprbs_sel(1))) AND (NOT rprbs_sel(2)));
	nillil <= (((((((((data_in(0) AND data_in(1)) AND data_in(2)) AND data_in(3)) AND data_in(4)) AND data_in(5)) AND data_in(6)) AND data_in(7)) AND data_in(8)) AND data_in(9));
	nilliO <= ((((((((((NOT data_in(0)) AND (NOT data_in(1))) AND (NOT data_in(2))) AND (NOT data_in(3))) AND (NOT data_in(4))) AND (NOT data_in(5))) AND (NOT data_in(6))) AND data_in(7)) AND data_in(8)) AND data_in(9));
	nillli <= ((((((((((NOT data_in(0)) AND (NOT data_in(1))) AND (NOT data_in(2))) AND (NOT data_in(3))) AND data_in(4)) AND data_in(5)) AND data_in(6)) AND data_in(7)) AND data_in(8)) AND data_in(9));
	nillll <= ((((((((((NOT data_in(0)) AND data_in(1)) AND data_in(2)) AND data_in(3)) AND (NOT data_in(4))) AND (NOT data_in(5))) AND (NOT data_in(6))) AND data_in(7)) AND (NOT data_in(8))) AND (NOT data_in(9)));
	nilllO <= (((((((((data_in(0) AND data_in(1)) AND data_in(2)) AND data_in(3)) AND data_in(4)) AND (NOT data_in(5))) AND (NOT data_in(6))) AND (NOT data_in(7))) AND data_in(8)) AND data_in(9));
	nilO0i <= ((((((((NOT data_in(0)) AND (NOT data_in(1))) AND (NOT data_in(2))) AND (NOT data_in(3))) AND (NOT data_in(4))) AND (NOT data_in(5))) AND data_in(6)) AND (NOT data_in(7)));
	nilO0l <= ((((((((NOT data_in(0)) AND (NOT data_in(1))) AND (NOT data_in(2))) AND (NOT data_in(3))) AND data_in(4)) AND data_in(5)) AND (NOT data_in(6))) AND (NOT data_in(7)));
	nilO0O <= ((((((((NOT data_in(0)) AND (NOT data_in(1))) AND data_in(2)) AND (NOT data_in(3))) AND data_in(4)) AND (NOT data_in(5))) AND (NOT data_in(6))) AND (NOT data_in(7)));
	nilO1l <= (((((((data_in(0) AND data_in(1)) AND data_in(2)) AND data_in(3)) AND data_in(4)) AND data_in(5)) AND data_in(6)) AND (NOT data_in(7)));
	nilOii <= (((((((data_in(0) AND data_in(1)) AND data_in(2)) AND data_in(3)) AND (NOT data_in(4))) AND (NOT data_in(5))) AND data_in(6)) AND (NOT data_in(7)));
	nilOil <= ((((((((NOT data_in(0)) AND (NOT data_in(1))) AND data_in(2)) AND (NOT data_in(3))) AND data_in(4)) AND data_in(5)) AND (NOT data_in(6))) AND (NOT data_in(7)));
	nilOli <= ((((((((NOT data_in(0)) AND data_in(1)) AND (NOT data_in(2))) AND data_in(3)) AND data_in(4)) AND (NOT data_in(5))) AND data_in(6)) AND (NOT data_in(7)));
	nilOll <= ((((((((NOT data_in(0)) AND (NOT data_in(1))) AND data_in(2)) AND (NOT data_in(3))) AND data_in(4)) AND data_in(5)) AND data_in(6)) AND data_in(7));
	nilOlO <= ((((((((NOT data_in(0)) AND data_in(1)) AND (NOT data_in(2))) AND (NOT data_in(3))) AND data_in(4)) AND (NOT data_in(5))) AND data_in(6)) AND (NOT data_in(7)));
	nilOOi <= ((((((((NOT data_in(0)) AND (NOT data_in(1))) AND (NOT data_in(2))) AND data_in(3)) AND data_in(4)) AND (NOT data_in(5))) AND data_in(6)) AND data_in(7));
	nilOOl <= (((((((data_in(0) AND data_in(1)) AND data_in(2)) AND data_in(3)) AND data_in(4)) AND data_in(5)) AND data_in(6)) AND data_in(7));
	nilOOO <= ((((((((NOT data_in(0)) AND (NOT data_in(1))) AND (NOT data_in(2))) AND (NOT data_in(3))) AND (NOT data_in(4))) AND (NOT data_in(5))) AND (NOT data_in(6))) AND (NOT data_in(7)));
	niO00O <= (((((((wire_ni_w_lg_nlil2972w(0) AND wire_ni_w_lg_nlii2973w(0)) AND wire_ni_w_lg_nl0O2975w(0)) AND wire_ni_w_lg_nl0l2977w(0)) AND wire_ni_w_lg_nl0i2979w(0)) AND wire_ni_w_lg_nl1O2981w(0)) AND wire_ni_w_lg_nl1l2983w(0)) AND nl1i);
	niO01i <= (wire_w_lg_niOi0O113w(0) AND (niO01l24 XOR niO01l23));
	niO0ii <= (niOi0O AND (((nlO AND wire_nill_o) AND (niO0iO20 XOR niO0iO19)) AND niO0il));
	niO0il <= ((wire_nliOi_w2989w(0) AND wire_nliOi_w_lg_nlli1i2990w(0)) AND nll0OO);
	niO0Ol <= ((((wire_w_lg_rpmadwidth_rx3059w(0) AND wire_w_lg_rpma_doublewidth_rx3060w(0)) AND (NOT rprbs_sel(0))) AND (NOT rprbs_sel(1))) AND (NOT rprbs_sel(2)));
	niO10O <= '0';
	niO11l <= (((((((((((((((data_in(0) AND data_in(1)) AND data_in(2)) AND data_in(3)) AND data_in(4)) AND data_in(5)) AND data_in(6)) AND data_in(7)) AND data_in(10)) AND data_in(11)) AND data_in(12)) AND data_in(13)) AND data_in(14)) AND data_in(15)) AND data_in(16)) AND data_in(17));
	niO11O <= (((((((((((((((((((data_in(0) AND data_in(1)) AND data_in(2)) AND data_in(3)) AND data_in(4)) AND data_in(5)) AND data_in(6)) AND data_in(7)) AND data_in(8)) AND data_in(9)) AND data_in(10)) AND data_in(11)) AND data_in(12)) AND data_in(13)) AND data_in(14)) AND data_in(15)) AND data_in(16)) AND data_in(17)) AND data_in(18)) AND data_in(19));
	niO1ii <= ((((rpmadwidth_rx AND rpma_doublewidth_rx) AND rprbs_sel(0)) AND (NOT rprbs_sel(1))) AND (NOT rprbs_sel(2)));
	niO1il <= (((wire_w_lg_w_lg_rpmadwidth_rx3059w3167w(0) AND rprbs_sel(0)) AND (NOT rprbs_sel(1))) AND (NOT rprbs_sel(2)));
	niO1iO <= ((((wire_w_lg_rpmadwidth_rx3059w(0) AND wire_w_lg_rpma_doublewidth_rx3060w(0)) AND (NOT rprbs_sel(0))) AND (NOT rprbs_sel(1))) AND rprbs_sel(2));
	niO1Oi <= (((((wire_nliOi_w_lg_w_lg_nlliii2965w2966w(0) AND nlli0i) AND nlli1O) AND nlli1l) AND nlli1i) AND nll0OO);
	niO1OO <= ((((wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlliii2993w2994w2996w2997w(0) AND wire_nliOi_w_lg_nlli1O2998w(0)) AND wire_nliOi_w_lg_nlli1l3000w(0)) AND wire_nliOi_w_lg_nlli1i2990w(0)) AND wire_nliOi_w_lg_nll0OO3003w(0));
	niOi0i <= '1';
	niOi0O <= (nll OR ((wire_nliil_dataout AND wire_nillO_dataout) AND (niOiii2 XOR niOiii1)));
	prbs_done <= nli0ll;
	prbs_err <= (nli0ii OR (nli0iO OR nli0il));
	prbs_err_lt <= nli00O;
	verify_on <= nli0li;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nillOi49 <= nillOi50;
		END IF;
		if (now = 0 ns) then
			nillOi49 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nillOi50 <= nillOi49;
		END IF;
	END PROCESS;
	wire_nillOi50_w_lg_w_lg_q242w243w(0) <= wire_nillOi50_w_lg_q242w(0) AND nliOl;
	wire_nillOi50_w_lg_q242w(0) <= nillOi50 XOR nillOi49;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nillOl47 <= nillOl48;
		END IF;
		if (now = 0 ns) then
			nillOl47 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nillOl48 <= nillOl47;
		END IF;
	END PROCESS;
	wire_nillOl48_w_lg_w_lg_q239w240w(0) <= wire_nillOl48_w_lg_q239w(0) AND nlilO;
	wire_nillOl48_w_lg_q239w(0) <= nillOl48 XOR nillOl47;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nillOO45 <= nillOO46;
		END IF;
		if (now = 0 ns) then
			nillOO45 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nillOO46 <= nillOO45;
		END IF;
	END PROCESS;
	wire_nillOO46_w_lg_w_lg_q235w236w(0) <= wire_nillOO46_w_lg_q235w(0) AND nlili;
	wire_nillOO46_w_lg_q235w(0) <= nillOO46 XOR nillOO45;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nilO1i43 <= nilO1i44;
		END IF;
		if (now = 0 ns) then
			nilO1i43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nilO1i44 <= nilO1i43;
		END IF;
	END PROCESS;
	wire_nilO1i44_w_lg_w_lg_q229w230w(0) <= wire_nilO1i44_w_lg_q229w(0) AND wire_w_lg_nilOOl185w(0);
	wire_nilO1i44_w_lg_q229w(0) <= nilO1i44 XOR nilO1i43;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nilO1O41 <= nilO1O42;
		END IF;
		if (now = 0 ns) then
			nilO1O41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nilO1O42 <= nilO1O41;
		END IF;
	END PROCESS;
	wire_nilO1O42_w_lg_w_lg_q221w223w(0) <= wire_nilO1O42_w_lg_q221w(0) AND wire_w_lg_nilOOO222w(0);
	wire_nilO1O42_w_lg_q221w(0) <= nilO1O42 XOR nilO1O41;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nilOiO39 <= nilOiO40;
		END IF;
		if (now = 0 ns) then
			nilOiO39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN nilOiO40 <= nilOiO39;
		END IF;
	END PROCESS;
	wire_nilOiO40_w_lg_w_lg_q187w189w(0) <= wire_nilOiO40_w_lg_q187w(0) AND wire_w_lg_nilOli188w(0);
	wire_nilOiO40_w_lg_q187w(0) <= nilOiO40 XOR nilOiO39;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO00i21 <= niO00i22;
		END IF;
		if (now = 0 ns) then
			niO00i21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO00i22 <= niO00i21;
		END IF;
	END PROCESS;
	wire_niO00i22_w_lg_q110w(0) <= niO00i22 XOR niO00i21;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO01l23 <= niO01l24;
		END IF;
		if (now = 0 ns) then
			niO01l23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO01l24 <= niO01l23;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO0iO19 <= niO0iO20;
		END IF;
		if (now = 0 ns) then
			niO0iO19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO0iO20 <= niO0iO19;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO0ll17 <= niO0ll18;
		END IF;
		if (now = 0 ns) then
			niO0ll17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO0ll18 <= niO0ll17;
		END IF;
	END PROCESS;
	wire_niO0ll18_w_lg_w_lg_q97w98w(0) <= wire_niO0ll18_w_lg_q97w(0) AND nl0O;
	wire_niO0ll18_w_lg_q97w(0) <= niO0ll18 XOR niO0ll17;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO0lO15 <= niO0lO16;
		END IF;
		if (now = 0 ns) then
			niO0lO15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO0lO16 <= niO0lO15;
		END IF;
	END PROCESS;
	wire_niO0lO16_w_lg_w_lg_q91w92w(0) <= wire_niO0lO16_w_lg_q91w(0) AND nl1l;
	wire_niO0lO16_w_lg_q91w(0) <= niO0lO16 XOR niO0lO15;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO0Oi13 <= niO0Oi14;
		END IF;
		if (now = 0 ns) then
			niO0Oi13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO0Oi14 <= niO0Oi13;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO0OO11 <= niO0OO12;
		END IF;
		if (now = 0 ns) then
			niO0OO11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO0OO12 <= niO0OO11;
		END IF;
	END PROCESS;
	wire_niO0OO12_w_lg_w_lg_q32w33w(0) <= wire_niO0OO12_w_lg_q32w(0) AND nlil;
	wire_niO0OO12_w_lg_q32w(0) <= niO0OO12 XOR niO0OO11;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO10i35 <= niO10i36;
		END IF;
		if (now = 0 ns) then
			niO10i35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO10i36 <= niO10i35;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO10l33 <= niO10l34;
		END IF;
		if (now = 0 ns) then
			niO10l33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO10l34 <= niO10l33;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO11i37 <= niO11i38;
		END IF;
		if (now = 0 ns) then
			niO11i37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO11i38 <= niO11i37;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO1li31 <= niO1li32;
		END IF;
		if (now = 0 ns) then
			niO1li31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO1li32 <= niO1li31;
		END IF;
	END PROCESS;
	wire_niO1li32_w_lg_w_lg_q159w160w(0) <= wire_niO1li32_w_lg_q159w(0) AND wire_n0OO_dataout;
	wire_niO1li32_w_lg_q159w(0) <= niO1li32 XOR niO1li31;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO1ll29 <= niO1ll30;
		END IF;
		if (now = 0 ns) then
			niO1ll29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO1ll30 <= niO1ll29;
		END IF;
	END PROCESS;
	wire_niO1ll30_w_lg_w_lg_q142w143w(0) <= wire_niO1ll30_w_lg_q142w(0) AND niOi;
	wire_niO1ll30_w_lg_q142w(0) <= niO1ll30 XOR niO1ll29;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO1lO27 <= niO1lO28;
		END IF;
		if (now = 0 ns) then
			niO1lO27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO1lO28 <= niO1lO27;
		END IF;
	END PROCESS;
	wire_niO1lO28_w_lg_w_lg_q138w139w(0) <= wire_niO1lO28_w_lg_q138w(0) AND nlliO;
	wire_niO1lO28_w_lg_q138w(0) <= niO1lO28 XOR niO1lO27;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO1Ol25 <= niO1Ol26;
		END IF;
		if (now = 0 ns) then
			niO1Ol25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niO1Ol26 <= niO1Ol25;
		END IF;
	END PROCESS;
	wire_niO1Ol26_w_lg_w_lg_q125w126w(0) <= wire_niO1Ol26_w_lg_q125w(0) AND wire_ni1l_dataout;
	wire_niO1Ol26_w_lg_q125w(0) <= niO1Ol26 XOR niO1Ol25;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niOi0l3 <= niOi0l4;
		END IF;
		if (now = 0 ns) then
			niOi0l3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niOi0l4 <= niOi0l3;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niOi1i10 <= niOi1i9;
		END IF;
	END PROCESS;
	wire_niOi1i10_w_lg_w_lg_q28w29w(0) <= wire_niOi1i10_w_lg_q28w(0) AND nl0O;
	wire_niOi1i10_w_lg_q28w(0) <= niOi1i10 XOR niOi1i9;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niOi1i9 <= niOi1i10;
		END IF;
		if (now = 0 ns) then
			niOi1i9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niOi1l7 <= niOi1l8;
		END IF;
		if (now = 0 ns) then
			niOi1l7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niOi1l8 <= niOi1l7;
		END IF;
	END PROCESS;
	wire_niOi1l8_w_lg_w_lg_q25w26w(0) <= wire_niOi1l8_w_lg_q25w(0) AND nl0l;
	wire_niOi1l8_w_lg_q25w(0) <= niOi1l8 XOR niOi1l7;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niOi1O5 <= niOi1O6;
		END IF;
		if (now = 0 ns) then
			niOi1O5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niOi1O6 <= niOi1O5;
		END IF;
	END PROCESS;
	wire_niOi1O6_w_lg_w_lg_q20w21w(0) <= wire_niOi1O6_w_lg_q20w(0) AND nl1l;
	wire_niOi1O6_w_lg_q20w(0) <= niOi1O6 XOR niOi1O5;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niOiii1 <= niOiii2;
		END IF;
		if (now = 0 ns) then
			niOiii1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk)
	BEGIN
		IF (rcvd_clk = '1' AND rcvd_clk'event) THEN niOiii2 <= niOiii1;
		END IF;
	END PROCESS;
	PROCESS (rcvd_clk, wire_ni_CLRN)
	BEGIN
		IF (wire_ni_CLRN = '0') THEN
				n0i <= '0';
				n0l <= '0';
				n0O <= '0';
				nii <= '0';
				nil <= '0';
				niO <= '0';
				nl <= '0';
				nl0i <= '0';
				nl0l <= '0';
				nl0O <= '0';
				nl1i <= '0';
				nl1l <= '0';
				nl1O <= '0';
				nli <= '0';
				nlii <= '0';
				nlil <= '0';
				nliO <= '0';
				nll <= '0';
				nlO <= '0';
		ELSIF (rcvd_clk = '1' AND rcvd_clk'event) THEN
				n0i <= data_in(1);
				n0l <= data_in(2);
				n0O <= data_in(3);
				nii <= data_in(4);
				nil <= data_in(5);
				niO <= data_in(6);
				nl <= cid_en;
				nl0i <= wire_nlOi_dataout;
				nl0l <= wire_nlOl_dataout;
				nl0O <= wire_nlOO_dataout;
				nl1i <= wire_nlli_dataout;
				nl1l <= wire_nlll_dataout;
				nl1O <= wire_nllO_dataout;
				nli <= data_in(7);
				nlii <= wire_n1i_dataout;
				nlil <= wire_n1l_dataout;
				nliO <= data_in(0);
				nll <= niOi0O;
				nlO <= nl;
		END IF;
	END PROCESS;
	wire_ni_CLRN <= ((niOi0l4 XOR niOi0l3) AND wire_w_lg_soft_reset7w(0));
	wire_ni_w_lg_w_lg_w_lg_nlO108w111w112w(0) <= wire_ni_w_lg_w_lg_nlO108w111w(0) AND niO0il;
	wire_ni_w_lg_w_lg_nlO108w111w(0) <= wire_ni_w_lg_nlO108w(0) AND wire_niO00i22_w_lg_q110w(0);
	wire_ni_w_lg_nlO108w(0) <= nlO AND niO00O;
	wire_ni_w_lg_nl0i2979w(0) <= NOT nl0i;
	wire_ni_w_lg_nl0l2977w(0) <= NOT nl0l;
	wire_ni_w_lg_nl0O2975w(0) <= NOT nl0O;
	wire_ni_w_lg_nl1l2983w(0) <= NOT nl1l;
	wire_ni_w_lg_nl1O2981w(0) <= NOT nl1O;
	wire_ni_w_lg_nlii2973w(0) <= NOT nlii;
	wire_ni_w_lg_nlil2972w(0) <= NOT nlil;
	wire_ni_w_lg_nll2606w(0) <= NOT nll;
	PROCESS (rcvd_clk, wire_nilO_PRN, soft_reset)
	BEGIN
		IF (wire_nilO_PRN = '0') THEN
				niOi <= '1';
				nlliO <= '1';
		ELSIF (soft_reset = '1') THEN
				niOi <= '0';
				nlliO <= '0';
		ELSIF (rcvd_clk = '1' AND rcvd_clk'event) THEN
			IF (niO0Ol = '1') THEN
				niOi <= wire_n0Oi_o;
				nlliO <= wire_n0lO_o;
			END IF;
		END IF;
	END PROCESS;
	wire_nilO_PRN <= (niO0Oi14 XOR niO0Oi13);
	PROCESS (rcvd_clk, soft_reset)
	BEGIN
		IF (soft_reset = '1') THEN
				niOO <= '1';
		ELSIF (rcvd_clk = '1' AND rcvd_clk'event) THEN
			IF (niO0Ol = '1') THEN
				niOO <= wire_n0Ol_o;
			END IF;
		END IF;
		if (now = 0 ns) then
			niOO <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (rcvd_clk, wire_nll0O_dataout, wire_nliOi_CLRN)
	BEGIN
		IF (wire_nll0O_dataout = '1') THEN
				nli0lO <= '1';
				nlii0O <= '1';
				nliOl <= '1';
				nll0il <= '1';
				nll0iO <= '1';
				nll0li <= '1';
				nll0ll <= '1';
				nll0lO <= '1';
				nll0Oi <= '1';
				nll0Ol <= '1';
				nll0OO <= '1';
				nlli0i <= '1';
				nlli0l <= '1';
				nlli0O <= '1';
				nlli1i <= '1';
				nlli1l <= '1';
				nlli1O <= '1';
				nlliii <= '1';
				nlliil <= '1';
				nlliiO <= '1';
				nllili <= '1';
				nllill <= '1';
				nllilO <= '1';
				nlliOi <= '1';
				nlliOl <= '1';
				nlliOO <= '1';
				nlll0i <= '1';
				nlll0l <= '1';
				nlll0O <= '1';
				nlll1i <= '1';
				nlll1l <= '1';
				nlll1O <= '1';
				nlllii <= '1';
		ELSIF (wire_nliOi_CLRN = '0') THEN
				nli0lO <= '0';
				nlii0O <= '0';
				nliOl <= '0';
				nll0il <= '0';
				nll0iO <= '0';
				nll0li <= '0';
				nll0ll <= '0';
				nll0lO <= '0';
				nll0Oi <= '0';
				nll0Ol <= '0';
				nll0OO <= '0';
				nlli0i <= '0';
				nlli0l <= '0';
				nlli0O <= '0';
				nlli1i <= '0';
				nlli1l <= '0';
				nlli1O <= '0';
				nlliii <= '0';
				nlliil <= '0';
				nlliiO <= '0';
				nllili <= '0';
				nllill <= '0';
				nllilO <= '0';
				nlliOi <= '0';
				nlliOl <= '0';
				nlliOO <= '0';
				nlll0i <= '0';
				nlll0l <= '0';
				nlll0O <= '0';
				nlll1i <= '0';
				nlll1l <= '0';
				nlll1O <= '0';
				nlllii <= '0';
		ELSIF (rcvd_clk = '1' AND rcvd_clk'event) THEN
				nli0lO <= wire_nllliO_dataout;
				nlii0O <= wire_nli0Oi_dataout;
				nliOl <= wire_niO0i_dataout;
				nll0il <= wire_nlllli_dataout;
				nll0iO <= wire_nlllll_dataout;
				nll0li <= wire_nllllO_dataout;
				nll0ll <= wire_nlllOi_dataout;
				nll0lO <= wire_nlllOl_dataout;
				nll0Oi <= wire_nlllOO_dataout;
				nll0Ol <= wire_nllO1i_dataout;
				nll0OO <= wire_nllO1l_dataout;
				nlli0i <= wire_nllO0O_dataout;
				nlli0l <= wire_nllOii_dataout;
				nlli0O <= wire_nllOil_dataout;
				nlli1i <= wire_nllO1O_dataout;
				nlli1l <= wire_nllO0i_dataout;
				nlli1O <= wire_nllO0l_dataout;
				nlliii <= wire_nllOiO_dataout;
				nlliil <= wire_nllOli_dataout;
				nlliiO <= wire_nllOll_dataout;
				nllili <= wire_nllOlO_dataout;
				nllill <= wire_nllOOi_dataout;
				nllilO <= wire_nllOOl_dataout;
				nlliOi <= wire_nllOOO_dataout;
				nlliOl <= wire_nlO11i_dataout;
				nlliOO <= wire_nlO11l_dataout;
				nlll0i <= wire_nlO10O_dataout;
				nlll0l <= wire_nlO1ii_dataout;
				nlll0O <= wire_nlO1il_dataout;
				nlll1i <= wire_nlO11O_dataout;
				nlll1l <= wire_nlO10i_dataout;
				nlll1O <= wire_nlO10l_dataout;
				nlllii <= wire_nlO1iO_dataout;
		END IF;
		if (now = 0 ns) then
			nli0lO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlii0O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nliOl <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll0il <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll0iO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll0li <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll0ll <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll0lO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll0Oi <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll0Ol <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll0OO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlli0i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlli0l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlli0O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlli1i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlli1l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlli1O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlliii <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlliil <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlliiO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nllili <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nllill <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nllilO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlliOi <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlliOl <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlliOO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlll0i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlll0l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlll0O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlll1i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlll1l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlll1O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlllii <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nliOi_CLRN <= (niO11i38 XOR niO11i37);
	wire_nliOi_w_lg_w_lg_w_lg_w_lg_w3441w3442w3443w3444w3445w(0) <= wire_nliOi_w_lg_w_lg_w_lg_w3441w3442w3443w3444w(0) AND nlli0O;
	wire_nliOi_w_lg_w_lg_w_lg_w3441w3442w3443w3444w(0) <= wire_nliOi_w_lg_w_lg_w3441w3442w3443w(0) AND wire_nliOi_w_lg_nlliii2993w(0);
	wire_nliOi_w_lg_w_lg_w3441w3442w3443w(0) <= wire_nliOi_w_lg_w3441w3442w(0) AND wire_nliOi_w_lg_nlliil3354w(0);
	wire_nliOi_w_lg_w3441w3442w(0) <= wire_nliOi_w3441w(0) AND wire_nliOi_w_lg_nlliiO3302w(0);
	wire_nliOi_w3357w(0) <= wire_nliOi_w_lg_w_lg_w_lg_w_lg_w3350w3352w3353w3355w3356w(0) AND nlli0O;
	wire_nliOi_w3441w(0) <= wire_nliOi_w_lg_w_lg_w_lg_w_lg_w3436w3437w3438w3439w3440w(0) AND wire_nliOi_w_lg_nllili3351w(0);
	wire_nliOi_w_lg_w_lg_w_lg_w_lg_w3350w3352w3353w3355w3356w(0) <= wire_nliOi_w_lg_w_lg_w_lg_w3350w3352w3353w3355w(0) AND wire_nliOi_w_lg_nlliii2993w(0);
	wire_nliOi_w_lg_w_lg_w_lg_w_lg_w3436w3437w3438w3439w3440w(0) <= wire_nliOi_w_lg_w_lg_w_lg_w3436w3437w3438w3439w(0) AND wire_nliOi_w_lg_nllill3349w(0);
	wire_nliOi_w_lg_w_lg_w_lg_w3306w3307w3308w3309w(0) <= wire_nliOi_w_lg_w_lg_w3306w3307w3308w(0) AND nlli1l;
	wire_nliOi_w_lg_w_lg_w_lg_w3350w3352w3353w3355w(0) <= wire_nliOi_w_lg_w_lg_w3350w3352w3353w(0) AND wire_nliOi_w_lg_nlliil3354w(0);
	wire_nliOi_w_lg_w_lg_w_lg_w3436w3437w3438w3439w(0) <= wire_nliOi_w_lg_w_lg_w3436w3437w3438w(0) AND nllilO;
	wire_nliOi_w_lg_w_lg_w3306w3307w3308w(0) <= wire_nliOi_w_lg_w3306w3307w(0) AND nlli1O;
	wire_nliOi_w_lg_w_lg_w3350w3352w3353w(0) <= wire_nliOi_w_lg_w3350w3352w(0) AND wire_nliOi_w_lg_nlliiO3302w(0);
	wire_nliOi_w_lg_w_lg_w3436w3437w3438w(0) <= wire_nliOi_w_lg_w3436w3437w(0) AND nlliOi;
	wire_nliOi_w_lg_w3306w3307w(0) <= wire_nliOi_w3306w(0) AND nlli0i;
	wire_nliOi_w_lg_w3350w3352w(0) <= wire_nliOi_w3350w(0) AND wire_nliOi_w_lg_nllili3351w(0);
	wire_nliOi_w_lg_w3436w3437w(0) <= wire_nliOi_w3436w(0) AND wire_nliOi_w_lg_nlliOl3345w(0);
	wire_nliOi_w3219w(0) <= wire_nliOi_w_lg_w_lg_w_lg_w_lg_nll0Ol3215w3216w3217w3218w(0) AND nll0iO;
	wire_nliOi_w2989w(0) <= wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlliii2965w2966w2987w2988w(0) AND nlli1l;
	wire_nliOi_w3306w(0) <= wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlliiO3302w3303w3304w3305w(0) AND nlli0l;
	wire_nliOi_w3350w(0) <= wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlliOO3344w3346w3347w3348w(0) AND wire_nliOi_w_lg_nllill3349w(0);
	wire_nliOi_w3436w(0) <= wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlll0i3430w3431w3433w3435w(0) AND wire_nliOi_w_lg_nlliOO3344w(0);
	wire_nliOi_w_lg_w_lg_w_lg_w_lg_nll0Ol3215w3222w3223w3224w(0) <= wire_nliOi_w_lg_w_lg_w_lg_nll0Ol3215w3222w3223w(0) AND nll0li;
	wire_nliOi_w_lg_w_lg_w_lg_w_lg_nll0Ol3215w3216w3217w3218w(0) <= wire_nliOi_w_lg_w_lg_w_lg_nll0Ol3215w3216w3217w(0) AND wire_nliOi_w_lg_nll0li3207w(0);
	wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlliii2965w2966w2987w2988w(0) <= wire_nliOi_w_lg_w_lg_w_lg_nlliii2965w2966w2987w(0) AND nlli1O;
	wire_nliOi_w_lg_w_lg_w_lg_w_lg_nll0Ol3202w3203w3205w3206w(0) <= wire_nliOi_w_lg_w_lg_w_lg_nll0Ol3202w3203w3205w(0) AND nll0ll;
	wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlliii2993w2994w2996w2997w(0) <= wire_nliOi_w_lg_w_lg_w_lg_nlliii2993w2994w2996w(0) AND nlli0i;
	wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlliiO3302w3303w3304w3305w(0) <= wire_nliOi_w_lg_w_lg_w_lg_nlliiO3302w3303w3304w(0) AND nlli0O;
	wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlliOO3344w3346w3347w3348w(0) <= wire_nliOi_w_lg_w_lg_w_lg_nlliOO3344w3346w3347w(0) AND nllilO;
	wire_nliOi_w_lg_w_lg_w_lg_w_lg_nlll0i3430w3431w3433w3435w(0) <= wire_nliOi_w_lg_w_lg_w_lg_nlll0i3430w3431w3433w(0) AND wire_nliOi_w_lg_nlll1i3434w(0);
	wire_nliOi_w_lg_w_lg_w_lg_nll0Ol3215w3222w3223w(0) <= wire_nliOi_w_lg_w_lg_nll0Ol3215w3222w(0) AND nll0ll;
	wire_nliOi_w_lg_w_lg_w_lg_nll0Ol3215w3216w3217w(0) <= wire_nliOi_w_lg_w_lg_nll0Ol3215w3216w(0) AND nll0ll;
	wire_nliOi_w_lg_w_lg_w_lg_nlliii2965w2966w2987w(0) <= wire_nliOi_w_lg_w_lg_nlliii2965w2966w(0) AND wire_nliOi_w_lg_nlli0i2986w(0);
	wire_nliOi_w_lg_w_lg_w_lg_nll0Ol3202w3203w3205w(0) <= wire_nliOi_w_lg_w_lg_nll0Ol3202w3203w(0) AND wire_nliOi_w_lg_nll0lO3204w(0);
	wire_nliOi_w_lg_w_lg_w_lg_nlliii2993w2994w2996w(0) <= wire_nliOi_w_lg_w_lg_nlliii2993w2994w(0) AND wire_nliOi_w_lg_nlli0l2995w(0);
	wire_nliOi_w_lg_w_lg_w_lg_nlliiO3302w3303w3304w(0) <= wire_nliOi_w_lg_w_lg_nlliiO3302w3303w(0) AND wire_nliOi_w_lg_nlliii2993w(0);
	wire_nliOi_w_lg_w_lg_w_lg_nlliOO3344w3346w3347w(0) <= wire_nliOi_w_lg_w_lg_nlliOO3344w3346w(0) AND nlliOi;
	wire_nliOi_w_lg_w_lg_w_lg_nlll0i3430w3431w3433w(0) <= wire_nliOi_w_lg_w_lg_nlll0i3430w3431w(0) AND wire_nliOi_w_lg_nlll1l3432w(0);
	wire_nliOi_w_lg_w_lg_nll0Ol3215w3222w(0) <= wire_nliOi_w_lg_nll0Ol3215w(0) AND wire_nliOi_w_lg_nll0lO3204w(0);
	wire_nliOi_w_lg_w_lg_nll0Ol3215w3216w(0) <= wire_nliOi_w_lg_nll0Ol3215w(0) AND nll0lO;
	wire_nliOi_w_lg_w_lg_nlliii2965w2966w(0) <= wire_nliOi_w_lg_nlliii2965w(0) AND nlli0l;
	wire_nliOi_w_lg_w_lg_nll0Ol3202w3203w(0) <= wire_nliOi_w_lg_nll0Ol3202w(0) AND nll0Oi;
	wire_nliOi_w_lg_w_lg_nlliii2993w2994w(0) <= wire_nliOi_w_lg_nlliii2993w(0) AND nlli0O;
	wire_nliOi_w_lg_w_lg_nlliiO3302w3303w(0) <= wire_nliOi_w_lg_nlliiO3302w(0) AND nlliil;
	wire_nliOi_w_lg_w_lg_nlliOO3344w3346w(0) <= wire_nliOi_w_lg_nlliOO3344w(0) AND wire_nliOi_w_lg_nlliOl3345w(0);
	wire_nliOi_w_lg_w_lg_nlll0i3430w3431w(0) <= wire_nliOi_w_lg_nlll0i3430w(0) AND nlll1O;
	wire_nliOi_w_lg_nlii0O2954w(0) <= nlii0O AND wire_w_lg_niil0O2953w(0);
	wire_nliOi_w_lg_nlii0O2944w(0) <= nlii0O AND wire_w_lg_niilii2943w(0);
	wire_nliOi_w_lg_nll0Ol3215w(0) <= nll0Ol AND nll0Oi;
	wire_nliOi_w_lg_nlliii2965w(0) <= nlliii AND nlli0O;
	wire_nliOi_w_lg_nli0lO3213w(0) <= NOT nli0lO;
	wire_nliOi_w_lg_nll0il3211w(0) <= NOT nll0il;
	wire_nliOi_w_lg_nll0iO3209w(0) <= NOT nll0iO;
	wire_nliOi_w_lg_nll0li3207w(0) <= NOT nll0li;
	wire_nliOi_w_lg_nll0lO3204w(0) <= NOT nll0lO;
	wire_nliOi_w_lg_nll0Ol3202w(0) <= NOT nll0Ol;
	wire_nliOi_w_lg_nll0OO3003w(0) <= NOT nll0OO;
	wire_nliOi_w_lg_nlli0i2986w(0) <= NOT nlli0i;
	wire_nliOi_w_lg_nlli0l2995w(0) <= NOT nlli0l;
	wire_nliOi_w_lg_nlli1i2990w(0) <= NOT nlli1i;
	wire_nliOi_w_lg_nlli1l3000w(0) <= NOT nlli1l;
	wire_nliOi_w_lg_nlli1O2998w(0) <= NOT nlli1O;
	wire_nliOi_w_lg_nlliii2993w(0) <= NOT nlliii;
	wire_nliOi_w_lg_nlliil3354w(0) <= NOT nlliil;
	wire_nliOi_w_lg_nlliiO3302w(0) <= NOT nlliiO;
	wire_nliOi_w_lg_nllili3351w(0) <= NOT nllili;
	wire_nliOi_w_lg_nllill3349w(0) <= NOT nllill;
	wire_nliOi_w_lg_nlliOl3345w(0) <= NOT nlliOl;
	wire_nliOi_w_lg_nlliOO3344w(0) <= NOT nlliOO;
	wire_nliOi_w_lg_nlll0i3430w(0) <= NOT nlll0i;
	wire_nliOi_w_lg_nlll1i3434w(0) <= NOT nlll1i;
	wire_nliOi_w_lg_nlll1l3432w(0) <= NOT nlll1l;
	wire_nliOi_w_lg_w_lg_nlliii2127w2128w(0) <= wire_nliOi_w_lg_nlliii2127w(0) XOR nlli1l;
	wire_nliOi_w_lg_w_lg_nlliOl1740w1741w(0) <= wire_nliOi_w_lg_nlliOl1740w(0) XOR nlliiO;
	wire_nliOi_w_lg_w_lg_nlliOO1669w1670w(0) <= wire_nliOi_w_lg_nlliOO1669w(0) XOR nllili;
	wire_nliOi_w_lg_w_lg_nlll0i1685w1686w(0) <= wire_nliOi_w_lg_nlll0i1685w(0) XOR nlliOl;
	wire_nliOi_w_lg_w_lg_nlll1i2573w2574w(0) <= wire_nliOi_w_lg_nlll1i2573w(0) XOR nlll0O;
	wire_nliOi_w_lg_w_lg_nlll1l2504w2505w(0) <= wire_nliOi_w_lg_nlll1l2504w(0) XOR nlllii;
	wire_nliOi_w_lg_w_lg_nlll1O1756w1757w(0) <= wire_nliOi_w_lg_nlll1O1756w(0) XOR nlliOi;
	wire_nliOi_w_lg_nlli0l2436w(0) <= nlli0l XOR nll0OO;
	wire_nliOi_w_lg_nlli0O2370w(0) <= nlli0O XOR nlli1i;
	wire_nliOi_w_lg_nlli0O2339w(0) <= nlli0O XOR nlli1O;
	wire_nliOi_w_lg_nlli1l2531w(0) <= nlli1l XOR nlli1i;
	wire_nliOi_w_lg_nlli1O2059w(0) <= nlli1O XOR nlli1i;
	wire_nliOi_w_lg_nlli1O2462w(0) <= nlli1O XOR nlli1l;
	wire_nliOi_w_lg_nlliii2273w(0) <= nlliii XOR nlli0i;
	wire_nliOi_w_lg_nlliii2127w(0) <= nlliii XOR nlli1i;
	wire_nliOi_w_lg_nlliil2207w(0) <= nlliil XOR nlli0l;
	wire_nliOi_w_lg_nlliiO2139w(0) <= nlliiO XOR nlli0O;
	wire_nliOi_w_lg_nllili2557w(0) <= nllili XOR nlliiO;
	wire_nliOi_w_lg_nllill2086w(0) <= nllill XOR nlliiO;
	wire_nliOi_w_lg_nllill2488w(0) <= nllill XOR nllili;
	wire_nliOi_w_lg_nllilO2017w(0) <= nllilO XOR nllili;
	wire_nliOi_w_lg_nlliOi1948w(0) <= nlliOi XOR nllill;
	wire_nliOi_w_lg_nlliOl1740w(0) <= nlliOl XOR nllili;
	wire_nliOi_w_lg_nlliOl1879w(0) <= nlliOl XOR nllilO;
	wire_nliOi_w_lg_nlliOO1669w(0) <= nlliOO XOR nllill;
	wire_nliOi_w_lg_nlll0i1685w(0) <= nlll0i XOR nlliOO;
	wire_nliOi_w_lg_nlll0i1825w(0) <= nlll0i XOR nlll1l;
	wire_nliOi_w_lg_nlll1i2573w(0) <= nlll1i XOR nlli1O;
	wire_nliOi_w_lg_nlll1i2032w(0) <= nlll1i XOR nlliOl;
	wire_nliOi_w_lg_nlll1l2504w(0) <= nlll1l XOR nlli0i;
	wire_nliOi_w_lg_nlll1l1963w(0) <= nlll1l XOR nlliOO;
	wire_nliOi_w_lg_nlll1O1756w(0) <= nlll1O XOR nlliOl;
	wire_nliOi_w_lg_nlll1O1894w(0) <= nlll1O XOR nlll1i;
	PROCESS (rcvd_clk, wire_nll0O_dataout)
	BEGIN
		IF (wire_nll0O_dataout = '1') THEN
				nli00O <= '0';
				nli0ii <= '0';
				nli0il <= '0';
				nli0iO <= '0';
				nli0li <= '0';
				nli0ll <= '0';
				nliiO <= '0';
				nlili <= '0';
				nlill <= '0';
				nlilO <= '0';
				nliOO <= '0';
				nll0i <= '0';
				nll1i <= '0';
				nll1l <= '0';
				nlllil <= '0';
		ELSIF (rcvd_clk = '1' AND rcvd_clk'event) THEN
				nli00O <= wire_nli0Ol_dataout;
				nli0ii <= nli0il;
				nli0il <= nli0iO;
				nli0iO <= wire_nli0OO_dataout;
				nli0li <= wire_nlii1l_dataout;
				nli0ll <= wire_nlii1i_dataout;
				nliiO <= wire_nilOO_dataout;
				nlili <= wire_niO1i_dataout;
				nlill <= wire_niO1l_dataout;
				nlilO <= wire_niO1O_dataout;
				nliOO <= niO11l;
				nll0i <= rprbs_en_rx;
				nll1i <= niO11O;
				nll1l <= nll0i;
				nlllil <= wire_nilOl_dataout;
		END IF;
	END PROCESS;
	wire_nll1O_w_lg_nli0li2861w(0) <= nli0li AND niil0i;
	wire_nll1O_w_lg_nli0li2856w(0) <= nli0li AND niil0l;
	wire_nll1O_w_lg_nli0li2902w(0) <= nli0li AND niil1l;
	wire_nll1O_w_lg_nli0li2886w(0) <= nli0li AND niil1O;
	wire_nll1O_w_lg_nli0li2589w(0) <= NOT nli0li;
	wire_nll1O_w_lg_nll1l2599w(0) <= NOT nll1l;
	wire_nll1O_w_lg_w_lg_nli0li2856w2857w(0) <= wire_nll1O_w_lg_nli0li2856w(0) OR nli0ll;
	wire_nll1O_w_lg_w_lg_nli0li2902w2903w(0) <= wire_nll1O_w_lg_nli0li2902w(0) OR nli0ll;
	wire_nll1O_w_lg_w_lg_nli0li2886w2887w(0) <= wire_nll1O_w_lg_nli0li2886w(0) OR nli0ll;
	PROCESS (rcvd_clk, wire_nllii_PRN, wire_nllii_CLRN)
	BEGIN
		IF (wire_nllii_PRN = '0') THEN
				nll0l <= '1';
				nllil <= '1';
		ELSIF (wire_nllii_CLRN = '0') THEN
				nll0l <= '0';
				nllil <= '0';
		ELSIF (rcvd_clk = '1' AND rcvd_clk'event) THEN
				nll0l <= nllil;
				nllil <= niO10O;
		END IF;
		if (now = 0 ns) then
			nll0l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nllil <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nllii_CLRN <= (niO10l34 XOR niO10l33);
	wire_nllii_PRN <= ((niO10i36 XOR niO10i35) AND wire_w_lg_soft_reset7w(0));
	wire_n00i_dataout <= nlll0i AND niO1iO;
	wire_n00l_dataout <= nlll1O AND niO1iO;
	wire_n00O_dataout <= nlll1l AND niO1iO;
	wire_n01i_dataout <= nlllii AND niO1iO;
	wire_n01l_dataout <= nlll0O AND niO1iO;
	wire_n01O_dataout <= nlll0l AND niO1iO;
	wire_n0i0l_dataout <= wire_n0iOi_dataout AND NOT(wire_n0li_dataout);
	wire_n0i0O_dataout <= wire_n0iOl_dataout OR wire_n0li_dataout;
	wire_n0ii_dataout <= nlll1i AND niO1iO;
	wire_n0iii_dataout <= wire_n0iOO_dataout AND NOT(wire_n0li_dataout);
	wire_n0iil_dataout <= wire_n0l1i_dataout OR wire_n0li_dataout;
	wire_n0iiO_dataout <= wire_n0l1l_dataout OR wire_n0li_dataout;
	wire_n0il_dataout <= nlliOO AND niO1iO;
	wire_n0ili_dataout <= wire_n0l1O_dataout AND NOT(wire_n0li_dataout);
	wire_n0ill_dataout <= wire_n0l0i_dataout OR wire_n0li_dataout;
	wire_n0ilO_dataout <= wire_n0l0l_dataout AND NOT(wire_n0li_dataout);
	wire_n0iO_dataout <= wire_n0ll_o AND niO0Ol;
	wire_n0iOi_dataout <= rcid_pattern WHEN wire_n0iO_dataout = '1'  ELSE nll0OO;
	wire_n0iOl_dataout <= rcid_pattern WHEN wire_n0iO_dataout = '1'  ELSE nlli1i;
	wire_n0iOO_dataout <= rcid_pattern WHEN wire_n0iO_dataout = '1'  ELSE nlli1l;
	wire_n0l0i_dataout <= rcid_pattern WHEN wire_n0iO_dataout = '1'  ELSE nlli0O;
	wire_n0l0l_dataout <= rcid_pattern WHEN wire_n0iO_dataout = '1'  ELSE nlliii;
	wire_n0l0O_dataout <= nll0OO WHEN niliil = '1'  ELSE ((nili0O XOR nlli1i) XOR nll0OO);
	wire_n0l1i_dataout <= rcid_pattern WHEN wire_n0iO_dataout = '1'  ELSE nlli1O;
	wire_n0l1l_dataout <= rcid_pattern WHEN wire_n0iO_dataout = '1'  ELSE nlli0i;
	wire_n0l1O_dataout <= rcid_pattern WHEN wire_n0iO_dataout = '1'  ELSE nlli0l;
	wire_n0li_dataout <= niOO AND niO0Ol;
	wire_n0lii_dataout <= nlli1i WHEN niliil = '1'  ELSE ((niliii XOR nlli1l) XOR nlli1i);
	wire_n0lil_dataout <= nlli1l WHEN niliil = '1'  ELSE (((((niliii XOR nlli0l) XOR nlli1O) XOR nlli1l) XOR nlli1i) XOR nll0OO);
	wire_n0liO_dataout <= nlli1O WHEN niliil = '1'  ELSE (((((nlliii XOR nlli0l) XOR nlli0i) XOR nlli1O) XOR nlli1l) XOR nll0OO);
	wire_n0lli_dataout <= nlli0i WHEN niliil = '1'  ELSE (nili0i XOR nll0OO);
	wire_n0lll_dataout <= nlli0l WHEN niliil = '1'  ELSE (nili0l XOR nlli1i);
	wire_n0llO_dataout <= nlli0O WHEN niliil = '1'  ELSE (nili0O XOR nlli1l);
	wire_n0lOi_dataout <= nlliii WHEN niliil = '1'  ELSE (niliii XOR nlli1O);
	wire_n0lOl_dataout <= nlliil OR NOT(niliil);
	wire_n0lOO_dataout <= nlliiO OR NOT(niliil);
	wire_n0O0i_dataout <= nlliOi OR NOT(niliil);
	wire_n0O0l_dataout <= nlliOl OR NOT(niliil);
	wire_n0O0O_dataout <= nlliOO OR NOT(niliil);
	wire_n0O1i_dataout <= nllili OR NOT(niliil);
	wire_n0O1l_dataout <= nllill OR NOT(niliil);
	wire_n0O1O_dataout <= nllilO OR NOT(niliil);
	wire_n0Oii_dataout <= nlll1i OR NOT(niliil);
	wire_n0Oil_dataout <= nlll1l OR NOT(niliil);
	wire_n0OiO_dataout <= nlll1O OR NOT(niliil);
	wire_n0Oli_dataout <= nlll0i OR NOT(niliil);
	wire_n0Oll_dataout <= nlll0l OR NOT(niliil);
	wire_n0OlO_dataout <= nlll0O OR NOT(niliil);
	wire_n0OO_dataout <= niO01i OR niO0ii;
	wire_n0OOi_dataout <= nlllii OR NOT(niliil);
	wire_n10i_dataout <= nlll1O WHEN niO1il = '1'  ELSE wire_n00l_dataout;
	wire_n10l_dataout <= nlll1l WHEN niO1il = '1'  ELSE wire_n00O_dataout;
	wire_n10O_dataout <= nlll1i WHEN niO1il = '1'  ELSE wire_n0ii_dataout;
	wire_n110i_dataout <= wire_n0ilO_dataout WHEN wire_nil0O_o(0) = '1'  ELSE nll0Ol;
	wire_n111i_dataout <= wire_n0iiO_dataout WHEN wire_nil0O_o(0) = '1'  ELSE nll0ll;
	wire_n111l_dataout <= wire_n0ili_dataout WHEN wire_nil0O_o(0) = '1'  ELSE nll0lO;
	wire_n111O_dataout <= wire_n0ill_dataout WHEN wire_nil0O_o(0) = '1'  ELSE nll0Oi;
	wire_n11i_dataout <= nlll0O WHEN niO1il = '1'  ELSE wire_n01l_dataout;
	wire_n11l_dataout <= nlll0l WHEN niO1il = '1'  ELSE wire_n01O_dataout;
	wire_n11O_dataout <= nlll0i WHEN niO1il = '1'  ELSE wire_n00i_dataout;
	wire_n1i_dataout <= wire_n1O_o(7) WHEN wire_n0iO_dataout = '1'  ELSE rcid_len(6);
	wire_n1ii_dataout <= nlliOO WHEN niO1il = '1'  ELSE wire_n0il_dataout;
	wire_n1il_dataout <= nlliOl AND niO1il;
	wire_n1iO_dataout <= nlliOi AND niO1il;
	wire_n1l_dataout <= wire_n1O_o(8) WHEN wire_n0iO_dataout = '1'  ELSE rcid_len(7);
	wire_n1li_dataout <= nllilO AND niO1il;
	wire_n1ll_dataout <= nllill AND niO1il;
	wire_n1lO_dataout <= nllili AND niO1il;
	wire_n1Oi_dataout <= nlliiO AND niO1il;
	wire_n1Ol_dataout <= nlliil AND niO1il;
	wire_n1OO_dataout <= nlliii AND niO1il;
	wire_ni0i_dataout <= niO1OO AND NOT(niO01i);
	wire_ni0il_dataout <= nli0lO OR NOT(nilill);
	wire_ni0li_dataout <= nll0iO OR NOT(nilill);
	wire_ni0ll_dataout <= nll0li OR NOT(nilill);
	wire_ni0Ol_dataout <= nll0lO OR NOT(nilill);
	wire_ni0OO_dataout <= nll0Oi OR NOT(nilill);
	wire_ni1i_dataout <= wire_ni1O_dataout AND NOT(niO0ii);
	wire_ni1l_dataout <= wire_ni0i_dataout AND NOT(niO0ii);
	wire_ni1O_dataout <= wire_w_lg_niO1OO117w(0) OR niO01i;
	wire_nii1i_dataout <= nll0Ol OR NOT(nilill);
	wire_nilii_dataout <= wire_nilOi_dataout WHEN rall_one_dect_only = '1'  ELSE wire_nillO_dataout;
	wire_nilii_w_lg_dataout2862w(0) <= wire_nilii_dataout AND wire_nll1O_w_lg_nli0li2861w(0);
	wire_nilii_w_lg_dataout2621w(0) <= NOT wire_nilii_dataout;
	wire_nilii_w_lg_w_lg_dataout2862w2863w(0) <= wire_nilii_w_lg_dataout2862w(0) OR nli0ll;
	wire_nilil_dataout <= (nll1i AND nill0i) WHEN niO1ii = '1'  ELSE wire_niliO_dataout;
	wire_nilil_w_lg_dataout2635w(0) <= NOT wire_nilil_dataout;
	wire_niliO_dataout <= (nliOO AND nill0l) AND niO1il;
	wire_nillO_dataout <= nlllil WHEN niO0Ol = '1'  ELSE wire_niO0O_dataout;
	wire_nilOi_dataout <= wire_nli1i_dataout WHEN niO0Ol = '1'  ELSE wire_niO0l_dataout;
	wire_nilOl_dataout <= wire_nli1l_dataout WHEN niO0Ol = '1'  ELSE wire_niOii_dataout;
	wire_nilOO_dataout <= wire_nli1O_dataout WHEN niO0Ol = '1'  ELSE wire_niOil_dataout;
	wire_niO0i_dataout <= wire_nli0O_o WHEN niO0Ol = '1'  ELSE wire_niOlO_dataout;
	wire_niO0l_dataout <= wire_niOOl_dataout AND NOT(nill0O);
	wire_niO0O_dataout <= nlllil WHEN nill0O = '1'  ELSE wire_niOOi_dataout;
	wire_niO1i_dataout <= wire_nli0i_dataout WHEN niO0Ol = '1'  ELSE wire_niOiO_dataout;
	wire_niO1l_dataout <= wire_nli1i_dataout WHEN niO0Ol = '1'  ELSE wire_niOli_dataout;
	wire_niO1O_dataout <= wire_nli0l_dataout WHEN niO0Ol = '1'  ELSE wire_niOll_dataout;
	wire_niOii_dataout <= wire_nl0li_dataout WHEN nill0O = '1'  ELSE wire_niOOO_dataout;
	wire_niOil_dataout <= wire_nl0ll_dataout WHEN nill0O = '1'  ELSE wire_nl11i_dataout;
	wire_niOiO_dataout <= wire_nl0lO_dataout WHEN nill0O = '1'  ELSE wire_nl11l_dataout;
	wire_niOli_dataout <= wire_nl0Oi_dataout WHEN nill0O = '1'  ELSE wire_nl11O_dataout;
	wire_niOll_dataout <= wire_nl0Ol_dataout WHEN nill0O = '1'  ELSE wire_nl10i_dataout;
	wire_niOlO_dataout <= wire_nl0OO_o WHEN nill0O = '1'  ELSE wire_nl10l_dataout;
	wire_niOOi_dataout <= nlllil WHEN niO1iO = '1'  ELSE wire_nl10O_dataout;
	wire_niOOl_dataout <= wire_nl00l_dataout WHEN niO1iO = '1'  ELSE wire_nl1ii_dataout;
	wire_niOOO_dataout <= wire_nl00O_dataout WHEN niO1iO = '1'  ELSE wire_nl1il_dataout;
	wire_nl00l_dataout <= nilO1l AND nlill;
	wire_nl00O_dataout <= nilOOO AND nliiO;
	wire_nl01i_dataout <= nillll AND nlili;
	wire_nl01l_dataout <= nillli AND nlill;
	wire_nl01O_dataout <= nilliO AND nlilO;
	wire_nl0ii_dataout <= nilOOO AND nlili;
	wire_nl0il_dataout <= nilOOl AND nliOl;
	wire_nl0li_dataout <= nilOil AND nliiO;
	wire_nl0ll_dataout <= nilOii AND nlili;
	wire_nl0lO_dataout <= nilO0O AND nlill;
	wire_nl0Oi_dataout <= nilO0l AND nlilO;
	wire_nl0Ol_dataout <= nilO0i AND nliOl;
	wire_nl10i_dataout <= wire_nl0il_dataout WHEN niO1iO = '1'  ELSE wire_nl1lO_dataout;
	wire_nl10l_dataout <= wire_nl0iO_o WHEN niO1iO = '1'  ELSE wire_nl1Oi_dataout;
	wire_nl10O_dataout <= nlllil AND nillii;
	wire_nl11i_dataout <= wire_nl0ii_dataout WHEN niO1iO = '1'  ELSE wire_nl1iO_dataout;
	wire_nl11l_dataout <= wire_nl00l_dataout WHEN niO1iO = '1'  ELSE wire_nl1li_dataout;
	wire_nl11O_dataout <= wire_nli1i_dataout WHEN niO1iO = '1'  ELSE wire_nl1ll_dataout;
	wire_nl1ii_dataout <= wire_nl1Ol_dataout AND nillii;
	wire_nl1il_dataout <= wire_nl1OO_dataout WHEN nillii = '1'  ELSE nlllil;
	wire_nl1iO_dataout <= wire_nl01i_dataout WHEN nillii = '1'  ELSE nliiO;
	wire_nl1li_dataout <= wire_nl01l_dataout WHEN nillii = '1'  ELSE nlili;
	wire_nl1ll_dataout <= wire_nl01O_dataout WHEN nillii = '1'  ELSE nlill;
	wire_nl1lO_dataout <= wire_nl1Ol_dataout WHEN nillii = '1'  ELSE nlilO;
	wire_nl1Oi_dataout <= wire_nl00i_o WHEN nillii = '1'  ELSE nliOl;
	wire_nl1Ol_dataout <= nillil AND nliOl;
	wire_nl1OO_dataout <= nilllO AND nliiO;
	wire_nli0i_dataout <= nilOll AND nlill;
	wire_nli0l_dataout <= nilOli AND nliOl;
	wire_nli0Oi_dataout <= wire_nlii1O_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nli0Ol_dataout <= wire_nlii0l_dataout AND NOT(wire_nll1O_w_lg_nll1l2599w(0));
	wire_nli0OO_dataout <= wire_nliiii_dataout AND NOT(wire_nll1O_w_lg_nll1l2599w(0));
	wire_nli1i_dataout <= nilOOl AND nlilO;
	wire_nli1l_dataout <= nilOOi AND nliiO;
	wire_nli1O_dataout <= nilOlO AND nlili;
	wire_nlii0i_dataout <= nli0li WHEN rprbs_clr_rslt_rx = '1'  ELSE wire_nliiOi_o;
	wire_nlii0l_dataout <= wire_nliill_o AND NOT(rprbs_clr_rslt_rx);
	wire_nlii1i_dataout <= wire_nliiil_dataout AND NOT(wire_nll1O_w_lg_nll1l2599w(0));
	wire_nlii1l_dataout <= wire_nlii0i_dataout AND NOT(wire_nll1O_w_lg_nll1l2599w(0));
	wire_nlii1O_dataout <= nlii0O WHEN rprbs_clr_rslt_rx = '1'  ELSE wire_nliiiO_o;
	wire_nliiii_dataout <= wire_nliilO_o AND NOT(rprbs_clr_rslt_rx);
	wire_nliiil_dataout <= wire_nliili_o AND NOT(rprbs_clr_rslt_rx);
	wire_nliil_dataout <= nilOOl WHEN rcid_pattern = '1'  ELSE nilOOO;
	wire_nliOil_dataout <= ((nli0li AND niiO0l) OR nli0ll) WHEN rall_one_dect_only = '1'  ELSE ((nli0li AND niiO0O) OR nli0ll);
	wire_nll01i_dataout <= ((nli0li AND nil11l) OR nli0ll) AND NOT(nil11i);
	wire_nll0O_dataout <= nll0l AND NOT(scan_mode);
	wire_nll0O_w_lg_dataout167w(0) <= NOT wire_nll0O_dataout;
	wire_nll1li_dataout <= wire_nll1OO_dataout WHEN rall_one_dect_only = '1'  ELSE wire_nll1ll_dataout;
	wire_nll1ll_dataout <= ((nli0li AND niiOOl) OR nli0ll) AND NOT(nil11i);
	wire_nll1OO_dataout <= wire_nll01i_dataout WHEN nlO = '1'  ELSE ((nli0li AND niiOOO) OR nli0ll);
	wire_nlli_dataout <= wire_n1O_o(1) WHEN wire_n0iO_dataout = '1'  ELSE rcid_len(0);
	wire_nlll_dataout <= wire_n1O_o(2) WHEN wire_n0iO_dataout = '1'  ELSE rcid_len(1);
	wire_nllli_dataout <= nlllii WHEN niO1ii = '1'  ELSE wire_nlOOO_dataout;
	wire_nllli_w_lg_dataout3262w(0) <= NOT wire_nllli_dataout;
	wire_nllliO_dataout <= wire_nlO1li_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllll_dataout <= nlll0O WHEN niO1ii = '1'  ELSE wire_n11i_dataout;
	wire_nlllli_dataout <= wire_nlO1ll_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nlllll_dataout <= wire_nlO1lO_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllllO_dataout <= wire_nlO1Oi_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nlllO_dataout <= nlll0l WHEN niO1ii = '1'  ELSE wire_n11l_dataout;
	wire_nlllOi_dataout <= wire_nlO1Ol_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nlllOl_dataout <= wire_nlO1OO_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nlllOO_dataout <= wire_nlO01i_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllO_dataout <= wire_n1O_o(3) WHEN wire_n0iO_dataout = '1'  ELSE rcid_len(2);
	wire_nllO0i_dataout <= wire_nlO00l_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllO0l_dataout <= wire_nlO00O_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllO0O_dataout <= wire_nlO0ii_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllO1i_dataout <= wire_nlO01l_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllO1l_dataout <= wire_nlO01O_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllO1O_dataout <= wire_nlO00i_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllOi_dataout <= nlll0i WHEN niO1ii = '1'  ELSE wire_n11O_dataout;
	wire_nllOii_dataout <= wire_nlO0il_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllOil_dataout <= wire_nlO0iO_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllOiO_dataout <= wire_nlO0li_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllOl_dataout <= nlll1O WHEN niO1ii = '1'  ELSE wire_n10i_dataout;
	wire_nllOli_dataout <= wire_nlO0ll_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllOll_dataout <= wire_nlO0lO_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllOlO_dataout <= wire_nlO0Oi_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllOO_dataout <= nlll1l WHEN niO1ii = '1'  ELSE wire_n10l_dataout;
	wire_nllOOi_dataout <= wire_nlO0Ol_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllOOl_dataout <= wire_nlO0OO_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nllOOO_dataout <= wire_nlOi1i_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nlO00i_dataout <= wire_nii0i_o WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOl0l_dataout;
	wire_nlO00l_dataout <= wire_nii0l_o WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOl0O_dataout;
	wire_nlO00O_dataout <= wire_nii0O_o WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOlii_dataout;
	wire_nlO01i_dataout <= wire_ni0OO_dataout WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOl1l_dataout;
	wire_nlO01l_dataout <= wire_nii1i_dataout WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOl1O_dataout;
	wire_nlO01O_dataout <= wire_nii1O_o WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOl0i_dataout;
	wire_nlO0i_dataout <= nlliOi WHEN niO1ii = '1'  ELSE wire_n1iO_dataout;
	wire_nlO0ii_dataout <= wire_niiii_o WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOlil_dataout;
	wire_nlO0il_dataout <= (NOT (((wire_nil0O_o(25) OR wire_nil0O_o(17)) OR wire_nil0O_o(16)) OR wire_nil0O_o(8))) WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOliO_dataout;
	wire_nlO0iO_dataout <= wire_niiiO_o WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOlli_dataout;
	wire_nlO0l_dataout <= nllilO WHEN niO1ii = '1'  ELSE wire_n1li_dataout;
	wire_nlO0li_dataout <= (NOT ((wire_nil0O_o(25) OR wire_nil0O_o(17)) OR wire_nil0O_o(16))) WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOlll_dataout;
	wire_nlO0ll_dataout <= wire_niill_o WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOllO_dataout;
	wire_nlO0lO_dataout <= wire_niilO_o WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOlOi_dataout;
	wire_nlO0O_dataout <= nllill WHEN niO1ii = '1'  ELSE wire_n1ll_dataout;
	wire_nlO0Oi_dataout <= (NOT (((wire_nil0O_o(25) OR wire_nil0O_o(8)) OR wire_nil0O_o(2)) OR wire_nil0O_o(0))) WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOlOl_dataout;
	wire_nlO0Ol_dataout <= wire_w_lg_nililO2595w(0) WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOlOO_dataout;
	wire_nlO0OO_dataout <= wire_w_lg_niliOi2594w(0) WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOO1i_dataout;
	wire_nlO10i_dataout <= wire_nlOi0l_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nlO10l_dataout <= wire_nlOi0O_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nlO10O_dataout <= wire_nlOiii_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nlO11i_dataout <= wire_nlOi1l_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nlO11l_dataout <= wire_nlOi1O_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nlO11O_dataout <= wire_nlOi0i_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nlO1i_dataout <= nlll1i WHEN niO1ii = '1'  ELSE wire_n10O_dataout;
	wire_nlO1i_w_lg_dataout3255w(0) <= NOT wire_nlO1i_dataout;
	wire_nlO1ii_dataout <= wire_nlOiil_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nlO1il_dataout <= wire_nlOiiO_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nlO1iO_dataout <= wire_nlOili_dataout OR wire_nll1O_w_lg_nll1l2599w(0);
	wire_nlO1l_dataout <= nlliOO WHEN niO1ii = '1'  ELSE wire_n1ii_dataout;
	wire_nlO1l_w_lg_w_lg_w3259w3260w3261w(0) <= wire_nlO1l_w_lg_w3259w3260w(0) AND wire_nllll_dataout;
	wire_nlO1l_w_lg_w3259w3260w(0) <= wire_nlO1l_w3259w(0) AND wire_nlllO_dataout;
	wire_nlO1l_w3259w(0) <= wire_nlO1l_w_lg_w_lg_w_lg_w_lg_dataout3254w3256w3257w3258w(0) AND wire_nllOi_dataout;
	wire_nlO1l_w_lg_w_lg_w_lg_w_lg_dataout3254w3256w3257w3258w(0) <= wire_nlO1l_w_lg_w_lg_w_lg_dataout3254w3256w3257w(0) AND wire_nllOl_dataout;
	wire_nlO1l_w_lg_w_lg_w_lg_dataout3254w3256w3257w(0) <= wire_nlO1l_w_lg_w_lg_dataout3254w3256w(0) AND wire_nllOO_dataout;
	wire_nlO1l_w_lg_w_lg_dataout3254w3256w(0) <= wire_nlO1l_w_lg_dataout3254w(0) AND wire_nlO1i_w_lg_dataout3255w(0);
	wire_nlO1l_w_lg_dataout3254w(0) <= NOT wire_nlO1l_dataout;
	wire_nlO1li_dataout <= wire_ni0il_dataout WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOill_dataout;
	wire_nlO1ll_dataout <= wire_ni0iO_o WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOilO_dataout;
	wire_nlO1lO_dataout <= wire_ni0li_dataout WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOiOi_dataout;
	wire_nlO1O_dataout <= nlliOl WHEN niO1ii = '1'  ELSE wire_n1il_dataout;
	wire_nlO1Oi_dataout <= wire_ni0ll_dataout WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOiOl_dataout;
	wire_nlO1Ol_dataout <= wire_ni0lO_o WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOiOO_dataout;
	wire_nlO1OO_dataout <= wire_ni0Ol_dataout WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOl1i_dataout;
	wire_nlOi_dataout <= wire_n1O_o(4) WHEN wire_n0iO_dataout = '1'  ELSE rcid_len(3);
	wire_nlOi0i_dataout <= wire_w_lg_niliOO2592w(0) WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOO0l_dataout;
	wire_nlOi0l_dataout <= wire_w_lg_nill1i2591w(0) WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOO0O_dataout;
	wire_nlOi0O_dataout <= wire_w_lg_nill1l2590w(0) WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOOii_dataout;
	wire_nlOi1i_dataout <= wire_w_lg_niliOi2594w(0) WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOO1l_dataout;
	wire_nlOi1l_dataout <= wire_w_lg_niliOl2593w(0) WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOO1O_dataout;
	wire_nlOi1O_dataout <= wire_w_lg_nill1O2588w(0) WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOO0i_dataout;
	wire_nlOii_dataout <= nllili WHEN niO1ii = '1'  ELSE wire_n1lO_dataout;
	wire_nlOiii_dataout <= wire_w_lg_nill1l2590w(0) WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOOil_dataout;
	wire_nlOiil_dataout <= wire_w_lg_nill1l2590w(0) WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOOiO_dataout;
	wire_nlOiiO_dataout <= wire_w_lg_nill1l2590w(0) WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOOli_dataout;
	wire_nlOil_dataout <= nlliiO WHEN niO1ii = '1'  ELSE wire_n1Oi_dataout;
	wire_nlOili_dataout <= wire_w_lg_nill1O2588w(0) WHEN wire_nll1O_w_lg_nli0li2589w(0) = '1'  ELSE wire_nlOOll_dataout;
	wire_nlOill_dataout <= wire_nlOOlO_dataout WHEN niliiO = '1'  ELSE nli0lO;
	wire_nlOilO_dataout <= wire_nlOOOi_dataout WHEN niliiO = '1'  ELSE nll0il;
	wire_nlOiO_dataout <= nlliil WHEN niO1ii = '1'  ELSE wire_n1Ol_dataout;
	wire_nlOiOi_dataout <= wire_nlOOOl_dataout WHEN niliiO = '1'  ELSE nll0iO;
	wire_nlOiOl_dataout <= wire_nlOOOO_dataout WHEN niliiO = '1'  ELSE nll0li;
	wire_nlOiOO_dataout <= wire_n111i_dataout WHEN niliiO = '1'  ELSE nll0ll;
	wire_nlOl_dataout <= wire_n1O_o(5) WHEN wire_n0iO_dataout = '1'  ELSE rcid_len(4);
	wire_nlOl0i_dataout <= wire_n110l_o WHEN niliiO = '1'  ELSE nll0OO;
	wire_nlOl0l_dataout <= wire_n110O_o WHEN niliiO = '1'  ELSE nlli1i;
	wire_nlOl0O_dataout <= wire_n11ii_o WHEN niliiO = '1'  ELSE nlli1l;
	wire_nlOl1i_dataout <= wire_n111l_dataout WHEN niliiO = '1'  ELSE nll0lO;
	wire_nlOl1l_dataout <= wire_n111O_dataout WHEN niliiO = '1'  ELSE nll0Oi;
	wire_nlOl1O_dataout <= wire_n110i_dataout WHEN niliiO = '1'  ELSE nll0Ol;
	wire_nlOli_dataout <= nlliii WHEN niO1ii = '1'  ELSE wire_n1OO_dataout;
	wire_nlOlii_dataout <= wire_n11il_o WHEN niliiO = '1'  ELSE nlli1O;
	wire_nlOlil_dataout <= wire_n11iO_o WHEN niliiO = '1'  ELSE nlli0i;
	wire_nlOliO_dataout <= wire_n11li_o WHEN niliiO = '1'  ELSE nlli0l;
	wire_nlOll_dataout <= nlli0O AND niO1ii;
	wire_nlOlli_dataout <= wire_n11ll_o WHEN niliiO = '1'  ELSE nlli0O;
	wire_nlOlll_dataout <= wire_n11lO_o WHEN niliiO = '1'  ELSE nlliii;
	wire_nlOllO_dataout <= wire_n11Oi_o WHEN niliiO = '1'  ELSE nlliil;
	wire_nlOlO_dataout <= nlli0l AND niO1ii;
	wire_nlOlOi_dataout <= wire_n11Ol_o WHEN niliiO = '1'  ELSE nlliiO;
	wire_nlOlOl_dataout <= wire_n11OO_o WHEN niliiO = '1'  ELSE nllili;
	wire_nlOlOO_dataout <= wire_n101i_o WHEN niliiO = '1'  ELSE nllill;
	wire_nlOO_dataout <= wire_n1O_o(6) WHEN wire_n0iO_dataout = '1'  ELSE rcid_len(5);
	wire_nlOO0i_dataout <= wire_n100l_o WHEN niliiO = '1'  ELSE nlliOO;
	wire_nlOO0l_dataout <= wire_n100O_o WHEN niliiO = '1'  ELSE nlll1i;
	wire_nlOO0O_dataout <= wire_n10ii_o WHEN niliiO = '1'  ELSE nlll1l;
	wire_nlOO1i_dataout <= wire_n101l_o WHEN niliiO = '1'  ELSE nllilO;
	wire_nlOO1l_dataout <= wire_n101O_o WHEN niliiO = '1'  ELSE nlliOi;
	wire_nlOO1O_dataout <= wire_n100i_o WHEN niliiO = '1'  ELSE nlliOl;
	wire_nlOOi_dataout <= nlli0i AND niO1ii;
	wire_nlOOii_dataout <= wire_n10il_o WHEN niliiO = '1'  ELSE nlll1O;
	wire_nlOOil_dataout <= wire_n10iO_o WHEN niliiO = '1'  ELSE nlll0i;
	wire_nlOOiO_dataout <= wire_n10li_o WHEN niliiO = '1'  ELSE nlll0l;
	wire_nlOOl_dataout <= nlli1O AND niO1ii;
	wire_nlOOli_dataout <= wire_n10ll_o WHEN niliiO = '1'  ELSE nlll0O;
	wire_nlOOll_dataout <= wire_n10lO_o WHEN niliiO = '1'  ELSE nlllii;
	wire_nlOOlO_dataout <= wire_n0i0l_dataout WHEN wire_nil0O_o(0) = '1'  ELSE nli0lO;
	wire_nlOOO_dataout <= nlllii WHEN niO1il = '1'  ELSE wire_n01i_dataout;
	wire_nlOOOi_dataout <= wire_n0i0O_dataout WHEN wire_nil0O_o(0) = '1'  ELSE nll0il;
	wire_nlOOOl_dataout <= wire_n0iii_dataout WHEN wire_nil0O_o(0) = '1'  ELSE nll0iO;
	wire_nlOOOO_dataout <= wire_n0iil_dataout WHEN wire_nil0O_o(0) = '1'  ELSE nll0li;
	wire_n1O_a <= ( wire_niO0OO12_w_lg_w_lg_q32w33w & nlii & wire_niOi1i10_w_lg_w_lg_q28w29w & wire_niOi1l8_w_lg_w_lg_q25w26w & nl0i & nl1O & wire_niOi1O6_w_lg_w_lg_q20w21w & nl1i & "1");
	wire_n1O_b <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "1");
	n1O :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 9,
		width_b => 9,
		width_o => 9
	  )
	  PORT MAP ( 
		a => wire_n1O_a,
		b => wire_n1O_b,
		cin => wire_gnd,
		o => wire_n1O_o
	  );
	wire_nil0O_i <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	nil0O :  oper_decoder
	  GENERIC MAP (
		width_i => 5,
		width_o => 32
	  )
	  PORT MAP ( 
		i => wire_nil0O_i,
		o => wire_nil0O_o
	  );
	wire_nill_a <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	wire_nill_b <= ( nlil & nlii & wire_niO0ll18_w_lg_w_lg_q97w98w & nl0l & nl0i & nl1O & wire_niO0lO16_w_lg_w_lg_q91w92w & nl1i);
	nill :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8
	  )
	  PORT MAP ( 
		a => wire_nill_a,
		b => wire_nill_b,
		cin => wire_gnd,
		o => wire_nill_o
	  );
	wire_n100i_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil1OO & wire_w_lg_w_lg_nil00O1614w1615w & "0" & "0" & "0" & "0" & "0" & "0" & nil00i & wire_w_lg_w_lg_nil0Ol1598w1599w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1" & "0" & "0" & "0" & nlli0O & "0" & "0" & "0" & wire_n0O0l_dataout);
	wire_n100i_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n100i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n100i_data,
		o => wire_n100i_o,
		sel => wire_n100i_sel
	  );
	wire_n100l_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil01i & wire_w_lg_w_lg_nil0ii1543w1544w & "0" & "0" & "0" & "0" & "0" & "0" & nil00l & wire_w_lg_w_lg_nil0OO1527w1528w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1" & "0" & "0" & "0" & nlliii & "0" & "0" & "0" & wire_n0O0O_dataout);
	wire_n100l_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n100l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n100l_data,
		o => wire_n100l_o,
		sel => wire_n100l_sel
	  );
	wire_n100O_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil01l & wire_w_lg_w_lg_nil0il1472w1473w & "0" & "0" & "0" & "0" & "0" & "0" & nll0OO & "1" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1" & "0" & "0" & "0" & nlliil & "0" & "0" & "0" & wire_n0Oii_dataout);
	wire_n100O_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n100O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n100O_data,
		o => wire_n100O_o,
		sel => wire_n100O_sel
	  );
	wire_n101i_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil1lO & wire_nliOi_w_lg_nlll0i1825w & "0" & "0" & "0" & "0" & "0" & "0" & nil01i & nil0Oi & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1" & "0" & "0" & "0" & nlli1O & "0" & "0" & "0" & wire_n0O1l_dataout);
	wire_n101i_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n101i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n101i_data,
		o => wire_n101i_o,
		sel => wire_n101i_sel
	  );
	wire_n101l_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil1Oi & wire_nliOi_w_lg_w_lg_nlll1O1756w1757w & "0" & "0" & "0" & "0" & "0" & "0" & nil01l & wire_nliOi_w_lg_w_lg_nlliOl1740w1741w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1" & "0" & "0" & "0" & nlli0i & "0" & "0" & "0" & wire_n0O1O_dataout);
	wire_n101l_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n101l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n101l_data,
		o => wire_n101l_o,
		sel => wire_n101l_sel
	  );
	wire_n101O_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil1Ol & wire_nliOi_w_lg_w_lg_nlll0i1685w1686w & "0" & "0" & "0" & "0" & "0" & "0" & nil01O & wire_nliOi_w_lg_w_lg_nlliOO1669w1670w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1" & "0" & "0" & "0" & nlli0l & "0" & "0" & "0" & wire_n0O0i_dataout);
	wire_n101O_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n101O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n101O_data,
		o => wire_n101O_o,
		sel => wire_n101O_sel
	  );
	wire_n10ii_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil01O & wire_w_lg_nil0iO1403w & "0" & "0" & "0" & "0" & "0" & "0" & nlli1i & "1" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1" & "0" & "0" & "0" & nlliiO & "0" & "0" & "0" & wire_n0Oil_dataout);
	wire_n10ii_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n10ii :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n10ii_data,
		o => wire_n10ii_o,
		sel => wire_n10ii_sel
	  );
	wire_n10il_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil00i & wire_w_lg_w_lg_nil0iO1333w1334w & "0" & "0" & "0" & "0" & "0" & "0" & nlli1l & "1" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1" & "0" & "0" & "0" & nllili & "0" & "0" & "0" & wire_n0OiO_dataout);
	wire_n10il_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n10il :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n10il_data,
		o => wire_n10il_o,
		sel => wire_n10il_sel
	  );
	wire_n10iO_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil00l & wire_w_lg_w_lg_nil0li1263w1264w & "0" & "0" & "0" & "0" & "0" & "0" & nlli1O & "1" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1" & "0" & "0" & "0" & nllill & "0" & "0" & "0" & wire_n0Oli_dataout);
	wire_n10iO_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n10iO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n10iO_data,
		o => wire_n10iO_o,
		sel => wire_n10iO_sel
	  );
	wire_n10li_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nll0OO & "1" & "0" & "0" & "0" & "0" & "0" & "0" & nlli0i & "1" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1" & "0" & "0" & "0" & nllilO & "0" & "0" & "0" & wire_n0Oll_dataout);
	wire_n10li_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n10li :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n10li_data,
		o => wire_n10li_o,
		sel => wire_n10li_sel
	  );
	wire_n10ll_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nlli1i & "1" & "0" & "0" & "0" & "0" & "0" & "0" & nlli0l & "1" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1" & "0" & "0" & "0" & nlliOi & "0" & "0" & "0" & wire_n0OlO_dataout);
	wire_n10ll_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n10ll :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n10ll_data,
		o => wire_n10ll_o,
		sel => wire_n10ll_sel
	  );
	wire_n10lO_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nlli1l & "1" & "0" & "0" & "0" & "0" & "0" & "0" & nlli0O & "1" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1" & "0" & "0" & "0" & nlliOl & "0" & "0" & "0" & wire_n0OOi_dataout);
	wire_n10lO_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n10lO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n10lO_data,
		o => wire_n10lO_o,
		sel => wire_n10lO_sel
	  );
	wire_n110l_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & wire_nliOi_w_lg_w_lg_nlll1i2573w2574w & nil0ll & "0" & "0" & "0" & "0" & "0" & "0" & nil10l & wire_nliOi_w_lg_nllili2557w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & nili1O & "0" & "0" & "0" & nil1Oi & "0" & wire_nliOi_w_lg_nlli1l2531w & "0" & wire_n0l0O_dataout);
	wire_n110l_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n110l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n110l_data,
		o => wire_n110l_o,
		sel => wire_n110l_sel
	  );
	wire_n110O_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & wire_nliOi_w_lg_w_lg_nlll1l2504w2505w & nil0lO & "0" & "0" & "0" & "0" & "0" & "0" & nil10O & wire_nliOi_w_lg_nllill2488w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & nili1l & "0" & "0" & "0" & nil1Ol & "0" & wire_nliOi_w_lg_nlli1O2462w & "0" & wire_n0lii_dataout);
	wire_n110O_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n110O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n110O_data,
		o => wire_n110O_o,
		sel => wire_n110O_sel
	  );
	wire_n11ii_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & wire_nliOi_w_lg_nlli0l2436w & nil00O & "0" & "0" & "0" & "0" & "0" & "0" & nil1ii & nil0Ol & "0" & "0" & "0" & "0" & "0" & "0" & "0" & nili1i & "0" & "0" & "0" & nil1OO & "0" & nili0i & "0" & wire_n0lil_dataout);
	wire_n11ii_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n11ii :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n11ii_data,
		o => wire_n11ii_o,
		sel => wire_n11ii_sel
	  );
	wire_n11il_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & wire_nliOi_w_lg_nlli0O2370w & nil0ii & "0" & "0" & "0" & "0" & "0" & "0" & nil1il & nil0OO & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nliOi_w_lg_nlli0O2339w & "0" & "0" & "0" & nil01i & "0" & nili0l & "0" & wire_n0liO_dataout);
	wire_n11il_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n11il :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n11il_data,
		o => wire_n11il_o,
		sel => wire_n11il_sel
	  );
	wire_n11iO_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil10l & nil0il & "0" & "0" & "0" & "0" & "0" & "0" & nil1iO & nil0ll & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nliOi_w_lg_nlliii2273w & "0" & "0" & "0" & nil01l & "0" & nili0O & "0" & wire_n0lli_dataout);
	wire_n11iO_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n11iO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n11iO_data,
		o => wire_n11iO_o,
		sel => wire_n11iO_sel
	  );
	wire_n11li_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil10O & nil0li & "0" & "0" & "0" & "0" & "0" & "0" & nil1li & nil0lO & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nliOi_w_lg_nlliil2207w & "0" & "0" & "0" & nil01O & "0" & niliii & "0" & wire_n0lll_dataout);
	wire_n11li_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n11li :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n11li_data,
		o => wire_n11li_o,
		sel => wire_n11li_sel
	  );
	wire_n11ll_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil1ii & wire_w_lg_nil01l2170w & "0" & "0" & "0" & "0" & "0" & "0" & nil1ll & wire_w_lg_nil1Oi2155w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nliOi_w_lg_nlliiO2139w & "0" & "0" & "0" & nil00i & "0" & wire_nliOi_w_lg_w_lg_nlliii2127w2128w & "0" & wire_n0llO_dataout);
	wire_n11ll_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n11ll :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n11ll_data,
		o => wire_n11ll_o,
		sel => wire_n11ll_sel
	  );
	wire_n11lO_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil1il & nil0Oi & "0" & "0" & "0" & "0" & "0" & "0" & nil1lO & wire_nliOi_w_lg_nllill2086w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_w_lg_nili1O2070w & "0" & "0" & "0" & nil00l & "0" & wire_nliOi_w_lg_nlli1O2059w & "0" & wire_n0lOi_dataout);
	wire_n11lO_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n11lO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n11lO_data,
		o => wire_n11lO_o,
		sel => wire_n11lO_sel
	  );
	wire_n11Oi_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil1iO & wire_nliOi_w_lg_nlll1i2032w & "0" & "0" & "0" & "0" & "0" & "0" & nil1Oi & wire_nliOi_w_lg_nllilO2017w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_w_lg_nili1l2001w & "0" & "0" & "0" & nll0OO & "0" & "0" & "0" & wire_n0lOl_dataout);
	wire_n11Oi_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n11Oi :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n11Oi_data,
		o => wire_n11Oi_o,
		sel => wire_n11Oi_sel
	  );
	wire_n11Ol_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil1li & wire_nliOi_w_lg_nlll1l1963w & "0" & "0" & "0" & "0" & "0" & "0" & nil1Ol & wire_nliOi_w_lg_nlliOi1948w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_w_lg_nili1i1932w & "0" & "0" & "0" & nlli1i & "0" & "0" & "0" & wire_n0lOO_dataout);
	wire_n11Ol_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n11Ol :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n11Ol_data,
		o => wire_n11Ol_o,
		sel => wire_n11Ol_sel
	  );
	wire_n11OO_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & nil1ll & wire_nliOi_w_lg_nlll1O1894w & "0" & "0" & "0" & "0" & "0" & "0" & nil1OO & wire_nliOi_w_lg_nlliOl1879w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1" & "0" & "0" & "0" & nlli1l & "0" & "0" & "0" & wire_n0O1i_dataout);
	wire_n11OO_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	n11OO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n11OO_data,
		o => wire_n11OO_o,
		sel => wire_n11OO_sel
	  );
	wire_nii0i_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_w_lg_rall_one_dect_only477w & "1" & "1" & "1" & "0" & "1" & "1" & "1" & wire_w_lg_rall_one_dect_only477w);
	wire_nii0i_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	nii0i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nii0i_data,
		o => wire_nii0i_o,
		sel => wire_nii0i_sel
	  );
	wire_nii0l_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & rall_one_dect_only);
	wire_nii0l_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	nii0l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nii0l_data,
		o => wire_nii0l_o,
		sel => wire_nii0l_sel
	  );
	wire_nii0O_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_w_lg_rall_one_dect_only477w);
	wire_nii0O_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	nii0O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nii0O_data,
		o => wire_nii0O_o,
		sel => wire_nii0O_sel
	  );
	wire_nii1O_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_w_lg_rall_one_dect_only477w & "1" & "1" & "1" & "0" & "1" & "0" & "1" & wire_w_lg_rall_one_dect_only477w);
	wire_nii1O_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	nii1O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nii1O_data,
		o => wire_nii1O_o,
		sel => wire_nii1O_sel
	  );
	wire_niiii_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_w_lg_rall_one_dect_only477w & "1" & "1" & "1" & "1" & "1" & "1" & "1" & rall_one_dect_only);
	wire_niiii_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	niiii :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_niiii_data,
		o => wire_niiii_o,
		sel => wire_niiii_sel
	  );
	wire_niiiO_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_w_lg_rall_one_dect_only477w & "1" & "1" & "1" & "1" & "1" & "0" & "1" & "1");
	wire_niiiO_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	niiiO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_niiiO_data,
		o => wire_niiiO_o,
		sel => wire_niiiO_sel
	  );
	wire_niill_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "0" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & rall_one_dect_only & "1" & "1" & "1" & "1" & "1" & "0" & "1" & "0");
	wire_niill_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	niill :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_niill_data,
		o => wire_niill_o,
		sel => wire_niill_sel
	  );
	wire_niilO_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "0" & "0" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & rall_one_dect_only & "1" & "1" & "1" & "1" & "1" & "0" & "1" & "0");
	wire_niilO_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	niilO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_niilO_data,
		o => wire_niilO_o,
		sel => wire_niilO_sel
	  );
	wire_nliiiO_data <= ( nlii0O & nlii0O & nlii0O & nlii0O & nlii0O & nlii0O & niilil & wire_nliOi_w_lg_nlii0O2954w & nlii0O & nlii0O & nlii0O & nlii0O & nlii0O & nlii0O & niilil & wire_nliOi_w_lg_nlii0O2944w & nlii0O & nlii0O & nlii0O & nlii0O & nlii0O & nlii0O & nlii0O & niiO0i & nlii0O & nlii0O & nlii0O & niiO0i & nlii0O & niiO0i & nlii0O & niiO0i);
	wire_nliiiO_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	nliiiO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nliiiO_data,
		o => wire_nliiiO_o,
		sel => wire_nliiiO_sel
	  );
	wire_nliili_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & niiliO & wire_nll1O_w_lg_w_lg_nli0li2902w2903w & "0" & "0" & "0" & "0" & "0" & "0" & niiliO & wire_nll1O_w_lg_w_lg_nli0li2886w2887w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nliOil_dataout & "0" & "0" & "0" & wire_nilii_w_lg_w_lg_dataout2862w2863w & "0" & wire_nll1O_w_lg_w_lg_nli0li2856w2857w & "0" & wire_nll1li_dataout);
	wire_nliili_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	nliili :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nliili_data,
		o => wire_nliili_o,
		sel => wire_nliili_sel
	  );
	wire_nliill_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & wire_w_lg_niilli2830w & wire_w_lg_niilOi2828w & "0" & "0" & "0" & "0" & "0" & "0" & wire_w_lg_niilOO2814w & wire_w_lg_niiO1l2812w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_w_lg_niiOii2796w & "0" & "0" & "0" & wire_w_lg_niiOli2788w & "0" & wire_w_lg_niiOlO2784w & "0" & wire_w_lg_nil11O2779w);
	wire_nliill_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	nliill :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nliill_data,
		o => wire_nliill_o,
		sel => wire_nliill_sel
	  );
	wire_nliilO_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & niilli & niilOi & "0" & "0" & "0" & "0" & "0" & "0" & niilOO & niiO1l & "0" & "0" & "0" & "0" & "0" & "0" & "0" & niiOii & "0" & "0" & "0" & niiOli & "0" & niiOlO & "0" & nil11O);
	wire_nliilO_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	nliilO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nliilO_data,
		o => wire_nliilO_o,
		sel => wire_nliilO_sel
	  );
	wire_nliiOi_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & niillO & wire_w_lg_w_lg_sync_status2690w2691w & "0" & "0" & "0" & "0" & "0" & "0" & niillO & wire_w_lg_w_lg_sync_status2674w2675w & "0" & "0" & "0" & "0" & "0" & "0" & "0" & niiOiO & "0" & "0" & "0" & niiOiO & "0" & niiOiO & "0" & niiOiO);
	wire_nliiOi_sel <= ( rpma_doublewidth_rx & rpmadwidth_rx & rprbs_sel(2 DOWNTO 0));
	nliiOi :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nliiOi_data,
		o => wire_nliiOi_o,
		sel => wire_nliiOi_sel
	  );
	wire_n0ll_data <= ( "0" & wire_niO1li32_w_lg_w_lg_q159w160w & "1");
	wire_n0ll_sel <= ( niOO & niOi & nlliO);
	n0ll :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0ll_data,
		o => wire_n0ll_o,
		sel => wire_n0ll_sel
	  );
	wire_n0lO_data <= ( "0" & niO0ii & wire_w_lg_niO00O146w);
	wire_n0lO_sel <= ( niOO & wire_niO1ll30_w_lg_w_lg_q142w143w & wire_niO1lO28_w_lg_w_lg_q138w139w);
	n0lO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0lO_data,
		o => wire_n0lO_o,
		sel => wire_n0lO_sel
	  );
	wire_n0Oi_data <= ( niO1Oi & wire_ni1i_dataout & niO00O);
	wire_n0Oi_sel <= ( niOO & niOi & nlliO);
	n0Oi :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0Oi_data,
		o => wire_n0Oi_o,
		sel => wire_n0Oi_sel
	  );
	wire_n0Ol_data <= ( wire_w_lg_niO1Oi128w & wire_niO1Ol26_w_lg_w_lg_q125w126w & "0");
	wire_n0Ol_sel <= ( niOO & niOi & nlliO);
	n0Ol :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_n0Ol_data,
		o => wire_n0Ol_o,
		sel => wire_n0Ol_sel
	  );
	wire_ni0iO_data <= ( "1" & nll0il & rall_one_dect_only);
	wire_ni0iO_sel <= ( nilili & nilill & wire_nil0O_o(0));
	ni0iO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_ni0iO_data,
		o => wire_ni0iO_o,
		sel => wire_ni0iO_sel
	  );
	wire_ni0lO_data <= ( "1" & nll0ll & rall_one_dect_only);
	wire_ni0lO_sel <= ( nilili & nilill & wire_nil0O_o(0));
	ni0lO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_ni0lO_data,
		o => wire_ni0lO_o,
		sel => wire_ni0lO_sel
	  );
	wire_nl00i_data <= ( wire_w_lg_nillil256w & wire_w_lg_nilliO254w & wire_w_lg_nillli252w & wire_w_lg_nillll250w & wire_w_lg_nilllO248w & "1");
	wire_nl00i_sel <= ( wire_nillOi50_w_lg_w_lg_q242w243w & wire_nillOl48_w_lg_w_lg_q239w240w & nlill & wire_nillOO46_w_lg_w_lg_q235w236w & nliiO & nlllil);
	nl00i :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_nl00i_data,
		o => wire_nl00i_o,
		sel => wire_nl00i_sel
	  );
	wire_nl0iO_data <= ( wire_nilO1i44_w_lg_w_lg_q229w230w & wire_w_lg_nilOOl185w & wire_w_lg_nilO1l226w & wire_w_lg_nilOOO222w & wire_nilO1O42_w_lg_w_lg_q221w223w & "1");
	wire_nl0iO_sel <= ( nliOl & nlilO & nlill & nlili & nliiO & nlllil);
	nl0iO :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_nl0iO_data,
		o => wire_nl0iO_o,
		sel => wire_nl0iO_sel
	  );
	wire_nl0OO_data <= ( wire_w_lg_nilO0i209w & wire_w_lg_nilO0l207w & wire_w_lg_nilO0O205w & wire_w_lg_nilOii203w & wire_w_lg_nilOil201w & "1");
	wire_nl0OO_sel <= ( nliOl & nlilO & nlill & nlili & nliiO & nlllil);
	nl0OO :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_nl0OO_data,
		o => wire_nl0OO_o,
		sel => wire_nl0OO_sel
	  );
	wire_nli0O_data <= ( wire_nilOiO40_w_lg_w_lg_q187w189w & wire_w_lg_nilOOl185w & wire_w_lg_nilOll183w & wire_w_lg_nilOlO181w & wire_w_lg_nilOOi179w & "1");
	wire_nli0O_sel <= ( nliOl & nlilO & nlill & nlili & nliiO & nlllil);
	nli0O :  oper_selector
	  GENERIC MAP (
		width_data => 6,
		width_sel => 6
	  )
	  PORT MAP ( 
		data => wire_nli0O_data,
		o => wire_nli0O_o,
		sel => wire_nli0O_sel
	  );

 END RTL; --stratixiv_hssi_rx_digi_prbs_ver
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 577 mux21 929 oper_add 13 oper_less_than 8 oper_mux 157 oper_selector 81 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_rx_digi_wordalign IS 
	 PORT 
	 ( 
		 a1a2_k1k2_flag	:	OUT  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 a1a2_size	:	IN  STD_LOGIC;
		 adata	:	OUT  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 adata_valid	:	OUT  STD_LOGIC;
		 autobytealign_dis	:	IN  STD_LOGIC;
		 bitloc_rev_en	:	IN  STD_LOGIC;
		 bitslip	:	IN  STD_LOGIC;
		 byte_rev_en	:	IN  STD_LOGIC;
		 cg_syncpat	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 clk	:	IN  STD_LOGIC;
		 comp_pat	:	IN  STD_LOGIC_VECTOR (39 DOWNTO 0);
		 comp_pat_porn	:	IN  STD_LOGIC;
		 comp_pat_size	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 disable_rx_disp	:	IN  STD_LOGIC;
		 dwidth	:	IN  STD_LOGIC;
		 encdet_prbs	:	IN  STD_LOGIC;
		 encdt	:	IN  STD_LOGIC;
		 enumber	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 gen2ngen1	:	IN  STD_LOGIC;
		 gen2ngen1_bundle	:	IN  STD_LOGIC;
		 gnumber	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 ib_invalid_code	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 kchar	:	OUT  STD_LOGIC;
		 kcount	:	OUT  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 knumber	:	IN  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 lpbk_en	:	IN  STD_LOGIC;
		 max_rlv_sel	:	IN  STD_LOGIC_VECTOR (5 DOWNTO 0);
		 pipe_loose_sync	:	IN  STD_LOGIC;
		 pmadwidth	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 polinv_en	:	IN  STD_LOGIC;
		 prbs_en	:	IN  STD_LOGIC;
		 pudi	:	IN  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 pudr	:	IN  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 r8b10b_dec_ibm_en	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rauto_speed_ena	:	IN  STD_LOGIC;
		 rbitloc_rev_en	:	IN  STD_LOGIC;
		 rbyte_rev_en	:	IN  STD_LOGIC;
		 rencdt_rising	:	IN  STD_LOGIC;
		 resync_badcg_en	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 rforce_sig_det_pcs	:	IN  STD_LOGIC;
		 rfreq_sel	:	IN  STD_LOGIC;
		 rindv_rx	:	IN  STD_LOGIC;
		 rkchar	:	IN  STD_LOGIC;
		 rlv	:	OUT  STD_LOGIC;
		 rlv_en	:	IN  STD_LOGIC;
		 rlv_lt	:	OUT  STD_LOGIC;
		 rosbased	:	IN  STD_LOGIC;
		 rosnumber	:	IN  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 rpolinv_en	:	IN  STD_LOGIC;
		 rrxpcsbypass_en	:	IN  STD_LOGIC;
		 rst	:	IN  STD_LOGIC;
		 rst1	:	OUT  STD_LOGIC;
		 scan_mode	:	IN  STD_LOGIC;
		 signal_detect	:	IN  STD_LOGIC;
		 signal_detect_rcvdclk	:	OUT  STD_LOGIC;
		 sudi	:	OUT  STD_LOGIC_VECTOR (31 DOWNTO 0);
		 sudi_pre	:	OUT  STD_LOGIC_VECTOR (13 DOWNTO 0);
		 sync_sm_dis	:	IN  STD_LOGIC;
		 sync_status	:	OUT  STD_LOGIC;
		 testbus	:	OUT  STD_LOGIC_VECTOR (9 DOWNTO 0);
		 wa_6g_en	:	IN  STD_LOGIC;
		 wa_boundary	:	OUT  STD_LOGIC_VECTOR (4 DOWNTO 0)
	 ); 
 END stratixiv_hssi_rx_digi_wordalign;

 ARCHITECTURE RTL OF stratixiv_hssi_rx_digi_wordalign IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 n1i00OO49	:	STD_LOGIC := '0';
	 SIGNAL	 n1i00OO50	:	STD_LOGIC := '0';
	 SIGNAL	 n1i0lOi47	:	STD_LOGIC := '0';
	 SIGNAL	 n1i0lOi48	:	STD_LOGIC := '0';
	 SIGNAL	 n1i0O0i43	:	STD_LOGIC := '0';
	 SIGNAL	 n1i0O0i44	:	STD_LOGIC := '0';
	 SIGNAL  wire_n1i0O0i44_w_lg_q340w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n1i0O1l45	:	STD_LOGIC := '0';
	 SIGNAL	 n1i0O1l46	:	STD_LOGIC := '0';
	 SIGNAL	 n1i0Oil41	:	STD_LOGIC := '0';
	 SIGNAL	 n1i0Oil42	:	STD_LOGIC := '0';
	 SIGNAL	 n1i0Oli39	:	STD_LOGIC := '0';
	 SIGNAL	 n1i0Oli40	:	STD_LOGIC := '0';
	 SIGNAL  wire_n1i0Oli40_w_lg_q324w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n1i0OlO37	:	STD_LOGIC := '0';
	 SIGNAL	 n1i0OlO38	:	STD_LOGIC := '0';
	 SIGNAL	 n1i0OOl35	:	STD_LOGIC := '0';
	 SIGNAL	 n1i0OOl36	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii00O19	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii00O20	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii0ii17	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii0ii18	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii0ll15	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii0ll16	:	STD_LOGIC := '0';
	 SIGNAL  wire_n1ii0ll16_w_lg_w_lg_q179w180w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ii0ll16_w_lg_q179w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n1ii0OO13	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii0OO14	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii10l33	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii10l34	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii1ii31	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii1ii32	:	STD_LOGIC := '0';
	 SIGNAL  wire_n1ii1ii32_w_lg_w_lg_q274w275w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ii1ii32_w_lg_q274w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n1ii1il29	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii1il30	:	STD_LOGIC := '0';
	 SIGNAL  wire_n1ii1il30_w_lg_w_lg_q270w271w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ii1il30_w_lg_q270w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n1ii1iO27	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii1iO28	:	STD_LOGIC := '0';
	 SIGNAL  wire_n1ii1iO28_w_lg_w_lg_q258w259w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ii1iO28_w_lg_q258w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n1ii1li25	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii1li26	:	STD_LOGIC := '0';
	 SIGNAL  wire_n1ii1li26_w_lg_w_lg_q243w244w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ii1li26_w_lg_q243w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n1ii1ll23	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii1ll24	:	STD_LOGIC := '0';
	 SIGNAL  wire_n1ii1ll24_w_lg_w_lg_q240w241w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1ii1ll24_w_lg_q240w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n1ii1Oi21	:	STD_LOGIC := '0';
	 SIGNAL	 n1ii1Oi22	:	STD_LOGIC := '0';
	 SIGNAL	 n1iii0i11	:	STD_LOGIC := '0';
	 SIGNAL	 n1iii0i12	:	STD_LOGIC := '0';
	 SIGNAL	 n1iii0O10	:	STD_LOGIC := '0';
	 SIGNAL	 n1iii0O9	:	STD_LOGIC := '0';
	 SIGNAL	 n1iiiil7	:	STD_LOGIC := '0';
	 SIGNAL	 n1iiiil8	:	STD_LOGIC := '0';
	 SIGNAL	 n1iiiOl5	:	STD_LOGIC := '0';
	 SIGNAL	 n1iiiOl6	:	STD_LOGIC := '0';
	 SIGNAL	 n1iil0O1	:	STD_LOGIC := '0';
	 SIGNAL	 n1iil0O2	:	STD_LOGIC := '0';
	 SIGNAL	 n1iil1i3	:	STD_LOGIC := '0';
	 SIGNAL	 n1iil1i4	:	STD_LOGIC := '0';
	 SIGNAL  wire_n1iil1i4_w_lg_q7w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	ni0li	:	STD_LOGIC := '0';
	 SIGNAL	ni0Ol	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni0Oi_CLRN	:	STD_LOGIC;
	 SIGNAL	n01000i	:	STD_LOGIC := '0';
	 SIGNAL	n01000l	:	STD_LOGIC := '0';
	 SIGNAL	n01000O	:	STD_LOGIC := '0';
	 SIGNAL	n01001i	:	STD_LOGIC := '0';
	 SIGNAL	n01001l	:	STD_LOGIC := '0';
	 SIGNAL	n01001O	:	STD_LOGIC := '0';
	 SIGNAL	n0100ii	:	STD_LOGIC := '0';
	 SIGNAL	n0100il	:	STD_LOGIC := '0';
	 SIGNAL	n0101il	:	STD_LOGIC := '0';
	 SIGNAL	n0101iO	:	STD_LOGIC := '0';
	 SIGNAL	n0101li	:	STD_LOGIC := '0';
	 SIGNAL	n0101ll	:	STD_LOGIC := '0';
	 SIGNAL	n0101lO	:	STD_LOGIC := '0';
	 SIGNAL	n0101Oi	:	STD_LOGIC := '0';
	 SIGNAL	n0101Ol	:	STD_LOGIC := '0';
	 SIGNAL	n0101OO	:	STD_LOGIC := '0';
	 SIGNAL	n010Ol	:	STD_LOGIC := '0';
	 SIGNAL	n010OO	:	STD_LOGIC := '0';
	 SIGNAL	n0110i	:	STD_LOGIC := '0';
	 SIGNAL	n0110l	:	STD_LOGIC := '0';
	 SIGNAL	n0110O	:	STD_LOGIC := '0';
	 SIGNAL	n0111i	:	STD_LOGIC := '0';
	 SIGNAL	n0111l	:	STD_LOGIC := '0';
	 SIGNAL	n0111O	:	STD_LOGIC := '0';
	 SIGNAL	n011ii	:	STD_LOGIC := '0';
	 SIGNAL	n011il	:	STD_LOGIC := '0';
	 SIGNAL	n011iO	:	STD_LOGIC := '0';
	 SIGNAL	n011l0i	:	STD_LOGIC := '0';
	 SIGNAL	n011l0l	:	STD_LOGIC := '0';
	 SIGNAL	n011l0O	:	STD_LOGIC := '0';
	 SIGNAL	n011l1l	:	STD_LOGIC := '0';
	 SIGNAL	n011l1O	:	STD_LOGIC := '0';
	 SIGNAL	n011li	:	STD_LOGIC := '0';
	 SIGNAL	n011lii	:	STD_LOGIC := '0';
	 SIGNAL	n011lil	:	STD_LOGIC := '0';
	 SIGNAL	n011liO	:	STD_LOGIC := '0';
	 SIGNAL	n011ll	:	STD_LOGIC := '0';
	 SIGNAL	n011lli	:	STD_LOGIC := '0';
	 SIGNAL	n011lll	:	STD_LOGIC := '0';
	 SIGNAL	n011llO	:	STD_LOGIC := '0';
	 SIGNAL	n011lO	:	STD_LOGIC := '0';
	 SIGNAL	n011lOi	:	STD_LOGIC := '0';
	 SIGNAL	n011lOl	:	STD_LOGIC := '0';
	 SIGNAL	n011lOO	:	STD_LOGIC := '0';
	 SIGNAL	n011O0i	:	STD_LOGIC := '0';
	 SIGNAL	n011O1i	:	STD_LOGIC := '0';
	 SIGNAL	n011O1l	:	STD_LOGIC := '0';
	 SIGNAL	n011O1O	:	STD_LOGIC := '0';
	 SIGNAL	n011Oi	:	STD_LOGIC := '0';
	 SIGNAL	n01i0i	:	STD_LOGIC := '0';
	 SIGNAL	n01i0l	:	STD_LOGIC := '0';
	 SIGNAL	n01i0O	:	STD_LOGIC := '0';
	 SIGNAL	n01i1i	:	STD_LOGIC := '0';
	 SIGNAL	n01i1l	:	STD_LOGIC := '0';
	 SIGNAL	n01i1O	:	STD_LOGIC := '0';
	 SIGNAL	n01iii	:	STD_LOGIC := '0';
	 SIGNAL	n01iil	:	STD_LOGIC := '0';
	 SIGNAL	n01iiO	:	STD_LOGIC := '0';
	 SIGNAL	n01ili	:	STD_LOGIC := '0';
	 SIGNAL	n01ill	:	STD_LOGIC := '0';
	 SIGNAL	n1l00O	:	STD_LOGIC := '0';
	 SIGNAL	n1l0ii	:	STD_LOGIC := '0';
	 SIGNAL	n1l0il	:	STD_LOGIC := '0';
	 SIGNAL	n1l0iO	:	STD_LOGIC := '0';
	 SIGNAL	n1l0li	:	STD_LOGIC := '0';
	 SIGNAL	n1l0ll	:	STD_LOGIC := '0';
	 SIGNAL	n1l0lO	:	STD_LOGIC := '0';
	 SIGNAL	n1l0Oi	:	STD_LOGIC := '0';
	 SIGNAL	n1liii	:	STD_LOGIC := '0';
	 SIGNAL	n1O01i	:	STD_LOGIC := '0';
	 SIGNAL	n1O01O	:	STD_LOGIC := '0';
	 SIGNAL	n1O1ll	:	STD_LOGIC := '0';
	 SIGNAL	n1O1lO	:	STD_LOGIC := '0';
	 SIGNAL	n1O1Oi	:	STD_LOGIC := '0';
	 SIGNAL	n1O1Ol	:	STD_LOGIC := '0';
	 SIGNAL	n1O1OO	:	STD_LOGIC := '0';
	 SIGNAL	n1Oi0i	:	STD_LOGIC := '0';
	 SIGNAL	n1Oi0l	:	STD_LOGIC := '0';
	 SIGNAL	n1Oi0O	:	STD_LOGIC := '0';
	 SIGNAL	n1Oi1O	:	STD_LOGIC := '0';
	 SIGNAL	n1OilO	:	STD_LOGIC := '0';
	 SIGNAL	n1OiOi	:	STD_LOGIC := '0';
	 SIGNAL	n1OiOl	:	STD_LOGIC := '0';
	 SIGNAL	n1OiOO	:	STD_LOGIC := '0';
	 SIGNAL	n1Ol00i	:	STD_LOGIC := '0';
	 SIGNAL	n1Ol00l	:	STD_LOGIC := '0';
	 SIGNAL	n1Ol00O	:	STD_LOGIC := '0';
	 SIGNAL	n1Ol01i	:	STD_LOGIC := '0';
	 SIGNAL	n1Ol01l	:	STD_LOGIC := '0';
	 SIGNAL	n1Ol01O	:	STD_LOGIC := '0';
	 SIGNAL	n1Ol0ii	:	STD_LOGIC := '0';
	 SIGNAL	n1Ol0il	:	STD_LOGIC := '0';
	 SIGNAL	n1Ol1Ol	:	STD_LOGIC := '0';
	 SIGNAL	n1Ol1OO	:	STD_LOGIC := '0';
	 SIGNAL	n1Oli0i	:	STD_LOGIC := '0';
	 SIGNAL	n1OO00i	:	STD_LOGIC := '0';
	 SIGNAL	n1OO01i	:	STD_LOGIC := '0';
	 SIGNAL	n1OO01l	:	STD_LOGIC := '0';
	 SIGNAL	n1OO0iO	:	STD_LOGIC := '0';
	 SIGNAL	n1OO0li	:	STD_LOGIC := '0';
	 SIGNAL	n1OO0ll	:	STD_LOGIC := '0';
	 SIGNAL	n1OO0lO	:	STD_LOGIC := '0';
	 SIGNAL	n1OO1lO	:	STD_LOGIC := '0';
	 SIGNAL	n1OO1Oi	:	STD_LOGIC := '0';
	 SIGNAL	n1OO1Ol	:	STD_LOGIC := '0';
	 SIGNAL	n1OO1OO	:	STD_LOGIC := '0';
	 SIGNAL	n1OOi0i	:	STD_LOGIC := '0';
	 SIGNAL	n1OOi1O	:	STD_LOGIC := '0';
	 SIGNAL	n1OOOl	:	STD_LOGIC := '0';
	 SIGNAL	n1OOOO	:	STD_LOGIC := '0';
	 SIGNAL	ni0iO	:	STD_LOGIC := '0';
	 SIGNAL	ni0OO	:	STD_LOGIC := '0';
	 SIGNAL	niii0i	:	STD_LOGIC := '0';
	 SIGNAL	niii0l	:	STD_LOGIC := '0';
	 SIGNAL	niii0O	:	STD_LOGIC := '0';
	 SIGNAL	niiill	:	STD_LOGIC := '0';
	 SIGNAL	nil00i	:	STD_LOGIC := '0';
	 SIGNAL	nil00l	:	STD_LOGIC := '0';
	 SIGNAL	nil00O	:	STD_LOGIC := '0';
	 SIGNAL	nil01i	:	STD_LOGIC := '0';
	 SIGNAL	nil01l	:	STD_LOGIC := '0';
	 SIGNAL	nil01O	:	STD_LOGIC := '0';
	 SIGNAL	nil0ii	:	STD_LOGIC := '0';
	 SIGNAL	nil0il	:	STD_LOGIC := '0';
	 SIGNAL	nil0iO	:	STD_LOGIC := '0';
	 SIGNAL	nil0li	:	STD_LOGIC := '0';
	 SIGNAL	nil0ll	:	STD_LOGIC := '0';
	 SIGNAL	nil0lO	:	STD_LOGIC := '0';
	 SIGNAL	nil0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nil0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nil0OO	:	STD_LOGIC := '0';
	 SIGNAL	nil1il	:	STD_LOGIC := '0';
	 SIGNAL	nil1iO	:	STD_LOGIC := '0';
	 SIGNAL	nil1li	:	STD_LOGIC := '0';
	 SIGNAL	nil1ll	:	STD_LOGIC := '0';
	 SIGNAL	nil1lO	:	STD_LOGIC := '0';
	 SIGNAL	nil1Ol	:	STD_LOGIC := '0';
	 SIGNAL	nil1OO	:	STD_LOGIC := '0';
	 SIGNAL	nili0i	:	STD_LOGIC := '0';
	 SIGNAL	nili0l	:	STD_LOGIC := '0';
	 SIGNAL	nili0O	:	STD_LOGIC := '0';
	 SIGNAL	nili1i	:	STD_LOGIC := '0';
	 SIGNAL	nili1l	:	STD_LOGIC := '0';
	 SIGNAL	nili1O	:	STD_LOGIC := '0';
	 SIGNAL	niliii	:	STD_LOGIC := '0';
	 SIGNAL	niliil	:	STD_LOGIC := '0';
	 SIGNAL	niliiO	:	STD_LOGIC := '0';
	 SIGNAL	nilili	:	STD_LOGIC := '0';
	 SIGNAL	nilill	:	STD_LOGIC := '0';
	 SIGNAL	nililO	:	STD_LOGIC := '0';
	 SIGNAL	niliOi	:	STD_LOGIC := '0';
	 SIGNAL	niliOl	:	STD_LOGIC := '0';
	 SIGNAL	niliOO	:	STD_LOGIC := '0';
	 SIGNAL	nill0i	:	STD_LOGIC := '0';
	 SIGNAL	nill0l	:	STD_LOGIC := '0';
	 SIGNAL	nill1i	:	STD_LOGIC := '0';
	 SIGNAL	nill1l	:	STD_LOGIC := '0';
	 SIGNAL	nill1O	:	STD_LOGIC := '0';
	 SIGNAL	niOlii	:	STD_LOGIC := '0';
	 SIGNAL	niOlil	:	STD_LOGIC := '0';
	 SIGNAL	niOlli	:	STD_LOGIC := '0';
	 SIGNAL	niOlll	:	STD_LOGIC := '0';
	 SIGNAL	niOllO	:	STD_LOGIC := '0';
	 SIGNAL	niOlOi	:	STD_LOGIC := '0';
	 SIGNAL	niOlOl	:	STD_LOGIC := '0';
	 SIGNAL	niOlOO	:	STD_LOGIC := '0';
	 SIGNAL	niOO0i	:	STD_LOGIC := '0';
	 SIGNAL	niOO1i	:	STD_LOGIC := '0';
	 SIGNAL	niOO1l	:	STD_LOGIC := '0';
	 SIGNAL	niOO1O	:	STD_LOGIC := '0';
	 SIGNAL	niOOOO	:	STD_LOGIC := '0';
	 SIGNAL	nl010il	:	STD_LOGIC := '0';
	 SIGNAL	nl010iO	:	STD_LOGIC := '0';
	 SIGNAL	nl010li	:	STD_LOGIC := '0';
	 SIGNAL	nl010ll	:	STD_LOGIC := '0';
	 SIGNAL	nl010lO	:	STD_LOGIC := '0';
	 SIGNAL	nl010Oi	:	STD_LOGIC := '0';
	 SIGNAL	nl010Ol	:	STD_LOGIC := '0';
	 SIGNAL	nl010OO	:	STD_LOGIC := '0';
	 SIGNAL	nl0110i	:	STD_LOGIC := '0';
	 SIGNAL	nl0110l	:	STD_LOGIC := '0';
	 SIGNAL	nl0110O	:	STD_LOGIC := '0';
	 SIGNAL	nl0111i	:	STD_LOGIC := '0';
	 SIGNAL	nl0111l	:	STD_LOGIC := '0';
	 SIGNAL	nl0111O	:	STD_LOGIC := '0';
	 SIGNAL	nl011ii	:	STD_LOGIC := '0';
	 SIGNAL	nl011il	:	STD_LOGIC := '0';
	 SIGNAL	nl011iO	:	STD_LOGIC := '0';
	 SIGNAL	nl011li	:	STD_LOGIC := '0';
	 SIGNAL	nl011ll	:	STD_LOGIC := '0';
	 SIGNAL	nl011lO	:	STD_LOGIC := '0';
	 SIGNAL	nl01i0i	:	STD_LOGIC := '0';
	 SIGNAL	nl01i0l	:	STD_LOGIC := '0';
	 SIGNAL	nl01i0O	:	STD_LOGIC := '0';
	 SIGNAL	nl01i1i	:	STD_LOGIC := '0';
	 SIGNAL	nl01i1l	:	STD_LOGIC := '0';
	 SIGNAL	nl01i1O	:	STD_LOGIC := '0';
	 SIGNAL	nl01iii	:	STD_LOGIC := '0';
	 SIGNAL	nl01iil	:	STD_LOGIC := '0';
	 SIGNAL	nl01iiO	:	STD_LOGIC := '0';
	 SIGNAL	nl01ili	:	STD_LOGIC := '0';
	 SIGNAL	nl01ill	:	STD_LOGIC := '0';
	 SIGNAL	nl01ilO	:	STD_LOGIC := '0';
	 SIGNAL	nl01iOi	:	STD_LOGIC := '0';
	 SIGNAL	nl01iOl	:	STD_LOGIC := '0';
	 SIGNAL	nl01iOO	:	STD_LOGIC := '0';
	 SIGNAL	nl01l0i	:	STD_LOGIC := '0';
	 SIGNAL	nl01l0l	:	STD_LOGIC := '0';
	 SIGNAL	nl01l0O	:	STD_LOGIC := '0';
	 SIGNAL	nl01l1i	:	STD_LOGIC := '0';
	 SIGNAL	nl01l1l	:	STD_LOGIC := '0';
	 SIGNAL	nl01l1O	:	STD_LOGIC := '0';
	 SIGNAL	nl01lii	:	STD_LOGIC := '0';
	 SIGNAL	nl01lil	:	STD_LOGIC := '0';
	 SIGNAL	nl01liO	:	STD_LOGIC := '0';
	 SIGNAL	nl01lli	:	STD_LOGIC := '0';
	 SIGNAL	nl01lll	:	STD_LOGIC := '0';
	 SIGNAL	nl01llO	:	STD_LOGIC := '0';
	 SIGNAL	nl01lOi	:	STD_LOGIC := '0';
	 SIGNAL	nl01lOl	:	STD_LOGIC := '0';
	 SIGNAL	nl01lOO	:	STD_LOGIC := '0';
	 SIGNAL	nl01O1i	:	STD_LOGIC := '0';
	 SIGNAL	nl01O1l	:	STD_LOGIC := '0';
	 SIGNAL	nl01O1O	:	STD_LOGIC := '0';
	 SIGNAL	nl100l	:	STD_LOGIC := '0';
	 SIGNAL	nl100O	:	STD_LOGIC := '0';
	 SIGNAL	nl10ii	:	STD_LOGIC := '0';
	 SIGNAL	nl10Ol	:	STD_LOGIC := '0';
	 SIGNAL	nl110i	:	STD_LOGIC := '0';
	 SIGNAL	nl110l	:	STD_LOGIC := '0';
	 SIGNAL	nl110O	:	STD_LOGIC := '0';
	 SIGNAL	nl111i	:	STD_LOGIC := '0';
	 SIGNAL	nl111l	:	STD_LOGIC := '0';
	 SIGNAL	nl111O	:	STD_LOGIC := '0';
	 SIGNAL	nl11ii	:	STD_LOGIC := '0';
	 SIGNAL	nl11il	:	STD_LOGIC := '0';
	 SIGNAL	nl11iO	:	STD_LOGIC := '0';
	 SIGNAL	nl1ill	:	STD_LOGIC := '0';
	 SIGNAL	nl1ilO	:	STD_LOGIC := '0';
	 SIGNAL	nl1l1l	:	STD_LOGIC := '0';
	 SIGNAL	nl1lii	:	STD_LOGIC := '0';
	 SIGNAL	nl1liii	:	STD_LOGIC := '0';
	 SIGNAL	nl1liil	:	STD_LOGIC := '0';
	 SIGNAL	nl1lOi	:	STD_LOGIC := '0';
	 SIGNAL	nl1Oiil	:	STD_LOGIC := '0';
	 SIGNAL	nl1OiiO	:	STD_LOGIC := '0';
	 SIGNAL	nl1Oili	:	STD_LOGIC := '0';
	 SIGNAL	nl1Oill	:	STD_LOGIC := '0';
	 SIGNAL	nl1OilO	:	STD_LOGIC := '0';
	 SIGNAL	nl1OiOi	:	STD_LOGIC := '0';
	 SIGNAL	nl1OiOl	:	STD_LOGIC := '0';
	 SIGNAL	nl1OiOO	:	STD_LOGIC := '0';
	 SIGNAL	nl1Ol0i	:	STD_LOGIC := '0';
	 SIGNAL	nl1Ol0l	:	STD_LOGIC := '0';
	 SIGNAL	nl1Ol0O	:	STD_LOGIC := '0';
	 SIGNAL	nl1Ol1i	:	STD_LOGIC := '0';
	 SIGNAL	nl1Ol1l	:	STD_LOGIC := '0';
	 SIGNAL	nl1Ol1O	:	STD_LOGIC := '0';
	 SIGNAL	nl1Olii	:	STD_LOGIC := '0';
	 SIGNAL	nl1Olil	:	STD_LOGIC := '0';
	 SIGNAL	nl1OliO	:	STD_LOGIC := '0';
	 SIGNAL	nl1Olli	:	STD_LOGIC := '0';
	 SIGNAL	nl1Olll	:	STD_LOGIC := '0';
	 SIGNAL	nl1OllO	:	STD_LOGIC := '0';
	 SIGNAL	nl1OlOi	:	STD_LOGIC := '0';
	 SIGNAL	nl1OlOl	:	STD_LOGIC := '0';
	 SIGNAL	nl1OlOO	:	STD_LOGIC := '0';
	 SIGNAL	nl1OO0i	:	STD_LOGIC := '0';
	 SIGNAL	nl1OO0l	:	STD_LOGIC := '0';
	 SIGNAL	nl1OO0O	:	STD_LOGIC := '0';
	 SIGNAL	nl1OO1i	:	STD_LOGIC := '0';
	 SIGNAL	nl1OO1l	:	STD_LOGIC := '0';
	 SIGNAL	nl1OO1O	:	STD_LOGIC := '0';
	 SIGNAL	nl1OOii	:	STD_LOGIC := '0';
	 SIGNAL	nl1OOil	:	STD_LOGIC := '0';
	 SIGNAL	nl1OOiO	:	STD_LOGIC := '0';
	 SIGNAL	nl1OOli	:	STD_LOGIC := '0';
	 SIGNAL	nl1OOll	:	STD_LOGIC := '0';
	 SIGNAL	nl1OOlO	:	STD_LOGIC := '0';
	 SIGNAL	nl1OOOi	:	STD_LOGIC := '0';
	 SIGNAL	nl1OOOl	:	STD_LOGIC := '0';
	 SIGNAL	nl1OOOO	:	STD_LOGIC := '0';
	 SIGNAL	nliiOl	:	STD_LOGIC := '0';
	 SIGNAL	nliiOO	:	STD_LOGIC := '0';
	 SIGNAL	nlil0i	:	STD_LOGIC := '0';
	 SIGNAL	nlil0l	:	STD_LOGIC := '0';
	 SIGNAL	nlil0O	:	STD_LOGIC := '0';
	 SIGNAL	nlil1i	:	STD_LOGIC := '0';
	 SIGNAL	nlil1l	:	STD_LOGIC := '0';
	 SIGNAL	nlil1O	:	STD_LOGIC := '0';
	 SIGNAL	nlilii	:	STD_LOGIC := '0';
	 SIGNAL	nlilll	:	STD_LOGIC := '0';
	 SIGNAL	nlillO	:	STD_LOGIC := '0';
	 SIGNAL	nlilOi	:	STD_LOGIC := '0';
	 SIGNAL	nlilOl	:	STD_LOGIC := '0';
	 SIGNAL	nlilOO	:	STD_LOGIC := '0';
	 SIGNAL	nliO0i	:	STD_LOGIC := '0';
	 SIGNAL	nliO0l	:	STD_LOGIC := '0';
	 SIGNAL	nliO0O	:	STD_LOGIC := '0';
	 SIGNAL	nliO1i	:	STD_LOGIC := '0';
	 SIGNAL	nliO1l	:	STD_LOGIC := '0';
	 SIGNAL	nliO1O	:	STD_LOGIC := '0';
	 SIGNAL	nliOii	:	STD_LOGIC := '0';
	 SIGNAL	nliOil	:	STD_LOGIC := '0';
	 SIGNAL	nliOiO	:	STD_LOGIC := '0';
	 SIGNAL	nliOli	:	STD_LOGIC := '0';
	 SIGNAL	nliOll	:	STD_LOGIC := '0';
	 SIGNAL	nliOlO	:	STD_LOGIC := '0';
	 SIGNAL	nliOOi	:	STD_LOGIC := '0';
	 SIGNAL	nliOOl	:	STD_LOGIC := '0';
	 SIGNAL	nliOOO	:	STD_LOGIC := '0';
	 SIGNAL	nll000i	:	STD_LOGIC := '0';
	 SIGNAL	nll000l	:	STD_LOGIC := '0';
	 SIGNAL	nll000O	:	STD_LOGIC := '0';
	 SIGNAL	nll001i	:	STD_LOGIC := '0';
	 SIGNAL	nll001l	:	STD_LOGIC := '0';
	 SIGNAL	nll001O	:	STD_LOGIC := '0';
	 SIGNAL	nll00ii	:	STD_LOGIC := '0';
	 SIGNAL	nll00il	:	STD_LOGIC := '0';
	 SIGNAL	nll00iO	:	STD_LOGIC := '0';
	 SIGNAL	nll00li	:	STD_LOGIC := '0';
	 SIGNAL	nll00ll	:	STD_LOGIC := '0';
	 SIGNAL	nll00lO	:	STD_LOGIC := '0';
	 SIGNAL	nll00Oi	:	STD_LOGIC := '0';
	 SIGNAL	nll00Ol	:	STD_LOGIC := '0';
	 SIGNAL	nll00OO	:	STD_LOGIC := '0';
	 SIGNAL	nll01ll	:	STD_LOGIC := '0';
	 SIGNAL	nll01lO	:	STD_LOGIC := '0';
	 SIGNAL	nll01Oi	:	STD_LOGIC := '0';
	 SIGNAL	nll01Ol	:	STD_LOGIC := '0';
	 SIGNAL	nll01OO	:	STD_LOGIC := '0';
	 SIGNAL	nll0i0i	:	STD_LOGIC := '0';
	 SIGNAL	nll0i0l	:	STD_LOGIC := '0';
	 SIGNAL	nll0i0O	:	STD_LOGIC := '0';
	 SIGNAL	nll0i1i	:	STD_LOGIC := '0';
	 SIGNAL	nll0i1l	:	STD_LOGIC := '0';
	 SIGNAL	nll0i1O	:	STD_LOGIC := '0';
	 SIGNAL	nll0iii	:	STD_LOGIC := '0';
	 SIGNAL	nll0iil	:	STD_LOGIC := '0';
	 SIGNAL	nll0iiO	:	STD_LOGIC := '0';
	 SIGNAL	nll0ili	:	STD_LOGIC := '0';
	 SIGNAL	nll0ill	:	STD_LOGIC := '0';
	 SIGNAL	nll0ilO	:	STD_LOGIC := '0';
	 SIGNAL	nll0iOi	:	STD_LOGIC := '0';
	 SIGNAL	nll0iOl	:	STD_LOGIC := '0';
	 SIGNAL	nll0iOO	:	STD_LOGIC := '0';
	 SIGNAL	nll0l0i	:	STD_LOGIC := '0';
	 SIGNAL	nll0l0l	:	STD_LOGIC := '0';
	 SIGNAL	nll0l0O	:	STD_LOGIC := '0';
	 SIGNAL	nll0l1i	:	STD_LOGIC := '0';
	 SIGNAL	nll0l1l	:	STD_LOGIC := '0';
	 SIGNAL	nll0l1O	:	STD_LOGIC := '0';
	 SIGNAL	nll0lii	:	STD_LOGIC := '0';
	 SIGNAL	nll0lil	:	STD_LOGIC := '0';
	 SIGNAL	nll0liO	:	STD_LOGIC := '0';
	 SIGNAL	nll0lli	:	STD_LOGIC := '0';
	 SIGNAL	nll0lll	:	STD_LOGIC := '0';
	 SIGNAL	nll0llO	:	STD_LOGIC := '0';
	 SIGNAL	nll0lOi	:	STD_LOGIC := '0';
	 SIGNAL	nll0lOl	:	STD_LOGIC := '0';
	 SIGNAL	nll0lOO	:	STD_LOGIC := '0';
	 SIGNAL	nll0O0i	:	STD_LOGIC := '0';
	 SIGNAL	nll0O0l	:	STD_LOGIC := '0';
	 SIGNAL	nll0O0O	:	STD_LOGIC := '0';
	 SIGNAL	nll0O1i	:	STD_LOGIC := '0';
	 SIGNAL	nll0O1l	:	STD_LOGIC := '0';
	 SIGNAL	nll0O1O	:	STD_LOGIC := '0';
	 SIGNAL	nll0Oii	:	STD_LOGIC := '0';
	 SIGNAL	nll0Oil	:	STD_LOGIC := '0';
	 SIGNAL	nll0OiO	:	STD_LOGIC := '0';
	 SIGNAL	nll0Oli	:	STD_LOGIC := '0';
	 SIGNAL	nll0Oll	:	STD_LOGIC := '0';
	 SIGNAL	nll0OlO	:	STD_LOGIC := '0';
	 SIGNAL	nll0OOi	:	STD_LOGIC := '0';
	 SIGNAL	nll0OOl	:	STD_LOGIC := '0';
	 SIGNAL	nll0OOO	:	STD_LOGIC := '0';
	 SIGNAL	nll10i	:	STD_LOGIC := '0';
	 SIGNAL	nll11i	:	STD_LOGIC := '0';
	 SIGNAL	nll11l	:	STD_LOGIC := '0';
	 SIGNAL	nll11O	:	STD_LOGIC := '0';
	 SIGNAL	nlli00i	:	STD_LOGIC := '0';
	 SIGNAL	nlli00l	:	STD_LOGIC := '0';
	 SIGNAL	nlli00O	:	STD_LOGIC := '0';
	 SIGNAL	nlli01i	:	STD_LOGIC := '0';
	 SIGNAL	nlli01l	:	STD_LOGIC := '0';
	 SIGNAL	nlli01O	:	STD_LOGIC := '0';
	 SIGNAL	nlli0ii	:	STD_LOGIC := '0';
	 SIGNAL	nlli0il	:	STD_LOGIC := '0';
	 SIGNAL	nlli0iO	:	STD_LOGIC := '0';
	 SIGNAL	nlli0li	:	STD_LOGIC := '0';
	 SIGNAL	nlli0ll	:	STD_LOGIC := '0';
	 SIGNAL	nlli0lO	:	STD_LOGIC := '0';
	 SIGNAL	nlli0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nlli0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlli0OO	:	STD_LOGIC := '0';
	 SIGNAL	nlli10i	:	STD_LOGIC := '0';
	 SIGNAL	nlli10l	:	STD_LOGIC := '0';
	 SIGNAL	nlli10O	:	STD_LOGIC := '0';
	 SIGNAL	nlli11i	:	STD_LOGIC := '0';
	 SIGNAL	nlli11l	:	STD_LOGIC := '0';
	 SIGNAL	nlli11O	:	STD_LOGIC := '0';
	 SIGNAL	nlli1ii	:	STD_LOGIC := '0';
	 SIGNAL	nlli1il	:	STD_LOGIC := '0';
	 SIGNAL	nlli1iO	:	STD_LOGIC := '0';
	 SIGNAL	nlli1li	:	STD_LOGIC := '0';
	 SIGNAL	nlli1ll	:	STD_LOGIC := '0';
	 SIGNAL	nlli1lO	:	STD_LOGIC := '0';
	 SIGNAL	nlli1Oi	:	STD_LOGIC := '0';
	 SIGNAL	nlli1Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlli1OO	:	STD_LOGIC := '0';
	 SIGNAL	nllii0i	:	STD_LOGIC := '0';
	 SIGNAL	nllii0l	:	STD_LOGIC := '0';
	 SIGNAL	nllii1i	:	STD_LOGIC := '0';
	 SIGNAL	nllii1l	:	STD_LOGIC := '0';
	 SIGNAL	nllii1O	:	STD_LOGIC := '0';
	 SIGNAL	nllll1i	:	STD_LOGIC := '0';
	 SIGNAL	nlllOl	:	STD_LOGIC := '0';
	 SIGNAL	nlllOO	:	STD_LOGIC := '0';
	 SIGNAL	nlO	:	STD_LOGIC := '0';
	 SIGNAL	nlO000i	:	STD_LOGIC := '0';
	 SIGNAL	nlO000l	:	STD_LOGIC := '0';
	 SIGNAL	nlO000O	:	STD_LOGIC := '0';
	 SIGNAL	nlO001i	:	STD_LOGIC := '0';
	 SIGNAL	nlO001l	:	STD_LOGIC := '0';
	 SIGNAL	nlO001O	:	STD_LOGIC := '0';
	 SIGNAL	nlO00ii	:	STD_LOGIC := '0';
	 SIGNAL	nlO00il	:	STD_LOGIC := '0';
	 SIGNAL	nlO00iO	:	STD_LOGIC := '0';
	 SIGNAL	nlO00li	:	STD_LOGIC := '0';
	 SIGNAL	nlO00ll	:	STD_LOGIC := '0';
	 SIGNAL	nlO00lO	:	STD_LOGIC := '0';
	 SIGNAL	nlO00Oi	:	STD_LOGIC := '0';
	 SIGNAL	nlO00Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlO00OO	:	STD_LOGIC := '0';
	 SIGNAL	nlO010i	:	STD_LOGIC := '0';
	 SIGNAL	nlO010l	:	STD_LOGIC := '0';
	 SIGNAL	nlO011i	:	STD_LOGIC := '0';
	 SIGNAL	nlO011l	:	STD_LOGIC := '0';
	 SIGNAL	nlO011O	:	STD_LOGIC := '0';
	 SIGNAL	nlO01ii	:	STD_LOGIC := '0';
	 SIGNAL	nlO01il	:	STD_LOGIC := '0';
	 SIGNAL	nlO01iO	:	STD_LOGIC := '0';
	 SIGNAL	nlO01li	:	STD_LOGIC := '0';
	 SIGNAL	nlO01ll	:	STD_LOGIC := '0';
	 SIGNAL	nlO01lO	:	STD_LOGIC := '0';
	 SIGNAL	nlO01Oi	:	STD_LOGIC := '0';
	 SIGNAL	nlO01Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlO01OO	:	STD_LOGIC := '0';
	 SIGNAL	nlO0i0i	:	STD_LOGIC := '0';
	 SIGNAL	nlO0i0l	:	STD_LOGIC := '0';
	 SIGNAL	nlO0i0O	:	STD_LOGIC := '0';
	 SIGNAL	nlO0i1i	:	STD_LOGIC := '0';
	 SIGNAL	nlO0i1l	:	STD_LOGIC := '0';
	 SIGNAL	nlO0i1O	:	STD_LOGIC := '0';
	 SIGNAL	nlO0iii	:	STD_LOGIC := '0';
	 SIGNAL	nlO0iil	:	STD_LOGIC := '0';
	 SIGNAL	nlO0iiO	:	STD_LOGIC := '0';
	 SIGNAL	nlO0ili	:	STD_LOGIC := '0';
	 SIGNAL	nlO0ill	:	STD_LOGIC := '0';
	 SIGNAL	nlO0ilO	:	STD_LOGIC := '0';
	 SIGNAL	nlO0l1i	:	STD_LOGIC := '0';
	 SIGNAL	nlO0l1l	:	STD_LOGIC := '0';
	 SIGNAL	nlO0l1O	:	STD_LOGIC := '0';
	 SIGNAL	nlOi0ll	:	STD_LOGIC := '0';
	 SIGNAL	nlOi0lO	:	STD_LOGIC := '0';
	 SIGNAL	nlOi0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nlOi0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nlOi0OO	:	STD_LOGIC := '0';
	 SIGNAL	nlOii0i	:	STD_LOGIC := '0';
	 SIGNAL	nlOii0l	:	STD_LOGIC := '0';
	 SIGNAL	nlOii0O	:	STD_LOGIC := '0';
	 SIGNAL	nlOii1i	:	STD_LOGIC := '0';
	 SIGNAL	nlOii1l	:	STD_LOGIC := '0';
	 SIGNAL	nlOii1O	:	STD_LOGIC := '0';
	 SIGNAL	nlOiiii	:	STD_LOGIC := '0';
	 SIGNAL	nlOiiil	:	STD_LOGIC := '0';
	 SIGNAL	nlOiiiO	:	STD_LOGIC := '0';
	 SIGNAL	nlOiili	:	STD_LOGIC := '0';
	 SIGNAL	nlOiill	:	STD_LOGIC := '0';
	 SIGNAL	nlOiilO	:	STD_LOGIC := '0';
	 SIGNAL	nlOilOl	:	STD_LOGIC := '0';
	 SIGNAL	nlOilOO	:	STD_LOGIC := '0';
	 SIGNAL	nlOiO0i	:	STD_LOGIC := '0';
	 SIGNAL	nlOiO0l	:	STD_LOGIC := '0';
	 SIGNAL	nlOiO1i	:	STD_LOGIC := '0';
	 SIGNAL	nlOiO1l	:	STD_LOGIC := '0';
	 SIGNAL	nlOiO1O	:	STD_LOGIC := '0';
	 SIGNAL	nO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nl_w16422w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_w16418w16419w16420w16421w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w16418w16419w16420w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w16418w16419w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w16418w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_w16414w16415w16416w16417w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w16414w16415w16416w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w16414w16415w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_w2928w2929w2930w2931w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w16414w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w2928w2929w2930w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_w16410w16411w16412w16413w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w2928w2929w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w16410w16411w16412w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w2928w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w16410w16411w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_w_lg_nl1lOi2612w2925w2926w2927w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w16410w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_nlil0l2177w2182w2187w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_nlilii2175w2180w2185w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_nlli1Ol14429w14434w14439w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_nl1lOi2612w2925w2926w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_nll0OOl16010w16408w16409w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlil0l2177w2182w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlilii2175w2180w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlli01O14427w14432w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlli1Ol14429w14434w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlOiill322w325w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nl1lOi2612w2925w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nll0OOl16010w16408w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_niii0i1208w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nl1ill342w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nl1ill389w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nl1ill397w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nl1ill381w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nl1ill373w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nl1ill365w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nl1ill357w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nl1ill327w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nl1liil17114w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nl1lOi2945w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlil0l2177w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlilii2175w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nll0OOl16448w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli01O14427w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli1Ol14429w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlO0l1l232w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOi0lO395w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOi0Ol387w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOii0l363w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOii1i379w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOii1O371w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOiiii355w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOiiiO337w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOiill322w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_w_lg_nlilii2087w2094w2101w2102w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w14161w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_nlilii2087w2094w2095w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14154w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlilii2087w2088w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlli01O14146w14147w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_n0101il16151w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_n010Ol2709w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_n011l1l16150w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_n011l1O16156w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_n1OiOi2540w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_n1OOOl2708w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_n1OOOO2714w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_niii0i1195w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_niii0l3438w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_niiill3373w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nl100l905w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nl1ill312w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nl1l1l1933w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nl1liil17102w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nl1lOi2612w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nliiOl2604w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nliiOO2596w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlil0i2588w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlil0l2618w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlil0O2616w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlil1i2594w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlil1l2592w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlil1O2590w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlilii2911w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nll01ll7899w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nll01lO4501w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nll0OOl16010w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nll0OOO15999w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli00l4491w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli01i16015w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli01l16013w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli01O16384w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli0lO15746w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli0OO4494w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli10i15955w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli10l15944w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli10O15942w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli11i15988w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli11l15977w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli11O15966w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli1ii15940w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli1il15938w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli1iO15936w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli1li15934w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli1ll15932w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli1lO15930w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli1Oi15928w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli1Ol16019w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli1OO16017w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nllii0i4486w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nllii1O4488w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlO00il4415w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlO00iO4413w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlO00li4411w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlO00ll4409w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlO00lO4407w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlO00Oi4405w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlO00Ol4403w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlO00OO4401w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlO010l3809w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlO0i1i4400w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlO0l1l246w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOi0ll394w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOi0Oi386w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOi0OO378w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOii0i362w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOii0O354w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOii1l370w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOiiil336w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlOiili321w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_nlilii2087w2094w2101w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlilii2087w2094w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_w_lg_nlli01O14146w14153w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlilii2087w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nlli01O14146w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nl10il	:	STD_LOGIC := '0';
	 SIGNAL	nl10li	:	STD_LOGIC := '0';
	 SIGNAL	nl10ll	:	STD_LOGIC := '0';
	 SIGNAL	nl10Oi	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl10lO_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nl10lO_w_lg_nl10il1929w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl10lO_w_lg_nl10li1927w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl10lO_w_lg_nl10ll1925w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl10lO_w_lg_nl10Oi1924w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nl1lil	:	STD_LOGIC := '0';
	 SIGNAL	nl1liO	:	STD_LOGIC := '0';
	 SIGNAL	nl1lli	:	STD_LOGIC := '0';
	 SIGNAL	nl1llO	:	STD_LOGIC := '0';
	 SIGNAL	nlilil	:	STD_LOGIC := '0';
	 SIGNAL	nliliO	:	STD_LOGIC := '0';
	 SIGNAL	nlilli	:	STD_LOGIC := '0';
	 SIGNAL	nll10l	:	STD_LOGIC := '0';
	 SIGNAL	nll1ii	:	STD_LOGIC := '0';
	 SIGNAL	wire_nll10O_PRN	:	STD_LOGIC;
	 SIGNAL	wire_nll10O_ENA	:	STD_LOGIC;
	 SIGNAL	n1O01l	:	STD_LOGIC := '0';
	 SIGNAL	n1OO01O	:	STD_LOGIC := '0';
	 SIGNAL	nil1Oi	:	STD_LOGIC := '0';
	 SIGNAL	nl0100i	:	STD_LOGIC := '0';
	 SIGNAL	nl0100l	:	STD_LOGIC := '0';
	 SIGNAL	nl0100O	:	STD_LOGIC := '0';
	 SIGNAL	nl0101i	:	STD_LOGIC := '0';
	 SIGNAL	nl0101l	:	STD_LOGIC := '0';
	 SIGNAL	nl0101O	:	STD_LOGIC := '0';
	 SIGNAL	nl010ii	:	STD_LOGIC := '0';
	 SIGNAL	nl011Oi	:	STD_LOGIC := '0';
	 SIGNAL	nl011Ol	:	STD_LOGIC := '0';
	 SIGNAL	nl011OO	:	STD_LOGIC := '0';
	 SIGNAL	nl1iOi	:	STD_LOGIC := '0';
	 SIGNAL	nl1iOl	:	STD_LOGIC := '0';
	 SIGNAL	nl1iOO	:	STD_LOGIC := '0';
	 SIGNAL	nl1l1i	:	STD_LOGIC := '0';
	 SIGNAL	nll01li	:	STD_LOGIC := '0';
	 SIGNAL	nll1il	:	STD_LOGIC := '0';
	 SIGNAL	nlli0l	:	STD_LOGIC := '0';
	 SIGNAL	nlli0O	:	STD_LOGIC := '0';
	 SIGNAL	nlliii	:	STD_LOGIC := '0';
	 SIGNAL	nllO1l	:	STD_LOGIC := '0';
	 SIGNAL	nlO010O	:	STD_LOGIC := '0';
	 SIGNAL	wire_nllO1i_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nllO1i_w_lg_nil1Oi3372w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO1i_w_lg_nll01li7901w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0100i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0100iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0100l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0100li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0100ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0100lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0100O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0100Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0100Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0100OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0101i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0101ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0101l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0101O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0110il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0110il_w_lg_dataout15757w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0110iO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0110iO_w_lg_dataout16493w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0110li_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0110li_w_lg_dataout16491w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0110ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0110lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0110lO_w_lg_dataout16488w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0110Oi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0110Oi_w_lg_dataout16486w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0110Ol_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0110Ol_w_lg_dataout16484w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0110OO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0110OO_w_lg_dataout16482w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n011i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011i1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n011i1i_w_lg_dataout16480w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n011i1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n011i1l_w_lg_w_lg_w_lg_w16485w16487w16489w16490w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n011i1l_w_lg_w_lg_w16485w16487w16489w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n011i1l_w_lg_w16485w16487w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n011i1l_w16485w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n011i1l_w_lg_w_lg_w_lg_dataout16479w16481w16483w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n011i1l_w_lg_w_lg_dataout16479w16481w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n011i1l_w_lg_dataout16479w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n011i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iliii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1iliii_w_lg_w_lg_dataout17118w17148w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1iliii_w_lg_dataout17118w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l11lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1l11lO_w_lg_dataout16770w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1l11lO_w_lg_dataout16758w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1l1Ol_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1l1Ol_w_lg_dataout173w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1li1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liO0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1liO0O_w_lg_dataout4506w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lllii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1lllii_w_lg_w_lg_dataout16774w16804w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1lllii_w_lg_dataout16774w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1llOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1llOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O00i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1O00i_w_lg_dataout2967w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1O00l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1O00l_w_lg_dataout2965w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1O00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0ii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1O0ii_w_lg_dataout2962w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1O0il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1O0il_w_lg_dataout2960w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1O0iO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1O0iO_w_lg_dataout2958w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1O0li_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1O0li_w_lg_dataout2956w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1O0ll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1O0ll_w_lg_w2963w2964w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O0ll_w2963w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O0ll_w_lg_w_lg_w_lg_w_lg_dataout2955w2957w2959w2961w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O0ll_w_lg_w_lg_w_lg_dataout2955w2957w2959w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O0ll_w_lg_w_lg_dataout2955w2957w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n1O0ll_w_lg_dataout2955w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1O10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O10lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol10O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1Ol10O_w_lg_dataout4507w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n1Oli0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oli0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oli1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oli1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oli1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ollil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOi1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOOi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1OOOi_w_lg_dataout2538w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0lO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0lO_w_lg_dataout2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiO0i_w_lg_dataout2058w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niiO0l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiO0l_w_lg_dataout2062w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niiO0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiO0O_w_lg_dataout2066w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niiO1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiO1i_w_lg_dataout2047w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niiO1l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiO1l_w_lg_dataout2050w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niiO1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiO1O_w_lg_dataout2054w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiOii_w_lg_dataout2070w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niiOil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiOil_w_lg_dataout2074w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niiOiO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiOiO_w_lg_dataout2078w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOli_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niiOli_w_lg_dataout2082w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOl0i_w_lg_w_lg_dataout1313w3182w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_w_lg_dataout1313w3202w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_w_lg_dataout1313w3199w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_w_lg_dataout1313w3221w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_w_lg_dataout1313w3216w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_w_lg_dataout1313w3018w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_dataout3205w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_dataout3224w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_dataout3179w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_dataout2997w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_dataout3011w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_dataout3227w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_dataout3004w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_dataout3029w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_dataout1320w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_dataout2981w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_dataout3017w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_dataout1313w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_w_lg_dataout3179w3183w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0i_w_lg_w_lg_dataout3017w3019w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niOl0l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_niOl0l_w_lg_w_lg_dataout3064w3066w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_w_lg_dataout1312w3091w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_dataout3203w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_dataout3200w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_dataout3222w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_dataout3217w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_dataout3206w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_dataout3225w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_dataout3012w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_dataout3228w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_dataout3005w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_dataout3030w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_dataout1321w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_dataout2982w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_dataout3064w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_dataout1312w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl0l_w_lg_dataout3061w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_niOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0000i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0000l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0000O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0001i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0001O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl000i_w_lg_dataout421w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl000ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl001i_w_lg_dataout415w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl001ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00ii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl00ii_w_lg_dataout428w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl00iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00li_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl00li_w_lg_dataout436w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00Oi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl00Oi_w_lg_dataout1914w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl010l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl010l_w_lg_dataout401w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl011O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl011O_w_lg_dataout1922w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl011O_w_lg_dataout446w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01ii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl01ii_w_lg_dataout403w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01li_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl01li_w_lg_dataout406w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01Oi_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl01Oi_w_lg_dataout410w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nl01Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0il0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0il0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0il0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0il1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0il1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0il1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0illi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0illO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1li0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1li0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1li0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1li1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1li1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1li1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oi0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oi0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oi0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oi1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllliil_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllliil_w_lg_dataout283w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nllliiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO00i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllO00i_w_lg_w_lg_w_lg_dataout4064w4065w4066w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO00i_w_lg_w_lg_dataout4064w4065w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO00i_w_lg_dataout4064w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nllO00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO00O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllO00O_w_lg_w_lg_w_lg_dataout3960w3961w3962w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO00O_w_lg_w_lg_dataout3960w3961w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO00O_w_lg_dataout3960w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nllO01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0ii_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllO0ii_w_lg_w_lg_w_lg_dataout3945w3946w3947w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO0ii_w_lg_w_lg_dataout3945w3946w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO0ii_w_lg_dataout3945w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO0ii_w_lg_dataout4069w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nllO0il_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllO0il_w_lg_w_lg_dataout3407w4078w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllO0il_w_lg_dataout3407w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO100i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO100l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO101i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO101l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO101O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOll0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nlOll0O_w_lg_w_lg_dataout1212w3256w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOll0O_w_lg_dataout1212w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_nlOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n011ili_a	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_n011ili_b	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_gnd	:	STD_LOGIC;
	 SIGNAL  wire_n011ili_o	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_n1li0i_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1li0i_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1li0i_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1li1O_a	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1li1O_b	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1li1O_o	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1O0lO_a	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n1O0lO_b	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n1O0lO_o	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n1Ol0Ol_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1Ol0Ol_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1Ol0Ol_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1Ol0OO_a	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n1Ol0OO_b	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_n1Ol0OO_o	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nl0iiOl_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0iiOl_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0iiOl_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl1iil_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl1iil_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl1iil_o	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nllO1lO_a	:	STD_LOGIC_VECTOR (10 DOWNTO 0);
	 SIGNAL  wire_nllO1lO_b	:	STD_LOGIC_VECTOR (10 DOWNTO 0);
	 SIGNAL  wire_nllO1lO_o	:	STD_LOGIC_VECTOR (10 DOWNTO 0);
	 SIGNAL  wire_nllO1Oi_a	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nllO1Oi_b	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nllO1Oi_o	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nllO1Ol_a	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nllO1Ol_b	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nllO1Ol_o	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nllO1OO_a	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nllO1OO_b	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nllO1OO_o	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nlO0l0i_a	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO0l0i_b	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO0l0i_o	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oill_a	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n1Oill_b	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_n1Oill_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OOi1l_a	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_n1OOi1l_b	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_n1OOi1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0iiOO_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0iiOO_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_vcc	:	STD_LOGIC;
	 SIGNAL  wire_nl0iiOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0illl_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0illl_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0illl_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0iOii_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0iOii_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0iOii_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0l11O_a	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0l11O_b	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0l11O_o	:	STD_LOGIC;
	 SIGNAL  wire_nllOO1l_a	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nllOO1l_b	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nllOO1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO10Ol_a	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nlO10Ol_b	:	STD_LOGIC_VECTOR (9 DOWNTO 0);
	 SIGNAL  wire_nlO10Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_niOO0l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niOO0l_o	:	STD_LOGIC;
	 SIGNAL  wire_niOO0l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niOO0O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niOO0O_o	:	STD_LOGIC;
	 SIGNAL  wire_niOO0O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niOOii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niOOii_o	:	STD_LOGIC;
	 SIGNAL  wire_niOOii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niOOil_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niOOil_o	:	STD_LOGIC;
	 SIGNAL  wire_niOOil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niOOiO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niOOiO_o	:	STD_LOGIC;
	 SIGNAL  wire_niOOiO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niOOli_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niOOli_o	:	STD_LOGIC;
	 SIGNAL  wire_niOOli_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niOOll_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niOOll_o	:	STD_LOGIC;
	 SIGNAL  wire_niOOll_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niOOlO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niOOlO_o	:	STD_LOGIC;
	 SIGNAL  wire_niOOlO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niOOOi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niOOOi_o	:	STD_LOGIC;
	 SIGNAL  wire_niOOOi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_niOOOl_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_niOOOl_o	:	STD_LOGIC;
	 SIGNAL  wire_niOOOl_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl00l0i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00l0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00l0i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00l0l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00l0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00l0l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00l0O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00l0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00l0O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00lii_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00lii_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00lii_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00lil_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00lil_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00lil_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00liO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00liO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00liO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00lli_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00lli_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00lli_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00lll_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00lll_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00lll_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00llO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00llO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00llO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00lOi_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00lOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00lOi_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00lOl_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00lOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00lOl_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00lOO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00lOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00lOO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00O0i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00O0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00O0i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00O0l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00O0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00O0l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00O0O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00O0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00O0O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00O1i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00O1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00O1i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00O1l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00O1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00O1l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00O1O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00O1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00O1O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00Oil_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00Oil_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00Oil_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00OiO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00OiO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00OiO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00Oli_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00Oli_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00Oli_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00Oll_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00Oll_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00Oll_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00OlO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00OlO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00OlO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00OOi_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00OOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00OOi_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00OOl_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00OOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00OOl_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl00OOO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl00OOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl00OOO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0i0Ol_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl0i0Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0i0Ol_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl0i0OO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl0i0OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0i0OO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl0i10i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl0i10i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0i10i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0i10l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl0i10l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0i10l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0i10O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl0i10O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0i10O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0i11i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl0i11i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0i11i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0i11l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl0i11l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0i11l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0i11O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl0i11O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0i11O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0i1ii_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl0i1ii_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0i1ii_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0i1il_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl0i1il_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0i1il_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0i1iO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl0i1iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0i1iO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0i1li_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl0i1li_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0i1li_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0i1ll_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl0i1ll_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0i1ll_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0i1lO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl0i1lO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0i1lO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl0ii1i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl0ii1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0ii1i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl0ii1l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl0ii1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0ii1l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl0ii1O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl0ii1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0ii1O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl0l0OO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0l0OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0l0OO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0li1i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0li1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0li1i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0OiOl_w_lg_o13575w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OiOl_w_lg_o5684w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OiOl_w_lg_o5615w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OiOl_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0OiOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0OiOl_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0OiOO_w_lg_o5429w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OiOO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0OiOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0OiOO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0Ol0i_w_lg_o5439w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Ol0i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0Ol0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0Ol0i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0Ol0l_w_lg_o5445w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Ol0l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0Ol0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0Ol0l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0Ol0O_w_lg_o5452w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Ol0O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0Ol0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0Ol0O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0Ol1i_w_lg_o5431w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Ol1i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0Ol1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0Ol1i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0Ol1l_w_lg_o5618w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Ol1l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0Ol1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0Ol1l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0Ol1O_w_lg_o5434w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Ol1O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0Ol1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0Ol1O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0Olii_w_lg_o5460w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Olii_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0Olii_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0Olii_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0Olil_w_lg_o5469w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Olil_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0Olil_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0Olil_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0OliO_w_lg_o5479w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OliO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0OliO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0OliO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0Olli_w_lg_o5490w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Olli_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0Olli_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0Olli_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0Olll_w_lg_o5502w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Olll_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0Olll_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0Olll_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0OllO_w_lg_o5515w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OllO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0OllO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0OllO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0OlOi_w_lg_o5529w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OlOi_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0OlOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0OlOi_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0OlOl_w_lg_o5544w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OlOl_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0OlOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0OlOl_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0OlOO_w_lg_o5560w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OlOO_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0OlOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0OlOO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0OO1i_w_lg_o5577w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OO1i_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0OO1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0OO1i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0OO1l_w_lg_o5595w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OO1l_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0OO1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0OO1l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl0OO1O_w_lg_o13557w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OO1O_data	:	STD_LOGIC_VECTOR (7 DOWNTO 0);
	 SIGNAL  wire_nl0OO1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl0OO1O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nl100i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl100i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl100i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl101i_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl101i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl101i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl101l_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl101l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl101l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl101O_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl101O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl101O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl11li_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl11li_o	:	STD_LOGIC;
	 SIGNAL  wire_nl11li_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl11ll_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl11ll_o	:	STD_LOGIC;
	 SIGNAL  wire_nl11ll_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl11lO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl11lO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl11lO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl11Oi_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl11Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_nl11Oi_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl11Ol_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl11Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_nl11Ol_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl11OO_data	:	STD_LOGIC_VECTOR (31 DOWNTO 0);
	 SIGNAL  wire_nl11OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl11OO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_nl1liiO_w_lg_o16992w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liiO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1liiO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1liiO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lili_w_lg_w_lg_o16990w17009w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lili_w_lg_w_lg_o16990w16991w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lili_w_lg_o16993w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lili_w_lg_o16990w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lili_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lili_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lili_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lill_w_lg_w_lg_o16982w17179w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lill_w_lg_w_lg_o16982w17174w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lill_w_lg_w_lg_o16982w17167w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lill_w_lg_w_lg_o16982w17164w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lill_w_lg_w_lg_o16982w17026w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lill_w_lg_w_lg_o16982w17021w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lill_w_lg_w_lg_o16982w17006w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lill_w_lg_w_lg_o16982w17003w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lill_w_lg_o17010w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lill_w_lg_o17029w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lill_w_lg_o17032w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lill_w_lg_o16982w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lill_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lill_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lill_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_w_lg_w_lg_o16913w17152w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_w_lg_w_lg_o16913w17112w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_w_lg_o17180w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_w_lg_o17175w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_w_lg_o17168w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_w_lg_o17165w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_w_lg_o17027w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_w_lg_o17022w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_w_lg_o17007w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_w_lg_o17004w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_w_lg_o17011w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_w_lg_o17030w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_w_lg_o17033w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_w_lg_o16979w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_w_lg_o16913w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lilO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lilO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1liOi_w_lg_w_lg_o16843w16914w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOi_w_lg_w_lg_o16843w16844w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOi_w_lg_w_lg_o16843w16907w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOi_w_lg_w_lg_o16843w16955w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOi_w_lg_o16980w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOi_w_lg_o16847w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOi_w_lg_o16925w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOi_w_lg_o16931w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOi_w_lg_o16843w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOi_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1liOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1liOi_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_w_lg_o16842w16915w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_w_lg_o16842w16908w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_w_lg_o16842w16987w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_w_lg_w_lg_o16842w16910w16911w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_w16916w16922w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w16941w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_w_lg_o16928w16929w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_o16956w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_o16981w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_o16848w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_o16926w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_o16932w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_o16988w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_o16867w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_o16842w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_w_lg_w_lg_o16842w16908w16909w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_w_lg_o16926w16927w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_w_lg_o16842w16910w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_w_lg_w_lg_w_lg_o16842w16908w16909w16912w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_w_lg_w_lg_o16926w16927w16930w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w16916w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_w_lg_w_lg_w_lg_o16926w16927w16930w16933w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_w_lg_o16928w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1liOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1liOl_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1liOO_w_lg_w_lg_o16856w17040w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOO_w_lg_w_lg_o16856w16963w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOO_w_lg_o16868w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOO_w_lg_o17121w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOO_w_lg_o16856w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1liOO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1liOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1liOO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1ll0i_w_lg_o16648w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1ll0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1ll0i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1ll0l_w_lg_w_lg_o16646w16665w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0l_w_lg_w_lg_o16646w16647w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0l_w_lg_o16649w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0l_w_lg_o16646w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1ll0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1ll0l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1ll0O_w_lg_w_lg_o16638w16835w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0O_w_lg_w_lg_o16638w16830w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0O_w_lg_w_lg_o16638w16823w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0O_w_lg_w_lg_o16638w16820w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0O_w_lg_w_lg_o16638w16682w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0O_w_lg_w_lg_o16638w16677w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0O_w_lg_w_lg_o16638w16662w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0O_w_lg_w_lg_o16638w16659w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0O_w_lg_o16666w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0O_w_lg_o16685w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0O_w_lg_o16688w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0O_w_lg_o16638w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll0O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1ll0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1ll0O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_w_lg_w_lg_o16855w17043w17044w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_w_lg_o17045w17046w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_w_lg_o16855w17053w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_w_lg_o16855w16857w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_w_lg_o16855w16895w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_w_lg_o16855w16872w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_w_lg_o16855w17043w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_w_lg_o16855w16880w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_w_lg_o16855w17061w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_o17050w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_o16869w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_o17122w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_o16883w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_o17062w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_o16876w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_o16901w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_o17045w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_o16850w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_o16855w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_w_lg_w_lg_w_lg_o16855w17043w17044w17047w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_w_lg_o16855w16919w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_w_lg_o16938w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1ll1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1ll1i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_w_lg_o16854w17054w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_w_lg_o16854w16891w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_w_lg_o16854w17093w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_w_lg_o16854w17088w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_w_lg_o16854w17074w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_w_lg_o16854w17071w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_o17077w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_o17096w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_o17051w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_o16870w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_o16884w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_o17099w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_o16877w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_o16902w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_o16851w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_o16890w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_o16854w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_w_lg_o17051w17055w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_w_lg_w_lg_o16890w16892w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1ll1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1ll1l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_w_lg_o16937w16939w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_w_lg_o16853w16969w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_o17094w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_o17089w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_o17075w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_o17072w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_o17078w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_o17097w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_o16885w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_o17100w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_o16878w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_o16903w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_o16852w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_o16937w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_o16853w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_w_lg_o16934w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1ll1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1ll1O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1llii_w_lg_w_lg_o16569w16808w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llii_w_lg_w_lg_o16569w16768w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llii_w_lg_o16836w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llii_w_lg_o16831w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llii_w_lg_o16824w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llii_w_lg_o16821w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llii_w_lg_o16683w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llii_w_lg_o16678w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llii_w_lg_o16663w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llii_w_lg_o16660w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llii_w_lg_o16667w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llii_w_lg_o16686w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llii_w_lg_o16689w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llii_w_lg_o16635w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llii_w_lg_o16569w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llii_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1llii_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1llii_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1llil_w_lg_w_lg_o16499w16570w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llil_w_lg_w_lg_o16499w16611w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llil_w_lg_w_lg_o16499w16563w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llil_w_lg_w_lg_o16499w16500w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llil_w_lg_o16636w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llil_w_lg_o16581w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llil_w_lg_o16503w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llil_w_lg_o16587w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llil_w_lg_o16499w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llil_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1llil_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1llil_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_w_lg_o16498w16571w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_w_lg_o16498w16564w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_w_lg_o16498w16643w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_w_lg_w_lg_o16498w16566w16567w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_w16572w16578w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w16597w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_w_lg_o16584w16585w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_o16612w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_o16637w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_o16582w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_o16504w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_o16588w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_o16644w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_o16523w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_o16498w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_w_lg_w_lg_o16498w16564w16565w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_w_lg_o16582w16583w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_w_lg_o16498w16566w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_w_lg_w_lg_w_lg_o16498w16564w16565w16568w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_w_lg_w_lg_o16582w16583w16586w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w16572w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_w_lg_w_lg_w_lg_o16582w16583w16586w16589w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_w_lg_o16584w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lliO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lliO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1llli_w_lg_w_lg_o16512w16696w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llli_w_lg_w_lg_o16512w16619w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llli_w_lg_o16524w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llli_w_lg_o16777w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llli_w_lg_o16512w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llli_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1llli_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1llli_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_w_lg_w_lg_o16511w16699w16700w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_w_lg_o16701w16702w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_w_lg_o16511w16709w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_w_lg_o16511w16513w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_w_lg_o16511w16699w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_w_lg_o16511w16551w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_w_lg_o16511w16528w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_w_lg_o16511w16536w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_w_lg_o16511w16717w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_o16706w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_o16525w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_o16778w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_o16539w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_o16718w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_o16701w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_o16532w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_o16557w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_o16506w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_o16511w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_w_lg_w_lg_w_lg_o16511w16699w16700w16703w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_w_lg_o16511w16575w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_w_lg_o16594w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llll_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1llll_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1llll_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_w_lg_o16510w16710w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_w_lg_o16510w16749w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_w_lg_o16510w16744w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_w_lg_o16510w16730w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_w_lg_o16510w16727w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_w_lg_o16510w16547w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_o16733w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_o16752w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_o16707w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_o16526w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_o16540w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_o16755w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_o16533w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_o16558w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_o16507w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_o16546w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_o16510w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_w_lg_o16707w16711w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_w_lg_w_lg_o16546w16548w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lllO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lllO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_w_lg_o16593w16595w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_w_lg_o16509w16625w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_o16750w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_o16745w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_o16731w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_o16728w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_o16734w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_o16753w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_o16541w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_o16756w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_o16534w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_o16559w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_o16508w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_o16593w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_o16509w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_w_lg_o16590w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1llOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1llOi_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1llOl_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1llOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1llOl_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1llOO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1llOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1llOO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lO0i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lO0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lO0i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lO0l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lO0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lO0l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lO0O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lO0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lO0O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lO1i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lO1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lO1i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lO1l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lO1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lO1l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lO1O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lO1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lO1O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lOii_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lOii_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lOii_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lOil_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lOil_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lOil_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lOiO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lOiO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lOiO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lOli_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lOli_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lOli_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lOll_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lOll_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lOll_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lOlO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lOlO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lOlO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lOOi_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lOOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lOOi_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lOOl_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lOOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lOOl_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1lOOO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lOOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lOOO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O00i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O00i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O00i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O01i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O01i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O01i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O01l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O01l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O01l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O01O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O01O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O01O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O10i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O10i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O10i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O10l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O10l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O10l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O10O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O10O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O10O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O11i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O11i_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O11i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O11l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O11l_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O11l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O11O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O11O_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O11O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O1ii_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O1ii_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O1ii_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O1il_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O1il_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O1il_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O1iO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O1iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O1iO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O1li_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O1li_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O1li_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O1ll_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O1ll_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O1ll_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O1lO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O1lO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O1lO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O1Oi_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O1Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O1Oi_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O1Ol_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O1Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O1Ol_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nl1O1OO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1O1OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1O1OO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllO0iO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nllO0iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nllO0iO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllO0li_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nllO0li_o	:	STD_LOGIC;
	 SIGNAL  wire_nllO0li_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllO0ll_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nllO0ll_o	:	STD_LOGIC;
	 SIGNAL  wire_nllO0ll_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllO0lO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nllO0lO_o	:	STD_LOGIC;
	 SIGNAL  wire_nllO0lO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllO0Oi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nllO0Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_nllO0Oi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllO0Ol_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nllO0Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_nllO0Ol_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllO0OO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nllO0OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nllO0OO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllOi1i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nllOi1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nllOi1i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO0O0i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO0O0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0O0i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlO0OiO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO0OiO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0OiO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlO0OOl_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlO0OOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nlO0OOl_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlOi00i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlOi00i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlOi00i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlOi0iO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlOi0iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlOi0iO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlOi10i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlOi10i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlOi10i_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlOi1iO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlOi1iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlOi1iO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nlOi1Ol_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlOi1Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_nlOi1Ol_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n1lili_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1lili_o	:	STD_LOGIC;
	 SIGNAL  wire_n1lili_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1lill_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1lill_o	:	STD_LOGIC;
	 SIGNAL  wire_n1lill_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1lilO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1lilO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1lilO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1liOi_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1liOi_o	:	STD_LOGIC;
	 SIGNAL  wire_n1liOi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1liOO_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1liOO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1liOO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1ll0O_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n1ll0O_o	:	STD_LOGIC;
	 SIGNAL  wire_n1ll0O_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n1ll1i_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1ll1i_o	:	STD_LOGIC;
	 SIGNAL  wire_n1ll1i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1ll1l_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1ll1l_o	:	STD_LOGIC;
	 SIGNAL  wire_n1ll1l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1ll1O_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1ll1O_o	:	STD_LOGIC;
	 SIGNAL  wire_n1ll1O_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1llil_data	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_n1llil_o	:	STD_LOGIC;
	 SIGNAL  wire_n1llil_sel	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_n1llli_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n1llli_o	:	STD_LOGIC;
	 SIGNAL  wire_n1llli_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n1lllO_data	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_n1lllO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1lllO_sel	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_n1Oliii_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oliii_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oliii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oliil_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Oliil_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oliil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1OliiO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1OliiO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OliiO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Olili_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Olili_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Olili_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Olill_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1Olill_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Olill_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1OliOi_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1OliOi_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OliOi_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1OliOl_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1OliOl_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OliOl_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1OliOO_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1OliOO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OliOO_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1Oll0l_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n1Oll0l_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oll0l_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n1Oll1i_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1Oll1i_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oll1i_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1Oll1l_data	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1Oll1l_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Oll1l_sel	:	STD_LOGIC_VECTOR (4 DOWNTO 0);
	 SIGNAL  wire_n1Ollii_data	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_n1Ollii_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Ollii_sel	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_n1OlliO_data	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n1OlliO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1OlliO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_n1Ollll_data	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_n1Ollll_o	:	STD_LOGIC;
	 SIGNAL  wire_n1Ollll_sel	:	STD_LOGIC_VECTOR (6 DOWNTO 0);
	 SIGNAL  wire_niO00i_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO00i_o	:	STD_LOGIC;
	 SIGNAL  wire_niO00i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO00l_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO00l_o	:	STD_LOGIC;
	 SIGNAL  wire_niO00l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO00O_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO00O_o	:	STD_LOGIC;
	 SIGNAL  wire_niO00O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO01i_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO01i_o	:	STD_LOGIC;
	 SIGNAL  wire_niO01i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO01l_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO01l_o	:	STD_LOGIC;
	 SIGNAL  wire_niO01l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO01O_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO01O_o	:	STD_LOGIC;
	 SIGNAL  wire_niO01O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO1Ol_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO1Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_niO1Ol_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO1OO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niO1OO_o	:	STD_LOGIC;
	 SIGNAL  wire_niO1OO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOill_w_lg_o3118w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOill_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOill_o	:	STD_LOGIC;
	 SIGNAL  wire_niOill_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOilO_w_lg_w_lg_o3116w3135w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOilO_w_lg_w_lg_o3116w3117w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOilO_w_lg_o3119w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOilO_w_lg_o3116w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOilO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOilO_o	:	STD_LOGIC;
	 SIGNAL  wire_niOilO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOiOi_w_lg_w_lg_o3108w3287w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOi_w_lg_w_lg_o3108w3282w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOi_w_lg_w_lg_o3108w3275w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOi_w_lg_w_lg_o3108w3272w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOi_w_lg_w_lg_o3108w3152w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOi_w_lg_w_lg_o3108w3147w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOi_w_lg_w_lg_o3108w3132w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOi_w_lg_w_lg_o3108w3129w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOi_w_lg_o3136w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOi_w_lg_o3155w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOi_w_lg_o3158w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOi_w_lg_o3108w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOi_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOiOi_o	:	STD_LOGIC;
	 SIGNAL  wire_niOiOi_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOiOl_w_lg_w_lg_o1205w3260w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOl_w_lg_w_lg_o1205w1206w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOl_w_lg_o3288w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOl_w_lg_o3283w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOl_w_lg_o3276w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOl_w_lg_o3273w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOl_w_lg_o3153w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOl_w_lg_o3148w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOl_w_lg_o3133w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOl_w_lg_o3130w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOl_w_lg_o3137w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOl_w_lg_o3156w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOl_w_lg_o3159w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOl_w_lg_o3105w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOl_w_lg_o1205w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOl_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOiOl_o	:	STD_LOGIC;
	 SIGNAL  wire_niOiOl_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOiOO_w_lg_w_lg_o2973w3041w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOO_w_lg_w_lg_o2973w3035w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOO_w_lg_w_lg_o2973w2974w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOO_w_lg_o3106w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOO_w_lg_o3052w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOO_w_lg_o2977w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOO_w_lg_o3058w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOO_w_lg_o2973w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOiOO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOiOO_o	:	STD_LOGIC;
	 SIGNAL  wire_niOiOO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_w_lg_o2972w3042w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_w_lg_o2972w3036w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_w_lg_o2972w3113w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_w_lg_w_lg_o2972w3038w3039w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_w3043w3049w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w3068w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_w_lg_o3055w3056w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_o3107w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_o3053w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_o2978w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_o3059w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_o3114w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_o2994w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_o2972w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_w_lg_w_lg_o2972w3036w3037w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_w_lg_o3053w3054w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_w_lg_o2972w3038w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_w_lg_w_lg_w_lg_o2972w3036w3037w3040w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_w_lg_w_lg_o3053w3054w3057w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w3043w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_w_lg_w_lg_w_lg_o3053w3054w3057w3060w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_w_lg_o3055w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1i_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOl1i_o	:	STD_LOGIC;
	 SIGNAL  wire_niOl1i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOl1l_w_lg_w_lg_o2983w3085w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1l_w_lg_w_lg_o2983w3166w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1l_w_lg_o2995w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1l_w_lg_o1215w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1l_w_lg_o2983w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1l_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOl1l_o	:	STD_LOGIC;
	 SIGNAL  wire_niOl1l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_w_lg_w_lg_o1314w3170w3171w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_w_lg_o3172w3173w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_w_lg_o1314w3181w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_w_lg_o1314w2984w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_w_lg_o1314w3022w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_w_lg_o1314w2999w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_w_lg_o1314w1315w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_w_lg_o1314w3170w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_w_lg_o1314w3007w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_w_lg_o1314w3189w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_o3178w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_o2996w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_o1216w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_o3010w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_o3190w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_o3003w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_o3028w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_o1319w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_o3172w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_o2980w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_o1314w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_w_lg_w_lg_w_lg_o1314w3170w3171w3174w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_w_lg_o1314w3046w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_w_lg_o3065w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niOl1O_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_niOl1O_o	:	STD_LOGIC;
	 SIGNAL  wire_niOl1O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll1llO_w_lg_o7418w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll1llO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll1llO_o	:	STD_LOGIC;
	 SIGNAL  wire_nll1llO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll1lOO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll1lOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nll1lOO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll1O1i_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nll1O1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nll1O1i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlll0i_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlll0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlll0i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlll1i_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlll1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlll1i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlll1l_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlll1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlll1l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlll1O_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlll1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlll1O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllll0i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllll0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nllll0i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllll0l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllll0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nllll0l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllll0O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllll0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nllll0O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllll1l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllll1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nllll1l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllll1O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllll1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nllll1O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllllii_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllllii_o	:	STD_LOGIC;
	 SIGNAL  wire_nllllii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllllil_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllllil_o	:	STD_LOGIC;
	 SIGNAL  wire_nllllil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllliO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllliO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlllliO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllllli_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllllli_o	:	STD_LOGIC;
	 SIGNAL  wire_nllllli_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllllll_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllllll_o	:	STD_LOGIC;
	 SIGNAL  wire_nllllll_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllllOl_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllllOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nllllOl_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllllOO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllllOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nllllOO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllO0i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllO0i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlllO0i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllO0l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllO0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlllO0l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllO0O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllO0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlllO0O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllO1i_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllO1i_o	:	STD_LOGIC;
	 SIGNAL  wire_nlllO1i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllO1l_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllO1l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlllO1l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllO1O_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllO1O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlllO1O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllOii_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllOii_o	:	STD_LOGIC;
	 SIGNAL  wire_nlllOii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllOil_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllOil_o	:	STD_LOGIC;
	 SIGNAL  wire_nlllOil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlllOli_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlllOli_o	:	STD_LOGIC;
	 SIGNAL  wire_nlllOli_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlllOOi_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlllOOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nlllOOi_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlllOOl_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlllOOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nlllOOl_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlllOOO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nlllOOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlllOOO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO10i_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO10i_o	:	STD_LOGIC;
	 SIGNAL  wire_nllO10i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO10l_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO10l_o	:	STD_LOGIC;
	 SIGNAL  wire_nllO10l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO10O_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO10O_o	:	STD_LOGIC;
	 SIGNAL  wire_nllO10O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO11i_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO11i_o	:	STD_LOGIC;
	 SIGNAL  wire_nllO11i_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO11l_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO11l_o	:	STD_LOGIC;
	 SIGNAL  wire_nllO11l_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO11O_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO11O_o	:	STD_LOGIC;
	 SIGNAL  wire_nllO11O_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO1ii_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO1ii_o	:	STD_LOGIC;
	 SIGNAL  wire_nllO1ii_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO1iO_data	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_nllO1iO_o	:	STD_LOGIC;
	 SIGNAL  wire_nllO1iO_sel	:	STD_LOGIC_VECTOR (2 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_rauto_speed_ena5w8w9w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n1i0O0O338w341w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n1ii01O227w228w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n1ii11O1325w1327w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rauto_speed_ena5w8w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n10liOl3443w3446w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n10ll1O3434w3435w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rkchar3383w3384w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w2208w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w2203w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w2198w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w2193w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w14500w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w14495w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w14490w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w14480w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w14485w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w14475w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w14470w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w14465w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w14455w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w14460w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w14450w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w14445w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n1i01lO1217w1218w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n1i1Oil1323w1324w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlOO0iOl16779w16780w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlOO1O0l17123w17124w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4782w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4786w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4780w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4776w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4774w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4770w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4800w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4804w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4798w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4794w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4792w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4788w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4764w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4768w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4762w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4758w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4756w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5097w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5095w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5091w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5089w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5757w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5743w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5738w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5061w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5067w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5065w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5059w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5055w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5053w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5079w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5085w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5083w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5077w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5073w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5071w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5043w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5049w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5047w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5041w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5037w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5035w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5025w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5031w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5029w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5023w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5019w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5017w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5007w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5013w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5011w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn5005w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4872w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4870w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4866w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4864w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4860w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4854w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4858w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4852w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4848w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4846w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4842w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4836w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4840w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4834w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4830w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4828w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4824w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4818w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4822w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4816w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4812w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4810w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_comp_pat_porn4806w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10l1ii4519w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O10i3044w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O10l3062w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O10O3020w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O11l3047w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i000O1200w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i00il3236w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i00il1198w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0l0l388w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0l1O396w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0lii380w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0liO372w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0lll364w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0lOO356w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0O0O338w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1Oll3180w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1OlO3177w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1ii01O227w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1ii11i326w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1ii11O1325w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO011i17049w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO01ll16920w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO01Oi16917w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO01Ol16935w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO01OO16893w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0i0O16788w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0i0O16761w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0lil16763w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0liO16708w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0lli16705w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0O0l16576w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0Oii16573w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0Oil16591w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0OiO16549w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO1llO17132w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO1llO17105w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO1OOl17107w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO1OOO17052w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rauto_speed_ena5w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rencdt_rising4509w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_wa_6g_en4496w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_comp_pat_size_range1330w1333w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_ib_invalid_code_range3169w17048w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_ib_invalid_code_range3169w16704w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_ib_invalid_code_range3169w3175w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_ib_invalid_code_range3176w3184w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_ib_invalid_code_range3176w17056w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_ib_invalid_code_range3176w16712w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2186w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14438w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w1328w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2181w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14433w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2176w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14428w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2103w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14162w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2096w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14155w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2089w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14148w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14247w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14253w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14240w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14233w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14226w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14262w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14259w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14256w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14212w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14219w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14205w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14198w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14191w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14177w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14184w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14170w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2172w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2138w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2141w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2132w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2125w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2118w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2111w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2912w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w16385w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14424w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14404w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14385w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2207w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2202w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2197w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2517w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2192w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2482w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w176w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w15676w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14499w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14494w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14484w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14489w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14479w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14474w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14469w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14459w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14464w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14454w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14449w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w14444w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w15643w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_r8b10b_dec_ibm_en_range3034w16923w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_r8b10b_dec_ibm_en_range3034w16579w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_r8b10b_dec_ibm_en_range3034w3050w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_r8b10b_dec_ibm_en_range3034w16942w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_r8b10b_dec_ibm_en_range3034w16598w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_r8b10b_dec_ibm_en_range3034w3069w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_resync_badcg_en_range4511w4518w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_autobytealign_dis5791w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_disable_rx_disp1194w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_lpbk_en4500w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10l00i3543w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10l01l3948w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10l01O3545w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10l0OO3456w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10l10i4528w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10l11i4530w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10l1il4527w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10l1li4548w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10li0i3455w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10li0O3453w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10lili3500w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10lilO3445w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10liOl3443w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10ll0i3493w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10ll0l3386w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10ll0O3433w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10ll1l3437w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10ll1O3434w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10llii3439w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10lOlO3084w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O00l2717w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O01l2767w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O01O2739w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O0il2712w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O0li2685w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O0Oi2526w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O0Ol2525w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O0OO2524w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O10O3014w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O1iO3025w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O1li3031w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O1Oi3072w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Oi0i2520w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Oi0l2490w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Oi0O2489w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Oi1i2523w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Oi1l2522w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Oi1O2521w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Oiii2488w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Oiil2487w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10OiiO2486w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Oili2485w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Oill2484w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10OiOO2455w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Ol0i2451w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Ol0l2449w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Ol0O2457w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Ol1i2453w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Ol1l2515w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Ol1O2459w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Olli2400w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10Olll2398w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10OllO2505w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10OlOi2404w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10OlOl2396w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10OlOO2394w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10OO0l2345w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10OO0O2343w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10OO1i2402w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10OOii2480w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10OOil2349w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10OOiO2341w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10OOli2339w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10OOll2347w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10OOOO2291w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110iiO5931w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110ili5930w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110iOl5657w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110l0i5646w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110l0l5644w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110l0O5642w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110l1i5652w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110l1l5650w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110l1O5648w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110lii5640w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110lil5638w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110liO5636w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110lli5634w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110lll5632w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110llO5630w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110lOi5628w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110lOl5626w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110lOO5624w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110O1i5616w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n110O1l5614w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n11100i14248w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n11100l14246w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n11100O14683w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n11101i14674w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n11101l14252w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n11101O14678w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1110ii14241w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1110il14239w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1110iO14689w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1110li14234w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1110ll14232w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1110lO14696w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1110Oi14227w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1110Ol14225w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1110OO14704w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n11110i15016w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n11110l15031w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n11110O15047w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n11111i14977w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n11111l14989w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n11111O15002w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1111ii15064w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1111il15082w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1111li16406w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1111ll14261w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1111lO14669w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1111Oi14258w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1111Ol14671w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1111OO14255w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111i0i14213w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111i0l14211w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111i0O14723w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111i1i14220w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111i1l14218w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111i1O14713w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111iii14206w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111iil14204w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111iiO14734w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111ili14199w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111ill14197w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111ilO14746w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111iOi14192w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111iOl14190w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111iOO14759w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111l0i14178w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111l0l14176w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111l0O14788w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111l1i14185w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111l1l14183w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111l1O14773w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111lii14171w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111lil14169w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111liO14804w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111lli14821w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111lll14839w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111lOi7419w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n111O1i7420w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i00lO1129w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i01ii1295w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i01il1227w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0i0i462w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0i0O459w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0iii457w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0iil455w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0iiO453w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0ili451w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0ill449w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0ilO447w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i0iOi445w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i100l2498w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i100O2508w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i101i2943w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i101O2353w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i10il2355w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i10ll2359w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i10Ol2364w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i110i2287w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i110l2285w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i110O2293w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i111i2289w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i111l2471w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i111O2295w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i11ii2953w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i11il2408w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i11li2410w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i11ll2414w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i11lO2419w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i11Oi2425w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i11Ol2432w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i11OO2440w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1i0i2385w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1i1l2370w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1i1O2377w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1iii2933w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1iil2299w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1iiO2171w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1ili2305w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1ill2310w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1ilO2316w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1iOi2323w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1iOl2331w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1l0i2137w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1l0l2464w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1l0O2133w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1l1i2923w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1l1l2140w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1l1O2244w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1lii2131w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1lil2246w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1liO2126w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1lli2124w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1lll2250w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1llO2119w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1lOi2117w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1lOl2255w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1lOO2112w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1O0i2276w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1O1i2110w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1O1l2261w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1O1O2268w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1ii00i237w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1ii00l231w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1ii1lO236w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1ii1OO229w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO000i16904w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO001O16898w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO00ii16945w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO01OO16887w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0l0O16618w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0OiO16543w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0OlO16554w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0OOi16560w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO1OlO16962w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi00i15691w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi00l15690w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi00O15689w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi01i15694w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi01l15693w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi01O15692w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi0ii15688w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi0il15687w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi0iO15686w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi0li15685w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi0ll15684w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi0lO15683w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi0Oi15682w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi0Ol15681w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi0OO15680w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi10l16209w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi10O16181w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi11i16601w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi1il16159w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi1ll16154w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOii0i15658w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOii0l15657w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOii0O15656w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOii1i15679w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOii1l15660w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOii1O15659w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiiii15655w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiiil15654w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiiiO15653w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiili15652w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiill15651w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiilO15650w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiiOi15649w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiiOl15648w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiiOO15647w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOil1i15646w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOil1l15645w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiliO15632w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOilli15630w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOilll15621w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOillO15619w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOilOi15617w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOilOl15615w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOilOO15609w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiO0i15601w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiO0l15599w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiO0O15597w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiO1i15607w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiO1l15605w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiO1O15603w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiOii15596w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiOil15594w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiOiO15592w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiOli15590w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOiOll15588w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl00i15346w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl00l15344w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl01i15352w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl01l15350w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl01O15348w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl0lO15144w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl0Oi15142w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl0Ol15133w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl0OO15131w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl10i15386w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl10l15377w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl10O15375w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl11O15388w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl1ii15373w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl1il15371w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl1iO15365w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl1li15363w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl1ll15361w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl1lO15359w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl1Oi15357w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl1Ol15355w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOl1OO15353w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOli0i15119w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOli0l15117w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOli0O15115w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOli1i15129w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOli1l15127w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOli1O15121w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOliii15113w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOliil15111w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOliiO15109w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlili15108w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlill15106w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlilO15104w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOliOi15102w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOliOl15100w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOll0O14902w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOllii14900w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOllil14891w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlliO14889w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOllli14887w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOllll14885w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlllO14879w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOllOi14877w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOllOl14875w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOllOO14873w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlO0i14866w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlO0l14864w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlO0O14862w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlO1i14871w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlO1l14869w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlO1O14867w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlOii14860w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlOil14858w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlOiO16466w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlOli15399w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlOlO15401w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlOOl15404w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO00i15157w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO00O15160w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO01l15155w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO0il15164w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO0iO15408w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO0ll15169w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO0Ol15175w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO10i15434w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO10l15443w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO10O15453w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO11i15413w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO11l15419w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO11O15426w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO1ii15464w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO1il15476w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO1iO15489w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO1li15503w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO1ll15518w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO1lO15534w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO1Oi15551w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO1Ol15569w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO1OO16446w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOi0l15190w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOi1l15182w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOiil15199w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOill15209w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOiOl15220w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOl0l15245w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOl1l15232w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOlil15259w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOlll15274w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOlOl15290w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOlOO15307w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOO0i16426w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOO0l14913w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOO0O14423w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOO1i15325w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOOii14915w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOOil14403w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOOiO14918w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOOli14384w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOOll14932w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOOlO14939w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOOOi14947w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOOOl14956w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOOOO14966w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rencdt_rising4504w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rfreq_sel4w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rkchar3383w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rosbased3492w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rst113w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_sync_sm_dis1224w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_wa_6g_en4499w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_comp_pat_size_range1331w1332w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w219w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_resync_badcg_en_range4513w4514w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_rauto_speed_ena5w8w9w10w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4782w4783w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4786w4787w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4780w4781w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4776w4777w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4774w4775w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4770w4771w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4800w4801w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4804w4805w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4798w4799w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4794w4795w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4792w4793w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4788w4789w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4764w4765w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4768w4769w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4762w4763w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4758w4759w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4756w4757w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5097w5098w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5095w5096w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5091w5092w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5089w5090w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5757w5758w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5743w5744w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5738w5739w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5061w5062w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5067w5068w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5065w5066w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5059w5060w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5055w5056w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5053w5054w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5079w5080w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5085w5086w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5083w5084w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5077w5078w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5073w5074w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5071w5072w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5043w5044w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5049w5050w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5047w5048w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5041w5042w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5037w5038w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5035w5036w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5025w5026w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5031w5032w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5029w5030w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5023w5024w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5019w5020w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5017w5018w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5007w5008w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5013w5014w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5011w5012w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn5005w5006w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4872w4873w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4870w4871w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4866w4867w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4864w4865w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4860w4861w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4854w4855w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4858w4859w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4852w4853w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4848w4849w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4846w4847w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4842w4843w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4836w4837w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4840w4841w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4834w4835w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4830w4831w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4828w4829w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4824w4825w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4818w4819w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4822w4823w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4816w4817w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4812w4813w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4810w4811w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_comp_pat_porn4806w4807w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w176w177w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n10ll0O3433w3447w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n11100i14248w15001w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n11100i14248w15015w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n11100i14248w15030w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n11100i14248w14965w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n11100i14248w14976w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n11100i14248w14988w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n11100i14248w15046w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n11100i14248w15063w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n11100i14248w15081w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n11100i14248w14931w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n11100i14248w14938w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n11100i14248w14946w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n11100i14248w14955w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n1i1l0O2133w2304w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n1i1l0O2133w2309w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n1i1l0O2133w2315w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n1i1l0O2133w2322w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n1i1l0O2133w2330w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w2572w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w2564w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w2556w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w219w2580w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_pmadwidth_range175w176w177w181w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15832w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15820w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15916w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15904w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15892w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15880w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15868w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15856w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15844w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_pmadwidth_range175w219w2572w2573w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_pmadwidth_range175w219w2564w2565w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_pmadwidth_range175w219w2556w2557w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_pmadwidth_range175w219w2580w2581w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w182w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15832w15833w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15820w15821w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15916w15917w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15904w15905w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15892w15893w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15880w15881w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15868w15869w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15856w15857w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15844w15845w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w2574w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w2566w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w2558w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w2582w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15832w15833w15834w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15820w15821w15822w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15916w15917w15918w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15904w15905w15906w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15892w15893w15894w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15880w15881w15882w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15868w15869w15870w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15856w15857w15858w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15844w15845w15846w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w2574w2575w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w2566w2567w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w2558w2559w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w2582w2583w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15832w15833w15834w15835w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15820w15821w15822w15823w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15916w15917w15918w15919w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15904w15905w15906w15907w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15892w15893w15894w15895w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15880w15881w15882w15883w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15868w15869w15870w15871w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15856w15857w15858w15859w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15844w15845w15846w15847w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w2574w2575w2576w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w2566w2567w2568w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w2558w2559w2560w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w2582w2583w2584w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15836w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15824w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15920w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15908w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15896w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15884w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15872w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15860w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15848w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w2574w2575w2576w2577w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w2566w2567w2568w2569w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w2558w2559w2560w2561w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w2582w2583w2584w2585w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15836w15837w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15824w15825w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15920w15921w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15908w15909w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15896w15897w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15884w15885w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15872w15873w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15860w15861w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15848w15849w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15836w15837w15838w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15824w15825w15826w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15920w15921w15922w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15908w15909w15910w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15896w15897w15898w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15884w15885w15886w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15872w15873w15874w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15860w15861w15862w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15848w15849w15850w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15836w15837w15838w15839w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15824w15825w15826w15827w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15920w15921w15922w15923w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15908w15909w15910w15911w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15896w15897w15898w15899w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15884w15885w15886w15887w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15872w15873w15874w15875w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15860w15861w15862w15863w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15848w15849w15850w15851w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15840w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15828w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15924w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15912w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15900w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15888w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15876w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15864w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15852w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15840w15841w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15828w15829w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15924w15925w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15912w15913w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15900w15901w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15888w15889w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15876w15877w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15864w15865w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15852w15853w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15840w15841w15842w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15828w15829w15830w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15924w15925w15926w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15912w15913w15914w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15900w15901w15902w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15888w15889w15890w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15876w15877w15878w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15864w15865w15866w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15852w15853w15854w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15814w15815w15816w15817w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15804w15805w15806w15807w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15794w15795w15796w15797w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15784w15785w15786w15787w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15774w15775w15776w15777w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15764w15765w15766w15767w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15753w15754w15755w15756w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15814w15815w15816w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15804w15805w15806w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15794w15795w15796w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15784w15785w15786w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15774w15775w15776w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15764w15765w15766w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15753w15754w15755w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15814w15815w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15804w15805w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15794w15795w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15784w15785w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15774w15775w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15764w15765w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15753w15754w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15814w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15804w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15794w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15784w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15774w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15764w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15753w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w1202w1203w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w17108w17109w17110w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w16764w16765w16766w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15810w15811w15812w15813w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15800w15801w15802w15803w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15790w15791w15792w15793w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15780w15781w15782w15783w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15770w15771w15772w15773w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15760w15761w15762w15763w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w15749w15750w15751w15752w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w1202w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w17108w17109w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w16764w16765w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15810w15811w15812w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15800w15801w15802w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15790w15791w15792w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15780w15781w15782w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15770w15771w15772w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15760w15761w15762w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w15749w15750w15751w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w2535w2536w2537w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w2551w2552w2553w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w2544w2545w2546w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_n1i00ll1196w1197w1199w1201w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w17108w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w16764w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15810w15811w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15800w15801w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15790w15791w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15780w15781w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15770w15771w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15760w15761w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w15749w15750w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w2535w2536w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w2551w2552w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w2544w2545w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_n1i00ll1196w1197w1199w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_nlOO010l17103w17104w17106w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_nlOO0lOl16759w16760w16762w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15810w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15800w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15790w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15780w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15770w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15760w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w15749w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w2535w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w2551w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w2544w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n10O10i3045w3048w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n10O10l3063w3067w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_n1i00ll1196w1197w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlOO010l17103w17104w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlOO01Oi16918w16921w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlOO01Ol16936w16940w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlOO0lOl16759w16760w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlOO0Oii16574w16577w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nlOO0Oil16592w16596w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w15747w15809w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w15747w15799w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w15747w15789w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w15747w15779w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w15747w15769w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w15747w15759w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w15747w15748w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w2533w2534w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w2549w2550w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_pmadwidth_range175w2542w2543w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_lpbk_en4495w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10l10O4521w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10l1ii4522w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10l1il4510w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10lOOO3237w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10lOOO3073w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O10i3045w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O10l3063w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O11i3074w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O1lO2970w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n10O1Oi2971w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1111li14881w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1111li14859w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i000i3077w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i001l1207w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i00li3076w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i00ll3075w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i00ll1196w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i01lO1217w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i01Ol1210w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i01OO1211w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i101i2395w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i101i2497w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i11ii2450w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i11ii2507w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1iii2340w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1iii2473w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1l1i2286w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1l1i2463w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1O0O1326w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1Oil1323w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1Oll3095w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n1i1OlO3094w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO000O16840w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO00ii16841w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO010l16948w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO010l17103w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO010O16949w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO011i16972w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO01ii16950w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO01iO17133w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO01iO16946w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO01li16947w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO01Oi16918w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO01Ol16936w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0i1l16769w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0ilO16773w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0iOl16779w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0l0i16772w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0liO16629w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0lli16628w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0lOl16604w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0lOl16759w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0lOO16605w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0O0i16603w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0O1i16606w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0O1O16789w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0O1O16602w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0Oii16574w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0Oil16592w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO0OOO16496w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO1lil17113w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO1O0l17123w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO1O1O17117w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO1Oli17116w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOO1OOO16973w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOi11i16497w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlOiO15611w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOlOiO15589w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO1OO15345w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOO1OO15367w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOO0i15123w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOOOO0i15101w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2589w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2608w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2600w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w15747w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2533w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2549w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_pmadwidth_range175w2542w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  n10000i :	STD_LOGIC;
	 SIGNAL  n10000l :	STD_LOGIC;
	 SIGNAL  n10000O :	STD_LOGIC;
	 SIGNAL  n10001i :	STD_LOGIC;
	 SIGNAL  n10001l :	STD_LOGIC;
	 SIGNAL  n10001O :	STD_LOGIC;
	 SIGNAL  n1000ii :	STD_LOGIC;
	 SIGNAL  n1000il :	STD_LOGIC;
	 SIGNAL  n1000iO :	STD_LOGIC;
	 SIGNAL  n1000li :	STD_LOGIC;
	 SIGNAL  n1000ll :	STD_LOGIC;
	 SIGNAL  n1000lO :	STD_LOGIC;
	 SIGNAL  n1000Oi :	STD_LOGIC;
	 SIGNAL  n1000Ol :	STD_LOGIC;
	 SIGNAL  n1000OO :	STD_LOGIC;
	 SIGNAL  n10010i :	STD_LOGIC;
	 SIGNAL  n10010l :	STD_LOGIC;
	 SIGNAL  n10010O :	STD_LOGIC;
	 SIGNAL  n10011i :	STD_LOGIC;
	 SIGNAL  n10011l :	STD_LOGIC;
	 SIGNAL  n10011O :	STD_LOGIC;
	 SIGNAL  n1001ii :	STD_LOGIC;
	 SIGNAL  n1001il :	STD_LOGIC;
	 SIGNAL  n1001iO :	STD_LOGIC;
	 SIGNAL  n1001li :	STD_LOGIC;
	 SIGNAL  n1001ll :	STD_LOGIC;
	 SIGNAL  n1001lO :	STD_LOGIC;
	 SIGNAL  n1001Oi :	STD_LOGIC;
	 SIGNAL  n1001Ol :	STD_LOGIC;
	 SIGNAL  n1001OO :	STD_LOGIC;
	 SIGNAL  n100i0i :	STD_LOGIC;
	 SIGNAL  n100i0l :	STD_LOGIC;
	 SIGNAL  n100i0O :	STD_LOGIC;
	 SIGNAL  n100i1i :	STD_LOGIC;
	 SIGNAL  n100i1l :	STD_LOGIC;
	 SIGNAL  n100i1O :	STD_LOGIC;
	 SIGNAL  n100iii :	STD_LOGIC;
	 SIGNAL  n100iil :	STD_LOGIC;
	 SIGNAL  n100iiO :	STD_LOGIC;
	 SIGNAL  n100ili :	STD_LOGIC;
	 SIGNAL  n100ill :	STD_LOGIC;
	 SIGNAL  n100ilO :	STD_LOGIC;
	 SIGNAL  n100iOi :	STD_LOGIC;
	 SIGNAL  n100iOl :	STD_LOGIC;
	 SIGNAL  n100iOO :	STD_LOGIC;
	 SIGNAL  n100l0i :	STD_LOGIC;
	 SIGNAL  n100l0l :	STD_LOGIC;
	 SIGNAL  n100l0O :	STD_LOGIC;
	 SIGNAL  n100l1i :	STD_LOGIC;
	 SIGNAL  n100l1l :	STD_LOGIC;
	 SIGNAL  n100l1O :	STD_LOGIC;
	 SIGNAL  n100lii :	STD_LOGIC;
	 SIGNAL  n100lil :	STD_LOGIC;
	 SIGNAL  n100liO :	STD_LOGIC;
	 SIGNAL  n100lli :	STD_LOGIC;
	 SIGNAL  n100lll :	STD_LOGIC;
	 SIGNAL  n100llO :	STD_LOGIC;
	 SIGNAL  n100lOi :	STD_LOGIC;
	 SIGNAL  n100lOl :	STD_LOGIC;
	 SIGNAL  n100lOO :	STD_LOGIC;
	 SIGNAL  n100O0i :	STD_LOGIC;
	 SIGNAL  n100O0l :	STD_LOGIC;
	 SIGNAL  n100O0O :	STD_LOGIC;
	 SIGNAL  n100O1i :	STD_LOGIC;
	 SIGNAL  n100O1l :	STD_LOGIC;
	 SIGNAL  n100O1O :	STD_LOGIC;
	 SIGNAL  n100Oii :	STD_LOGIC;
	 SIGNAL  n100Oil :	STD_LOGIC;
	 SIGNAL  n100OiO :	STD_LOGIC;
	 SIGNAL  n100Oli :	STD_LOGIC;
	 SIGNAL  n100Oll :	STD_LOGIC;
	 SIGNAL  n100OlO :	STD_LOGIC;
	 SIGNAL  n100OOi :	STD_LOGIC;
	 SIGNAL  n100OOl :	STD_LOGIC;
	 SIGNAL  n100OOO :	STD_LOGIC;
	 SIGNAL  n10100i :	STD_LOGIC;
	 SIGNAL  n10100l :	STD_LOGIC;
	 SIGNAL  n10100O :	STD_LOGIC;
	 SIGNAL  n10101i :	STD_LOGIC;
	 SIGNAL  n10101l :	STD_LOGIC;
	 SIGNAL  n10101O :	STD_LOGIC;
	 SIGNAL  n1010ii :	STD_LOGIC;
	 SIGNAL  n1010il :	STD_LOGIC;
	 SIGNAL  n1010iO :	STD_LOGIC;
	 SIGNAL  n1010li :	STD_LOGIC;
	 SIGNAL  n1010ll :	STD_LOGIC;
	 SIGNAL  n1010lO :	STD_LOGIC;
	 SIGNAL  n1010Oi :	STD_LOGIC;
	 SIGNAL  n1010Ol :	STD_LOGIC;
	 SIGNAL  n1010OO :	STD_LOGIC;
	 SIGNAL  n10110i :	STD_LOGIC;
	 SIGNAL  n10110l :	STD_LOGIC;
	 SIGNAL  n10110O :	STD_LOGIC;
	 SIGNAL  n10111i :	STD_LOGIC;
	 SIGNAL  n10111l :	STD_LOGIC;
	 SIGNAL  n10111O :	STD_LOGIC;
	 SIGNAL  n1011ii :	STD_LOGIC;
	 SIGNAL  n1011il :	STD_LOGIC;
	 SIGNAL  n1011iO :	STD_LOGIC;
	 SIGNAL  n1011li :	STD_LOGIC;
	 SIGNAL  n1011ll :	STD_LOGIC;
	 SIGNAL  n1011lO :	STD_LOGIC;
	 SIGNAL  n1011Oi :	STD_LOGIC;
	 SIGNAL  n1011Ol :	STD_LOGIC;
	 SIGNAL  n1011OO :	STD_LOGIC;
	 SIGNAL  n101i0i :	STD_LOGIC;
	 SIGNAL  n101i0l :	STD_LOGIC;
	 SIGNAL  n101i0O :	STD_LOGIC;
	 SIGNAL  n101i1i :	STD_LOGIC;
	 SIGNAL  n101i1l :	STD_LOGIC;
	 SIGNAL  n101i1O :	STD_LOGIC;
	 SIGNAL  n101iii :	STD_LOGIC;
	 SIGNAL  n101iil :	STD_LOGIC;
	 SIGNAL  n101iiO :	STD_LOGIC;
	 SIGNAL  n101ili :	STD_LOGIC;
	 SIGNAL  n101ill :	STD_LOGIC;
	 SIGNAL  n101ilO :	STD_LOGIC;
	 SIGNAL  n101iOi :	STD_LOGIC;
	 SIGNAL  n101iOl :	STD_LOGIC;
	 SIGNAL  n101iOO :	STD_LOGIC;
	 SIGNAL  n101l0i :	STD_LOGIC;
	 SIGNAL  n101l0l :	STD_LOGIC;
	 SIGNAL  n101l0O :	STD_LOGIC;
	 SIGNAL  n101l1i :	STD_LOGIC;
	 SIGNAL  n101l1l :	STD_LOGIC;
	 SIGNAL  n101l1O :	STD_LOGIC;
	 SIGNAL  n101lii :	STD_LOGIC;
	 SIGNAL  n101lil :	STD_LOGIC;
	 SIGNAL  n101liO :	STD_LOGIC;
	 SIGNAL  n101lli :	STD_LOGIC;
	 SIGNAL  n101lll :	STD_LOGIC;
	 SIGNAL  n101llO :	STD_LOGIC;
	 SIGNAL  n101lOi :	STD_LOGIC;
	 SIGNAL  n101lOl :	STD_LOGIC;
	 SIGNAL  n101lOO :	STD_LOGIC;
	 SIGNAL  n101O0i :	STD_LOGIC;
	 SIGNAL  n101O0l :	STD_LOGIC;
	 SIGNAL  n101O0O :	STD_LOGIC;
	 SIGNAL  n101O1i :	STD_LOGIC;
	 SIGNAL  n101O1l :	STD_LOGIC;
	 SIGNAL  n101O1O :	STD_LOGIC;
	 SIGNAL  n101Oii :	STD_LOGIC;
	 SIGNAL  n101Oil :	STD_LOGIC;
	 SIGNAL  n101OiO :	STD_LOGIC;
	 SIGNAL  n101Oli :	STD_LOGIC;
	 SIGNAL  n101Oll :	STD_LOGIC;
	 SIGNAL  n101OlO :	STD_LOGIC;
	 SIGNAL  n101OOi :	STD_LOGIC;
	 SIGNAL  n101OOl :	STD_LOGIC;
	 SIGNAL  n101OOO :	STD_LOGIC;
	 SIGNAL  n10i00i :	STD_LOGIC;
	 SIGNAL  n10i00l :	STD_LOGIC;
	 SIGNAL  n10i00O :	STD_LOGIC;
	 SIGNAL  n10i01i :	STD_LOGIC;
	 SIGNAL  n10i01l :	STD_LOGIC;
	 SIGNAL  n10i01O :	STD_LOGIC;
	 SIGNAL  n10i0ii :	STD_LOGIC;
	 SIGNAL  n10i0il :	STD_LOGIC;
	 SIGNAL  n10i0iO :	STD_LOGIC;
	 SIGNAL  n10i0li :	STD_LOGIC;
	 SIGNAL  n10i0ll :	STD_LOGIC;
	 SIGNAL  n10i0lO :	STD_LOGIC;
	 SIGNAL  n10i0Oi :	STD_LOGIC;
	 SIGNAL  n10i0Ol :	STD_LOGIC;
	 SIGNAL  n10i0OO :	STD_LOGIC;
	 SIGNAL  n10i10i :	STD_LOGIC;
	 SIGNAL  n10i10l :	STD_LOGIC;
	 SIGNAL  n10i10O :	STD_LOGIC;
	 SIGNAL  n10i11i :	STD_LOGIC;
	 SIGNAL  n10i11l :	STD_LOGIC;
	 SIGNAL  n10i11O :	STD_LOGIC;
	 SIGNAL  n10i1ii :	STD_LOGIC;
	 SIGNAL  n10i1il :	STD_LOGIC;
	 SIGNAL  n10i1iO :	STD_LOGIC;
	 SIGNAL  n10i1li :	STD_LOGIC;
	 SIGNAL  n10i1ll :	STD_LOGIC;
	 SIGNAL  n10i1lO :	STD_LOGIC;
	 SIGNAL  n10i1Oi :	STD_LOGIC;
	 SIGNAL  n10i1Ol :	STD_LOGIC;
	 SIGNAL  n10i1OO :	STD_LOGIC;
	 SIGNAL  n10ii0i :	STD_LOGIC;
	 SIGNAL  n10ii0l :	STD_LOGIC;
	 SIGNAL  n10ii0O :	STD_LOGIC;
	 SIGNAL  n10ii1i :	STD_LOGIC;
	 SIGNAL  n10ii1l :	STD_LOGIC;
	 SIGNAL  n10ii1O :	STD_LOGIC;
	 SIGNAL  n10iiii :	STD_LOGIC;
	 SIGNAL  n10iiil :	STD_LOGIC;
	 SIGNAL  n10iiiO :	STD_LOGIC;
	 SIGNAL  n10iili :	STD_LOGIC;
	 SIGNAL  n10iill :	STD_LOGIC;
	 SIGNAL  n10iilO :	STD_LOGIC;
	 SIGNAL  n10iiOi :	STD_LOGIC;
	 SIGNAL  n10iiOl :	STD_LOGIC;
	 SIGNAL  n10iiOO :	STD_LOGIC;
	 SIGNAL  n10il0i :	STD_LOGIC;
	 SIGNAL  n10il0l :	STD_LOGIC;
	 SIGNAL  n10il0O :	STD_LOGIC;
	 SIGNAL  n10il1i :	STD_LOGIC;
	 SIGNAL  n10il1l :	STD_LOGIC;
	 SIGNAL  n10il1O :	STD_LOGIC;
	 SIGNAL  n10ilii :	STD_LOGIC;
	 SIGNAL  n10ilil :	STD_LOGIC;
	 SIGNAL  n10iliO :	STD_LOGIC;
	 SIGNAL  n10illi :	STD_LOGIC;
	 SIGNAL  n10illl :	STD_LOGIC;
	 SIGNAL  n10illO :	STD_LOGIC;
	 SIGNAL  n10ilOi :	STD_LOGIC;
	 SIGNAL  n10ilOl :	STD_LOGIC;
	 SIGNAL  n10ilOO :	STD_LOGIC;
	 SIGNAL  n10iO0i :	STD_LOGIC;
	 SIGNAL  n10iO0l :	STD_LOGIC;
	 SIGNAL  n10iO0O :	STD_LOGIC;
	 SIGNAL  n10iO1i :	STD_LOGIC;
	 SIGNAL  n10iO1l :	STD_LOGIC;
	 SIGNAL  n10iO1O :	STD_LOGIC;
	 SIGNAL  n10iOii :	STD_LOGIC;
	 SIGNAL  n10iOil :	STD_LOGIC;
	 SIGNAL  n10iOiO :	STD_LOGIC;
	 SIGNAL  n10iOli :	STD_LOGIC;
	 SIGNAL  n10iOll :	STD_LOGIC;
	 SIGNAL  n10iOlO :	STD_LOGIC;
	 SIGNAL  n10iOOi :	STD_LOGIC;
	 SIGNAL  n10iOOl :	STD_LOGIC;
	 SIGNAL  n10iOOO :	STD_LOGIC;
	 SIGNAL  n10l00i :	STD_LOGIC;
	 SIGNAL  n10l00l :	STD_LOGIC;
	 SIGNAL  n10l00O :	STD_LOGIC;
	 SIGNAL  n10l01i :	STD_LOGIC;
	 SIGNAL  n10l01l :	STD_LOGIC;
	 SIGNAL  n10l01O :	STD_LOGIC;
	 SIGNAL  n10l0ii :	STD_LOGIC;
	 SIGNAL  n10l0il :	STD_LOGIC;
	 SIGNAL  n10l0iO :	STD_LOGIC;
	 SIGNAL  n10l0li :	STD_LOGIC;
	 SIGNAL  n10l0ll :	STD_LOGIC;
	 SIGNAL  n10l0lO :	STD_LOGIC;
	 SIGNAL  n10l0Oi :	STD_LOGIC;
	 SIGNAL  n10l0Ol :	STD_LOGIC;
	 SIGNAL  n10l0OO :	STD_LOGIC;
	 SIGNAL  n10l10i :	STD_LOGIC;
	 SIGNAL  n10l10l :	STD_LOGIC;
	 SIGNAL  n10l10O :	STD_LOGIC;
	 SIGNAL  n10l11i :	STD_LOGIC;
	 SIGNAL  n10l11l :	STD_LOGIC;
	 SIGNAL  n10l11O :	STD_LOGIC;
	 SIGNAL  n10l1ii :	STD_LOGIC;
	 SIGNAL  n10l1il :	STD_LOGIC;
	 SIGNAL  n10l1iO :	STD_LOGIC;
	 SIGNAL  n10l1li :	STD_LOGIC;
	 SIGNAL  n10l1ll :	STD_LOGIC;
	 SIGNAL  n10l1lO :	STD_LOGIC;
	 SIGNAL  n10l1Oi :	STD_LOGIC;
	 SIGNAL  n10l1Ol :	STD_LOGIC;
	 SIGNAL  n10l1OO :	STD_LOGIC;
	 SIGNAL  n10li0i :	STD_LOGIC;
	 SIGNAL  n10li0l :	STD_LOGIC;
	 SIGNAL  n10li0O :	STD_LOGIC;
	 SIGNAL  n10li1i :	STD_LOGIC;
	 SIGNAL  n10li1l :	STD_LOGIC;
	 SIGNAL  n10li1O :	STD_LOGIC;
	 SIGNAL  n10liii :	STD_LOGIC;
	 SIGNAL  n10liil :	STD_LOGIC;
	 SIGNAL  n10liiO :	STD_LOGIC;
	 SIGNAL  n10lili :	STD_LOGIC;
	 SIGNAL  n10lill :	STD_LOGIC;
	 SIGNAL  n10lilO :	STD_LOGIC;
	 SIGNAL  n10liOi :	STD_LOGIC;
	 SIGNAL  n10liOl :	STD_LOGIC;
	 SIGNAL  n10liOO :	STD_LOGIC;
	 SIGNAL  n10ll0i :	STD_LOGIC;
	 SIGNAL  n10ll0l :	STD_LOGIC;
	 SIGNAL  n10ll0O :	STD_LOGIC;
	 SIGNAL  n10ll1i :	STD_LOGIC;
	 SIGNAL  n10ll1l :	STD_LOGIC;
	 SIGNAL  n10ll1O :	STD_LOGIC;
	 SIGNAL  n10llii :	STD_LOGIC;
	 SIGNAL  n10llil :	STD_LOGIC;
	 SIGNAL  n10lliO :	STD_LOGIC;
	 SIGNAL  n10llli :	STD_LOGIC;
	 SIGNAL  n10llll :	STD_LOGIC;
	 SIGNAL  n10lllO :	STD_LOGIC;
	 SIGNAL  n10llOi :	STD_LOGIC;
	 SIGNAL  n10llOl :	STD_LOGIC;
	 SIGNAL  n10llOO :	STD_LOGIC;
	 SIGNAL  n10lO0i :	STD_LOGIC;
	 SIGNAL  n10lO0l :	STD_LOGIC;
	 SIGNAL  n10lO0O :	STD_LOGIC;
	 SIGNAL  n10lO1i :	STD_LOGIC;
	 SIGNAL  n10lO1l :	STD_LOGIC;
	 SIGNAL  n10lO1O :	STD_LOGIC;
	 SIGNAL  n10lOii :	STD_LOGIC;
	 SIGNAL  n10lOil :	STD_LOGIC;
	 SIGNAL  n10lOiO :	STD_LOGIC;
	 SIGNAL  n10lOli :	STD_LOGIC;
	 SIGNAL  n10lOll :	STD_LOGIC;
	 SIGNAL  n10lOlO :	STD_LOGIC;
	 SIGNAL  n10lOOi :	STD_LOGIC;
	 SIGNAL  n10lOOl :	STD_LOGIC;
	 SIGNAL  n10lOOO :	STD_LOGIC;
	 SIGNAL  n10O00i :	STD_LOGIC;
	 SIGNAL  n10O00l :	STD_LOGIC;
	 SIGNAL  n10O00O :	STD_LOGIC;
	 SIGNAL  n10O01i :	STD_LOGIC;
	 SIGNAL  n10O01l :	STD_LOGIC;
	 SIGNAL  n10O01O :	STD_LOGIC;
	 SIGNAL  n10O0ii :	STD_LOGIC;
	 SIGNAL  n10O0il :	STD_LOGIC;
	 SIGNAL  n10O0iO :	STD_LOGIC;
	 SIGNAL  n10O0li :	STD_LOGIC;
	 SIGNAL  n10O0ll :	STD_LOGIC;
	 SIGNAL  n10O0lO :	STD_LOGIC;
	 SIGNAL  n10O0Oi :	STD_LOGIC;
	 SIGNAL  n10O0Ol :	STD_LOGIC;
	 SIGNAL  n10O0OO :	STD_LOGIC;
	 SIGNAL  n10O10i :	STD_LOGIC;
	 SIGNAL  n10O10l :	STD_LOGIC;
	 SIGNAL  n10O10O :	STD_LOGIC;
	 SIGNAL  n10O11i :	STD_LOGIC;
	 SIGNAL  n10O11l :	STD_LOGIC;
	 SIGNAL  n10O11O :	STD_LOGIC;
	 SIGNAL  n10O1ii :	STD_LOGIC;
	 SIGNAL  n10O1il :	STD_LOGIC;
	 SIGNAL  n10O1iO :	STD_LOGIC;
	 SIGNAL  n10O1li :	STD_LOGIC;
	 SIGNAL  n10O1ll :	STD_LOGIC;
	 SIGNAL  n10O1lO :	STD_LOGIC;
	 SIGNAL  n10O1Oi :	STD_LOGIC;
	 SIGNAL  n10O1Ol :	STD_LOGIC;
	 SIGNAL  n10O1OO :	STD_LOGIC;
	 SIGNAL  n10Oi0i :	STD_LOGIC;
	 SIGNAL  n10Oi0l :	STD_LOGIC;
	 SIGNAL  n10Oi0O :	STD_LOGIC;
	 SIGNAL  n10Oi1i :	STD_LOGIC;
	 SIGNAL  n10Oi1l :	STD_LOGIC;
	 SIGNAL  n10Oi1O :	STD_LOGIC;
	 SIGNAL  n10Oiii :	STD_LOGIC;
	 SIGNAL  n10Oiil :	STD_LOGIC;
	 SIGNAL  n10OiiO :	STD_LOGIC;
	 SIGNAL  n10Oili :	STD_LOGIC;
	 SIGNAL  n10Oill :	STD_LOGIC;
	 SIGNAL  n10OilO :	STD_LOGIC;
	 SIGNAL  n10OiOi :	STD_LOGIC;
	 SIGNAL  n10OiOl :	STD_LOGIC;
	 SIGNAL  n10OiOO :	STD_LOGIC;
	 SIGNAL  n10Ol0i :	STD_LOGIC;
	 SIGNAL  n10Ol0l :	STD_LOGIC;
	 SIGNAL  n10Ol0O :	STD_LOGIC;
	 SIGNAL  n10Ol1i :	STD_LOGIC;
	 SIGNAL  n10Ol1l :	STD_LOGIC;
	 SIGNAL  n10Ol1O :	STD_LOGIC;
	 SIGNAL  n10Olii :	STD_LOGIC;
	 SIGNAL  n10Olil :	STD_LOGIC;
	 SIGNAL  n10OliO :	STD_LOGIC;
	 SIGNAL  n10Olli :	STD_LOGIC;
	 SIGNAL  n10Olll :	STD_LOGIC;
	 SIGNAL  n10OllO :	STD_LOGIC;
	 SIGNAL  n10OlOi :	STD_LOGIC;
	 SIGNAL  n10OlOl :	STD_LOGIC;
	 SIGNAL  n10OlOO :	STD_LOGIC;
	 SIGNAL  n10OO0i :	STD_LOGIC;
	 SIGNAL  n10OO0l :	STD_LOGIC;
	 SIGNAL  n10OO0O :	STD_LOGIC;
	 SIGNAL  n10OO1i :	STD_LOGIC;
	 SIGNAL  n10OO1l :	STD_LOGIC;
	 SIGNAL  n10OO1O :	STD_LOGIC;
	 SIGNAL  n10OOii :	STD_LOGIC;
	 SIGNAL  n10OOil :	STD_LOGIC;
	 SIGNAL  n10OOiO :	STD_LOGIC;
	 SIGNAL  n10OOli :	STD_LOGIC;
	 SIGNAL  n10OOll :	STD_LOGIC;
	 SIGNAL  n10OOlO :	STD_LOGIC;
	 SIGNAL  n10OOOi :	STD_LOGIC;
	 SIGNAL  n10OOOl :	STD_LOGIC;
	 SIGNAL  n10OOOO :	STD_LOGIC;
	 SIGNAL  n11000i :	STD_LOGIC;
	 SIGNAL  n11000l :	STD_LOGIC;
	 SIGNAL  n11000O :	STD_LOGIC;
	 SIGNAL  n11001i :	STD_LOGIC;
	 SIGNAL  n11001l :	STD_LOGIC;
	 SIGNAL  n11001O :	STD_LOGIC;
	 SIGNAL  n1100ii :	STD_LOGIC;
	 SIGNAL  n1100il :	STD_LOGIC;
	 SIGNAL  n1100iO :	STD_LOGIC;
	 SIGNAL  n1100li :	STD_LOGIC;
	 SIGNAL  n1100ll :	STD_LOGIC;
	 SIGNAL  n1100lO :	STD_LOGIC;
	 SIGNAL  n1100Oi :	STD_LOGIC;
	 SIGNAL  n1100Ol :	STD_LOGIC;
	 SIGNAL  n1100OO :	STD_LOGIC;
	 SIGNAL  n11010i :	STD_LOGIC;
	 SIGNAL  n11010l :	STD_LOGIC;
	 SIGNAL  n11010O :	STD_LOGIC;
	 SIGNAL  n11011i :	STD_LOGIC;
	 SIGNAL  n11011l :	STD_LOGIC;
	 SIGNAL  n11011O :	STD_LOGIC;
	 SIGNAL  n1101ii :	STD_LOGIC;
	 SIGNAL  n1101il :	STD_LOGIC;
	 SIGNAL  n1101iO :	STD_LOGIC;
	 SIGNAL  n1101li :	STD_LOGIC;
	 SIGNAL  n1101ll :	STD_LOGIC;
	 SIGNAL  n1101lO :	STD_LOGIC;
	 SIGNAL  n1101Oi :	STD_LOGIC;
	 SIGNAL  n1101Ol :	STD_LOGIC;
	 SIGNAL  n1101OO :	STD_LOGIC;
	 SIGNAL  n110i0i :	STD_LOGIC;
	 SIGNAL  n110i0l :	STD_LOGIC;
	 SIGNAL  n110i0O :	STD_LOGIC;
	 SIGNAL  n110i1i :	STD_LOGIC;
	 SIGNAL  n110i1l :	STD_LOGIC;
	 SIGNAL  n110i1O :	STD_LOGIC;
	 SIGNAL  n110iii :	STD_LOGIC;
	 SIGNAL  n110iil :	STD_LOGIC;
	 SIGNAL  n110iiO :	STD_LOGIC;
	 SIGNAL  n110ili :	STD_LOGIC;
	 SIGNAL  n110ill :	STD_LOGIC;
	 SIGNAL  n110ilO :	STD_LOGIC;
	 SIGNAL  n110iOi :	STD_LOGIC;
	 SIGNAL  n110iOl :	STD_LOGIC;
	 SIGNAL  n110iOO :	STD_LOGIC;
	 SIGNAL  n110l0i :	STD_LOGIC;
	 SIGNAL  n110l0l :	STD_LOGIC;
	 SIGNAL  n110l0O :	STD_LOGIC;
	 SIGNAL  n110l1i :	STD_LOGIC;
	 SIGNAL  n110l1l :	STD_LOGIC;
	 SIGNAL  n110l1O :	STD_LOGIC;
	 SIGNAL  n110lii :	STD_LOGIC;
	 SIGNAL  n110lil :	STD_LOGIC;
	 SIGNAL  n110liO :	STD_LOGIC;
	 SIGNAL  n110lli :	STD_LOGIC;
	 SIGNAL  n110lll :	STD_LOGIC;
	 SIGNAL  n110llO :	STD_LOGIC;
	 SIGNAL  n110lOi :	STD_LOGIC;
	 SIGNAL  n110lOl :	STD_LOGIC;
	 SIGNAL  n110lOO :	STD_LOGIC;
	 SIGNAL  n110O0i :	STD_LOGIC;
	 SIGNAL  n110O0l :	STD_LOGIC;
	 SIGNAL  n110O0O :	STD_LOGIC;
	 SIGNAL  n110O1i :	STD_LOGIC;
	 SIGNAL  n110O1l :	STD_LOGIC;
	 SIGNAL  n110O1O :	STD_LOGIC;
	 SIGNAL  n110Oii :	STD_LOGIC;
	 SIGNAL  n110Oil :	STD_LOGIC;
	 SIGNAL  n110OiO :	STD_LOGIC;
	 SIGNAL  n110Oli :	STD_LOGIC;
	 SIGNAL  n110Oll :	STD_LOGIC;
	 SIGNAL  n110OlO :	STD_LOGIC;
	 SIGNAL  n110OOi :	STD_LOGIC;
	 SIGNAL  n110OOl :	STD_LOGIC;
	 SIGNAL  n110OOO :	STD_LOGIC;
	 SIGNAL  n11100i :	STD_LOGIC;
	 SIGNAL  n11100l :	STD_LOGIC;
	 SIGNAL  n11100O :	STD_LOGIC;
	 SIGNAL  n11101i :	STD_LOGIC;
	 SIGNAL  n11101l :	STD_LOGIC;
	 SIGNAL  n11101O :	STD_LOGIC;
	 SIGNAL  n1110ii :	STD_LOGIC;
	 SIGNAL  n1110il :	STD_LOGIC;
	 SIGNAL  n1110iO :	STD_LOGIC;
	 SIGNAL  n1110li :	STD_LOGIC;
	 SIGNAL  n1110ll :	STD_LOGIC;
	 SIGNAL  n1110lO :	STD_LOGIC;
	 SIGNAL  n1110Oi :	STD_LOGIC;
	 SIGNAL  n1110Ol :	STD_LOGIC;
	 SIGNAL  n1110OO :	STD_LOGIC;
	 SIGNAL  n11110i :	STD_LOGIC;
	 SIGNAL  n11110l :	STD_LOGIC;
	 SIGNAL  n11110O :	STD_LOGIC;
	 SIGNAL  n11111i :	STD_LOGIC;
	 SIGNAL  n11111l :	STD_LOGIC;
	 SIGNAL  n11111O :	STD_LOGIC;
	 SIGNAL  n1111ii :	STD_LOGIC;
	 SIGNAL  n1111il :	STD_LOGIC;
	 SIGNAL  n1111iO :	STD_LOGIC;
	 SIGNAL  n1111li :	STD_LOGIC;
	 SIGNAL  n1111ll :	STD_LOGIC;
	 SIGNAL  n1111lO :	STD_LOGIC;
	 SIGNAL  n1111Oi :	STD_LOGIC;
	 SIGNAL  n1111Ol :	STD_LOGIC;
	 SIGNAL  n1111OO :	STD_LOGIC;
	 SIGNAL  n111i0i :	STD_LOGIC;
	 SIGNAL  n111i0l :	STD_LOGIC;
	 SIGNAL  n111i0O :	STD_LOGIC;
	 SIGNAL  n111i1i :	STD_LOGIC;
	 SIGNAL  n111i1l :	STD_LOGIC;
	 SIGNAL  n111i1O :	STD_LOGIC;
	 SIGNAL  n111iii :	STD_LOGIC;
	 SIGNAL  n111iil :	STD_LOGIC;
	 SIGNAL  n111iiO :	STD_LOGIC;
	 SIGNAL  n111ili :	STD_LOGIC;
	 SIGNAL  n111ill :	STD_LOGIC;
	 SIGNAL  n111ilO :	STD_LOGIC;
	 SIGNAL  n111iOi :	STD_LOGIC;
	 SIGNAL  n111iOl :	STD_LOGIC;
	 SIGNAL  n111iOO :	STD_LOGIC;
	 SIGNAL  n111l0i :	STD_LOGIC;
	 SIGNAL  n111l0l :	STD_LOGIC;
	 SIGNAL  n111l0O :	STD_LOGIC;
	 SIGNAL  n111l1i :	STD_LOGIC;
	 SIGNAL  n111l1l :	STD_LOGIC;
	 SIGNAL  n111l1O :	STD_LOGIC;
	 SIGNAL  n111lii :	STD_LOGIC;
	 SIGNAL  n111lil :	STD_LOGIC;
	 SIGNAL  n111liO :	STD_LOGIC;
	 SIGNAL  n111lli :	STD_LOGIC;
	 SIGNAL  n111lll :	STD_LOGIC;
	 SIGNAL  n111llO :	STD_LOGIC;
	 SIGNAL  n111lOi :	STD_LOGIC;
	 SIGNAL  n111lOl :	STD_LOGIC;
	 SIGNAL  n111lOO :	STD_LOGIC;
	 SIGNAL  n111O0i :	STD_LOGIC;
	 SIGNAL  n111O0l :	STD_LOGIC;
	 SIGNAL  n111O0O :	STD_LOGIC;
	 SIGNAL  n111O1i :	STD_LOGIC;
	 SIGNAL  n111O1l :	STD_LOGIC;
	 SIGNAL  n111O1O :	STD_LOGIC;
	 SIGNAL  n111Oii :	STD_LOGIC;
	 SIGNAL  n111Oil :	STD_LOGIC;
	 SIGNAL  n111OiO :	STD_LOGIC;
	 SIGNAL  n111Oli :	STD_LOGIC;
	 SIGNAL  n111Oll :	STD_LOGIC;
	 SIGNAL  n111OlO :	STD_LOGIC;
	 SIGNAL  n111OOi :	STD_LOGIC;
	 SIGNAL  n111OOl :	STD_LOGIC;
	 SIGNAL  n111OOO :	STD_LOGIC;
	 SIGNAL  n11i00i :	STD_LOGIC;
	 SIGNAL  n11i00l :	STD_LOGIC;
	 SIGNAL  n11i00O :	STD_LOGIC;
	 SIGNAL  n11i01i :	STD_LOGIC;
	 SIGNAL  n11i01l :	STD_LOGIC;
	 SIGNAL  n11i01O :	STD_LOGIC;
	 SIGNAL  n11i0ii :	STD_LOGIC;
	 SIGNAL  n11i0il :	STD_LOGIC;
	 SIGNAL  n11i0iO :	STD_LOGIC;
	 SIGNAL  n11i0li :	STD_LOGIC;
	 SIGNAL  n11i0ll :	STD_LOGIC;
	 SIGNAL  n11i0lO :	STD_LOGIC;
	 SIGNAL  n11i0Oi :	STD_LOGIC;
	 SIGNAL  n11i0Ol :	STD_LOGIC;
	 SIGNAL  n11i0OO :	STD_LOGIC;
	 SIGNAL  n11i10i :	STD_LOGIC;
	 SIGNAL  n11i10l :	STD_LOGIC;
	 SIGNAL  n11i10O :	STD_LOGIC;
	 SIGNAL  n11i11i :	STD_LOGIC;
	 SIGNAL  n11i11l :	STD_LOGIC;
	 SIGNAL  n11i11O :	STD_LOGIC;
	 SIGNAL  n11i1ii :	STD_LOGIC;
	 SIGNAL  n11i1il :	STD_LOGIC;
	 SIGNAL  n11i1iO :	STD_LOGIC;
	 SIGNAL  n11i1li :	STD_LOGIC;
	 SIGNAL  n11i1ll :	STD_LOGIC;
	 SIGNAL  n11i1lO :	STD_LOGIC;
	 SIGNAL  n11i1Oi :	STD_LOGIC;
	 SIGNAL  n11i1Ol :	STD_LOGIC;
	 SIGNAL  n11i1OO :	STD_LOGIC;
	 SIGNAL  n11ii0i :	STD_LOGIC;
	 SIGNAL  n11ii0l :	STD_LOGIC;
	 SIGNAL  n11ii0O :	STD_LOGIC;
	 SIGNAL  n11ii1i :	STD_LOGIC;
	 SIGNAL  n11ii1l :	STD_LOGIC;
	 SIGNAL  n11ii1O :	STD_LOGIC;
	 SIGNAL  n11iiii :	STD_LOGIC;
	 SIGNAL  n11iiil :	STD_LOGIC;
	 SIGNAL  n11iiiO :	STD_LOGIC;
	 SIGNAL  n11iili :	STD_LOGIC;
	 SIGNAL  n11iill :	STD_LOGIC;
	 SIGNAL  n11iilO :	STD_LOGIC;
	 SIGNAL  n11iiOi :	STD_LOGIC;
	 SIGNAL  n11iiOl :	STD_LOGIC;
	 SIGNAL  n11iiOO :	STD_LOGIC;
	 SIGNAL  n11il0i :	STD_LOGIC;
	 SIGNAL  n11il0l :	STD_LOGIC;
	 SIGNAL  n11il0O :	STD_LOGIC;
	 SIGNAL  n11il1i :	STD_LOGIC;
	 SIGNAL  n11il1l :	STD_LOGIC;
	 SIGNAL  n11il1O :	STD_LOGIC;
	 SIGNAL  n11ilii :	STD_LOGIC;
	 SIGNAL  n11ilil :	STD_LOGIC;
	 SIGNAL  n11iliO :	STD_LOGIC;
	 SIGNAL  n11illi :	STD_LOGIC;
	 SIGNAL  n11illl :	STD_LOGIC;
	 SIGNAL  n11illO :	STD_LOGIC;
	 SIGNAL  n11ilOi :	STD_LOGIC;
	 SIGNAL  n11ilOl :	STD_LOGIC;
	 SIGNAL  n11ilOO :	STD_LOGIC;
	 SIGNAL  n11iO0i :	STD_LOGIC;
	 SIGNAL  n11iO0l :	STD_LOGIC;
	 SIGNAL  n11iO0O :	STD_LOGIC;
	 SIGNAL  n11iO1i :	STD_LOGIC;
	 SIGNAL  n11iO1l :	STD_LOGIC;
	 SIGNAL  n11iO1O :	STD_LOGIC;
	 SIGNAL  n11iOii :	STD_LOGIC;
	 SIGNAL  n11iOil :	STD_LOGIC;
	 SIGNAL  n11iOiO :	STD_LOGIC;
	 SIGNAL  n11iOli :	STD_LOGIC;
	 SIGNAL  n11iOll :	STD_LOGIC;
	 SIGNAL  n11iOlO :	STD_LOGIC;
	 SIGNAL  n11iOOi :	STD_LOGIC;
	 SIGNAL  n11iOOl :	STD_LOGIC;
	 SIGNAL  n11iOOO :	STD_LOGIC;
	 SIGNAL  n11l00i :	STD_LOGIC;
	 SIGNAL  n11l00l :	STD_LOGIC;
	 SIGNAL  n11l00O :	STD_LOGIC;
	 SIGNAL  n11l01i :	STD_LOGIC;
	 SIGNAL  n11l01l :	STD_LOGIC;
	 SIGNAL  n11l01O :	STD_LOGIC;
	 SIGNAL  n11l0ii :	STD_LOGIC;
	 SIGNAL  n11l0il :	STD_LOGIC;
	 SIGNAL  n11l0iO :	STD_LOGIC;
	 SIGNAL  n11l0li :	STD_LOGIC;
	 SIGNAL  n11l0ll :	STD_LOGIC;
	 SIGNAL  n11l0lO :	STD_LOGIC;
	 SIGNAL  n11l0Oi :	STD_LOGIC;
	 SIGNAL  n11l0Ol :	STD_LOGIC;
	 SIGNAL  n11l0OO :	STD_LOGIC;
	 SIGNAL  n11l10i :	STD_LOGIC;
	 SIGNAL  n11l10l :	STD_LOGIC;
	 SIGNAL  n11l10O :	STD_LOGIC;
	 SIGNAL  n11l11i :	STD_LOGIC;
	 SIGNAL  n11l11l :	STD_LOGIC;
	 SIGNAL  n11l11O :	STD_LOGIC;
	 SIGNAL  n11l1ii :	STD_LOGIC;
	 SIGNAL  n11l1il :	STD_LOGIC;
	 SIGNAL  n11l1iO :	STD_LOGIC;
	 SIGNAL  n11l1li :	STD_LOGIC;
	 SIGNAL  n11l1ll :	STD_LOGIC;
	 SIGNAL  n11l1lO :	STD_LOGIC;
	 SIGNAL  n11l1Oi :	STD_LOGIC;
	 SIGNAL  n11l1Ol :	STD_LOGIC;
	 SIGNAL  n11l1OO :	STD_LOGIC;
	 SIGNAL  n11li0i :	STD_LOGIC;
	 SIGNAL  n11li0l :	STD_LOGIC;
	 SIGNAL  n11li0O :	STD_LOGIC;
	 SIGNAL  n11li1i :	STD_LOGIC;
	 SIGNAL  n11li1l :	STD_LOGIC;
	 SIGNAL  n11li1O :	STD_LOGIC;
	 SIGNAL  n11liii :	STD_LOGIC;
	 SIGNAL  n11liil :	STD_LOGIC;
	 SIGNAL  n11liiO :	STD_LOGIC;
	 SIGNAL  n11lili :	STD_LOGIC;
	 SIGNAL  n11lill :	STD_LOGIC;
	 SIGNAL  n11lilO :	STD_LOGIC;
	 SIGNAL  n11liOi :	STD_LOGIC;
	 SIGNAL  n11liOl :	STD_LOGIC;
	 SIGNAL  n11liOO :	STD_LOGIC;
	 SIGNAL  n11ll0i :	STD_LOGIC;
	 SIGNAL  n11ll0l :	STD_LOGIC;
	 SIGNAL  n11ll0O :	STD_LOGIC;
	 SIGNAL  n11ll1i :	STD_LOGIC;
	 SIGNAL  n11ll1l :	STD_LOGIC;
	 SIGNAL  n11ll1O :	STD_LOGIC;
	 SIGNAL  n11llii :	STD_LOGIC;
	 SIGNAL  n11llil :	STD_LOGIC;
	 SIGNAL  n11lliO :	STD_LOGIC;
	 SIGNAL  n11llli :	STD_LOGIC;
	 SIGNAL  n11llll :	STD_LOGIC;
	 SIGNAL  n11lllO :	STD_LOGIC;
	 SIGNAL  n11llOi :	STD_LOGIC;
	 SIGNAL  n11llOl :	STD_LOGIC;
	 SIGNAL  n11llOO :	STD_LOGIC;
	 SIGNAL  n11lO0i :	STD_LOGIC;
	 SIGNAL  n11lO0l :	STD_LOGIC;
	 SIGNAL  n11lO0O :	STD_LOGIC;
	 SIGNAL  n11lO1i :	STD_LOGIC;
	 SIGNAL  n11lO1l :	STD_LOGIC;
	 SIGNAL  n11lO1O :	STD_LOGIC;
	 SIGNAL  n11lOii :	STD_LOGIC;
	 SIGNAL  n11lOil :	STD_LOGIC;
	 SIGNAL  n11lOiO :	STD_LOGIC;
	 SIGNAL  n11lOli :	STD_LOGIC;
	 SIGNAL  n11lOll :	STD_LOGIC;
	 SIGNAL  n11lOlO :	STD_LOGIC;
	 SIGNAL  n11lOOi :	STD_LOGIC;
	 SIGNAL  n11lOOl :	STD_LOGIC;
	 SIGNAL  n11lOOO :	STD_LOGIC;
	 SIGNAL  n11O00i :	STD_LOGIC;
	 SIGNAL  n11O00l :	STD_LOGIC;
	 SIGNAL  n11O00O :	STD_LOGIC;
	 SIGNAL  n11O01i :	STD_LOGIC;
	 SIGNAL  n11O01l :	STD_LOGIC;
	 SIGNAL  n11O01O :	STD_LOGIC;
	 SIGNAL  n11O0ii :	STD_LOGIC;
	 SIGNAL  n11O0il :	STD_LOGIC;
	 SIGNAL  n11O0iO :	STD_LOGIC;
	 SIGNAL  n11O0li :	STD_LOGIC;
	 SIGNAL  n11O0ll :	STD_LOGIC;
	 SIGNAL  n11O0lO :	STD_LOGIC;
	 SIGNAL  n11O0Oi :	STD_LOGIC;
	 SIGNAL  n11O0Ol :	STD_LOGIC;
	 SIGNAL  n11O0OO :	STD_LOGIC;
	 SIGNAL  n11O10i :	STD_LOGIC;
	 SIGNAL  n11O10l :	STD_LOGIC;
	 SIGNAL  n11O10O :	STD_LOGIC;
	 SIGNAL  n11O11i :	STD_LOGIC;
	 SIGNAL  n11O11l :	STD_LOGIC;
	 SIGNAL  n11O11O :	STD_LOGIC;
	 SIGNAL  n11O1ii :	STD_LOGIC;
	 SIGNAL  n11O1il :	STD_LOGIC;
	 SIGNAL  n11O1iO :	STD_LOGIC;
	 SIGNAL  n11O1li :	STD_LOGIC;
	 SIGNAL  n11O1ll :	STD_LOGIC;
	 SIGNAL  n11O1lO :	STD_LOGIC;
	 SIGNAL  n11O1Oi :	STD_LOGIC;
	 SIGNAL  n11O1Ol :	STD_LOGIC;
	 SIGNAL  n11O1OO :	STD_LOGIC;
	 SIGNAL  n11Oi0i :	STD_LOGIC;
	 SIGNAL  n11Oi0l :	STD_LOGIC;
	 SIGNAL  n11Oi0O :	STD_LOGIC;
	 SIGNAL  n11Oi1i :	STD_LOGIC;
	 SIGNAL  n11Oi1l :	STD_LOGIC;
	 SIGNAL  n11Oi1O :	STD_LOGIC;
	 SIGNAL  n11Oiii :	STD_LOGIC;
	 SIGNAL  n11Oiil :	STD_LOGIC;
	 SIGNAL  n11OiiO :	STD_LOGIC;
	 SIGNAL  n11Oili :	STD_LOGIC;
	 SIGNAL  n11Oill :	STD_LOGIC;
	 SIGNAL  n11OilO :	STD_LOGIC;
	 SIGNAL  n11OiOi :	STD_LOGIC;
	 SIGNAL  n11OiOl :	STD_LOGIC;
	 SIGNAL  n11OiOO :	STD_LOGIC;
	 SIGNAL  n11Ol0i :	STD_LOGIC;
	 SIGNAL  n11Ol0l :	STD_LOGIC;
	 SIGNAL  n11Ol0O :	STD_LOGIC;
	 SIGNAL  n11Ol1i :	STD_LOGIC;
	 SIGNAL  n11Ol1l :	STD_LOGIC;
	 SIGNAL  n11Ol1O :	STD_LOGIC;
	 SIGNAL  n11Olii :	STD_LOGIC;
	 SIGNAL  n11Olil :	STD_LOGIC;
	 SIGNAL  n11OliO :	STD_LOGIC;
	 SIGNAL  n11Olli :	STD_LOGIC;
	 SIGNAL  n11Olll :	STD_LOGIC;
	 SIGNAL  n11OllO :	STD_LOGIC;
	 SIGNAL  n11OlOi :	STD_LOGIC;
	 SIGNAL  n11OlOl :	STD_LOGIC;
	 SIGNAL  n11OlOO :	STD_LOGIC;
	 SIGNAL  n11OO0i :	STD_LOGIC;
	 SIGNAL  n11OO0l :	STD_LOGIC;
	 SIGNAL  n11OO0O :	STD_LOGIC;
	 SIGNAL  n11OO1i :	STD_LOGIC;
	 SIGNAL  n11OO1l :	STD_LOGIC;
	 SIGNAL  n11OO1O :	STD_LOGIC;
	 SIGNAL  n11OOii :	STD_LOGIC;
	 SIGNAL  n11OOil :	STD_LOGIC;
	 SIGNAL  n11OOiO :	STD_LOGIC;
	 SIGNAL  n11OOli :	STD_LOGIC;
	 SIGNAL  n11OOll :	STD_LOGIC;
	 SIGNAL  n11OOlO :	STD_LOGIC;
	 SIGNAL  n11OOOi :	STD_LOGIC;
	 SIGNAL  n11OOOl :	STD_LOGIC;
	 SIGNAL  n11OOOO :	STD_LOGIC;
	 SIGNAL  n1i000i :	STD_LOGIC;
	 SIGNAL  n1i000l :	STD_LOGIC;
	 SIGNAL  n1i000O :	STD_LOGIC;
	 SIGNAL  n1i001i :	STD_LOGIC;
	 SIGNAL  n1i001l :	STD_LOGIC;
	 SIGNAL  n1i001O :	STD_LOGIC;
	 SIGNAL  n1i00ii :	STD_LOGIC;
	 SIGNAL  n1i00il :	STD_LOGIC;
	 SIGNAL  n1i00iO :	STD_LOGIC;
	 SIGNAL  n1i00li :	STD_LOGIC;
	 SIGNAL  n1i00ll :	STD_LOGIC;
	 SIGNAL  n1i00lO :	STD_LOGIC;
	 SIGNAL  n1i00Oi :	STD_LOGIC;
	 SIGNAL  n1i00Ol :	STD_LOGIC;
	 SIGNAL  n1i010i :	STD_LOGIC;
	 SIGNAL  n1i010l :	STD_LOGIC;
	 SIGNAL  n1i010O :	STD_LOGIC;
	 SIGNAL  n1i011i :	STD_LOGIC;
	 SIGNAL  n1i011l :	STD_LOGIC;
	 SIGNAL  n1i011O :	STD_LOGIC;
	 SIGNAL  n1i01ii :	STD_LOGIC;
	 SIGNAL  n1i01il :	STD_LOGIC;
	 SIGNAL  n1i01iO :	STD_LOGIC;
	 SIGNAL  n1i01li :	STD_LOGIC;
	 SIGNAL  n1i01ll :	STD_LOGIC;
	 SIGNAL  n1i01lO :	STD_LOGIC;
	 SIGNAL  n1i01Oi :	STD_LOGIC;
	 SIGNAL  n1i01Ol :	STD_LOGIC;
	 SIGNAL  n1i01OO :	STD_LOGIC;
	 SIGNAL  n1i0i0i :	STD_LOGIC;
	 SIGNAL  n1i0i0l :	STD_LOGIC;
	 SIGNAL  n1i0i0O :	STD_LOGIC;
	 SIGNAL  n1i0i1i :	STD_LOGIC;
	 SIGNAL  n1i0i1l :	STD_LOGIC;
	 SIGNAL  n1i0i1O :	STD_LOGIC;
	 SIGNAL  n1i0iii :	STD_LOGIC;
	 SIGNAL  n1i0iil :	STD_LOGIC;
	 SIGNAL  n1i0iiO :	STD_LOGIC;
	 SIGNAL  n1i0ili :	STD_LOGIC;
	 SIGNAL  n1i0ill :	STD_LOGIC;
	 SIGNAL  n1i0ilO :	STD_LOGIC;
	 SIGNAL  n1i0iOi :	STD_LOGIC;
	 SIGNAL  n1i0iOl :	STD_LOGIC;
	 SIGNAL  n1i0iOO :	STD_LOGIC;
	 SIGNAL  n1i0l0i :	STD_LOGIC;
	 SIGNAL  n1i0l0l :	STD_LOGIC;
	 SIGNAL  n1i0l0O :	STD_LOGIC;
	 SIGNAL  n1i0l1i :	STD_LOGIC;
	 SIGNAL  n1i0l1l :	STD_LOGIC;
	 SIGNAL  n1i0l1O :	STD_LOGIC;
	 SIGNAL  n1i0lii :	STD_LOGIC;
	 SIGNAL  n1i0lil :	STD_LOGIC;
	 SIGNAL  n1i0liO :	STD_LOGIC;
	 SIGNAL  n1i0lli :	STD_LOGIC;
	 SIGNAL  n1i0lll :	STD_LOGIC;
	 SIGNAL  n1i0llO :	STD_LOGIC;
	 SIGNAL  n1i0lOO :	STD_LOGIC;
	 SIGNAL  n1i0O0O :	STD_LOGIC;
	 SIGNAL  n1i0O1i :	STD_LOGIC;
	 SIGNAL  n1i0Oii :	STD_LOGIC;
	 SIGNAL  n1i100i :	STD_LOGIC;
	 SIGNAL  n1i100l :	STD_LOGIC;
	 SIGNAL  n1i100O :	STD_LOGIC;
	 SIGNAL  n1i101i :	STD_LOGIC;
	 SIGNAL  n1i101l :	STD_LOGIC;
	 SIGNAL  n1i101O :	STD_LOGIC;
	 SIGNAL  n1i10ii :	STD_LOGIC;
	 SIGNAL  n1i10il :	STD_LOGIC;
	 SIGNAL  n1i10iO :	STD_LOGIC;
	 SIGNAL  n1i10li :	STD_LOGIC;
	 SIGNAL  n1i10ll :	STD_LOGIC;
	 SIGNAL  n1i10lO :	STD_LOGIC;
	 SIGNAL  n1i10Oi :	STD_LOGIC;
	 SIGNAL  n1i10Ol :	STD_LOGIC;
	 SIGNAL  n1i10OO :	STD_LOGIC;
	 SIGNAL  n1i110i :	STD_LOGIC;
	 SIGNAL  n1i110l :	STD_LOGIC;
	 SIGNAL  n1i110O :	STD_LOGIC;
	 SIGNAL  n1i111i :	STD_LOGIC;
	 SIGNAL  n1i111l :	STD_LOGIC;
	 SIGNAL  n1i111O :	STD_LOGIC;
	 SIGNAL  n1i11ii :	STD_LOGIC;
	 SIGNAL  n1i11il :	STD_LOGIC;
	 SIGNAL  n1i11iO :	STD_LOGIC;
	 SIGNAL  n1i11li :	STD_LOGIC;
	 SIGNAL  n1i11ll :	STD_LOGIC;
	 SIGNAL  n1i11lO :	STD_LOGIC;
	 SIGNAL  n1i11Oi :	STD_LOGIC;
	 SIGNAL  n1i11Ol :	STD_LOGIC;
	 SIGNAL  n1i11OO :	STD_LOGIC;
	 SIGNAL  n1i1i0i :	STD_LOGIC;
	 SIGNAL  n1i1i0l :	STD_LOGIC;
	 SIGNAL  n1i1i0O :	STD_LOGIC;
	 SIGNAL  n1i1i1i :	STD_LOGIC;
	 SIGNAL  n1i1i1l :	STD_LOGIC;
	 SIGNAL  n1i1i1O :	STD_LOGIC;
	 SIGNAL  n1i1iii :	STD_LOGIC;
	 SIGNAL  n1i1iil :	STD_LOGIC;
	 SIGNAL  n1i1iiO :	STD_LOGIC;
	 SIGNAL  n1i1ili :	STD_LOGIC;
	 SIGNAL  n1i1ill :	STD_LOGIC;
	 SIGNAL  n1i1ilO :	STD_LOGIC;
	 SIGNAL  n1i1iOi :	STD_LOGIC;
	 SIGNAL  n1i1iOl :	STD_LOGIC;
	 SIGNAL  n1i1iOO :	STD_LOGIC;
	 SIGNAL  n1i1l0i :	STD_LOGIC;
	 SIGNAL  n1i1l0l :	STD_LOGIC;
	 SIGNAL  n1i1l0O :	STD_LOGIC;
	 SIGNAL  n1i1l1i :	STD_LOGIC;
	 SIGNAL  n1i1l1l :	STD_LOGIC;
	 SIGNAL  n1i1l1O :	STD_LOGIC;
	 SIGNAL  n1i1lii :	STD_LOGIC;
	 SIGNAL  n1i1lil :	STD_LOGIC;
	 SIGNAL  n1i1liO :	STD_LOGIC;
	 SIGNAL  n1i1lli :	STD_LOGIC;
	 SIGNAL  n1i1lll :	STD_LOGIC;
	 SIGNAL  n1i1llO :	STD_LOGIC;
	 SIGNAL  n1i1lOi :	STD_LOGIC;
	 SIGNAL  n1i1lOl :	STD_LOGIC;
	 SIGNAL  n1i1lOO :	STD_LOGIC;
	 SIGNAL  n1i1O0i :	STD_LOGIC;
	 SIGNAL  n1i1O0l :	STD_LOGIC;
	 SIGNAL  n1i1O0O :	STD_LOGIC;
	 SIGNAL  n1i1O1i :	STD_LOGIC;
	 SIGNAL  n1i1O1l :	STD_LOGIC;
	 SIGNAL  n1i1O1O :	STD_LOGIC;
	 SIGNAL  n1i1Oii :	STD_LOGIC;
	 SIGNAL  n1i1Oil :	STD_LOGIC;
	 SIGNAL  n1i1OiO :	STD_LOGIC;
	 SIGNAL  n1i1Oli :	STD_LOGIC;
	 SIGNAL  n1i1Oll :	STD_LOGIC;
	 SIGNAL  n1i1OlO :	STD_LOGIC;
	 SIGNAL  n1i1OOi :	STD_LOGIC;
	 SIGNAL  n1i1OOl :	STD_LOGIC;
	 SIGNAL  n1i1OOO :	STD_LOGIC;
	 SIGNAL  n1ii00i :	STD_LOGIC;
	 SIGNAL  n1ii00l :	STD_LOGIC;
	 SIGNAL  n1ii01i :	STD_LOGIC;
	 SIGNAL  n1ii01l :	STD_LOGIC;
	 SIGNAL  n1ii01O :	STD_LOGIC;
	 SIGNAL  n1ii0iO :	STD_LOGIC;
	 SIGNAL  n1ii0li :	STD_LOGIC;
	 SIGNAL  n1ii0Oi :	STD_LOGIC;
	 SIGNAL  n1ii0Ol :	STD_LOGIC;
	 SIGNAL  n1ii10i :	STD_LOGIC;
	 SIGNAL  n1ii10O :	STD_LOGIC;
	 SIGNAL  n1ii11i :	STD_LOGIC;
	 SIGNAL  n1ii11l :	STD_LOGIC;
	 SIGNAL  n1ii11O :	STD_LOGIC;
	 SIGNAL  n1ii1lO :	STD_LOGIC;
	 SIGNAL  n1ii1OO :	STD_LOGIC;
	 SIGNAL  n1iii1i :	STD_LOGIC;
	 SIGNAL  n1iii1l :	STD_LOGIC;
	 SIGNAL  n1iii1O :	STD_LOGIC;
	 SIGNAL  n1iiili :	STD_LOGIC;
	 SIGNAL  n1iiill :	STD_LOGIC;
	 SIGNAL  n1iiilO :	STD_LOGIC;
	 SIGNAL  n1iiiOi :	STD_LOGIC;
	 SIGNAL  n1iil0i :	STD_LOGIC;
	 SIGNAL  nlOO000i :	STD_LOGIC;
	 SIGNAL  nlOO000l :	STD_LOGIC;
	 SIGNAL  nlOO000O :	STD_LOGIC;
	 SIGNAL  nlOO001i :	STD_LOGIC;
	 SIGNAL  nlOO001l :	STD_LOGIC;
	 SIGNAL  nlOO001O :	STD_LOGIC;
	 SIGNAL  nlOO00ii :	STD_LOGIC;
	 SIGNAL  nlOO00il :	STD_LOGIC;
	 SIGNAL  nlOO00iO :	STD_LOGIC;
	 SIGNAL  nlOO00li :	STD_LOGIC;
	 SIGNAL  nlOO00ll :	STD_LOGIC;
	 SIGNAL  nlOO00lO :	STD_LOGIC;
	 SIGNAL  nlOO00Oi :	STD_LOGIC;
	 SIGNAL  nlOO00Ol :	STD_LOGIC;
	 SIGNAL  nlOO00OO :	STD_LOGIC;
	 SIGNAL  nlOO010i :	STD_LOGIC;
	 SIGNAL  nlOO010l :	STD_LOGIC;
	 SIGNAL  nlOO010O :	STD_LOGIC;
	 SIGNAL  nlOO011i :	STD_LOGIC;
	 SIGNAL  nlOO011l :	STD_LOGIC;
	 SIGNAL  nlOO011O :	STD_LOGIC;
	 SIGNAL  nlOO01ii :	STD_LOGIC;
	 SIGNAL  nlOO01il :	STD_LOGIC;
	 SIGNAL  nlOO01iO :	STD_LOGIC;
	 SIGNAL  nlOO01li :	STD_LOGIC;
	 SIGNAL  nlOO01ll :	STD_LOGIC;
	 SIGNAL  nlOO01lO :	STD_LOGIC;
	 SIGNAL  nlOO01Oi :	STD_LOGIC;
	 SIGNAL  nlOO01Ol :	STD_LOGIC;
	 SIGNAL  nlOO01OO :	STD_LOGIC;
	 SIGNAL  nlOO0i0i :	STD_LOGIC;
	 SIGNAL  nlOO0i0l :	STD_LOGIC;
	 SIGNAL  nlOO0i0O :	STD_LOGIC;
	 SIGNAL  nlOO0i1i :	STD_LOGIC;
	 SIGNAL  nlOO0i1l :	STD_LOGIC;
	 SIGNAL  nlOO0i1O :	STD_LOGIC;
	 SIGNAL  nlOO0iii :	STD_LOGIC;
	 SIGNAL  nlOO0iil :	STD_LOGIC;
	 SIGNAL  nlOO0iiO :	STD_LOGIC;
	 SIGNAL  nlOO0ili :	STD_LOGIC;
	 SIGNAL  nlOO0ill :	STD_LOGIC;
	 SIGNAL  nlOO0ilO :	STD_LOGIC;
	 SIGNAL  nlOO0iOi :	STD_LOGIC;
	 SIGNAL  nlOO0iOl :	STD_LOGIC;
	 SIGNAL  nlOO0iOO :	STD_LOGIC;
	 SIGNAL  nlOO0l0i :	STD_LOGIC;
	 SIGNAL  nlOO0l0l :	STD_LOGIC;
	 SIGNAL  nlOO0l0O :	STD_LOGIC;
	 SIGNAL  nlOO0l1i :	STD_LOGIC;
	 SIGNAL  nlOO0l1l :	STD_LOGIC;
	 SIGNAL  nlOO0l1O :	STD_LOGIC;
	 SIGNAL  nlOO0lii :	STD_LOGIC;
	 SIGNAL  nlOO0lil :	STD_LOGIC;
	 SIGNAL  nlOO0liO :	STD_LOGIC;
	 SIGNAL  nlOO0lli :	STD_LOGIC;
	 SIGNAL  nlOO0lll :	STD_LOGIC;
	 SIGNAL  nlOO0llO :	STD_LOGIC;
	 SIGNAL  nlOO0lOi :	STD_LOGIC;
	 SIGNAL  nlOO0lOl :	STD_LOGIC;
	 SIGNAL  nlOO0lOO :	STD_LOGIC;
	 SIGNAL  nlOO0O0i :	STD_LOGIC;
	 SIGNAL  nlOO0O0l :	STD_LOGIC;
	 SIGNAL  nlOO0O0O :	STD_LOGIC;
	 SIGNAL  nlOO0O1i :	STD_LOGIC;
	 SIGNAL  nlOO0O1l :	STD_LOGIC;
	 SIGNAL  nlOO0O1O :	STD_LOGIC;
	 SIGNAL  nlOO0Oii :	STD_LOGIC;
	 SIGNAL  nlOO0Oil :	STD_LOGIC;
	 SIGNAL  nlOO0OiO :	STD_LOGIC;
	 SIGNAL  nlOO0Oli :	STD_LOGIC;
	 SIGNAL  nlOO0Oll :	STD_LOGIC;
	 SIGNAL  nlOO0OlO :	STD_LOGIC;
	 SIGNAL  nlOO0OOi :	STD_LOGIC;
	 SIGNAL  nlOO0OOl :	STD_LOGIC;
	 SIGNAL  nlOO0OOO :	STD_LOGIC;
	 SIGNAL  nlOO1iOl :	STD_LOGIC;
	 SIGNAL  nlOO1iOO :	STD_LOGIC;
	 SIGNAL  nlOO1l0i :	STD_LOGIC;
	 SIGNAL  nlOO1l0l :	STD_LOGIC;
	 SIGNAL  nlOO1l0O :	STD_LOGIC;
	 SIGNAL  nlOO1l1i :	STD_LOGIC;
	 SIGNAL  nlOO1l1l :	STD_LOGIC;
	 SIGNAL  nlOO1l1O :	STD_LOGIC;
	 SIGNAL  nlOO1lii :	STD_LOGIC;
	 SIGNAL  nlOO1lil :	STD_LOGIC;
	 SIGNAL  nlOO1liO :	STD_LOGIC;
	 SIGNAL  nlOO1lli :	STD_LOGIC;
	 SIGNAL  nlOO1lll :	STD_LOGIC;
	 SIGNAL  nlOO1llO :	STD_LOGIC;
	 SIGNAL  nlOO1lOi :	STD_LOGIC;
	 SIGNAL  nlOO1lOl :	STD_LOGIC;
	 SIGNAL  nlOO1lOO :	STD_LOGIC;
	 SIGNAL  nlOO1O0i :	STD_LOGIC;
	 SIGNAL  nlOO1O0l :	STD_LOGIC;
	 SIGNAL  nlOO1O0O :	STD_LOGIC;
	 SIGNAL  nlOO1O1i :	STD_LOGIC;
	 SIGNAL  nlOO1O1l :	STD_LOGIC;
	 SIGNAL  nlOO1O1O :	STD_LOGIC;
	 SIGNAL  nlOO1Oii :	STD_LOGIC;
	 SIGNAL  nlOO1Oil :	STD_LOGIC;
	 SIGNAL  nlOO1OiO :	STD_LOGIC;
	 SIGNAL  nlOO1Oli :	STD_LOGIC;
	 SIGNAL  nlOO1Oll :	STD_LOGIC;
	 SIGNAL  nlOO1OlO :	STD_LOGIC;
	 SIGNAL  nlOO1OOi :	STD_LOGIC;
	 SIGNAL  nlOO1OOl :	STD_LOGIC;
	 SIGNAL  nlOO1OOO :	STD_LOGIC;
	 SIGNAL  nlOOi00i :	STD_LOGIC;
	 SIGNAL  nlOOi00l :	STD_LOGIC;
	 SIGNAL  nlOOi00O :	STD_LOGIC;
	 SIGNAL  nlOOi01i :	STD_LOGIC;
	 SIGNAL  nlOOi01l :	STD_LOGIC;
	 SIGNAL  nlOOi01O :	STD_LOGIC;
	 SIGNAL  nlOOi0ii :	STD_LOGIC;
	 SIGNAL  nlOOi0il :	STD_LOGIC;
	 SIGNAL  nlOOi0iO :	STD_LOGIC;
	 SIGNAL  nlOOi0li :	STD_LOGIC;
	 SIGNAL  nlOOi0ll :	STD_LOGIC;
	 SIGNAL  nlOOi0lO :	STD_LOGIC;
	 SIGNAL  nlOOi0Oi :	STD_LOGIC;
	 SIGNAL  nlOOi0Ol :	STD_LOGIC;
	 SIGNAL  nlOOi0OO :	STD_LOGIC;
	 SIGNAL  nlOOi10i :	STD_LOGIC;
	 SIGNAL  nlOOi10l :	STD_LOGIC;
	 SIGNAL  nlOOi10O :	STD_LOGIC;
	 SIGNAL  nlOOi11i :	STD_LOGIC;
	 SIGNAL  nlOOi11l :	STD_LOGIC;
	 SIGNAL  nlOOi11O :	STD_LOGIC;
	 SIGNAL  nlOOi1ii :	STD_LOGIC;
	 SIGNAL  nlOOi1il :	STD_LOGIC;
	 SIGNAL  nlOOi1iO :	STD_LOGIC;
	 SIGNAL  nlOOi1li :	STD_LOGIC;
	 SIGNAL  nlOOi1ll :	STD_LOGIC;
	 SIGNAL  nlOOi1lO :	STD_LOGIC;
	 SIGNAL  nlOOi1Oi :	STD_LOGIC;
	 SIGNAL  nlOOi1Ol :	STD_LOGIC;
	 SIGNAL  nlOOi1OO :	STD_LOGIC;
	 SIGNAL  nlOOii0i :	STD_LOGIC;
	 SIGNAL  nlOOii0l :	STD_LOGIC;
	 SIGNAL  nlOOii0O :	STD_LOGIC;
	 SIGNAL  nlOOii1i :	STD_LOGIC;
	 SIGNAL  nlOOii1l :	STD_LOGIC;
	 SIGNAL  nlOOii1O :	STD_LOGIC;
	 SIGNAL  nlOOiiii :	STD_LOGIC;
	 SIGNAL  nlOOiiil :	STD_LOGIC;
	 SIGNAL  nlOOiiiO :	STD_LOGIC;
	 SIGNAL  nlOOiili :	STD_LOGIC;
	 SIGNAL  nlOOiill :	STD_LOGIC;
	 SIGNAL  nlOOiilO :	STD_LOGIC;
	 SIGNAL  nlOOiiOi :	STD_LOGIC;
	 SIGNAL  nlOOiiOl :	STD_LOGIC;
	 SIGNAL  nlOOiiOO :	STD_LOGIC;
	 SIGNAL  nlOOil0i :	STD_LOGIC;
	 SIGNAL  nlOOil0l :	STD_LOGIC;
	 SIGNAL  nlOOil0O :	STD_LOGIC;
	 SIGNAL  nlOOil1i :	STD_LOGIC;
	 SIGNAL  nlOOil1l :	STD_LOGIC;
	 SIGNAL  nlOOil1O :	STD_LOGIC;
	 SIGNAL  nlOOilii :	STD_LOGIC;
	 SIGNAL  nlOOilil :	STD_LOGIC;
	 SIGNAL  nlOOiliO :	STD_LOGIC;
	 SIGNAL  nlOOilli :	STD_LOGIC;
	 SIGNAL  nlOOilll :	STD_LOGIC;
	 SIGNAL  nlOOillO :	STD_LOGIC;
	 SIGNAL  nlOOilOi :	STD_LOGIC;
	 SIGNAL  nlOOilOl :	STD_LOGIC;
	 SIGNAL  nlOOilOO :	STD_LOGIC;
	 SIGNAL  nlOOiO0i :	STD_LOGIC;
	 SIGNAL  nlOOiO0l :	STD_LOGIC;
	 SIGNAL  nlOOiO0O :	STD_LOGIC;
	 SIGNAL  nlOOiO1i :	STD_LOGIC;
	 SIGNAL  nlOOiO1l :	STD_LOGIC;
	 SIGNAL  nlOOiO1O :	STD_LOGIC;
	 SIGNAL  nlOOiOii :	STD_LOGIC;
	 SIGNAL  nlOOiOil :	STD_LOGIC;
	 SIGNAL  nlOOiOiO :	STD_LOGIC;
	 SIGNAL  nlOOiOli :	STD_LOGIC;
	 SIGNAL  nlOOiOll :	STD_LOGIC;
	 SIGNAL  nlOOiOlO :	STD_LOGIC;
	 SIGNAL  nlOOiOOi :	STD_LOGIC;
	 SIGNAL  nlOOiOOl :	STD_LOGIC;
	 SIGNAL  nlOOiOOO :	STD_LOGIC;
	 SIGNAL  nlOOl00i :	STD_LOGIC;
	 SIGNAL  nlOOl00l :	STD_LOGIC;
	 SIGNAL  nlOOl00O :	STD_LOGIC;
	 SIGNAL  nlOOl01i :	STD_LOGIC;
	 SIGNAL  nlOOl01l :	STD_LOGIC;
	 SIGNAL  nlOOl01O :	STD_LOGIC;
	 SIGNAL  nlOOl0ii :	STD_LOGIC;
	 SIGNAL  nlOOl0il :	STD_LOGIC;
	 SIGNAL  nlOOl0iO :	STD_LOGIC;
	 SIGNAL  nlOOl0li :	STD_LOGIC;
	 SIGNAL  nlOOl0ll :	STD_LOGIC;
	 SIGNAL  nlOOl0lO :	STD_LOGIC;
	 SIGNAL  nlOOl0Oi :	STD_LOGIC;
	 SIGNAL  nlOOl0Ol :	STD_LOGIC;
	 SIGNAL  nlOOl0OO :	STD_LOGIC;
	 SIGNAL  nlOOl10i :	STD_LOGIC;
	 SIGNAL  nlOOl10l :	STD_LOGIC;
	 SIGNAL  nlOOl10O :	STD_LOGIC;
	 SIGNAL  nlOOl11i :	STD_LOGIC;
	 SIGNAL  nlOOl11l :	STD_LOGIC;
	 SIGNAL  nlOOl11O :	STD_LOGIC;
	 SIGNAL  nlOOl1ii :	STD_LOGIC;
	 SIGNAL  nlOOl1il :	STD_LOGIC;
	 SIGNAL  nlOOl1iO :	STD_LOGIC;
	 SIGNAL  nlOOl1li :	STD_LOGIC;
	 SIGNAL  nlOOl1ll :	STD_LOGIC;
	 SIGNAL  nlOOl1lO :	STD_LOGIC;
	 SIGNAL  nlOOl1Oi :	STD_LOGIC;
	 SIGNAL  nlOOl1Ol :	STD_LOGIC;
	 SIGNAL  nlOOl1OO :	STD_LOGIC;
	 SIGNAL  nlOOli0i :	STD_LOGIC;
	 SIGNAL  nlOOli0l :	STD_LOGIC;
	 SIGNAL  nlOOli0O :	STD_LOGIC;
	 SIGNAL  nlOOli1i :	STD_LOGIC;
	 SIGNAL  nlOOli1l :	STD_LOGIC;
	 SIGNAL  nlOOli1O :	STD_LOGIC;
	 SIGNAL  nlOOliii :	STD_LOGIC;
	 SIGNAL  nlOOliil :	STD_LOGIC;
	 SIGNAL  nlOOliiO :	STD_LOGIC;
	 SIGNAL  nlOOlili :	STD_LOGIC;
	 SIGNAL  nlOOlill :	STD_LOGIC;
	 SIGNAL  nlOOlilO :	STD_LOGIC;
	 SIGNAL  nlOOliOi :	STD_LOGIC;
	 SIGNAL  nlOOliOl :	STD_LOGIC;
	 SIGNAL  nlOOliOO :	STD_LOGIC;
	 SIGNAL  nlOOll0i :	STD_LOGIC;
	 SIGNAL  nlOOll0l :	STD_LOGIC;
	 SIGNAL  nlOOll0O :	STD_LOGIC;
	 SIGNAL  nlOOll1i :	STD_LOGIC;
	 SIGNAL  nlOOll1l :	STD_LOGIC;
	 SIGNAL  nlOOll1O :	STD_LOGIC;
	 SIGNAL  nlOOllii :	STD_LOGIC;
	 SIGNAL  nlOOllil :	STD_LOGIC;
	 SIGNAL  nlOOlliO :	STD_LOGIC;
	 SIGNAL  nlOOllli :	STD_LOGIC;
	 SIGNAL  nlOOllll :	STD_LOGIC;
	 SIGNAL  nlOOlllO :	STD_LOGIC;
	 SIGNAL  nlOOllOi :	STD_LOGIC;
	 SIGNAL  nlOOllOl :	STD_LOGIC;
	 SIGNAL  nlOOllOO :	STD_LOGIC;
	 SIGNAL  nlOOlO0i :	STD_LOGIC;
	 SIGNAL  nlOOlO0l :	STD_LOGIC;
	 SIGNAL  nlOOlO0O :	STD_LOGIC;
	 SIGNAL  nlOOlO1i :	STD_LOGIC;
	 SIGNAL  nlOOlO1l :	STD_LOGIC;
	 SIGNAL  nlOOlO1O :	STD_LOGIC;
	 SIGNAL  nlOOlOii :	STD_LOGIC;
	 SIGNAL  nlOOlOil :	STD_LOGIC;
	 SIGNAL  nlOOlOiO :	STD_LOGIC;
	 SIGNAL  nlOOlOli :	STD_LOGIC;
	 SIGNAL  nlOOlOll :	STD_LOGIC;
	 SIGNAL  nlOOlOlO :	STD_LOGIC;
	 SIGNAL  nlOOlOOi :	STD_LOGIC;
	 SIGNAL  nlOOlOOl :	STD_LOGIC;
	 SIGNAL  nlOOlOOO :	STD_LOGIC;
	 SIGNAL  nlOOO00i :	STD_LOGIC;
	 SIGNAL  nlOOO00l :	STD_LOGIC;
	 SIGNAL  nlOOO00O :	STD_LOGIC;
	 SIGNAL  nlOOO01i :	STD_LOGIC;
	 SIGNAL  nlOOO01l :	STD_LOGIC;
	 SIGNAL  nlOOO01O :	STD_LOGIC;
	 SIGNAL  nlOOO0ii :	STD_LOGIC;
	 SIGNAL  nlOOO0il :	STD_LOGIC;
	 SIGNAL  nlOOO0iO :	STD_LOGIC;
	 SIGNAL  nlOOO0li :	STD_LOGIC;
	 SIGNAL  nlOOO0ll :	STD_LOGIC;
	 SIGNAL  nlOOO0lO :	STD_LOGIC;
	 SIGNAL  nlOOO0Oi :	STD_LOGIC;
	 SIGNAL  nlOOO0Ol :	STD_LOGIC;
	 SIGNAL  nlOOO0OO :	STD_LOGIC;
	 SIGNAL  nlOOO10i :	STD_LOGIC;
	 SIGNAL  nlOOO10l :	STD_LOGIC;
	 SIGNAL  nlOOO10O :	STD_LOGIC;
	 SIGNAL  nlOOO11i :	STD_LOGIC;
	 SIGNAL  nlOOO11l :	STD_LOGIC;
	 SIGNAL  nlOOO11O :	STD_LOGIC;
	 SIGNAL  nlOOO1ii :	STD_LOGIC;
	 SIGNAL  nlOOO1il :	STD_LOGIC;
	 SIGNAL  nlOOO1iO :	STD_LOGIC;
	 SIGNAL  nlOOO1li :	STD_LOGIC;
	 SIGNAL  nlOOO1ll :	STD_LOGIC;
	 SIGNAL  nlOOO1lO :	STD_LOGIC;
	 SIGNAL  nlOOO1Oi :	STD_LOGIC;
	 SIGNAL  nlOOO1Ol :	STD_LOGIC;
	 SIGNAL  nlOOO1OO :	STD_LOGIC;
	 SIGNAL  nlOOOi0i :	STD_LOGIC;
	 SIGNAL  nlOOOi0l :	STD_LOGIC;
	 SIGNAL  nlOOOi0O :	STD_LOGIC;
	 SIGNAL  nlOOOi1i :	STD_LOGIC;
	 SIGNAL  nlOOOi1l :	STD_LOGIC;
	 SIGNAL  nlOOOi1O :	STD_LOGIC;
	 SIGNAL  nlOOOiii :	STD_LOGIC;
	 SIGNAL  nlOOOiil :	STD_LOGIC;
	 SIGNAL  nlOOOiiO :	STD_LOGIC;
	 SIGNAL  nlOOOili :	STD_LOGIC;
	 SIGNAL  nlOOOill :	STD_LOGIC;
	 SIGNAL  nlOOOilO :	STD_LOGIC;
	 SIGNAL  nlOOOiOi :	STD_LOGIC;
	 SIGNAL  nlOOOiOl :	STD_LOGIC;
	 SIGNAL  nlOOOiOO :	STD_LOGIC;
	 SIGNAL  nlOOOl0i :	STD_LOGIC;
	 SIGNAL  nlOOOl0l :	STD_LOGIC;
	 SIGNAL  nlOOOl0O :	STD_LOGIC;
	 SIGNAL  nlOOOl1i :	STD_LOGIC;
	 SIGNAL  nlOOOl1l :	STD_LOGIC;
	 SIGNAL  nlOOOl1O :	STD_LOGIC;
	 SIGNAL  nlOOOlii :	STD_LOGIC;
	 SIGNAL  nlOOOlil :	STD_LOGIC;
	 SIGNAL  nlOOOliO :	STD_LOGIC;
	 SIGNAL  nlOOOlli :	STD_LOGIC;
	 SIGNAL  nlOOOlll :	STD_LOGIC;
	 SIGNAL  nlOOOllO :	STD_LOGIC;
	 SIGNAL  nlOOOlOi :	STD_LOGIC;
	 SIGNAL  nlOOOlOl :	STD_LOGIC;
	 SIGNAL  nlOOOlOO :	STD_LOGIC;
	 SIGNAL  nlOOOO0i :	STD_LOGIC;
	 SIGNAL  nlOOOO0l :	STD_LOGIC;
	 SIGNAL  nlOOOO0O :	STD_LOGIC;
	 SIGNAL  nlOOOO1i :	STD_LOGIC;
	 SIGNAL  nlOOOO1l :	STD_LOGIC;
	 SIGNAL  nlOOOO1O :	STD_LOGIC;
	 SIGNAL  nlOOOOii :	STD_LOGIC;
	 SIGNAL  nlOOOOil :	STD_LOGIC;
	 SIGNAL  nlOOOOiO :	STD_LOGIC;
	 SIGNAL  nlOOOOli :	STD_LOGIC;
	 SIGNAL  nlOOOOll :	STD_LOGIC;
	 SIGNAL  nlOOOOlO :	STD_LOGIC;
	 SIGNAL  nlOOOOOi :	STD_LOGIC;
	 SIGNAL  nlOOOOOl :	STD_LOGIC;
	 SIGNAL  nlOOOOOO :	STD_LOGIC;
	 SIGNAL  wire_w_comp_pat_size_range1330w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_comp_pat_size_range1331w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_ib_invalid_code_range3169w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_ib_invalid_code_range3176w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_pmadwidth_range175w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_r8b10b_dec_ibm_en_range3034w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_resync_badcg_en_range4511w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_resync_badcg_en_range4513w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_gnd <= '0';
	wire_vcc <= '1';
	wire_w_lg_w_lg_w_lg_rauto_speed_ena5w8w9w(0) <= wire_w_lg_w_lg_rauto_speed_ena5w8w(0) AND ni0OO;
	wire_w_lg_w_lg_n1i0O0O338w341w(0) <= wire_w_lg_n1i0O0O338w(0) AND wire_n1i0O0i44_w_lg_q340w(0);
	wire_w_lg_w_lg_n1ii01O227w228w(0) <= wire_w_lg_n1ii01O227w(0) AND n1ii01i;
	wire_w_lg_w_lg_n1ii11O1325w1327w(0) <= wire_w_lg_n1ii11O1325w(0) AND wire_w_lg_n1i1O0O1326w(0);
	wire_w_lg_w_lg_rauto_speed_ena5w8w(0) <= wire_w_lg_rauto_speed_ena5w(0) AND wire_n1iil1i4_w_lg_q7w(0);
	wire_w_lg_w_lg_n10liOl3443w3446w(0) <= wire_w_lg_n10liOl3443w(0) AND niii0l;
	wire_w_lg_w_lg_n10ll1O3434w3435w(0) <= wire_w_lg_n10ll1O3434w(0) AND niii0l;
	wire_w_lg_w_lg_rkchar3383w3384w(0) <= wire_w_lg_rkchar3383w(0) AND niii0l;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w2208w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND n1i100O;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w2203w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND n1i10iO;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w2198w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND n1i10lO;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w2193w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND n1i10OO;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w14500w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND nlOOO0iO;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w14495w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND nlOOO0lO;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w14490w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND nlOOO0OO;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w14480w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND nlOOOi0O;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w14485w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND nlOOOi1O;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w14475w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND nlOOOiiO;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w14470w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND nlOOOilO;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w14465w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND nlOOOiOO;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w14455w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND nlOOOl0O;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w14460w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND nlOOOl1O;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w14450w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND nlOOOliO;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w14445w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) AND nlOOOllO;
	wire_w_lg_w_lg_n1i01lO1217w1218w(0) <= wire_w_lg_n1i01lO1217w(0) AND wire_nlOll0O_dataout;
	wire_w_lg_w_lg_n1i1Oil1323w1324w(0) <= wire_w_lg_n1i1Oil1323w(0) AND n1i1OOi;
	wire_w_lg_w_lg_nlOO0iOl16779w16780w(0) <= wire_w_lg_nlOO0iOl16779w(0) AND wire_n1lllii_dataout;
	wire_w_lg_w_lg_nlOO1O0l17123w17124w(0) <= wire_w_lg_nlOO1O0l17123w(0) AND wire_n1iliii_dataout;
	wire_w_lg_comp_pat_porn4782w(0) <= comp_pat_porn AND n10100l;
	wire_w_lg_comp_pat_porn4786w(0) <= comp_pat_porn AND n10101l;
	wire_w_lg_comp_pat_porn4780w(0) <= comp_pat_porn AND n1010ii;
	wire_w_lg_comp_pat_porn4776w(0) <= comp_pat_porn AND n1010li;
	wire_w_lg_comp_pat_porn4774w(0) <= comp_pat_porn AND n1010lO;
	wire_w_lg_comp_pat_porn4770w(0) <= comp_pat_porn AND n1010OO;
	wire_w_lg_comp_pat_porn4800w(0) <= comp_pat_porn AND n10110l;
	wire_w_lg_comp_pat_porn4804w(0) <= comp_pat_porn AND n10111l;
	wire_w_lg_comp_pat_porn4798w(0) <= comp_pat_porn AND n1011ii;
	wire_w_lg_comp_pat_porn4794w(0) <= comp_pat_porn AND n1011li;
	wire_w_lg_comp_pat_porn4792w(0) <= comp_pat_porn AND n1011lO;
	wire_w_lg_comp_pat_porn4788w(0) <= comp_pat_porn AND n1011OO;
	wire_w_lg_comp_pat_porn4764w(0) <= comp_pat_porn AND n101i0l;
	wire_w_lg_comp_pat_porn4768w(0) <= comp_pat_porn AND n101i1l;
	wire_w_lg_comp_pat_porn4762w(0) <= comp_pat_porn AND n101iii;
	wire_w_lg_comp_pat_porn4758w(0) <= comp_pat_porn AND n101ili;
	wire_w_lg_comp_pat_porn4756w(0) <= comp_pat_porn AND n101ilO;
	wire_w_lg_comp_pat_porn5097w(0) <= comp_pat_porn AND n110O0O;
	wire_w_lg_comp_pat_porn5095w(0) <= comp_pat_porn AND n110Oil;
	wire_w_lg_comp_pat_porn5091w(0) <= comp_pat_porn AND n110Oll;
	wire_w_lg_comp_pat_porn5089w(0) <= comp_pat_porn AND n110OOi;
	wire_w_lg_comp_pat_porn5757w(0) <= comp_pat_porn AND n111Oil;
	wire_w_lg_comp_pat_porn5743w(0) <= comp_pat_porn AND n111Oll;
	wire_w_lg_comp_pat_porn5738w(0) <= comp_pat_porn AND n111OOl;
	wire_w_lg_comp_pat_porn5061w(0) <= comp_pat_porn AND n11i00O;
	wire_w_lg_comp_pat_porn5067w(0) <= comp_pat_porn AND n11i01i;
	wire_w_lg_comp_pat_porn5065w(0) <= comp_pat_porn AND n11i01O;
	wire_w_lg_comp_pat_porn5059w(0) <= comp_pat_porn AND n11i0il;
	wire_w_lg_comp_pat_porn5055w(0) <= comp_pat_porn AND n11i0ll;
	wire_w_lg_comp_pat_porn5053w(0) <= comp_pat_porn AND n11i0Oi;
	wire_w_lg_comp_pat_porn5079w(0) <= comp_pat_porn AND n11i10O;
	wire_w_lg_comp_pat_porn5085w(0) <= comp_pat_porn AND n11i11i;
	wire_w_lg_comp_pat_porn5083w(0) <= comp_pat_porn AND n11i11O;
	wire_w_lg_comp_pat_porn5077w(0) <= comp_pat_porn AND n11i1il;
	wire_w_lg_comp_pat_porn5073w(0) <= comp_pat_porn AND n11i1ll;
	wire_w_lg_comp_pat_porn5071w(0) <= comp_pat_porn AND n11i1Oi;
	wire_w_lg_comp_pat_porn5043w(0) <= comp_pat_porn AND n11ii0O;
	wire_w_lg_comp_pat_porn5049w(0) <= comp_pat_porn AND n11ii1i;
	wire_w_lg_comp_pat_porn5047w(0) <= comp_pat_porn AND n11ii1O;
	wire_w_lg_comp_pat_porn5041w(0) <= comp_pat_porn AND n11iiil;
	wire_w_lg_comp_pat_porn5037w(0) <= comp_pat_porn AND n11iill;
	wire_w_lg_comp_pat_porn5035w(0) <= comp_pat_porn AND n11iiOi;
	wire_w_lg_comp_pat_porn5025w(0) <= comp_pat_porn AND n11il0O;
	wire_w_lg_comp_pat_porn5031w(0) <= comp_pat_porn AND n11il1i;
	wire_w_lg_comp_pat_porn5029w(0) <= comp_pat_porn AND n11il1O;
	wire_w_lg_comp_pat_porn5023w(0) <= comp_pat_porn AND n11ilil;
	wire_w_lg_comp_pat_porn5019w(0) <= comp_pat_porn AND n11illl;
	wire_w_lg_comp_pat_porn5017w(0) <= comp_pat_porn AND n11ilOi;
	wire_w_lg_comp_pat_porn5007w(0) <= comp_pat_porn AND n11iO0O;
	wire_w_lg_comp_pat_porn5013w(0) <= comp_pat_porn AND n11iO1i;
	wire_w_lg_comp_pat_porn5011w(0) <= comp_pat_porn AND n11iO1O;
	wire_w_lg_comp_pat_porn5005w(0) <= comp_pat_porn AND n11iOil;
	wire_w_lg_comp_pat_porn4872w(0) <= comp_pat_porn AND n11O00l;
	wire_w_lg_comp_pat_porn4870w(0) <= comp_pat_porn AND n11O0ii;
	wire_w_lg_comp_pat_porn4866w(0) <= comp_pat_porn AND n11O0li;
	wire_w_lg_comp_pat_porn4864w(0) <= comp_pat_porn AND n11O0lO;
	wire_w_lg_comp_pat_porn4860w(0) <= comp_pat_porn AND n11O0OO;
	wire_w_lg_comp_pat_porn4854w(0) <= comp_pat_porn AND n11Oi0l;
	wire_w_lg_comp_pat_porn4858w(0) <= comp_pat_porn AND n11Oi1l;
	wire_w_lg_comp_pat_porn4852w(0) <= comp_pat_porn AND n11Oiii;
	wire_w_lg_comp_pat_porn4848w(0) <= comp_pat_porn AND n11Oili;
	wire_w_lg_comp_pat_porn4846w(0) <= comp_pat_porn AND n11OilO;
	wire_w_lg_comp_pat_porn4842w(0) <= comp_pat_porn AND n11OiOO;
	wire_w_lg_comp_pat_porn4836w(0) <= comp_pat_porn AND n11Ol0l;
	wire_w_lg_comp_pat_porn4840w(0) <= comp_pat_porn AND n11Ol1l;
	wire_w_lg_comp_pat_porn4834w(0) <= comp_pat_porn AND n11Olii;
	wire_w_lg_comp_pat_porn4830w(0) <= comp_pat_porn AND n11Olli;
	wire_w_lg_comp_pat_porn4828w(0) <= comp_pat_porn AND n11OllO;
	wire_w_lg_comp_pat_porn4824w(0) <= comp_pat_porn AND n11OlOO;
	wire_w_lg_comp_pat_porn4818w(0) <= comp_pat_porn AND n11OO0l;
	wire_w_lg_comp_pat_porn4822w(0) <= comp_pat_porn AND n11OO1l;
	wire_w_lg_comp_pat_porn4816w(0) <= comp_pat_porn AND n11OOii;
	wire_w_lg_comp_pat_porn4812w(0) <= comp_pat_porn AND n11OOli;
	wire_w_lg_comp_pat_porn4810w(0) <= comp_pat_porn AND n11OOlO;
	wire_w_lg_comp_pat_porn4806w(0) <= comp_pat_porn AND n11OOOO;
	wire_w_lg_n10l1ii4519w(0) <= n10l1ii AND wire_w_lg_w_resync_badcg_en_range4511w4518w(0);
	wire_w_lg_n10O10i3044w(0) <= n10O10i AND n10O11l;
	wire_w_lg_n10O10l3062w(0) <= n10O10l AND wire_niOl0l_w_lg_dataout3061w(0);
	wire_w_lg_n10O10O3020w(0) <= n10O10O AND wire_niOl0i_w_lg_w_lg_dataout3017w3019w(0);
	wire_w_lg_n10O11l3047w(0) <= n10O11l AND wire_niOl1O_w_lg_w_lg_o1314w3046w(0);
	wire_w_lg_n1i000O1200w(0) <= n1i000O AND n1i000l;
	wire_w_lg_n1i00il3236w(0) <= n1i00il AND n10llOl;
	wire_w_lg_n1i00il1198w(0) <= n1i00il AND n1i00ii;
	wire_w_lg_n1i0l0l388w(0) <= n1i0l0l AND wire_nl_w_lg_nlOi0Ol387w(0);
	wire_w_lg_n1i0l1O396w(0) <= n1i0l1O AND wire_nl_w_lg_nlOi0lO395w(0);
	wire_w_lg_n1i0lii380w(0) <= n1i0lii AND wire_nl_w_lg_nlOii1i379w(0);
	wire_w_lg_n1i0liO372w(0) <= n1i0liO AND wire_nl_w_lg_nlOii1O371w(0);
	wire_w_lg_n1i0lll364w(0) <= n1i0lll AND wire_nl_w_lg_nlOii0l363w(0);
	wire_w_lg_n1i0lOO356w(0) <= n1i0lOO AND wire_nl_w_lg_nlOiiii355w(0);
	wire_w_lg_n1i0O0O338w(0) <= n1i0O0O AND wire_nl_w_lg_nlOiiiO337w(0);
	wire_w_lg_n1i1Oll3180w(0) <= n1i1Oll AND n1i01ll;
	wire_w_lg_n1i1OlO3177w(0) <= n1i1OlO AND n1i01ll;
	wire_w_lg_n1ii01O227w(0) <= n1ii01O AND n1ii01l;
	wire_w_lg_n1ii11i326w(0) <= n1ii11i AND wire_nl_w_lg_w_lg_nlOiill322w325w(0);
	wire_w_lg_n1ii11O1325w(0) <= n1ii11O AND wire_n1l1Ol_dataout;
	wire_w_lg_nlOO011i17049w(0) <= nlOO011i AND nlOO1O0i;
	wire_w_lg_nlOO01ll16920w(0) <= nlOO01ll AND wire_nl1ll1i_w_lg_w_lg_o16855w16919w(0);
	wire_w_lg_nlOO01Oi16917w(0) <= nlOO01Oi AND nlOO01ll;
	wire_w_lg_nlOO01Ol16935w(0) <= nlOO01Ol AND wire_nl1ll1O_w_lg_o16934w(0);
	wire_w_lg_nlOO01OO16893w(0) <= nlOO01OO AND wire_nl1ll1l_w_lg_w_lg_o16890w16892w(0);
	wire_w_lg_nlOO0i0O16788w(0) <= nlOO0i0O AND nlOO00Ol;
	wire_w_lg_nlOO0i0O16761w(0) <= nlOO0i0O AND nlOO0i0l;
	wire_w_lg_nlOO0lil16763w(0) <= nlOO0lil AND nlOO0i0i;
	wire_w_lg_nlOO0liO16708w(0) <= nlOO0liO AND nlOO0iOi;
	wire_w_lg_nlOO0lli16705w(0) <= nlOO0lli AND nlOO0iOi;
	wire_w_lg_nlOO0O0l16576w(0) <= nlOO0O0l AND wire_nl1llll_w_lg_w_lg_o16511w16575w(0);
	wire_w_lg_nlOO0Oii16573w(0) <= nlOO0Oii AND nlOO0O0l;
	wire_w_lg_nlOO0Oil16591w(0) <= nlOO0Oil AND wire_nl1llOi_w_lg_o16590w(0);
	wire_w_lg_nlOO0OiO16549w(0) <= nlOO0OiO AND wire_nl1lllO_w_lg_w_lg_o16546w16548w(0);
	wire_w_lg_nlOO1llO17132w(0) <= nlOO1llO AND nlOO1l0l;
	wire_w_lg_nlOO1llO17105w(0) <= nlOO1llO AND nlOO1lll;
	wire_w_lg_nlOO1OOl17107w(0) <= nlOO1OOl AND nlOO1lli;
	wire_w_lg_nlOO1OOO17052w(0) <= nlOO1OOO AND nlOO1O0i;
	wire_w_lg_rauto_speed_ena5w(0) <= rauto_speed_ena AND wire_w_lg_rfreq_sel4w(0);
	wire_w_lg_rencdt_rising4509w(0) <= rencdt_rising AND nlli0Ol;
	wire_w_lg_wa_6g_en4496w(0) <= wa_6g_en AND wire_w_lg_lpbk_en4495w(0);
	wire_w_lg_w_comp_pat_size_range1330w1333w(0) <= wire_w_comp_pat_size_range1330w(0) AND wire_w_lg_w_comp_pat_size_range1331w1332w(0);
	wire_w_lg_w_ib_invalid_code_range3169w17048w(0) <= wire_w_ib_invalid_code_range3169w(0) AND wire_nl1ll1i_w_lg_w_lg_w_lg_w_lg_o16855w17043w17044w17047w(0);
	wire_w_lg_w_ib_invalid_code_range3169w16704w(0) <= wire_w_ib_invalid_code_range3169w(0) AND wire_nl1llll_w_lg_w_lg_w_lg_w_lg_o16511w16699w16700w16703w(0);
	wire_w_lg_w_ib_invalid_code_range3169w3175w(0) <= wire_w_ib_invalid_code_range3169w(0) AND wire_niOl1O_w_lg_w_lg_w_lg_w_lg_o1314w3170w3171w3174w(0);
	wire_w_lg_w_ib_invalid_code_range3176w3184w(0) <= wire_w_ib_invalid_code_range3176w(0) AND wire_niOl0i_w_lg_w_lg_dataout3179w3183w(0);
	wire_w_lg_w_ib_invalid_code_range3176w17056w(0) <= wire_w_ib_invalid_code_range3176w(0) AND wire_nl1ll1l_w_lg_w_lg_o17051w17055w(0);
	wire_w_lg_w_ib_invalid_code_range3176w16712w(0) <= wire_w_ib_invalid_code_range3176w(0) AND wire_nl1lllO_w_lg_w_lg_o16707w16711w(0);
	wire_w_lg_w_pmadwidth_range175w2186w(0) <= wire_w_pmadwidth_range175w(0) AND wire_nl_w_lg_w_lg_w_lg_nlilii2175w2180w2185w(0);
	wire_w_lg_w_pmadwidth_range175w14438w(0) <= wire_w_pmadwidth_range175w(0) AND wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0);
	wire_w_lg_w_pmadwidth_range175w1328w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_w_lg_n1ii11O1325w1327w(0);
	wire_w_lg_w_pmadwidth_range175w2181w(0) <= wire_w_pmadwidth_range175w(0) AND wire_nl_w_lg_w_lg_nlilii2175w2180w(0);
	wire_w_lg_w_pmadwidth_range175w14433w(0) <= wire_w_pmadwidth_range175w(0) AND wire_nl_w_lg_w_lg_nlli01O14427w14432w(0);
	wire_w_lg_w_pmadwidth_range175w2176w(0) <= wire_w_pmadwidth_range175w(0) AND wire_nl_w_lg_nlilii2175w(0);
	wire_w_lg_w_pmadwidth_range175w14428w(0) <= wire_w_pmadwidth_range175w(0) AND wire_nl_w_lg_nlli01O14427w(0);
	wire_w_lg_w_pmadwidth_range175w2103w(0) <= wire_w_pmadwidth_range175w(0) AND wire_nl_w_lg_w_lg_w_lg_w_lg_nlilii2087w2094w2101w2102w(0);
	wire_w_lg_w_pmadwidth_range175w14162w(0) <= wire_w_pmadwidth_range175w(0) AND wire_nl_w14161w(0);
	wire_w_lg_w_pmadwidth_range175w2096w(0) <= wire_w_pmadwidth_range175w(0) AND wire_nl_w_lg_w_lg_w_lg_nlilii2087w2094w2095w(0);
	wire_w_lg_w_pmadwidth_range175w14155w(0) <= wire_w_pmadwidth_range175w(0) AND wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14154w(0);
	wire_w_lg_w_pmadwidth_range175w2089w(0) <= wire_w_pmadwidth_range175w(0) AND wire_nl_w_lg_w_lg_nlilii2087w2088w(0);
	wire_w_lg_w_pmadwidth_range175w14148w(0) <= wire_w_pmadwidth_range175w(0) AND wire_nl_w_lg_w_lg_nlli01O14146w14147w(0);
	wire_w_lg_w_pmadwidth_range175w14247w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n11100l14246w(0);
	wire_w_lg_w_pmadwidth_range175w14253w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n11101l14252w(0);
	wire_w_lg_w_pmadwidth_range175w14240w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n1110il14239w(0);
	wire_w_lg_w_pmadwidth_range175w14233w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n1110ll14232w(0);
	wire_w_lg_w_pmadwidth_range175w14226w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n1110Ol14225w(0);
	wire_w_lg_w_pmadwidth_range175w14262w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n1111ll14261w(0);
	wire_w_lg_w_pmadwidth_range175w14259w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n1111Oi14258w(0);
	wire_w_lg_w_pmadwidth_range175w14256w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n1111OO14255w(0);
	wire_w_lg_w_pmadwidth_range175w14212w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n111i0l14211w(0);
	wire_w_lg_w_pmadwidth_range175w14219w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n111i1l14218w(0);
	wire_w_lg_w_pmadwidth_range175w14205w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n111iil14204w(0);
	wire_w_lg_w_pmadwidth_range175w14198w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n111ill14197w(0);
	wire_w_lg_w_pmadwidth_range175w14191w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n111iOl14190w(0);
	wire_w_lg_w_pmadwidth_range175w14177w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n111l0l14176w(0);
	wire_w_lg_w_pmadwidth_range175w14184w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n111l1l14183w(0);
	wire_w_lg_w_pmadwidth_range175w14170w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n111lil14169w(0);
	wire_w_lg_w_pmadwidth_range175w2172w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n1i1iiO2171w(0);
	wire_w_lg_w_pmadwidth_range175w2138w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n1i1l0i2137w(0);
	wire_w_lg_w_pmadwidth_range175w2141w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n1i1l1l2140w(0);
	wire_w_lg_w_pmadwidth_range175w2132w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n1i1lii2131w(0);
	wire_w_lg_w_pmadwidth_range175w2125w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n1i1lli2124w(0);
	wire_w_lg_w_pmadwidth_range175w2118w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n1i1lOi2117w(0);
	wire_w_lg_w_pmadwidth_range175w2111w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_n1i1O1i2110w(0);
	wire_w_lg_w_pmadwidth_range175w2912w(0) <= wire_w_pmadwidth_range175w(0) AND wire_nl_w_lg_nlilii2911w(0);
	wire_w_lg_w_pmadwidth_range175w16385w(0) <= wire_w_pmadwidth_range175w(0) AND wire_nl_w_lg_nlli01O16384w(0);
	wire_w_lg_w_pmadwidth_range175w14424w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_nlOOOO0O14423w(0);
	wire_w_lg_w_pmadwidth_range175w14404w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_nlOOOOil14403w(0);
	wire_w_lg_w_pmadwidth_range175w14385w(0) <= wire_w_pmadwidth_range175w(0) AND wire_w_lg_nlOOOOli14384w(0);
	wire_w_lg_w_pmadwidth_range175w2207w(0) <= wire_w_pmadwidth_range175w(0) AND n1i10ii;
	wire_w_lg_w_pmadwidth_range175w2202w(0) <= wire_w_pmadwidth_range175w(0) AND n1i10li;
	wire_w_lg_w_pmadwidth_range175w2197w(0) <= wire_w_pmadwidth_range175w(0) AND n1i10Oi;
	wire_w_lg_w_pmadwidth_range175w2517w(0) <= wire_w_pmadwidth_range175w(0) AND n1i11ii;
	wire_w_lg_w_pmadwidth_range175w2192w(0) <= wire_w_pmadwidth_range175w(0) AND n1i1i1i;
	wire_w_lg_w_pmadwidth_range175w2482w(0) <= wire_w_pmadwidth_range175w(0) AND n1i1iii;
	wire_w_lg_w_pmadwidth_range175w176w(0) <= wire_w_pmadwidth_range175w(0) AND n1ii0Ol;
	wire_w_lg_w_pmadwidth_range175w15676w(0) <= wire_w_pmadwidth_range175w(0) AND nlOOlOiO;
	wire_w_lg_w_pmadwidth_range175w14499w(0) <= wire_w_pmadwidth_range175w(0) AND nlOOO0li;
	wire_w_lg_w_pmadwidth_range175w14494w(0) <= wire_w_pmadwidth_range175w(0) AND nlOOO0Oi;
	wire_w_lg_w_pmadwidth_range175w14484w(0) <= wire_w_pmadwidth_range175w(0) AND nlOOOi0i;
	wire_w_lg_w_pmadwidth_range175w14489w(0) <= wire_w_pmadwidth_range175w(0) AND nlOOOi1i;
	wire_w_lg_w_pmadwidth_range175w14479w(0) <= wire_w_pmadwidth_range175w(0) AND nlOOOiii;
	wire_w_lg_w_pmadwidth_range175w14474w(0) <= wire_w_pmadwidth_range175w(0) AND nlOOOili;
	wire_w_lg_w_pmadwidth_range175w14469w(0) <= wire_w_pmadwidth_range175w(0) AND nlOOOiOi;
	wire_w_lg_w_pmadwidth_range175w14459w(0) <= wire_w_pmadwidth_range175w(0) AND nlOOOl0i;
	wire_w_lg_w_pmadwidth_range175w14464w(0) <= wire_w_pmadwidth_range175w(0) AND nlOOOl1i;
	wire_w_lg_w_pmadwidth_range175w14454w(0) <= wire_w_pmadwidth_range175w(0) AND nlOOOlii;
	wire_w_lg_w_pmadwidth_range175w14449w(0) <= wire_w_pmadwidth_range175w(0) AND nlOOOlli;
	wire_w_lg_w_pmadwidth_range175w14444w(0) <= wire_w_pmadwidth_range175w(0) AND nlOOOlOi;
	wire_w_lg_w_pmadwidth_range175w15643w(0) <= wire_w_pmadwidth_range175w(0) AND nlOOOO0i;
	wire_w_lg_w_r8b10b_dec_ibm_en_range3034w16923w(0) <= wire_w_r8b10b_dec_ibm_en_range3034w(0) AND wire_nl1liOl_w_lg_w16916w16922w(0);
	wire_w_lg_w_r8b10b_dec_ibm_en_range3034w16579w(0) <= wire_w_r8b10b_dec_ibm_en_range3034w(0) AND wire_nl1lliO_w_lg_w16572w16578w(0);
	wire_w_lg_w_r8b10b_dec_ibm_en_range3034w3050w(0) <= wire_w_r8b10b_dec_ibm_en_range3034w(0) AND wire_niOl1i_w_lg_w3043w3049w(0);
	wire_w_lg_w_r8b10b_dec_ibm_en_range3034w16942w(0) <= wire_w_r8b10b_dec_ibm_en_range3034w(0) AND wire_nl1liOl_w16941w(0);
	wire_w_lg_w_r8b10b_dec_ibm_en_range3034w16598w(0) <= wire_w_r8b10b_dec_ibm_en_range3034w(0) AND wire_nl1lliO_w16597w(0);
	wire_w_lg_w_r8b10b_dec_ibm_en_range3034w3069w(0) <= wire_w_r8b10b_dec_ibm_en_range3034w(0) AND wire_niOl1i_w3068w(0);
	wire_w_lg_w_resync_badcg_en_range4511w4518w(0) <= wire_w_resync_badcg_en_range4511w(0) AND wire_w_lg_w_resync_badcg_en_range4513w4514w(0);
	wire_w_lg_autobytealign_dis5791w(0) <= NOT autobytealign_dis;
	wire_w_lg_disable_rx_disp1194w(0) <= NOT disable_rx_disp;
	wire_w_lg_lpbk_en4500w(0) <= NOT lpbk_en;
	wire_w_lg_n10l00i3543w(0) <= NOT n10l00i;
	wire_w_lg_n10l01l3948w(0) <= NOT n10l01l;
	wire_w_lg_n10l01O3545w(0) <= NOT n10l01O;
	wire_w_lg_n10l0OO3456w(0) <= NOT n10l0OO;
	wire_w_lg_n10l10i4528w(0) <= NOT n10l10i;
	wire_w_lg_n10l11i4530w(0) <= NOT n10l11i;
	wire_w_lg_n10l1il4527w(0) <= NOT n10l1il;
	wire_w_lg_n10l1li4548w(0) <= NOT n10l1li;
	wire_w_lg_n10li0i3455w(0) <= NOT n10li0i;
	wire_w_lg_n10li0O3453w(0) <= NOT n10li0O;
	wire_w_lg_n10lili3500w(0) <= NOT n10lili;
	wire_w_lg_n10lilO3445w(0) <= NOT n10lilO;
	wire_w_lg_n10liOl3443w(0) <= NOT n10liOl;
	wire_w_lg_n10ll0i3493w(0) <= NOT n10ll0i;
	wire_w_lg_n10ll0l3386w(0) <= NOT n10ll0l;
	wire_w_lg_n10ll0O3433w(0) <= NOT n10ll0O;
	wire_w_lg_n10ll1l3437w(0) <= NOT n10ll1l;
	wire_w_lg_n10ll1O3434w(0) <= NOT n10ll1O;
	wire_w_lg_n10llii3439w(0) <= NOT n10llii;
	wire_w_lg_n10lOlO3084w(0) <= NOT n10lOlO;
	wire_w_lg_n10O00l2717w(0) <= NOT n10O00l;
	wire_w_lg_n10O01l2767w(0) <= NOT n10O01l;
	wire_w_lg_n10O01O2739w(0) <= NOT n10O01O;
	wire_w_lg_n10O0il2712w(0) <= NOT n10O0il;
	wire_w_lg_n10O0li2685w(0) <= NOT n10O0li;
	wire_w_lg_n10O0Oi2526w(0) <= NOT n10O0Oi;
	wire_w_lg_n10O0Ol2525w(0) <= NOT n10O0Ol;
	wire_w_lg_n10O0OO2524w(0) <= NOT n10O0OO;
	wire_w_lg_n10O10O3014w(0) <= NOT n10O10O;
	wire_w_lg_n10O1iO3025w(0) <= NOT n10O1iO;
	wire_w_lg_n10O1li3031w(0) <= NOT n10O1li;
	wire_w_lg_n10O1Oi3072w(0) <= NOT n10O1Oi;
	wire_w_lg_n10Oi0i2520w(0) <= NOT n10Oi0i;
	wire_w_lg_n10Oi0l2490w(0) <= NOT n10Oi0l;
	wire_w_lg_n10Oi0O2489w(0) <= NOT n10Oi0O;
	wire_w_lg_n10Oi1i2523w(0) <= NOT n10Oi1i;
	wire_w_lg_n10Oi1l2522w(0) <= NOT n10Oi1l;
	wire_w_lg_n10Oi1O2521w(0) <= NOT n10Oi1O;
	wire_w_lg_n10Oiii2488w(0) <= NOT n10Oiii;
	wire_w_lg_n10Oiil2487w(0) <= NOT n10Oiil;
	wire_w_lg_n10OiiO2486w(0) <= NOT n10OiiO;
	wire_w_lg_n10Oili2485w(0) <= NOT n10Oili;
	wire_w_lg_n10Oill2484w(0) <= NOT n10Oill;
	wire_w_lg_n10OiOO2455w(0) <= NOT n10OiOO;
	wire_w_lg_n10Ol0i2451w(0) <= NOT n10Ol0i;
	wire_w_lg_n10Ol0l2449w(0) <= NOT n10Ol0l;
	wire_w_lg_n10Ol0O2457w(0) <= NOT n10Ol0O;
	wire_w_lg_n10Ol1i2453w(0) <= NOT n10Ol1i;
	wire_w_lg_n10Ol1l2515w(0) <= NOT n10Ol1l;
	wire_w_lg_n10Ol1O2459w(0) <= NOT n10Ol1O;
	wire_w_lg_n10Olli2400w(0) <= NOT n10Olli;
	wire_w_lg_n10Olll2398w(0) <= NOT n10Olll;
	wire_w_lg_n10OllO2505w(0) <= NOT n10OllO;
	wire_w_lg_n10OlOi2404w(0) <= NOT n10OlOi;
	wire_w_lg_n10OlOl2396w(0) <= NOT n10OlOl;
	wire_w_lg_n10OlOO2394w(0) <= NOT n10OlOO;
	wire_w_lg_n10OO0l2345w(0) <= NOT n10OO0l;
	wire_w_lg_n10OO0O2343w(0) <= NOT n10OO0O;
	wire_w_lg_n10OO1i2402w(0) <= NOT n10OO1i;
	wire_w_lg_n10OOii2480w(0) <= NOT n10OOii;
	wire_w_lg_n10OOil2349w(0) <= NOT n10OOil;
	wire_w_lg_n10OOiO2341w(0) <= NOT n10OOiO;
	wire_w_lg_n10OOli2339w(0) <= NOT n10OOli;
	wire_w_lg_n10OOll2347w(0) <= NOT n10OOll;
	wire_w_lg_n10OOOO2291w(0) <= NOT n10OOOO;
	wire_w_lg_n110iiO5931w(0) <= NOT n110iiO;
	wire_w_lg_n110ili5930w(0) <= NOT n110ili;
	wire_w_lg_n110iOl5657w(0) <= NOT n110iOl;
	wire_w_lg_n110l0i5646w(0) <= NOT n110l0i;
	wire_w_lg_n110l0l5644w(0) <= NOT n110l0l;
	wire_w_lg_n110l0O5642w(0) <= NOT n110l0O;
	wire_w_lg_n110l1i5652w(0) <= NOT n110l1i;
	wire_w_lg_n110l1l5650w(0) <= NOT n110l1l;
	wire_w_lg_n110l1O5648w(0) <= NOT n110l1O;
	wire_w_lg_n110lii5640w(0) <= NOT n110lii;
	wire_w_lg_n110lil5638w(0) <= NOT n110lil;
	wire_w_lg_n110liO5636w(0) <= NOT n110liO;
	wire_w_lg_n110lli5634w(0) <= NOT n110lli;
	wire_w_lg_n110lll5632w(0) <= NOT n110lll;
	wire_w_lg_n110llO5630w(0) <= NOT n110llO;
	wire_w_lg_n110lOi5628w(0) <= NOT n110lOi;
	wire_w_lg_n110lOl5626w(0) <= NOT n110lOl;
	wire_w_lg_n110lOO5624w(0) <= NOT n110lOO;
	wire_w_lg_n110O1i5616w(0) <= NOT n110O1i;
	wire_w_lg_n110O1l5614w(0) <= NOT n110O1l;
	wire_w_lg_n11100i14248w(0) <= NOT n11100i;
	wire_w_lg_n11100l14246w(0) <= NOT n11100l;
	wire_w_lg_n11100O14683w(0) <= NOT n11100O;
	wire_w_lg_n11101i14674w(0) <= NOT n11101i;
	wire_w_lg_n11101l14252w(0) <= NOT n11101l;
	wire_w_lg_n11101O14678w(0) <= NOT n11101O;
	wire_w_lg_n1110ii14241w(0) <= NOT n1110ii;
	wire_w_lg_n1110il14239w(0) <= NOT n1110il;
	wire_w_lg_n1110iO14689w(0) <= NOT n1110iO;
	wire_w_lg_n1110li14234w(0) <= NOT n1110li;
	wire_w_lg_n1110ll14232w(0) <= NOT n1110ll;
	wire_w_lg_n1110lO14696w(0) <= NOT n1110lO;
	wire_w_lg_n1110Oi14227w(0) <= NOT n1110Oi;
	wire_w_lg_n1110Ol14225w(0) <= NOT n1110Ol;
	wire_w_lg_n1110OO14704w(0) <= NOT n1110OO;
	wire_w_lg_n11110i15016w(0) <= NOT n11110i;
	wire_w_lg_n11110l15031w(0) <= NOT n11110l;
	wire_w_lg_n11110O15047w(0) <= NOT n11110O;
	wire_w_lg_n11111i14977w(0) <= NOT n11111i;
	wire_w_lg_n11111l14989w(0) <= NOT n11111l;
	wire_w_lg_n11111O15002w(0) <= NOT n11111O;
	wire_w_lg_n1111ii15064w(0) <= NOT n1111ii;
	wire_w_lg_n1111il15082w(0) <= NOT n1111il;
	wire_w_lg_n1111li16406w(0) <= NOT n1111li;
	wire_w_lg_n1111ll14261w(0) <= NOT n1111ll;
	wire_w_lg_n1111lO14669w(0) <= NOT n1111lO;
	wire_w_lg_n1111Oi14258w(0) <= NOT n1111Oi;
	wire_w_lg_n1111Ol14671w(0) <= NOT n1111Ol;
	wire_w_lg_n1111OO14255w(0) <= NOT n1111OO;
	wire_w_lg_n111i0i14213w(0) <= NOT n111i0i;
	wire_w_lg_n111i0l14211w(0) <= NOT n111i0l;
	wire_w_lg_n111i0O14723w(0) <= NOT n111i0O;
	wire_w_lg_n111i1i14220w(0) <= NOT n111i1i;
	wire_w_lg_n111i1l14218w(0) <= NOT n111i1l;
	wire_w_lg_n111i1O14713w(0) <= NOT n111i1O;
	wire_w_lg_n111iii14206w(0) <= NOT n111iii;
	wire_w_lg_n111iil14204w(0) <= NOT n111iil;
	wire_w_lg_n111iiO14734w(0) <= NOT n111iiO;
	wire_w_lg_n111ili14199w(0) <= NOT n111ili;
	wire_w_lg_n111ill14197w(0) <= NOT n111ill;
	wire_w_lg_n111ilO14746w(0) <= NOT n111ilO;
	wire_w_lg_n111iOi14192w(0) <= NOT n111iOi;
	wire_w_lg_n111iOl14190w(0) <= NOT n111iOl;
	wire_w_lg_n111iOO14759w(0) <= NOT n111iOO;
	wire_w_lg_n111l0i14178w(0) <= NOT n111l0i;
	wire_w_lg_n111l0l14176w(0) <= NOT n111l0l;
	wire_w_lg_n111l0O14788w(0) <= NOT n111l0O;
	wire_w_lg_n111l1i14185w(0) <= NOT n111l1i;
	wire_w_lg_n111l1l14183w(0) <= NOT n111l1l;
	wire_w_lg_n111l1O14773w(0) <= NOT n111l1O;
	wire_w_lg_n111lii14171w(0) <= NOT n111lii;
	wire_w_lg_n111lil14169w(0) <= NOT n111lil;
	wire_w_lg_n111liO14804w(0) <= NOT n111liO;
	wire_w_lg_n111lli14821w(0) <= NOT n111lli;
	wire_w_lg_n111lll14839w(0) <= NOT n111lll;
	wire_w_lg_n111lOi7419w(0) <= NOT n111lOi;
	wire_w_lg_n111O1i7420w(0) <= NOT n111O1i;
	wire_w_lg_n1i00lO1129w(0) <= NOT n1i00lO;
	wire_w_lg_n1i01ii1295w(0) <= NOT n1i01ii;
	wire_w_lg_n1i01il1227w(0) <= NOT n1i01il;
	wire_w_lg_n1i0i0i462w(0) <= NOT n1i0i0i;
	wire_w_lg_n1i0i0O459w(0) <= NOT n1i0i0O;
	wire_w_lg_n1i0iii457w(0) <= NOT n1i0iii;
	wire_w_lg_n1i0iil455w(0) <= NOT n1i0iil;
	wire_w_lg_n1i0iiO453w(0) <= NOT n1i0iiO;
	wire_w_lg_n1i0ili451w(0) <= NOT n1i0ili;
	wire_w_lg_n1i0ill449w(0) <= NOT n1i0ill;
	wire_w_lg_n1i0ilO447w(0) <= NOT n1i0ilO;
	wire_w_lg_n1i0iOi445w(0) <= NOT n1i0iOi;
	wire_w_lg_n1i100l2498w(0) <= NOT n1i100l;
	wire_w_lg_n1i100O2508w(0) <= NOT n1i100O;
	wire_w_lg_n1i101i2943w(0) <= NOT n1i101i;
	wire_w_lg_n1i101O2353w(0) <= NOT n1i101O;
	wire_w_lg_n1i10il2355w(0) <= NOT n1i10il;
	wire_w_lg_n1i10ll2359w(0) <= NOT n1i10ll;
	wire_w_lg_n1i10Ol2364w(0) <= NOT n1i10Ol;
	wire_w_lg_n1i110i2287w(0) <= NOT n1i110i;
	wire_w_lg_n1i110l2285w(0) <= NOT n1i110l;
	wire_w_lg_n1i110O2293w(0) <= NOT n1i110O;
	wire_w_lg_n1i111i2289w(0) <= NOT n1i111i;
	wire_w_lg_n1i111l2471w(0) <= NOT n1i111l;
	wire_w_lg_n1i111O2295w(0) <= NOT n1i111O;
	wire_w_lg_n1i11ii2953w(0) <= NOT n1i11ii;
	wire_w_lg_n1i11il2408w(0) <= NOT n1i11il;
	wire_w_lg_n1i11li2410w(0) <= NOT n1i11li;
	wire_w_lg_n1i11ll2414w(0) <= NOT n1i11ll;
	wire_w_lg_n1i11lO2419w(0) <= NOT n1i11lO;
	wire_w_lg_n1i11Oi2425w(0) <= NOT n1i11Oi;
	wire_w_lg_n1i11Ol2432w(0) <= NOT n1i11Ol;
	wire_w_lg_n1i11OO2440w(0) <= NOT n1i11OO;
	wire_w_lg_n1i1i0i2385w(0) <= NOT n1i1i0i;
	wire_w_lg_n1i1i1l2370w(0) <= NOT n1i1i1l;
	wire_w_lg_n1i1i1O2377w(0) <= NOT n1i1i1O;
	wire_w_lg_n1i1iii2933w(0) <= NOT n1i1iii;
	wire_w_lg_n1i1iil2299w(0) <= NOT n1i1iil;
	wire_w_lg_n1i1iiO2171w(0) <= NOT n1i1iiO;
	wire_w_lg_n1i1ili2305w(0) <= NOT n1i1ili;
	wire_w_lg_n1i1ill2310w(0) <= NOT n1i1ill;
	wire_w_lg_n1i1ilO2316w(0) <= NOT n1i1ilO;
	wire_w_lg_n1i1iOi2323w(0) <= NOT n1i1iOi;
	wire_w_lg_n1i1iOl2331w(0) <= NOT n1i1iOl;
	wire_w_lg_n1i1l0i2137w(0) <= NOT n1i1l0i;
	wire_w_lg_n1i1l0l2464w(0) <= NOT n1i1l0l;
	wire_w_lg_n1i1l0O2133w(0) <= NOT n1i1l0O;
	wire_w_lg_n1i1l1i2923w(0) <= NOT n1i1l1i;
	wire_w_lg_n1i1l1l2140w(0) <= NOT n1i1l1l;
	wire_w_lg_n1i1l1O2244w(0) <= NOT n1i1l1O;
	wire_w_lg_n1i1lii2131w(0) <= NOT n1i1lii;
	wire_w_lg_n1i1lil2246w(0) <= NOT n1i1lil;
	wire_w_lg_n1i1liO2126w(0) <= NOT n1i1liO;
	wire_w_lg_n1i1lli2124w(0) <= NOT n1i1lli;
	wire_w_lg_n1i1lll2250w(0) <= NOT n1i1lll;
	wire_w_lg_n1i1llO2119w(0) <= NOT n1i1llO;
	wire_w_lg_n1i1lOi2117w(0) <= NOT n1i1lOi;
	wire_w_lg_n1i1lOl2255w(0) <= NOT n1i1lOl;
	wire_w_lg_n1i1lOO2112w(0) <= NOT n1i1lOO;
	wire_w_lg_n1i1O0i2276w(0) <= NOT n1i1O0i;
	wire_w_lg_n1i1O1i2110w(0) <= NOT n1i1O1i;
	wire_w_lg_n1i1O1l2261w(0) <= NOT n1i1O1l;
	wire_w_lg_n1i1O1O2268w(0) <= NOT n1i1O1O;
	wire_w_lg_n1ii00i237w(0) <= NOT n1ii00i;
	wire_w_lg_n1ii00l231w(0) <= NOT n1ii00l;
	wire_w_lg_n1ii1lO236w(0) <= NOT n1ii1lO;
	wire_w_lg_n1ii1OO229w(0) <= NOT n1ii1OO;
	wire_w_lg_nlOO000i16904w(0) <= NOT nlOO000i;
	wire_w_lg_nlOO001O16898w(0) <= NOT nlOO001O;
	wire_w_lg_nlOO00ii16945w(0) <= NOT nlOO00ii;
	wire_w_lg_nlOO01OO16887w(0) <= NOT nlOO01OO;
	wire_w_lg_nlOO0l0O16618w(0) <= NOT nlOO0l0O;
	wire_w_lg_nlOO0OiO16543w(0) <= NOT nlOO0OiO;
	wire_w_lg_nlOO0OlO16554w(0) <= NOT nlOO0OlO;
	wire_w_lg_nlOO0OOi16560w(0) <= NOT nlOO0OOi;
	wire_w_lg_nlOO1OlO16962w(0) <= NOT nlOO1OlO;
	wire_w_lg_nlOOi00i15691w(0) <= NOT nlOOi00i;
	wire_w_lg_nlOOi00l15690w(0) <= NOT nlOOi00l;
	wire_w_lg_nlOOi00O15689w(0) <= NOT nlOOi00O;
	wire_w_lg_nlOOi01i15694w(0) <= NOT nlOOi01i;
	wire_w_lg_nlOOi01l15693w(0) <= NOT nlOOi01l;
	wire_w_lg_nlOOi01O15692w(0) <= NOT nlOOi01O;
	wire_w_lg_nlOOi0ii15688w(0) <= NOT nlOOi0ii;
	wire_w_lg_nlOOi0il15687w(0) <= NOT nlOOi0il;
	wire_w_lg_nlOOi0iO15686w(0) <= NOT nlOOi0iO;
	wire_w_lg_nlOOi0li15685w(0) <= NOT nlOOi0li;
	wire_w_lg_nlOOi0ll15684w(0) <= NOT nlOOi0ll;
	wire_w_lg_nlOOi0lO15683w(0) <= NOT nlOOi0lO;
	wire_w_lg_nlOOi0Oi15682w(0) <= NOT nlOOi0Oi;
	wire_w_lg_nlOOi0Ol15681w(0) <= NOT nlOOi0Ol;
	wire_w_lg_nlOOi0OO15680w(0) <= NOT nlOOi0OO;
	wire_w_lg_nlOOi10l16209w(0) <= NOT nlOOi10l;
	wire_w_lg_nlOOi10O16181w(0) <= NOT nlOOi10O;
	wire_w_lg_nlOOi11i16601w(0) <= NOT nlOOi11i;
	wire_w_lg_nlOOi1il16159w(0) <= NOT nlOOi1il;
	wire_w_lg_nlOOi1ll16154w(0) <= NOT nlOOi1ll;
	wire_w_lg_nlOOii0i15658w(0) <= NOT nlOOii0i;
	wire_w_lg_nlOOii0l15657w(0) <= NOT nlOOii0l;
	wire_w_lg_nlOOii0O15656w(0) <= NOT nlOOii0O;
	wire_w_lg_nlOOii1i15679w(0) <= NOT nlOOii1i;
	wire_w_lg_nlOOii1l15660w(0) <= NOT nlOOii1l;
	wire_w_lg_nlOOii1O15659w(0) <= NOT nlOOii1O;
	wire_w_lg_nlOOiiii15655w(0) <= NOT nlOOiiii;
	wire_w_lg_nlOOiiil15654w(0) <= NOT nlOOiiil;
	wire_w_lg_nlOOiiiO15653w(0) <= NOT nlOOiiiO;
	wire_w_lg_nlOOiili15652w(0) <= NOT nlOOiili;
	wire_w_lg_nlOOiill15651w(0) <= NOT nlOOiill;
	wire_w_lg_nlOOiilO15650w(0) <= NOT nlOOiilO;
	wire_w_lg_nlOOiiOi15649w(0) <= NOT nlOOiiOi;
	wire_w_lg_nlOOiiOl15648w(0) <= NOT nlOOiiOl;
	wire_w_lg_nlOOiiOO15647w(0) <= NOT nlOOiiOO;
	wire_w_lg_nlOOil1i15646w(0) <= NOT nlOOil1i;
	wire_w_lg_nlOOil1l15645w(0) <= NOT nlOOil1l;
	wire_w_lg_nlOOiliO15632w(0) <= NOT nlOOiliO;
	wire_w_lg_nlOOilli15630w(0) <= NOT nlOOilli;
	wire_w_lg_nlOOilll15621w(0) <= NOT nlOOilll;
	wire_w_lg_nlOOillO15619w(0) <= NOT nlOOillO;
	wire_w_lg_nlOOilOi15617w(0) <= NOT nlOOilOi;
	wire_w_lg_nlOOilOl15615w(0) <= NOT nlOOilOl;
	wire_w_lg_nlOOilOO15609w(0) <= NOT nlOOilOO;
	wire_w_lg_nlOOiO0i15601w(0) <= NOT nlOOiO0i;
	wire_w_lg_nlOOiO0l15599w(0) <= NOT nlOOiO0l;
	wire_w_lg_nlOOiO0O15597w(0) <= NOT nlOOiO0O;
	wire_w_lg_nlOOiO1i15607w(0) <= NOT nlOOiO1i;
	wire_w_lg_nlOOiO1l15605w(0) <= NOT nlOOiO1l;
	wire_w_lg_nlOOiO1O15603w(0) <= NOT nlOOiO1O;
	wire_w_lg_nlOOiOii15596w(0) <= NOT nlOOiOii;
	wire_w_lg_nlOOiOil15594w(0) <= NOT nlOOiOil;
	wire_w_lg_nlOOiOiO15592w(0) <= NOT nlOOiOiO;
	wire_w_lg_nlOOiOli15590w(0) <= NOT nlOOiOli;
	wire_w_lg_nlOOiOll15588w(0) <= NOT nlOOiOll;
	wire_w_lg_nlOOl00i15346w(0) <= NOT nlOOl00i;
	wire_w_lg_nlOOl00l15344w(0) <= NOT nlOOl00l;
	wire_w_lg_nlOOl01i15352w(0) <= NOT nlOOl01i;
	wire_w_lg_nlOOl01l15350w(0) <= NOT nlOOl01l;
	wire_w_lg_nlOOl01O15348w(0) <= NOT nlOOl01O;
	wire_w_lg_nlOOl0lO15144w(0) <= NOT nlOOl0lO;
	wire_w_lg_nlOOl0Oi15142w(0) <= NOT nlOOl0Oi;
	wire_w_lg_nlOOl0Ol15133w(0) <= NOT nlOOl0Ol;
	wire_w_lg_nlOOl0OO15131w(0) <= NOT nlOOl0OO;
	wire_w_lg_nlOOl10i15386w(0) <= NOT nlOOl10i;
	wire_w_lg_nlOOl10l15377w(0) <= NOT nlOOl10l;
	wire_w_lg_nlOOl10O15375w(0) <= NOT nlOOl10O;
	wire_w_lg_nlOOl11O15388w(0) <= NOT nlOOl11O;
	wire_w_lg_nlOOl1ii15373w(0) <= NOT nlOOl1ii;
	wire_w_lg_nlOOl1il15371w(0) <= NOT nlOOl1il;
	wire_w_lg_nlOOl1iO15365w(0) <= NOT nlOOl1iO;
	wire_w_lg_nlOOl1li15363w(0) <= NOT nlOOl1li;
	wire_w_lg_nlOOl1ll15361w(0) <= NOT nlOOl1ll;
	wire_w_lg_nlOOl1lO15359w(0) <= NOT nlOOl1lO;
	wire_w_lg_nlOOl1Oi15357w(0) <= NOT nlOOl1Oi;
	wire_w_lg_nlOOl1Ol15355w(0) <= NOT nlOOl1Ol;
	wire_w_lg_nlOOl1OO15353w(0) <= NOT nlOOl1OO;
	wire_w_lg_nlOOli0i15119w(0) <= NOT nlOOli0i;
	wire_w_lg_nlOOli0l15117w(0) <= NOT nlOOli0l;
	wire_w_lg_nlOOli0O15115w(0) <= NOT nlOOli0O;
	wire_w_lg_nlOOli1i15129w(0) <= NOT nlOOli1i;
	wire_w_lg_nlOOli1l15127w(0) <= NOT nlOOli1l;
	wire_w_lg_nlOOli1O15121w(0) <= NOT nlOOli1O;
	wire_w_lg_nlOOliii15113w(0) <= NOT nlOOliii;
	wire_w_lg_nlOOliil15111w(0) <= NOT nlOOliil;
	wire_w_lg_nlOOliiO15109w(0) <= NOT nlOOliiO;
	wire_w_lg_nlOOlili15108w(0) <= NOT nlOOlili;
	wire_w_lg_nlOOlill15106w(0) <= NOT nlOOlill;
	wire_w_lg_nlOOlilO15104w(0) <= NOT nlOOlilO;
	wire_w_lg_nlOOliOi15102w(0) <= NOT nlOOliOi;
	wire_w_lg_nlOOliOl15100w(0) <= NOT nlOOliOl;
	wire_w_lg_nlOOll0O14902w(0) <= NOT nlOOll0O;
	wire_w_lg_nlOOllii14900w(0) <= NOT nlOOllii;
	wire_w_lg_nlOOllil14891w(0) <= NOT nlOOllil;
	wire_w_lg_nlOOlliO14889w(0) <= NOT nlOOlliO;
	wire_w_lg_nlOOllli14887w(0) <= NOT nlOOllli;
	wire_w_lg_nlOOllll14885w(0) <= NOT nlOOllll;
	wire_w_lg_nlOOlllO14879w(0) <= NOT nlOOlllO;
	wire_w_lg_nlOOllOi14877w(0) <= NOT nlOOllOi;
	wire_w_lg_nlOOllOl14875w(0) <= NOT nlOOllOl;
	wire_w_lg_nlOOllOO14873w(0) <= NOT nlOOllOO;
	wire_w_lg_nlOOlO0i14866w(0) <= NOT nlOOlO0i;
	wire_w_lg_nlOOlO0l14864w(0) <= NOT nlOOlO0l;
	wire_w_lg_nlOOlO0O14862w(0) <= NOT nlOOlO0O;
	wire_w_lg_nlOOlO1i14871w(0) <= NOT nlOOlO1i;
	wire_w_lg_nlOOlO1l14869w(0) <= NOT nlOOlO1l;
	wire_w_lg_nlOOlO1O14867w(0) <= NOT nlOOlO1O;
	wire_w_lg_nlOOlOii14860w(0) <= NOT nlOOlOii;
	wire_w_lg_nlOOlOil14858w(0) <= NOT nlOOlOil;
	wire_w_lg_nlOOlOiO16466w(0) <= NOT nlOOlOiO;
	wire_w_lg_nlOOlOli15399w(0) <= NOT nlOOlOli;
	wire_w_lg_nlOOlOlO15401w(0) <= NOT nlOOlOlO;
	wire_w_lg_nlOOlOOl15404w(0) <= NOT nlOOlOOl;
	wire_w_lg_nlOOO00i15157w(0) <= NOT nlOOO00i;
	wire_w_lg_nlOOO00O15160w(0) <= NOT nlOOO00O;
	wire_w_lg_nlOOO01l15155w(0) <= NOT nlOOO01l;
	wire_w_lg_nlOOO0il15164w(0) <= NOT nlOOO0il;
	wire_w_lg_nlOOO0iO15408w(0) <= NOT nlOOO0iO;
	wire_w_lg_nlOOO0ll15169w(0) <= NOT nlOOO0ll;
	wire_w_lg_nlOOO0Ol15175w(0) <= NOT nlOOO0Ol;
	wire_w_lg_nlOOO10i15434w(0) <= NOT nlOOO10i;
	wire_w_lg_nlOOO10l15443w(0) <= NOT nlOOO10l;
	wire_w_lg_nlOOO10O15453w(0) <= NOT nlOOO10O;
	wire_w_lg_nlOOO11i15413w(0) <= NOT nlOOO11i;
	wire_w_lg_nlOOO11l15419w(0) <= NOT nlOOO11l;
	wire_w_lg_nlOOO11O15426w(0) <= NOT nlOOO11O;
	wire_w_lg_nlOOO1ii15464w(0) <= NOT nlOOO1ii;
	wire_w_lg_nlOOO1il15476w(0) <= NOT nlOOO1il;
	wire_w_lg_nlOOO1iO15489w(0) <= NOT nlOOO1iO;
	wire_w_lg_nlOOO1li15503w(0) <= NOT nlOOO1li;
	wire_w_lg_nlOOO1ll15518w(0) <= NOT nlOOO1ll;
	wire_w_lg_nlOOO1lO15534w(0) <= NOT nlOOO1lO;
	wire_w_lg_nlOOO1Oi15551w(0) <= NOT nlOOO1Oi;
	wire_w_lg_nlOOO1Ol15569w(0) <= NOT nlOOO1Ol;
	wire_w_lg_nlOOO1OO16446w(0) <= NOT nlOOO1OO;
	wire_w_lg_nlOOOi0l15190w(0) <= NOT nlOOOi0l;
	wire_w_lg_nlOOOi1l15182w(0) <= NOT nlOOOi1l;
	wire_w_lg_nlOOOiil15199w(0) <= NOT nlOOOiil;
	wire_w_lg_nlOOOill15209w(0) <= NOT nlOOOill;
	wire_w_lg_nlOOOiOl15220w(0) <= NOT nlOOOiOl;
	wire_w_lg_nlOOOl0l15245w(0) <= NOT nlOOOl0l;
	wire_w_lg_nlOOOl1l15232w(0) <= NOT nlOOOl1l;
	wire_w_lg_nlOOOlil15259w(0) <= NOT nlOOOlil;
	wire_w_lg_nlOOOlll15274w(0) <= NOT nlOOOlll;
	wire_w_lg_nlOOOlOl15290w(0) <= NOT nlOOOlOl;
	wire_w_lg_nlOOOlOO15307w(0) <= NOT nlOOOlOO;
	wire_w_lg_nlOOOO0i16426w(0) <= NOT nlOOOO0i;
	wire_w_lg_nlOOOO0l14913w(0) <= NOT nlOOOO0l;
	wire_w_lg_nlOOOO0O14423w(0) <= NOT nlOOOO0O;
	wire_w_lg_nlOOOO1i15325w(0) <= NOT nlOOOO1i;
	wire_w_lg_nlOOOOii14915w(0) <= NOT nlOOOOii;
	wire_w_lg_nlOOOOil14403w(0) <= NOT nlOOOOil;
	wire_w_lg_nlOOOOiO14918w(0) <= NOT nlOOOOiO;
	wire_w_lg_nlOOOOli14384w(0) <= NOT nlOOOOli;
	wire_w_lg_nlOOOOll14932w(0) <= NOT nlOOOOll;
	wire_w_lg_nlOOOOlO14939w(0) <= NOT nlOOOOlO;
	wire_w_lg_nlOOOOOi14947w(0) <= NOT nlOOOOOi;
	wire_w_lg_nlOOOOOl14956w(0) <= NOT nlOOOOOl;
	wire_w_lg_nlOOOOOO14966w(0) <= NOT nlOOOOOO;
	wire_w_lg_rencdt_rising4504w(0) <= NOT rencdt_rising;
	wire_w_lg_rfreq_sel4w(0) <= NOT rfreq_sel;
	wire_w_lg_rkchar3383w(0) <= NOT rkchar;
	wire_w_lg_rosbased3492w(0) <= NOT rosbased;
	wire_w_lg_rst113w(0) <= NOT rst;
	wire_w_lg_sync_sm_dis1224w(0) <= NOT sync_sm_dis;
	wire_w_lg_wa_6g_en4499w(0) <= NOT wa_6g_en;
	wire_w_lg_w_comp_pat_size_range1331w1332w(0) <= NOT wire_w_comp_pat_size_range1331w(0);
	wire_w_lg_w_pmadwidth_range175w219w(0) <= NOT wire_w_pmadwidth_range175w(0);
	wire_w_lg_w_resync_badcg_en_range4513w4514w(0) <= NOT wire_w_resync_badcg_en_range4513w(0);
	wire_w_lg_w_lg_w_lg_w_lg_rauto_speed_ena5w8w9w10w(0) <= wire_w_lg_w_lg_w_lg_rauto_speed_ena5w8w9w(0) OR dwidth;
	wire_w_lg_w_lg_comp_pat_porn4782w4783w(0) <= wire_w_lg_comp_pat_porn4782w(0) OR n10100i;
	wire_w_lg_w_lg_comp_pat_porn4786w4787w(0) <= wire_w_lg_comp_pat_porn4786w(0) OR n10101i;
	wire_w_lg_w_lg_comp_pat_porn4780w4781w(0) <= wire_w_lg_comp_pat_porn4780w(0) OR n10100O;
	wire_w_lg_w_lg_comp_pat_porn4776w4777w(0) <= wire_w_lg_comp_pat_porn4776w(0) OR n1010iO;
	wire_w_lg_w_lg_comp_pat_porn4774w4775w(0) <= wire_w_lg_comp_pat_porn4774w(0) OR n1010ll;
	wire_w_lg_w_lg_comp_pat_porn4770w4771w(0) <= wire_w_lg_comp_pat_porn4770w(0) OR n1010Ol;
	wire_w_lg_w_lg_comp_pat_porn4800w4801w(0) <= wire_w_lg_comp_pat_porn4800w(0) OR n10110i;
	wire_w_lg_w_lg_comp_pat_porn4804w4805w(0) <= wire_w_lg_comp_pat_porn4804w(0) OR n10111i;
	wire_w_lg_w_lg_comp_pat_porn4798w4799w(0) <= wire_w_lg_comp_pat_porn4798w(0) OR n10110O;
	wire_w_lg_w_lg_comp_pat_porn4794w4795w(0) <= wire_w_lg_comp_pat_porn4794w(0) OR n1011iO;
	wire_w_lg_w_lg_comp_pat_porn4792w4793w(0) <= wire_w_lg_comp_pat_porn4792w(0) OR n1011ll;
	wire_w_lg_w_lg_comp_pat_porn4788w4789w(0) <= wire_w_lg_comp_pat_porn4788w(0) OR n1011Ol;
	wire_w_lg_w_lg_comp_pat_porn4764w4765w(0) <= wire_w_lg_comp_pat_porn4764w(0) OR n101i0i;
	wire_w_lg_w_lg_comp_pat_porn4768w4769w(0) <= wire_w_lg_comp_pat_porn4768w(0) OR n101i1i;
	wire_w_lg_w_lg_comp_pat_porn4762w4763w(0) <= wire_w_lg_comp_pat_porn4762w(0) OR n101i0O;
	wire_w_lg_w_lg_comp_pat_porn4758w4759w(0) <= wire_w_lg_comp_pat_porn4758w(0) OR n101iiO;
	wire_w_lg_w_lg_comp_pat_porn4756w4757w(0) <= wire_w_lg_comp_pat_porn4756w(0) OR n101ill;
	wire_w_lg_w_lg_comp_pat_porn5097w5098w(0) <= wire_w_lg_comp_pat_porn5097w(0) OR n110O0l;
	wire_w_lg_w_lg_comp_pat_porn5095w5096w(0) <= wire_w_lg_comp_pat_porn5095w(0) OR n110Oii;
	wire_w_lg_w_lg_comp_pat_porn5091w5092w(0) <= wire_w_lg_comp_pat_porn5091w(0) OR n110Oli;
	wire_w_lg_w_lg_comp_pat_porn5089w5090w(0) <= wire_w_lg_comp_pat_porn5089w(0) OR n110OlO;
	wire_w_lg_w_lg_comp_pat_porn5757w5758w(0) <= wire_w_lg_comp_pat_porn5757w(0) OR n111Oii;
	wire_w_lg_w_lg_comp_pat_porn5743w5744w(0) <= wire_w_lg_comp_pat_porn5743w(0) OR n111Oli;
	wire_w_lg_w_lg_comp_pat_porn5738w5739w(0) <= wire_w_lg_comp_pat_porn5738w(0) OR n111OOi;
	wire_w_lg_w_lg_comp_pat_porn5061w5062w(0) <= wire_w_lg_comp_pat_porn5061w(0) OR n11i00l;
	wire_w_lg_w_lg_comp_pat_porn5067w5068w(0) <= wire_w_lg_comp_pat_porn5067w(0) OR n11i1OO;
	wire_w_lg_w_lg_comp_pat_porn5065w5066w(0) <= wire_w_lg_comp_pat_porn5065w(0) OR n11i01l;
	wire_w_lg_w_lg_comp_pat_porn5059w5060w(0) <= wire_w_lg_comp_pat_porn5059w(0) OR n11i0ii;
	wire_w_lg_w_lg_comp_pat_porn5055w5056w(0) <= wire_w_lg_comp_pat_porn5055w(0) OR n11i0li;
	wire_w_lg_w_lg_comp_pat_porn5053w5054w(0) <= wire_w_lg_comp_pat_porn5053w(0) OR n11i0lO;
	wire_w_lg_w_lg_comp_pat_porn5079w5080w(0) <= wire_w_lg_comp_pat_porn5079w(0) OR n11i10l;
	wire_w_lg_w_lg_comp_pat_porn5085w5086w(0) <= wire_w_lg_comp_pat_porn5085w(0) OR n110OOO;
	wire_w_lg_w_lg_comp_pat_porn5083w5084w(0) <= wire_w_lg_comp_pat_porn5083w(0) OR n11i11l;
	wire_w_lg_w_lg_comp_pat_porn5077w5078w(0) <= wire_w_lg_comp_pat_porn5077w(0) OR n11i1ii;
	wire_w_lg_w_lg_comp_pat_porn5073w5074w(0) <= wire_w_lg_comp_pat_porn5073w(0) OR n11i1li;
	wire_w_lg_w_lg_comp_pat_porn5071w5072w(0) <= wire_w_lg_comp_pat_porn5071w(0) OR n11i1lO;
	wire_w_lg_w_lg_comp_pat_porn5043w5044w(0) <= wire_w_lg_comp_pat_porn5043w(0) OR n11ii0l;
	wire_w_lg_w_lg_comp_pat_porn5049w5050w(0) <= wire_w_lg_comp_pat_porn5049w(0) OR n11i0OO;
	wire_w_lg_w_lg_comp_pat_porn5047w5048w(0) <= wire_w_lg_comp_pat_porn5047w(0) OR n11ii1l;
	wire_w_lg_w_lg_comp_pat_porn5041w5042w(0) <= wire_w_lg_comp_pat_porn5041w(0) OR n11iiii;
	wire_w_lg_w_lg_comp_pat_porn5037w5038w(0) <= wire_w_lg_comp_pat_porn5037w(0) OR n11iili;
	wire_w_lg_w_lg_comp_pat_porn5035w5036w(0) <= wire_w_lg_comp_pat_porn5035w(0) OR n11iilO;
	wire_w_lg_w_lg_comp_pat_porn5025w5026w(0) <= wire_w_lg_comp_pat_porn5025w(0) OR n11il0l;
	wire_w_lg_w_lg_comp_pat_porn5031w5032w(0) <= wire_w_lg_comp_pat_porn5031w(0) OR n11iiOO;
	wire_w_lg_w_lg_comp_pat_porn5029w5030w(0) <= wire_w_lg_comp_pat_porn5029w(0) OR n11il1l;
	wire_w_lg_w_lg_comp_pat_porn5023w5024w(0) <= wire_w_lg_comp_pat_porn5023w(0) OR n11ilii;
	wire_w_lg_w_lg_comp_pat_porn5019w5020w(0) <= wire_w_lg_comp_pat_porn5019w(0) OR n11illi;
	wire_w_lg_w_lg_comp_pat_porn5017w5018w(0) <= wire_w_lg_comp_pat_porn5017w(0) OR n11illO;
	wire_w_lg_w_lg_comp_pat_porn5007w5008w(0) <= wire_w_lg_comp_pat_porn5007w(0) OR n11iO0l;
	wire_w_lg_w_lg_comp_pat_porn5013w5014w(0) <= wire_w_lg_comp_pat_porn5013w(0) OR n11ilOO;
	wire_w_lg_w_lg_comp_pat_porn5011w5012w(0) <= wire_w_lg_comp_pat_porn5011w(0) OR n11iO1l;
	wire_w_lg_w_lg_comp_pat_porn5005w5006w(0) <= wire_w_lg_comp_pat_porn5005w(0) OR n11iOii;
	wire_w_lg_w_lg_comp_pat_porn4872w4873w(0) <= wire_w_lg_comp_pat_porn4872w(0) OR n11O00i;
	wire_w_lg_w_lg_comp_pat_porn4870w4871w(0) <= wire_w_lg_comp_pat_porn4870w(0) OR n11O00O;
	wire_w_lg_w_lg_comp_pat_porn4866w4867w(0) <= wire_w_lg_comp_pat_porn4866w(0) OR n11O0iO;
	wire_w_lg_w_lg_comp_pat_porn4864w4865w(0) <= wire_w_lg_comp_pat_porn4864w(0) OR n11O0ll;
	wire_w_lg_w_lg_comp_pat_porn4860w4861w(0) <= wire_w_lg_comp_pat_porn4860w(0) OR n11O0Ol;
	wire_w_lg_w_lg_comp_pat_porn4854w4855w(0) <= wire_w_lg_comp_pat_porn4854w(0) OR n11Oi0i;
	wire_w_lg_w_lg_comp_pat_porn4858w4859w(0) <= wire_w_lg_comp_pat_porn4858w(0) OR n11Oi1i;
	wire_w_lg_w_lg_comp_pat_porn4852w4853w(0) <= wire_w_lg_comp_pat_porn4852w(0) OR n11Oi0O;
	wire_w_lg_w_lg_comp_pat_porn4848w4849w(0) <= wire_w_lg_comp_pat_porn4848w(0) OR n11OiiO;
	wire_w_lg_w_lg_comp_pat_porn4846w4847w(0) <= wire_w_lg_comp_pat_porn4846w(0) OR n11Oill;
	wire_w_lg_w_lg_comp_pat_porn4842w4843w(0) <= wire_w_lg_comp_pat_porn4842w(0) OR n11OiOl;
	wire_w_lg_w_lg_comp_pat_porn4836w4837w(0) <= wire_w_lg_comp_pat_porn4836w(0) OR n11Ol0i;
	wire_w_lg_w_lg_comp_pat_porn4840w4841w(0) <= wire_w_lg_comp_pat_porn4840w(0) OR n11Ol1i;
	wire_w_lg_w_lg_comp_pat_porn4834w4835w(0) <= wire_w_lg_comp_pat_porn4834w(0) OR n11Ol0O;
	wire_w_lg_w_lg_comp_pat_porn4830w4831w(0) <= wire_w_lg_comp_pat_porn4830w(0) OR n11OliO;
	wire_w_lg_w_lg_comp_pat_porn4828w4829w(0) <= wire_w_lg_comp_pat_porn4828w(0) OR n11Olll;
	wire_w_lg_w_lg_comp_pat_porn4824w4825w(0) <= wire_w_lg_comp_pat_porn4824w(0) OR n11OlOl;
	wire_w_lg_w_lg_comp_pat_porn4818w4819w(0) <= wire_w_lg_comp_pat_porn4818w(0) OR n11OO0i;
	wire_w_lg_w_lg_comp_pat_porn4822w4823w(0) <= wire_w_lg_comp_pat_porn4822w(0) OR n11OO1i;
	wire_w_lg_w_lg_comp_pat_porn4816w4817w(0) <= wire_w_lg_comp_pat_porn4816w(0) OR n11OO0O;
	wire_w_lg_w_lg_comp_pat_porn4812w4813w(0) <= wire_w_lg_comp_pat_porn4812w(0) OR n11OOiO;
	wire_w_lg_w_lg_comp_pat_porn4810w4811w(0) <= wire_w_lg_comp_pat_porn4810w(0) OR n11OOll;
	wire_w_lg_w_lg_comp_pat_porn4806w4807w(0) <= wire_w_lg_comp_pat_porn4806w(0) OR n11OOOl;
	wire_w_lg_w_lg_w_pmadwidth_range175w176w177w(0) <= wire_w_lg_w_pmadwidth_range175w176w(0) OR n1ii0Oi;
	wire_w_lg_w_lg_n10ll0O3433w3447w(0) <= wire_w_lg_n10ll0O3433w(0) OR n10ll0l;
	wire_w_lg_w_lg_n11100i14248w15001w(0) <= wire_w_lg_n11100i14248w(0) OR n11110i;
	wire_w_lg_w_lg_n11100i14248w15015w(0) <= wire_w_lg_n11100i14248w(0) OR n11110l;
	wire_w_lg_w_lg_n11100i14248w15030w(0) <= wire_w_lg_n11100i14248w(0) OR n11110O;
	wire_w_lg_w_lg_n11100i14248w14965w(0) <= wire_w_lg_n11100i14248w(0) OR n11111i;
	wire_w_lg_w_lg_n11100i14248w14976w(0) <= wire_w_lg_n11100i14248w(0) OR n11111l;
	wire_w_lg_w_lg_n11100i14248w14988w(0) <= wire_w_lg_n11100i14248w(0) OR n11111O;
	wire_w_lg_w_lg_n11100i14248w15046w(0) <= wire_w_lg_n11100i14248w(0) OR n1111ii;
	wire_w_lg_w_lg_n11100i14248w15063w(0) <= wire_w_lg_n11100i14248w(0) OR n1111il;
	wire_w_lg_w_lg_n11100i14248w15081w(0) <= wire_w_lg_n11100i14248w(0) OR n1111iO;
	wire_w_lg_w_lg_n11100i14248w14931w(0) <= wire_w_lg_n11100i14248w(0) OR nlOOOOlO;
	wire_w_lg_w_lg_n11100i14248w14938w(0) <= wire_w_lg_n11100i14248w(0) OR nlOOOOOi;
	wire_w_lg_w_lg_n11100i14248w14946w(0) <= wire_w_lg_n11100i14248w(0) OR nlOOOOOl;
	wire_w_lg_w_lg_n11100i14248w14955w(0) <= wire_w_lg_n11100i14248w(0) OR nlOOOOOO;
	wire_w_lg_w_lg_n1i1l0O2133w2304w(0) <= wire_w_lg_n1i1l0O2133w(0) OR n1i1ill;
	wire_w_lg_w_lg_n1i1l0O2133w2309w(0) <= wire_w_lg_n1i1l0O2133w(0) OR n1i1ilO;
	wire_w_lg_w_lg_n1i1l0O2133w2315w(0) <= wire_w_lg_n1i1l0O2133w(0) OR n1i1iOi;
	wire_w_lg_w_lg_n1i1l0O2133w2322w(0) <= wire_w_lg_n1i1l0O2133w(0) OR n1i1iOl;
	wire_w_lg_w_lg_n1i1l0O2133w2330w(0) <= wire_w_lg_n1i1l0O2133w(0) OR n1i1iOO;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) OR wire_nl_w_lg_nlli0lO15746w(0);
	wire_w_lg_w_lg_w_pmadwidth_range175w219w2572w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) OR nlil0i;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w2564w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) OR nlil0l;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w2556w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) OR nlil0O;
	wire_w_lg_w_lg_w_pmadwidth_range175w219w2580w(0) <= wire_w_lg_w_pmadwidth_range175w219w(0) OR nlil1O;
	wire_w_lg_w_lg_w_lg_w_pmadwidth_range175w176w177w181w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w176w177w(0) OR wire_n1ii0ll16_w_lg_w_lg_q179w180w(0);
	wire_w15832w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR nlli01i;
	wire_w15820w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR nlli01l;
	wire_w15916w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR nlli1iO;
	wire_w15904w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR nlli1li;
	wire_w15892w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR nlli1ll;
	wire_w15880w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR nlli1lO;
	wire_w15868w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR nlli1Oi;
	wire_w15856w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR nlli1Ol;
	wire_w15844w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR nlli1OO;
	wire_w_lg_w_lg_w_lg_w_pmadwidth_range175w219w2572w2573w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w219w2572w(0) OR nlil1O;
	wire_w_lg_w_lg_w_lg_w_pmadwidth_range175w219w2564w2565w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w219w2564w(0) OR nlil0i;
	wire_w_lg_w_lg_w_lg_w_pmadwidth_range175w219w2556w2557w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w219w2556w(0) OR nlil0l;
	wire_w_lg_w_lg_w_lg_w_pmadwidth_range175w219w2580w2581w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w219w2580w(0) OR nlil1l;
	wire_w182w(0) <= wire_w_lg_w_lg_w_lg_w_pmadwidth_range175w176w177w181w(0) OR n1ii0li;
	wire_w_lg_w15832w15833w(0) <= wire_w15832w(0) OR nlli1OO;
	wire_w_lg_w15820w15821w(0) <= wire_w15820w(0) OR nlli01i;
	wire_w_lg_w15916w15917w(0) <= wire_w15916w(0) OR nlli1il;
	wire_w_lg_w15904w15905w(0) <= wire_w15904w(0) OR nlli1iO;
	wire_w_lg_w15892w15893w(0) <= wire_w15892w(0) OR nlli1li;
	wire_w_lg_w15880w15881w(0) <= wire_w15880w(0) OR nlli1ll;
	wire_w_lg_w15868w15869w(0) <= wire_w15868w(0) OR nlli1lO;
	wire_w_lg_w15856w15857w(0) <= wire_w15856w(0) OR nlli1Oi;
	wire_w_lg_w15844w15845w(0) <= wire_w15844w(0) OR nlli1Ol;
	wire_w2574w(0) <= wire_w_lg_w_lg_w_lg_w_pmadwidth_range175w219w2572w2573w(0) OR nlil1l;
	wire_w2566w(0) <= wire_w_lg_w_lg_w_lg_w_pmadwidth_range175w219w2564w2565w(0) OR nlil1O;
	wire_w2558w(0) <= wire_w_lg_w_lg_w_lg_w_pmadwidth_range175w219w2556w2557w(0) OR nlil0i;
	wire_w2582w(0) <= wire_w_lg_w_lg_w_lg_w_pmadwidth_range175w219w2580w2581w(0) OR nlil1i;
	wire_w_lg_w_lg_w15832w15833w15834w(0) <= wire_w_lg_w15832w15833w(0) OR nlli1Ol;
	wire_w_lg_w_lg_w15820w15821w15822w(0) <= wire_w_lg_w15820w15821w(0) OR nlli1OO;
	wire_w_lg_w_lg_w15916w15917w15918w(0) <= wire_w_lg_w15916w15917w(0) OR nlli1ii;
	wire_w_lg_w_lg_w15904w15905w15906w(0) <= wire_w_lg_w15904w15905w(0) OR nlli1il;
	wire_w_lg_w_lg_w15892w15893w15894w(0) <= wire_w_lg_w15892w15893w(0) OR nlli1iO;
	wire_w_lg_w_lg_w15880w15881w15882w(0) <= wire_w_lg_w15880w15881w(0) OR nlli1li;
	wire_w_lg_w_lg_w15868w15869w15870w(0) <= wire_w_lg_w15868w15869w(0) OR nlli1ll;
	wire_w_lg_w_lg_w15856w15857w15858w(0) <= wire_w_lg_w15856w15857w(0) OR nlli1lO;
	wire_w_lg_w_lg_w15844w15845w15846w(0) <= wire_w_lg_w15844w15845w(0) OR nlli1Oi;
	wire_w_lg_w2574w2575w(0) <= wire_w2574w(0) OR nlil1i;
	wire_w_lg_w2566w2567w(0) <= wire_w2566w(0) OR nlil1l;
	wire_w_lg_w2558w2559w(0) <= wire_w2558w(0) OR nlil1O;
	wire_w_lg_w2582w2583w(0) <= wire_w2582w(0) OR nliiOO;
	wire_w_lg_w_lg_w_lg_w15832w15833w15834w15835w(0) <= wire_w_lg_w_lg_w15832w15833w15834w(0) OR nlli1Oi;
	wire_w_lg_w_lg_w_lg_w15820w15821w15822w15823w(0) <= wire_w_lg_w_lg_w15820w15821w15822w(0) OR nlli1Ol;
	wire_w_lg_w_lg_w_lg_w15916w15917w15918w15919w(0) <= wire_w_lg_w_lg_w15916w15917w15918w(0) OR nlli10O;
	wire_w_lg_w_lg_w_lg_w15904w15905w15906w15907w(0) <= wire_w_lg_w_lg_w15904w15905w15906w(0) OR nlli1ii;
	wire_w_lg_w_lg_w_lg_w15892w15893w15894w15895w(0) <= wire_w_lg_w_lg_w15892w15893w15894w(0) OR nlli1il;
	wire_w_lg_w_lg_w_lg_w15880w15881w15882w15883w(0) <= wire_w_lg_w_lg_w15880w15881w15882w(0) OR nlli1iO;
	wire_w_lg_w_lg_w_lg_w15868w15869w15870w15871w(0) <= wire_w_lg_w_lg_w15868w15869w15870w(0) OR nlli1li;
	wire_w_lg_w_lg_w_lg_w15856w15857w15858w15859w(0) <= wire_w_lg_w_lg_w15856w15857w15858w(0) OR nlli1ll;
	wire_w_lg_w_lg_w_lg_w15844w15845w15846w15847w(0) <= wire_w_lg_w_lg_w15844w15845w15846w(0) OR nlli1lO;
	wire_w_lg_w_lg_w2574w2575w2576w(0) <= wire_w_lg_w2574w2575w(0) OR nliiOO;
	wire_w_lg_w_lg_w2566w2567w2568w(0) <= wire_w_lg_w2566w2567w(0) OR nlil1i;
	wire_w_lg_w_lg_w2558w2559w2560w(0) <= wire_w_lg_w2558w2559w(0) OR nlil1l;
	wire_w_lg_w_lg_w2582w2583w2584w(0) <= wire_w_lg_w2582w2583w(0) OR nliiOl;
	wire_w15836w(0) <= wire_w_lg_w_lg_w_lg_w15832w15833w15834w15835w(0) OR nlli1lO;
	wire_w15824w(0) <= wire_w_lg_w_lg_w_lg_w15820w15821w15822w15823w(0) OR nlli1Oi;
	wire_w15920w(0) <= wire_w_lg_w_lg_w_lg_w15916w15917w15918w15919w(0) OR nlli10l;
	wire_w15908w(0) <= wire_w_lg_w_lg_w_lg_w15904w15905w15906w15907w(0) OR nlli10O;
	wire_w15896w(0) <= wire_w_lg_w_lg_w_lg_w15892w15893w15894w15895w(0) OR nlli1ii;
	wire_w15884w(0) <= wire_w_lg_w_lg_w_lg_w15880w15881w15882w15883w(0) OR nlli1il;
	wire_w15872w(0) <= wire_w_lg_w_lg_w_lg_w15868w15869w15870w15871w(0) OR nlli1iO;
	wire_w15860w(0) <= wire_w_lg_w_lg_w_lg_w15856w15857w15858w15859w(0) OR nlli1li;
	wire_w15848w(0) <= wire_w_lg_w_lg_w_lg_w15844w15845w15846w15847w(0) OR nlli1ll;
	wire_w_lg_w_lg_w_lg_w2574w2575w2576w2577w(0) <= wire_w_lg_w_lg_w2574w2575w2576w(0) OR nliiOl;
	wire_w_lg_w_lg_w_lg_w2566w2567w2568w2569w(0) <= wire_w_lg_w_lg_w2566w2567w2568w(0) OR nliiOO;
	wire_w_lg_w_lg_w_lg_w2558w2559w2560w2561w(0) <= wire_w_lg_w_lg_w2558w2559w2560w(0) OR nlil1i;
	wire_w_lg_w_lg_w_lg_w2582w2583w2584w2585w(0) <= wire_w_lg_w_lg_w2582w2583w2584w(0) OR nl1lOi;
	wire_w_lg_w15836w15837w(0) <= wire_w15836w(0) OR nlli1ll;
	wire_w_lg_w15824w15825w(0) <= wire_w15824w(0) OR nlli1lO;
	wire_w_lg_w15920w15921w(0) <= wire_w15920w(0) OR nlli10i;
	wire_w_lg_w15908w15909w(0) <= wire_w15908w(0) OR nlli10l;
	wire_w_lg_w15896w15897w(0) <= wire_w15896w(0) OR nlli10O;
	wire_w_lg_w15884w15885w(0) <= wire_w15884w(0) OR nlli1ii;
	wire_w_lg_w15872w15873w(0) <= wire_w15872w(0) OR nlli1il;
	wire_w_lg_w15860w15861w(0) <= wire_w15860w(0) OR nlli1iO;
	wire_w_lg_w15848w15849w(0) <= wire_w15848w(0) OR nlli1li;
	wire_w_lg_w_lg_w15836w15837w15838w(0) <= wire_w_lg_w15836w15837w(0) OR nlli1li;
	wire_w_lg_w_lg_w15824w15825w15826w(0) <= wire_w_lg_w15824w15825w(0) OR nlli1ll;
	wire_w_lg_w_lg_w15920w15921w15922w(0) <= wire_w_lg_w15920w15921w(0) OR nlli11O;
	wire_w_lg_w_lg_w15908w15909w15910w(0) <= wire_w_lg_w15908w15909w(0) OR nlli10i;
	wire_w_lg_w_lg_w15896w15897w15898w(0) <= wire_w_lg_w15896w15897w(0) OR nlli10l;
	wire_w_lg_w_lg_w15884w15885w15886w(0) <= wire_w_lg_w15884w15885w(0) OR nlli10O;
	wire_w_lg_w_lg_w15872w15873w15874w(0) <= wire_w_lg_w15872w15873w(0) OR nlli1ii;
	wire_w_lg_w_lg_w15860w15861w15862w(0) <= wire_w_lg_w15860w15861w(0) OR nlli1il;
	wire_w_lg_w_lg_w15848w15849w15850w(0) <= wire_w_lg_w15848w15849w(0) OR nlli1iO;
	wire_w_lg_w_lg_w_lg_w15836w15837w15838w15839w(0) <= wire_w_lg_w_lg_w15836w15837w15838w(0) OR nlli1iO;
	wire_w_lg_w_lg_w_lg_w15824w15825w15826w15827w(0) <= wire_w_lg_w_lg_w15824w15825w15826w(0) OR nlli1li;
	wire_w_lg_w_lg_w_lg_w15920w15921w15922w15923w(0) <= wire_w_lg_w_lg_w15920w15921w15922w(0) OR nlli11l;
	wire_w_lg_w_lg_w_lg_w15908w15909w15910w15911w(0) <= wire_w_lg_w_lg_w15908w15909w15910w(0) OR nlli11O;
	wire_w_lg_w_lg_w_lg_w15896w15897w15898w15899w(0) <= wire_w_lg_w_lg_w15896w15897w15898w(0) OR nlli10i;
	wire_w_lg_w_lg_w_lg_w15884w15885w15886w15887w(0) <= wire_w_lg_w_lg_w15884w15885w15886w(0) OR nlli10l;
	wire_w_lg_w_lg_w_lg_w15872w15873w15874w15875w(0) <= wire_w_lg_w_lg_w15872w15873w15874w(0) OR nlli10O;
	wire_w_lg_w_lg_w_lg_w15860w15861w15862w15863w(0) <= wire_w_lg_w_lg_w15860w15861w15862w(0) OR nlli1ii;
	wire_w_lg_w_lg_w_lg_w15848w15849w15850w15851w(0) <= wire_w_lg_w_lg_w15848w15849w15850w(0) OR nlli1il;
	wire_w15840w(0) <= wire_w_lg_w_lg_w_lg_w15836w15837w15838w15839w(0) OR nlli1il;
	wire_w15828w(0) <= wire_w_lg_w_lg_w_lg_w15824w15825w15826w15827w(0) OR nlli1iO;
	wire_w15924w(0) <= wire_w_lg_w_lg_w_lg_w15920w15921w15922w15923w(0) OR nlli11i;
	wire_w15912w(0) <= wire_w_lg_w_lg_w_lg_w15908w15909w15910w15911w(0) OR nlli11l;
	wire_w15900w(0) <= wire_w_lg_w_lg_w_lg_w15896w15897w15898w15899w(0) OR nlli11O;
	wire_w15888w(0) <= wire_w_lg_w_lg_w_lg_w15884w15885w15886w15887w(0) OR nlli10i;
	wire_w15876w(0) <= wire_w_lg_w_lg_w_lg_w15872w15873w15874w15875w(0) OR nlli10l;
	wire_w15864w(0) <= wire_w_lg_w_lg_w_lg_w15860w15861w15862w15863w(0) OR nlli10O;
	wire_w15852w(0) <= wire_w_lg_w_lg_w_lg_w15848w15849w15850w15851w(0) OR nlli1ii;
	wire_w_lg_w15840w15841w(0) <= wire_w15840w(0) OR nlli1ii;
	wire_w_lg_w15828w15829w(0) <= wire_w15828w(0) OR nlli1il;
	wire_w_lg_w15924w15925w(0) <= wire_w15924w(0) OR nll0OOO;
	wire_w_lg_w15912w15913w(0) <= wire_w15912w(0) OR nlli11i;
	wire_w_lg_w15900w15901w(0) <= wire_w15900w(0) OR nlli11l;
	wire_w_lg_w15888w15889w(0) <= wire_w15888w(0) OR nlli11O;
	wire_w_lg_w15876w15877w(0) <= wire_w15876w(0) OR nlli10i;
	wire_w_lg_w15864w15865w(0) <= wire_w15864w(0) OR nlli10l;
	wire_w_lg_w15852w15853w(0) <= wire_w15852w(0) OR nlli10O;
	wire_w_lg_w_lg_w15840w15841w15842w(0) <= wire_w_lg_w15840w15841w(0) OR nlli10O;
	wire_w_lg_w_lg_w15828w15829w15830w(0) <= wire_w_lg_w15828w15829w(0) OR nlli1ii;
	wire_w_lg_w_lg_w15924w15925w15926w(0) <= wire_w_lg_w15924w15925w(0) OR nll0OOl;
	wire_w_lg_w_lg_w15912w15913w15914w(0) <= wire_w_lg_w15912w15913w(0) OR nll0OOO;
	wire_w_lg_w_lg_w15900w15901w15902w(0) <= wire_w_lg_w15900w15901w(0) OR nlli11i;
	wire_w_lg_w_lg_w15888w15889w15890w(0) <= wire_w_lg_w15888w15889w(0) OR nlli11l;
	wire_w_lg_w_lg_w15876w15877w15878w(0) <= wire_w_lg_w15876w15877w(0) OR nlli11O;
	wire_w_lg_w_lg_w15864w15865w15866w(0) <= wire_w_lg_w15864w15865w(0) OR nlli10i;
	wire_w_lg_w_lg_w15852w15853w15854w(0) <= wire_w_lg_w15852w15853w(0) OR nlli10l;
	wire_w_lg_w_lg_w_lg_w15814w15815w15816w15817w(0) <= wire_w_lg_w_lg_w15814w15815w15816w(0) OR nll0OOl;
	wire_w_lg_w_lg_w_lg_w15804w15805w15806w15807w(0) <= wire_w_lg_w_lg_w15804w15805w15806w(0) OR nll0OOO;
	wire_w_lg_w_lg_w_lg_w15794w15795w15796w15797w(0) <= wire_w_lg_w_lg_w15794w15795w15796w(0) OR nlli11i;
	wire_w_lg_w_lg_w_lg_w15784w15785w15786w15787w(0) <= wire_w_lg_w_lg_w15784w15785w15786w(0) OR nlli11l;
	wire_w_lg_w_lg_w_lg_w15774w15775w15776w15777w(0) <= wire_w_lg_w_lg_w15774w15775w15776w(0) OR nlli11O;
	wire_w_lg_w_lg_w_lg_w15764w15765w15766w15767w(0) <= wire_w_lg_w_lg_w15764w15765w15766w(0) OR nlli10i;
	wire_w_lg_w_lg_w_lg_w15753w15754w15755w15756w(0) <= wire_w_lg_w_lg_w15753w15754w15755w(0) OR nlli10l;
	wire_w_lg_w_lg_w15814w15815w15816w(0) <= wire_w_lg_w15814w15815w(0) OR nll0OOO;
	wire_w_lg_w_lg_w15804w15805w15806w(0) <= wire_w_lg_w15804w15805w(0) OR nlli11i;
	wire_w_lg_w_lg_w15794w15795w15796w(0) <= wire_w_lg_w15794w15795w(0) OR nlli11l;
	wire_w_lg_w_lg_w15784w15785w15786w(0) <= wire_w_lg_w15784w15785w(0) OR nlli11O;
	wire_w_lg_w_lg_w15774w15775w15776w(0) <= wire_w_lg_w15774w15775w(0) OR nlli10i;
	wire_w_lg_w_lg_w15764w15765w15766w(0) <= wire_w_lg_w15764w15765w(0) OR nlli10l;
	wire_w_lg_w_lg_w15753w15754w15755w(0) <= wire_w_lg_w15753w15754w(0) OR nlli10O;
	wire_w_lg_w15814w15815w(0) <= wire_w15814w(0) OR nlli11i;
	wire_w_lg_w15804w15805w(0) <= wire_w15804w(0) OR nlli11l;
	wire_w_lg_w15794w15795w(0) <= wire_w15794w(0) OR nlli11O;
	wire_w_lg_w15784w15785w(0) <= wire_w15784w(0) OR nlli10i;
	wire_w_lg_w15774w15775w(0) <= wire_w15774w(0) OR nlli10l;
	wire_w_lg_w15764w15765w(0) <= wire_w15764w(0) OR nlli10O;
	wire_w_lg_w15753w15754w(0) <= wire_w15753w(0) OR nlli1ii;
	wire_w15814w(0) <= wire_w_lg_w_lg_w_lg_w15810w15811w15812w15813w(0) OR nlli11l;
	wire_w15804w(0) <= wire_w_lg_w_lg_w_lg_w15800w15801w15802w15803w(0) OR nlli11O;
	wire_w15794w(0) <= wire_w_lg_w_lg_w_lg_w15790w15791w15792w15793w(0) OR nlli10i;
	wire_w15784w(0) <= wire_w_lg_w_lg_w_lg_w15780w15781w15782w15783w(0) OR nlli10l;
	wire_w15774w(0) <= wire_w_lg_w_lg_w_lg_w15770w15771w15772w15773w(0) OR nlli10O;
	wire_w15764w(0) <= wire_w_lg_w_lg_w_lg_w15760w15761w15762w15763w(0) OR nlli1ii;
	wire_w15753w(0) <= wire_w_lg_w_lg_w_lg_w15749w15750w15751w15752w(0) OR nlli1il;
	wire_w_lg_w1202w1203w(0) <= wire_w1202w(0) OR n1i001O;
	wire_w_lg_w_lg_w17108w17109w17110w(0) <= wire_w_lg_w17108w17109w(0) OR nlOO1liO;
	wire_w_lg_w_lg_w16764w16765w16766w(0) <= wire_w_lg_w16764w16765w(0) OR nlOO0i1O;
	wire_w_lg_w_lg_w_lg_w15810w15811w15812w15813w(0) <= wire_w_lg_w_lg_w15810w15811w15812w(0) OR nlli11O;
	wire_w_lg_w_lg_w_lg_w15800w15801w15802w15803w(0) <= wire_w_lg_w_lg_w15800w15801w15802w(0) OR nlli10i;
	wire_w_lg_w_lg_w_lg_w15790w15791w15792w15793w(0) <= wire_w_lg_w_lg_w15790w15791w15792w(0) OR nlli10l;
	wire_w_lg_w_lg_w_lg_w15780w15781w15782w15783w(0) <= wire_w_lg_w_lg_w15780w15781w15782w(0) OR nlli10O;
	wire_w_lg_w_lg_w_lg_w15770w15771w15772w15773w(0) <= wire_w_lg_w_lg_w15770w15771w15772w(0) OR nlli1ii;
	wire_w_lg_w_lg_w_lg_w15760w15761w15762w15763w(0) <= wire_w_lg_w_lg_w15760w15761w15762w(0) OR nlli1il;
	wire_w_lg_w_lg_w_lg_w15749w15750w15751w15752w(0) <= wire_w_lg_w_lg_w15749w15750w15751w(0) OR nlli1iO;
	wire_w1202w(0) <= wire_w_lg_w_lg_w_lg_w_lg_n1i00ll1196w1197w1199w1201w(0) OR n1i000i;
	wire_w_lg_w17108w17109w(0) <= wire_w17108w(0) OR nlOO01ii;
	wire_w_lg_w16764w16765w(0) <= wire_w16764w(0) OR nlOO0O1i;
	wire_w_lg_w_lg_w15810w15811w15812w(0) <= wire_w_lg_w15810w15811w(0) OR nlli10i;
	wire_w_lg_w_lg_w15800w15801w15802w(0) <= wire_w_lg_w15800w15801w(0) OR nlli10l;
	wire_w_lg_w_lg_w15790w15791w15792w(0) <= wire_w_lg_w15790w15791w(0) OR nlli10O;
	wire_w_lg_w_lg_w15780w15781w15782w(0) <= wire_w_lg_w15780w15781w(0) OR nlli1ii;
	wire_w_lg_w_lg_w15770w15771w15772w(0) <= wire_w_lg_w15770w15771w(0) OR nlli1il;
	wire_w_lg_w_lg_w15760w15761w15762w(0) <= wire_w_lg_w15760w15761w(0) OR nlli1iO;
	wire_w_lg_w_lg_w15749w15750w15751w(0) <= wire_w_lg_w15749w15750w(0) OR nlli1li;
	wire_w_lg_w_lg_w2535w2536w2537w(0) <= wire_w_lg_w2535w2536w(0) OR nliiOO;
	wire_w_lg_w_lg_w2551w2552w2553w(0) <= wire_w_lg_w2551w2552w(0) OR nl1lOi;
	wire_w_lg_w_lg_w2544w2545w2546w(0) <= wire_w_lg_w2544w2545w(0) OR nliiOl;
	wire_w_lg_w_lg_w_lg_w_lg_n1i00ll1196w1197w1199w1201w(0) <= wire_w_lg_w_lg_w_lg_n1i00ll1196w1197w1199w(0) OR wire_w_lg_n1i000O1200w(0);
	wire_w17108w(0) <= wire_w_lg_w_lg_w_lg_nlOO010l17103w17104w17106w(0) OR wire_w_lg_nlOO1OOl17107w(0);
	wire_w16764w(0) <= wire_w_lg_w_lg_w_lg_nlOO0lOl16759w16760w16762w(0) OR wire_w_lg_nlOO0lil16763w(0);
	wire_w_lg_w15810w15811w(0) <= wire_w15810w(0) OR nlli10l;
	wire_w_lg_w15800w15801w(0) <= wire_w15800w(0) OR nlli10O;
	wire_w_lg_w15790w15791w(0) <= wire_w15790w(0) OR nlli1ii;
	wire_w_lg_w15780w15781w(0) <= wire_w15780w(0) OR nlli1il;
	wire_w_lg_w15770w15771w(0) <= wire_w15770w(0) OR nlli1iO;
	wire_w_lg_w15760w15761w(0) <= wire_w15760w(0) OR nlli1li;
	wire_w_lg_w15749w15750w(0) <= wire_w15749w(0) OR nlli1ll;
	wire_w_lg_w2535w2536w(0) <= wire_w2535w(0) OR nlil1i;
	wire_w_lg_w2551w2552w(0) <= wire_w2551w(0) OR nliiOl;
	wire_w_lg_w2544w2545w(0) <= wire_w2544w(0) OR nliiOO;
	wire_w_lg_w_lg_w_lg_n1i00ll1196w1197w1199w(0) <= wire_w_lg_w_lg_n1i00ll1196w1197w(0) OR wire_w_lg_n1i00il1198w(0);
	wire_w_lg_w_lg_w_lg_nlOO010l17103w17104w17106w(0) <= wire_w_lg_w_lg_nlOO010l17103w17104w(0) OR wire_w_lg_nlOO1llO17105w(0);
	wire_w_lg_w_lg_w_lg_nlOO0lOl16759w16760w16762w(0) <= wire_w_lg_w_lg_nlOO0lOl16759w16760w(0) OR wire_w_lg_nlOO0i0O16761w(0);
	wire_w15810w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w15747w15809w(0) OR nlli10O;
	wire_w15800w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w15747w15799w(0) OR nlli1ii;
	wire_w15790w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w15747w15789w(0) OR nlli1il;
	wire_w15780w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w15747w15779w(0) OR nlli1iO;
	wire_w15770w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w15747w15769w(0) OR nlli1li;
	wire_w15760w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w15747w15759w(0) OR nlli1ll;
	wire_w15749w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w15747w15748w(0) OR nlli1lO;
	wire_w2535w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w2533w2534w(0) OR nlil1l;
	wire_w2551w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w2549w2550w(0) OR nliiOO;
	wire_w2544w(0) <= wire_w_lg_w_lg_w_pmadwidth_range175w2542w2543w(0) OR nlil1i;
	wire_w_lg_w_lg_n10O10i3045w3048w(0) <= wire_w_lg_n10O10i3045w(0) OR wire_w_lg_n10O11l3047w(0);
	wire_w_lg_w_lg_n10O10l3063w3067w(0) <= wire_w_lg_n10O10l3063w(0) OR wire_niOl0l_w_lg_w_lg_dataout3064w3066w(0);
	wire_w_lg_w_lg_n1i00ll1196w1197w(0) <= wire_w_lg_n1i00ll1196w(0) OR n1i00iO;
	wire_w_lg_w_lg_nlOO010l17103w17104w(0) <= wire_w_lg_nlOO010l17103w(0) OR nlOO010i;
	wire_w_lg_w_lg_nlOO01Oi16918w16921w(0) <= wire_w_lg_nlOO01Oi16918w(0) OR wire_w_lg_nlOO01ll16920w(0);
	wire_w_lg_w_lg_nlOO01Ol16936w16940w(0) <= wire_w_lg_nlOO01Ol16936w(0) OR wire_nl1ll1O_w_lg_w_lg_o16937w16939w(0);
	wire_w_lg_w_lg_nlOO0lOl16759w16760w(0) <= wire_w_lg_nlOO0lOl16759w(0) OR nlOO0lOi;
	wire_w_lg_w_lg_nlOO0Oii16574w16577w(0) <= wire_w_lg_nlOO0Oii16574w(0) OR wire_w_lg_nlOO0O0l16576w(0);
	wire_w_lg_w_lg_nlOO0Oil16592w16596w(0) <= wire_w_lg_nlOO0Oil16592w(0) OR wire_nl1llOi_w_lg_w_lg_o16593w16595w(0);
	wire_w_lg_w_lg_w_pmadwidth_range175w15747w15809w(0) <= wire_w_lg_w_pmadwidth_range175w15747w(0) OR nlli1ii;
	wire_w_lg_w_lg_w_pmadwidth_range175w15747w15799w(0) <= wire_w_lg_w_pmadwidth_range175w15747w(0) OR nlli1il;
	wire_w_lg_w_lg_w_pmadwidth_range175w15747w15789w(0) <= wire_w_lg_w_pmadwidth_range175w15747w(0) OR nlli1iO;
	wire_w_lg_w_lg_w_pmadwidth_range175w15747w15779w(0) <= wire_w_lg_w_pmadwidth_range175w15747w(0) OR nlli1li;
	wire_w_lg_w_lg_w_pmadwidth_range175w15747w15769w(0) <= wire_w_lg_w_pmadwidth_range175w15747w(0) OR nlli1ll;
	wire_w_lg_w_lg_w_pmadwidth_range175w15747w15759w(0) <= wire_w_lg_w_pmadwidth_range175w15747w(0) OR nlli1lO;
	wire_w_lg_w_lg_w_pmadwidth_range175w15747w15748w(0) <= wire_w_lg_w_pmadwidth_range175w15747w(0) OR nlli1Oi;
	wire_w_lg_w_lg_w_pmadwidth_range175w2533w2534w(0) <= wire_w_lg_w_pmadwidth_range175w2533w(0) OR nlil1O;
	wire_w_lg_w_lg_w_pmadwidth_range175w2549w2550w(0) <= wire_w_lg_w_pmadwidth_range175w2549w(0) OR nlil1i;
	wire_w_lg_w_lg_w_pmadwidth_range175w2542w2543w(0) <= wire_w_lg_w_pmadwidth_range175w2542w(0) OR nlil1l;
	wire_w_lg_lpbk_en4495w(0) <= lpbk_en OR nll01lO;
	wire_w_lg_n10l10O4521w(0) <= n10l10O OR n10l10l;
	wire_w_lg_n10l1ii4522w(0) <= n10l1ii OR wire_w_lg_n10l10O4521w(0);
	wire_w_lg_n10l1il4510w(0) <= n10l1il OR wire_w_lg_rencdt_rising4509w(0);
	wire_w_lg_n10lOOO3237w(0) <= n10lOOO OR wire_w_lg_n1i00il3236w(0);
	wire_w_lg_n10lOOO3073w(0) <= n10lOOO OR n10lOOl;
	wire_w_lg_n10O10i3045w(0) <= n10O10i OR wire_w_lg_n10O10i3044w(0);
	wire_w_lg_n10O10l3063w(0) <= n10O10l OR wire_w_lg_n10O10l3062w(0);
	wire_w_lg_n10O11i3074w(0) <= n10O11i OR wire_w_lg_n10lOOO3073w(0);
	wire_w_lg_n10O1lO2970w(0) <= n10O1lO OR n10O1ll;
	wire_w_lg_n10O1Oi2971w(0) <= n10O1Oi OR wire_w_lg_n10O1lO2970w(0);
	wire_w_lg_n1111li14881w(0) <= n1111li OR wire_w_lg_nlOOlO0i14866w(0);
	wire_w_lg_n1111li14859w(0) <= n1111li OR wire_w_lg_nlOOlOil14858w(0);
	wire_w_lg_n1i000i3077w(0) <= n1i000i OR wire_w_lg_n1i00li3076w(0);
	wire_w_lg_n1i001l1207w(0) <= n1i001l OR wire_niOiOl_w_lg_w_lg_o1205w1206w(0);
	wire_w_lg_n1i00li3076w(0) <= n1i00li OR wire_w_lg_n1i00ll3075w(0);
	wire_w_lg_n1i00ll3075w(0) <= n1i00ll OR n1i00iO;
	wire_w_lg_n1i00ll1196w(0) <= n1i00ll OR n1i00li;
	wire_w_lg_n1i01lO1217w(0) <= n1i01lO OR wire_niOl1O_w_lg_o1216w(0);
	wire_w_lg_n1i01Ol1210w(0) <= n1i01Ol OR n1i01Oi;
	wire_w_lg_n1i01OO1211w(0) <= n1i01OO OR wire_w_lg_n1i01Ol1210w(0);
	wire_w_lg_n1i101i2395w(0) <= n1i101i OR wire_w_lg_n10OlOO2394w(0);
	wire_w_lg_n1i101i2497w(0) <= n1i101i OR wire_w_lg_n10OO1i2402w(0);
	wire_w_lg_n1i11ii2450w(0) <= n1i11ii OR wire_w_lg_n10Ol0l2449w(0);
	wire_w_lg_n1i11ii2507w(0) <= n1i11ii OR wire_w_lg_n10Ol0O2457w(0);
	wire_w_lg_n1i1iii2340w(0) <= n1i1iii OR wire_w_lg_n10OOli2339w(0);
	wire_w_lg_n1i1iii2473w(0) <= n1i1iii OR wire_w_lg_n10OOll2347w(0);
	wire_w_lg_n1i1l1i2286w(0) <= n1i1l1i OR wire_w_lg_n1i110l2285w(0);
	wire_w_lg_n1i1l1i2463w(0) <= n1i1l1i OR wire_w_lg_n1i110O2293w(0);
	wire_w_lg_n1i1O0O1326w(0) <= n1i1O0O OR n1i1O0l;
	wire_w_lg_n1i1Oil1323w(0) <= n1i1Oil OR n1i1Oii;
	wire_w_lg_n1i1Oll3095w(0) <= n1i1Oll OR wire_w_lg_n1i1OlO3094w(0);
	wire_w_lg_n1i1OlO3094w(0) <= n1i1OlO OR n10lOlO;
	wire_w_lg_nlOO000O16840w(0) <= nlOO000O OR nlOO000l;
	wire_w_lg_nlOO00ii16841w(0) <= nlOO00ii OR wire_w_lg_nlOO000O16840w(0);
	wire_w_lg_nlOO010l16948w(0) <= nlOO010l OR nlOO010i;
	wire_w_lg_nlOO010l17103w(0) <= nlOO010l OR nlOO010O;
	wire_w_lg_nlOO010O16949w(0) <= nlOO010O OR wire_w_lg_nlOO010l16948w(0);
	wire_w_lg_nlOO011i16972w(0) <= nlOO011i OR nlOO1OlO;
	wire_w_lg_nlOO01ii16950w(0) <= nlOO01ii OR wire_w_lg_nlOO010O16949w(0);
	wire_w_lg_nlOO01iO17133w(0) <= nlOO01iO OR wire_w_lg_nlOO1llO17132w(0);
	wire_w_lg_nlOO01iO16946w(0) <= nlOO01iO OR nlOO01il;
	wire_w_lg_nlOO01li16947w(0) <= nlOO01li OR wire_w_lg_nlOO01iO16946w(0);
	wire_w_lg_nlOO01Oi16918w(0) <= nlOO01Oi OR wire_w_lg_nlOO01Oi16917w(0);
	wire_w_lg_nlOO01Ol16936w(0) <= nlOO01Ol OR wire_w_lg_nlOO01Ol16935w(0);
	wire_w_lg_nlOO0i1l16769w(0) <= nlOO0i1l OR wire_nl1llii_w_lg_w_lg_o16569w16768w(0);
	wire_w_lg_nlOO0ilO16773w(0) <= nlOO0ilO OR wire_w_lg_nlOO0l0i16772w(0);
	wire_w_lg_nlOO0iOl16779w(0) <= nlOO0iOl OR wire_nl1llll_w_lg_o16778w(0);
	wire_w_lg_nlOO0l0i16772w(0) <= nlOO0l0i OR nlOO0lll;
	wire_w_lg_nlOO0liO16629w(0) <= nlOO0liO OR wire_w_lg_nlOO0lli16628w(0);
	wire_w_lg_nlOO0lli16628w(0) <= nlOO0lli OR nlOO0l0O;
	wire_w_lg_nlOO0lOl16604w(0) <= nlOO0lOl OR nlOO0lOi;
	wire_w_lg_nlOO0lOl16759w(0) <= nlOO0lOl OR nlOO0lOO;
	wire_w_lg_nlOO0lOO16605w(0) <= nlOO0lOO OR wire_w_lg_nlOO0lOl16604w(0);
	wire_w_lg_nlOO0O0i16603w(0) <= nlOO0O0i OR wire_w_lg_nlOO0O1O16602w(0);
	wire_w_lg_nlOO0O1i16606w(0) <= nlOO0O1i OR wire_w_lg_nlOO0lOO16605w(0);
	wire_w_lg_nlOO0O1O16789w(0) <= nlOO0O1O OR wire_w_lg_nlOO0i0O16788w(0);
	wire_w_lg_nlOO0O1O16602w(0) <= nlOO0O1O OR nlOO0O1l;
	wire_w_lg_nlOO0Oii16574w(0) <= nlOO0Oii OR wire_w_lg_nlOO0Oii16573w(0);
	wire_w_lg_nlOO0Oil16592w(0) <= nlOO0Oil OR wire_w_lg_nlOO0Oil16591w(0);
	wire_w_lg_nlOO0OOO16496w(0) <= nlOO0OOO OR nlOO0OOl;
	wire_w_lg_nlOO1lil17113w(0) <= nlOO1lil OR wire_nl1lilO_w_lg_w_lg_o16913w17112w(0);
	wire_w_lg_nlOO1O0l17123w(0) <= nlOO1O0l OR wire_nl1ll1i_w_lg_o17122w(0);
	wire_w_lg_nlOO1O1O17117w(0) <= nlOO1O1O OR wire_w_lg_nlOO1Oli17116w(0);
	wire_w_lg_nlOO1Oli17116w(0) <= nlOO1Oli OR nlOO011l;
	wire_w_lg_nlOO1OOO16973w(0) <= nlOO1OOO OR wire_w_lg_nlOO011i16972w(0);
	wire_w_lg_nlOOi11i16497w(0) <= nlOOi11i OR wire_w_lg_nlOO0OOO16496w(0);
	wire_w_lg_nlOOlOiO15611w(0) <= nlOOlOiO OR wire_w_lg_nlOOiOii15596w(0);
	wire_w_lg_nlOOlOiO15589w(0) <= nlOOlOiO OR wire_w_lg_nlOOiOll15588w(0);
	wire_w_lg_nlOOO1OO15345w(0) <= nlOOO1OO OR wire_w_lg_nlOOl00l15344w(0);
	wire_w_lg_nlOOO1OO15367w(0) <= nlOOO1OO OR wire_w_lg_nlOOl01i15352w(0);
	wire_w_lg_nlOOOO0i15123w(0) <= nlOOOO0i OR wire_w_lg_nlOOlili15108w(0);
	wire_w_lg_nlOOOO0i15101w(0) <= nlOOOO0i OR wire_w_lg_nlOOliOl15100w(0);
	wire_w_lg_w_pmadwidth_range175w2589w(0) <= wire_w_pmadwidth_range175w(0) OR wire_nl_w_lg_nlil0i2588w(0);
	wire_w_lg_w_pmadwidth_range175w2608w(0) <= wire_w_pmadwidth_range175w(0) OR wire_nl_w_lg_nlil1l2592w(0);
	wire_w_lg_w_pmadwidth_range175w2600w(0) <= wire_w_pmadwidth_range175w(0) OR wire_nl_w_lg_nlil1O2590w(0);
	wire_w_lg_w_pmadwidth_range175w15747w(0) <= wire_w_pmadwidth_range175w(0) OR wire_nl_w_lg_nlli0lO15746w(0);
	wire_w_lg_w_pmadwidth_range175w2533w(0) <= wire_w_pmadwidth_range175w(0) OR nlil0i;
	wire_w_lg_w_pmadwidth_range175w2549w(0) <= wire_w_pmadwidth_range175w(0) OR nlil1l;
	wire_w_lg_w_pmadwidth_range175w2542w(0) <= wire_w_pmadwidth_range175w(0) OR nlil1O;
	a1a2_k1k2_flag <= ( wire_niiiO_dataout & wire_niiil_dataout & wire_niiii_dataout & wire_nii0O_dataout);
	adata <= ( wire_niOili_dataout & wire_niOiiO_dataout & wire_niOiil_dataout & wire_niOiii_dataout & wire_niOi0O_dataout & wire_niOi0l_dataout & wire_niOi0i_dataout & wire_niOi1O_dataout & wire_niOi1l_dataout & wire_niOi1i_dataout);
	adata_valid <= nlO01ii;
	cg_syncpat <= ( wire_nlOi_dataout & wire_nllO_dataout);
	kchar <= niiill;
	kcount <= ( nlO0ill & nlO0ili & nlO0iiO & nlO0iil & nlO0iii & nlO0i0O & nlO0i0l & nlO0i0i & nlO0i1O & nlO0i1l);
	n10000i <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0l1O)) AND (NOT ((NOT comp_pat(11)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(12)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(13)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(14)) XOR nll0lii))) AND (NOT ((NOT comp_pat(15)) XOR nll0lil))) AND (NOT ((NOT comp_pat(16)) XOR nll0liO))) AND (NOT ((NOT comp_pat(17)) XOR nll0lli))) AND (NOT ((NOT comp_pat(18)) XOR nll0lll))) AND (NOT ((NOT comp_pat(19)) XOR nll0llO)));
	n10000l <= (n10i10O AND ((comp_pat_porn AND n1000ii) OR n10000O));
	n10000O <= ((((((((((NOT (comp_pat(10) XOR nll0l1l)) AND (NOT (comp_pat(11) XOR nll0l1O))) AND (NOT (comp_pat(12) XOR nll0l0i))) AND (NOT (comp_pat(13) XOR nll0l0l))) AND (NOT (comp_pat(14) XOR nll0l0O))) AND (NOT (comp_pat(15) XOR nll0lii))) AND (NOT (comp_pat(16) XOR nll0lil))) AND (NOT (comp_pat(17) XOR nll0liO))) AND (NOT (comp_pat(18) XOR nll0lli))) AND (NOT (comp_pat(19) XOR nll0lll)));
	n10001i <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0l0i)) AND (NOT ((NOT comp_pat(11)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(12)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(13)) XOR nll0lii))) AND (NOT ((NOT comp_pat(14)) XOR nll0lil))) AND (NOT ((NOT comp_pat(15)) XOR nll0liO))) AND (NOT ((NOT comp_pat(16)) XOR nll0lli))) AND (NOT ((NOT comp_pat(17)) XOR nll0lll))) AND (NOT ((NOT comp_pat(18)) XOR nll0llO))) AND (NOT ((NOT comp_pat(19)) XOR nll0lOi)));
	n10001l <= (n10i11O AND ((comp_pat_porn AND n10000i) OR n10001O));
	n10001O <= ((((((((((NOT (comp_pat(10) XOR nll0l1O)) AND (NOT (comp_pat(11) XOR nll0l0i))) AND (NOT (comp_pat(12) XOR nll0l0l))) AND (NOT (comp_pat(13) XOR nll0l0O))) AND (NOT (comp_pat(14) XOR nll0lii))) AND (NOT (comp_pat(15) XOR nll0lil))) AND (NOT (comp_pat(16) XOR nll0liO))) AND (NOT (comp_pat(17) XOR nll0lli))) AND (NOT (comp_pat(18) XOR nll0lll))) AND (NOT (comp_pat(19) XOR nll0llO)));
	n1000ii <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0l1l)) AND (NOT ((NOT comp_pat(11)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(12)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(13)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(14)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(15)) XOR nll0lii))) AND (NOT ((NOT comp_pat(16)) XOR nll0lil))) AND (NOT ((NOT comp_pat(17)) XOR nll0liO))) AND (NOT ((NOT comp_pat(18)) XOR nll0lli))) AND (NOT ((NOT comp_pat(19)) XOR nll0lll)));
	n1000il <= (n10i1iO AND ((comp_pat_porn AND n1000li) OR n1000iO));
	n1000iO <= ((((((((((NOT (comp_pat(10) XOR nll0l1i)) AND (NOT (comp_pat(11) XOR nll0l1l))) AND (NOT (comp_pat(12) XOR nll0l1O))) AND (NOT (comp_pat(13) XOR nll0l0i))) AND (NOT (comp_pat(14) XOR nll0l0l))) AND (NOT (comp_pat(15) XOR nll0l0O))) AND (NOT (comp_pat(16) XOR nll0lii))) AND (NOT (comp_pat(17) XOR nll0lil))) AND (NOT (comp_pat(18) XOR nll0liO))) AND (NOT (comp_pat(19) XOR nll0lli)));
	n1000li <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0l1i)) AND (NOT ((NOT comp_pat(11)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(12)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(13)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(14)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(15)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(16)) XOR nll0lii))) AND (NOT ((NOT comp_pat(17)) XOR nll0lil))) AND (NOT ((NOT comp_pat(18)) XOR nll0liO))) AND (NOT ((NOT comp_pat(19)) XOR nll0lli)));
	n1000ll <= (n10i1lO AND ((comp_pat_porn AND n1000Oi) OR n1000lO));
	n1000lO <= ((((((((((NOT (comp_pat(10) XOR nll0iOO)) AND (NOT (comp_pat(11) XOR nll0l1i))) AND (NOT (comp_pat(12) XOR nll0l1l))) AND (NOT (comp_pat(13) XOR nll0l1O))) AND (NOT (comp_pat(14) XOR nll0l0i))) AND (NOT (comp_pat(15) XOR nll0l0l))) AND (NOT (comp_pat(16) XOR nll0l0O))) AND (NOT (comp_pat(17) XOR nll0lii))) AND (NOT (comp_pat(18) XOR nll0lil))) AND (NOT (comp_pat(19) XOR nll0liO)));
	n1000Oi <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0iOO)) AND (NOT ((NOT comp_pat(11)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(12)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(13)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(14)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(15)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(16)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(17)) XOR nll0lii))) AND (NOT ((NOT comp_pat(18)) XOR nll0lil))) AND (NOT ((NOT comp_pat(19)) XOR nll0liO)));
	n1000Ol <= (((((((((((((((((((n10i1lO OR n10i1iO) OR n10i10O) OR n10i11O) OR n100OOO) OR n100OlO) OR n100OiO) OR n100O0O) OR n100O1O) OR n100lOO) OR n100llO) OR n100liO) OR n100l0O) OR n100l1O) OR n100iOO) OR n100ilO) OR n100iiO) OR n100i0O) OR n100i1O) OR n1000OO);
	n1000OO <= ((comp_pat_porn AND n100i1l) OR n100i1i);
	n10010i <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0lil)) AND (NOT ((NOT comp_pat(11)) XOR nll0liO))) AND (NOT ((NOT comp_pat(12)) XOR nll0lli))) AND (NOT ((NOT comp_pat(13)) XOR nll0lll))) AND (NOT ((NOT comp_pat(14)) XOR nll0llO))) AND (NOT ((NOT comp_pat(15)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(16)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(17)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(18)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(19)) XOR nll0O1l)));
	n10010l <= (n100O0O AND ((comp_pat_porn AND n1001ii) OR n10010O));
	n10010O <= ((((((((((NOT (comp_pat(10) XOR nll0lii)) AND (NOT (comp_pat(11) XOR nll0lil))) AND (NOT (comp_pat(12) XOR nll0liO))) AND (NOT (comp_pat(13) XOR nll0lli))) AND (NOT (comp_pat(14) XOR nll0lll))) AND (NOT (comp_pat(15) XOR nll0llO))) AND (NOT (comp_pat(16) XOR nll0lOi))) AND (NOT (comp_pat(17) XOR nll0lOl))) AND (NOT (comp_pat(18) XOR nll0lOO))) AND (NOT (comp_pat(19) XOR nll0O1i)));
	n10011i <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0liO)) AND (NOT ((NOT comp_pat(11)) XOR nll0lli))) AND (NOT ((NOT comp_pat(12)) XOR nll0lll))) AND (NOT ((NOT comp_pat(13)) XOR nll0llO))) AND (NOT ((NOT comp_pat(14)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(15)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(16)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(17)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(18)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(19)) XOR nll0O1O)));
	n10011l <= (n100O1O AND ((comp_pat_porn AND n10010i) OR n10011O));
	n10011O <= ((((((((((NOT (comp_pat(10) XOR nll0lil)) AND (NOT (comp_pat(11) XOR nll0liO))) AND (NOT (comp_pat(12) XOR nll0lli))) AND (NOT (comp_pat(13) XOR nll0lll))) AND (NOT (comp_pat(14) XOR nll0llO))) AND (NOT (comp_pat(15) XOR nll0lOi))) AND (NOT (comp_pat(16) XOR nll0lOl))) AND (NOT (comp_pat(17) XOR nll0lOO))) AND (NOT (comp_pat(18) XOR nll0O1i))) AND (NOT (comp_pat(19) XOR nll0O1l)));
	n1001ii <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0lii)) AND (NOT ((NOT comp_pat(11)) XOR nll0lil))) AND (NOT ((NOT comp_pat(12)) XOR nll0liO))) AND (NOT ((NOT comp_pat(13)) XOR nll0lli))) AND (NOT ((NOT comp_pat(14)) XOR nll0lll))) AND (NOT ((NOT comp_pat(15)) XOR nll0llO))) AND (NOT ((NOT comp_pat(16)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(17)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(18)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(19)) XOR nll0O1i)));
	n1001il <= (n100OiO AND ((comp_pat_porn AND n1001li) OR n1001iO));
	n1001iO <= ((((((((((NOT (comp_pat(10) XOR nll0l0O)) AND (NOT (comp_pat(11) XOR nll0lii))) AND (NOT (comp_pat(12) XOR nll0lil))) AND (NOT (comp_pat(13) XOR nll0liO))) AND (NOT (comp_pat(14) XOR nll0lli))) AND (NOT (comp_pat(15) XOR nll0lll))) AND (NOT (comp_pat(16) XOR nll0llO))) AND (NOT (comp_pat(17) XOR nll0lOi))) AND (NOT (comp_pat(18) XOR nll0lOl))) AND (NOT (comp_pat(19) XOR nll0lOO)));
	n1001li <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0l0O)) AND (NOT ((NOT comp_pat(11)) XOR nll0lii))) AND (NOT ((NOT comp_pat(12)) XOR nll0lil))) AND (NOT ((NOT comp_pat(13)) XOR nll0liO))) AND (NOT ((NOT comp_pat(14)) XOR nll0lli))) AND (NOT ((NOT comp_pat(15)) XOR nll0lll))) AND (NOT ((NOT comp_pat(16)) XOR nll0llO))) AND (NOT ((NOT comp_pat(17)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(18)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(19)) XOR nll0lOO)));
	n1001ll <= (n100OlO AND ((comp_pat_porn AND n1001Oi) OR n1001lO));
	n1001lO <= ((((((((((NOT (comp_pat(10) XOR nll0l0l)) AND (NOT (comp_pat(11) XOR nll0l0O))) AND (NOT (comp_pat(12) XOR nll0lii))) AND (NOT (comp_pat(13) XOR nll0lil))) AND (NOT (comp_pat(14) XOR nll0liO))) AND (NOT (comp_pat(15) XOR nll0lli))) AND (NOT (comp_pat(16) XOR nll0lll))) AND (NOT (comp_pat(17) XOR nll0llO))) AND (NOT (comp_pat(18) XOR nll0lOi))) AND (NOT (comp_pat(19) XOR nll0lOl)));
	n1001Oi <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0l0l)) AND (NOT ((NOT comp_pat(11)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(12)) XOR nll0lii))) AND (NOT ((NOT comp_pat(13)) XOR nll0lil))) AND (NOT ((NOT comp_pat(14)) XOR nll0liO))) AND (NOT ((NOT comp_pat(15)) XOR nll0lli))) AND (NOT ((NOT comp_pat(16)) XOR nll0lll))) AND (NOT ((NOT comp_pat(17)) XOR nll0llO))) AND (NOT ((NOT comp_pat(18)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(19)) XOR nll0lOl)));
	n1001Ol <= (n100OOO AND ((comp_pat_porn AND n10001i) OR n1001OO));
	n1001OO <= ((((((((((NOT (comp_pat(10) XOR nll0l0i)) AND (NOT (comp_pat(11) XOR nll0l0l))) AND (NOT (comp_pat(12) XOR nll0l0O))) AND (NOT (comp_pat(13) XOR nll0lii))) AND (NOT (comp_pat(14) XOR nll0lil))) AND (NOT (comp_pat(15) XOR nll0liO))) AND (NOT (comp_pat(16) XOR nll0lli))) AND (NOT (comp_pat(17) XOR nll0lll))) AND (NOT (comp_pat(18) XOR nll0llO))) AND (NOT (comp_pat(19) XOR nll0lOi)));
	n100i0i <= ((((((((((NOT (comp_pat(0) XOR nll0lil)) AND (NOT (comp_pat(1) XOR nll0liO))) AND (NOT (comp_pat(2) XOR nll0lli))) AND (NOT (comp_pat(3) XOR nll0lll))) AND (NOT (comp_pat(4) XOR nll0llO))) AND (NOT (comp_pat(5) XOR nll0lOi))) AND (NOT (comp_pat(6) XOR nll0lOl))) AND (NOT (comp_pat(7) XOR nll0lOO))) AND (NOT (comp_pat(8) XOR nll0O1i))) AND (NOT (comp_pat(9) XOR nll0O1l)));
	n100i0l <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0lil)) AND (NOT ((NOT comp_pat(1)) XOR nll0liO))) AND (NOT ((NOT comp_pat(2)) XOR nll0lli))) AND (NOT ((NOT comp_pat(3)) XOR nll0lll))) AND (NOT ((NOT comp_pat(4)) XOR nll0llO))) AND (NOT ((NOT comp_pat(5)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(6)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(7)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(8)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(9)) XOR nll0O1l)));
	n100i0O <= ((comp_pat_porn AND n100iil) OR n100iii);
	n100i1i <= ((((((((((NOT (comp_pat(0) XOR nll0liO)) AND (NOT (comp_pat(1) XOR nll0lli))) AND (NOT (comp_pat(2) XOR nll0lll))) AND (NOT (comp_pat(3) XOR nll0llO))) AND (NOT (comp_pat(4) XOR nll0lOi))) AND (NOT (comp_pat(5) XOR nll0lOl))) AND (NOT (comp_pat(6) XOR nll0lOO))) AND (NOT (comp_pat(7) XOR nll0O1i))) AND (NOT (comp_pat(8) XOR nll0O1l))) AND (NOT (comp_pat(9) XOR nll0O1O)));
	n100i1l <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0liO)) AND (NOT ((NOT comp_pat(1)) XOR nll0lli))) AND (NOT ((NOT comp_pat(2)) XOR nll0lll))) AND (NOT ((NOT comp_pat(3)) XOR nll0llO))) AND (NOT ((NOT comp_pat(4)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(5)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(6)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(7)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(8)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(9)) XOR nll0O1O)));
	n100i1O <= ((comp_pat_porn AND n100i0l) OR n100i0i);
	n100iii <= ((((((((((NOT (comp_pat(0) XOR nll0lii)) AND (NOT (comp_pat(1) XOR nll0lil))) AND (NOT (comp_pat(2) XOR nll0liO))) AND (NOT (comp_pat(3) XOR nll0lli))) AND (NOT (comp_pat(4) XOR nll0lll))) AND (NOT (comp_pat(5) XOR nll0llO))) AND (NOT (comp_pat(6) XOR nll0lOi))) AND (NOT (comp_pat(7) XOR nll0lOl))) AND (NOT (comp_pat(8) XOR nll0lOO))) AND (NOT (comp_pat(9) XOR nll0O1i)));
	n100iil <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0lii)) AND (NOT ((NOT comp_pat(1)) XOR nll0lil))) AND (NOT ((NOT comp_pat(2)) XOR nll0liO))) AND (NOT ((NOT comp_pat(3)) XOR nll0lli))) AND (NOT ((NOT comp_pat(4)) XOR nll0lll))) AND (NOT ((NOT comp_pat(5)) XOR nll0llO))) AND (NOT ((NOT comp_pat(6)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(7)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(8)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(9)) XOR nll0O1i)));
	n100iiO <= ((comp_pat_porn AND n100ill) OR n100ili);
	n100ili <= ((((((((((NOT (comp_pat(0) XOR nll0l0O)) AND (NOT (comp_pat(1) XOR nll0lii))) AND (NOT (comp_pat(2) XOR nll0lil))) AND (NOT (comp_pat(3) XOR nll0liO))) AND (NOT (comp_pat(4) XOR nll0lli))) AND (NOT (comp_pat(5) XOR nll0lll))) AND (NOT (comp_pat(6) XOR nll0llO))) AND (NOT (comp_pat(7) XOR nll0lOi))) AND (NOT (comp_pat(8) XOR nll0lOl))) AND (NOT (comp_pat(9) XOR nll0lOO)));
	n100ill <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0l0O)) AND (NOT ((NOT comp_pat(1)) XOR nll0lii))) AND (NOT ((NOT comp_pat(2)) XOR nll0lil))) AND (NOT ((NOT comp_pat(3)) XOR nll0liO))) AND (NOT ((NOT comp_pat(4)) XOR nll0lli))) AND (NOT ((NOT comp_pat(5)) XOR nll0lll))) AND (NOT ((NOT comp_pat(6)) XOR nll0llO))) AND (NOT ((NOT comp_pat(7)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(8)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(9)) XOR nll0lOO)));
	n100ilO <= ((comp_pat_porn AND n100iOl) OR n100iOi);
	n100iOi <= ((((((((((NOT (comp_pat(0) XOR nll0l0l)) AND (NOT (comp_pat(1) XOR nll0l0O))) AND (NOT (comp_pat(2) XOR nll0lii))) AND (NOT (comp_pat(3) XOR nll0lil))) AND (NOT (comp_pat(4) XOR nll0liO))) AND (NOT (comp_pat(5) XOR nll0lli))) AND (NOT (comp_pat(6) XOR nll0lll))) AND (NOT (comp_pat(7) XOR nll0llO))) AND (NOT (comp_pat(8) XOR nll0lOi))) AND (NOT (comp_pat(9) XOR nll0lOl)));
	n100iOl <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0l0l)) AND (NOT ((NOT comp_pat(1)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(2)) XOR nll0lii))) AND (NOT ((NOT comp_pat(3)) XOR nll0lil))) AND (NOT ((NOT comp_pat(4)) XOR nll0liO))) AND (NOT ((NOT comp_pat(5)) XOR nll0lli))) AND (NOT ((NOT comp_pat(6)) XOR nll0lll))) AND (NOT ((NOT comp_pat(7)) XOR nll0llO))) AND (NOT ((NOT comp_pat(8)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(9)) XOR nll0lOl)));
	n100iOO <= ((comp_pat_porn AND n100l1l) OR n100l1i);
	n100l0i <= ((((((((((NOT (comp_pat(0) XOR nll0l1O)) AND (NOT (comp_pat(1) XOR nll0l0i))) AND (NOT (comp_pat(2) XOR nll0l0l))) AND (NOT (comp_pat(3) XOR nll0l0O))) AND (NOT (comp_pat(4) XOR nll0lii))) AND (NOT (comp_pat(5) XOR nll0lil))) AND (NOT (comp_pat(6) XOR nll0liO))) AND (NOT (comp_pat(7) XOR nll0lli))) AND (NOT (comp_pat(8) XOR nll0lll))) AND (NOT (comp_pat(9) XOR nll0llO)));
	n100l0l <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0l1O)) AND (NOT ((NOT comp_pat(1)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(2)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(3)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(4)) XOR nll0lii))) AND (NOT ((NOT comp_pat(5)) XOR nll0lil))) AND (NOT ((NOT comp_pat(6)) XOR nll0liO))) AND (NOT ((NOT comp_pat(7)) XOR nll0lli))) AND (NOT ((NOT comp_pat(8)) XOR nll0lll))) AND (NOT ((NOT comp_pat(9)) XOR nll0llO)));
	n100l0O <= ((comp_pat_porn AND n100lil) OR n100lii);
	n100l1i <= ((((((((((NOT (comp_pat(0) XOR nll0l0i)) AND (NOT (comp_pat(1) XOR nll0l0l))) AND (NOT (comp_pat(2) XOR nll0l0O))) AND (NOT (comp_pat(3) XOR nll0lii))) AND (NOT (comp_pat(4) XOR nll0lil))) AND (NOT (comp_pat(5) XOR nll0liO))) AND (NOT (comp_pat(6) XOR nll0lli))) AND (NOT (comp_pat(7) XOR nll0lll))) AND (NOT (comp_pat(8) XOR nll0llO))) AND (NOT (comp_pat(9) XOR nll0lOi)));
	n100l1l <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0l0i)) AND (NOT ((NOT comp_pat(1)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(2)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(3)) XOR nll0lii))) AND (NOT ((NOT comp_pat(4)) XOR nll0lil))) AND (NOT ((NOT comp_pat(5)) XOR nll0liO))) AND (NOT ((NOT comp_pat(6)) XOR nll0lli))) AND (NOT ((NOT comp_pat(7)) XOR nll0lll))) AND (NOT ((NOT comp_pat(8)) XOR nll0llO))) AND (NOT ((NOT comp_pat(9)) XOR nll0lOi)));
	n100l1O <= ((comp_pat_porn AND n100l0l) OR n100l0i);
	n100lii <= ((((((((((NOT (comp_pat(0) XOR nll0l1l)) AND (NOT (comp_pat(1) XOR nll0l1O))) AND (NOT (comp_pat(2) XOR nll0l0i))) AND (NOT (comp_pat(3) XOR nll0l0l))) AND (NOT (comp_pat(4) XOR nll0l0O))) AND (NOT (comp_pat(5) XOR nll0lii))) AND (NOT (comp_pat(6) XOR nll0lil))) AND (NOT (comp_pat(7) XOR nll0liO))) AND (NOT (comp_pat(8) XOR nll0lli))) AND (NOT (comp_pat(9) XOR nll0lll)));
	n100lil <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0l1l)) AND (NOT ((NOT comp_pat(1)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(2)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(3)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(4)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(5)) XOR nll0lii))) AND (NOT ((NOT comp_pat(6)) XOR nll0lil))) AND (NOT ((NOT comp_pat(7)) XOR nll0liO))) AND (NOT ((NOT comp_pat(8)) XOR nll0lli))) AND (NOT ((NOT comp_pat(9)) XOR nll0lll)));
	n100liO <= ((comp_pat_porn AND n100lll) OR n100lli);
	n100lli <= ((((((((((NOT (comp_pat(0) XOR nll0l1i)) AND (NOT (comp_pat(1) XOR nll0l1l))) AND (NOT (comp_pat(2) XOR nll0l1O))) AND (NOT (comp_pat(3) XOR nll0l0i))) AND (NOT (comp_pat(4) XOR nll0l0l))) AND (NOT (comp_pat(5) XOR nll0l0O))) AND (NOT (comp_pat(6) XOR nll0lii))) AND (NOT (comp_pat(7) XOR nll0lil))) AND (NOT (comp_pat(8) XOR nll0liO))) AND (NOT (comp_pat(9) XOR nll0lli)));
	n100lll <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0l1i)) AND (NOT ((NOT comp_pat(1)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(2)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(3)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(4)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(5)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(6)) XOR nll0lii))) AND (NOT ((NOT comp_pat(7)) XOR nll0lil))) AND (NOT ((NOT comp_pat(8)) XOR nll0liO))) AND (NOT ((NOT comp_pat(9)) XOR nll0lli)));
	n100llO <= ((comp_pat_porn AND n100lOl) OR n100lOi);
	n100lOi <= ((((((((((NOT (comp_pat(0) XOR nll0iOO)) AND (NOT (comp_pat(1) XOR nll0l1i))) AND (NOT (comp_pat(2) XOR nll0l1l))) AND (NOT (comp_pat(3) XOR nll0l1O))) AND (NOT (comp_pat(4) XOR nll0l0i))) AND (NOT (comp_pat(5) XOR nll0l0l))) AND (NOT (comp_pat(6) XOR nll0l0O))) AND (NOT (comp_pat(7) XOR nll0lii))) AND (NOT (comp_pat(8) XOR nll0lil))) AND (NOT (comp_pat(9) XOR nll0liO)));
	n100lOl <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0iOO)) AND (NOT ((NOT comp_pat(1)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(2)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(3)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(4)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(5)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(6)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(7)) XOR nll0lii))) AND (NOT ((NOT comp_pat(8)) XOR nll0lil))) AND (NOT ((NOT comp_pat(9)) XOR nll0liO)));
	n100lOO <= ((comp_pat_porn AND n100O1l) OR n100O1i);
	n100O0i <= ((((((((((NOT (comp_pat(0) XOR nll0iOi)) AND (NOT (comp_pat(1) XOR nll0iOl))) AND (NOT (comp_pat(2) XOR nll0iOO))) AND (NOT (comp_pat(3) XOR nll0l1i))) AND (NOT (comp_pat(4) XOR nll0l1l))) AND (NOT (comp_pat(5) XOR nll0l1O))) AND (NOT (comp_pat(6) XOR nll0l0i))) AND (NOT (comp_pat(7) XOR nll0l0l))) AND (NOT (comp_pat(8) XOR nll0l0O))) AND (NOT (comp_pat(9) XOR nll0lii)));
	n100O0l <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0iOi)) AND (NOT ((NOT comp_pat(1)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(2)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(3)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(4)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(5)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(6)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(7)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(8)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(9)) XOR nll0lii)));
	n100O0O <= ((comp_pat_porn AND n100Oil) OR n100Oii);
	n100O1i <= ((((((((((NOT (comp_pat(0) XOR nll0iOl)) AND (NOT (comp_pat(1) XOR nll0iOO))) AND (NOT (comp_pat(2) XOR nll0l1i))) AND (NOT (comp_pat(3) XOR nll0l1l))) AND (NOT (comp_pat(4) XOR nll0l1O))) AND (NOT (comp_pat(5) XOR nll0l0i))) AND (NOT (comp_pat(6) XOR nll0l0l))) AND (NOT (comp_pat(7) XOR nll0l0O))) AND (NOT (comp_pat(8) XOR nll0lii))) AND (NOT (comp_pat(9) XOR nll0lil)));
	n100O1l <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0iOl)) AND (NOT ((NOT comp_pat(1)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(2)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(3)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(4)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(5)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(6)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(7)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(8)) XOR nll0lii))) AND (NOT ((NOT comp_pat(9)) XOR nll0lil)));
	n100O1O <= ((comp_pat_porn AND n100O0l) OR n100O0i);
	n100Oii <= ((((((((((NOT (comp_pat(0) XOR nll0ilO)) AND (NOT (comp_pat(1) XOR nll0iOi))) AND (NOT (comp_pat(2) XOR nll0iOl))) AND (NOT (comp_pat(3) XOR nll0iOO))) AND (NOT (comp_pat(4) XOR nll0l1i))) AND (NOT (comp_pat(5) XOR nll0l1l))) AND (NOT (comp_pat(6) XOR nll0l1O))) AND (NOT (comp_pat(7) XOR nll0l0i))) AND (NOT (comp_pat(8) XOR nll0l0l))) AND (NOT (comp_pat(9) XOR nll0l0O)));
	n100Oil <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0ilO)) AND (NOT ((NOT comp_pat(1)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(2)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(3)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(4)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(5)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(6)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(7)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(8)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(9)) XOR nll0l0O)));
	n100OiO <= ((comp_pat_porn AND n100Oll) OR n100Oli);
	n100Oli <= ((((((((((NOT (comp_pat(0) XOR nll0ill)) AND (NOT (comp_pat(1) XOR nll0ilO))) AND (NOT (comp_pat(2) XOR nll0iOi))) AND (NOT (comp_pat(3) XOR nll0iOl))) AND (NOT (comp_pat(4) XOR nll0iOO))) AND (NOT (comp_pat(5) XOR nll0l1i))) AND (NOT (comp_pat(6) XOR nll0l1l))) AND (NOT (comp_pat(7) XOR nll0l1O))) AND (NOT (comp_pat(8) XOR nll0l0i))) AND (NOT (comp_pat(9) XOR nll0l0l)));
	n100Oll <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0ill)) AND (NOT ((NOT comp_pat(1)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(2)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(3)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(4)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(5)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(6)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(7)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(8)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(9)) XOR nll0l0l)));
	n100OlO <= ((comp_pat_porn AND n100OOl) OR n100OOi);
	n100OOi <= ((((((((((NOT (comp_pat(0) XOR nll0ili)) AND (NOT (comp_pat(1) XOR nll0ill))) AND (NOT (comp_pat(2) XOR nll0ilO))) AND (NOT (comp_pat(3) XOR nll0iOi))) AND (NOT (comp_pat(4) XOR nll0iOl))) AND (NOT (comp_pat(5) XOR nll0iOO))) AND (NOT (comp_pat(6) XOR nll0l1i))) AND (NOT (comp_pat(7) XOR nll0l1l))) AND (NOT (comp_pat(8) XOR nll0l1O))) AND (NOT (comp_pat(9) XOR nll0l0i)));
	n100OOl <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0ili)) AND (NOT ((NOT comp_pat(1)) XOR nll0ill))) AND (NOT ((NOT comp_pat(2)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(3)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(4)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(5)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(6)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(7)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(8)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(9)) XOR nll0l0i)));
	n100OOO <= ((comp_pat_porn AND n10i11l) OR n10i11i);
	n10100i <= ((((((((((NOT (comp_pat(20) XOR nll0lOl)) AND (NOT (comp_pat(21) XOR nll0lOO))) AND (NOT (comp_pat(22) XOR nll0O1i))) AND (NOT (comp_pat(23) XOR nll0O1l))) AND (NOT (comp_pat(24) XOR nll0O1O))) AND (NOT (comp_pat(25) XOR nll0O0i))) AND (NOT (comp_pat(26) XOR nll0O0l))) AND (NOT (comp_pat(27) XOR nll0O0O))) AND (NOT (comp_pat(28) XOR nll0Oii))) AND (NOT (comp_pat(29) XOR nll0Oil)));
	n10100l <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0lOl)) AND (NOT ((NOT comp_pat(21)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(22)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(23)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(24)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(25)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(26)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(27)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(28)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(29)) XOR nll0Oil)));
	n10100O <= ((((((((((NOT (comp_pat(30) XOR nll0OiO)) AND (NOT (comp_pat(31) XOR nll0Oli))) AND (NOT (comp_pat(32) XOR nll0Oll))) AND (NOT (comp_pat(33) XOR nll0OlO))) AND (NOT (comp_pat(34) XOR nll0OOi))) AND (NOT (comp_pat(35) XOR nll0OOl))) AND (NOT (comp_pat(36) XOR nll0OOO))) AND (NOT (comp_pat(37) XOR nlli11i))) AND (NOT (comp_pat(38) XOR nlli11l))) AND (NOT (comp_pat(39) XOR nlli11O)));
	n10101i <= ((((((((((NOT (comp_pat(30) XOR nll0Oli)) AND (NOT (comp_pat(31) XOR nll0Oll))) AND (NOT (comp_pat(32) XOR nll0OlO))) AND (NOT (comp_pat(33) XOR nll0OOi))) AND (NOT (comp_pat(34) XOR nll0OOl))) AND (NOT (comp_pat(35) XOR nll0OOO))) AND (NOT (comp_pat(36) XOR nlli11i))) AND (NOT (comp_pat(37) XOR nlli11l))) AND (NOT (comp_pat(38) XOR nlli11O))) AND (NOT (comp_pat(39) XOR nlli10i)));
	n10101l <= ((((((((((NOT ((NOT comp_pat(30)) XOR nll0Oli)) AND (NOT ((NOT comp_pat(31)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(32)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(33)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(34)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(35)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(36)) XOR nlli11i))) AND (NOT ((NOT comp_pat(37)) XOR nlli11l))) AND (NOT ((NOT comp_pat(38)) XOR nlli11O))) AND (NOT ((NOT comp_pat(39)) XOR nlli10i)));
	n10101O <= (n1001Ol AND (wire_w_lg_w_lg_comp_pat_porn4780w4781w(0) AND wire_w_lg_w_lg_comp_pat_porn4782w4783w(0)));
	n1010ii <= ((((((((((NOT ((NOT comp_pat(30)) XOR nll0OiO)) AND (NOT ((NOT comp_pat(31)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(32)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(33)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(34)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(35)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(36)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(37)) XOR nlli11i))) AND (NOT ((NOT comp_pat(38)) XOR nlli11l))) AND (NOT ((NOT comp_pat(39)) XOR nlli11O)));
	n1010il <= (n10001l AND (wire_w_lg_w_lg_comp_pat_porn4774w4775w(0) AND wire_w_lg_w_lg_comp_pat_porn4776w4777w(0)));
	n1010iO <= ((((((((((NOT (comp_pat(20) XOR nll0lOi)) AND (NOT (comp_pat(21) XOR nll0lOl))) AND (NOT (comp_pat(22) XOR nll0lOO))) AND (NOT (comp_pat(23) XOR nll0O1i))) AND (NOT (comp_pat(24) XOR nll0O1l))) AND (NOT (comp_pat(25) XOR nll0O1O))) AND (NOT (comp_pat(26) XOR nll0O0i))) AND (NOT (comp_pat(27) XOR nll0O0l))) AND (NOT (comp_pat(28) XOR nll0O0O))) AND (NOT (comp_pat(29) XOR nll0Oii)));
	n1010li <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0lOi)) AND (NOT ((NOT comp_pat(21)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(22)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(23)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(24)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(25)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(26)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(27)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(28)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(29)) XOR nll0Oii)));
	n1010ll <= ((((((((((NOT (comp_pat(30) XOR nll0Oil)) AND (NOT (comp_pat(31) XOR nll0OiO))) AND (NOT (comp_pat(32) XOR nll0Oli))) AND (NOT (comp_pat(33) XOR nll0Oll))) AND (NOT (comp_pat(34) XOR nll0OlO))) AND (NOT (comp_pat(35) XOR nll0OOi))) AND (NOT (comp_pat(36) XOR nll0OOl))) AND (NOT (comp_pat(37) XOR nll0OOO))) AND (NOT (comp_pat(38) XOR nlli11i))) AND (NOT (comp_pat(39) XOR nlli11l)));
	n1010lO <= ((((((((((NOT ((NOT comp_pat(30)) XOR nll0Oil)) AND (NOT ((NOT comp_pat(31)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(32)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(33)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(34)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(35)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(36)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(37)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(38)) XOR nlli11i))) AND (NOT ((NOT comp_pat(39)) XOR nlli11l)));
	n1010Oi <= (n10000l AND (wire_w_lg_w_lg_comp_pat_porn4768w4769w(0) AND wire_w_lg_w_lg_comp_pat_porn4770w4771w(0)));
	n1010Ol <= ((((((((((NOT (comp_pat(20) XOR nll0llO)) AND (NOT (comp_pat(21) XOR nll0lOi))) AND (NOT (comp_pat(22) XOR nll0lOl))) AND (NOT (comp_pat(23) XOR nll0lOO))) AND (NOT (comp_pat(24) XOR nll0O1i))) AND (NOT (comp_pat(25) XOR nll0O1l))) AND (NOT (comp_pat(26) XOR nll0O1O))) AND (NOT (comp_pat(27) XOR nll0O0i))) AND (NOT (comp_pat(28) XOR nll0O0l))) AND (NOT (comp_pat(29) XOR nll0O0O)));
	n1010OO <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0llO)) AND (NOT ((NOT comp_pat(21)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(22)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(23)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(24)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(25)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(26)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(27)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(28)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(29)) XOR nll0O0O)));
	n10110i <= ((((((((((NOT (comp_pat(20) XOR nll0O1l)) AND (NOT (comp_pat(21) XOR nll0O1O))) AND (NOT (comp_pat(22) XOR nll0O0i))) AND (NOT (comp_pat(23) XOR nll0O0l))) AND (NOT (comp_pat(24) XOR nll0O0O))) AND (NOT (comp_pat(25) XOR nll0Oii))) AND (NOT (comp_pat(26) XOR nll0Oil))) AND (NOT (comp_pat(27) XOR nll0OiO))) AND (NOT (comp_pat(28) XOR nll0Oli))) AND (NOT (comp_pat(29) XOR nll0Oll)));
	n10110l <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0O1l)) AND (NOT ((NOT comp_pat(21)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(22)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(23)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(24)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(25)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(26)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(27)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(28)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(29)) XOR nll0Oll)));
	n10110O <= ((((((((((NOT (comp_pat(30) XOR nll0OlO)) AND (NOT (comp_pat(31) XOR nll0OOi))) AND (NOT (comp_pat(32) XOR nll0OOl))) AND (NOT (comp_pat(33) XOR nll0OOO))) AND (NOT (comp_pat(34) XOR nlli11i))) AND (NOT (comp_pat(35) XOR nlli11l))) AND (NOT (comp_pat(36) XOR nlli11O))) AND (NOT (comp_pat(37) XOR nlli10i))) AND (NOT (comp_pat(38) XOR nlli10l))) AND (NOT (comp_pat(39) XOR nlli10O)));
	n10111i <= ((((((((((NOT (comp_pat(30) XOR nll0OOi)) AND (NOT (comp_pat(31) XOR nll0OOl))) AND (NOT (comp_pat(32) XOR nll0OOO))) AND (NOT (comp_pat(33) XOR nlli11i))) AND (NOT (comp_pat(34) XOR nlli11l))) AND (NOT (comp_pat(35) XOR nlli11O))) AND (NOT (comp_pat(36) XOR nlli10i))) AND (NOT (comp_pat(37) XOR nlli10l))) AND (NOT (comp_pat(38) XOR nlli10O))) AND (NOT (comp_pat(39) XOR nlli1ii)));
	n10111l <= ((((((((((NOT ((NOT comp_pat(30)) XOR nll0OOi)) AND (NOT ((NOT comp_pat(31)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(32)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(33)) XOR nlli11i))) AND (NOT ((NOT comp_pat(34)) XOR nlli11l))) AND (NOT ((NOT comp_pat(35)) XOR nlli11O))) AND (NOT ((NOT comp_pat(36)) XOR nlli10i))) AND (NOT ((NOT comp_pat(37)) XOR nlli10l))) AND (NOT ((NOT comp_pat(38)) XOR nlli10O))) AND (NOT ((NOT comp_pat(39)) XOR nlli1ii)));
	n10111O <= (n10010l AND (wire_w_lg_w_lg_comp_pat_porn4798w4799w(0) AND wire_w_lg_w_lg_comp_pat_porn4800w4801w(0)));
	n1011ii <= ((((((((((NOT ((NOT comp_pat(30)) XOR nll0OlO)) AND (NOT ((NOT comp_pat(31)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(32)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(33)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(34)) XOR nlli11i))) AND (NOT ((NOT comp_pat(35)) XOR nlli11l))) AND (NOT ((NOT comp_pat(36)) XOR nlli11O))) AND (NOT ((NOT comp_pat(37)) XOR nlli10i))) AND (NOT ((NOT comp_pat(38)) XOR nlli10l))) AND (NOT ((NOT comp_pat(39)) XOR nlli10O)));
	n1011il <= (n1001il AND (wire_w_lg_w_lg_comp_pat_porn4792w4793w(0) AND wire_w_lg_w_lg_comp_pat_porn4794w4795w(0)));
	n1011iO <= ((((((((((NOT (comp_pat(20) XOR nll0O1i)) AND (NOT (comp_pat(21) XOR nll0O1l))) AND (NOT (comp_pat(22) XOR nll0O1O))) AND (NOT (comp_pat(23) XOR nll0O0i))) AND (NOT (comp_pat(24) XOR nll0O0l))) AND (NOT (comp_pat(25) XOR nll0O0O))) AND (NOT (comp_pat(26) XOR nll0Oii))) AND (NOT (comp_pat(27) XOR nll0Oil))) AND (NOT (comp_pat(28) XOR nll0OiO))) AND (NOT (comp_pat(29) XOR nll0Oli)));
	n1011li <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0O1i)) AND (NOT ((NOT comp_pat(21)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(22)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(23)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(24)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(25)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(26)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(27)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(28)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(29)) XOR nll0Oli)));
	n1011ll <= ((((((((((NOT (comp_pat(30) XOR nll0Oll)) AND (NOT (comp_pat(31) XOR nll0OlO))) AND (NOT (comp_pat(32) XOR nll0OOi))) AND (NOT (comp_pat(33) XOR nll0OOl))) AND (NOT (comp_pat(34) XOR nll0OOO))) AND (NOT (comp_pat(35) XOR nlli11i))) AND (NOT (comp_pat(36) XOR nlli11l))) AND (NOT (comp_pat(37) XOR nlli11O))) AND (NOT (comp_pat(38) XOR nlli10i))) AND (NOT (comp_pat(39) XOR nlli10l)));
	n1011lO <= ((((((((((NOT ((NOT comp_pat(30)) XOR nll0Oll)) AND (NOT ((NOT comp_pat(31)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(32)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(33)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(34)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(35)) XOR nlli11i))) AND (NOT ((NOT comp_pat(36)) XOR nlli11l))) AND (NOT ((NOT comp_pat(37)) XOR nlli11O))) AND (NOT ((NOT comp_pat(38)) XOR nlli10i))) AND (NOT ((NOT comp_pat(39)) XOR nlli10l)));
	n1011Oi <= (n1001ll AND (wire_w_lg_w_lg_comp_pat_porn4786w4787w(0) AND wire_w_lg_w_lg_comp_pat_porn4788w4789w(0)));
	n1011Ol <= ((((((((((NOT (comp_pat(20) XOR nll0lOO)) AND (NOT (comp_pat(21) XOR nll0O1i))) AND (NOT (comp_pat(22) XOR nll0O1l))) AND (NOT (comp_pat(23) XOR nll0O1O))) AND (NOT (comp_pat(24) XOR nll0O0i))) AND (NOT (comp_pat(25) XOR nll0O0l))) AND (NOT (comp_pat(26) XOR nll0O0O))) AND (NOT (comp_pat(27) XOR nll0Oii))) AND (NOT (comp_pat(28) XOR nll0Oil))) AND (NOT (comp_pat(29) XOR nll0OiO)));
	n1011OO <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0lOO)) AND (NOT ((NOT comp_pat(21)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(22)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(23)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(24)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(25)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(26)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(27)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(28)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(29)) XOR nll0OiO)));
	n101i0i <= ((((((((((NOT (comp_pat(20) XOR nll0lll)) AND (NOT (comp_pat(21) XOR nll0llO))) AND (NOT (comp_pat(22) XOR nll0lOi))) AND (NOT (comp_pat(23) XOR nll0lOl))) AND (NOT (comp_pat(24) XOR nll0lOO))) AND (NOT (comp_pat(25) XOR nll0O1i))) AND (NOT (comp_pat(26) XOR nll0O1l))) AND (NOT (comp_pat(27) XOR nll0O1O))) AND (NOT (comp_pat(28) XOR nll0O0i))) AND (NOT (comp_pat(29) XOR nll0O0l)));
	n101i0l <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0lll)) AND (NOT ((NOT comp_pat(21)) XOR nll0llO))) AND (NOT ((NOT comp_pat(22)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(23)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(24)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(25)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(26)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(27)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(28)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(29)) XOR nll0O0l)));
	n101i0O <= ((((((((((NOT (comp_pat(30) XOR nll0O0O)) AND (NOT (comp_pat(31) XOR nll0Oii))) AND (NOT (comp_pat(32) XOR nll0Oil))) AND (NOT (comp_pat(33) XOR nll0OiO))) AND (NOT (comp_pat(34) XOR nll0Oli))) AND (NOT (comp_pat(35) XOR nll0Oll))) AND (NOT (comp_pat(36) XOR nll0OlO))) AND (NOT (comp_pat(37) XOR nll0OOi))) AND (NOT (comp_pat(38) XOR nll0OOl))) AND (NOT (comp_pat(39) XOR nll0OOO)));
	n101i1i <= ((((((((((NOT (comp_pat(30) XOR nll0Oii)) AND (NOT (comp_pat(31) XOR nll0Oil))) AND (NOT (comp_pat(32) XOR nll0OiO))) AND (NOT (comp_pat(33) XOR nll0Oli))) AND (NOT (comp_pat(34) XOR nll0Oll))) AND (NOT (comp_pat(35) XOR nll0OlO))) AND (NOT (comp_pat(36) XOR nll0OOi))) AND (NOT (comp_pat(37) XOR nll0OOl))) AND (NOT (comp_pat(38) XOR nll0OOO))) AND (NOT (comp_pat(39) XOR nlli11i)));
	n101i1l <= ((((((((((NOT ((NOT comp_pat(30)) XOR nll0Oii)) AND (NOT ((NOT comp_pat(31)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(32)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(33)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(34)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(35)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(36)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(37)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(38)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(39)) XOR nlli11i)));
	n101i1O <= (n1000il AND (wire_w_lg_w_lg_comp_pat_porn4762w4763w(0) AND wire_w_lg_w_lg_comp_pat_porn4764w4765w(0)));
	n101iii <= ((((((((((NOT ((NOT comp_pat(30)) XOR nll0O0O)) AND (NOT ((NOT comp_pat(31)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(32)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(33)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(34)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(35)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(36)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(37)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(38)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(39)) XOR nll0OOO)));
	n101iil <= (n1000ll AND (wire_w_lg_w_lg_comp_pat_porn4756w4757w(0) AND wire_w_lg_w_lg_comp_pat_porn4758w4759w(0)));
	n101iiO <= ((((((((((NOT (comp_pat(20) XOR nll0lli)) AND (NOT (comp_pat(21) XOR nll0lll))) AND (NOT (comp_pat(22) XOR nll0llO))) AND (NOT (comp_pat(23) XOR nll0lOi))) AND (NOT (comp_pat(24) XOR nll0lOl))) AND (NOT (comp_pat(25) XOR nll0lOO))) AND (NOT (comp_pat(26) XOR nll0O1i))) AND (NOT (comp_pat(27) XOR nll0O1l))) AND (NOT (comp_pat(28) XOR nll0O1O))) AND (NOT (comp_pat(29) XOR nll0O0i)));
	n101ili <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0lli)) AND (NOT ((NOT comp_pat(21)) XOR nll0lll))) AND (NOT ((NOT comp_pat(22)) XOR nll0llO))) AND (NOT ((NOT comp_pat(23)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(24)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(25)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(26)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(27)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(28)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(29)) XOR nll0O0i)));
	n101ill <= ((((((((((NOT (comp_pat(30) XOR nll0O0l)) AND (NOT (comp_pat(31) XOR nll0O0O))) AND (NOT (comp_pat(32) XOR nll0Oii))) AND (NOT (comp_pat(33) XOR nll0Oil))) AND (NOT (comp_pat(34) XOR nll0OiO))) AND (NOT (comp_pat(35) XOR nll0Oli))) AND (NOT (comp_pat(36) XOR nll0Oll))) AND (NOT (comp_pat(37) XOR nll0OlO))) AND (NOT (comp_pat(38) XOR nll0OOi))) AND (NOT (comp_pat(39) XOR nll0OOl)));
	n101ilO <= ((((((((((NOT ((NOT comp_pat(30)) XOR nll0O0l)) AND (NOT ((NOT comp_pat(31)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(32)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(33)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(34)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(35)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(36)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(37)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(38)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(39)) XOR nll0OOl)));
	n101iOi <= (((((((((((((((((((n1000ll OR n1000il) OR n10000l) OR n10001l) OR n1001Ol) OR n1001ll) OR n1001il) OR n10010l) OR n10011l) OR n101OOl) OR n101Oll) OR n101Oil) OR n101O0l) OR n101O1l) OR n101lOl) OR n101lll) OR n101lil) OR n101l0l) OR n101l1l) OR n101iOl);
	n101iOl <= (n1000OO AND ((comp_pat_porn AND n101l1i) OR n101iOO));
	n101iOO <= ((((((((((NOT (comp_pat(10) XOR nll0O0i)) AND (NOT (comp_pat(11) XOR nll0O0l))) AND (NOT (comp_pat(12) XOR nll0O0O))) AND (NOT (comp_pat(13) XOR nll0Oii))) AND (NOT (comp_pat(14) XOR nll0Oil))) AND (NOT (comp_pat(15) XOR nll0OiO))) AND (NOT (comp_pat(16) XOR nll0Oli))) AND (NOT (comp_pat(17) XOR nll0Oll))) AND (NOT (comp_pat(18) XOR nll0OlO))) AND (NOT (comp_pat(19) XOR nll0OOi)));
	n101l0i <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0O1O)) AND (NOT ((NOT comp_pat(11)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(12)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(13)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(14)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(15)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(16)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(17)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(18)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(19)) XOR nll0OlO)));
	n101l0l <= (n100i0O AND ((comp_pat_porn AND n101lii) OR n101l0O));
	n101l0O <= ((((((((((NOT (comp_pat(10) XOR nll0O1l)) AND (NOT (comp_pat(11) XOR nll0O1O))) AND (NOT (comp_pat(12) XOR nll0O0i))) AND (NOT (comp_pat(13) XOR nll0O0l))) AND (NOT (comp_pat(14) XOR nll0O0O))) AND (NOT (comp_pat(15) XOR nll0Oii))) AND (NOT (comp_pat(16) XOR nll0Oil))) AND (NOT (comp_pat(17) XOR nll0OiO))) AND (NOT (comp_pat(18) XOR nll0Oli))) AND (NOT (comp_pat(19) XOR nll0Oll)));
	n101l1i <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0O0i)) AND (NOT ((NOT comp_pat(11)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(12)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(13)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(14)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(15)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(16)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(17)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(18)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(19)) XOR nll0OOi)));
	n101l1l <= (n100i1O AND ((comp_pat_porn AND n101l0i) OR n101l1O));
	n101l1O <= ((((((((((NOT (comp_pat(10) XOR nll0O1O)) AND (NOT (comp_pat(11) XOR nll0O0i))) AND (NOT (comp_pat(12) XOR nll0O0l))) AND (NOT (comp_pat(13) XOR nll0O0O))) AND (NOT (comp_pat(14) XOR nll0Oii))) AND (NOT (comp_pat(15) XOR nll0Oil))) AND (NOT (comp_pat(16) XOR nll0OiO))) AND (NOT (comp_pat(17) XOR nll0Oli))) AND (NOT (comp_pat(18) XOR nll0Oll))) AND (NOT (comp_pat(19) XOR nll0OlO)));
	n101lii <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0O1l)) AND (NOT ((NOT comp_pat(11)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(12)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(13)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(14)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(15)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(16)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(17)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(18)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(19)) XOR nll0Oll)));
	n101lil <= (n100iiO AND ((comp_pat_porn AND n101lli) OR n101liO));
	n101liO <= ((((((((((NOT (comp_pat(10) XOR nll0O1i)) AND (NOT (comp_pat(11) XOR nll0O1l))) AND (NOT (comp_pat(12) XOR nll0O1O))) AND (NOT (comp_pat(13) XOR nll0O0i))) AND (NOT (comp_pat(14) XOR nll0O0l))) AND (NOT (comp_pat(15) XOR nll0O0O))) AND (NOT (comp_pat(16) XOR nll0Oii))) AND (NOT (comp_pat(17) XOR nll0Oil))) AND (NOT (comp_pat(18) XOR nll0OiO))) AND (NOT (comp_pat(19) XOR nll0Oli)));
	n101lli <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0O1i)) AND (NOT ((NOT comp_pat(11)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(12)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(13)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(14)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(15)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(16)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(17)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(18)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(19)) XOR nll0Oli)));
	n101lll <= (n100ilO AND ((comp_pat_porn AND n101lOi) OR n101llO));
	n101llO <= ((((((((((NOT (comp_pat(10) XOR nll0lOO)) AND (NOT (comp_pat(11) XOR nll0O1i))) AND (NOT (comp_pat(12) XOR nll0O1l))) AND (NOT (comp_pat(13) XOR nll0O1O))) AND (NOT (comp_pat(14) XOR nll0O0i))) AND (NOT (comp_pat(15) XOR nll0O0l))) AND (NOT (comp_pat(16) XOR nll0O0O))) AND (NOT (comp_pat(17) XOR nll0Oii))) AND (NOT (comp_pat(18) XOR nll0Oil))) AND (NOT (comp_pat(19) XOR nll0OiO)));
	n101lOi <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0lOO)) AND (NOT ((NOT comp_pat(11)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(12)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(13)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(14)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(15)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(16)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(17)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(18)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(19)) XOR nll0OiO)));
	n101lOl <= (n100iOO AND ((comp_pat_porn AND n101O1i) OR n101lOO));
	n101lOO <= ((((((((((NOT (comp_pat(10) XOR nll0lOl)) AND (NOT (comp_pat(11) XOR nll0lOO))) AND (NOT (comp_pat(12) XOR nll0O1i))) AND (NOT (comp_pat(13) XOR nll0O1l))) AND (NOT (comp_pat(14) XOR nll0O1O))) AND (NOT (comp_pat(15) XOR nll0O0i))) AND (NOT (comp_pat(16) XOR nll0O0l))) AND (NOT (comp_pat(17) XOR nll0O0O))) AND (NOT (comp_pat(18) XOR nll0Oii))) AND (NOT (comp_pat(19) XOR nll0Oil)));
	n101O0i <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0lOi)) AND (NOT ((NOT comp_pat(11)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(12)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(13)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(14)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(15)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(16)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(17)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(18)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(19)) XOR nll0Oii)));
	n101O0l <= (n100l0O AND ((comp_pat_porn AND n101Oii) OR n101O0O));
	n101O0O <= ((((((((((NOT (comp_pat(10) XOR nll0llO)) AND (NOT (comp_pat(11) XOR nll0lOi))) AND (NOT (comp_pat(12) XOR nll0lOl))) AND (NOT (comp_pat(13) XOR nll0lOO))) AND (NOT (comp_pat(14) XOR nll0O1i))) AND (NOT (comp_pat(15) XOR nll0O1l))) AND (NOT (comp_pat(16) XOR nll0O1O))) AND (NOT (comp_pat(17) XOR nll0O0i))) AND (NOT (comp_pat(18) XOR nll0O0l))) AND (NOT (comp_pat(19) XOR nll0O0O)));
	n101O1i <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0lOl)) AND (NOT ((NOT comp_pat(11)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(12)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(13)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(14)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(15)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(16)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(17)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(18)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(19)) XOR nll0Oil)));
	n101O1l <= (n100l1O AND ((comp_pat_porn AND n101O0i) OR n101O1O));
	n101O1O <= ((((((((((NOT (comp_pat(10) XOR nll0lOi)) AND (NOT (comp_pat(11) XOR nll0lOl))) AND (NOT (comp_pat(12) XOR nll0lOO))) AND (NOT (comp_pat(13) XOR nll0O1i))) AND (NOT (comp_pat(14) XOR nll0O1l))) AND (NOT (comp_pat(15) XOR nll0O1O))) AND (NOT (comp_pat(16) XOR nll0O0i))) AND (NOT (comp_pat(17) XOR nll0O0l))) AND (NOT (comp_pat(18) XOR nll0O0O))) AND (NOT (comp_pat(19) XOR nll0Oii)));
	n101Oii <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0llO)) AND (NOT ((NOT comp_pat(11)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(12)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(13)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(14)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(15)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(16)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(17)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(18)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(19)) XOR nll0O0O)));
	n101Oil <= (n100liO AND ((comp_pat_porn AND n101Oli) OR n101OiO));
	n101OiO <= ((((((((((NOT (comp_pat(10) XOR nll0lll)) AND (NOT (comp_pat(11) XOR nll0llO))) AND (NOT (comp_pat(12) XOR nll0lOi))) AND (NOT (comp_pat(13) XOR nll0lOl))) AND (NOT (comp_pat(14) XOR nll0lOO))) AND (NOT (comp_pat(15) XOR nll0O1i))) AND (NOT (comp_pat(16) XOR nll0O1l))) AND (NOT (comp_pat(17) XOR nll0O1O))) AND (NOT (comp_pat(18) XOR nll0O0i))) AND (NOT (comp_pat(19) XOR nll0O0l)));
	n101Oli <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0lll)) AND (NOT ((NOT comp_pat(11)) XOR nll0llO))) AND (NOT ((NOT comp_pat(12)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(13)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(14)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(15)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(16)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(17)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(18)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(19)) XOR nll0O0l)));
	n101Oll <= (n100llO AND ((comp_pat_porn AND n101OOi) OR n101OlO));
	n101OlO <= ((((((((((NOT (comp_pat(10) XOR nll0lli)) AND (NOT (comp_pat(11) XOR nll0lll))) AND (NOT (comp_pat(12) XOR nll0llO))) AND (NOT (comp_pat(13) XOR nll0lOi))) AND (NOT (comp_pat(14) XOR nll0lOl))) AND (NOT (comp_pat(15) XOR nll0lOO))) AND (NOT (comp_pat(16) XOR nll0O1i))) AND (NOT (comp_pat(17) XOR nll0O1l))) AND (NOT (comp_pat(18) XOR nll0O1O))) AND (NOT (comp_pat(19) XOR nll0O0i)));
	n101OOi <= ((((((((((NOT ((NOT comp_pat(10)) XOR nll0lli)) AND (NOT ((NOT comp_pat(11)) XOR nll0lll))) AND (NOT ((NOT comp_pat(12)) XOR nll0llO))) AND (NOT ((NOT comp_pat(13)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(14)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(15)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(16)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(17)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(18)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(19)) XOR nll0O0i)));
	n101OOl <= (n100lOO AND ((comp_pat_porn AND n10011i) OR n101OOO));
	n101OOO <= ((((((((((NOT (comp_pat(10) XOR nll0liO)) AND (NOT (comp_pat(11) XOR nll0lli))) AND (NOT (comp_pat(12) XOR nll0lll))) AND (NOT (comp_pat(13) XOR nll0llO))) AND (NOT (comp_pat(14) XOR nll0lOi))) AND (NOT (comp_pat(15) XOR nll0lOl))) AND (NOT (comp_pat(16) XOR nll0lOO))) AND (NOT (comp_pat(17) XOR nll0O1i))) AND (NOT (comp_pat(18) XOR nll0O1l))) AND (NOT (comp_pat(19) XOR nll0O1O)));
	n10i00i <= ((comp_pat_porn AND n10i00O) OR n10i00l);
	n10i00l <= (((((((NOT (comp_pat(0) XOR nll0lil)) AND (NOT (comp_pat(1) XOR nll0liO))) AND (NOT (comp_pat(2) XOR nll0lli))) AND (NOT (comp_pat(3) XOR nll0lll))) AND (NOT (comp_pat(4) XOR nll0llO))) AND (NOT (comp_pat(5) XOR nll0lOi))) AND (NOT (comp_pat(6) XOR nll0lOl)));
	n10i00O <= (((((((NOT ((NOT comp_pat(0)) XOR nll0lil)) AND (NOT ((NOT comp_pat(1)) XOR nll0liO))) AND (NOT ((NOT comp_pat(2)) XOR nll0lli))) AND (NOT ((NOT comp_pat(3)) XOR nll0lll))) AND (NOT ((NOT comp_pat(4)) XOR nll0llO))) AND (NOT ((NOT comp_pat(5)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(6)) XOR nll0lOl)));
	n10i01i <= ((comp_pat_porn AND n10i01O) OR n10i01l);
	n10i01l <= (((((((NOT (comp_pat(0) XOR nll0liO)) AND (NOT (comp_pat(1) XOR nll0lli))) AND (NOT (comp_pat(2) XOR nll0lll))) AND (NOT (comp_pat(3) XOR nll0llO))) AND (NOT (comp_pat(4) XOR nll0lOi))) AND (NOT (comp_pat(5) XOR nll0lOl))) AND (NOT (comp_pat(6) XOR nll0lOO)));
	n10i01O <= (((((((NOT ((NOT comp_pat(0)) XOR nll0liO)) AND (NOT ((NOT comp_pat(1)) XOR nll0lli))) AND (NOT ((NOT comp_pat(2)) XOR nll0lll))) AND (NOT ((NOT comp_pat(3)) XOR nll0llO))) AND (NOT ((NOT comp_pat(4)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(5)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(6)) XOR nll0lOO)));
	n10i0ii <= ((comp_pat_porn AND n10i0iO) OR n10i0il);
	n10i0il <= (((((((NOT (comp_pat(0) XOR nll0lii)) AND (NOT (comp_pat(1) XOR nll0lil))) AND (NOT (comp_pat(2) XOR nll0liO))) AND (NOT (comp_pat(3) XOR nll0lli))) AND (NOT (comp_pat(4) XOR nll0lll))) AND (NOT (comp_pat(5) XOR nll0llO))) AND (NOT (comp_pat(6) XOR nll0lOi)));
	n10i0iO <= (((((((NOT ((NOT comp_pat(0)) XOR nll0lii)) AND (NOT ((NOT comp_pat(1)) XOR nll0lil))) AND (NOT ((NOT comp_pat(2)) XOR nll0liO))) AND (NOT ((NOT comp_pat(3)) XOR nll0lli))) AND (NOT ((NOT comp_pat(4)) XOR nll0lll))) AND (NOT ((NOT comp_pat(5)) XOR nll0llO))) AND (NOT ((NOT comp_pat(6)) XOR nll0lOi)));
	n10i0li <= ((comp_pat_porn AND n10i0lO) OR n10i0ll);
	n10i0ll <= (((((((NOT (comp_pat(0) XOR nll0l0O)) AND (NOT (comp_pat(1) XOR nll0lii))) AND (NOT (comp_pat(2) XOR nll0lil))) AND (NOT (comp_pat(3) XOR nll0liO))) AND (NOT (comp_pat(4) XOR nll0lli))) AND (NOT (comp_pat(5) XOR nll0lll))) AND (NOT (comp_pat(6) XOR nll0llO)));
	n10i0lO <= (((((((NOT ((NOT comp_pat(0)) XOR nll0l0O)) AND (NOT ((NOT comp_pat(1)) XOR nll0lii))) AND (NOT ((NOT comp_pat(2)) XOR nll0lil))) AND (NOT ((NOT comp_pat(3)) XOR nll0liO))) AND (NOT ((NOT comp_pat(4)) XOR nll0lli))) AND (NOT ((NOT comp_pat(5)) XOR nll0lll))) AND (NOT ((NOT comp_pat(6)) XOR nll0llO)));
	n10i0Oi <= ((comp_pat_porn AND n10i0OO) OR n10i0Ol);
	n10i0Ol <= (((((((NOT (comp_pat(0) XOR nll0l0l)) AND (NOT (comp_pat(1) XOR nll0l0O))) AND (NOT (comp_pat(2) XOR nll0lii))) AND (NOT (comp_pat(3) XOR nll0lil))) AND (NOT (comp_pat(4) XOR nll0liO))) AND (NOT (comp_pat(5) XOR nll0lli))) AND (NOT (comp_pat(6) XOR nll0lll)));
	n10i0OO <= (((((((NOT ((NOT comp_pat(0)) XOR nll0l0l)) AND (NOT ((NOT comp_pat(1)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(2)) XOR nll0lii))) AND (NOT ((NOT comp_pat(3)) XOR nll0lil))) AND (NOT ((NOT comp_pat(4)) XOR nll0liO))) AND (NOT ((NOT comp_pat(5)) XOR nll0lli))) AND (NOT ((NOT comp_pat(6)) XOR nll0lll)));
	n10i10i <= ((((((((((NOT (comp_pat(0) XOR nll0iil)) AND (NOT (comp_pat(1) XOR nll0iiO))) AND (NOT (comp_pat(2) XOR nll0ili))) AND (NOT (comp_pat(3) XOR nll0ill))) AND (NOT (comp_pat(4) XOR nll0ilO))) AND (NOT (comp_pat(5) XOR nll0iOi))) AND (NOT (comp_pat(6) XOR nll0iOl))) AND (NOT (comp_pat(7) XOR nll0iOO))) AND (NOT (comp_pat(8) XOR nll0l1i))) AND (NOT (comp_pat(9) XOR nll0l1l)));
	n10i10l <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0iil)) AND (NOT ((NOT comp_pat(1)) XOR nll0iiO))) AND (NOT ((NOT comp_pat(2)) XOR nll0ili))) AND (NOT ((NOT comp_pat(3)) XOR nll0ill))) AND (NOT ((NOT comp_pat(4)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(5)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(6)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(7)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(8)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(9)) XOR nll0l1l)));
	n10i10O <= ((comp_pat_porn AND n10i1il) OR n10i1ii);
	n10i11i <= ((((((((((NOT (comp_pat(0) XOR nll0iiO)) AND (NOT (comp_pat(1) XOR nll0ili))) AND (NOT (comp_pat(2) XOR nll0ill))) AND (NOT (comp_pat(3) XOR nll0ilO))) AND (NOT (comp_pat(4) XOR nll0iOi))) AND (NOT (comp_pat(5) XOR nll0iOl))) AND (NOT (comp_pat(6) XOR nll0iOO))) AND (NOT (comp_pat(7) XOR nll0l1i))) AND (NOT (comp_pat(8) XOR nll0l1l))) AND (NOT (comp_pat(9) XOR nll0l1O)));
	n10i11l <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0iiO)) AND (NOT ((NOT comp_pat(1)) XOR nll0ili))) AND (NOT ((NOT comp_pat(2)) XOR nll0ill))) AND (NOT ((NOT comp_pat(3)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(4)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(5)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(6)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(7)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(8)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(9)) XOR nll0l1O)));
	n10i11O <= ((comp_pat_porn AND n10i10l) OR n10i10i);
	n10i1ii <= ((((((((((NOT (comp_pat(0) XOR nll0iii)) AND (NOT (comp_pat(1) XOR nll0iil))) AND (NOT (comp_pat(2) XOR nll0iiO))) AND (NOT (comp_pat(3) XOR nll0ili))) AND (NOT (comp_pat(4) XOR nll0ill))) AND (NOT (comp_pat(5) XOR nll0ilO))) AND (NOT (comp_pat(6) XOR nll0iOi))) AND (NOT (comp_pat(7) XOR nll0iOl))) AND (NOT (comp_pat(8) XOR nll0iOO))) AND (NOT (comp_pat(9) XOR nll0l1i)));
	n10i1il <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0iii)) AND (NOT ((NOT comp_pat(1)) XOR nll0iil))) AND (NOT ((NOT comp_pat(2)) XOR nll0iiO))) AND (NOT ((NOT comp_pat(3)) XOR nll0ili))) AND (NOT ((NOT comp_pat(4)) XOR nll0ill))) AND (NOT ((NOT comp_pat(5)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(6)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(7)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(8)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(9)) XOR nll0l1i)));
	n10i1iO <= ((comp_pat_porn AND n10i1ll) OR n10i1li);
	n10i1li <= ((((((((((NOT (comp_pat(0) XOR nll0i0O)) AND (NOT (comp_pat(1) XOR nll0iii))) AND (NOT (comp_pat(2) XOR nll0iil))) AND (NOT (comp_pat(3) XOR nll0iiO))) AND (NOT (comp_pat(4) XOR nll0ili))) AND (NOT (comp_pat(5) XOR nll0ill))) AND (NOT (comp_pat(6) XOR nll0ilO))) AND (NOT (comp_pat(7) XOR nll0iOi))) AND (NOT (comp_pat(8) XOR nll0iOl))) AND (NOT (comp_pat(9) XOR nll0iOO)));
	n10i1ll <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0i0O)) AND (NOT ((NOT comp_pat(1)) XOR nll0iii))) AND (NOT ((NOT comp_pat(2)) XOR nll0iil))) AND (NOT ((NOT comp_pat(3)) XOR nll0iiO))) AND (NOT ((NOT comp_pat(4)) XOR nll0ili))) AND (NOT ((NOT comp_pat(5)) XOR nll0ill))) AND (NOT ((NOT comp_pat(6)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(7)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(8)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(9)) XOR nll0iOO)));
	n10i1lO <= ((comp_pat_porn AND n10i1Ol) OR n10i1Oi);
	n10i1Oi <= ((((((((((NOT (comp_pat(0) XOR nll0i0l)) AND (NOT (comp_pat(1) XOR nll0i0O))) AND (NOT (comp_pat(2) XOR nll0iii))) AND (NOT (comp_pat(3) XOR nll0iil))) AND (NOT (comp_pat(4) XOR nll0iiO))) AND (NOT (comp_pat(5) XOR nll0ili))) AND (NOT (comp_pat(6) XOR nll0ill))) AND (NOT (comp_pat(7) XOR nll0ilO))) AND (NOT (comp_pat(8) XOR nll0iOi))) AND (NOT (comp_pat(9) XOR nll0iOl)));
	n10i1Ol <= ((((((((((NOT ((NOT comp_pat(0)) XOR nll0i0l)) AND (NOT ((NOT comp_pat(1)) XOR nll0i0O))) AND (NOT ((NOT comp_pat(2)) XOR nll0iii))) AND (NOT ((NOT comp_pat(3)) XOR nll0iil))) AND (NOT ((NOT comp_pat(4)) XOR nll0iiO))) AND (NOT ((NOT comp_pat(5)) XOR nll0ili))) AND (NOT ((NOT comp_pat(6)) XOR nll0ill))) AND (NOT ((NOT comp_pat(7)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(8)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(9)) XOR nll0iOl)));
	n10i1OO <= (((((((((((((((((((n10iOOi OR n10iOli) OR n10iOii) OR n10iO0i) OR n10iO1i) OR n10ilOi) OR n10illi) OR n10ilii) OR n10il0i) OR n10il1i) OR n10iiOi) OR n10iili) OR n10iiii) OR n10ii0i) OR n10ii1i) OR n10i0Oi) OR n10i0li) OR n10i0ii) OR n10i00i) OR n10i01i);
	n10ii0i <= ((comp_pat_porn AND n10ii0O) OR n10ii0l);
	n10ii0l <= (((((((NOT (comp_pat(0) XOR nll0l1O)) AND (NOT (comp_pat(1) XOR nll0l0i))) AND (NOT (comp_pat(2) XOR nll0l0l))) AND (NOT (comp_pat(3) XOR nll0l0O))) AND (NOT (comp_pat(4) XOR nll0lii))) AND (NOT (comp_pat(5) XOR nll0lil))) AND (NOT (comp_pat(6) XOR nll0liO)));
	n10ii0O <= (((((((NOT ((NOT comp_pat(0)) XOR nll0l1O)) AND (NOT ((NOT comp_pat(1)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(2)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(3)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(4)) XOR nll0lii))) AND (NOT ((NOT comp_pat(5)) XOR nll0lil))) AND (NOT ((NOT comp_pat(6)) XOR nll0liO)));
	n10ii1i <= ((comp_pat_porn AND n10ii1O) OR n10ii1l);
	n10ii1l <= (((((((NOT (comp_pat(0) XOR nll0l0i)) AND (NOT (comp_pat(1) XOR nll0l0l))) AND (NOT (comp_pat(2) XOR nll0l0O))) AND (NOT (comp_pat(3) XOR nll0lii))) AND (NOT (comp_pat(4) XOR nll0lil))) AND (NOT (comp_pat(5) XOR nll0liO))) AND (NOT (comp_pat(6) XOR nll0lli)));
	n10ii1O <= (((((((NOT ((NOT comp_pat(0)) XOR nll0l0i)) AND (NOT ((NOT comp_pat(1)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(2)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(3)) XOR nll0lii))) AND (NOT ((NOT comp_pat(4)) XOR nll0lil))) AND (NOT ((NOT comp_pat(5)) XOR nll0liO))) AND (NOT ((NOT comp_pat(6)) XOR nll0lli)));
	n10iiii <= ((comp_pat_porn AND n10iiiO) OR n10iiil);
	n10iiil <= (((((((NOT (comp_pat(0) XOR nll0l1l)) AND (NOT (comp_pat(1) XOR nll0l1O))) AND (NOT (comp_pat(2) XOR nll0l0i))) AND (NOT (comp_pat(3) XOR nll0l0l))) AND (NOT (comp_pat(4) XOR nll0l0O))) AND (NOT (comp_pat(5) XOR nll0lii))) AND (NOT (comp_pat(6) XOR nll0lil)));
	n10iiiO <= (((((((NOT ((NOT comp_pat(0)) XOR nll0l1l)) AND (NOT ((NOT comp_pat(1)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(2)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(3)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(4)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(5)) XOR nll0lii))) AND (NOT ((NOT comp_pat(6)) XOR nll0lil)));
	n10iili <= ((comp_pat_porn AND n10iilO) OR n10iill);
	n10iill <= (((((((NOT (comp_pat(0) XOR nll0l1i)) AND (NOT (comp_pat(1) XOR nll0l1l))) AND (NOT (comp_pat(2) XOR nll0l1O))) AND (NOT (comp_pat(3) XOR nll0l0i))) AND (NOT (comp_pat(4) XOR nll0l0l))) AND (NOT (comp_pat(5) XOR nll0l0O))) AND (NOT (comp_pat(6) XOR nll0lii)));
	n10iilO <= (((((((NOT ((NOT comp_pat(0)) XOR nll0l1i)) AND (NOT ((NOT comp_pat(1)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(2)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(3)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(4)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(5)) XOR nll0l0O))) AND (NOT ((NOT comp_pat(6)) XOR nll0lii)));
	n10iiOi <= ((comp_pat_porn AND n10iiOO) OR n10iiOl);
	n10iiOl <= (((((((NOT (comp_pat(0) XOR nll0iOO)) AND (NOT (comp_pat(1) XOR nll0l1i))) AND (NOT (comp_pat(2) XOR nll0l1l))) AND (NOT (comp_pat(3) XOR nll0l1O))) AND (NOT (comp_pat(4) XOR nll0l0i))) AND (NOT (comp_pat(5) XOR nll0l0l))) AND (NOT (comp_pat(6) XOR nll0l0O)));
	n10iiOO <= (((((((NOT ((NOT comp_pat(0)) XOR nll0iOO)) AND (NOT ((NOT comp_pat(1)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(2)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(3)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(4)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(5)) XOR nll0l0l))) AND (NOT ((NOT comp_pat(6)) XOR nll0l0O)));
	n10il0i <= ((comp_pat_porn AND n10il0O) OR n10il0l);
	n10il0l <= (((((((NOT (comp_pat(0) XOR nll0iOi)) AND (NOT (comp_pat(1) XOR nll0iOl))) AND (NOT (comp_pat(2) XOR nll0iOO))) AND (NOT (comp_pat(3) XOR nll0l1i))) AND (NOT (comp_pat(4) XOR nll0l1l))) AND (NOT (comp_pat(5) XOR nll0l1O))) AND (NOT (comp_pat(6) XOR nll0l0i)));
	n10il0O <= (((((((NOT ((NOT comp_pat(0)) XOR nll0iOi)) AND (NOT ((NOT comp_pat(1)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(2)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(3)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(4)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(5)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(6)) XOR nll0l0i)));
	n10il1i <= ((comp_pat_porn AND n10il1O) OR n10il1l);
	n10il1l <= (((((((NOT (comp_pat(0) XOR nll0iOl)) AND (NOT (comp_pat(1) XOR nll0iOO))) AND (NOT (comp_pat(2) XOR nll0l1i))) AND (NOT (comp_pat(3) XOR nll0l1l))) AND (NOT (comp_pat(4) XOR nll0l1O))) AND (NOT (comp_pat(5) XOR nll0l0i))) AND (NOT (comp_pat(6) XOR nll0l0l)));
	n10il1O <= (((((((NOT ((NOT comp_pat(0)) XOR nll0iOl)) AND (NOT ((NOT comp_pat(1)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(2)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(3)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(4)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(5)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(6)) XOR nll0l0l)));
	n10ilii <= ((comp_pat_porn AND n10iliO) OR n10ilil);
	n10ilil <= (((((((NOT (comp_pat(0) XOR nll0ilO)) AND (NOT (comp_pat(1) XOR nll0iOi))) AND (NOT (comp_pat(2) XOR nll0iOl))) AND (NOT (comp_pat(3) XOR nll0iOO))) AND (NOT (comp_pat(4) XOR nll0l1i))) AND (NOT (comp_pat(5) XOR nll0l1l))) AND (NOT (comp_pat(6) XOR nll0l1O)));
	n10iliO <= (((((((NOT ((NOT comp_pat(0)) XOR nll0ilO)) AND (NOT ((NOT comp_pat(1)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(2)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(3)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(4)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(5)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(6)) XOR nll0l1O)));
	n10illi <= ((comp_pat_porn AND n10illO) OR n10illl);
	n10illl <= (((((((NOT (comp_pat(0) XOR nll0ill)) AND (NOT (comp_pat(1) XOR nll0ilO))) AND (NOT (comp_pat(2) XOR nll0iOi))) AND (NOT (comp_pat(3) XOR nll0iOl))) AND (NOT (comp_pat(4) XOR nll0iOO))) AND (NOT (comp_pat(5) XOR nll0l1i))) AND (NOT (comp_pat(6) XOR nll0l1l)));
	n10illO <= (((((((NOT ((NOT comp_pat(0)) XOR nll0ill)) AND (NOT ((NOT comp_pat(1)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(2)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(3)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(4)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(5)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(6)) XOR nll0l1l)));
	n10ilOi <= ((comp_pat_porn AND n10ilOO) OR n10ilOl);
	n10ilOl <= (((((((NOT (comp_pat(0) XOR nll0ili)) AND (NOT (comp_pat(1) XOR nll0ill))) AND (NOT (comp_pat(2) XOR nll0ilO))) AND (NOT (comp_pat(3) XOR nll0iOi))) AND (NOT (comp_pat(4) XOR nll0iOl))) AND (NOT (comp_pat(5) XOR nll0iOO))) AND (NOT (comp_pat(6) XOR nll0l1i)));
	n10ilOO <= (((((((NOT ((NOT comp_pat(0)) XOR nll0ili)) AND (NOT ((NOT comp_pat(1)) XOR nll0ill))) AND (NOT ((NOT comp_pat(2)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(3)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(4)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(5)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(6)) XOR nll0l1i)));
	n10iO0i <= ((comp_pat_porn AND n10iO0O) OR n10iO0l);
	n10iO0l <= (((((((NOT (comp_pat(0) XOR nll0iil)) AND (NOT (comp_pat(1) XOR nll0iiO))) AND (NOT (comp_pat(2) XOR nll0ili))) AND (NOT (comp_pat(3) XOR nll0ill))) AND (NOT (comp_pat(4) XOR nll0ilO))) AND (NOT (comp_pat(5) XOR nll0iOi))) AND (NOT (comp_pat(6) XOR nll0iOl)));
	n10iO0O <= (((((((NOT ((NOT comp_pat(0)) XOR nll0iil)) AND (NOT ((NOT comp_pat(1)) XOR nll0iiO))) AND (NOT ((NOT comp_pat(2)) XOR nll0ili))) AND (NOT ((NOT comp_pat(3)) XOR nll0ill))) AND (NOT ((NOT comp_pat(4)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(5)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(6)) XOR nll0iOl)));
	n10iO1i <= ((comp_pat_porn AND n10iO1O) OR n10iO1l);
	n10iO1l <= (((((((NOT (comp_pat(0) XOR nll0iiO)) AND (NOT (comp_pat(1) XOR nll0ili))) AND (NOT (comp_pat(2) XOR nll0ill))) AND (NOT (comp_pat(3) XOR nll0ilO))) AND (NOT (comp_pat(4) XOR nll0iOi))) AND (NOT (comp_pat(5) XOR nll0iOl))) AND (NOT (comp_pat(6) XOR nll0iOO)));
	n10iO1O <= (((((((NOT ((NOT comp_pat(0)) XOR nll0iiO)) AND (NOT ((NOT comp_pat(1)) XOR nll0ili))) AND (NOT ((NOT comp_pat(2)) XOR nll0ill))) AND (NOT ((NOT comp_pat(3)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(4)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(5)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(6)) XOR nll0iOO)));
	n10iOii <= ((comp_pat_porn AND n10iOiO) OR n10iOil);
	n10iOil <= (((((((NOT (comp_pat(0) XOR nll0iii)) AND (NOT (comp_pat(1) XOR nll0iil))) AND (NOT (comp_pat(2) XOR nll0iiO))) AND (NOT (comp_pat(3) XOR nll0ili))) AND (NOT (comp_pat(4) XOR nll0ill))) AND (NOT (comp_pat(5) XOR nll0ilO))) AND (NOT (comp_pat(6) XOR nll0iOi)));
	n10iOiO <= (((((((NOT ((NOT comp_pat(0)) XOR nll0iii)) AND (NOT ((NOT comp_pat(1)) XOR nll0iil))) AND (NOT ((NOT comp_pat(2)) XOR nll0iiO))) AND (NOT ((NOT comp_pat(3)) XOR nll0ili))) AND (NOT ((NOT comp_pat(4)) XOR nll0ill))) AND (NOT ((NOT comp_pat(5)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(6)) XOR nll0iOi)));
	n10iOli <= ((comp_pat_porn AND n10iOlO) OR n10iOll);
	n10iOll <= (((((((NOT (comp_pat(0) XOR nll0i0O)) AND (NOT (comp_pat(1) XOR nll0iii))) AND (NOT (comp_pat(2) XOR nll0iil))) AND (NOT (comp_pat(3) XOR nll0iiO))) AND (NOT (comp_pat(4) XOR nll0ili))) AND (NOT (comp_pat(5) XOR nll0ill))) AND (NOT (comp_pat(6) XOR nll0ilO)));
	n10iOlO <= (((((((NOT ((NOT comp_pat(0)) XOR nll0i0O)) AND (NOT ((NOT comp_pat(1)) XOR nll0iii))) AND (NOT ((NOT comp_pat(2)) XOR nll0iil))) AND (NOT ((NOT comp_pat(3)) XOR nll0iiO))) AND (NOT ((NOT comp_pat(4)) XOR nll0ili))) AND (NOT ((NOT comp_pat(5)) XOR nll0ill))) AND (NOT ((NOT comp_pat(6)) XOR nll0ilO)));
	n10iOOi <= ((comp_pat_porn AND n10iOOO) OR n10iOOl);
	n10iOOl <= (((((((NOT (comp_pat(0) XOR nll0i0l)) AND (NOT (comp_pat(1) XOR nll0i0O))) AND (NOT (comp_pat(2) XOR nll0iii))) AND (NOT (comp_pat(3) XOR nll0iil))) AND (NOT (comp_pat(4) XOR nll0iiO))) AND (NOT (comp_pat(5) XOR nll0ili))) AND (NOT (comp_pat(6) XOR nll0ill)));
	n10iOOO <= (((((((NOT ((NOT comp_pat(0)) XOR nll0i0l)) AND (NOT ((NOT comp_pat(1)) XOR nll0i0O))) AND (NOT ((NOT comp_pat(2)) XOR nll0iii))) AND (NOT ((NOT comp_pat(3)) XOR nll0iil))) AND (NOT ((NOT comp_pat(4)) XOR nll0iiO))) AND (NOT ((NOT comp_pat(5)) XOR nll0ili))) AND (NOT ((NOT comp_pat(6)) XOR nll0ill)));
	n10l00i <= ((n10ll0i AND n10lili) AND wire_w_lg_n10li0O3453w(0));
	n10l00l <= (n10ll0i AND wire_w_lg_n10lili3500w(0));
	n10l00O <= (n10l0iO AND wire_w_lg_n10l0OO3456w(0));
	n10l01i <= (wire_nllO0ii_w_lg_w_lg_w_lg_dataout3945w3946w3947w(0) OR wire_w_lg_n10l01l3948w(0));
	n10l01l <= ((((wire_nllO0il_w_lg_dataout3407w(0) OR wire_nllO00O_dataout) OR wire_nllO00i_dataout) OR wire_nllO01O_dataout) OR wire_nllO01l_dataout);
	n10l01O <= (n10lili AND wire_w_lg_n10li0O3453w(0));
	n10l0ii <= ((wire_nllOO1l_o AND n10l0iO) AND n10l0OO);
	n10l0il <= ((wire_nlO10Ol_o AND n10l0iO) AND n10l0OO);
	n10l0iO <= (wire_w_lg_n10ll0i3493w(0) AND n10lili);
	n10l0li <= (wire_w_lg_n10ll0i3493w(0) AND wire_w_lg_n10lili3500w(0));
	n10l0ll <= ((n10liil AND n10l0lO) AND n10l0OO);
	n10l0lO <= (((((((((wire_nl_w_lg_nlO0i1i4400w(0) AND wire_nl_w_lg_nlO00OO4401w(0)) AND wire_nl_w_lg_nlO00Ol4403w(0)) AND wire_nl_w_lg_nlO00Oi4405w(0)) AND wire_nl_w_lg_nlO00lO4407w(0)) AND wire_nl_w_lg_nlO00ll4409w(0)) AND wire_nl_w_lg_nlO00li4411w(0)) AND wire_nl_w_lg_nlO00iO4413w(0)) AND wire_nl_w_lg_nlO00il4415w(0)) AND nlO00ii);
	n10l0Oi <= ((wire_nlO10Ol_o AND n10liil) AND n10l0OO);
	n10l0Ol <= (n10liil AND wire_w_lg_n10l0OO3456w(0));
	n10l0OO <= ((((((((((NOT (gnumber(0) XOR nlO01lO)) AND (NOT (gnumber(1) XOR nlO01Oi))) AND (NOT (gnumber(2) XOR nlO01Ol))) AND (NOT (gnumber(3) XOR nlO01OO))) AND (NOT (gnumber(4) XOR nlO001i))) AND (NOT (gnumber(5) XOR nlO001l))) AND (NOT (gnumber(6) XOR nlO001O))) AND (NOT (gnumber(7) XOR nlO000i))) AND (NOT (gnumber(8) XOR nlO000l))) AND (NOT (gnumber(9) XOR nlO000O)));
	n10l10i <= (wire_w_lg_n10l1il4510w(0) AND (((((NOT resync_badcg_en(0)) AND wire_w_lg_w_resync_badcg_en_range4513w4514w(0)) OR (resync_badcg_en(0) AND resync_badcg_en(1))) OR wire_w_lg_n10l1ii4519w(0)) OR (wire_w_lg_n10l1ii4522w(0) AND ((NOT resync_badcg_en(0)) AND resync_badcg_en(1)))));
	n10l10l <= ((((wire_n1l11lO_w_lg_dataout16758w(0) AND wire_w_lg_w_lg_w16764w16765w16766w(0)) OR wire_n1l11lO_w_lg_dataout16770w(0)) OR (wire_w_lg_nlOO0ilO16773w(0) AND wire_n1lllii_w_lg_dataout16774w(0))) OR wire_w_lg_w_lg_nlOO0iOl16779w16780w(0));
	n10l10O <= ((((wire_nl_w_lg_nl1liil17102w(0) AND wire_w_lg_w_lg_w17108w17109w17110w(0)) OR wire_nl_w_lg_nl1liil17114w(0)) OR (wire_w_lg_nlOO1O1O17117w(0) AND wire_n1iliii_w_lg_dataout17118w(0))) OR wire_w_lg_w_lg_nlOO1O0l17123w17124w(0));
	n10l11i <= (n10l11O OR n10l11l);
	n10l11l <= (nll01ll AND wire_nllO1i_w_lg_nll01li7901w(0));
	n10l11O <= (wire_nl_w_lg_nll01ll7899w(0) AND nll01li);
	n10l1ii <= (wire_n1liO0O_w_lg_dataout4506w(0) OR wire_n1Ol10O_w_lg_dataout4507w(0));
	n10l1il <= (wire_w_lg_rencdt_rising4504w(0) AND nllii0i);
	n10l1iO <= (wire_w_lg_wa_6g_en4499w(0) OR (wire_w_lg_lpbk_en4500w(0) AND wire_nl_w_lg_nll01lO4501w(0)));
	n10l1li <= ((wire_nl_w_lg_nlli0OO4494w(0) AND wire_w_lg_wa_6g_en4496w(0)) AND n1iiilO);
	n10l1ll <= (wire_nllO0ii_dataout OR ((((NOT (rosnumber(0) XOR nlO01il)) AND (NOT (rosnumber(1) XOR nlO01iO))) AND (NOT (rosnumber(2) XOR nlO01li))) AND (NOT (rosnumber(3) XOR nlO01ll))));
	n10l1lO <= wire_nllO00i_w_lg_dataout4064w(0);
	n10l1Oi <= (wire_nllO0il_w_lg_dataout3407w(0) OR wire_w_lg_n10l01l3948w(0));
	n10l1Ol <= (wire_nllO0il_w_lg_w_lg_dataout3407w4078w(0) OR wire_w_lg_n10l01l3948w(0));
	n10l1OO <= (wire_nllO00O_w_lg_w_lg_w_lg_dataout3960w3961w3962w(0) OR wire_w_lg_n10l01l3948w(0));
	n10li0i <= (rosbased AND wire_w_lg_n10ll0i3493w(0));
	n10li0l <= (n10liii AND wire_w_lg_n10li0O3453w(0));
	n10li0O <= ((((((((((NOT (enumber(0) XOR nlO00ii)) AND (NOT (enumber(1) XOR nlO00il))) AND (NOT (enumber(2) XOR nlO00iO))) AND (NOT (enumber(3) XOR nlO00li))) AND (NOT (enumber(4) XOR nlO00ll))) AND (NOT (enumber(5) XOR nlO00lO))) AND (NOT (enumber(6) XOR nlO00Oi))) AND (NOT (enumber(7) XOR nlO00Ol))) AND (NOT (enumber(8) XOR nlO00OO))) AND (NOT (enumber(9) XOR nlO0i1i)));
	n10li1i <= ((wire_nlO10Ol_o AND n10liil) AND n10l0OO);
	n10li1l <= (n10liil AND wire_w_lg_n10l0OO3456w(0));
	n10li1O <= ((n10liil AND n10l0lO) AND n10l0OO);
	n10liii <= (wire_w_lg_rosbased3492w(0) AND n10ll0i);
	n10liil <= (wire_w_lg_rosbased3492w(0) AND wire_w_lg_n10ll0i3493w(0));
	n10liiO <= (n10liii AND n10li0O);
	n10lili <= ((((NOT (rosnumber(0) XOR wire_nlO0l0i_o(0))) AND (NOT (rosnumber(1) XOR wire_nlO0l0i_o(1)))) AND (NOT (rosnumber(2) XOR wire_nlO0l0i_o(2)))) AND (NOT (rosnumber(3) XOR wire_nlO0l0i_o(3))));
	n10lill <= (wire_w_lg_w_lg_n10liOl3443w3446w(0) AND wire_w_lg_w_lg_n10ll0O3433w3447w(0));
	n10lilO <= ((n10liOO OR (n10llii AND (n10ll0O AND n10lili))) AND n10liOl);
	n10liOi <= (n10liOO AND wire_w_lg_n10liOl3443w(0));
	n10liOl <= ((((((((((NOT (knumber(0) XOR nlO0i1l)) AND (NOT (knumber(1) XOR nlO0i1O))) AND (NOT (knumber(2) XOR nlO0i0i))) AND (NOT (knumber(3) XOR nlO0i0l))) AND (NOT (knumber(4) XOR nlO0i0O))) AND (NOT (knumber(5) XOR nlO0iii))) AND (NOT (knumber(6) XOR nlO0iil))) AND (NOT (knumber(7) XOR nlO0iiO))) AND (NOT (knumber(8) XOR nlO0ili))) AND (NOT (knumber(9) XOR nlO0ill)));
	n10liOO <= (wire_w_lg_n10ll0O3433w(0) AND niii0l);
	n10ll0i <= ((n10ll0O AND (((rkchar AND niiill) OR wire_w_lg_w_lg_rkchar3383w3384w(0)) AND wire_w_lg_n10ll0l3386w(0))) OR nil1Oi);
	n10ll0l <= ((((NOT (rosnumber(0) XOR nlO01il)) AND (NOT (rosnumber(1) XOR nlO01iO))) AND (NOT (rosnumber(2) XOR nlO01li))) AND (NOT (rosnumber(3) XOR nlO01ll)));
	n10ll0O <= (((rosnumber(0) OR rosnumber(1)) OR rosnumber(2)) OR rosnumber(3));
	n10ll1i <= ((wire_w_lg_n10llii3439w(0) AND n10ll0O) OR nil1Oi);
	n10ll1l <= (wire_w_lg_n10ll0O3433w(0) AND wire_w_lg_w_lg_n10ll1O3434w3435w(0));
	n10ll1O <= (((((((((knumber(0) OR knumber(1)) OR knumber(2)) OR knumber(3)) OR knumber(4)) OR knumber(5)) OR knumber(6)) OR knumber(7)) OR knumber(8)) OR knumber(9));
	n10llii <= (wire_nllO1i_w_lg_nil1Oi3372w(0) AND wire_nl_w_lg_niiill3373w(0));
	n10llil <= (wire_niOilO_o AND wire_niOill_o);
	n10lliO <= wire_niOilO_w_lg_w_lg_o3116w3135w(0);
	n10llli <= wire_niOilO_w_lg_o3119w(0);
	n10llll <= wire_niOilO_w_lg_w_lg_o3116w3117w(0);
	n10lllO <= (n1i000O AND n10llOl);
	n10llOi <= (wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_w_lg_o3108w(0) AND wire_niOilO_w_lg_w_lg_o3116w3135w(0)));
	n10llOl <= wire_niOl1i_w_lg_o2994w(0);
	n10llOO <= (wire_niOiOl_o AND (wire_niOiOi_o AND (wire_niOilO_o AND wire_niOill_o)));
	n10lO0i <= wire_niOl1O_w_lg_o3190w(0);
	n10lO0l <= wire_niOl1O_w_lg_w_lg_o1314w3189w(0);
	n10lO0O <= (wire_niOl0i_dataout XOR wire_niOl1l_o);
	n10lO1i <= ((((wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_o AND n10llil)) OR wire_niOiOl_w_lg_o3288w(0)) OR wire_niOiOl_w_lg_o3156w(0)) OR wire_niOiOl_w_lg_o3159w(0));
	n10lO1l <= wire_niOl1O_w_lg_o2980w(0);
	n10lO1O <= wire_niOl1O_w_lg_w_lg_o1314w2984w(0);
	n10lOii <= (wire_niOilO_o AND wire_niOill_o);
	n10lOil <= wire_niOilO_w_lg_w_lg_o3116w3135w(0);
	n10lOiO <= wire_niOilO_w_lg_o3119w(0);
	n10lOli <= wire_niOilO_w_lg_w_lg_o3116w3117w(0);
	n10lOll <= ((((wire_niOl0l_w_lg_dataout1312w(0) AND (wire_niOl0i_dataout AND n10lO1l)) OR wire_niOl0l_w_lg_dataout3222w(0)) OR wire_niOl0l_w_lg_dataout3225w(0)) OR wire_niOl0l_w_lg_dataout3228w(0));
	n10lOlO <= (wire_nlOll0O_w_lg_w_lg_dataout1212w3256w(0) OR (wire_nlOll0O_dataout AND n1i00ii));
	n10lOOi <= wire_niOl0l_w_lg_dataout2982w(0);
	n10lOOl <= (n10llOO AND n1i000l);
	n10lOOO <= ((n10llOO AND n10llOl) OR (n10lO1i AND n10llOl));
	n10O00i <= (n1O01l OR n1O01i);
	n10O00l <= (wire_nl_w_lg_n1OOOO2714w(0) AND wire_nl_w_lg_n1OOOl2708w(0));
	n10O00O <= (wire_nl_w_lg_n1OOOO2714w(0) AND n1OOOl);
	n10O01i <= (n1O1OO OR n1O1Ol);
	n10O01l <= ((((n1O01l OR n1O01i) OR n1O1OO) OR n1O1Ol) OR n1O1Oi);
	n10O01O <= ((((n1O01l OR n1O01i) OR n1O1lO) OR n1O1ll) OR n1l0Oi);
	n10O0ii <= (n1l0lO AND n1l0ll);
	n10O0il <= (wire_nl_w_lg_n010Ol2709w(0) AND wire_nl_w_lg_n1OOOl2708w(0));
	n10O0iO <= (wire_nl_w_lg_n010Ol2709w(0) AND n1OOOl);
	n10O0li <= ((((max_rlv_sel(0) OR max_rlv_sel(1)) OR max_rlv_sel(2)) OR max_rlv_sel(3)) OR max_rlv_sel(4));
	n10O0ll <= ((wire_n1O0ll_w_lg_w2963w2964w(0) AND wire_n1O00l_w_lg_dataout2965w(0)) AND wire_n1O00i_w_lg_dataout2967w(0));
	n10O0lO <= ((wire_n1O0ll_w_lg_w2963w2964w(0) AND wire_n1O00l_w_lg_dataout2965w(0)) AND wire_n1O00i_dataout);
	n10O0Oi <= ((((((wire_w_lg_w_pmadwidth_range175w2600w(0) OR wire_nl_w_lg_nlil1l2592w(0)) OR wire_nl_w_lg_nlil1i2594w(0)) OR wire_nl_w_lg_nliiOO2596w(0)) OR wire_nl_w_lg_nliiOl2604w(0)) OR wire_n1OOOi_w_lg_dataout2538w(0)) OR wire_nl_w_lg_n1OiOi2540w(0));
	n10O0Ol <= ((((((wire_w_lg_w_pmadwidth_range175w2589w(0) OR wire_nl_w_lg_nlil1O2590w(0)) OR wire_nl_w_lg_nlil1l2592w(0)) OR wire_nl_w_lg_nlil1i2594w(0)) OR wire_nl_w_lg_nliiOO2596w(0)) OR wire_n1OOOi_w_lg_dataout2538w(0)) OR wire_nl_w_lg_n1OiOi2540w(0));
	n10O0OO <= ((((((wire_w_lg_w_pmadwidth_range175w2608w(0) OR wire_nl_w_lg_nlil1i2594w(0)) OR wire_nl_w_lg_nliiOO2596w(0)) OR wire_nl_w_lg_nliiOl2604w(0)) OR wire_nl_w_lg_nl1lOi2612w(0)) OR wire_n1OOOi_w_lg_dataout2538w(0)) OR wire_nl_w_lg_n1OiOi2540w(0));
	n10O10i <= wire_niOl1O_w_lg_w_lg_o1314w2984w(0);
	n10O10l <= wire_niOl1O_w_lg_o2980w(0);
	n10O10O <= (wire_niOl1i_w_lg_o3107w(0) OR (wire_niOl1i_w_lg_o2972w(0) AND (wire_niOiOO_w_lg_o2973w(0) AND (wire_niOiOl_w_lg_o1205w(0) AND wire_niOiOi_w_lg_o3108w(0)))));
	n10O11i <= (n10llOO AND n1i00ii);
	n10O11l <= (wire_niOl0l_w_lg_dataout1312w(0) AND wire_niOl0i_w_lg_dataout1313w(0));
	n10O11O <= ((((((wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_w_lg_o3108w(0) AND (wire_niOilO_o AND wire_niOill_o))) OR (wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_o AND n10lOli))) OR (wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_o AND n10lOiO))) OR wire_niOiOl_w_lg_o3130w(0)) OR wire_niOiOl_w_lg_o3133w(0)) OR wire_niOiOl_w_lg_o3137w(0));
	n10O1ii <= wire_niOl1i_w_lg_w_lg_o2972w3113w(0);
	n10O1il <= wire_niOl1i_w_lg_o3114w(0);
	n10O1iO <= ((((wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_o AND n10lOii)) OR wire_niOiOl_w_lg_o3153w(0)) OR wire_niOiOl_w_lg_o3156w(0)) OR wire_niOiOl_w_lg_o3159w(0));
	n10O1li <= ((((wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_w_lg_o3108w(0) AND wire_niOilO_w_lg_w_lg_o3116w3117w(0))) OR (wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_w_lg_o3108w(0) AND wire_niOilO_w_lg_o3119w(0)))) OR (wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_o AND n10lOil))) OR wire_niOiOl_w_lg_o3148w(0));
	n10O1ll <= (wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_w_lg_o3108w(0) AND wire_niOilO_w_lg_w_lg_o3116w3135w(0)));
	n10O1lO <= (wire_niOiOl_o AND (wire_niOiOi_o AND (wire_niOilO_o AND wire_niOill_o)));
	n10O1Oi <= (wire_w_lg_w_ib_invalid_code_range3169w3175w(0) OR wire_w_lg_w_ib_invalid_code_range3176w3184w(0));
	n10O1Ol <= (n1O1Oi OR n1l0Oi);
	n10O1OO <= (n1O1lO OR n1O1ll);
	n10Oi0i <= ((((((((wire_w_lg_w_pmadwidth_range175w219w(0) OR wire_nl_w_lg_nlil1O2590w(0)) OR wire_nl_w_lg_nlil1l2592w(0)) OR wire_nl_w_lg_nlil1i2594w(0)) OR wire_nl_w_lg_nliiOO2596w(0)) OR wire_nl_w_lg_nliiOl2604w(0)) OR wire_nl_w_lg_nl1lOi2612w(0)) OR wire_n1OOOi_w_lg_dataout2538w(0)) OR wire_nl_w_lg_n1OiOi2540w(0));
	n10Oi0l <= ((wire_w_lg_w_lg_w2544w2545w2546w(0) OR wire_n1OOOi_w_lg_dataout2538w(0)) OR wire_nl_w_lg_n1OiOi2540w(0));
	n10Oi0O <= ((wire_w_lg_w_lg_w2535w2536w2537w(0) OR wire_n1OOOi_w_lg_dataout2538w(0)) OR wire_nl_w_lg_n1OiOi2540w(0));
	n10Oi1i <= ((((((((wire_w_lg_w_pmadwidth_range175w219w(0) OR wire_nl_w_lg_nlil0O2616w(0)) OR wire_nl_w_lg_nlil0l2618w(0)) OR wire_nl_w_lg_nlil0i2588w(0)) OR wire_nl_w_lg_nlil1O2590w(0)) OR wire_nl_w_lg_nlil1l2592w(0)) OR wire_nl_w_lg_nlil1i2594w(0)) OR wire_n1OOOi_w_lg_dataout2538w(0)) OR wire_nl_w_lg_n1OiOi2540w(0));
	n10Oi1l <= ((((((((wire_w_lg_w_pmadwidth_range175w219w(0) OR wire_nl_w_lg_nlil0l2618w(0)) OR wire_nl_w_lg_nlil0i2588w(0)) OR wire_nl_w_lg_nlil1O2590w(0)) OR wire_nl_w_lg_nlil1l2592w(0)) OR wire_nl_w_lg_nlil1i2594w(0)) OR wire_nl_w_lg_nliiOO2596w(0)) OR wire_n1OOOi_w_lg_dataout2538w(0)) OR wire_nl_w_lg_n1OiOi2540w(0));
	n10Oi1O <= ((((((((wire_w_lg_w_pmadwidth_range175w219w(0) OR wire_nl_w_lg_nlil0i2588w(0)) OR wire_nl_w_lg_nlil1O2590w(0)) OR wire_nl_w_lg_nlil1l2592w(0)) OR wire_nl_w_lg_nlil1i2594w(0)) OR wire_nl_w_lg_nliiOO2596w(0)) OR wire_nl_w_lg_nliiOl2604w(0)) OR wire_n1OOOi_w_lg_dataout2538w(0)) OR wire_nl_w_lg_n1OiOi2540w(0));
	n10Oiii <= ((wire_w_lg_w_lg_w2551w2552w2553w(0) OR wire_n1OOOi_w_lg_dataout2538w(0)) OR wire_nl_w_lg_n1OiOi2540w(0));
	n10Oiil <= ((wire_w_lg_w_lg_w_lg_w2558w2559w2560w2561w(0) OR wire_n1OOOi_w_lg_dataout2538w(0)) OR wire_nl_w_lg_n1OiOi2540w(0));
	n10OiiO <= ((wire_w_lg_w_lg_w_lg_w2566w2567w2568w2569w(0) OR wire_n1OOOi_w_lg_dataout2538w(0)) OR wire_nl_w_lg_n1OiOi2540w(0));
	n10Oili <= ((wire_w_lg_w_lg_w_lg_w2574w2575w2576w2577w(0) OR wire_n1OOOi_w_lg_dataout2538w(0)) OR wire_nl_w_lg_n1OiOi2540w(0));
	n10Oill <= ((wire_w_lg_w_lg_w_lg_w2582w2583w2584w2585w(0) OR wire_n1OOOi_w_lg_dataout2538w(0)) OR wire_nl_w_lg_n1OiOi2540w(0));
	n10OilO <= ((((wire_w_lg_n10Ol0O2457w(0) OR wire_w_lg_n10Ol0l2449w(0)) OR wire_w_lg_n10Ol1O2459w(0)) OR wire_w_lg_n10Ol1i2453w(0)) OR n10OiOi);
	n10OiOi <= ((((((((wire_nl_w_lg_nl1lOi2945w(0) AND wire_w_lg_n1i11OO2440w(0)) AND wire_w_lg_n1i11Ol2432w(0)) AND wire_w_lg_n1i11Oi2425w(0)) AND wire_w_lg_n1i11lO2419w(0)) AND wire_w_lg_n1i11ll2414w(0)) AND wire_w_lg_n1i11li2410w(0)) AND wire_w_lg_n1i11il2408w(0)) AND wire_w_lg_n1i11ii2953w(0));
	n10OiOl <= (((wire_w_lg_n1i11ii2450w(0) OR wire_w_lg_n10Ol0i2451w(0)) OR wire_w_lg_n10Ol1i2453w(0)) OR wire_w_lg_n10OiOO2455w(0));
	n10OiOO <= ((((((((n1i100O OR wire_w_lg_n1i11OO2440w(0)) OR n1i11Ol) OR n1i11Oi) OR n1i11lO) OR n1i11ll) OR n1i11li) OR n1i11il) OR n1i11ii);
	n10Ol0i <= ((((n1i100O OR wire_w_lg_n1i11ll2414w(0)) OR n1i11li) OR n1i11il) OR n1i11ii);
	n10Ol0l <= (((n1i100O OR wire_w_lg_n1i11li2410w(0)) OR n1i11il) OR n1i11ii);
	n10Ol0O <= (wire_w_lg_n1i11il2408w(0) OR n1i11ii);
	n10Ol1i <= (((((((n1i100O OR wire_w_lg_n1i11Ol2432w(0)) OR n1i11Oi) OR n1i11lO) OR n1i11ll) OR n1i11li) OR n1i11il) OR n1i11ii);
	n10Ol1l <= ((((((n1i100O OR wire_w_lg_n1i11Oi2425w(0)) OR n1i11lO) OR n1i11ll) OR n1i11li) OR n1i11il) OR n1i11ii);
	n10Ol1O <= (((((n1i100O OR wire_w_lg_n1i11lO2419w(0)) OR n1i11ll) OR n1i11li) OR n1i11il) OR n1i11ii);
	n10Olii <= ((((wire_w_lg_n10OO1i2402w(0) OR wire_w_lg_n10OlOO2394w(0)) OR wire_w_lg_n10OlOi2404w(0)) OR wire_w_lg_n10Olll2398w(0)) OR n10Olil);
	n10Olil <= ((((((((((n1i1i0O OR n1i1i0l) AND wire_w_lg_n1i1i0i2385w(0)) AND wire_w_lg_n1i1i1O2377w(0)) AND wire_w_lg_n1i1i1l2370w(0)) AND wire_w_lg_n1i10Ol2364w(0)) AND wire_w_lg_n1i10ll2359w(0)) AND wire_w_lg_n1i10il2355w(0)) AND wire_w_lg_n1i100l2498w(0)) AND wire_w_lg_n1i101O2353w(0)) AND wire_w_lg_n1i101i2943w(0));
	n10OliO <= (((wire_w_lg_n1i101i2395w(0) OR wire_w_lg_n10OlOl2396w(0)) OR wire_w_lg_n10Olll2398w(0)) OR wire_w_lg_n10Olli2400w(0));
	n10Olli <= ((((((((wire_w_lg_n1i1i0i2385w(0) OR n1i1i1O) OR n1i1i1l) OR n1i10Ol) OR n1i10ll) OR n1i10il) OR n1i100l) OR n1i101O) OR n1i101i);
	n10Olll <= (((((((wire_w_lg_n1i1i1O2377w(0) OR n1i1i1l) OR n1i10Ol) OR n1i10ll) OR n1i10il) OR n1i100l) OR n1i101O) OR n1i101i);
	n10OllO <= ((((((wire_w_lg_n1i1i1l2370w(0) OR n1i10Ol) OR n1i10ll) OR n1i10il) OR n1i100l) OR n1i101O) OR n1i101i);
	n10OlOi <= (((((wire_w_lg_n1i10Ol2364w(0) OR n1i10ll) OR n1i10il) OR n1i100l) OR n1i101O) OR n1i101i);
	n10OlOl <= ((((wire_w_lg_n1i10ll2359w(0) OR n1i10il) OR n1i100l) OR n1i101O) OR n1i101i);
	n10OlOO <= (((wire_w_lg_n1i10il2355w(0) OR n1i100l) OR n1i101O) OR n1i101i);
	n10OO0i <= (((wire_w_lg_n1i1iii2340w(0) OR wire_w_lg_n10OOiO2341w(0)) OR wire_w_lg_n10OO0O2343w(0)) OR wire_w_lg_n10OO0l2345w(0));
	n10OO0l <= (((((((wire_w_lg_w_lg_n1i1l0O2133w2330w(0) OR wire_w_lg_n1i1iOl2331w(0)) OR wire_w_lg_n1i1iOi2323w(0)) OR wire_w_lg_n1i1ilO2316w(0)) OR wire_w_lg_n1i1ill2310w(0)) OR wire_w_lg_n1i1ili2305w(0)) OR n1i1iil) OR n1i1iii);
	n10OO0O <= ((((((wire_w_lg_w_lg_n1i1l0O2133w2322w(0) OR wire_w_lg_n1i1iOi2323w(0)) OR wire_w_lg_n1i1ilO2316w(0)) OR wire_w_lg_n1i1ill2310w(0)) OR wire_w_lg_n1i1ili2305w(0)) OR n1i1iil) OR n1i1iii);
	n10OO1i <= (wire_w_lg_n1i101O2353w(0) OR n1i101i);
	n10OO1l <= ((((wire_w_lg_n10OOll2347w(0) OR wire_w_lg_n10OOli2339w(0)) OR wire_w_lg_n10OOil2349w(0)) OR wire_w_lg_n10OO0O2343w(0)) OR n10OO1O);
	n10OO1O <= ((wire_nl_w_lg_w_lg_w_lg_w2928w2929w2930w2931w(0) AND wire_w_lg_n1i1iil2299w(0)) AND wire_w_lg_n1i1iii2933w(0));
	n10OOii <= (((((wire_w_lg_w_lg_n1i1l0O2133w2315w(0) OR wire_w_lg_n1i1ilO2316w(0)) OR wire_w_lg_n1i1ill2310w(0)) OR wire_w_lg_n1i1ili2305w(0)) OR n1i1iil) OR n1i1iii);
	n10OOil <= ((((wire_w_lg_w_lg_n1i1l0O2133w2309w(0) OR wire_w_lg_n1i1ill2310w(0)) OR wire_w_lg_n1i1ili2305w(0)) OR n1i1iil) OR n1i1iii);
	n10OOiO <= (((wire_w_lg_w_lg_n1i1l0O2133w2304w(0) OR wire_w_lg_n1i1ili2305w(0)) OR n1i1iil) OR n1i1iii);
	n10OOli <= (((wire_w_lg_n1i1l0O2133w(0) OR n1i1ili) OR n1i1iil) OR n1i1iii);
	n10OOll <= (wire_w_lg_n1i1iil2299w(0) OR n1i1iii);
	n10OOlO <= ((((wire_w_lg_n1i110O2293w(0) OR wire_w_lg_n1i110l2285w(0)) OR wire_w_lg_n1i111O2295w(0)) OR wire_w_lg_n1i111i2289w(0)) OR n10OOOi);
	n10OOOi <= ((((((((((wire_w_lg_w_pmadwidth_range175w2912w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_nl_w_lg_nlil0l2618w(0))) AND wire_w_lg_n1i1O0i2276w(0)) AND wire_w_lg_n1i1O1O2268w(0)) AND wire_w_lg_n1i1O1l2261w(0)) AND wire_w_lg_n1i1lOl2255w(0)) AND wire_w_lg_n1i1lll2250w(0)) AND wire_w_lg_n1i1lil2246w(0)) AND wire_w_lg_n1i1l0l2464w(0)) AND wire_w_lg_n1i1l1O2244w(0)) AND wire_w_lg_n1i1l1i2923w(0));
	n10OOOl <= (((wire_w_lg_n1i1l1i2286w(0) OR wire_w_lg_n1i110i2287w(0)) OR wire_w_lg_n1i111i2289w(0)) OR wire_w_lg_n10OOOO2291w(0));
	n10OOOO <= ((((((((wire_w_lg_n1i1O0i2276w(0) OR n1i1O1O) OR n1i1O1l) OR n1i1lOl) OR n1i1lll) OR n1i1lil) OR n1i1l0l) OR n1i1l1O) OR n1i1l1i);
	n11000i <= ((((((((((NOT ((NOT comp_pat(0)) XOR nl01iOi)) AND (NOT ((NOT comp_pat(1)) XOR nl01iOl))) AND (NOT ((NOT comp_pat(2)) XOR nl01iOO))) AND (NOT ((NOT comp_pat(3)) XOR nl01l1i))) AND (NOT ((NOT comp_pat(4)) XOR nl01l1l))) AND (NOT ((NOT comp_pat(5)) XOR nl01l1O))) AND (NOT ((NOT comp_pat(6)) XOR nl01l0i))) AND (NOT ((NOT comp_pat(7)) XOR nl01l0l))) AND (NOT ((NOT comp_pat(8)) XOR nl01l0O))) AND (NOT ((NOT comp_pat(9)) XOR nl01lii)));
	n11000l <= ((comp_pat_porn AND n1100ii) OR n11000O);
	n11000O <= ((((((((NOT (comp_pat(8) XOR nl01l0O)) AND (NOT (comp_pat(9) XOR nl01lii))) AND (NOT (comp_pat(10) XOR nl01lil))) AND (NOT (comp_pat(11) XOR nl01liO))) AND (NOT (comp_pat(12) XOR nl01lli))) AND (NOT (comp_pat(13) XOR nl01lll))) AND (NOT (comp_pat(14) XOR nl01llO))) AND (NOT (comp_pat(15) XOR nl01lOi)));
	n11001i <= ((((((((((NOT ((NOT comp_pat(0)) XOR nl01lil)) AND (NOT ((NOT comp_pat(1)) XOR nl01liO))) AND (NOT ((NOT comp_pat(2)) XOR nl01lli))) AND (NOT ((NOT comp_pat(3)) XOR nl01lll))) AND (NOT ((NOT comp_pat(4)) XOR nl01llO))) AND (NOT ((NOT comp_pat(5)) XOR nl01lOi))) AND (NOT ((NOT comp_pat(6)) XOR nl01lOl))) AND (NOT ((NOT comp_pat(7)) XOR nl01lOO))) AND (NOT ((NOT comp_pat(8)) XOR nl01O1i))) AND (NOT ((NOT comp_pat(9)) XOR nl01O1l)));
	n11001l <= ((comp_pat_porn AND n11000i) OR n11001O);
	n11001O <= ((((((((((NOT (comp_pat(0) XOR nl01iOi)) AND (NOT (comp_pat(1) XOR nl01iOl))) AND (NOT (comp_pat(2) XOR nl01iOO))) AND (NOT (comp_pat(3) XOR nl01l1i))) AND (NOT (comp_pat(4) XOR nl01l1l))) AND (NOT (comp_pat(5) XOR nl01l1O))) AND (NOT (comp_pat(6) XOR nl01l0i))) AND (NOT (comp_pat(7) XOR nl01l0l))) AND (NOT (comp_pat(8) XOR nl01l0O))) AND (NOT (comp_pat(9) XOR nl01lii)));
	n1100ii <= ((((((((NOT ((NOT comp_pat(8)) XOR nl01l0O)) AND (NOT ((NOT comp_pat(9)) XOR nl01lii))) AND (NOT ((NOT comp_pat(10)) XOR nl01lil))) AND (NOT ((NOT comp_pat(11)) XOR nl01liO))) AND (NOT ((NOT comp_pat(12)) XOR nl01lli))) AND (NOT ((NOT comp_pat(13)) XOR nl01lll))) AND (NOT ((NOT comp_pat(14)) XOR nl01llO))) AND (NOT ((NOT comp_pat(15)) XOR nl01lOi)));
	n1100il <= ((comp_pat_porn AND n1100li) OR n1100iO);
	n1100iO <= ((((((((NOT (comp_pat(8) XOR nl01iOi)) AND (NOT (comp_pat(9) XOR nl01iOl))) AND (NOT (comp_pat(10) XOR nl01iOO))) AND (NOT (comp_pat(11) XOR nl01l1i))) AND (NOT (comp_pat(12) XOR nl01l1l))) AND (NOT (comp_pat(13) XOR nl01l1O))) AND (NOT (comp_pat(14) XOR nl01l0i))) AND (NOT (comp_pat(15) XOR nl01l0l)));
	n1100li <= ((((((((NOT ((NOT comp_pat(8)) XOR nl01iOi)) AND (NOT ((NOT comp_pat(9)) XOR nl01iOl))) AND (NOT ((NOT comp_pat(10)) XOR nl01iOO))) AND (NOT ((NOT comp_pat(11)) XOR nl01l1i))) AND (NOT ((NOT comp_pat(12)) XOR nl01l1l))) AND (NOT ((NOT comp_pat(13)) XOR nl01l1O))) AND (NOT ((NOT comp_pat(14)) XOR nl01l0i))) AND (NOT ((NOT comp_pat(15)) XOR nl01l0l)));
	n1100ll <= ((comp_pat_porn AND n1100Oi) OR n1100lO);
	n1100lO <= ((((((((NOT (comp_pat(0) XOR nl01l0O)) AND (NOT (comp_pat(1) XOR nl01lii))) AND (NOT (comp_pat(2) XOR nl01lil))) AND (NOT (comp_pat(3) XOR nl01liO))) AND (NOT (comp_pat(4) XOR nl01lli))) AND (NOT (comp_pat(5) XOR nl01lll))) AND (NOT (comp_pat(6) XOR nl01llO))) AND (NOT (comp_pat(7) XOR nl01lOi)));
	n1100Oi <= ((((((((NOT ((NOT comp_pat(0)) XOR nl01l0O)) AND (NOT ((NOT comp_pat(1)) XOR nl01lii))) AND (NOT ((NOT comp_pat(2)) XOR nl01lil))) AND (NOT ((NOT comp_pat(3)) XOR nl01liO))) AND (NOT ((NOT comp_pat(4)) XOR nl01lli))) AND (NOT ((NOT comp_pat(5)) XOR nl01lll))) AND (NOT ((NOT comp_pat(6)) XOR nl01llO))) AND (NOT ((NOT comp_pat(7)) XOR nl01lOi)));
	n1100Ol <= ((comp_pat_porn AND n110i1i) OR n1100OO);
	n1100OO <= ((((((((NOT (comp_pat(0) XOR nl01iOi)) AND (NOT (comp_pat(1) XOR nl01iOl))) AND (NOT (comp_pat(2) XOR nl01iOO))) AND (NOT (comp_pat(3) XOR nl01l1i))) AND (NOT (comp_pat(4) XOR nl01l1l))) AND (NOT (comp_pat(5) XOR nl01l1O))) AND (NOT (comp_pat(6) XOR nl01l0i))) AND (NOT (comp_pat(7) XOR nl01l0l)));
	n11010i <= ((((((((((NOT (comp_pat(10) XOR nl01i1O)) AND (NOT (comp_pat(11) XOR nl01i0i))) AND (NOT (comp_pat(12) XOR nl01i0l))) AND (NOT (comp_pat(13) XOR nl01i0O))) AND (NOT (comp_pat(14) XOR nl01iii))) AND (NOT (comp_pat(15) XOR nl01iil))) AND (NOT (comp_pat(16) XOR nl01iiO))) AND (NOT (comp_pat(17) XOR nl01ili))) AND (NOT (comp_pat(18) XOR nl01ill))) AND (NOT (comp_pat(19) XOR nl01ilO)));
	n11010l <= ((((((((((NOT ((NOT comp_pat(10)) XOR nl01i1O)) AND (NOT ((NOT comp_pat(11)) XOR nl01i0i))) AND (NOT ((NOT comp_pat(12)) XOR nl01i0l))) AND (NOT ((NOT comp_pat(13)) XOR nl01i0O))) AND (NOT ((NOT comp_pat(14)) XOR nl01iii))) AND (NOT ((NOT comp_pat(15)) XOR nl01iil))) AND (NOT ((NOT comp_pat(16)) XOR nl01iiO))) AND (NOT ((NOT comp_pat(17)) XOR nl01ili))) AND (NOT ((NOT comp_pat(18)) XOR nl01ill))) AND (NOT ((NOT comp_pat(19)) XOR nl01ilO)));
	n11010O <= ((n1101Ol OR nl1Ol0O) OR (n1iiiOi AND nl1OiOi));
	n11011i <= ((((((((((NOT (comp_pat(0) XOR nl010il)) AND (NOT (comp_pat(1) XOR nl010iO))) AND (NOT (comp_pat(2) XOR nl010li))) AND (NOT (comp_pat(3) XOR nl010ll))) AND (NOT (comp_pat(4) XOR nl010lO))) AND (NOT (comp_pat(5) XOR nl010Oi))) AND (NOT (comp_pat(6) XOR nl010Ol))) AND (NOT (comp_pat(7) XOR nl010OO))) AND (NOT (comp_pat(8) XOR nl01i1i))) AND (NOT (comp_pat(9) XOR nl01i1l)));
	n11011l <= ((((((((((NOT ((NOT comp_pat(0)) XOR nl010il)) AND (NOT ((NOT comp_pat(1)) XOR nl010iO))) AND (NOT ((NOT comp_pat(2)) XOR nl010li))) AND (NOT ((NOT comp_pat(3)) XOR nl010ll))) AND (NOT ((NOT comp_pat(4)) XOR nl010lO))) AND (NOT ((NOT comp_pat(5)) XOR nl010Oi))) AND (NOT ((NOT comp_pat(6)) XOR nl010Ol))) AND (NOT ((NOT comp_pat(7)) XOR nl010OO))) AND (NOT ((NOT comp_pat(8)) XOR nl01i1i))) AND (NOT ((NOT comp_pat(9)) XOR nl01i1l)));
	n11011O <= ((comp_pat_porn AND n11010l) OR n11010i);
	n1101ii <= ((n11001l OR nl1Ol0l) OR (n1iiiOi AND nl1OilO));
	n1101il <= ((comp_pat_porn AND n1101li) OR n1101iO);
	n1101iO <= ((((((((((NOT (comp_pat(10) XOR nl01lil)) AND (NOT (comp_pat(11) XOR nl01liO))) AND (NOT (comp_pat(12) XOR nl01lli))) AND (NOT (comp_pat(13) XOR nl01lll))) AND (NOT (comp_pat(14) XOR nl01llO))) AND (NOT (comp_pat(15) XOR nl01lOi))) AND (NOT (comp_pat(16) XOR nl01lOl))) AND (NOT (comp_pat(17) XOR nl01lOO))) AND (NOT (comp_pat(18) XOR nl01O1i))) AND (NOT (comp_pat(19) XOR nl01O1l)));
	n1101li <= ((((((((((NOT ((NOT comp_pat(10)) XOR nl01lil)) AND (NOT ((NOT comp_pat(11)) XOR nl01liO))) AND (NOT ((NOT comp_pat(12)) XOR nl01lli))) AND (NOT ((NOT comp_pat(13)) XOR nl01lll))) AND (NOT ((NOT comp_pat(14)) XOR nl01llO))) AND (NOT ((NOT comp_pat(15)) XOR nl01lOi))) AND (NOT ((NOT comp_pat(16)) XOR nl01lOl))) AND (NOT ((NOT comp_pat(17)) XOR nl01lOO))) AND (NOT ((NOT comp_pat(18)) XOR nl01O1i))) AND (NOT ((NOT comp_pat(19)) XOR nl01O1l)));
	n1101ll <= ((comp_pat_porn AND n1101Oi) OR n1101lO);
	n1101lO <= ((((((((((NOT (comp_pat(10) XOR nl01iOi)) AND (NOT (comp_pat(11) XOR nl01iOl))) AND (NOT (comp_pat(12) XOR nl01iOO))) AND (NOT (comp_pat(13) XOR nl01l1i))) AND (NOT (comp_pat(14) XOR nl01l1l))) AND (NOT (comp_pat(15) XOR nl01l1O))) AND (NOT (comp_pat(16) XOR nl01l0i))) AND (NOT (comp_pat(17) XOR nl01l0l))) AND (NOT (comp_pat(18) XOR nl01l0O))) AND (NOT (comp_pat(19) XOR nl01lii)));
	n1101Oi <= ((((((((((NOT ((NOT comp_pat(10)) XOR nl01iOi)) AND (NOT ((NOT comp_pat(11)) XOR nl01iOl))) AND (NOT ((NOT comp_pat(12)) XOR nl01iOO))) AND (NOT ((NOT comp_pat(13)) XOR nl01l1i))) AND (NOT ((NOT comp_pat(14)) XOR nl01l1l))) AND (NOT ((NOT comp_pat(15)) XOR nl01l1O))) AND (NOT ((NOT comp_pat(16)) XOR nl01l0i))) AND (NOT ((NOT comp_pat(17)) XOR nl01l0l))) AND (NOT ((NOT comp_pat(18)) XOR nl01l0O))) AND (NOT ((NOT comp_pat(19)) XOR nl01lii)));
	n1101Ol <= ((comp_pat_porn AND n11001i) OR n1101OO);
	n1101OO <= ((((((((((NOT (comp_pat(0) XOR nl01lil)) AND (NOT (comp_pat(1) XOR nl01liO))) AND (NOT (comp_pat(2) XOR nl01lli))) AND (NOT (comp_pat(3) XOR nl01lll))) AND (NOT (comp_pat(4) XOR nl01llO))) AND (NOT (comp_pat(5) XOR nl01lOi))) AND (NOT (comp_pat(6) XOR nl01lOl))) AND (NOT (comp_pat(7) XOR nl01lOO))) AND (NOT (comp_pat(8) XOR nl01O1i))) AND (NOT (comp_pat(9) XOR nl01O1l)));
	n110i0i <= (((NOT comp_pat_size(0)) AND wire_w_lg_w_comp_pat_size_range1331w1332w(0)) AND comp_pat_size(2));
	n110i0l <= ((comp_pat_size(0) AND comp_pat_size(1)) AND (NOT comp_pat_size(2)));
	n110i0O <= (((NOT comp_pat_size(0)) AND comp_pat_size(1)) AND (NOT comp_pat_size(2)));
	n110i1i <= ((((((((NOT ((NOT comp_pat(0)) XOR nl01iOi)) AND (NOT ((NOT comp_pat(1)) XOR nl01iOl))) AND (NOT ((NOT comp_pat(2)) XOR nl01iOO))) AND (NOT ((NOT comp_pat(3)) XOR nl01l1i))) AND (NOT ((NOT comp_pat(4)) XOR nl01l1l))) AND (NOT ((NOT comp_pat(5)) XOR nl01l1O))) AND (NOT ((NOT comp_pat(6)) XOR nl01l0i))) AND (NOT ((NOT comp_pat(7)) XOR nl01l0l)));
	n110i1l <= (((NOT comp_pat_size(0)) AND comp_pat_size(1)) AND comp_pat_size(2));
	n110i1O <= (wire_w_lg_w_comp_pat_size_range1330w1333w(0) AND comp_pat_size(2));
	n110iii <= (wire_w_lg_w_comp_pat_size_range1330w1333w(0) AND (NOT comp_pat_size(2)));
	n110iil <= (((NOT comp_pat_size(0)) AND wire_w_lg_w_comp_pat_size_range1331w1332w(0)) AND (NOT comp_pat_size(2)));
	n110iiO <= ((((((((wire_nl0OiOl_w_lg_o5684w(0) OR wire_w_lg_n110lOO5624w(0)) OR wire_w_lg_n110lOi5628w(0)) OR wire_w_lg_n110lll5632w(0)) OR wire_w_lg_n110liO5636w(0)) OR wire_w_lg_n110lii5640w(0)) OR wire_w_lg_n110l0l5644w(0)) OR wire_w_lg_n110l1O5648w(0)) OR wire_w_lg_n110l1i5652w(0));
	n110ili <= ((((((((wire_nl0OiOl_w_lg_o5615w(0) OR wire_w_lg_n110lOO5624w(0)) OR wire_w_lg_n110lOl5626w(0)) OR wire_w_lg_n110lll5632w(0)) OR wire_w_lg_n110lli5634w(0)) OR wire_w_lg_n110lii5640w(0)) OR wire_w_lg_n110l0O5642w(0)) OR wire_w_lg_n110l1O5648w(0)) OR wire_w_lg_n110l1l5650w(0));
	n110ill <= ((((((((wire_w_lg_n110lOO5624w(0) OR wire_w_lg_n110lOl5626w(0)) OR wire_w_lg_n110lOi5628w(0)) OR wire_w_lg_n110llO5630w(0)) OR wire_w_lg_n110lii5640w(0)) OR wire_w_lg_n110l0O5642w(0)) OR wire_w_lg_n110l0l5644w(0)) OR wire_w_lg_n110l0i5646w(0)) OR wire_w_lg_n110iOl5657w(0));
	n110ilO <= ((((((((wire_w_lg_n110lll5632w(0) OR wire_w_lg_n110lli5634w(0)) OR wire_w_lg_n110liO5636w(0)) OR wire_w_lg_n110lil5638w(0)) OR wire_w_lg_n110lii5640w(0)) OR wire_w_lg_n110l0O5642w(0)) OR wire_w_lg_n110l0l5644w(0)) OR wire_w_lg_n110l0i5646w(0)) OR wire_w_lg_n110iOl5657w(0));
	n110iOi <= ((((wire_w_lg_n110l1O5648w(0) OR wire_w_lg_n110l1l5650w(0)) OR wire_w_lg_n110l1i5652w(0)) OR wire_w_lg_n110iOl5657w(0)) OR n110iOO);
	n110iOl <= ((((((((((((((((((wire_nl0OiOl_w_lg_o5615w(0) OR wire_w_lg_n110O1i5616w(0)) OR (NOT (((wire_nl0Ol1l_w_lg_o5618w(0) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o))) OR wire_w_lg_n110lOO5624w(0)) OR wire_w_lg_n110lOl5626w(0)) OR wire_w_lg_n110lOi5628w(0)) OR wire_w_lg_n110llO5630w(0)) OR wire_w_lg_n110lll5632w(0)) OR wire_w_lg_n110lli5634w(0)) OR wire_w_lg_n110liO5636w(0)) OR wire_w_lg_n110lil5638w(0)) OR wire_w_lg_n110lii5640w(0)) OR wire_w_lg_n110l0O5642w(0)) OR wire_w_lg_n110l0l5644w(0)) OR wire_w_lg_n110l0i5646w(0)) OR wire_w_lg_n110l1O5648w(0)) OR wire_w_lg_n110l1l5650w(0)) OR wire_w_lg_n110l1i5652w(0)) OR n110iOO);
	n110iOO <= ((((((((((((((((((wire_nl0OO1O_w_lg_o13557w(0) AND wire_nl0OO1i_w_lg_o5577w(0)) AND wire_nl0OlOO_w_lg_o5560w(0)) AND wire_nl0OlOl_w_lg_o5544w(0)) AND wire_nl0OlOi_w_lg_o5529w(0)) AND wire_nl0OllO_w_lg_o5515w(0)) AND wire_nl0Olll_w_lg_o5502w(0)) AND wire_nl0Olli_w_lg_o5490w(0)) AND wire_nl0OliO_w_lg_o5479w(0)) AND wire_nl0Olil_w_lg_o5469w(0)) AND wire_nl0Olii_w_lg_o5460w(0)) AND wire_nl0Ol0O_w_lg_o5452w(0)) AND wire_nl0Ol0l_w_lg_o5445w(0)) AND wire_nl0Ol0i_w_lg_o5439w(0)) AND wire_nl0Ol1O_w_lg_o5434w(0)) AND wire_nl0Ol1l_w_lg_o5618w(0)) AND wire_nl0Ol1i_w_lg_o5431w(0)) AND wire_nl0OiOO_w_lg_o5429w(0)) AND wire_nl0OiOl_w_lg_o13575w(0));
	n110l0i <= (((((((((((((((wire_nl0OlOl_w_lg_o5544w(0) OR wire_nl0OlOi_o) OR wire_nl0OllO_o) OR wire_nl0Olll_o) OR wire_nl0Olli_o) OR wire_nl0OliO_o) OR wire_nl0Olil_o) OR wire_nl0Olii_o) OR wire_nl0Ol0O_o) OR wire_nl0Ol0l_o) OR wire_nl0Ol0i_o) OR wire_nl0Ol1O_o) OR wire_nl0Ol1l_o) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110l0l <= ((((((((((((((wire_nl0OlOi_w_lg_o5529w(0) OR wire_nl0OllO_o) OR wire_nl0Olll_o) OR wire_nl0Olli_o) OR wire_nl0OliO_o) OR wire_nl0Olil_o) OR wire_nl0Olii_o) OR wire_nl0Ol0O_o) OR wire_nl0Ol0l_o) OR wire_nl0Ol0i_o) OR wire_nl0Ol1O_o) OR wire_nl0Ol1l_o) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110l0O <= (((((((((((((wire_nl0OllO_w_lg_o5515w(0) OR wire_nl0Olll_o) OR wire_nl0Olli_o) OR wire_nl0OliO_o) OR wire_nl0Olil_o) OR wire_nl0Olii_o) OR wire_nl0Ol0O_o) OR wire_nl0Ol0l_o) OR wire_nl0Ol0i_o) OR wire_nl0Ol1O_o) OR wire_nl0Ol1l_o) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110l1i <= ((((((((((((((((((wire_nl0OO1l_w_lg_o5595w(0) OR wire_nl0OO1i_o) OR wire_nl0OlOO_o) OR wire_nl0OlOl_o) OR wire_nl0OlOi_o) OR wire_nl0OllO_o) OR wire_nl0Olll_o) OR wire_nl0Olli_o) OR wire_nl0OliO_o) OR wire_nl0Olil_o) OR wire_nl0Olii_o) OR wire_nl0Ol0O_o) OR wire_nl0Ol0l_o) OR wire_nl0Ol0i_o) OR wire_nl0Ol1O_o) OR wire_nl0Ol1l_o) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110l1l <= (((((((((((((((((wire_nl0OO1i_w_lg_o5577w(0) OR wire_nl0OlOO_o) OR wire_nl0OlOl_o) OR wire_nl0OlOi_o) OR wire_nl0OllO_o) OR wire_nl0Olll_o) OR wire_nl0Olli_o) OR wire_nl0OliO_o) OR wire_nl0Olil_o) OR wire_nl0Olii_o) OR wire_nl0Ol0O_o) OR wire_nl0Ol0l_o) OR wire_nl0Ol0i_o) OR wire_nl0Ol1O_o) OR wire_nl0Ol1l_o) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110l1O <= ((((((((((((((((wire_nl0OlOO_w_lg_o5560w(0) OR wire_nl0OlOl_o) OR wire_nl0OlOi_o) OR wire_nl0OllO_o) OR wire_nl0Olll_o) OR wire_nl0Olli_o) OR wire_nl0OliO_o) OR wire_nl0Olil_o) OR wire_nl0Olii_o) OR wire_nl0Ol0O_o) OR wire_nl0Ol0l_o) OR wire_nl0Ol0i_o) OR wire_nl0Ol1O_o) OR wire_nl0Ol1l_o) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110lii <= ((((((((((((wire_nl0Olll_w_lg_o5502w(0) OR wire_nl0Olli_o) OR wire_nl0OliO_o) OR wire_nl0Olil_o) OR wire_nl0Olii_o) OR wire_nl0Ol0O_o) OR wire_nl0Ol0l_o) OR wire_nl0Ol0i_o) OR wire_nl0Ol1O_o) OR wire_nl0Ol1l_o) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110lil <= (((((((((((wire_nl0Olli_w_lg_o5490w(0) OR wire_nl0OliO_o) OR wire_nl0Olil_o) OR wire_nl0Olii_o) OR wire_nl0Ol0O_o) OR wire_nl0Ol0l_o) OR wire_nl0Ol0i_o) OR wire_nl0Ol1O_o) OR wire_nl0Ol1l_o) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110liO <= ((((((((((wire_nl0OliO_w_lg_o5479w(0) OR wire_nl0Olil_o) OR wire_nl0Olii_o) OR wire_nl0Ol0O_o) OR wire_nl0Ol0l_o) OR wire_nl0Ol0i_o) OR wire_nl0Ol1O_o) OR wire_nl0Ol1l_o) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110lli <= (((((((((wire_nl0Olil_w_lg_o5469w(0) OR wire_nl0Olii_o) OR wire_nl0Ol0O_o) OR wire_nl0Ol0l_o) OR wire_nl0Ol0i_o) OR wire_nl0Ol1O_o) OR wire_nl0Ol1l_o) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110lll <= ((((((((wire_nl0Olii_w_lg_o5460w(0) OR wire_nl0Ol0O_o) OR wire_nl0Ol0l_o) OR wire_nl0Ol0i_o) OR wire_nl0Ol1O_o) OR wire_nl0Ol1l_o) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110llO <= (((((((wire_nl0Ol0O_w_lg_o5452w(0) OR wire_nl0Ol0l_o) OR wire_nl0Ol0i_o) OR wire_nl0Ol1O_o) OR wire_nl0Ol1l_o) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110lOi <= ((((((wire_nl0Ol0l_w_lg_o5445w(0) OR wire_nl0Ol0i_o) OR wire_nl0Ol1O_o) OR wire_nl0Ol1l_o) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110lOl <= (((((wire_nl0Ol0i_w_lg_o5439w(0) OR wire_nl0Ol1O_o) OR wire_nl0Ol1l_o) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110lOO <= ((((wire_nl0Ol1O_w_lg_o5434w(0) OR wire_nl0Ol1l_o) OR wire_nl0Ol1i_o) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110O0i <= (n11iOli AND (wire_w_lg_w_lg_comp_pat_porn5095w5096w(0) AND wire_w_lg_w_lg_comp_pat_porn5097w5098w(0)));
	n110O0l <= ((((((((NOT (comp_pat(16) XOR nll0OOl)) AND (NOT (comp_pat(17) XOR nll0OOO))) AND (NOT (comp_pat(18) XOR nlli11i))) AND (NOT (comp_pat(19) XOR nlli11l))) AND (NOT (comp_pat(20) XOR nlli11O))) AND (NOT (comp_pat(21) XOR nlli10i))) AND (NOT (comp_pat(22) XOR nlli10l))) AND (NOT (comp_pat(23) XOR nlli10O)));
	n110O0O <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0OOl)) AND (NOT ((NOT comp_pat(17)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(18)) XOR nlli11i))) AND (NOT ((NOT comp_pat(19)) XOR nlli11l))) AND (NOT ((NOT comp_pat(20)) XOR nlli11O))) AND (NOT ((NOT comp_pat(21)) XOR nlli10i))) AND (NOT ((NOT comp_pat(22)) XOR nlli10l))) AND (NOT ((NOT comp_pat(23)) XOR nlli10O)));
	n110O1i <= ((wire_nl0Ol1i_w_lg_o5431w(0) OR wire_nl0OiOO_o) OR wire_nl0OiOl_o);
	n110O1l <= (wire_nl0OiOO_w_lg_o5429w(0) OR wire_nl0OiOl_o);
	n110O1O <= (((((((((((((((n11iO0i OR n11ilOl) OR n11iliO) OR n11il0i) OR n11iiOl) OR n11iiiO) OR n11ii0i) OR n11i0Ol) OR n11i0iO) OR n11i00i) OR n11i1Ol) OR n11i1iO) OR n11i10i) OR n110OOl) OR n110OiO) OR n110O0i);
	n110Oii <= ((((((((NOT (comp_pat(24) XOR nlli1ii)) AND (NOT (comp_pat(25) XOR nlli1il))) AND (NOT (comp_pat(26) XOR nlli1iO))) AND (NOT (comp_pat(27) XOR nlli1li))) AND (NOT (comp_pat(28) XOR nlli1ll))) AND (NOT (comp_pat(29) XOR nlli1lO))) AND (NOT (comp_pat(30) XOR nlli1Oi))) AND (NOT (comp_pat(31) XOR nlli1Ol)));
	n110Oil <= ((((((((NOT ((NOT comp_pat(24)) XOR nlli1ii)) AND (NOT ((NOT comp_pat(25)) XOR nlli1il))) AND (NOT ((NOT comp_pat(26)) XOR nlli1iO))) AND (NOT ((NOT comp_pat(27)) XOR nlli1li))) AND (NOT ((NOT comp_pat(28)) XOR nlli1ll))) AND (NOT ((NOT comp_pat(29)) XOR nlli1lO))) AND (NOT ((NOT comp_pat(30)) XOR nlli1Oi))) AND (NOT ((NOT comp_pat(31)) XOR nlli1Ol)));
	n110OiO <= (n11iOOi AND (wire_w_lg_w_lg_comp_pat_porn5089w5090w(0) AND wire_w_lg_w_lg_comp_pat_porn5091w5092w(0)));
	n110Oli <= ((((((((NOT (comp_pat(16) XOR nll0OiO)) AND (NOT (comp_pat(17) XOR nll0OOl))) AND (NOT (comp_pat(18) XOR nll0OOO))) AND (NOT (comp_pat(19) XOR nlli11i))) AND (NOT (comp_pat(20) XOR nlli11l))) AND (NOT (comp_pat(21) XOR nlli11O))) AND (NOT (comp_pat(22) XOR nlli10i))) AND (NOT (comp_pat(23) XOR nlli10l)));
	n110Oll <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0OiO)) AND (NOT ((NOT comp_pat(17)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(18)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(19)) XOR nlli11i))) AND (NOT ((NOT comp_pat(20)) XOR nlli11l))) AND (NOT ((NOT comp_pat(21)) XOR nlli11O))) AND (NOT ((NOT comp_pat(22)) XOR nlli10i))) AND (NOT ((NOT comp_pat(23)) XOR nlli10l)));
	n110OlO <= ((((((((NOT (comp_pat(24) XOR nlli10O)) AND (NOT (comp_pat(25) XOR nlli1ii))) AND (NOT (comp_pat(26) XOR nlli1il))) AND (NOT (comp_pat(27) XOR nlli1iO))) AND (NOT (comp_pat(28) XOR nlli1li))) AND (NOT (comp_pat(29) XOR nlli1ll))) AND (NOT (comp_pat(30) XOR nlli1lO))) AND (NOT (comp_pat(31) XOR nlli1Oi)));
	n110OOi <= ((((((((NOT ((NOT comp_pat(24)) XOR nlli10O)) AND (NOT ((NOT comp_pat(25)) XOR nlli1ii))) AND (NOT ((NOT comp_pat(26)) XOR nlli1il))) AND (NOT ((NOT comp_pat(27)) XOR nlli1iO))) AND (NOT ((NOT comp_pat(28)) XOR nlli1li))) AND (NOT ((NOT comp_pat(29)) XOR nlli1ll))) AND (NOT ((NOT comp_pat(30)) XOR nlli1lO))) AND (NOT ((NOT comp_pat(31)) XOR nlli1Oi)));
	n110OOl <= (n11l11i AND (wire_w_lg_w_lg_comp_pat_porn5083w5084w(0) AND wire_w_lg_w_lg_comp_pat_porn5085w5086w(0)));
	n110OOO <= ((((((((NOT (comp_pat(16) XOR nll0Oil)) AND (NOT (comp_pat(17) XOR nll0OiO))) AND (NOT (comp_pat(18) XOR nll0OOl))) AND (NOT (comp_pat(19) XOR nll0OOO))) AND (NOT (comp_pat(20) XOR nlli11i))) AND (NOT (comp_pat(21) XOR nlli11l))) AND (NOT (comp_pat(22) XOR nlli11O))) AND (NOT (comp_pat(23) XOR nlli10i)));
	n11100i <= (((((((((((((((nlli1Ol OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	n11100l <= ((((((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O);
	n11100O <= (wire_w_lg_w_pmadwidth_range175w14240w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n1110ii14241w(0)));
	n11101i <= wire_w_lg_w_pmadwidth_range175w14253w(0);
	n11101l <= (((((((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l);
	n11101O <= (wire_w_lg_w_pmadwidth_range175w14247w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n11100i14248w(0)));
	n1110ii <= ((((((((((((((nlli1Ol OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO);
	n1110il <= (((((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i);
	n1110iO <= (wire_w_lg_w_pmadwidth_range175w14233w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n1110li14234w(0)));
	n1110li <= (((((((((((((nlli1Ol OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i);
	n1110ll <= ((((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l);
	n1110lO <= (wire_w_lg_w_pmadwidth_range175w14226w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n1110Oi14227w(0)));
	n1110Oi <= ((((((((((((nlli1Ol OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l);
	n1110Ol <= (((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O);
	n1110OO <= (wire_w_lg_w_pmadwidth_range175w14219w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n111i1i14220w(0)));
	n11110i <= ((((((nlli10l OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	n11110l <= (((((nlli10i OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	n11110O <= ((((nlli11O OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	n11111i <= (((((((((nlli1il OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	n11111l <= ((((((((nlli1ii OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	n11111O <= (((((((nlli10O OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	n1111ii <= (((nlli11l OR nlli11i) OR nll0OOO) OR nll0OOl);
	n1111il <= ((nlli11i OR nll0OOO) OR nll0OOl);
	n1111iO <= (nll0OOO OR nll0OOl);
	n1111li <= wire_w_lg_w_pmadwidth_range175w14262w(0);
	n1111ll <= ((((((((((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	n1111lO <= wire_w_lg_w_pmadwidth_range175w14259w(0);
	n1111Oi <= (((((((((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO);
	n1111Ol <= wire_w_lg_w_pmadwidth_range175w14256w(0);
	n1111OO <= ((((((((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i);
	n111i0i <= ((((((((((nlli1Ol OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i);
	n111i0l <= (((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il);
	n111i0O <= (wire_w_lg_w_pmadwidth_range175w14205w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n111iii14206w(0)));
	n111i1i <= (((((((((((nlli1Ol OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O);
	n111i1l <= ((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii);
	n111i1O <= (wire_w_lg_w_pmadwidth_range175w14212w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n111i0i14213w(0)));
	n111iii <= (((((((((nlli1Ol OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l);
	n111iil <= ((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO);
	n111iiO <= (wire_w_lg_w_pmadwidth_range175w14198w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n111ili14199w(0)));
	n111ili <= ((((((((nlli1Ol OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O);
	n111ill <= (((((wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li);
	n111ilO <= (wire_w_lg_w_pmadwidth_range175w14191w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n111iOi14192w(0)));
	n111iOi <= (((((((nlli1Ol OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii);
	n111iOl <= ((((wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll);
	n111iOO <= (wire_w_lg_w_pmadwidth_range175w14184w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n111l1i14185w(0)));
	n111l0i <= (((((nlli1Ol OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO);
	n111l0l <= ((wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol) OR nlli1Oi);
	n111l0O <= (wire_w_lg_w_pmadwidth_range175w14170w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n111lii14171w(0)));
	n111l1i <= ((((((nlli1Ol OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il);
	n111l1l <= (((wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol) OR nlli1Oi) OR nlli1lO);
	n111l1O <= (wire_w_lg_w_pmadwidth_range175w14177w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n111l0i14178w(0)));
	n111lii <= ((((nlli1Ol OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li);
	n111lil <= (wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) OR nlli1Ol);
	n111liO <= (wire_w_lg_w_pmadwidth_range175w14162w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND (NOT (((nlli1Ol OR nlli1Oi) OR nlli1lO) OR nlli1ll))));
	n111lli <= (wire_w_lg_w_pmadwidth_range175w14155w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND (NOT ((nlli1Ol OR nlli1Oi) OR nlli1lO))));
	n111lll <= (wire_w_lg_w_pmadwidth_range175w14148w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND (NOT (nlli1Ol OR nlli1Oi))));
	n111llO <= (wire_w_lg_w_pmadwidth_range175w219w(0) AND pmadwidth(1));
	n111lOi <= (((((NOT (nl0101O XOR nl011Oi)) AND (NOT (nl0100i XOR nl011Ol))) AND (NOT (nl0100l XOR nl011OO))) AND (NOT (nl0100O XOR nl0101i))) AND (NOT (nl010ii XOR nl0101l)));
	n111lOl <= (comp_pat_size(0) AND autobytealign_dis);
	n111lOO <= ((NOT comp_pat_size(0)) AND autobytealign_dis);
	n111O0i <= (n110i1O OR n110i1l);
	n111O0l <= (n110iil OR n110i0O);
	n111O0O <= ((((((((NOT (comp_pat(0) XOR nl010il)) AND (NOT (comp_pat(1) XOR nl010iO))) AND (NOT (comp_pat(2) XOR nl010li))) AND (NOT (comp_pat(3) XOR nl010ll))) AND (NOT (comp_pat(4) XOR nl010lO))) AND (NOT (comp_pat(5) XOR nl010Oi))) AND (NOT (comp_pat(6) XOR nl010Ol))) AND (NOT (comp_pat(7) XOR nl010OO)));
	n111O1i <= ((((nl010ii AND nl0100O) AND nl0100l) AND nl0100i) AND nl0101O);
	n111O1l <= (wa_6g_en AND autobytealign_dis);
	n111O1O <= (wire_nll1lOi_dataout AND (wire_w_lg_autobytealign_dis5791w(0) AND n1iiilO));
	n111Oii <= (((((((NOT (comp_pat(0) XOR nl010il)) AND (NOT (comp_pat(1) XOR nl010iO))) AND (NOT (comp_pat(2) XOR nl010li))) AND (NOT (comp_pat(3) XOR nl010ll))) AND (NOT (comp_pat(4) XOR nl010lO))) AND (NOT (comp_pat(5) XOR nl010Oi))) AND (NOT (comp_pat(6) XOR nl010Ol)));
	n111Oil <= (((((((NOT ((NOT comp_pat(0)) XOR nl010il)) AND (NOT ((NOT comp_pat(1)) XOR nl010iO))) AND (NOT ((NOT comp_pat(2)) XOR nl010li))) AND (NOT ((NOT comp_pat(3)) XOR nl010ll))) AND (NOT ((NOT comp_pat(4)) XOR nl010lO))) AND (NOT ((NOT comp_pat(5)) XOR nl010Oi))) AND (NOT ((NOT comp_pat(6)) XOR nl010Ol)));
	n111OiO <= ((((((((NOT (comp_pat(8) XOR nl01i1i)) AND (NOT (comp_pat(9) XOR nl01i1l))) AND (NOT (comp_pat(10) XOR nl01i1O))) AND (NOT (comp_pat(11) XOR nl01i0i))) AND (NOT (comp_pat(12) XOR nl01i0l))) AND (NOT (comp_pat(13) XOR nl01i0O))) AND (NOT (comp_pat(14) XOR nl01iii))) AND (NOT (comp_pat(15) XOR nl01iil)));
	n111Oli <= ((((((((((NOT (comp_pat(0) XOR nl01i1O)) AND (NOT (comp_pat(1) XOR nl01i0i))) AND (NOT (comp_pat(2) XOR nl01i0l))) AND (NOT (comp_pat(3) XOR nl01i0O))) AND (NOT (comp_pat(4) XOR nl01iii))) AND (NOT (comp_pat(5) XOR nl01iil))) AND (NOT (comp_pat(6) XOR nl01iiO))) AND (NOT (comp_pat(7) XOR nl01ili))) AND (NOT (comp_pat(8) XOR nl01ill))) AND (NOT (comp_pat(9) XOR nl01ilO)));
	n111Oll <= ((((((((((NOT ((NOT comp_pat(0)) XOR nl01i1O)) AND (NOT ((NOT comp_pat(1)) XOR nl01i0i))) AND (NOT ((NOT comp_pat(2)) XOR nl01i0l))) AND (NOT ((NOT comp_pat(3)) XOR nl01i0O))) AND (NOT ((NOT comp_pat(4)) XOR nl01iii))) AND (NOT ((NOT comp_pat(5)) XOR nl01iil))) AND (NOT ((NOT comp_pat(6)) XOR nl01iiO))) AND (NOT ((NOT comp_pat(7)) XOR nl01ili))) AND (NOT ((NOT comp_pat(8)) XOR nl01ill))) AND (NOT ((NOT comp_pat(9)) XOR nl01ilO)));
	n111OlO <= ((((((((NOT (comp_pat(0) XOR nl01i1i)) AND (NOT (comp_pat(1) XOR nl01i1l))) AND (NOT (comp_pat(2) XOR nl01i1O))) AND (NOT (comp_pat(3) XOR nl01i0i))) AND (NOT (comp_pat(4) XOR nl01i0l))) AND (NOT (comp_pat(5) XOR nl01i0O))) AND (NOT (comp_pat(6) XOR nl01iii))) AND (NOT (comp_pat(7) XOR nl01iil)));
	n111OOi <= (((((((NOT (comp_pat(0) XOR nl01i1O)) AND (NOT (comp_pat(1) XOR nl01i0i))) AND (NOT (comp_pat(2) XOR nl01i0l))) AND (NOT (comp_pat(3) XOR nl01i0O))) AND (NOT (comp_pat(4) XOR nl01iii))) AND (NOT (comp_pat(5) XOR nl01iil))) AND (NOT (comp_pat(6) XOR nl01iiO)));
	n111OOl <= (((((((NOT ((NOT comp_pat(0)) XOR nl01i1O)) AND (NOT ((NOT comp_pat(1)) XOR nl01i0i))) AND (NOT ((NOT comp_pat(2)) XOR nl01i0l))) AND (NOT ((NOT comp_pat(3)) XOR nl01i0O))) AND (NOT ((NOT comp_pat(4)) XOR nl01iii))) AND (NOT ((NOT comp_pat(5)) XOR nl01iil))) AND (NOT ((NOT comp_pat(6)) XOR nl01iiO)));
	n111OOO <= ((comp_pat_porn AND n11011l) OR n11011i);
	n11i00i <= (n11l1Oi AND (wire_w_lg_w_lg_comp_pat_porn5059w5060w(0) AND wire_w_lg_w_lg_comp_pat_porn5061w5062w(0)));
	n11i00l <= ((((((((NOT (comp_pat(16) XOR nll0O0i)) AND (NOT (comp_pat(17) XOR nll0O0l))) AND (NOT (comp_pat(18) XOR nll0O0O))) AND (NOT (comp_pat(19) XOR nll0Oii))) AND (NOT (comp_pat(20) XOR nll0Oil))) AND (NOT (comp_pat(21) XOR nll0OiO))) AND (NOT (comp_pat(22) XOR nll0OOl))) AND (NOT (comp_pat(23) XOR nll0OOO)));
	n11i00O <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0O0i)) AND (NOT ((NOT comp_pat(17)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(18)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(19)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(20)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(21)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(22)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(23)) XOR nll0OOO)));
	n11i01i <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0O0l)) AND (NOT ((NOT comp_pat(17)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(18)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(19)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(20)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(21)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(22)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(23)) XOR nlli11i)));
	n11i01l <= ((((((((NOT (comp_pat(24) XOR nlli11l)) AND (NOT (comp_pat(25) XOR nlli11O))) AND (NOT (comp_pat(26) XOR nlli10i))) AND (NOT (comp_pat(27) XOR nlli10l))) AND (NOT (comp_pat(28) XOR nlli10O))) AND (NOT (comp_pat(29) XOR nlli1ii))) AND (NOT (comp_pat(30) XOR nlli1il))) AND (NOT (comp_pat(31) XOR nlli1iO)));
	n11i01O <= ((((((((NOT ((NOT comp_pat(24)) XOR nlli11l)) AND (NOT ((NOT comp_pat(25)) XOR nlli11O))) AND (NOT ((NOT comp_pat(26)) XOR nlli10i))) AND (NOT ((NOT comp_pat(27)) XOR nlli10l))) AND (NOT ((NOT comp_pat(28)) XOR nlli10O))) AND (NOT ((NOT comp_pat(29)) XOR nlli1ii))) AND (NOT ((NOT comp_pat(30)) XOR nlli1il))) AND (NOT ((NOT comp_pat(31)) XOR nlli1iO)));
	n11i0ii <= ((((((((NOT (comp_pat(24) XOR nlli11i)) AND (NOT (comp_pat(25) XOR nlli11l))) AND (NOT (comp_pat(26) XOR nlli11O))) AND (NOT (comp_pat(27) XOR nlli10i))) AND (NOT (comp_pat(28) XOR nlli10l))) AND (NOT (comp_pat(29) XOR nlli10O))) AND (NOT (comp_pat(30) XOR nlli1ii))) AND (NOT (comp_pat(31) XOR nlli1il)));
	n11i0il <= ((((((((NOT ((NOT comp_pat(24)) XOR nlli11i)) AND (NOT ((NOT comp_pat(25)) XOR nlli11l))) AND (NOT ((NOT comp_pat(26)) XOR nlli11O))) AND (NOT ((NOT comp_pat(27)) XOR nlli10i))) AND (NOT ((NOT comp_pat(28)) XOR nlli10l))) AND (NOT ((NOT comp_pat(29)) XOR nlli10O))) AND (NOT ((NOT comp_pat(30)) XOR nlli1ii))) AND (NOT ((NOT comp_pat(31)) XOR nlli1il)));
	n11i0iO <= (n11l01i AND (wire_w_lg_w_lg_comp_pat_porn5053w5054w(0) AND wire_w_lg_w_lg_comp_pat_porn5055w5056w(0)));
	n11i0li <= ((((((((NOT (comp_pat(16) XOR nll0O1O)) AND (NOT (comp_pat(17) XOR nll0O0i))) AND (NOT (comp_pat(18) XOR nll0O0l))) AND (NOT (comp_pat(19) XOR nll0O0O))) AND (NOT (comp_pat(20) XOR nll0Oii))) AND (NOT (comp_pat(21) XOR nll0Oil))) AND (NOT (comp_pat(22) XOR nll0OiO))) AND (NOT (comp_pat(23) XOR nll0OOl)));
	n11i0ll <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0O1O)) AND (NOT ((NOT comp_pat(17)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(18)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(19)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(20)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(21)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(22)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(23)) XOR nll0OOl)));
	n11i0lO <= ((((((((NOT (comp_pat(24) XOR nll0OOO)) AND (NOT (comp_pat(25) XOR nlli11i))) AND (NOT (comp_pat(26) XOR nlli11l))) AND (NOT (comp_pat(27) XOR nlli11O))) AND (NOT (comp_pat(28) XOR nlli10i))) AND (NOT (comp_pat(29) XOR nlli10l))) AND (NOT (comp_pat(30) XOR nlli10O))) AND (NOT (comp_pat(31) XOR nlli1ii)));
	n11i0Oi <= ((((((((NOT ((NOT comp_pat(24)) XOR nll0OOO)) AND (NOT ((NOT comp_pat(25)) XOR nlli11i))) AND (NOT ((NOT comp_pat(26)) XOR nlli11l))) AND (NOT ((NOT comp_pat(27)) XOR nlli11O))) AND (NOT ((NOT comp_pat(28)) XOR nlli10i))) AND (NOT ((NOT comp_pat(29)) XOR nlli10l))) AND (NOT ((NOT comp_pat(30)) XOR nlli10O))) AND (NOT ((NOT comp_pat(31)) XOR nlli1ii)));
	n11i0Ol <= (n11l00i AND (wire_w_lg_w_lg_comp_pat_porn5047w5048w(0) AND wire_w_lg_w_lg_comp_pat_porn5049w5050w(0)));
	n11i0OO <= ((((((((NOT (comp_pat(16) XOR nll0O1l)) AND (NOT (comp_pat(17) XOR nll0O1O))) AND (NOT (comp_pat(18) XOR nll0O0i))) AND (NOT (comp_pat(19) XOR nll0O0l))) AND (NOT (comp_pat(20) XOR nll0O0O))) AND (NOT (comp_pat(21) XOR nll0Oii))) AND (NOT (comp_pat(22) XOR nll0Oil))) AND (NOT (comp_pat(23) XOR nll0OiO)));
	n11i10i <= (n11l10i AND (wire_w_lg_w_lg_comp_pat_porn5077w5078w(0) AND wire_w_lg_w_lg_comp_pat_porn5079w5080w(0)));
	n11i10l <= ((((((((NOT (comp_pat(16) XOR nll0Oii)) AND (NOT (comp_pat(17) XOR nll0Oil))) AND (NOT (comp_pat(18) XOR nll0OiO))) AND (NOT (comp_pat(19) XOR nll0OOl))) AND (NOT (comp_pat(20) XOR nll0OOO))) AND (NOT (comp_pat(21) XOR nlli11i))) AND (NOT (comp_pat(22) XOR nlli11l))) AND (NOT (comp_pat(23) XOR nlli11O)));
	n11i10O <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0Oii)) AND (NOT ((NOT comp_pat(17)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(18)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(19)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(20)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(21)) XOR nlli11i))) AND (NOT ((NOT comp_pat(22)) XOR nlli11l))) AND (NOT ((NOT comp_pat(23)) XOR nlli11O)));
	n11i11i <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0Oil)) AND (NOT ((NOT comp_pat(17)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(18)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(19)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(20)) XOR nlli11i))) AND (NOT ((NOT comp_pat(21)) XOR nlli11l))) AND (NOT ((NOT comp_pat(22)) XOR nlli11O))) AND (NOT ((NOT comp_pat(23)) XOR nlli10i)));
	n11i11l <= ((((((((NOT (comp_pat(24) XOR nlli10l)) AND (NOT (comp_pat(25) XOR nlli10O))) AND (NOT (comp_pat(26) XOR nlli1ii))) AND (NOT (comp_pat(27) XOR nlli1il))) AND (NOT (comp_pat(28) XOR nlli1iO))) AND (NOT (comp_pat(29) XOR nlli1li))) AND (NOT (comp_pat(30) XOR nlli1ll))) AND (NOT (comp_pat(31) XOR nlli1lO)));
	n11i11O <= ((((((((NOT ((NOT comp_pat(24)) XOR nlli10l)) AND (NOT ((NOT comp_pat(25)) XOR nlli10O))) AND (NOT ((NOT comp_pat(26)) XOR nlli1ii))) AND (NOT ((NOT comp_pat(27)) XOR nlli1il))) AND (NOT ((NOT comp_pat(28)) XOR nlli1iO))) AND (NOT ((NOT comp_pat(29)) XOR nlli1li))) AND (NOT ((NOT comp_pat(30)) XOR nlli1ll))) AND (NOT ((NOT comp_pat(31)) XOR nlli1lO)));
	n11i1ii <= ((((((((NOT (comp_pat(24) XOR nlli10i)) AND (NOT (comp_pat(25) XOR nlli10l))) AND (NOT (comp_pat(26) XOR nlli10O))) AND (NOT (comp_pat(27) XOR nlli1ii))) AND (NOT (comp_pat(28) XOR nlli1il))) AND (NOT (comp_pat(29) XOR nlli1iO))) AND (NOT (comp_pat(30) XOR nlli1li))) AND (NOT (comp_pat(31) XOR nlli1ll)));
	n11i1il <= ((((((((NOT ((NOT comp_pat(24)) XOR nlli10i)) AND (NOT ((NOT comp_pat(25)) XOR nlli10l))) AND (NOT ((NOT comp_pat(26)) XOR nlli10O))) AND (NOT ((NOT comp_pat(27)) XOR nlli1ii))) AND (NOT ((NOT comp_pat(28)) XOR nlli1il))) AND (NOT ((NOT comp_pat(29)) XOR nlli1iO))) AND (NOT ((NOT comp_pat(30)) XOR nlli1li))) AND (NOT ((NOT comp_pat(31)) XOR nlli1ll)));
	n11i1iO <= (n11l1ii AND (wire_w_lg_w_lg_comp_pat_porn5071w5072w(0) AND wire_w_lg_w_lg_comp_pat_porn5073w5074w(0)));
	n11i1li <= ((((((((NOT (comp_pat(16) XOR nll0O0O)) AND (NOT (comp_pat(17) XOR nll0Oii))) AND (NOT (comp_pat(18) XOR nll0Oil))) AND (NOT (comp_pat(19) XOR nll0OiO))) AND (NOT (comp_pat(20) XOR nll0OOl))) AND (NOT (comp_pat(21) XOR nll0OOO))) AND (NOT (comp_pat(22) XOR nlli11i))) AND (NOT (comp_pat(23) XOR nlli11l)));
	n11i1ll <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0O0O)) AND (NOT ((NOT comp_pat(17)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(18)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(19)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(20)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(21)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(22)) XOR nlli11i))) AND (NOT ((NOT comp_pat(23)) XOR nlli11l)));
	n11i1lO <= ((((((((NOT (comp_pat(24) XOR nlli11O)) AND (NOT (comp_pat(25) XOR nlli10i))) AND (NOT (comp_pat(26) XOR nlli10l))) AND (NOT (comp_pat(27) XOR nlli10O))) AND (NOT (comp_pat(28) XOR nlli1ii))) AND (NOT (comp_pat(29) XOR nlli1il))) AND (NOT (comp_pat(30) XOR nlli1iO))) AND (NOT (comp_pat(31) XOR nlli1li)));
	n11i1Oi <= ((((((((NOT ((NOT comp_pat(24)) XOR nlli11O)) AND (NOT ((NOT comp_pat(25)) XOR nlli10i))) AND (NOT ((NOT comp_pat(26)) XOR nlli10l))) AND (NOT ((NOT comp_pat(27)) XOR nlli10O))) AND (NOT ((NOT comp_pat(28)) XOR nlli1ii))) AND (NOT ((NOT comp_pat(29)) XOR nlli1il))) AND (NOT ((NOT comp_pat(30)) XOR nlli1iO))) AND (NOT ((NOT comp_pat(31)) XOR nlli1li)));
	n11i1Ol <= (n11l1li AND (wire_w_lg_w_lg_comp_pat_porn5065w5066w(0) AND wire_w_lg_w_lg_comp_pat_porn5067w5068w(0)));
	n11i1OO <= ((((((((NOT (comp_pat(16) XOR nll0O0l)) AND (NOT (comp_pat(17) XOR nll0O0O))) AND (NOT (comp_pat(18) XOR nll0Oii))) AND (NOT (comp_pat(19) XOR nll0Oil))) AND (NOT (comp_pat(20) XOR nll0OiO))) AND (NOT (comp_pat(21) XOR nll0OOl))) AND (NOT (comp_pat(22) XOR nll0OOO))) AND (NOT (comp_pat(23) XOR nlli11i)));
	n11ii0i <= (n11l0ii AND (wire_w_lg_w_lg_comp_pat_porn5041w5042w(0) AND wire_w_lg_w_lg_comp_pat_porn5043w5044w(0)));
	n11ii0l <= ((((((((NOT (comp_pat(16) XOR nll0O1i)) AND (NOT (comp_pat(17) XOR nll0O1l))) AND (NOT (comp_pat(18) XOR nll0O1O))) AND (NOT (comp_pat(19) XOR nll0O0i))) AND (NOT (comp_pat(20) XOR nll0O0l))) AND (NOT (comp_pat(21) XOR nll0O0O))) AND (NOT (comp_pat(22) XOR nll0Oii))) AND (NOT (comp_pat(23) XOR nll0Oil)));
	n11ii0O <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0O1i)) AND (NOT ((NOT comp_pat(17)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(18)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(19)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(20)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(21)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(22)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(23)) XOR nll0Oil)));
	n11ii1i <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0O1l)) AND (NOT ((NOT comp_pat(17)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(18)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(19)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(20)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(21)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(22)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(23)) XOR nll0OiO)));
	n11ii1l <= ((((((((NOT (comp_pat(24) XOR nll0OOl)) AND (NOT (comp_pat(25) XOR nll0OOO))) AND (NOT (comp_pat(26) XOR nlli11i))) AND (NOT (comp_pat(27) XOR nlli11l))) AND (NOT (comp_pat(28) XOR nlli11O))) AND (NOT (comp_pat(29) XOR nlli10i))) AND (NOT (comp_pat(30) XOR nlli10l))) AND (NOT (comp_pat(31) XOR nlli10O)));
	n11ii1O <= ((((((((NOT ((NOT comp_pat(24)) XOR nll0OOl)) AND (NOT ((NOT comp_pat(25)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(26)) XOR nlli11i))) AND (NOT ((NOT comp_pat(27)) XOR nlli11l))) AND (NOT ((NOT comp_pat(28)) XOR nlli11O))) AND (NOT ((NOT comp_pat(29)) XOR nlli10i))) AND (NOT ((NOT comp_pat(30)) XOR nlli10l))) AND (NOT ((NOT comp_pat(31)) XOR nlli10O)));
	n11iiii <= ((((((((NOT (comp_pat(24) XOR nll0OiO)) AND (NOT (comp_pat(25) XOR nll0OOl))) AND (NOT (comp_pat(26) XOR nll0OOO))) AND (NOT (comp_pat(27) XOR nlli11i))) AND (NOT (comp_pat(28) XOR nlli11l))) AND (NOT (comp_pat(29) XOR nlli11O))) AND (NOT (comp_pat(30) XOR nlli10i))) AND (NOT (comp_pat(31) XOR nlli10l)));
	n11iiil <= ((((((((NOT ((NOT comp_pat(24)) XOR nll0OiO)) AND (NOT ((NOT comp_pat(25)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(26)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(27)) XOR nlli11i))) AND (NOT ((NOT comp_pat(28)) XOR nlli11l))) AND (NOT ((NOT comp_pat(29)) XOR nlli11O))) AND (NOT ((NOT comp_pat(30)) XOR nlli10i))) AND (NOT ((NOT comp_pat(31)) XOR nlli10l)));
	n11iiiO <= (n11l0li AND (wire_w_lg_w_lg_comp_pat_porn5035w5036w(0) AND wire_w_lg_w_lg_comp_pat_porn5037w5038w(0)));
	n11iili <= ((((((((NOT (comp_pat(16) XOR nll0lOO)) AND (NOT (comp_pat(17) XOR nll0O1i))) AND (NOT (comp_pat(18) XOR nll0O1l))) AND (NOT (comp_pat(19) XOR nll0O1O))) AND (NOT (comp_pat(20) XOR nll0O0i))) AND (NOT (comp_pat(21) XOR nll0O0l))) AND (NOT (comp_pat(22) XOR nll0O0O))) AND (NOT (comp_pat(23) XOR nll0Oii)));
	n11iill <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0lOO)) AND (NOT ((NOT comp_pat(17)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(18)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(19)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(20)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(21)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(22)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(23)) XOR nll0Oii)));
	n11iilO <= ((((((((NOT (comp_pat(24) XOR nll0Oil)) AND (NOT (comp_pat(25) XOR nll0OiO))) AND (NOT (comp_pat(26) XOR nll0OOl))) AND (NOT (comp_pat(27) XOR nll0OOO))) AND (NOT (comp_pat(28) XOR nlli11i))) AND (NOT (comp_pat(29) XOR nlli11l))) AND (NOT (comp_pat(30) XOR nlli11O))) AND (NOT (comp_pat(31) XOR nlli10i)));
	n11iiOi <= ((((((((NOT ((NOT comp_pat(24)) XOR nll0Oil)) AND (NOT ((NOT comp_pat(25)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(26)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(27)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(28)) XOR nlli11i))) AND (NOT ((NOT comp_pat(29)) XOR nlli11l))) AND (NOT ((NOT comp_pat(30)) XOR nlli11O))) AND (NOT ((NOT comp_pat(31)) XOR nlli10i)));
	n11iiOl <= (n11l0Oi AND (wire_w_lg_w_lg_comp_pat_porn5029w5030w(0) AND wire_w_lg_w_lg_comp_pat_porn5031w5032w(0)));
	n11iiOO <= ((((((((NOT (comp_pat(16) XOR nll0lOl)) AND (NOT (comp_pat(17) XOR nll0lOO))) AND (NOT (comp_pat(18) XOR nll0O1i))) AND (NOT (comp_pat(19) XOR nll0O1l))) AND (NOT (comp_pat(20) XOR nll0O1O))) AND (NOT (comp_pat(21) XOR nll0O0i))) AND (NOT (comp_pat(22) XOR nll0O0l))) AND (NOT (comp_pat(23) XOR nll0O0O)));
	n11il0i <= (n11li1i AND (wire_w_lg_w_lg_comp_pat_porn5023w5024w(0) AND wire_w_lg_w_lg_comp_pat_porn5025w5026w(0)));
	n11il0l <= ((((((((NOT (comp_pat(16) XOR nll0lOi)) AND (NOT (comp_pat(17) XOR nll0lOl))) AND (NOT (comp_pat(18) XOR nll0lOO))) AND (NOT (comp_pat(19) XOR nll0O1i))) AND (NOT (comp_pat(20) XOR nll0O1l))) AND (NOT (comp_pat(21) XOR nll0O1O))) AND (NOT (comp_pat(22) XOR nll0O0i))) AND (NOT (comp_pat(23) XOR nll0O0l)));
	n11il0O <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0lOi)) AND (NOT ((NOT comp_pat(17)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(18)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(19)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(20)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(21)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(22)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(23)) XOR nll0O0l)));
	n11il1i <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0lOl)) AND (NOT ((NOT comp_pat(17)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(18)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(19)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(20)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(21)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(22)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(23)) XOR nll0O0O)));
	n11il1l <= ((((((((NOT (comp_pat(24) XOR nll0Oii)) AND (NOT (comp_pat(25) XOR nll0Oil))) AND (NOT (comp_pat(26) XOR nll0OiO))) AND (NOT (comp_pat(27) XOR nll0OOl))) AND (NOT (comp_pat(28) XOR nll0OOO))) AND (NOT (comp_pat(29) XOR nlli11i))) AND (NOT (comp_pat(30) XOR nlli11l))) AND (NOT (comp_pat(31) XOR nlli11O)));
	n11il1O <= ((((((((NOT ((NOT comp_pat(24)) XOR nll0Oii)) AND (NOT ((NOT comp_pat(25)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(26)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(27)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(28)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(29)) XOR nlli11i))) AND (NOT ((NOT comp_pat(30)) XOR nlli11l))) AND (NOT ((NOT comp_pat(31)) XOR nlli11O)));
	n11ilii <= ((((((((NOT (comp_pat(24) XOR nll0O0O)) AND (NOT (comp_pat(25) XOR nll0Oii))) AND (NOT (comp_pat(26) XOR nll0Oil))) AND (NOT (comp_pat(27) XOR nll0OiO))) AND (NOT (comp_pat(28) XOR nll0OOl))) AND (NOT (comp_pat(29) XOR nll0OOO))) AND (NOT (comp_pat(30) XOR nlli11i))) AND (NOT (comp_pat(31) XOR nlli11l)));
	n11ilil <= ((((((((NOT ((NOT comp_pat(24)) XOR nll0O0O)) AND (NOT ((NOT comp_pat(25)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(26)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(27)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(28)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(29)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(30)) XOR nlli11i))) AND (NOT ((NOT comp_pat(31)) XOR nlli11l)));
	n11iliO <= (n11li0i AND (wire_w_lg_w_lg_comp_pat_porn5017w5018w(0) AND wire_w_lg_w_lg_comp_pat_porn5019w5020w(0)));
	n11illi <= ((((((((NOT (comp_pat(16) XOR nll0llO)) AND (NOT (comp_pat(17) XOR nll0lOi))) AND (NOT (comp_pat(18) XOR nll0lOl))) AND (NOT (comp_pat(19) XOR nll0lOO))) AND (NOT (comp_pat(20) XOR nll0O1i))) AND (NOT (comp_pat(21) XOR nll0O1l))) AND (NOT (comp_pat(22) XOR nll0O1O))) AND (NOT (comp_pat(23) XOR nll0O0i)));
	n11illl <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0llO)) AND (NOT ((NOT comp_pat(17)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(18)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(19)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(20)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(21)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(22)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(23)) XOR nll0O0i)));
	n11illO <= ((((((((NOT (comp_pat(24) XOR nll0O0l)) AND (NOT (comp_pat(25) XOR nll0O0O))) AND (NOT (comp_pat(26) XOR nll0Oii))) AND (NOT (comp_pat(27) XOR nll0Oil))) AND (NOT (comp_pat(28) XOR nll0OiO))) AND (NOT (comp_pat(29) XOR nll0OOl))) AND (NOT (comp_pat(30) XOR nll0OOO))) AND (NOT (comp_pat(31) XOR nlli11i)));
	n11ilOi <= ((((((((NOT ((NOT comp_pat(24)) XOR nll0O0l)) AND (NOT ((NOT comp_pat(25)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(26)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(27)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(28)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(29)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(30)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(31)) XOR nlli11i)));
	n11ilOl <= (n11liii AND (wire_w_lg_w_lg_comp_pat_porn5011w5012w(0) AND wire_w_lg_w_lg_comp_pat_porn5013w5014w(0)));
	n11ilOO <= ((((((((NOT (comp_pat(16) XOR nll0lll)) AND (NOT (comp_pat(17) XOR nll0llO))) AND (NOT (comp_pat(18) XOR nll0lOi))) AND (NOT (comp_pat(19) XOR nll0lOl))) AND (NOT (comp_pat(20) XOR nll0lOO))) AND (NOT (comp_pat(21) XOR nll0O1i))) AND (NOT (comp_pat(22) XOR nll0O1l))) AND (NOT (comp_pat(23) XOR nll0O1O)));
	n11iO0i <= (n11lili AND (wire_w_lg_w_lg_comp_pat_porn5005w5006w(0) AND wire_w_lg_w_lg_comp_pat_porn5007w5008w(0)));
	n11iO0l <= ((((((((NOT (comp_pat(16) XOR nll0lli)) AND (NOT (comp_pat(17) XOR nll0lll))) AND (NOT (comp_pat(18) XOR nll0llO))) AND (NOT (comp_pat(19) XOR nll0lOi))) AND (NOT (comp_pat(20) XOR nll0lOl))) AND (NOT (comp_pat(21) XOR nll0lOO))) AND (NOT (comp_pat(22) XOR nll0O1i))) AND (NOT (comp_pat(23) XOR nll0O1l)));
	n11iO0O <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0lli)) AND (NOT ((NOT comp_pat(17)) XOR nll0lll))) AND (NOT ((NOT comp_pat(18)) XOR nll0llO))) AND (NOT ((NOT comp_pat(19)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(20)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(21)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(22)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(23)) XOR nll0O1l)));
	n11iO1i <= ((((((((NOT ((NOT comp_pat(16)) XOR nll0lll)) AND (NOT ((NOT comp_pat(17)) XOR nll0llO))) AND (NOT ((NOT comp_pat(18)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(19)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(20)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(21)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(22)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(23)) XOR nll0O1O)));
	n11iO1l <= ((((((((NOT (comp_pat(24) XOR nll0O0i)) AND (NOT (comp_pat(25) XOR nll0O0l))) AND (NOT (comp_pat(26) XOR nll0O0O))) AND (NOT (comp_pat(27) XOR nll0Oii))) AND (NOT (comp_pat(28) XOR nll0Oil))) AND (NOT (comp_pat(29) XOR nll0OiO))) AND (NOT (comp_pat(30) XOR nll0OOl))) AND (NOT (comp_pat(31) XOR nll0OOO)));
	n11iO1O <= ((((((((NOT ((NOT comp_pat(24)) XOR nll0O0i)) AND (NOT ((NOT comp_pat(25)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(26)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(27)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(28)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(29)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(30)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(31)) XOR nll0OOO)));
	n11iOii <= ((((((((NOT (comp_pat(24) XOR nll0O1O)) AND (NOT (comp_pat(25) XOR nll0O0i))) AND (NOT (comp_pat(26) XOR nll0O0l))) AND (NOT (comp_pat(27) XOR nll0O0O))) AND (NOT (comp_pat(28) XOR nll0Oii))) AND (NOT (comp_pat(29) XOR nll0Oil))) AND (NOT (comp_pat(30) XOR nll0OiO))) AND (NOT (comp_pat(31) XOR nll0OOl)));
	n11iOil <= ((((((((NOT ((NOT comp_pat(24)) XOR nll0O1O)) AND (NOT ((NOT comp_pat(25)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(26)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(27)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(28)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(29)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(30)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(31)) XOR nll0OOl)));
	n11iOiO <= (((((((((((((((n11lili OR n11liii) OR n11li0i) OR n11li1i) OR n11l0Oi) OR n11l0li) OR n11l0ii) OR n11l00i) OR n11l01i) OR n11l1Oi) OR n11l1li) OR n11l1ii) OR n11l10i) OR n11l11i) OR n11iOOi) OR n11iOli);
	n11iOli <= (n11liOl AND ((comp_pat_porn AND n11iOlO) OR n11iOll));
	n11iOll <= ((((((((NOT (comp_pat(8) XOR nll0O1l)) AND (NOT (comp_pat(9) XOR nll0O1O))) AND (NOT (comp_pat(10) XOR nll0O0i))) AND (NOT (comp_pat(11) XOR nll0O0l))) AND (NOT (comp_pat(12) XOR nll0O0O))) AND (NOT (comp_pat(13) XOR nll0Oii))) AND (NOT (comp_pat(14) XOR nll0Oil))) AND (NOT (comp_pat(15) XOR nll0OiO)));
	n11iOlO <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0O1l)) AND (NOT ((NOT comp_pat(9)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(10)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(11)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(12)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(13)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(14)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(15)) XOR nll0OiO)));
	n11iOOi <= (n11ll1l AND ((comp_pat_porn AND n11iOOO) OR n11iOOl));
	n11iOOl <= ((((((((NOT (comp_pat(8) XOR nll0O1i)) AND (NOT (comp_pat(9) XOR nll0O1l))) AND (NOT (comp_pat(10) XOR nll0O1O))) AND (NOT (comp_pat(11) XOR nll0O0i))) AND (NOT (comp_pat(12) XOR nll0O0l))) AND (NOT (comp_pat(13) XOR nll0O0O))) AND (NOT (comp_pat(14) XOR nll0Oii))) AND (NOT (comp_pat(15) XOR nll0Oil)));
	n11iOOO <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0O1i)) AND (NOT ((NOT comp_pat(9)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(10)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(11)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(12)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(13)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(14)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(15)) XOR nll0Oil)));
	n11l00i <= (n11lOil AND ((comp_pat_porn AND n11l00O) OR n11l00l));
	n11l00l <= ((((((((NOT (comp_pat(8) XOR nll0liO)) AND (NOT (comp_pat(9) XOR nll0lli))) AND (NOT (comp_pat(10) XOR nll0lll))) AND (NOT (comp_pat(11) XOR nll0llO))) AND (NOT (comp_pat(12) XOR nll0lOi))) AND (NOT (comp_pat(13) XOR nll0lOl))) AND (NOT (comp_pat(14) XOR nll0lOO))) AND (NOT (comp_pat(15) XOR nll0O1i)));
	n11l00O <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0liO)) AND (NOT ((NOT comp_pat(9)) XOR nll0lli))) AND (NOT ((NOT comp_pat(10)) XOR nll0lll))) AND (NOT ((NOT comp_pat(11)) XOR nll0llO))) AND (NOT ((NOT comp_pat(12)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(13)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(14)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(15)) XOR nll0O1i)));
	n11l01i <= (n11lO0l AND ((comp_pat_porn AND n11l01O) OR n11l01l));
	n11l01l <= ((((((((NOT (comp_pat(8) XOR nll0lli)) AND (NOT (comp_pat(9) XOR nll0lll))) AND (NOT (comp_pat(10) XOR nll0llO))) AND (NOT (comp_pat(11) XOR nll0lOi))) AND (NOT (comp_pat(12) XOR nll0lOl))) AND (NOT (comp_pat(13) XOR nll0lOO))) AND (NOT (comp_pat(14) XOR nll0O1i))) AND (NOT (comp_pat(15) XOR nll0O1l)));
	n11l01O <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0lli)) AND (NOT ((NOT comp_pat(9)) XOR nll0lll))) AND (NOT ((NOT comp_pat(10)) XOR nll0llO))) AND (NOT ((NOT comp_pat(11)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(12)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(13)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(14)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(15)) XOR nll0O1l)));
	n11l0ii <= (n11lOll AND ((comp_pat_porn AND n11l0iO) OR n11l0il));
	n11l0il <= ((((((((NOT (comp_pat(8) XOR nll0l0i)) AND (NOT (comp_pat(9) XOR nll0liO))) AND (NOT (comp_pat(10) XOR nll0lli))) AND (NOT (comp_pat(11) XOR nll0lll))) AND (NOT (comp_pat(12) XOR nll0llO))) AND (NOT (comp_pat(13) XOR nll0lOi))) AND (NOT (comp_pat(14) XOR nll0lOl))) AND (NOT (comp_pat(15) XOR nll0lOO)));
	n11l0iO <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0l0i)) AND (NOT ((NOT comp_pat(9)) XOR nll0liO))) AND (NOT ((NOT comp_pat(10)) XOR nll0lli))) AND (NOT ((NOT comp_pat(11)) XOR nll0lll))) AND (NOT ((NOT comp_pat(12)) XOR nll0llO))) AND (NOT ((NOT comp_pat(13)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(14)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(15)) XOR nll0lOO)));
	n11l0li <= (n11lOOl AND ((comp_pat_porn AND n11l0lO) OR n11l0ll));
	n11l0ll <= ((((((((NOT (comp_pat(8) XOR nll0l1O)) AND (NOT (comp_pat(9) XOR nll0l0i))) AND (NOT (comp_pat(10) XOR nll0liO))) AND (NOT (comp_pat(11) XOR nll0lli))) AND (NOT (comp_pat(12) XOR nll0lll))) AND (NOT (comp_pat(13) XOR nll0llO))) AND (NOT (comp_pat(14) XOR nll0lOi))) AND (NOT (comp_pat(15) XOR nll0lOl)));
	n11l0lO <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0l1O)) AND (NOT ((NOT comp_pat(9)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(10)) XOR nll0liO))) AND (NOT ((NOT comp_pat(11)) XOR nll0lli))) AND (NOT ((NOT comp_pat(12)) XOR nll0lll))) AND (NOT ((NOT comp_pat(13)) XOR nll0llO))) AND (NOT ((NOT comp_pat(14)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(15)) XOR nll0lOl)));
	n11l0Oi <= (n11O11l AND ((comp_pat_porn AND n11l0OO) OR n11l0Ol));
	n11l0Ol <= ((((((((NOT (comp_pat(8) XOR nll0l1l)) AND (NOT (comp_pat(9) XOR nll0l1O))) AND (NOT (comp_pat(10) XOR nll0l0i))) AND (NOT (comp_pat(11) XOR nll0liO))) AND (NOT (comp_pat(12) XOR nll0lli))) AND (NOT (comp_pat(13) XOR nll0lll))) AND (NOT (comp_pat(14) XOR nll0llO))) AND (NOT (comp_pat(15) XOR nll0lOi)));
	n11l0OO <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0l1l)) AND (NOT ((NOT comp_pat(9)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(10)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(11)) XOR nll0liO))) AND (NOT ((NOT comp_pat(12)) XOR nll0lli))) AND (NOT ((NOT comp_pat(13)) XOR nll0lll))) AND (NOT ((NOT comp_pat(14)) XOR nll0llO))) AND (NOT ((NOT comp_pat(15)) XOR nll0lOi)));
	n11l10i <= (n11llil AND ((comp_pat_porn AND n11l10O) OR n11l10l));
	n11l10l <= ((((((((NOT (comp_pat(8) XOR nll0lOl)) AND (NOT (comp_pat(9) XOR nll0lOO))) AND (NOT (comp_pat(10) XOR nll0O1i))) AND (NOT (comp_pat(11) XOR nll0O1l))) AND (NOT (comp_pat(12) XOR nll0O1O))) AND (NOT (comp_pat(13) XOR nll0O0i))) AND (NOT (comp_pat(14) XOR nll0O0l))) AND (NOT (comp_pat(15) XOR nll0O0O)));
	n11l10O <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0lOl)) AND (NOT ((NOT comp_pat(9)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(10)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(11)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(12)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(13)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(14)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(15)) XOR nll0O0O)));
	n11l11i <= (n11ll0l AND ((comp_pat_porn AND n11l11O) OR n11l11l));
	n11l11l <= ((((((((NOT (comp_pat(8) XOR nll0lOO)) AND (NOT (comp_pat(9) XOR nll0O1i))) AND (NOT (comp_pat(10) XOR nll0O1l))) AND (NOT (comp_pat(11) XOR nll0O1O))) AND (NOT (comp_pat(12) XOR nll0O0i))) AND (NOT (comp_pat(13) XOR nll0O0l))) AND (NOT (comp_pat(14) XOR nll0O0O))) AND (NOT (comp_pat(15) XOR nll0Oii)));
	n11l11O <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0lOO)) AND (NOT ((NOT comp_pat(9)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(10)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(11)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(12)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(13)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(14)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(15)) XOR nll0Oii)));
	n11l1ii <= (n11llll AND ((comp_pat_porn AND n11l1iO) OR n11l1il));
	n11l1il <= ((((((((NOT (comp_pat(8) XOR nll0lOi)) AND (NOT (comp_pat(9) XOR nll0lOl))) AND (NOT (comp_pat(10) XOR nll0lOO))) AND (NOT (comp_pat(11) XOR nll0O1i))) AND (NOT (comp_pat(12) XOR nll0O1l))) AND (NOT (comp_pat(13) XOR nll0O1O))) AND (NOT (comp_pat(14) XOR nll0O0i))) AND (NOT (comp_pat(15) XOR nll0O0l)));
	n11l1iO <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0lOi)) AND (NOT ((NOT comp_pat(9)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(10)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(11)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(12)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(13)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(14)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(15)) XOR nll0O0l)));
	n11l1li <= (n11llOl AND ((comp_pat_porn AND n11l1lO) OR n11l1ll));
	n11l1ll <= ((((((((NOT (comp_pat(8) XOR nll0llO)) AND (NOT (comp_pat(9) XOR nll0lOi))) AND (NOT (comp_pat(10) XOR nll0lOl))) AND (NOT (comp_pat(11) XOR nll0lOO))) AND (NOT (comp_pat(12) XOR nll0O1i))) AND (NOT (comp_pat(13) XOR nll0O1l))) AND (NOT (comp_pat(14) XOR nll0O1O))) AND (NOT (comp_pat(15) XOR nll0O0i)));
	n11l1lO <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0llO)) AND (NOT ((NOT comp_pat(9)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(10)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(11)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(12)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(13)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(14)) XOR nll0O1O))) AND (NOT ((NOT comp_pat(15)) XOR nll0O0i)));
	n11l1Oi <= (n11lO1l AND ((comp_pat_porn AND n11l1OO) OR n11l1Ol));
	n11l1Ol <= ((((((((NOT (comp_pat(8) XOR nll0lll)) AND (NOT (comp_pat(9) XOR nll0llO))) AND (NOT (comp_pat(10) XOR nll0lOi))) AND (NOT (comp_pat(11) XOR nll0lOl))) AND (NOT (comp_pat(12) XOR nll0lOO))) AND (NOT (comp_pat(13) XOR nll0O1i))) AND (NOT (comp_pat(14) XOR nll0O1l))) AND (NOT (comp_pat(15) XOR nll0O1O)));
	n11l1OO <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0lll)) AND (NOT ((NOT comp_pat(9)) XOR nll0llO))) AND (NOT ((NOT comp_pat(10)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(11)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(12)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(13)) XOR nll0O1i))) AND (NOT ((NOT comp_pat(14)) XOR nll0O1l))) AND (NOT ((NOT comp_pat(15)) XOR nll0O1O)));
	n11li0i <= (n11O1il AND ((comp_pat_porn AND n11li0O) OR n11li0l));
	n11li0l <= ((((((((NOT (comp_pat(8) XOR nll0iOO)) AND (NOT (comp_pat(9) XOR nll0l1i))) AND (NOT (comp_pat(10) XOR nll0l1l))) AND (NOT (comp_pat(11) XOR nll0l1O))) AND (NOT (comp_pat(12) XOR nll0l0i))) AND (NOT (comp_pat(13) XOR nll0liO))) AND (NOT (comp_pat(14) XOR nll0lli))) AND (NOT (comp_pat(15) XOR nll0lll)));
	n11li0O <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0iOO)) AND (NOT ((NOT comp_pat(9)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(10)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(11)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(12)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(13)) XOR nll0liO))) AND (NOT ((NOT comp_pat(14)) XOR nll0lli))) AND (NOT ((NOT comp_pat(15)) XOR nll0lll)));
	n11li1i <= (n11O10l AND ((comp_pat_porn AND n11li1O) OR n11li1l));
	n11li1l <= ((((((((NOT (comp_pat(8) XOR nll0l1i)) AND (NOT (comp_pat(9) XOR nll0l1l))) AND (NOT (comp_pat(10) XOR nll0l1O))) AND (NOT (comp_pat(11) XOR nll0l0i))) AND (NOT (comp_pat(12) XOR nll0liO))) AND (NOT (comp_pat(13) XOR nll0lli))) AND (NOT (comp_pat(14) XOR nll0lll))) AND (NOT (comp_pat(15) XOR nll0llO)));
	n11li1O <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0l1i)) AND (NOT ((NOT comp_pat(9)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(10)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(11)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(12)) XOR nll0liO))) AND (NOT ((NOT comp_pat(13)) XOR nll0lli))) AND (NOT ((NOT comp_pat(14)) XOR nll0lll))) AND (NOT ((NOT comp_pat(15)) XOR nll0llO)));
	n11liii <= (n11O1ll AND ((comp_pat_porn AND n11liiO) OR n11liil));
	n11liil <= ((((((((NOT (comp_pat(8) XOR nll0iOl)) AND (NOT (comp_pat(9) XOR nll0iOO))) AND (NOT (comp_pat(10) XOR nll0l1i))) AND (NOT (comp_pat(11) XOR nll0l1l))) AND (NOT (comp_pat(12) XOR nll0l1O))) AND (NOT (comp_pat(13) XOR nll0l0i))) AND (NOT (comp_pat(14) XOR nll0liO))) AND (NOT (comp_pat(15) XOR nll0lli)));
	n11liiO <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0iOl)) AND (NOT ((NOT comp_pat(9)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(10)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(11)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(12)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(13)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(14)) XOR nll0liO))) AND (NOT ((NOT comp_pat(15)) XOR nll0lli)));
	n11lili <= (n11O1Ol AND ((comp_pat_porn AND n11lilO) OR n11lill));
	n11lill <= ((((((((NOT (comp_pat(8) XOR nll0iOi)) AND (NOT (comp_pat(9) XOR nll0iOl))) AND (NOT (comp_pat(10) XOR nll0iOO))) AND (NOT (comp_pat(11) XOR nll0l1i))) AND (NOT (comp_pat(12) XOR nll0l1l))) AND (NOT (comp_pat(13) XOR nll0l1O))) AND (NOT (comp_pat(14) XOR nll0l0i))) AND (NOT (comp_pat(15) XOR nll0liO)));
	n11lilO <= ((((((((NOT ((NOT comp_pat(8)) XOR nll0iOi)) AND (NOT ((NOT comp_pat(9)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(10)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(11)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(12)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(13)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(14)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(15)) XOR nll0liO)));
	n11liOi <= (((((((((((((((n11O1Ol OR n11O1ll) OR n11O1il) OR n11O10l) OR n11O11l) OR n11lOOl) OR n11lOll) OR n11lOil) OR n11lO0l) OR n11lO1l) OR n11llOl) OR n11llll) OR n11llil) OR n11ll0l) OR n11ll1l) OR n11liOl);
	n11liOl <= ((comp_pat_porn AND n11ll1i) OR n11liOO);
	n11liOO <= ((((((((NOT (comp_pat(0) XOR nll0liO)) AND (NOT (comp_pat(1) XOR nll0lli))) AND (NOT (comp_pat(2) XOR nll0lll))) AND (NOT (comp_pat(3) XOR nll0llO))) AND (NOT (comp_pat(4) XOR nll0lOi))) AND (NOT (comp_pat(5) XOR nll0lOl))) AND (NOT (comp_pat(6) XOR nll0lOO))) AND (NOT (comp_pat(7) XOR nll0O1i)));
	n11ll0i <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0l0i)) AND (NOT ((NOT comp_pat(1)) XOR nll0liO))) AND (NOT ((NOT comp_pat(2)) XOR nll0lli))) AND (NOT ((NOT comp_pat(3)) XOR nll0lll))) AND (NOT ((NOT comp_pat(4)) XOR nll0llO))) AND (NOT ((NOT comp_pat(5)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(6)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(7)) XOR nll0lOO)));
	n11ll0l <= ((comp_pat_porn AND n11llii) OR n11ll0O);
	n11ll0O <= ((((((((NOT (comp_pat(0) XOR nll0l1O)) AND (NOT (comp_pat(1) XOR nll0l0i))) AND (NOT (comp_pat(2) XOR nll0liO))) AND (NOT (comp_pat(3) XOR nll0lli))) AND (NOT (comp_pat(4) XOR nll0lll))) AND (NOT (comp_pat(5) XOR nll0llO))) AND (NOT (comp_pat(6) XOR nll0lOi))) AND (NOT (comp_pat(7) XOR nll0lOl)));
	n11ll1i <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0liO)) AND (NOT ((NOT comp_pat(1)) XOR nll0lli))) AND (NOT ((NOT comp_pat(2)) XOR nll0lll))) AND (NOT ((NOT comp_pat(3)) XOR nll0llO))) AND (NOT ((NOT comp_pat(4)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(5)) XOR nll0lOl))) AND (NOT ((NOT comp_pat(6)) XOR nll0lOO))) AND (NOT ((NOT comp_pat(7)) XOR nll0O1i)));
	n11ll1l <= ((comp_pat_porn AND n11ll0i) OR n11ll1O);
	n11ll1O <= ((((((((NOT (comp_pat(0) XOR nll0l0i)) AND (NOT (comp_pat(1) XOR nll0liO))) AND (NOT (comp_pat(2) XOR nll0lli))) AND (NOT (comp_pat(3) XOR nll0lll))) AND (NOT (comp_pat(4) XOR nll0llO))) AND (NOT (comp_pat(5) XOR nll0lOi))) AND (NOT (comp_pat(6) XOR nll0lOl))) AND (NOT (comp_pat(7) XOR nll0lOO)));
	n11llii <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0l1O)) AND (NOT ((NOT comp_pat(1)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(2)) XOR nll0liO))) AND (NOT ((NOT comp_pat(3)) XOR nll0lli))) AND (NOT ((NOT comp_pat(4)) XOR nll0lll))) AND (NOT ((NOT comp_pat(5)) XOR nll0llO))) AND (NOT ((NOT comp_pat(6)) XOR nll0lOi))) AND (NOT ((NOT comp_pat(7)) XOR nll0lOl)));
	n11llil <= ((comp_pat_porn AND n11llli) OR n11lliO);
	n11lliO <= ((((((((NOT (comp_pat(0) XOR nll0l1l)) AND (NOT (comp_pat(1) XOR nll0l1O))) AND (NOT (comp_pat(2) XOR nll0l0i))) AND (NOT (comp_pat(3) XOR nll0liO))) AND (NOT (comp_pat(4) XOR nll0lli))) AND (NOT (comp_pat(5) XOR nll0lll))) AND (NOT (comp_pat(6) XOR nll0llO))) AND (NOT (comp_pat(7) XOR nll0lOi)));
	n11llli <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0l1l)) AND (NOT ((NOT comp_pat(1)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(2)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(3)) XOR nll0liO))) AND (NOT ((NOT comp_pat(4)) XOR nll0lli))) AND (NOT ((NOT comp_pat(5)) XOR nll0lll))) AND (NOT ((NOT comp_pat(6)) XOR nll0llO))) AND (NOT ((NOT comp_pat(7)) XOR nll0lOi)));
	n11llll <= ((comp_pat_porn AND n11llOi) OR n11lllO);
	n11lllO <= ((((((((NOT (comp_pat(0) XOR nll0l1i)) AND (NOT (comp_pat(1) XOR nll0l1l))) AND (NOT (comp_pat(2) XOR nll0l1O))) AND (NOT (comp_pat(3) XOR nll0l0i))) AND (NOT (comp_pat(4) XOR nll0liO))) AND (NOT (comp_pat(5) XOR nll0lli))) AND (NOT (comp_pat(6) XOR nll0lll))) AND (NOT (comp_pat(7) XOR nll0llO)));
	n11llOi <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0l1i)) AND (NOT ((NOT comp_pat(1)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(2)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(3)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(4)) XOR nll0liO))) AND (NOT ((NOT comp_pat(5)) XOR nll0lli))) AND (NOT ((NOT comp_pat(6)) XOR nll0lll))) AND (NOT ((NOT comp_pat(7)) XOR nll0llO)));
	n11llOl <= ((comp_pat_porn AND n11lO1i) OR n11llOO);
	n11llOO <= ((((((((NOT (comp_pat(0) XOR nll0iOO)) AND (NOT (comp_pat(1) XOR nll0l1i))) AND (NOT (comp_pat(2) XOR nll0l1l))) AND (NOT (comp_pat(3) XOR nll0l1O))) AND (NOT (comp_pat(4) XOR nll0l0i))) AND (NOT (comp_pat(5) XOR nll0liO))) AND (NOT (comp_pat(6) XOR nll0lli))) AND (NOT (comp_pat(7) XOR nll0lll)));
	n11lO0i <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0iOl)) AND (NOT ((NOT comp_pat(1)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(2)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(3)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(4)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(5)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(6)) XOR nll0liO))) AND (NOT ((NOT comp_pat(7)) XOR nll0lli)));
	n11lO0l <= ((comp_pat_porn AND n11lOii) OR n11lO0O);
	n11lO0O <= ((((((((NOT (comp_pat(0) XOR nll0iOi)) AND (NOT (comp_pat(1) XOR nll0iOl))) AND (NOT (comp_pat(2) XOR nll0iOO))) AND (NOT (comp_pat(3) XOR nll0l1i))) AND (NOT (comp_pat(4) XOR nll0l1l))) AND (NOT (comp_pat(5) XOR nll0l1O))) AND (NOT (comp_pat(6) XOR nll0l0i))) AND (NOT (comp_pat(7) XOR nll0liO)));
	n11lO1i <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0iOO)) AND (NOT ((NOT comp_pat(1)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(2)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(3)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(4)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(5)) XOR nll0liO))) AND (NOT ((NOT comp_pat(6)) XOR nll0lli))) AND (NOT ((NOT comp_pat(7)) XOR nll0lll)));
	n11lO1l <= ((comp_pat_porn AND n11lO0i) OR n11lO1O);
	n11lO1O <= ((((((((NOT (comp_pat(0) XOR nll0iOl)) AND (NOT (comp_pat(1) XOR nll0iOO))) AND (NOT (comp_pat(2) XOR nll0l1i))) AND (NOT (comp_pat(3) XOR nll0l1l))) AND (NOT (comp_pat(4) XOR nll0l1O))) AND (NOT (comp_pat(5) XOR nll0l0i))) AND (NOT (comp_pat(6) XOR nll0liO))) AND (NOT (comp_pat(7) XOR nll0lli)));
	n11lOii <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0iOi)) AND (NOT ((NOT comp_pat(1)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(2)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(3)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(4)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(5)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(6)) XOR nll0l0i))) AND (NOT ((NOT comp_pat(7)) XOR nll0liO)));
	n11lOil <= ((comp_pat_porn AND n11lOli) OR n11lOiO);
	n11lOiO <= ((((((((NOT (comp_pat(0) XOR nll0ilO)) AND (NOT (comp_pat(1) XOR nll0iOi))) AND (NOT (comp_pat(2) XOR nll0iOl))) AND (NOT (comp_pat(3) XOR nll0iOO))) AND (NOT (comp_pat(4) XOR nll0l1i))) AND (NOT (comp_pat(5) XOR nll0l1l))) AND (NOT (comp_pat(6) XOR nll0l1O))) AND (NOT (comp_pat(7) XOR nll0l0i)));
	n11lOli <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0ilO)) AND (NOT ((NOT comp_pat(1)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(2)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(3)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(4)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(5)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(6)) XOR nll0l1O))) AND (NOT ((NOT comp_pat(7)) XOR nll0l0i)));
	n11lOll <= ((comp_pat_porn AND n11lOOi) OR n11lOlO);
	n11lOlO <= ((((((((NOT (comp_pat(0) XOR nll0ill)) AND (NOT (comp_pat(1) XOR nll0ilO))) AND (NOT (comp_pat(2) XOR nll0iOi))) AND (NOT (comp_pat(3) XOR nll0iOl))) AND (NOT (comp_pat(4) XOR nll0iOO))) AND (NOT (comp_pat(5) XOR nll0l1i))) AND (NOT (comp_pat(6) XOR nll0l1l))) AND (NOT (comp_pat(7) XOR nll0l1O)));
	n11lOOi <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0ill)) AND (NOT ((NOT comp_pat(1)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(2)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(3)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(4)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(5)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(6)) XOR nll0l1l))) AND (NOT ((NOT comp_pat(7)) XOR nll0l1O)));
	n11lOOl <= ((comp_pat_porn AND n11O11i) OR n11lOOO);
	n11lOOO <= ((((((((NOT (comp_pat(0) XOR nll0ili)) AND (NOT (comp_pat(1) XOR nll0ill))) AND (NOT (comp_pat(2) XOR nll0ilO))) AND (NOT (comp_pat(3) XOR nll0iOi))) AND (NOT (comp_pat(4) XOR nll0iOl))) AND (NOT (comp_pat(5) XOR nll0iOO))) AND (NOT (comp_pat(6) XOR nll0l1i))) AND (NOT (comp_pat(7) XOR nll0l1l)));
	n11O00i <= ((((((((((NOT (comp_pat(20) XOR nll0OOl)) AND (NOT (comp_pat(21) XOR nll0OOO))) AND (NOT (comp_pat(22) XOR nlli11i))) AND (NOT (comp_pat(23) XOR nlli11l))) AND (NOT (comp_pat(24) XOR nlli11O))) AND (NOT (comp_pat(25) XOR nlli10i))) AND (NOT (comp_pat(26) XOR nlli10l))) AND (NOT (comp_pat(27) XOR nlli10O))) AND (NOT (comp_pat(28) XOR nlli1ii))) AND (NOT (comp_pat(29) XOR nlli1il)));
	n11O00l <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0OOl)) AND (NOT ((NOT comp_pat(21)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(22)) XOR nlli11i))) AND (NOT ((NOT comp_pat(23)) XOR nlli11l))) AND (NOT ((NOT comp_pat(24)) XOR nlli11O))) AND (NOT ((NOT comp_pat(25)) XOR nlli10i))) AND (NOT ((NOT comp_pat(26)) XOR nlli10l))) AND (NOT ((NOT comp_pat(27)) XOR nlli10O))) AND (NOT ((NOT comp_pat(28)) XOR nlli1ii))) AND (NOT ((NOT comp_pat(29)) XOR nlli1il)));
	n11O00O <= ((((((((((NOT (comp_pat(30) XOR nlli1iO)) AND (NOT (comp_pat(31) XOR nlli1li))) AND (NOT (comp_pat(32) XOR nlli1ll))) AND (NOT (comp_pat(33) XOR nlli1lO))) AND (NOT (comp_pat(34) XOR nlli1Oi))) AND (NOT (comp_pat(35) XOR nlli1Ol))) AND (NOT (comp_pat(36) XOR nlli1OO))) AND (NOT (comp_pat(37) XOR nlli01i))) AND (NOT (comp_pat(38) XOR nlli01l))) AND (NOT (comp_pat(39) XOR nlli01O)));
	n11O01i <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0i0l)) AND (NOT ((NOT comp_pat(1)) XOR nll0i0O))) AND (NOT ((NOT comp_pat(2)) XOR nll0iii))) AND (NOT ((NOT comp_pat(3)) XOR nll0iil))) AND (NOT ((NOT comp_pat(4)) XOR nll0iiO))) AND (NOT ((NOT comp_pat(5)) XOR nll0ili))) AND (NOT ((NOT comp_pat(6)) XOR nll0ill))) AND (NOT ((NOT comp_pat(7)) XOR nll0ilO)));
	n11O01l <= (((((((((((((((((((n101iil OR n101i1O) OR n1010Oi) OR n1010il) OR n10101O) OR n1011Oi) OR n1011il) OR n10111O) OR n11OOOi) OR n11OOil) OR n11OO1O) OR n11OlOi) OR n11Olil) OR n11Ol1O) OR n11OiOi) OR n11Oiil) OR n11Oi1O) OR n11O0Oi) OR n11O0il) OR n11O01O);
	n11O01O <= (n101iOl AND (wire_w_lg_w_lg_comp_pat_porn4870w4871w(0) AND wire_w_lg_w_lg_comp_pat_porn4872w4873w(0)));
	n11O0ii <= ((((((((((NOT ((NOT comp_pat(30)) XOR nlli1iO)) AND (NOT ((NOT comp_pat(31)) XOR nlli1li))) AND (NOT ((NOT comp_pat(32)) XOR nlli1ll))) AND (NOT ((NOT comp_pat(33)) XOR nlli1lO))) AND (NOT ((NOT comp_pat(34)) XOR nlli1Oi))) AND (NOT ((NOT comp_pat(35)) XOR nlli1Ol))) AND (NOT ((NOT comp_pat(36)) XOR nlli1OO))) AND (NOT ((NOT comp_pat(37)) XOR nlli01i))) AND (NOT ((NOT comp_pat(38)) XOR nlli01l))) AND (NOT ((NOT comp_pat(39)) XOR nlli01O)));
	n11O0il <= (n101l1l AND (wire_w_lg_w_lg_comp_pat_porn4864w4865w(0) AND wire_w_lg_w_lg_comp_pat_porn4866w4867w(0)));
	n11O0iO <= ((((((((((NOT (comp_pat(20) XOR nll0OOi)) AND (NOT (comp_pat(21) XOR nll0OOl))) AND (NOT (comp_pat(22) XOR nll0OOO))) AND (NOT (comp_pat(23) XOR nlli11i))) AND (NOT (comp_pat(24) XOR nlli11l))) AND (NOT (comp_pat(25) XOR nlli11O))) AND (NOT (comp_pat(26) XOR nlli10i))) AND (NOT (comp_pat(27) XOR nlli10l))) AND (NOT (comp_pat(28) XOR nlli10O))) AND (NOT (comp_pat(29) XOR nlli1ii)));
	n11O0li <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0OOi)) AND (NOT ((NOT comp_pat(21)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(22)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(23)) XOR nlli11i))) AND (NOT ((NOT comp_pat(24)) XOR nlli11l))) AND (NOT ((NOT comp_pat(25)) XOR nlli11O))) AND (NOT ((NOT comp_pat(26)) XOR nlli10i))) AND (NOT ((NOT comp_pat(27)) XOR nlli10l))) AND (NOT ((NOT comp_pat(28)) XOR nlli10O))) AND (NOT ((NOT comp_pat(29)) XOR nlli1ii)));
	n11O0ll <= ((((((((((NOT (comp_pat(30) XOR nlli1il)) AND (NOT (comp_pat(31) XOR nlli1iO))) AND (NOT (comp_pat(32) XOR nlli1li))) AND (NOT (comp_pat(33) XOR nlli1ll))) AND (NOT (comp_pat(34) XOR nlli1lO))) AND (NOT (comp_pat(35) XOR nlli1Oi))) AND (NOT (comp_pat(36) XOR nlli1Ol))) AND (NOT (comp_pat(37) XOR nlli1OO))) AND (NOT (comp_pat(38) XOR nlli01i))) AND (NOT (comp_pat(39) XOR nlli01l)));
	n11O0lO <= ((((((((((NOT ((NOT comp_pat(30)) XOR nlli1il)) AND (NOT ((NOT comp_pat(31)) XOR nlli1iO))) AND (NOT ((NOT comp_pat(32)) XOR nlli1li))) AND (NOT ((NOT comp_pat(33)) XOR nlli1ll))) AND (NOT ((NOT comp_pat(34)) XOR nlli1lO))) AND (NOT ((NOT comp_pat(35)) XOR nlli1Oi))) AND (NOT ((NOT comp_pat(36)) XOR nlli1Ol))) AND (NOT ((NOT comp_pat(37)) XOR nlli1OO))) AND (NOT ((NOT comp_pat(38)) XOR nlli01i))) AND (NOT ((NOT comp_pat(39)) XOR nlli01l)));
	n11O0Oi <= (n101l0l AND (wire_w_lg_w_lg_comp_pat_porn4858w4859w(0) AND wire_w_lg_w_lg_comp_pat_porn4860w4861w(0)));
	n11O0Ol <= ((((((((((NOT (comp_pat(20) XOR nll0OlO)) AND (NOT (comp_pat(21) XOR nll0OOi))) AND (NOT (comp_pat(22) XOR nll0OOl))) AND (NOT (comp_pat(23) XOR nll0OOO))) AND (NOT (comp_pat(24) XOR nlli11i))) AND (NOT (comp_pat(25) XOR nlli11l))) AND (NOT (comp_pat(26) XOR nlli11O))) AND (NOT (comp_pat(27) XOR nlli10i))) AND (NOT (comp_pat(28) XOR nlli10l))) AND (NOT (comp_pat(29) XOR nlli10O)));
	n11O0OO <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0OlO)) AND (NOT ((NOT comp_pat(21)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(22)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(23)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(24)) XOR nlli11i))) AND (NOT ((NOT comp_pat(25)) XOR nlli11l))) AND (NOT ((NOT comp_pat(26)) XOR nlli11O))) AND (NOT ((NOT comp_pat(27)) XOR nlli10i))) AND (NOT ((NOT comp_pat(28)) XOR nlli10l))) AND (NOT ((NOT comp_pat(29)) XOR nlli10O)));
	n11O10i <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0iiO)) AND (NOT ((NOT comp_pat(1)) XOR nll0ili))) AND (NOT ((NOT comp_pat(2)) XOR nll0ill))) AND (NOT ((NOT comp_pat(3)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(4)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(5)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(6)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(7)) XOR nll0l1i)));
	n11O10l <= ((comp_pat_porn AND n11O1ii) OR n11O10O);
	n11O10O <= ((((((((NOT (comp_pat(0) XOR nll0iil)) AND (NOT (comp_pat(1) XOR nll0iiO))) AND (NOT (comp_pat(2) XOR nll0ili))) AND (NOT (comp_pat(3) XOR nll0ill))) AND (NOT (comp_pat(4) XOR nll0ilO))) AND (NOT (comp_pat(5) XOR nll0iOi))) AND (NOT (comp_pat(6) XOR nll0iOl))) AND (NOT (comp_pat(7) XOR nll0iOO)));
	n11O11i <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0ili)) AND (NOT ((NOT comp_pat(1)) XOR nll0ill))) AND (NOT ((NOT comp_pat(2)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(3)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(4)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(5)) XOR nll0iOO))) AND (NOT ((NOT comp_pat(6)) XOR nll0l1i))) AND (NOT ((NOT comp_pat(7)) XOR nll0l1l)));
	n11O11l <= ((comp_pat_porn AND n11O10i) OR n11O11O);
	n11O11O <= ((((((((NOT (comp_pat(0) XOR nll0iiO)) AND (NOT (comp_pat(1) XOR nll0ili))) AND (NOT (comp_pat(2) XOR nll0ill))) AND (NOT (comp_pat(3) XOR nll0ilO))) AND (NOT (comp_pat(4) XOR nll0iOi))) AND (NOT (comp_pat(5) XOR nll0iOl))) AND (NOT (comp_pat(6) XOR nll0iOO))) AND (NOT (comp_pat(7) XOR nll0l1i)));
	n11O1ii <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0iil)) AND (NOT ((NOT comp_pat(1)) XOR nll0iiO))) AND (NOT ((NOT comp_pat(2)) XOR nll0ili))) AND (NOT ((NOT comp_pat(3)) XOR nll0ill))) AND (NOT ((NOT comp_pat(4)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(5)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(6)) XOR nll0iOl))) AND (NOT ((NOT comp_pat(7)) XOR nll0iOO)));
	n11O1il <= ((comp_pat_porn AND n11O1li) OR n11O1iO);
	n11O1iO <= ((((((((NOT (comp_pat(0) XOR nll0iii)) AND (NOT (comp_pat(1) XOR nll0iil))) AND (NOT (comp_pat(2) XOR nll0iiO))) AND (NOT (comp_pat(3) XOR nll0ili))) AND (NOT (comp_pat(4) XOR nll0ill))) AND (NOT (comp_pat(5) XOR nll0ilO))) AND (NOT (comp_pat(6) XOR nll0iOi))) AND (NOT (comp_pat(7) XOR nll0iOl)));
	n11O1li <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0iii)) AND (NOT ((NOT comp_pat(1)) XOR nll0iil))) AND (NOT ((NOT comp_pat(2)) XOR nll0iiO))) AND (NOT ((NOT comp_pat(3)) XOR nll0ili))) AND (NOT ((NOT comp_pat(4)) XOR nll0ill))) AND (NOT ((NOT comp_pat(5)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(6)) XOR nll0iOi))) AND (NOT ((NOT comp_pat(7)) XOR nll0iOl)));
	n11O1ll <= ((comp_pat_porn AND n11O1Oi) OR n11O1lO);
	n11O1lO <= ((((((((NOT (comp_pat(0) XOR nll0i0O)) AND (NOT (comp_pat(1) XOR nll0iii))) AND (NOT (comp_pat(2) XOR nll0iil))) AND (NOT (comp_pat(3) XOR nll0iiO))) AND (NOT (comp_pat(4) XOR nll0ili))) AND (NOT (comp_pat(5) XOR nll0ill))) AND (NOT (comp_pat(6) XOR nll0ilO))) AND (NOT (comp_pat(7) XOR nll0iOi)));
	n11O1Oi <= ((((((((NOT ((NOT comp_pat(0)) XOR nll0i0O)) AND (NOT ((NOT comp_pat(1)) XOR nll0iii))) AND (NOT ((NOT comp_pat(2)) XOR nll0iil))) AND (NOT ((NOT comp_pat(3)) XOR nll0iiO))) AND (NOT ((NOT comp_pat(4)) XOR nll0ili))) AND (NOT ((NOT comp_pat(5)) XOR nll0ill))) AND (NOT ((NOT comp_pat(6)) XOR nll0ilO))) AND (NOT ((NOT comp_pat(7)) XOR nll0iOi)));
	n11O1Ol <= ((comp_pat_porn AND n11O01i) OR n11O1OO);
	n11O1OO <= ((((((((NOT (comp_pat(0) XOR nll0i0l)) AND (NOT (comp_pat(1) XOR nll0i0O))) AND (NOT (comp_pat(2) XOR nll0iii))) AND (NOT (comp_pat(3) XOR nll0iil))) AND (NOT (comp_pat(4) XOR nll0iiO))) AND (NOT (comp_pat(5) XOR nll0ili))) AND (NOT (comp_pat(6) XOR nll0ill))) AND (NOT (comp_pat(7) XOR nll0ilO)));
	n11Oi0i <= ((((((((((NOT (comp_pat(20) XOR nll0Oll)) AND (NOT (comp_pat(21) XOR nll0OlO))) AND (NOT (comp_pat(22) XOR nll0OOi))) AND (NOT (comp_pat(23) XOR nll0OOl))) AND (NOT (comp_pat(24) XOR nll0OOO))) AND (NOT (comp_pat(25) XOR nlli11i))) AND (NOT (comp_pat(26) XOR nlli11l))) AND (NOT (comp_pat(27) XOR nlli11O))) AND (NOT (comp_pat(28) XOR nlli10i))) AND (NOT (comp_pat(29) XOR nlli10l)));
	n11Oi0l <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0Oll)) AND (NOT ((NOT comp_pat(21)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(22)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(23)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(24)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(25)) XOR nlli11i))) AND (NOT ((NOT comp_pat(26)) XOR nlli11l))) AND (NOT ((NOT comp_pat(27)) XOR nlli11O))) AND (NOT ((NOT comp_pat(28)) XOR nlli10i))) AND (NOT ((NOT comp_pat(29)) XOR nlli10l)));
	n11Oi0O <= ((((((((((NOT (comp_pat(30) XOR nlli10O)) AND (NOT (comp_pat(31) XOR nlli1ii))) AND (NOT (comp_pat(32) XOR nlli1il))) AND (NOT (comp_pat(33) XOR nlli1iO))) AND (NOT (comp_pat(34) XOR nlli1li))) AND (NOT (comp_pat(35) XOR nlli1ll))) AND (NOT (comp_pat(36) XOR nlli1lO))) AND (NOT (comp_pat(37) XOR nlli1Oi))) AND (NOT (comp_pat(38) XOR nlli1Ol))) AND (NOT (comp_pat(39) XOR nlli1OO)));
	n11Oi1i <= ((((((((((NOT (comp_pat(30) XOR nlli1ii)) AND (NOT (comp_pat(31) XOR nlli1il))) AND (NOT (comp_pat(32) XOR nlli1iO))) AND (NOT (comp_pat(33) XOR nlli1li))) AND (NOT (comp_pat(34) XOR nlli1ll))) AND (NOT (comp_pat(35) XOR nlli1lO))) AND (NOT (comp_pat(36) XOR nlli1Oi))) AND (NOT (comp_pat(37) XOR nlli1Ol))) AND (NOT (comp_pat(38) XOR nlli1OO))) AND (NOT (comp_pat(39) XOR nlli01i)));
	n11Oi1l <= ((((((((((NOT ((NOT comp_pat(30)) XOR nlli1ii)) AND (NOT ((NOT comp_pat(31)) XOR nlli1il))) AND (NOT ((NOT comp_pat(32)) XOR nlli1iO))) AND (NOT ((NOT comp_pat(33)) XOR nlli1li))) AND (NOT ((NOT comp_pat(34)) XOR nlli1ll))) AND (NOT ((NOT comp_pat(35)) XOR nlli1lO))) AND (NOT ((NOT comp_pat(36)) XOR nlli1Oi))) AND (NOT ((NOT comp_pat(37)) XOR nlli1Ol))) AND (NOT ((NOT comp_pat(38)) XOR nlli1OO))) AND (NOT ((NOT comp_pat(39)) XOR nlli01i)));
	n11Oi1O <= (n101lil AND (wire_w_lg_w_lg_comp_pat_porn4852w4853w(0) AND wire_w_lg_w_lg_comp_pat_porn4854w4855w(0)));
	n11Oiii <= ((((((((((NOT ((NOT comp_pat(30)) XOR nlli10O)) AND (NOT ((NOT comp_pat(31)) XOR nlli1ii))) AND (NOT ((NOT comp_pat(32)) XOR nlli1il))) AND (NOT ((NOT comp_pat(33)) XOR nlli1iO))) AND (NOT ((NOT comp_pat(34)) XOR nlli1li))) AND (NOT ((NOT comp_pat(35)) XOR nlli1ll))) AND (NOT ((NOT comp_pat(36)) XOR nlli1lO))) AND (NOT ((NOT comp_pat(37)) XOR nlli1Oi))) AND (NOT ((NOT comp_pat(38)) XOR nlli1Ol))) AND (NOT ((NOT comp_pat(39)) XOR nlli1OO)));
	n11Oiil <= (n101lll AND (wire_w_lg_w_lg_comp_pat_porn4846w4847w(0) AND wire_w_lg_w_lg_comp_pat_porn4848w4849w(0)));
	n11OiiO <= ((((((((((NOT (comp_pat(20) XOR nll0Oli)) AND (NOT (comp_pat(21) XOR nll0Oll))) AND (NOT (comp_pat(22) XOR nll0OlO))) AND (NOT (comp_pat(23) XOR nll0OOi))) AND (NOT (comp_pat(24) XOR nll0OOl))) AND (NOT (comp_pat(25) XOR nll0OOO))) AND (NOT (comp_pat(26) XOR nlli11i))) AND (NOT (comp_pat(27) XOR nlli11l))) AND (NOT (comp_pat(28) XOR nlli11O))) AND (NOT (comp_pat(29) XOR nlli10i)));
	n11Oili <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0Oli)) AND (NOT ((NOT comp_pat(21)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(22)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(23)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(24)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(25)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(26)) XOR nlli11i))) AND (NOT ((NOT comp_pat(27)) XOR nlli11l))) AND (NOT ((NOT comp_pat(28)) XOR nlli11O))) AND (NOT ((NOT comp_pat(29)) XOR nlli10i)));
	n11Oill <= ((((((((((NOT (comp_pat(30) XOR nlli10l)) AND (NOT (comp_pat(31) XOR nlli10O))) AND (NOT (comp_pat(32) XOR nlli1ii))) AND (NOT (comp_pat(33) XOR nlli1il))) AND (NOT (comp_pat(34) XOR nlli1iO))) AND (NOT (comp_pat(35) XOR nlli1li))) AND (NOT (comp_pat(36) XOR nlli1ll))) AND (NOT (comp_pat(37) XOR nlli1lO))) AND (NOT (comp_pat(38) XOR nlli1Oi))) AND (NOT (comp_pat(39) XOR nlli1Ol)));
	n11OilO <= ((((((((((NOT ((NOT comp_pat(30)) XOR nlli10l)) AND (NOT ((NOT comp_pat(31)) XOR nlli10O))) AND (NOT ((NOT comp_pat(32)) XOR nlli1ii))) AND (NOT ((NOT comp_pat(33)) XOR nlli1il))) AND (NOT ((NOT comp_pat(34)) XOR nlli1iO))) AND (NOT ((NOT comp_pat(35)) XOR nlli1li))) AND (NOT ((NOT comp_pat(36)) XOR nlli1ll))) AND (NOT ((NOT comp_pat(37)) XOR nlli1lO))) AND (NOT ((NOT comp_pat(38)) XOR nlli1Oi))) AND (NOT ((NOT comp_pat(39)) XOR nlli1Ol)));
	n11OiOi <= (n101lOl AND (wire_w_lg_w_lg_comp_pat_porn4840w4841w(0) AND wire_w_lg_w_lg_comp_pat_porn4842w4843w(0)));
	n11OiOl <= ((((((((((NOT (comp_pat(20) XOR nll0OiO)) AND (NOT (comp_pat(21) XOR nll0Oli))) AND (NOT (comp_pat(22) XOR nll0Oll))) AND (NOT (comp_pat(23) XOR nll0OlO))) AND (NOT (comp_pat(24) XOR nll0OOi))) AND (NOT (comp_pat(25) XOR nll0OOl))) AND (NOT (comp_pat(26) XOR nll0OOO))) AND (NOT (comp_pat(27) XOR nlli11i))) AND (NOT (comp_pat(28) XOR nlli11l))) AND (NOT (comp_pat(29) XOR nlli11O)));
	n11OiOO <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0OiO)) AND (NOT ((NOT comp_pat(21)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(22)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(23)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(24)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(25)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(26)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(27)) XOR nlli11i))) AND (NOT ((NOT comp_pat(28)) XOR nlli11l))) AND (NOT ((NOT comp_pat(29)) XOR nlli11O)));
	n11Ol0i <= ((((((((((NOT (comp_pat(20) XOR nll0Oil)) AND (NOT (comp_pat(21) XOR nll0OiO))) AND (NOT (comp_pat(22) XOR nll0Oli))) AND (NOT (comp_pat(23) XOR nll0Oll))) AND (NOT (comp_pat(24) XOR nll0OlO))) AND (NOT (comp_pat(25) XOR nll0OOi))) AND (NOT (comp_pat(26) XOR nll0OOl))) AND (NOT (comp_pat(27) XOR nll0OOO))) AND (NOT (comp_pat(28) XOR nlli11i))) AND (NOT (comp_pat(29) XOR nlli11l)));
	n11Ol0l <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0Oil)) AND (NOT ((NOT comp_pat(21)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(22)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(23)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(24)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(25)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(26)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(27)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(28)) XOR nlli11i))) AND (NOT ((NOT comp_pat(29)) XOR nlli11l)));
	n11Ol0O <= ((((((((((NOT (comp_pat(30) XOR nlli11O)) AND (NOT (comp_pat(31) XOR nlli10i))) AND (NOT (comp_pat(32) XOR nlli10l))) AND (NOT (comp_pat(33) XOR nlli10O))) AND (NOT (comp_pat(34) XOR nlli1ii))) AND (NOT (comp_pat(35) XOR nlli1il))) AND (NOT (comp_pat(36) XOR nlli1iO))) AND (NOT (comp_pat(37) XOR nlli1li))) AND (NOT (comp_pat(38) XOR nlli1ll))) AND (NOT (comp_pat(39) XOR nlli1lO)));
	n11Ol1i <= ((((((((((NOT (comp_pat(30) XOR nlli10i)) AND (NOT (comp_pat(31) XOR nlli10l))) AND (NOT (comp_pat(32) XOR nlli10O))) AND (NOT (comp_pat(33) XOR nlli1ii))) AND (NOT (comp_pat(34) XOR nlli1il))) AND (NOT (comp_pat(35) XOR nlli1iO))) AND (NOT (comp_pat(36) XOR nlli1li))) AND (NOT (comp_pat(37) XOR nlli1ll))) AND (NOT (comp_pat(38) XOR nlli1lO))) AND (NOT (comp_pat(39) XOR nlli1Oi)));
	n11Ol1l <= ((((((((((NOT ((NOT comp_pat(30)) XOR nlli10i)) AND (NOT ((NOT comp_pat(31)) XOR nlli10l))) AND (NOT ((NOT comp_pat(32)) XOR nlli10O))) AND (NOT ((NOT comp_pat(33)) XOR nlli1ii))) AND (NOT ((NOT comp_pat(34)) XOR nlli1il))) AND (NOT ((NOT comp_pat(35)) XOR nlli1iO))) AND (NOT ((NOT comp_pat(36)) XOR nlli1li))) AND (NOT ((NOT comp_pat(37)) XOR nlli1ll))) AND (NOT ((NOT comp_pat(38)) XOR nlli1lO))) AND (NOT ((NOT comp_pat(39)) XOR nlli1Oi)));
	n11Ol1O <= (n101O1l AND (wire_w_lg_w_lg_comp_pat_porn4834w4835w(0) AND wire_w_lg_w_lg_comp_pat_porn4836w4837w(0)));
	n11Olii <= ((((((((((NOT ((NOT comp_pat(30)) XOR nlli11O)) AND (NOT ((NOT comp_pat(31)) XOR nlli10i))) AND (NOT ((NOT comp_pat(32)) XOR nlli10l))) AND (NOT ((NOT comp_pat(33)) XOR nlli10O))) AND (NOT ((NOT comp_pat(34)) XOR nlli1ii))) AND (NOT ((NOT comp_pat(35)) XOR nlli1il))) AND (NOT ((NOT comp_pat(36)) XOR nlli1iO))) AND (NOT ((NOT comp_pat(37)) XOR nlli1li))) AND (NOT ((NOT comp_pat(38)) XOR nlli1ll))) AND (NOT ((NOT comp_pat(39)) XOR nlli1lO)));
	n11Olil <= (n101O0l AND (wire_w_lg_w_lg_comp_pat_porn4828w4829w(0) AND wire_w_lg_w_lg_comp_pat_porn4830w4831w(0)));
	n11OliO <= ((((((((((NOT (comp_pat(20) XOR nll0Oii)) AND (NOT (comp_pat(21) XOR nll0Oil))) AND (NOT (comp_pat(22) XOR nll0OiO))) AND (NOT (comp_pat(23) XOR nll0Oli))) AND (NOT (comp_pat(24) XOR nll0Oll))) AND (NOT (comp_pat(25) XOR nll0OlO))) AND (NOT (comp_pat(26) XOR nll0OOi))) AND (NOT (comp_pat(27) XOR nll0OOl))) AND (NOT (comp_pat(28) XOR nll0OOO))) AND (NOT (comp_pat(29) XOR nlli11i)));
	n11Olli <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0Oii)) AND (NOT ((NOT comp_pat(21)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(22)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(23)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(24)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(25)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(26)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(27)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(28)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(29)) XOR nlli11i)));
	n11Olll <= ((((((((((NOT (comp_pat(30) XOR nlli11l)) AND (NOT (comp_pat(31) XOR nlli11O))) AND (NOT (comp_pat(32) XOR nlli10i))) AND (NOT (comp_pat(33) XOR nlli10l))) AND (NOT (comp_pat(34) XOR nlli10O))) AND (NOT (comp_pat(35) XOR nlli1ii))) AND (NOT (comp_pat(36) XOR nlli1il))) AND (NOT (comp_pat(37) XOR nlli1iO))) AND (NOT (comp_pat(38) XOR nlli1li))) AND (NOT (comp_pat(39) XOR nlli1ll)));
	n11OllO <= ((((((((((NOT ((NOT comp_pat(30)) XOR nlli11l)) AND (NOT ((NOT comp_pat(31)) XOR nlli11O))) AND (NOT ((NOT comp_pat(32)) XOR nlli10i))) AND (NOT ((NOT comp_pat(33)) XOR nlli10l))) AND (NOT ((NOT comp_pat(34)) XOR nlli10O))) AND (NOT ((NOT comp_pat(35)) XOR nlli1ii))) AND (NOT ((NOT comp_pat(36)) XOR nlli1il))) AND (NOT ((NOT comp_pat(37)) XOR nlli1iO))) AND (NOT ((NOT comp_pat(38)) XOR nlli1li))) AND (NOT ((NOT comp_pat(39)) XOR nlli1ll)));
	n11OlOi <= (n101Oil AND (wire_w_lg_w_lg_comp_pat_porn4822w4823w(0) AND wire_w_lg_w_lg_comp_pat_porn4824w4825w(0)));
	n11OlOl <= ((((((((((NOT (comp_pat(20) XOR nll0O0O)) AND (NOT (comp_pat(21) XOR nll0Oii))) AND (NOT (comp_pat(22) XOR nll0Oil))) AND (NOT (comp_pat(23) XOR nll0OiO))) AND (NOT (comp_pat(24) XOR nll0Oli))) AND (NOT (comp_pat(25) XOR nll0Oll))) AND (NOT (comp_pat(26) XOR nll0OlO))) AND (NOT (comp_pat(27) XOR nll0OOi))) AND (NOT (comp_pat(28) XOR nll0OOl))) AND (NOT (comp_pat(29) XOR nll0OOO)));
	n11OlOO <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0O0O)) AND (NOT ((NOT comp_pat(21)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(22)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(23)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(24)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(25)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(26)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(27)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(28)) XOR nll0OOl))) AND (NOT ((NOT comp_pat(29)) XOR nll0OOO)));
	n11OO0i <= ((((((((((NOT (comp_pat(20) XOR nll0O0l)) AND (NOT (comp_pat(21) XOR nll0O0O))) AND (NOT (comp_pat(22) XOR nll0Oii))) AND (NOT (comp_pat(23) XOR nll0Oil))) AND (NOT (comp_pat(24) XOR nll0OiO))) AND (NOT (comp_pat(25) XOR nll0Oli))) AND (NOT (comp_pat(26) XOR nll0Oll))) AND (NOT (comp_pat(27) XOR nll0OlO))) AND (NOT (comp_pat(28) XOR nll0OOi))) AND (NOT (comp_pat(29) XOR nll0OOl)));
	n11OO0l <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0O0l)) AND (NOT ((NOT comp_pat(21)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(22)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(23)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(24)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(25)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(26)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(27)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(28)) XOR nll0OOi))) AND (NOT ((NOT comp_pat(29)) XOR nll0OOl)));
	n11OO0O <= ((((((((((NOT (comp_pat(30) XOR nll0OOO)) AND (NOT (comp_pat(31) XOR nlli11i))) AND (NOT (comp_pat(32) XOR nlli11l))) AND (NOT (comp_pat(33) XOR nlli11O))) AND (NOT (comp_pat(34) XOR nlli10i))) AND (NOT (comp_pat(35) XOR nlli10l))) AND (NOT (comp_pat(36) XOR nlli10O))) AND (NOT (comp_pat(37) XOR nlli1ii))) AND (NOT (comp_pat(38) XOR nlli1il))) AND (NOT (comp_pat(39) XOR nlli1iO)));
	n11OO1i <= ((((((((((NOT (comp_pat(30) XOR nlli11i)) AND (NOT (comp_pat(31) XOR nlli11l))) AND (NOT (comp_pat(32) XOR nlli11O))) AND (NOT (comp_pat(33) XOR nlli10i))) AND (NOT (comp_pat(34) XOR nlli10l))) AND (NOT (comp_pat(35) XOR nlli10O))) AND (NOT (comp_pat(36) XOR nlli1ii))) AND (NOT (comp_pat(37) XOR nlli1il))) AND (NOT (comp_pat(38) XOR nlli1iO))) AND (NOT (comp_pat(39) XOR nlli1li)));
	n11OO1l <= ((((((((((NOT ((NOT comp_pat(30)) XOR nlli11i)) AND (NOT ((NOT comp_pat(31)) XOR nlli11l))) AND (NOT ((NOT comp_pat(32)) XOR nlli11O))) AND (NOT ((NOT comp_pat(33)) XOR nlli10i))) AND (NOT ((NOT comp_pat(34)) XOR nlli10l))) AND (NOT ((NOT comp_pat(35)) XOR nlli10O))) AND (NOT ((NOT comp_pat(36)) XOR nlli1ii))) AND (NOT ((NOT comp_pat(37)) XOR nlli1il))) AND (NOT ((NOT comp_pat(38)) XOR nlli1iO))) AND (NOT ((NOT comp_pat(39)) XOR nlli1li)));
	n11OO1O <= (n101Oll AND (wire_w_lg_w_lg_comp_pat_porn4816w4817w(0) AND wire_w_lg_w_lg_comp_pat_porn4818w4819w(0)));
	n11OOii <= ((((((((((NOT ((NOT comp_pat(30)) XOR nll0OOO)) AND (NOT ((NOT comp_pat(31)) XOR nlli11i))) AND (NOT ((NOT comp_pat(32)) XOR nlli11l))) AND (NOT ((NOT comp_pat(33)) XOR nlli11O))) AND (NOT ((NOT comp_pat(34)) XOR nlli10i))) AND (NOT ((NOT comp_pat(35)) XOR nlli10l))) AND (NOT ((NOT comp_pat(36)) XOR nlli10O))) AND (NOT ((NOT comp_pat(37)) XOR nlli1ii))) AND (NOT ((NOT comp_pat(38)) XOR nlli1il))) AND (NOT ((NOT comp_pat(39)) XOR nlli1iO)));
	n11OOil <= (n101OOl AND (wire_w_lg_w_lg_comp_pat_porn4810w4811w(0) AND wire_w_lg_w_lg_comp_pat_porn4812w4813w(0)));
	n11OOiO <= ((((((((((NOT (comp_pat(20) XOR nll0O0i)) AND (NOT (comp_pat(21) XOR nll0O0l))) AND (NOT (comp_pat(22) XOR nll0O0O))) AND (NOT (comp_pat(23) XOR nll0Oii))) AND (NOT (comp_pat(24) XOR nll0Oil))) AND (NOT (comp_pat(25) XOR nll0OiO))) AND (NOT (comp_pat(26) XOR nll0Oli))) AND (NOT (comp_pat(27) XOR nll0Oll))) AND (NOT (comp_pat(28) XOR nll0OlO))) AND (NOT (comp_pat(29) XOR nll0OOi)));
	n11OOli <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0O0i)) AND (NOT ((NOT comp_pat(21)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(22)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(23)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(24)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(25)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(26)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(27)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(28)) XOR nll0OlO))) AND (NOT ((NOT comp_pat(29)) XOR nll0OOi)));
	n11OOll <= ((((((((((NOT (comp_pat(30) XOR nll0OOl)) AND (NOT (comp_pat(31) XOR nll0OOO))) AND (NOT (comp_pat(32) XOR nlli11i))) AND (NOT (comp_pat(33) XOR nlli11l))) AND (NOT (comp_pat(34) XOR nlli11O))) AND (NOT (comp_pat(35) XOR nlli10i))) AND (NOT (comp_pat(36) XOR nlli10l))) AND (NOT (comp_pat(37) XOR nlli10O))) AND (NOT (comp_pat(38) XOR nlli1ii))) AND (NOT (comp_pat(39) XOR nlli1il)));
	n11OOlO <= ((((((((((NOT ((NOT comp_pat(30)) XOR nll0OOl)) AND (NOT ((NOT comp_pat(31)) XOR nll0OOO))) AND (NOT ((NOT comp_pat(32)) XOR nlli11i))) AND (NOT ((NOT comp_pat(33)) XOR nlli11l))) AND (NOT ((NOT comp_pat(34)) XOR nlli11O))) AND (NOT ((NOT comp_pat(35)) XOR nlli10i))) AND (NOT ((NOT comp_pat(36)) XOR nlli10l))) AND (NOT ((NOT comp_pat(37)) XOR nlli10O))) AND (NOT ((NOT comp_pat(38)) XOR nlli1ii))) AND (NOT ((NOT comp_pat(39)) XOR nlli1il)));
	n11OOOi <= (n10011l AND (wire_w_lg_w_lg_comp_pat_porn4804w4805w(0) AND wire_w_lg_w_lg_comp_pat_porn4806w4807w(0)));
	n11OOOl <= ((((((((((NOT (comp_pat(20) XOR nll0O1O)) AND (NOT (comp_pat(21) XOR nll0O0i))) AND (NOT (comp_pat(22) XOR nll0O0l))) AND (NOT (comp_pat(23) XOR nll0O0O))) AND (NOT (comp_pat(24) XOR nll0Oii))) AND (NOT (comp_pat(25) XOR nll0Oil))) AND (NOT (comp_pat(26) XOR nll0OiO))) AND (NOT (comp_pat(27) XOR nll0Oli))) AND (NOT (comp_pat(28) XOR nll0Oll))) AND (NOT (comp_pat(29) XOR nll0OlO)));
	n11OOOO <= ((((((((((NOT ((NOT comp_pat(20)) XOR nll0O1O)) AND (NOT ((NOT comp_pat(21)) XOR nll0O0i))) AND (NOT ((NOT comp_pat(22)) XOR nll0O0l))) AND (NOT ((NOT comp_pat(23)) XOR nll0O0O))) AND (NOT ((NOT comp_pat(24)) XOR nll0Oii))) AND (NOT ((NOT comp_pat(25)) XOR nll0Oil))) AND (NOT ((NOT comp_pat(26)) XOR nll0OiO))) AND (NOT ((NOT comp_pat(27)) XOR nll0Oli))) AND (NOT ((NOT comp_pat(28)) XOR nll0Oll))) AND (NOT ((NOT comp_pat(29)) XOR nll0OlO)));
	n1i000i <= (n10llOi AND n10llOl);
	n1i000l <= (wire_niOl1i_w_lg_w_lg_o2972w3113w(0) OR wire_niOl1i_w_lg_o3114w(0));
	n1i000O <= ((((wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_w_lg_o3108w(0) AND wire_niOilO_w_lg_w_lg_o3116w3117w(0))) OR (wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_w_lg_o3108w(0) AND wire_niOilO_w_lg_o3119w(0)))) OR (wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_o AND n10lliO))) OR wire_niOiOl_w_lg_o3283w(0));
	n1i001i <= (n10lO1i AND n1i00ii);
	n1i001l <= (((wire_w_lg_n10lOOO3237w(0) OR (n10lO1i AND n1i000l)) OR n10lOOl) OR n10O11i);
	n1i001O <= (wire_niOiOl_o AND n10lllO);
	n1i00ii <= (wire_niOl1i_w_lg_o2972w(0) AND wire_niOiOO_w_lg_o2973w(0));
	n1i00il <= ((((((wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_w_lg_o3108w(0) AND (wire_niOilO_o AND wire_niOill_o))) OR (wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_o AND n10llll))) OR (wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_o AND n10llli))) OR wire_niOiOl_w_lg_o3273w(0)) OR wire_niOiOl_w_lg_o3276w(0)) OR wire_niOiOl_w_lg_o3137w(0));
	n1i00iO <= (n1i000O AND n1i00ii);
	n1i00li <= (n10llOi AND n1i000l);
	n1i00ll <= (n10llOi AND n1i00ii);
	n1i00lO <= (n1i00Ol OR n1i00Oi);
	n1i00Oi <= (pmadwidth(0) AND nill0l);
	n1i00Ol <= (wire_w_lg_w_pmadwidth_range175w219w(0) AND nill0l);
	n1i010i <= ((((((((NOT (comp_pat(0) XOR wire_nilllO_dataout)) AND (NOT (comp_pat(1) XOR wire_nillOi_dataout))) AND (NOT (comp_pat(2) XOR wire_nillOl_dataout))) AND (NOT (comp_pat(3) XOR wire_nillOO_dataout))) AND (NOT (comp_pat(4) XOR wire_nilO1i_dataout))) AND (NOT (comp_pat(5) XOR wire_nilO1l_dataout))) AND (NOT (comp_pat(6) XOR wire_nilO1O_dataout))) AND (NOT (comp_pat(7) XOR wire_nilO0i_dataout)));
	n1i010l <= (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n1i01ii1295w(0));
	n1i010O <= (nl1l1l AND (wire_w_lg_w_pmadwidth_range175w219w(0) AND nl1lii));
	n1i011i <= (((((((NOT ((NOT comp_pat(0)) XOR wire_nilllO_dataout)) AND (NOT ((NOT comp_pat(1)) XOR wire_nillOi_dataout))) AND (NOT ((NOT comp_pat(2)) XOR wire_nillOl_dataout))) AND (NOT ((NOT comp_pat(3)) XOR wire_nillOO_dataout))) AND (NOT ((NOT comp_pat(4)) XOR wire_nilO1i_dataout))) AND (NOT ((NOT comp_pat(5)) XOR wire_nilO1l_dataout))) AND (NOT ((NOT comp_pat(6)) XOR wire_nilO1O_dataout)));
	n1i011l <= (((((((NOT (comp_pat(0) XOR wire_nilllO_dataout)) AND (NOT (comp_pat(1) XOR wire_nillOi_dataout))) AND (NOT (comp_pat(2) XOR wire_nillOl_dataout))) AND (NOT (comp_pat(3) XOR wire_nillOO_dataout))) AND (NOT (comp_pat(4) XOR wire_nilO1i_dataout))) AND (NOT (comp_pat(5) XOR wire_nilO1l_dataout))) AND (NOT (comp_pat(6) XOR wire_nilO1O_dataout)));
	n1i011O <= ((((((((NOT (comp_pat(8) XOR wire_nilllO_dataout)) AND (NOT (comp_pat(9) XOR wire_nillOi_dataout))) AND (NOT (comp_pat(10) XOR wire_nillOl_dataout))) AND (NOT (comp_pat(11) XOR wire_nillOO_dataout))) AND (NOT (comp_pat(12) XOR wire_nilO1i_dataout))) AND (NOT (comp_pat(13) XOR wire_nilO1l_dataout))) AND (NOT (comp_pat(14) XOR wire_nilO1O_dataout))) AND (NOT (comp_pat(15) XOR wire_nilO0i_dataout)));
	n1i01ii <= (nl1lii AND nl1l1l);
	n1i01il <= (n1i01li OR n1i01iO);
	n1i01iO <= (nl1lii AND wire_nl_w_lg_nl1l1l1933w(0));
	n1i01li <= (nl1lii AND nl1l1l);
	n1i01ll <= ((((((wire_niOl0l_w_lg_dataout1312w(0) AND (wire_niOl0i_w_lg_dataout1313w(0) AND wire_niOl1O_w_lg_o2980w(0))) OR (wire_niOl0l_w_lg_dataout1312w(0) AND (wire_niOl0i_dataout AND n10lO0l))) OR (wire_niOl0l_w_lg_dataout1312w(0) AND (wire_niOl0i_dataout AND n10lO0i))) OR wire_niOl0l_w_lg_dataout3200w(0)) OR wire_niOl0l_w_lg_dataout3203w(0)) OR wire_niOl0l_w_lg_dataout3206w(0));
	n1i01lO <= (n10lOll OR n10lOOi);
	n1i01Oi <= (wire_niOl0l_w_lg_dataout1312w(0) AND (wire_niOl0i_w_lg_dataout1313w(0) AND wire_niOl1O_w_lg_w_lg_o1314w2984w(0)));
	n1i01Ol <= ((((wire_niOl0l_w_lg_dataout1312w(0) AND (wire_niOl0i_w_lg_dataout1313w(0) AND wire_niOl1O_w_lg_w_lg_o1314w3189w(0))) OR (wire_niOl0l_w_lg_dataout1312w(0) AND (wire_niOl0i_w_lg_dataout1313w(0) AND wire_niOl1O_w_lg_o3190w(0)))) OR (wire_niOl0l_w_lg_dataout1312w(0) AND (wire_niOl0i_dataout AND n10lO1O))) OR wire_niOl0l_w_lg_dataout3217w(0));
	n1i01OO <= (wire_niOl1O_w_lg_o1314w(0) AND wire_niOl1l_w_lg_w_lg_o2983w3166w(0));
	n1i0i0i <= ((((((((wire_nl011O_w_lg_dataout446w(0) OR wire_w_lg_n1i0ilO447w(0)) OR wire_w_lg_n1i0ill449w(0)) OR wire_w_lg_n1i0ili451w(0)) OR wire_w_lg_n1i0iiO453w(0)) OR wire_w_lg_n1i0iil455w(0)) OR wire_w_lg_n1i0iii457w(0)) OR wire_w_lg_n1i0i0O459w(0)) OR n1i0i0l);
	n1i0i0l <= ((((((((wire_nl00Oi_w_lg_dataout1914w(0) AND wire_nl00ii_w_lg_dataout428w(0)) AND wire_nl000i_w_lg_dataout421w(0)) AND wire_nl001i_w_lg_dataout415w(0)) AND wire_nl01Oi_w_lg_dataout410w(0)) AND wire_nl01li_w_lg_dataout406w(0)) AND wire_nl01ii_w_lg_dataout403w(0)) AND wire_nl010l_w_lg_dataout401w(0)) AND wire_nl011O_w_lg_dataout1922w(0));
	n1i0i0O <= ((((((((wire_nl00li_w_lg_dataout436w(0) OR wire_nl00ii_dataout) OR wire_nl000i_dataout) OR wire_nl001i_dataout) OR wire_nl01Oi_dataout) OR wire_nl01li_dataout) OR wire_nl01ii_dataout) OR wire_nl010l_dataout) OR wire_nl011O_dataout);
	n1i0i1i <= (wire_w_lg_w_pmadwidth_range175w219w(0) AND n1i0i1O);
	n1i0i1l <= (pmadwidth(0) AND n1i0i1O);
	n1i0i1O <= (((wire_nl10lO_w_lg_nl10Oi1924w(0) AND wire_nl10lO_w_lg_nl10ll1925w(0)) AND wire_nl10lO_w_lg_nl10li1927w(0)) AND wire_nl10lO_w_lg_nl10il1929w(0));
	n1i0iii <= (((((((wire_nl00ii_w_lg_dataout428w(0) OR wire_nl000i_dataout) OR wire_nl001i_dataout) OR wire_nl01Oi_dataout) OR wire_nl01li_dataout) OR wire_nl01ii_dataout) OR wire_nl010l_dataout) OR wire_nl011O_dataout);
	n1i0iil <= ((((((wire_nl000i_w_lg_dataout421w(0) OR wire_nl001i_dataout) OR wire_nl01Oi_dataout) OR wire_nl01li_dataout) OR wire_nl01ii_dataout) OR wire_nl010l_dataout) OR wire_nl011O_dataout);
	n1i0iiO <= (((((wire_nl001i_w_lg_dataout415w(0) OR wire_nl01Oi_dataout) OR wire_nl01li_dataout) OR wire_nl01ii_dataout) OR wire_nl010l_dataout) OR wire_nl011O_dataout);
	n1i0ili <= ((((wire_nl01Oi_w_lg_dataout410w(0) OR wire_nl01li_dataout) OR wire_nl01ii_dataout) OR wire_nl010l_dataout) OR wire_nl011O_dataout);
	n1i0ill <= (((wire_nl01li_w_lg_dataout406w(0) OR wire_nl01ii_dataout) OR wire_nl010l_dataout) OR wire_nl011O_dataout);
	n1i0ilO <= ((wire_nl01ii_w_lg_dataout403w(0) OR wire_nl010l_dataout) OR wire_nl011O_dataout);
	n1i0iOi <= (wire_nl010l_w_lg_dataout401w(0) OR wire_nl011O_dataout);
	n1i0iOl <= ((((((((((NOT (wire_nli00i_dataout XOR wire_nl0i1i_dataout)) AND (NOT (wire_nli00l_dataout XOR wire_nl0i1l_dataout))) AND (NOT (wire_nli00O_dataout XOR wire_nl0i1O_dataout))) AND (NOT (wire_nli0ii_dataout XOR wire_nl0i0i_dataout))) AND (NOT (wire_nli0il_dataout XOR wire_nl0i0l_dataout))) AND (NOT (wire_nli0iO_dataout XOR wire_nl0i0O_dataout))) AND (NOT (wire_nli0li_dataout XOR wire_nl0iii_dataout))) AND (NOT (wire_nli0ll_dataout XOR wire_nl0iil_dataout))) AND (NOT (wire_nli0lO_dataout XOR wire_nl0iiO_dataout))) AND (NOT (wire_nli0Oi_dataout XOR wire_nl0ili_dataout)));
	n1i0iOO <= ((((((((((NOT (comp_pat(0) XOR wire_nl0i1i_dataout)) AND (NOT (comp_pat(1) XOR wire_nl0i1l_dataout))) AND (NOT (comp_pat(2) XOR wire_nl0i1O_dataout))) AND (NOT (comp_pat(3) XOR wire_nl0i0i_dataout))) AND (NOT (comp_pat(4) XOR wire_nl0i0l_dataout))) AND (NOT (comp_pat(5) XOR wire_nl0i0O_dataout))) AND (NOT (comp_pat(6) XOR wire_nl0iii_dataout))) AND (NOT (wire_nliiiO_dataout XOR wire_nl0iil_dataout))) AND (NOT (wire_nliili_dataout XOR wire_nl0iiO_dataout))) AND (NOT (wire_nliill_dataout XOR wire_nl0ili_dataout)));
	n1i0l0i <= ((((((((((NOT (comp_pat(0) XOR nliO0l)) AND (NOT (comp_pat(1) XOR nliO0O))) AND (NOT (comp_pat(2) XOR nliOii))) AND (NOT (comp_pat(3) XOR nliOil))) AND (NOT (comp_pat(4) XOR nliOiO))) AND (NOT (comp_pat(5) XOR nliOli))) AND (NOT (comp_pat(6) XOR nliOll))) AND (NOT (wire_nliiiO_dataout XOR wire_nl0O1l_dataout))) AND (NOT (wire_nliili_dataout XOR wire_nl0O1O_dataout))) AND (NOT (wire_nliill_dataout XOR wire_nl0O0i_dataout)));
	n1i0l0l <= ((((((((((NOT (nliO0O XOR wire_nli00i_dataout)) AND (NOT (nliOii XOR wire_nli00l_dataout))) AND (NOT (nliOil XOR wire_nli00O_dataout))) AND (NOT (nliOiO XOR wire_nli0ii_dataout))) AND (NOT (nliOli XOR wire_nli0il_dataout))) AND (NOT (nliOll XOR wire_nli0iO_dataout))) AND (NOT (nliOlO XOR wire_nli0li_dataout))) AND (NOT (wire_nli0ll_dataout XOR wire_nl0O0O_dataout))) AND (NOT (wire_nli0lO_dataout XOR wire_nl0Oii_dataout))) AND (NOT (wire_nli0Oi_dataout XOR wire_nl0Oil_dataout)));
	n1i0l0O <= ((((((((((NOT (comp_pat(0) XOR nliO0O)) AND (NOT (comp_pat(1) XOR nliOii))) AND (NOT (comp_pat(2) XOR nliOil))) AND (NOT (comp_pat(3) XOR nliOiO))) AND (NOT (comp_pat(4) XOR nliOli))) AND (NOT (comp_pat(5) XOR nliOll))) AND (NOT (comp_pat(6) XOR nliOlO))) AND (NOT (wire_nliiiO_dataout XOR wire_nl0O0O_dataout))) AND (NOT (wire_nliili_dataout XOR wire_nl0Oii_dataout))) AND (NOT (wire_nliill_dataout XOR wire_nl0Oil_dataout)));
	n1i0l1i <= ((((((((((NOT (wire_nli00i_dataout XOR wire_nl0l0O_dataout)) AND (NOT (wire_nli00l_dataout XOR wire_nl0lii_dataout))) AND (NOT (wire_nli00O_dataout XOR wire_nl0lil_dataout))) AND (NOT (wire_nli0ii_dataout XOR wire_nl0liO_dataout))) AND (NOT (wire_nli0il_dataout XOR wire_nl0lli_dataout))) AND (NOT (wire_nli0iO_dataout XOR wire_nl0lll_dataout))) AND (NOT (wire_nli0li_dataout XOR wire_nl0llO_dataout))) AND (NOT (wire_nli0ll_dataout XOR wire_nl0lOi_dataout))) AND (NOT (wire_nli0lO_dataout XOR wire_nl0lOl_dataout))) AND (NOT (wire_nli0Oi_dataout XOR wire_nl0lOO_dataout)));
	n1i0l1l <= ((((((((((NOT (comp_pat(0) XOR wire_nl0l0O_dataout)) AND (NOT (comp_pat(1) XOR wire_nl0lii_dataout))) AND (NOT (comp_pat(2) XOR wire_nl0lil_dataout))) AND (NOT (comp_pat(3) XOR wire_nl0liO_dataout))) AND (NOT (comp_pat(4) XOR wire_nl0lli_dataout))) AND (NOT (comp_pat(5) XOR wire_nl0lll_dataout))) AND (NOT (comp_pat(6) XOR wire_nl0llO_dataout))) AND (NOT (wire_nliiiO_dataout XOR wire_nl0lOi_dataout))) AND (NOT (wire_nliili_dataout XOR wire_nl0lOl_dataout))) AND (NOT (wire_nliill_dataout XOR wire_nl0lOO_dataout)));
	n1i0l1O <= ((((((((((NOT (nliO0l XOR wire_nli00i_dataout)) AND (NOT (nliO0O XOR wire_nli00l_dataout))) AND (NOT (nliOii XOR wire_nli00O_dataout))) AND (NOT (nliOil XOR wire_nli0ii_dataout))) AND (NOT (nliOiO XOR wire_nli0il_dataout))) AND (NOT (nliOli XOR wire_nli0iO_dataout))) AND (NOT (nliOll XOR wire_nli0li_dataout))) AND (NOT (wire_nli0ll_dataout XOR wire_nl0O1l_dataout))) AND (NOT (wire_nli0lO_dataout XOR wire_nl0O1O_dataout))) AND (NOT (wire_nli0Oi_dataout XOR wire_nl0O0i_dataout)));
	n1i0lii <= ((((((((((NOT (nliOii XOR wire_nli00i_dataout)) AND (NOT (nliOil XOR wire_nli00l_dataout))) AND (NOT (nliOiO XOR wire_nli00O_dataout))) AND (NOT (nliOli XOR wire_nli0ii_dataout))) AND (NOT (nliOll XOR wire_nli0il_dataout))) AND (NOT (nliOlO XOR wire_nli0iO_dataout))) AND (NOT (nliOOi XOR wire_nli0li_dataout))) AND (NOT (wire_nli0ll_dataout XOR wire_nl0Oli_dataout))) AND (NOT (wire_nli0lO_dataout XOR wire_nl0Oll_dataout))) AND (NOT (wire_nli0Oi_dataout XOR wire_nl0OlO_dataout)));
	n1i0lil <= ((((((((((NOT (comp_pat(0) XOR nliOii)) AND (NOT (comp_pat(1) XOR nliOil))) AND (NOT (comp_pat(2) XOR nliOiO))) AND (NOT (comp_pat(3) XOR nliOli))) AND (NOT (comp_pat(4) XOR nliOll))) AND (NOT (comp_pat(5) XOR nliOlO))) AND (NOT (comp_pat(6) XOR nliOOi))) AND (NOT (wire_nliiiO_dataout XOR wire_nl0Oli_dataout))) AND (NOT (wire_nliili_dataout XOR wire_nl0Oll_dataout))) AND (NOT (wire_nliill_dataout XOR wire_nl0OlO_dataout)));
	n1i0liO <= ((((((((((NOT (nliOil XOR wire_nli00i_dataout)) AND (NOT (nliOiO XOR wire_nli00l_dataout))) AND (NOT (nliOli XOR wire_nli00O_dataout))) AND (NOT (nliOll XOR wire_nli0ii_dataout))) AND (NOT (nliOlO XOR wire_nli0il_dataout))) AND (NOT (nliOOi XOR wire_nli0iO_dataout))) AND (NOT (nliOOl XOR wire_nli0li_dataout))) AND (NOT (wire_nli0ll_dataout XOR wire_nl0OOl_dataout))) AND (NOT (wire_nli0lO_dataout XOR wire_nl0OOO_dataout))) AND (NOT (wire_nli0Oi_dataout XOR wire_nli11i_dataout)));
	n1i0lli <= ((((((((((NOT (comp_pat(0) XOR nliOil)) AND (NOT (comp_pat(1) XOR nliOiO))) AND (NOT (comp_pat(2) XOR nliOli))) AND (NOT (comp_pat(3) XOR nliOll))) AND (NOT (comp_pat(4) XOR nliOlO))) AND (NOT (comp_pat(5) XOR nliOOi))) AND (NOT (comp_pat(6) XOR nliOOl))) AND (NOT (wire_nliiiO_dataout XOR wire_nl0OOl_dataout))) AND (NOT (wire_nliili_dataout XOR wire_nl0OOO_dataout))) AND (NOT (wire_nliill_dataout XOR wire_nli11i_dataout)));
	n1i0lll <= ((((((((((NOT (nliOiO XOR wire_nli00i_dataout)) AND (NOT (nliOli XOR wire_nli00l_dataout))) AND (NOT (nliOll XOR wire_nli00O_dataout))) AND (NOT (nliOlO XOR wire_nli0ii_dataout))) AND (NOT (nliOOi XOR wire_nli0il_dataout))) AND (NOT (nliOOl XOR wire_nli0iO_dataout))) AND (NOT (nliOOO XOR wire_nli0li_dataout))) AND (NOT (wire_nli0ll_dataout XOR wire_nli11O_dataout))) AND (NOT (wire_nli0lO_dataout XOR wire_nli10i_dataout))) AND (NOT (wire_nli0Oi_dataout XOR wire_nli10l_dataout)));
	n1i0llO <= ((((((((((NOT (comp_pat(0) XOR nliOiO)) AND (NOT (comp_pat(1) XOR nliOli))) AND (NOT (comp_pat(2) XOR nliOll))) AND (NOT (comp_pat(3) XOR nliOlO))) AND (NOT (comp_pat(4) XOR nliOOi))) AND (NOT (comp_pat(5) XOR nliOOl))) AND (NOT (comp_pat(6) XOR nliOOO))) AND (NOT (wire_nliiiO_dataout XOR wire_nli11O_dataout))) AND (NOT (wire_nliili_dataout XOR wire_nli10i_dataout))) AND (NOT (wire_nliill_dataout XOR wire_nli10l_dataout)));
	n1i0lOO <= ((((((((((NOT (nliOli XOR wire_nli00i_dataout)) AND (NOT (nliOll XOR wire_nli00l_dataout))) AND (NOT (nliOlO XOR wire_nli00O_dataout))) AND (NOT (nliOOi XOR wire_nli0ii_dataout))) AND (NOT (nliOOl XOR wire_nli0il_dataout))) AND (NOT (nliOOO XOR wire_nli0iO_dataout))) AND (NOT (nll11i XOR wire_nli0li_dataout))) AND (NOT (wire_nli0ll_dataout XOR wire_nli1ii_dataout))) AND (NOT (wire_nli0lO_dataout XOR wire_nli1il_dataout))) AND (NOT (wire_nli0Oi_dataout XOR wire_nli1iO_dataout)));
	n1i0O0O <= ((((((((((NOT (nliOll XOR wire_nli00i_dataout)) AND (NOT (nliOlO XOR wire_nli00l_dataout))) AND (NOT (nliOOi XOR wire_nli00O_dataout))) AND (NOT (nliOOl XOR wire_nli0ii_dataout))) AND (NOT (nliOOO XOR wire_nli0il_dataout))) AND (NOT (nll11i XOR wire_nli0iO_dataout))) AND (NOT (nll11l XOR wire_nli0li_dataout))) AND (NOT (wire_nli0ll_dataout XOR wire_nli1ll_dataout))) AND (NOT (wire_nli0lO_dataout XOR wire_nli1lO_dataout))) AND (NOT (wire_nli0Oi_dataout XOR wire_nli1Oi_dataout)));
	n1i0O1i <= ((((((((((NOT (comp_pat(0) XOR nliOli)) AND (NOT (comp_pat(1) XOR nliOll))) AND (NOT (comp_pat(2) XOR nliOlO))) AND (NOT (comp_pat(3) XOR nliOOi))) AND (NOT (comp_pat(4) XOR nliOOl))) AND (NOT (comp_pat(5) XOR nliOOO))) AND (NOT (comp_pat(6) XOR nll11i))) AND (NOT (wire_nliiiO_dataout XOR wire_nli1ii_dataout))) AND (NOT (wire_nliili_dataout XOR wire_nli1il_dataout))) AND (NOT (wire_nliill_dataout XOR wire_nli1iO_dataout)));
	n1i0Oii <= ((((((((((NOT (comp_pat(0) XOR nliOll)) AND (NOT (comp_pat(1) XOR nliOlO))) AND (NOT (comp_pat(2) XOR nliOOi))) AND (NOT (comp_pat(3) XOR nliOOl))) AND (NOT (comp_pat(4) XOR nliOOO))) AND (NOT (comp_pat(5) XOR nll11i))) AND (NOT (comp_pat(6) XOR nll11l))) AND (NOT (wire_nliiiO_dataout XOR wire_nli1ll_dataout))) AND (NOT (wire_nliili_dataout XOR wire_nli1lO_dataout))) AND (NOT (wire_nliill_dataout XOR wire_nli1Oi_dataout)));
	n1i100i <= (((((wire_nl_w_lg_w_lg_w_lg_nlilii2175w2180w2185w(0) AND nlil1O) AND nlil1l) AND nlil1i) AND nliiOO) AND nliiOl);
	n1i100l <= (wire_w_lg_w_pmadwidth_range175w2207w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w2208w(0));
	n1i100O <= ((((wire_nl_w_lg_w_lg_w_lg_nlil0l2177w2182w2187w(0) AND nlil1i) AND nliiOO) AND nliiOl) AND nl1lOi);
	n1i101i <= (pmadwidth(0) AND n1i101l);
	n1i101l <= ((((((wire_nl_w_lg_w_lg_w_lg_nlilii2175w2180w2185w(0) AND nlil1O) AND nlil1l) AND nlil1i) AND nliiOO) AND nliiOl) AND nl1lOi);
	n1i101O <= (pmadwidth(0) AND n1i100i);
	n1i10ii <= ((((wire_nl_w_lg_w_lg_w_lg_nlilii2175w2180w2185w(0) AND nlil1O) AND nlil1l) AND nlil1i) AND nliiOO);
	n1i10il <= (wire_w_lg_w_pmadwidth_range175w2202w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w2203w(0));
	n1i10iO <= (((wire_nl_w_lg_w_lg_w_lg_nlil0l2177w2182w2187w(0) AND nlil1i) AND nliiOO) AND nliiOl);
	n1i10li <= (((wire_nl_w_lg_w_lg_w_lg_nlilii2175w2180w2185w(0) AND nlil1O) AND nlil1l) AND nlil1i);
	n1i10ll <= (wire_w_lg_w_pmadwidth_range175w2197w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w2198w(0));
	n1i10lO <= ((wire_nl_w_lg_w_lg_w_lg_nlil0l2177w2182w2187w(0) AND nlil1i) AND nliiOO);
	n1i10Oi <= ((wire_nl_w_lg_w_lg_w_lg_nlilii2175w2180w2185w(0) AND nlil1O) AND nlil1l);
	n1i10Ol <= (wire_w_lg_w_pmadwidth_range175w2192w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w2193w(0));
	n1i10OO <= (wire_nl_w_lg_w_lg_w_lg_nlil0l2177w2182w2187w(0) AND nlil1i);
	n1i110i <= ((((wire_w_lg_n1i1lll2250w(0) OR n1i1lil) OR n1i1l0l) OR n1i1l1O) OR n1i1l1i);
	n1i110l <= (((wire_w_lg_n1i1lil2246w(0) OR n1i1l0l) OR n1i1l1O) OR n1i1l1i);
	n1i110O <= (wire_w_lg_n1i1l1O2244w(0) OR n1i1l1i);
	n1i111i <= (((((((wire_w_lg_n1i1O1O2268w(0) OR n1i1O1l) OR n1i1lOl) OR n1i1lll) OR n1i1lil) OR n1i1l0l) OR n1i1l1O) OR n1i1l1i);
	n1i111l <= ((((((wire_w_lg_n1i1O1l2261w(0) OR n1i1lOl) OR n1i1lll) OR n1i1lil) OR n1i1l0l) OR n1i1l1O) OR n1i1l1i);
	n1i111O <= (((((wire_w_lg_n1i1lOl2255w(0) OR n1i1lll) OR n1i1lil) OR n1i1l0l) OR n1i1l1O) OR n1i1l1i);
	n1i11ii <= (pmadwidth(0) AND n1i101l);
	n1i11il <= (pmadwidth(0) AND n1i11iO);
	n1i11iO <= ((((((((nlil0O AND nlil0l) AND nlil0i) AND nlil1O) AND nlil1l) AND nlil1i) AND nliiOO) AND nliiOl) AND nl1lOi);
	n1i11li <= ((((((nlil0i AND nlil1O) AND nlil1l) AND nlil1i) AND nliiOO) AND nliiOl) AND nl1lOi);
	n1i11ll <= (((((nlil1O AND nlil1l) AND nlil1i) AND nliiOO) AND nliiOl) AND nl1lOi);
	n1i11lO <= ((((nlil1l AND nlil1i) AND nliiOO) AND nliiOl) AND nl1lOi);
	n1i11Oi <= (((nlil1i AND nliiOO) AND nliiOl) AND nl1lOi);
	n1i11Ol <= ((nliiOO AND nliiOl) AND nl1lOi);
	n1i11OO <= (nliiOl AND nl1lOi);
	n1i1i0i <= (wire_w_lg_w_pmadwidth_range175w2176w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_nl_w_lg_nlil0l2177w(0)));
	n1i1i0l <= (wire_w_lg_w_pmadwidth_range175w219w(0) AND nlil0l);
	n1i1i0O <= (pmadwidth(0) AND nlilii);
	n1i1i1i <= (wire_nl_w_lg_w_lg_w_lg_nlilii2175w2180w2185w(0) AND nlil1O);
	n1i1i1l <= (wire_w_lg_w_pmadwidth_range175w2186w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_nl_w_lg_w_lg_w_lg_nlil0l2177w2182w2187w(0)));
	n1i1i1O <= (wire_w_lg_w_pmadwidth_range175w2181w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_nl_w_lg_w_lg_nlil0l2177w2182w(0)));
	n1i1iii <= wire_w_lg_w_pmadwidth_range175w2141w(0);
	n1i1iil <= wire_w_lg_w_pmadwidth_range175w2172w(0);
	n1i1iiO <= ((((((((nlil0O OR nlil0l) OR nlil0i) OR nlil1O) OR nlil1l) OR nlil1i) OR nliiOO) OR nliiOl) OR nl1lOi);
	n1i1ili <= ((((((nlil0i OR nlil1O) OR nlil1l) OR nlil1i) OR nliiOO) OR nliiOl) OR nl1lOi);
	n1i1ill <= (((((nlil1O OR nlil1l) OR nlil1i) OR nliiOO) OR nliiOl) OR nl1lOi);
	n1i1ilO <= ((((nlil1l OR nlil1i) OR nliiOO) OR nliiOl) OR nl1lOi);
	n1i1iOi <= (((nlil1i OR nliiOO) OR nliiOl) OR nl1lOi);
	n1i1iOl <= ((nliiOO OR nliiOl) OR nl1lOi);
	n1i1iOO <= (nliiOl OR nl1lOi);
	n1i1l0i <= (((((wire_nl_w_lg_w_lg_w_lg_nlilii2087w2094w2101w(0) OR nlil1O) OR nlil1l) OR nlil1i) OR nliiOO) OR nliiOl);
	n1i1l0l <= (wire_w_lg_w_pmadwidth_range175w2132w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n1i1l0O2133w(0)));
	n1i1l0O <= (((((((nlil0l OR nlil0i) OR nlil1O) OR nlil1l) OR nlil1i) OR nliiOO) OR nliiOl) OR nl1lOi);
	n1i1l1i <= wire_w_lg_w_pmadwidth_range175w2141w(0);
	n1i1l1l <= ((((((wire_nl_w_lg_w_lg_w_lg_nlilii2087w2094w2101w(0) OR nlil1O) OR nlil1l) OR nlil1i) OR nliiOO) OR nliiOl) OR nl1lOi);
	n1i1l1O <= wire_w_lg_w_pmadwidth_range175w2138w(0);
	n1i1lii <= ((((wire_nl_w_lg_w_lg_w_lg_nlilii2087w2094w2101w(0) OR nlil1O) OR nlil1l) OR nlil1i) OR nliiOO);
	n1i1lil <= (wire_w_lg_w_pmadwidth_range175w2125w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n1i1liO2126w(0)));
	n1i1liO <= ((((((nlil0l OR nlil0i) OR nlil1O) OR nlil1l) OR nlil1i) OR nliiOO) OR nliiOl);
	n1i1lli <= (((wire_nl_w_lg_w_lg_w_lg_nlilii2087w2094w2101w(0) OR nlil1O) OR nlil1l) OR nlil1i);
	n1i1lll <= (wire_w_lg_w_pmadwidth_range175w2118w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n1i1llO2119w(0)));
	n1i1llO <= (((((nlil0l OR nlil0i) OR nlil1O) OR nlil1l) OR nlil1i) OR nliiOO);
	n1i1lOi <= ((wire_nl_w_lg_w_lg_w_lg_nlilii2087w2094w2101w(0) OR nlil1O) OR nlil1l);
	n1i1lOl <= (wire_w_lg_w_pmadwidth_range175w2111w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n1i1lOO2112w(0)));
	n1i1lOO <= ((((nlil0l OR nlil0i) OR nlil1O) OR nlil1l) OR nlil1i);
	n1i1O0i <= (wire_w_lg_w_pmadwidth_range175w2089w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND (NOT (nlil0l OR nlil0i))));
	n1i1O0l <= (((((((NOT (wire_niOill_o XOR wire_niiO1i_w_lg_dataout2047w(0))) AND (NOT (wire_niOilO_o XOR wire_niiO1l_w_lg_dataout2050w(0)))) AND (NOT (wire_niOiOi_o XOR wire_niiO1O_w_lg_dataout2054w(0)))) AND (NOT (wire_niOiOl_o XOR wire_niiO0i_w_lg_dataout2058w(0)))) AND (NOT (wire_niOiOO_o XOR wire_niiO0l_w_lg_dataout2062w(0)))) AND (NOT (wire_niOl1i_o XOR wire_niiO0O_w_lg_dataout2066w(0)))) AND (NOT (wire_niOl1l_o XOR wire_niiOii_w_lg_dataout2070w(0))));
	n1i1O0O <= (((((((NOT (wire_niOill_o XOR wire_niiO1i_dataout)) AND (NOT (wire_niOilO_o XOR wire_niiO1l_dataout))) AND (NOT (wire_niOiOi_o XOR wire_niiO1O_dataout))) AND (NOT (wire_niOiOl_o XOR wire_niiO0i_dataout))) AND (NOT (wire_niOiOO_o XOR wire_niiO0l_dataout))) AND (NOT (wire_niOl1i_o XOR wire_niiO0O_dataout))) AND (NOT (wire_niOl1l_o XOR wire_niiOii_dataout)));
	n1i1O1i <= (wire_nl_w_lg_w_lg_w_lg_nlilii2087w2094w2101w(0) OR nlil1O);
	n1i1O1l <= (wire_w_lg_w_pmadwidth_range175w2103w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND (NOT (((nlil0l OR nlil0i) OR nlil1O) OR nlil1l))));
	n1i1O1O <= (wire_w_lg_w_pmadwidth_range175w2096w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND (NOT ((nlil0l OR nlil0i) OR nlil1O))));
	n1i1Oii <= ((((((((((NOT (wire_niOill_o XOR wire_niiO1i_w_lg_dataout2047w(0))) AND (NOT (wire_niOilO_o XOR wire_niiO1l_w_lg_dataout2050w(0)))) AND (NOT (wire_niOiOi_o XOR wire_niiO1O_w_lg_dataout2054w(0)))) AND (NOT (wire_niOiOl_o XOR wire_niiO0i_w_lg_dataout2058w(0)))) AND (NOT (wire_niOiOO_o XOR wire_niiO0l_w_lg_dataout2062w(0)))) AND (NOT (wire_niOl1i_o XOR wire_niiO0O_w_lg_dataout2066w(0)))) AND (NOT (wire_niOl1l_o XOR wire_niiOii_w_lg_dataout2070w(0)))) AND (NOT (wire_niOl1O_o XOR wire_niiOil_w_lg_dataout2074w(0)))) AND (NOT (wire_niOl0i_dataout XOR wire_niiOiO_w_lg_dataout2078w(0)))) AND (NOT (wire_niOl0l_dataout XOR wire_niiOli_w_lg_dataout2082w(0))));
	n1i1Oil <= ((((((((((NOT (wire_niOill_o XOR wire_niiO1i_dataout)) AND (NOT (wire_niOilO_o XOR wire_niiO1l_dataout))) AND (NOT (wire_niOiOi_o XOR wire_niiO1O_dataout))) AND (NOT (wire_niOiOl_o XOR wire_niiO0i_dataout))) AND (NOT (wire_niOiOO_o XOR wire_niiO0l_dataout))) AND (NOT (wire_niOl1i_o XOR wire_niiO0O_dataout))) AND (NOT (wire_niOl1l_o XOR wire_niiOii_dataout))) AND (NOT (wire_niOl1O_o XOR wire_niiOil_dataout))) AND (NOT (wire_niOl0i_dataout XOR wire_niiOiO_dataout))) AND (NOT (wire_niOl0l_dataout XOR wire_niiOli_dataout)));
	n1i1OiO <= (wire_niOl1i_o AND (wire_niOiOO_w_lg_o2973w(0) AND n1i000O));
	n1i1Oli <= (wire_niOl1i_w_lg_o2972w(0) AND (wire_niOiOO_o AND n10lO1i));
	n1i1Oll <= (wire_niOl1i_w_lg_o2972w(0) AND (wire_niOiOO_w_lg_o2973w(0) AND (wire_niOiOl_w_lg_o1205w(0) AND (wire_niOiOi_w_lg_o3108w(0) AND (wire_niOilO_o AND wire_niOill_o)))));
	n1i1OlO <= (wire_niOl1i_o AND (wire_niOiOO_o AND wire_niOiOl_w_lg_o3137w(0)));
	n1i1OOi <= ((NOT comp_pat_size(0)) AND comp_pat_size(1));
	n1i1OOl <= ((((((((((NOT ((NOT comp_pat(0)) XOR wire_nilllO_dataout)) AND (NOT ((NOT comp_pat(1)) XOR wire_nillOi_dataout))) AND (NOT ((NOT comp_pat(2)) XOR wire_nillOl_dataout))) AND (NOT ((NOT comp_pat(3)) XOR wire_nillOO_dataout))) AND (NOT ((NOT comp_pat(4)) XOR wire_nilO1i_dataout))) AND (NOT ((NOT comp_pat(5)) XOR wire_nilO1l_dataout))) AND (NOT ((NOT comp_pat(6)) XOR wire_nilO1O_dataout))) AND (NOT ((NOT comp_pat(7)) XOR wire_nilO0i_dataout))) AND (NOT ((NOT comp_pat(8)) XOR wire_nilO0l_dataout))) AND (NOT ((NOT comp_pat(9)) XOR wire_nilO0O_dataout)));
	n1i1OOO <= ((((((((((NOT (comp_pat(0) XOR wire_nilllO_dataout)) AND (NOT (comp_pat(1) XOR wire_nillOi_dataout))) AND (NOT (comp_pat(2) XOR wire_nillOl_dataout))) AND (NOT (comp_pat(3) XOR wire_nillOO_dataout))) AND (NOT (comp_pat(4) XOR wire_nilO1i_dataout))) AND (NOT (comp_pat(5) XOR wire_nilO1l_dataout))) AND (NOT (comp_pat(6) XOR wire_nilO1O_dataout))) AND (NOT (comp_pat(7) XOR wire_nilO0i_dataout))) AND (NOT (comp_pat(8) XOR wire_nilO0l_dataout))) AND (NOT (comp_pat(9) XOR wire_nilO0O_dataout)));
	n1ii00i <= (nlO0l1l AND n1ii00l);
	n1ii00l <= (wire_w_lg_w_lg_n1ii01O227w228w(0) AND wire_w_lg_n1ii1OO229w(0));
	n1ii01i <= ((((wire_w_lg_n1i0ilO447w(0) OR wire_w_lg_n1i0ill449w(0)) OR wire_w_lg_n1i0iil455w(0)) OR wire_w_lg_n1i0iii457w(0)) OR wire_w_lg_n1i0i0i462w(0));
	n1ii01l <= ((((wire_w_lg_n1i0ilO447w(0) OR wire_w_lg_n1i0ill449w(0)) OR wire_w_lg_n1i0ili451w(0)) OR wire_w_lg_n1i0iiO453w(0)) OR wire_w_lg_n1i0i0i462w(0));
	n1ii01O <= (wire_nl011O_w_lg_dataout446w(0) OR wire_w_lg_n1i0i0i462w(0));
	n1ii0iO <= (wire_w_lg_disable_rx_disp1194w(0) AND ((((wire_nl_w_lg_niii0i1195w(0) AND wire_w_lg_w1202w1203w(0)) OR wire_nl_w_lg_niii0i1208w(0)) OR (wire_w_lg_n1i01OO1211w(0) AND wire_nlOll0O_w_lg_dataout1212w(0))) OR wire_w_lg_w_lg_n1i01lO1217w1218w(0)));
	n1ii0li <= (wire_w_lg_sync_sm_dis1224w(0) AND nlO01ii);
	n1ii0Oi <= (wire_w_lg_w_pmadwidth_range175w219w(0) AND (sync_sm_dis AND nil1Ol));
	n1ii0Ol <= (sync_sm_dis AND nl10Ol);
	n1ii10i <= wire_w_lg_w_comp_pat_size_range1330w1333w(0);
	n1ii10O <= (wire_nllliil_dataout AND (NOT (wire_w_lg_w_lg_n1ii01O227w228w(0) AND wire_w_lg_n1ii1OO229w(0))));
	n1ii11i <= ((((((((((NOT (nliOlO XOR wire_nli00i_dataout)) AND (NOT (nliOOi XOR wire_nli00l_dataout))) AND (NOT (nliOOl XOR wire_nli00O_dataout))) AND (NOT (nliOOO XOR wire_nli0ii_dataout))) AND (NOT (nll11i XOR wire_nli0il_dataout))) AND (NOT (nll11l XOR wire_nli0iO_dataout))) AND (NOT (nll11O XOR wire_nli0li_dataout))) AND (NOT (wire_nli0ll_dataout XOR wire_nli1OO_dataout))) AND (NOT (wire_nli0lO_dataout XOR wire_nli01i_dataout))) AND (NOT (wire_nli0Oi_dataout XOR wire_nli01l_dataout)));
	n1ii11l <= ((((((((((NOT (comp_pat(0) XOR nliOlO)) AND (NOT (comp_pat(1) XOR nliOOi))) AND (NOT (comp_pat(2) XOR nliOOl))) AND (NOT (comp_pat(3) XOR nliOOO))) AND (NOT (comp_pat(4) XOR nll11i))) AND (NOT (comp_pat(5) XOR nll11l))) AND (NOT (comp_pat(6) XOR nll11O))) AND (NOT (wire_nliiiO_dataout XOR wire_nli1OO_dataout))) AND (NOT (wire_nliili_dataout XOR wire_nli01i_dataout))) AND (NOT (wire_nliill_dataout XOR wire_nli01l_dataout)));
	n1ii11O <= ((NOT comp_pat_size(0)) AND wire_w_lg_w_comp_pat_size_range1331w1332w(0));
	n1ii1lO <= (wire_nl_w_lg_nlO0l1l232w(0) AND (n1ii1Oi22 XOR n1ii1Oi21));
	n1ii1OO <= ((((wire_w_lg_n1i0iOi445w(0) OR wire_w_lg_n1i0ill449w(0)) OR wire_w_lg_n1i0iiO453w(0)) OR wire_w_lg_n1i0iii457w(0)) OR n1i0i0l);
	n1iii1i <= '0';
	n1iii1l <= ((wire_w_lg_w_pmadwidth_range175w219w(0) AND pmadwidth(1)) AND (n1ii0ii18 XOR n1ii0ii17));
	n1iii1O <= (wire_w_lg_w_pmadwidth_range175w219w(0) AND pmadwidth(1));
	n1iiili <= (n1OO0lO OR n1OO0ll);
	n1iiill <= (n1Oi0O OR n1Oi0l);
	n1iiilO <= (((((((n10i1OO AND n110iil) OR (n11liOi AND n110iii)) OR (n1000Ol AND n110i0O)) OR (n11iOiO AND n110i0l)) OR (n101iOi AND n110i0i)) OR (n110O1O AND n110i1O)) OR (n11O01l AND n110i1l));
	n1iiiOi <= (wire_w_lg_w_lg_w_lg_w_lg_rauto_speed_ena5w8w9w10w(0) OR (NOT (n1iiiOl6 XOR n1iiiOl5)));
	n1iil0i <= '1';
	nlOO000i <= ((((wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_w_lg_o16982w(0) AND wire_nl1lili_w_lg_w_lg_o16990w16991w(0))) OR (wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_w_lg_o16982w(0) AND wire_nl1lili_w_lg_o16993w(0)))) OR (wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_o AND nlOO1Oii))) OR wire_nl1lilO_w_lg_o17022w(0));
	nlOO000l <= (wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_w_lg_o16982w(0) AND wire_nl1lili_w_lg_w_lg_o16990w17009w(0)));
	nlOO000O <= (wire_nl1lilO_o AND (wire_nl1lill_o AND (wire_nl1lili_o AND wire_nl1liiO_o)));
	nlOO001i <= wire_nl1liOl_w_lg_w_lg_o16842w16987w(0);
	nlOO001l <= wire_nl1liOl_w_lg_o16988w(0);
	nlOO001O <= ((((wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_o AND nlOO1O0O)) OR wire_nl1lilO_w_lg_o17027w(0)) OR wire_nl1lilO_w_lg_o17030w(0)) OR wire_nl1lilO_w_lg_o17033w(0));
	nlOO00ii <= (wire_w_lg_w_ib_invalid_code_range3169w17048w(0) OR wire_w_lg_w_ib_invalid_code_range3176w17056w(0));
	nlOO00il <= (wire_nl1ll0l_o AND wire_nl1ll0i_o);
	nlOO00iO <= wire_nl1ll0l_w_lg_w_lg_o16646w16665w(0);
	nlOO00li <= wire_nl1ll0l_w_lg_o16649w(0);
	nlOO00ll <= wire_nl1ll0l_w_lg_w_lg_o16646w16647w(0);
	nlOO00lO <= (nlOO0lil AND nlOO00Ol);
	nlOO00Oi <= (wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_w_lg_o16638w(0) AND wire_nl1ll0l_w_lg_w_lg_o16646w16665w(0)));
	nlOO00Ol <= wire_nl1lliO_w_lg_o16523w(0);
	nlOO00OO <= (wire_nl1llii_o AND (wire_nl1ll0O_o AND (wire_nl1ll0l_o AND wire_nl1ll0i_o)));
	nlOO010i <= (nlOO1OOl AND nlOO1lll);
	nlOO010l <= (nlOO1l0i AND nlOO1lll);
	nlOO010O <= (nlOO1l0i AND nlOO1lli);
	nlOO011i <= (wire_nl1liOl_o AND (wire_nl1liOi_o AND wire_nl1lilO_w_lg_o17011w(0)));
	nlOO011l <= (wire_nl1ll1O_w_lg_o16853w(0) AND (wire_nl1ll1l_w_lg_o16854w(0) AND wire_nl1ll1i_w_lg_w_lg_o16855w16857w(0)));
	nlOO011O <= wire_nl1ll1O_w_lg_o16852w(0);
	nlOO01ii <= (nlOO1l0i AND nlOO1l0l);
	nlOO01il <= (nlOO1l0O AND nlOO1lli);
	nlOO01iO <= ((nlOO1l0O AND nlOO1l0l) OR (nlOO1OOi AND nlOO1l0l));
	nlOO01li <= (nlOO1l0O AND nlOO1lll);
	nlOO01ll <= (wire_nl1ll1O_w_lg_o16853w(0) AND wire_nl1ll1l_w_lg_o16854w(0));
	nlOO01lO <= ((((((wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_w_lg_o16982w(0) AND (wire_nl1lili_o AND wire_nl1liiO_o))) OR (wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_o AND nlOO1OiO))) OR (wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_o AND nlOO1Oil))) OR wire_nl1lilO_w_lg_o17004w(0)) OR wire_nl1lilO_w_lg_o17007w(0)) OR wire_nl1lilO_w_lg_o17011w(0));
	nlOO01Oi <= wire_nl1ll1i_w_lg_w_lg_o16855w16857w(0);
	nlOO01Ol <= wire_nl1ll1i_w_lg_o16850w(0);
	nlOO01OO <= (wire_nl1liOl_w_lg_o16981w(0) OR (wire_nl1liOl_w_lg_o16842w(0) AND (wire_nl1liOi_w_lg_o16843w(0) AND (wire_nl1lilO_w_lg_o16913w(0) AND wire_nl1lill_w_lg_o16982w(0)))));
	nlOO0i0i <= (wire_nl1lliO_w_lg_w_lg_o16498w16643w(0) OR wire_nl1lliO_w_lg_o16644w(0));
	nlOO0i0l <= (wire_nl1lliO_w_lg_o16498w(0) AND wire_nl1llil_w_lg_o16499w(0));
	nlOO0i0O <= ((((((wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_w_lg_o16638w(0) AND (wire_nl1ll0l_o AND wire_nl1ll0i_o))) OR (wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_o AND nlOO00ll))) OR (wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_o AND nlOO00li))) OR wire_nl1llii_w_lg_o16821w(0)) OR wire_nl1llii_w_lg_o16824w(0)) OR wire_nl1llii_w_lg_o16667w(0));
	nlOO0i1i <= (nlOO0lii AND nlOO0i0l);
	nlOO0i1l <= (((wire_w_lg_nlOO0O1O16789w(0) OR (nlOO0lii AND nlOO0i0i)) OR nlOO0O1l) OR nlOO0O0i);
	nlOO0i1O <= (wire_nl1llii_o AND nlOO00lO);
	nlOO0iii <= wire_nl1llll_w_lg_o16506w(0);
	nlOO0iil <= wire_nl1llll_w_lg_w_lg_o16511w16513w(0);
	nlOO0iiO <= wire_nl1llll_w_lg_o16718w(0);
	nlOO0ili <= wire_nl1llll_w_lg_w_lg_o16511w16717w(0);
	nlOO0ill <= (wire_nl1lllO_o XOR wire_nl1llli_o);
	nlOO0ilO <= (wire_nl1llll_w_lg_o16511w(0) AND wire_nl1llli_w_lg_w_lg_o16512w16696w(0));
	nlOO0iOi <= ((((((wire_nl1llOi_w_lg_o16509w(0) AND (wire_nl1lllO_w_lg_o16510w(0) AND wire_nl1llll_w_lg_o16506w(0))) OR (wire_nl1llOi_w_lg_o16509w(0) AND (wire_nl1lllO_o AND nlOO0ili))) OR (wire_nl1llOi_w_lg_o16509w(0) AND (wire_nl1lllO_o AND nlOO0iiO))) OR wire_nl1llOi_w_lg_o16728w(0)) OR wire_nl1llOi_w_lg_o16731w(0)) OR wire_nl1llOi_w_lg_o16734w(0));
	nlOO0iOl <= (nlOO0l0l OR nlOO0llO);
	nlOO0iOO <= (wire_nl1ll0l_o AND wire_nl1ll0i_o);
	nlOO0l0i <= ((((wire_nl1llOi_w_lg_o16509w(0) AND (wire_nl1lllO_w_lg_o16510w(0) AND wire_nl1llll_w_lg_w_lg_o16511w16717w(0))) OR (wire_nl1llOi_w_lg_o16509w(0) AND (wire_nl1lllO_w_lg_o16510w(0) AND wire_nl1llll_w_lg_o16718w(0)))) OR (wire_nl1llOi_w_lg_o16509w(0) AND (wire_nl1lllO_o AND nlOO0iil))) OR wire_nl1llOi_w_lg_o16745w(0));
	nlOO0l0l <= ((((wire_nl1llOi_w_lg_o16509w(0) AND (wire_nl1lllO_o AND nlOO0iii)) OR wire_nl1llOi_w_lg_o16750w(0)) OR wire_nl1llOi_w_lg_o16753w(0)) OR wire_nl1llOi_w_lg_o16756w(0));
	nlOO0l0O <= (wire_n1lllii_w_lg_w_lg_dataout16774w16804w(0) OR (wire_n1lllii_dataout AND nlOO0i0l));
	nlOO0l1i <= wire_nl1ll0l_w_lg_w_lg_o16646w16665w(0);
	nlOO0l1l <= wire_nl1ll0l_w_lg_o16649w(0);
	nlOO0l1O <= wire_nl1ll0l_w_lg_w_lg_o16646w16647w(0);
	nlOO0lii <= ((((wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_o AND nlOO00il)) OR wire_nl1llii_w_lg_o16836w(0)) OR wire_nl1llii_w_lg_o16686w(0)) OR wire_nl1llii_w_lg_o16689w(0));
	nlOO0lil <= ((((wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_w_lg_o16638w(0) AND wire_nl1ll0l_w_lg_w_lg_o16646w16647w(0))) OR (wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_w_lg_o16638w(0) AND wire_nl1ll0l_w_lg_o16649w(0)))) OR (wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_o AND nlOO00iO))) OR wire_nl1llii_w_lg_o16831w(0));
	nlOO0liO <= (wire_nl1lliO_w_lg_o16498w(0) AND (wire_nl1llil_w_lg_o16499w(0) AND (wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_w_lg_o16638w(0) AND (wire_nl1ll0l_o AND wire_nl1ll0i_o)))));
	nlOO0lli <= (wire_nl1lliO_o AND (wire_nl1llil_o AND wire_nl1llii_w_lg_o16667w(0)));
	nlOO0lll <= (wire_nl1llOi_w_lg_o16509w(0) AND (wire_nl1lllO_w_lg_o16510w(0) AND wire_nl1llll_w_lg_w_lg_o16511w16513w(0)));
	nlOO0llO <= wire_nl1llOi_w_lg_o16508w(0);
	nlOO0lOi <= (nlOO0lil AND nlOO0i0l);
	nlOO0lOl <= (nlOO00Oi AND nlOO0i0l);
	nlOO0lOO <= (nlOO00Oi AND nlOO0i0i);
	nlOO0O0i <= (nlOO00OO AND nlOO0i0l);
	nlOO0O0l <= (wire_nl1llOi_w_lg_o16509w(0) AND wire_nl1lllO_w_lg_o16510w(0));
	nlOO0O0O <= ((((((wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_w_lg_o16638w(0) AND (wire_nl1ll0l_o AND wire_nl1ll0i_o))) OR (wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_o AND nlOO0l1O))) OR (wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_o AND nlOO0l1l))) OR wire_nl1llii_w_lg_o16660w(0)) OR wire_nl1llii_w_lg_o16663w(0)) OR wire_nl1llii_w_lg_o16667w(0));
	nlOO0O1i <= (nlOO00Oi AND nlOO00Ol);
	nlOO0O1l <= (nlOO00OO AND nlOO0i0i);
	nlOO0O1O <= ((nlOO00OO AND nlOO00Ol) OR (nlOO0lii AND nlOO00Ol));
	nlOO0Oii <= wire_nl1llll_w_lg_w_lg_o16511w16513w(0);
	nlOO0Oil <= wire_nl1llll_w_lg_o16506w(0);
	nlOO0OiO <= (wire_nl1lliO_w_lg_o16637w(0) OR (wire_nl1lliO_w_lg_o16498w(0) AND (wire_nl1llil_w_lg_o16499w(0) AND (wire_nl1llii_w_lg_o16569w(0) AND wire_nl1ll0O_w_lg_o16638w(0)))));
	nlOO0Oli <= wire_nl1lliO_w_lg_w_lg_o16498w16643w(0);
	nlOO0Oll <= wire_nl1lliO_w_lg_o16644w(0);
	nlOO0OlO <= ((((wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_o AND nlOO0iOO)) OR wire_nl1llii_w_lg_o16683w(0)) OR wire_nl1llii_w_lg_o16686w(0)) OR wire_nl1llii_w_lg_o16689w(0));
	nlOO0OOi <= ((((wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_w_lg_o16638w(0) AND wire_nl1ll0l_w_lg_w_lg_o16646w16647w(0))) OR (wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_w_lg_o16638w(0) AND wire_nl1ll0l_w_lg_o16649w(0)))) OR (wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_o AND nlOO0l1i))) OR wire_nl1llii_w_lg_o16678w(0));
	nlOO0OOl <= (wire_nl1llii_w_lg_o16569w(0) AND (wire_nl1ll0O_w_lg_o16638w(0) AND wire_nl1ll0l_w_lg_w_lg_o16646w16665w(0)));
	nlOO0OOO <= (wire_nl1llii_o AND (wire_nl1ll0O_o AND (wire_nl1ll0l_o AND wire_nl1ll0i_o)));
	nlOO1iOl <= (wire_nl1lili_o AND wire_nl1liiO_o);
	nlOO1iOO <= wire_nl1lili_w_lg_w_lg_o16990w17009w(0);
	nlOO1l0i <= (wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_w_lg_o16982w(0) AND wire_nl1lili_w_lg_w_lg_o16990w17009w(0)));
	nlOO1l0l <= wire_nl1liOl_w_lg_o16867w(0);
	nlOO1l0O <= (wire_nl1lilO_o AND (wire_nl1lill_o AND (wire_nl1lili_o AND wire_nl1liiO_o)));
	nlOO1l1i <= wire_nl1lili_w_lg_o16993w(0);
	nlOO1l1l <= wire_nl1lili_w_lg_w_lg_o16990w16991w(0);
	nlOO1l1O <= (nlOO1OOl AND nlOO1l0l);
	nlOO1lii <= (nlOO1OOi AND nlOO1lll);
	nlOO1lil <= (((wire_w_lg_nlOO01iO17133w(0) OR (nlOO1OOi AND nlOO1lli)) OR nlOO01il) OR nlOO01li);
	nlOO1liO <= (wire_nl1lilO_o AND nlOO1l1O);
	nlOO1lli <= (wire_nl1liOl_w_lg_w_lg_o16842w16987w(0) OR wire_nl1liOl_w_lg_o16988w(0));
	nlOO1lll <= (wire_nl1liOl_w_lg_o16842w(0) AND wire_nl1liOi_w_lg_o16843w(0));
	nlOO1llO <= ((((((wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_w_lg_o16982w(0) AND (wire_nl1lili_o AND wire_nl1liiO_o))) OR (wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_o AND nlOO1l1l))) OR (wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_o AND nlOO1l1i))) OR wire_nl1lilO_w_lg_o17165w(0)) OR wire_nl1lilO_w_lg_o17168w(0)) OR wire_nl1lilO_w_lg_o17011w(0));
	nlOO1lOi <= wire_nl1ll1i_w_lg_o16850w(0);
	nlOO1lOl <= wire_nl1ll1i_w_lg_w_lg_o16855w16857w(0);
	nlOO1lOO <= wire_nl1ll1i_w_lg_o17062w(0);
	nlOO1O0i <= ((((((wire_nl1ll1O_w_lg_o16853w(0) AND (wire_nl1ll1l_w_lg_o16854w(0) AND wire_nl1ll1i_w_lg_o16850w(0))) OR (wire_nl1ll1O_w_lg_o16853w(0) AND (wire_nl1ll1l_o AND nlOO1O1i))) OR (wire_nl1ll1O_w_lg_o16853w(0) AND (wire_nl1ll1l_o AND nlOO1lOO))) OR wire_nl1ll1O_w_lg_o17072w(0)) OR wire_nl1ll1O_w_lg_o17075w(0)) OR wire_nl1ll1O_w_lg_o17078w(0));
	nlOO1O0l <= (nlOO1Oll OR nlOO011O);
	nlOO1O0O <= (wire_nl1lili_o AND wire_nl1liiO_o);
	nlOO1O1i <= wire_nl1ll1i_w_lg_w_lg_o16855w17061w(0);
	nlOO1O1l <= (wire_nl1ll1l_o XOR wire_nl1liOO_o);
	nlOO1O1O <= (wire_nl1ll1i_w_lg_o16855w(0) AND wire_nl1liOO_w_lg_w_lg_o16856w17040w(0));
	nlOO1Oii <= wire_nl1lili_w_lg_w_lg_o16990w17009w(0);
	nlOO1Oil <= wire_nl1lili_w_lg_o16993w(0);
	nlOO1OiO <= wire_nl1lili_w_lg_w_lg_o16990w16991w(0);
	nlOO1Oli <= ((((wire_nl1ll1O_w_lg_o16853w(0) AND (wire_nl1ll1l_w_lg_o16854w(0) AND wire_nl1ll1i_w_lg_w_lg_o16855w17061w(0))) OR (wire_nl1ll1O_w_lg_o16853w(0) AND (wire_nl1ll1l_w_lg_o16854w(0) AND wire_nl1ll1i_w_lg_o17062w(0)))) OR (wire_nl1ll1O_w_lg_o16853w(0) AND (wire_nl1ll1l_o AND nlOO1lOl))) OR wire_nl1ll1O_w_lg_o17089w(0));
	nlOO1Oll <= ((((wire_nl1ll1O_w_lg_o16853w(0) AND (wire_nl1ll1l_o AND nlOO1lOi)) OR wire_nl1ll1O_w_lg_o17094w(0)) OR wire_nl1ll1O_w_lg_o17097w(0)) OR wire_nl1ll1O_w_lg_o17100w(0));
	nlOO1OlO <= (wire_n1iliii_w_lg_w_lg_dataout17118w17148w(0) OR (wire_n1iliii_dataout AND nlOO1lll));
	nlOO1OOi <= ((((wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_o AND nlOO1iOl)) OR wire_nl1lilO_w_lg_o17180w(0)) OR wire_nl1lilO_w_lg_o17030w(0)) OR wire_nl1lilO_w_lg_o17033w(0));
	nlOO1OOl <= ((((wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_w_lg_o16982w(0) AND wire_nl1lili_w_lg_w_lg_o16990w16991w(0))) OR (wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_w_lg_o16982w(0) AND wire_nl1lili_w_lg_o16993w(0)))) OR (wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_o AND nlOO1iOO))) OR wire_nl1lilO_w_lg_o17175w(0));
	nlOO1OOO <= (wire_nl1liOl_w_lg_o16842w(0) AND (wire_nl1liOi_w_lg_o16843w(0) AND (wire_nl1lilO_w_lg_o16913w(0) AND (wire_nl1lill_w_lg_o16982w(0) AND (wire_nl1lili_o AND wire_nl1liiO_o)))));
	nlOOi00i <= ((((((((((wire_w_lg_w_pmadwidth_range175w15747w(0) OR wire_nl_w_lg_nlli1li15934w(0)) OR wire_nl_w_lg_nlli1iO15936w(0)) OR wire_nl_w_lg_nlli1il15938w(0)) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_nl_w_lg_nlli10O15942w(0)) OR wire_nl_w_lg_nlli10l15944w(0)) OR wire_nl_w_lg_nlli10i15955w(0)) OR wire_nl_w_lg_nlli11O15966w(0)) OR wire_nl_w_lg_nlli11l15977w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOi00l <= ((((((((((wire_w_lg_w_pmadwidth_range175w15747w(0) OR wire_nl_w_lg_nlli1iO15936w(0)) OR wire_nl_w_lg_nlli1il15938w(0)) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_nl_w_lg_nlli10O15942w(0)) OR wire_nl_w_lg_nlli10l15944w(0)) OR wire_nl_w_lg_nlli10i15955w(0)) OR wire_nl_w_lg_nlli11O15966w(0)) OR wire_nl_w_lg_nlli11l15977w(0)) OR wire_nl_w_lg_nlli11i15988w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOi00O <= ((((((((((wire_w_lg_w_pmadwidth_range175w15747w(0) OR wire_nl_w_lg_nlli1il15938w(0)) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_nl_w_lg_nlli10O15942w(0)) OR wire_nl_w_lg_nlli10l15944w(0)) OR wire_nl_w_lg_nlli10i15955w(0)) OR wire_nl_w_lg_nlli11O15966w(0)) OR wire_nl_w_lg_nlli11l15977w(0)) OR wire_nl_w_lg_nlli11i15988w(0)) OR wire_nl_w_lg_nll0OOO15999w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOi01i <= ((((((((((wire_w_lg_w_pmadwidth_range175w15747w(0) OR wire_nl_w_lg_nlli1lO15930w(0)) OR wire_nl_w_lg_nlli1ll15932w(0)) OR wire_nl_w_lg_nlli1li15934w(0)) OR wire_nl_w_lg_nlli1iO15936w(0)) OR wire_nl_w_lg_nlli1il15938w(0)) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_nl_w_lg_nlli10O15942w(0)) OR wire_nl_w_lg_nlli10l15944w(0)) OR wire_nl_w_lg_nlli10i15955w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOi01l <= ((((((((((wire_w_lg_w_pmadwidth_range175w15747w(0) OR wire_nl_w_lg_nlli1Oi15928w(0)) OR wire_nl_w_lg_nlli1lO15930w(0)) OR wire_nl_w_lg_nlli1ll15932w(0)) OR wire_nl_w_lg_nlli1li15934w(0)) OR wire_nl_w_lg_nlli1iO15936w(0)) OR wire_nl_w_lg_nlli1il15938w(0)) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_nl_w_lg_nlli10O15942w(0)) OR wire_nl_w_lg_nlli10l15944w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOi01O <= ((((((((((wire_w_lg_w_pmadwidth_range175w15747w(0) OR wire_nl_w_lg_nlli1ll15932w(0)) OR wire_nl_w_lg_nlli1li15934w(0)) OR wire_nl_w_lg_nlli1iO15936w(0)) OR wire_nl_w_lg_nlli1il15938w(0)) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_nl_w_lg_nlli10O15942w(0)) OR wire_nl_w_lg_nlli10l15944w(0)) OR wire_nl_w_lg_nlli10i15955w(0)) OR wire_nl_w_lg_nlli11O15966w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOi0ii <= ((((((((((wire_w_lg_w_pmadwidth_range175w15747w(0) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_nl_w_lg_nlli10O15942w(0)) OR wire_nl_w_lg_nlli10l15944w(0)) OR wire_nl_w_lg_nlli10i15955w(0)) OR wire_nl_w_lg_nlli11O15966w(0)) OR wire_nl_w_lg_nlli11l15977w(0)) OR wire_nl_w_lg_nlli11i15988w(0)) OR wire_nl_w_lg_nll0OOO15999w(0)) OR wire_nl_w_lg_nll0OOl16010w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOi0il <= ((((((((((((wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR wire_nl_w_lg_nlli01l16013w(0)) OR wire_nl_w_lg_nlli01i16015w(0)) OR wire_nl_w_lg_nlli1OO16017w(0)) OR wire_nl_w_lg_nlli1Ol16019w(0)) OR wire_nl_w_lg_nlli1Oi15928w(0)) OR wire_nl_w_lg_nlli1lO15930w(0)) OR wire_nl_w_lg_nlli1ll15932w(0)) OR wire_nl_w_lg_nlli1li15934w(0)) OR wire_nl_w_lg_nlli1iO15936w(0)) OR wire_nl_w_lg_nlli1il15938w(0)) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOi0iO <= ((((((((((((wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR wire_nl_w_lg_nlli01i16015w(0)) OR wire_nl_w_lg_nlli1OO16017w(0)) OR wire_nl_w_lg_nlli1Ol16019w(0)) OR wire_nl_w_lg_nlli1Oi15928w(0)) OR wire_nl_w_lg_nlli1lO15930w(0)) OR wire_nl_w_lg_nlli1ll15932w(0)) OR wire_nl_w_lg_nlli1li15934w(0)) OR wire_nl_w_lg_nlli1iO15936w(0)) OR wire_nl_w_lg_nlli1il15938w(0)) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_nl_w_lg_nlli10O15942w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOi0li <= ((((((((((((wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR wire_nl_w_lg_nlli1OO16017w(0)) OR wire_nl_w_lg_nlli1Ol16019w(0)) OR wire_nl_w_lg_nlli1Oi15928w(0)) OR wire_nl_w_lg_nlli1lO15930w(0)) OR wire_nl_w_lg_nlli1ll15932w(0)) OR wire_nl_w_lg_nlli1li15934w(0)) OR wire_nl_w_lg_nlli1iO15936w(0)) OR wire_nl_w_lg_nlli1il15938w(0)) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_nl_w_lg_nlli10O15942w(0)) OR wire_nl_w_lg_nlli10l15944w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOi0ll <= ((((((((((((wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR wire_nl_w_lg_nlli1Ol16019w(0)) OR wire_nl_w_lg_nlli1Oi15928w(0)) OR wire_nl_w_lg_nlli1lO15930w(0)) OR wire_nl_w_lg_nlli1ll15932w(0)) OR wire_nl_w_lg_nlli1li15934w(0)) OR wire_nl_w_lg_nlli1iO15936w(0)) OR wire_nl_w_lg_nlli1il15938w(0)) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_nl_w_lg_nlli10O15942w(0)) OR wire_nl_w_lg_nlli10l15944w(0)) OR wire_nl_w_lg_nlli10i15955w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOi0lO <= ((((((((((((wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR wire_nl_w_lg_nlli1Oi15928w(0)) OR wire_nl_w_lg_nlli1lO15930w(0)) OR wire_nl_w_lg_nlli1ll15932w(0)) OR wire_nl_w_lg_nlli1li15934w(0)) OR wire_nl_w_lg_nlli1iO15936w(0)) OR wire_nl_w_lg_nlli1il15938w(0)) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_nl_w_lg_nlli10O15942w(0)) OR wire_nl_w_lg_nlli10l15944w(0)) OR wire_nl_w_lg_nlli10i15955w(0)) OR wire_nl_w_lg_nlli11O15966w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOi0Oi <= ((((((((((((wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR wire_nl_w_lg_nlli1lO15930w(0)) OR wire_nl_w_lg_nlli1ll15932w(0)) OR wire_nl_w_lg_nlli1li15934w(0)) OR wire_nl_w_lg_nlli1iO15936w(0)) OR wire_nl_w_lg_nlli1il15938w(0)) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_nl_w_lg_nlli10O15942w(0)) OR wire_nl_w_lg_nlli10l15944w(0)) OR wire_nl_w_lg_nlli10i15955w(0)) OR wire_nl_w_lg_nlli11O15966w(0)) OR wire_nl_w_lg_nlli11l15977w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOi0Ol <= ((((((((((((wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR wire_nl_w_lg_nlli1ll15932w(0)) OR wire_nl_w_lg_nlli1li15934w(0)) OR wire_nl_w_lg_nlli1iO15936w(0)) OR wire_nl_w_lg_nlli1il15938w(0)) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_nl_w_lg_nlli10O15942w(0)) OR wire_nl_w_lg_nlli10l15944w(0)) OR wire_nl_w_lg_nlli10i15955w(0)) OR wire_nl_w_lg_nlli11O15966w(0)) OR wire_nl_w_lg_nlli11l15977w(0)) OR wire_nl_w_lg_nlli11i15988w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOi0OO <= ((((((((((((wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR wire_nl_w_lg_nlli1li15934w(0)) OR wire_nl_w_lg_nlli1iO15936w(0)) OR wire_nl_w_lg_nlli1il15938w(0)) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_nl_w_lg_nlli10O15942w(0)) OR wire_nl_w_lg_nlli10l15944w(0)) OR wire_nl_w_lg_nlli10i15955w(0)) OR wire_nl_w_lg_nlli11O15966w(0)) OR wire_nl_w_lg_nlli11l15977w(0)) OR wire_nl_w_lg_nlli11i15988w(0)) OR wire_nl_w_lg_nll0OOO15999w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOi10i <= (n1OO01i OR n1OO1OO);
	nlOOi10l <= ((((n1OO01O OR n1OO01l) OR n1OO01i) OR n1OO1OO) OR n1OO1Ol);
	nlOOi10O <= ((((n1OO01O OR n1OO01l) OR n1OO1Oi) OR n1OO1lO) OR n1Ol0il);
	nlOOi11i <= (wire_w_lg_w_ib_invalid_code_range3169w16704w(0) OR wire_w_lg_w_ib_invalid_code_range3176w16712w(0));
	nlOOi11l <= (n1OO1Ol OR n1Ol0il);
	nlOOi11O <= (n1OO1Oi OR n1OO1lO);
	nlOOi1ii <= (n1OO01O OR n1OO01l);
	nlOOi1il <= (wire_nl_w_lg_n011l1O16156w(0) AND wire_nl_w_lg_n011l1l16150w(0));
	nlOOi1iO <= (wire_nl_w_lg_n011l1O16156w(0) AND n011l1l);
	nlOOi1li <= (n1Ol0ii AND n1Ol00O);
	nlOOi1ll <= (wire_nl_w_lg_n0101il16151w(0) AND wire_nl_w_lg_n011l1l16150w(0));
	nlOOi1lO <= (wire_nl_w_lg_n0101il16151w(0) AND n011l1l);
	nlOOi1Oi <= ((wire_n011i1l_w_lg_w_lg_w_lg_w16485w16487w16489w16490w(0) AND wire_n0110li_w_lg_dataout16491w(0)) AND wire_n0110iO_w_lg_dataout16493w(0));
	nlOOi1Ol <= ((wire_n011i1l_w_lg_w_lg_w_lg_w16485w16487w16489w16490w(0) AND wire_n0110li_w_lg_dataout16491w(0)) AND wire_n0110iO_dataout);
	nlOOi1OO <= ((((((NOT max_rlv_sel(0)) AND (NOT max_rlv_sel(1))) AND (NOT max_rlv_sel(2))) AND (NOT max_rlv_sel(3))) AND (NOT max_rlv_sel(4))) AND (NOT max_rlv_sel(5)));
	nlOOii0i <= (wire_w_lg_w_lg_w_lg_w15774w15775w15776w15777w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOii0l <= (wire_w_lg_w_lg_w_lg_w15784w15785w15786w15787w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOii0O <= (wire_w_lg_w_lg_w_lg_w15794w15795w15796w15797w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOii1i <= ((((((((((((wire_w_lg_w_lg_w_pmadwidth_range175w219w15819w(0) OR wire_nl_w_lg_nlli1iO15936w(0)) OR wire_nl_w_lg_nlli1il15938w(0)) OR wire_nl_w_lg_nlli1ii15940w(0)) OR wire_nl_w_lg_nlli10O15942w(0)) OR wire_nl_w_lg_nlli10l15944w(0)) OR wire_nl_w_lg_nlli10i15955w(0)) OR wire_nl_w_lg_nlli11O15966w(0)) OR wire_nl_w_lg_nlli11l15977w(0)) OR wire_nl_w_lg_nlli11i15988w(0)) OR wire_nl_w_lg_nll0OOO15999w(0)) OR wire_nl_w_lg_nll0OOl16010w(0)) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOii1l <= (wire_w_lg_w_lg_w_lg_w15764w15765w15766w15767w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOii1O <= (wire_w_lg_w_lg_w_lg_w15753w15754w15755w15756w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOiiii <= (wire_w_lg_w_lg_w_lg_w15804w15805w15806w15807w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOiiil <= (wire_w_lg_w_lg_w_lg_w15814w15815w15816w15817w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOiiiO <= (wire_w_lg_w_lg_w15828w15829w15830w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOiili <= (wire_w_lg_w_lg_w15840w15841w15842w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOiill <= (wire_w_lg_w_lg_w15852w15853w15854w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOiilO <= (wire_w_lg_w_lg_w15864w15865w15866w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOiiOi <= (wire_w_lg_w_lg_w15876w15877w15878w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOiiOl <= (wire_w_lg_w_lg_w15888w15889w15890w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOiiOO <= (wire_w_lg_w_lg_w15900w15901w15902w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOil0i <= ((((((((((((((((((wire_nl_w_lg_nll0OOl16448w(0) AND wire_w_lg_nlOOO1Ol15569w(0)) AND wire_w_lg_nlOOO1Oi15551w(0)) AND wire_w_lg_nlOOO1lO15534w(0)) AND wire_w_lg_nlOOO1ll15518w(0)) AND wire_w_lg_nlOOO1li15503w(0)) AND wire_w_lg_nlOOO1iO15489w(0)) AND wire_w_lg_nlOOO1il15476w(0)) AND wire_w_lg_nlOOO1ii15464w(0)) AND wire_w_lg_nlOOO10O15453w(0)) AND wire_w_lg_nlOOO10l15443w(0)) AND wire_w_lg_nlOOO10i15434w(0)) AND wire_w_lg_nlOOO11O15426w(0)) AND wire_w_lg_nlOOO11l15419w(0)) AND wire_w_lg_nlOOO11i15413w(0)) AND wire_w_lg_nlOOlOOl15404w(0)) AND wire_w_lg_nlOOlOlO15401w(0)) AND wire_w_lg_nlOOlOli15399w(0)) AND wire_w_lg_nlOOlOiO16466w(0));
	nlOOil0l <= (((((((((wire_w_lg_nlOOiOll15588w(0) OR wire_w_lg_nlOOiOli15590w(0)) OR wire_w_lg_nlOOiOii15596w(0)) OR wire_w_lg_nlOOiO0O15597w(0)) OR wire_w_lg_nlOOiO1O15603w(0)) OR wire_w_lg_nlOOiO1l15605w(0)) OR wire_w_lg_nlOOilOl15615w(0)) OR wire_w_lg_nlOOilOi15617w(0)) OR wire_w_lg_nlOOilli15630w(0)) OR wire_w_lg_nlOOiliO15632w(0));
	nlOOil0O <= (((((((wire_w_lg_nlOOlOiO15611w(0) OR wire_w_lg_nlOOiO0O15597w(0)) OR wire_w_lg_nlOOiO0l15599w(0)) OR wire_w_lg_nlOOiO0i15601w(0)) OR wire_w_lg_nlOOilOl15615w(0)) OR wire_w_lg_nlOOilOi15617w(0)) OR wire_w_lg_nlOOillO15619w(0)) OR wire_w_lg_nlOOilll15621w(0));
	nlOOil1i <= (wire_w_lg_w_lg_w15912w15913w15914w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOil1l <= (wire_w_lg_w_lg_w15924w15925w15926w(0) OR wire_n0110il_w_lg_dataout15757w(0));
	nlOOil1O <= (((((((((wire_w_lg_nlOOiOll15588w(0) OR wire_w_lg_nlOOiOiO15592w(0)) OR wire_w_lg_nlOOiOii15596w(0)) OR wire_w_lg_nlOOiO0l15599w(0)) OR wire_w_lg_nlOOiO1O15603w(0)) OR wire_w_lg_nlOOiO1i15607w(0)) OR wire_w_lg_nlOOilOl15615w(0)) OR wire_w_lg_nlOOillO15619w(0)) OR wire_w_lg_nlOOilli15630w(0)) OR nlOOil0i);
	nlOOilii <= (((((((wire_w_lg_nlOOiOii15596w(0) OR wire_w_lg_nlOOiO0O15597w(0)) OR wire_w_lg_nlOOiO0l15599w(0)) OR wire_w_lg_nlOOiO0i15601w(0)) OR wire_w_lg_nlOOiO1O15603w(0)) OR wire_w_lg_nlOOiO1l15605w(0)) OR wire_w_lg_nlOOiO1i15607w(0)) OR wire_w_lg_nlOOilOO15609w(0));
	nlOOilil <= (((wire_w_lg_nlOOlOiO15589w(0) OR wire_w_lg_nlOOiOli15590w(0)) OR wire_w_lg_nlOOiOiO15592w(0)) OR wire_w_lg_nlOOiOil15594w(0));
	nlOOiliO <= ((((((((((((((((((nlOOO0iO OR wire_w_lg_nlOOO1Ol15569w(0)) OR nlOOO1Oi) OR nlOOO1lO) OR nlOOO1ll) OR nlOOO1li) OR nlOOO1iO) OR nlOOO1il) OR nlOOO1ii) OR nlOOO10O) OR nlOOO10l) OR nlOOO10i) OR nlOOO11O) OR nlOOO11l) OR nlOOO11i) OR nlOOlOOl) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOilli <= (((((((((((((((((nlOOO0iO OR wire_w_lg_nlOOO1Oi15551w(0)) OR nlOOO1lO) OR nlOOO1ll) OR nlOOO1li) OR nlOOO1iO) OR nlOOO1il) OR nlOOO1ii) OR nlOOO10O) OR nlOOO10l) OR nlOOO10i) OR nlOOO11O) OR nlOOO11l) OR nlOOO11i) OR nlOOlOOl) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOilll <= ((((((((((((((((nlOOO0iO OR wire_w_lg_nlOOO1lO15534w(0)) OR nlOOO1ll) OR nlOOO1li) OR nlOOO1iO) OR nlOOO1il) OR nlOOO1ii) OR nlOOO10O) OR nlOOO10l) OR nlOOO10i) OR nlOOO11O) OR nlOOO11l) OR nlOOO11i) OR nlOOlOOl) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOillO <= (((((((((((((((nlOOO0iO OR wire_w_lg_nlOOO1ll15518w(0)) OR nlOOO1li) OR nlOOO1iO) OR nlOOO1il) OR nlOOO1ii) OR nlOOO10O) OR nlOOO10l) OR nlOOO10i) OR nlOOO11O) OR nlOOO11l) OR nlOOO11i) OR nlOOlOOl) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOilOi <= ((((((((((((((nlOOO0iO OR wire_w_lg_nlOOO1li15503w(0)) OR nlOOO1iO) OR nlOOO1il) OR nlOOO1ii) OR nlOOO10O) OR nlOOO10l) OR nlOOO10i) OR nlOOO11O) OR nlOOO11l) OR nlOOO11i) OR nlOOlOOl) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOilOl <= (((((((((((((nlOOO0iO OR wire_w_lg_nlOOO1iO15489w(0)) OR nlOOO1il) OR nlOOO1ii) OR nlOOO10O) OR nlOOO10l) OR nlOOO10i) OR nlOOO11O) OR nlOOO11l) OR nlOOO11i) OR nlOOlOOl) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOilOO <= ((((((((((((nlOOO0iO OR wire_w_lg_nlOOO1il15476w(0)) OR nlOOO1ii) OR nlOOO10O) OR nlOOO10l) OR nlOOO10i) OR nlOOO11O) OR nlOOO11l) OR nlOOO11i) OR nlOOlOOl) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOiO0i <= ((((((((nlOOO0iO OR wire_w_lg_nlOOO10i15434w(0)) OR nlOOO11O) OR nlOOO11l) OR nlOOO11i) OR nlOOlOOl) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOiO0l <= (((((((nlOOO0iO OR wire_w_lg_nlOOO11O15426w(0)) OR nlOOO11l) OR nlOOO11i) OR nlOOlOOl) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOiO0O <= ((((((nlOOO0iO OR wire_w_lg_nlOOO11l15419w(0)) OR nlOOO11i) OR nlOOlOOl) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOiO1i <= (((((((((((nlOOO0iO OR wire_w_lg_nlOOO1ii15464w(0)) OR nlOOO10O) OR nlOOO10l) OR nlOOO10i) OR nlOOO11O) OR nlOOO11l) OR nlOOO11i) OR nlOOlOOl) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOiO1l <= ((((((((((nlOOO0iO OR wire_w_lg_nlOOO10O15453w(0)) OR nlOOO10l) OR nlOOO10i) OR nlOOO11O) OR nlOOO11l) OR nlOOO11i) OR nlOOlOOl) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOiO1O <= (((((((((nlOOO0iO OR wire_w_lg_nlOOO10l15443w(0)) OR nlOOO10i) OR nlOOO11O) OR nlOOO11l) OR nlOOO11i) OR nlOOlOOl) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOiOii <= (((((nlOOO0iO OR wire_w_lg_nlOOO11i15413w(0)) OR nlOOlOOl) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOiOil <= ((((wire_w_lg_nlOOO0iO15408w(0) OR nlOOlOOl) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOiOiO <= (((wire_w_lg_nlOOlOOl15404w(0) OR nlOOlOlO) OR nlOOlOli) OR nlOOlOiO);
	nlOOiOli <= ((wire_w_lg_nlOOlOlO15401w(0) OR nlOOlOli) OR nlOOlOiO);
	nlOOiOll <= (wire_w_lg_nlOOlOli15399w(0) OR nlOOlOiO);
	nlOOiOlO <= (((((((((wire_w_lg_nlOOl00l15344w(0) OR wire_w_lg_nlOOl01O15348w(0)) OR wire_w_lg_nlOOl01i15352w(0)) OR wire_w_lg_nlOOl1Ol15355w(0)) OR wire_w_lg_nlOOl1lO15359w(0)) OR wire_w_lg_nlOOl1li15363w(0)) OR wire_w_lg_nlOOl1il15371w(0)) OR wire_w_lg_nlOOl10O15375w(0)) OR wire_w_lg_nlOOl10i15386w(0)) OR nlOOiOOi);
	nlOOiOOi <= ((((((((((((((((((((nlOOOO1O OR nlOOOO1l) AND wire_w_lg_nlOOOO1i15325w(0)) AND wire_w_lg_nlOOOlOO15307w(0)) AND wire_w_lg_nlOOOlOl15290w(0)) AND wire_w_lg_nlOOOlll15274w(0)) AND wire_w_lg_nlOOOlil15259w(0)) AND wire_w_lg_nlOOOl0l15245w(0)) AND wire_w_lg_nlOOOl1l15232w(0)) AND wire_w_lg_nlOOOiOl15220w(0)) AND wire_w_lg_nlOOOill15209w(0)) AND wire_w_lg_nlOOOiil15199w(0)) AND wire_w_lg_nlOOOi0l15190w(0)) AND wire_w_lg_nlOOOi1l15182w(0)) AND wire_w_lg_nlOOO0Ol15175w(0)) AND wire_w_lg_nlOOO0ll15169w(0)) AND wire_w_lg_nlOOO0il15164w(0)) AND wire_w_lg_nlOOO00O15160w(0)) AND wire_w_lg_nlOOO00i15157w(0)) AND wire_w_lg_nlOOO01l15155w(0)) AND wire_w_lg_nlOOO1OO16446w(0));
	nlOOiOOl <= (((((((((wire_w_lg_nlOOl00l15344w(0) OR wire_w_lg_nlOOl00i15346w(0)) OR wire_w_lg_nlOOl01i15352w(0)) OR wire_w_lg_nlOOl1OO15353w(0)) OR wire_w_lg_nlOOl1lO15359w(0)) OR wire_w_lg_nlOOl1ll15361w(0)) OR wire_w_lg_nlOOl1il15371w(0)) OR wire_w_lg_nlOOl1ii15373w(0)) OR wire_w_lg_nlOOl10i15386w(0)) OR wire_w_lg_nlOOl11O15388w(0));
	nlOOiOOO <= (((((((wire_w_lg_nlOOO1OO15367w(0) OR wire_w_lg_nlOOl1OO15353w(0)) OR wire_w_lg_nlOOl1Ol15355w(0)) OR wire_w_lg_nlOOl1Oi15357w(0)) OR wire_w_lg_nlOOl1il15371w(0)) OR wire_w_lg_nlOOl1ii15373w(0)) OR wire_w_lg_nlOOl10O15375w(0)) OR wire_w_lg_nlOOl10l15377w(0));
	nlOOl00i <= ((wire_w_lg_nlOOO00i15157w(0) OR nlOOO01l) OR nlOOO1OO);
	nlOOl00l <= (wire_w_lg_nlOOO01l15155w(0) OR nlOOO1OO);
	nlOOl00O <= (((((((((wire_w_lg_nlOOliOl15100w(0) OR wire_w_lg_nlOOlilO15104w(0)) OR wire_w_lg_nlOOlili15108w(0)) OR wire_w_lg_nlOOliil15111w(0)) OR wire_w_lg_nlOOli0O15115w(0)) OR wire_w_lg_nlOOli0i15119w(0)) OR wire_w_lg_nlOOli1l15127w(0)) OR wire_w_lg_nlOOl0OO15131w(0)) OR wire_w_lg_nlOOl0Oi15142w(0)) OR nlOOl0ii);
	nlOOl01i <= (((((wire_w_lg_nlOOO0ll15169w(0) OR nlOOO0il) OR nlOOO00O) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOl01l <= ((((wire_w_lg_nlOOO0il15164w(0) OR nlOOO00O) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOl01O <= (((wire_w_lg_nlOOO00O15160w(0) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOl0ii <= ((((wire_nl_w16422w(0) AND wire_w_lg_nlOOOOiO14918w(0)) AND wire_w_lg_nlOOOOii14915w(0)) AND wire_w_lg_nlOOOO0l14913w(0)) AND wire_w_lg_nlOOOO0i16426w(0));
	nlOOl0il <= (((((((((wire_w_lg_nlOOliOl15100w(0) OR wire_w_lg_nlOOliOi15102w(0)) OR wire_w_lg_nlOOlili15108w(0)) OR wire_w_lg_nlOOliiO15109w(0)) OR wire_w_lg_nlOOli0O15115w(0)) OR wire_w_lg_nlOOli0l15117w(0)) OR wire_w_lg_nlOOli1l15127w(0)) OR wire_w_lg_nlOOli1i15129w(0)) OR wire_w_lg_nlOOl0Oi15142w(0)) OR wire_w_lg_nlOOl0lO15144w(0));
	nlOOl0iO <= (((((((wire_w_lg_nlOOOO0i15123w(0) OR wire_w_lg_nlOOliiO15109w(0)) OR wire_w_lg_nlOOliil15111w(0)) OR wire_w_lg_nlOOliii15113w(0)) OR wire_w_lg_nlOOli1l15127w(0)) OR wire_w_lg_nlOOli1i15129w(0)) OR wire_w_lg_nlOOl0OO15131w(0)) OR wire_w_lg_nlOOl0Ol15133w(0));
	nlOOl0li <= (((((((wire_w_lg_nlOOlili15108w(0) OR wire_w_lg_nlOOliiO15109w(0)) OR wire_w_lg_nlOOliil15111w(0)) OR wire_w_lg_nlOOliii15113w(0)) OR wire_w_lg_nlOOli0O15115w(0)) OR wire_w_lg_nlOOli0l15117w(0)) OR wire_w_lg_nlOOli0i15119w(0)) OR wire_w_lg_nlOOli1O15121w(0));
	nlOOl0ll <= (((wire_w_lg_nlOOOO0i15101w(0) OR wire_w_lg_nlOOliOi15102w(0)) OR wire_w_lg_nlOOlilO15104w(0)) OR wire_w_lg_nlOOlill15106w(0));
	nlOOl0lO <= (((((((((((((((((wire_w_lg_w_lg_n11100i14248w15081w(0) OR wire_w_lg_n1111il15082w(0)) OR wire_w_lg_n1111ii15064w(0)) OR wire_w_lg_n11110O15047w(0)) OR wire_w_lg_n11110l15031w(0)) OR wire_w_lg_n11110i15016w(0)) OR wire_w_lg_n11111O15002w(0)) OR wire_w_lg_n11111l14989w(0)) OR wire_w_lg_n11111i14977w(0)) OR wire_w_lg_nlOOOOOO14966w(0)) OR wire_w_lg_nlOOOOOl14956w(0)) OR wire_w_lg_nlOOOOOi14947w(0)) OR wire_w_lg_nlOOOOlO14939w(0)) OR wire_w_lg_nlOOOOll14932w(0)) OR nlOOOOiO) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOl0Oi <= ((((((((((((((((wire_w_lg_w_lg_n11100i14248w15063w(0) OR wire_w_lg_n1111ii15064w(0)) OR wire_w_lg_n11110O15047w(0)) OR wire_w_lg_n11110l15031w(0)) OR wire_w_lg_n11110i15016w(0)) OR wire_w_lg_n11111O15002w(0)) OR wire_w_lg_n11111l14989w(0)) OR wire_w_lg_n11111i14977w(0)) OR wire_w_lg_nlOOOOOO14966w(0)) OR wire_w_lg_nlOOOOOl14956w(0)) OR wire_w_lg_nlOOOOOi14947w(0)) OR wire_w_lg_nlOOOOlO14939w(0)) OR wire_w_lg_nlOOOOll14932w(0)) OR nlOOOOiO) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOl0Ol <= (((((((((((((((wire_w_lg_w_lg_n11100i14248w15046w(0) OR wire_w_lg_n11110O15047w(0)) OR wire_w_lg_n11110l15031w(0)) OR wire_w_lg_n11110i15016w(0)) OR wire_w_lg_n11111O15002w(0)) OR wire_w_lg_n11111l14989w(0)) OR wire_w_lg_n11111i14977w(0)) OR wire_w_lg_nlOOOOOO14966w(0)) OR wire_w_lg_nlOOOOOl14956w(0)) OR wire_w_lg_nlOOOOOi14947w(0)) OR wire_w_lg_nlOOOOlO14939w(0)) OR wire_w_lg_nlOOOOll14932w(0)) OR nlOOOOiO) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOl0OO <= ((((((((((((((wire_w_lg_w_lg_n11100i14248w15030w(0) OR wire_w_lg_n11110l15031w(0)) OR wire_w_lg_n11110i15016w(0)) OR wire_w_lg_n11111O15002w(0)) OR wire_w_lg_n11111l14989w(0)) OR wire_w_lg_n11111i14977w(0)) OR wire_w_lg_nlOOOOOO14966w(0)) OR wire_w_lg_nlOOOOOl14956w(0)) OR wire_w_lg_nlOOOOOi14947w(0)) OR wire_w_lg_nlOOOOlO14939w(0)) OR wire_w_lg_nlOOOOll14932w(0)) OR nlOOOOiO) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOl10i <= (((((((((((((((((wire_w_lg_nlOOOlOO15307w(0) OR nlOOOlOl) OR nlOOOlll) OR nlOOOlil) OR nlOOOl0l) OR nlOOOl1l) OR nlOOOiOl) OR nlOOOill) OR nlOOOiil) OR nlOOOi0l) OR nlOOOi1l) OR nlOOO0Ol) OR nlOOO0ll) OR nlOOO0il) OR nlOOO00O) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOl10l <= ((((((((((((((((wire_w_lg_nlOOOlOl15290w(0) OR nlOOOlll) OR nlOOOlil) OR nlOOOl0l) OR nlOOOl1l) OR nlOOOiOl) OR nlOOOill) OR nlOOOiil) OR nlOOOi0l) OR nlOOOi1l) OR nlOOO0Ol) OR nlOOO0ll) OR nlOOO0il) OR nlOOO00O) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOl10O <= (((((((((((((((wire_w_lg_nlOOOlll15274w(0) OR nlOOOlil) OR nlOOOl0l) OR nlOOOl1l) OR nlOOOiOl) OR nlOOOill) OR nlOOOiil) OR nlOOOi0l) OR nlOOOi1l) OR nlOOO0Ol) OR nlOOO0ll) OR nlOOO0il) OR nlOOO00O) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOl11i <= (((((((wire_w_lg_nlOOl01i15352w(0) OR wire_w_lg_nlOOl1OO15353w(0)) OR wire_w_lg_nlOOl1Ol15355w(0)) OR wire_w_lg_nlOOl1Oi15357w(0)) OR wire_w_lg_nlOOl1lO15359w(0)) OR wire_w_lg_nlOOl1ll15361w(0)) OR wire_w_lg_nlOOl1li15363w(0)) OR wire_w_lg_nlOOl1iO15365w(0));
	nlOOl11l <= (((wire_w_lg_nlOOO1OO15345w(0) OR wire_w_lg_nlOOl00i15346w(0)) OR wire_w_lg_nlOOl01O15348w(0)) OR wire_w_lg_nlOOl01l15350w(0));
	nlOOl11O <= ((((((((((((((((((wire_w_lg_nlOOOO1i15325w(0) OR nlOOOlOO) OR nlOOOlOl) OR nlOOOlll) OR nlOOOlil) OR nlOOOl0l) OR nlOOOl1l) OR nlOOOiOl) OR nlOOOill) OR nlOOOiil) OR nlOOOi0l) OR nlOOOi1l) OR nlOOO0Ol) OR nlOOO0ll) OR nlOOO0il) OR nlOOO00O) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOl1ii <= ((((((((((((((wire_w_lg_nlOOOlil15259w(0) OR nlOOOl0l) OR nlOOOl1l) OR nlOOOiOl) OR nlOOOill) OR nlOOOiil) OR nlOOOi0l) OR nlOOOi1l) OR nlOOO0Ol) OR nlOOO0ll) OR nlOOO0il) OR nlOOO00O) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOl1il <= (((((((((((((wire_w_lg_nlOOOl0l15245w(0) OR nlOOOl1l) OR nlOOOiOl) OR nlOOOill) OR nlOOOiil) OR nlOOOi0l) OR nlOOOi1l) OR nlOOO0Ol) OR nlOOO0ll) OR nlOOO0il) OR nlOOO00O) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOl1iO <= ((((((((((((wire_w_lg_nlOOOl1l15232w(0) OR nlOOOiOl) OR nlOOOill) OR nlOOOiil) OR nlOOOi0l) OR nlOOOi1l) OR nlOOO0Ol) OR nlOOO0ll) OR nlOOO0il) OR nlOOO00O) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOl1li <= (((((((((((wire_w_lg_nlOOOiOl15220w(0) OR nlOOOill) OR nlOOOiil) OR nlOOOi0l) OR nlOOOi1l) OR nlOOO0Ol) OR nlOOO0ll) OR nlOOO0il) OR nlOOO00O) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOl1ll <= ((((((((((wire_w_lg_nlOOOill15209w(0) OR nlOOOiil) OR nlOOOi0l) OR nlOOOi1l) OR nlOOO0Ol) OR nlOOO0ll) OR nlOOO0il) OR nlOOO00O) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOl1lO <= (((((((((wire_w_lg_nlOOOiil15199w(0) OR nlOOOi0l) OR nlOOOi1l) OR nlOOO0Ol) OR nlOOO0ll) OR nlOOO0il) OR nlOOO00O) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOl1Oi <= ((((((((wire_w_lg_nlOOOi0l15190w(0) OR nlOOOi1l) OR nlOOO0Ol) OR nlOOO0ll) OR nlOOO0il) OR nlOOO00O) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOl1Ol <= (((((((wire_w_lg_nlOOOi1l15182w(0) OR nlOOO0Ol) OR nlOOO0ll) OR nlOOO0il) OR nlOOO00O) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOl1OO <= ((((((wire_w_lg_nlOOO0Ol15175w(0) OR nlOOO0ll) OR nlOOO0il) OR nlOOO00O) OR nlOOO00i) OR nlOOO01l) OR nlOOO1OO);
	nlOOli0i <= ((((((((((wire_w_lg_w_lg_n11100i14248w14976w(0) OR wire_w_lg_n11111i14977w(0)) OR wire_w_lg_nlOOOOOO14966w(0)) OR wire_w_lg_nlOOOOOl14956w(0)) OR wire_w_lg_nlOOOOOi14947w(0)) OR wire_w_lg_nlOOOOlO14939w(0)) OR wire_w_lg_nlOOOOll14932w(0)) OR nlOOOOiO) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOli0l <= (((((((((wire_w_lg_w_lg_n11100i14248w14965w(0) OR wire_w_lg_nlOOOOOO14966w(0)) OR wire_w_lg_nlOOOOOl14956w(0)) OR wire_w_lg_nlOOOOOi14947w(0)) OR wire_w_lg_nlOOOOlO14939w(0)) OR wire_w_lg_nlOOOOll14932w(0)) OR nlOOOOiO) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOli0O <= ((((((((wire_w_lg_w_lg_n11100i14248w14955w(0) OR wire_w_lg_nlOOOOOl14956w(0)) OR wire_w_lg_nlOOOOOi14947w(0)) OR wire_w_lg_nlOOOOlO14939w(0)) OR wire_w_lg_nlOOOOll14932w(0)) OR nlOOOOiO) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOli1i <= (((((((((((((wire_w_lg_w_lg_n11100i14248w15015w(0) OR wire_w_lg_n11110i15016w(0)) OR wire_w_lg_n11111O15002w(0)) OR wire_w_lg_n11111l14989w(0)) OR wire_w_lg_n11111i14977w(0)) OR wire_w_lg_nlOOOOOO14966w(0)) OR wire_w_lg_nlOOOOOl14956w(0)) OR wire_w_lg_nlOOOOOi14947w(0)) OR wire_w_lg_nlOOOOlO14939w(0)) OR wire_w_lg_nlOOOOll14932w(0)) OR nlOOOOiO) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOli1l <= ((((((((((((wire_w_lg_w_lg_n11100i14248w15001w(0) OR wire_w_lg_n11111O15002w(0)) OR wire_w_lg_n11111l14989w(0)) OR wire_w_lg_n11111i14977w(0)) OR wire_w_lg_nlOOOOOO14966w(0)) OR wire_w_lg_nlOOOOOl14956w(0)) OR wire_w_lg_nlOOOOOi14947w(0)) OR wire_w_lg_nlOOOOlO14939w(0)) OR wire_w_lg_nlOOOOll14932w(0)) OR nlOOOOiO) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOli1O <= (((((((((((wire_w_lg_w_lg_n11100i14248w14988w(0) OR wire_w_lg_n11111l14989w(0)) OR wire_w_lg_n11111i14977w(0)) OR wire_w_lg_nlOOOOOO14966w(0)) OR wire_w_lg_nlOOOOOl14956w(0)) OR wire_w_lg_nlOOOOOi14947w(0)) OR wire_w_lg_nlOOOOlO14939w(0)) OR wire_w_lg_nlOOOOll14932w(0)) OR nlOOOOiO) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOliii <= (((((((wire_w_lg_w_lg_n11100i14248w14946w(0) OR wire_w_lg_nlOOOOOi14947w(0)) OR wire_w_lg_nlOOOOlO14939w(0)) OR wire_w_lg_nlOOOOll14932w(0)) OR nlOOOOiO) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOliil <= ((((((wire_w_lg_w_lg_n11100i14248w14938w(0) OR wire_w_lg_nlOOOOlO14939w(0)) OR wire_w_lg_nlOOOOll14932w(0)) OR nlOOOOiO) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOliiO <= (((((wire_w_lg_w_lg_n11100i14248w14931w(0) OR wire_w_lg_nlOOOOll14932w(0)) OR nlOOOOiO) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOlili <= (((((wire_w_lg_n11100i14248w(0) OR nlOOOOll) OR nlOOOOiO) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOlill <= ((((n11100i OR nlOOOOiO) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOlilO <= (((wire_w_lg_nlOOOOiO14918w(0) OR nlOOOOii) OR nlOOOO0l) OR nlOOOO0i);
	nlOOliOi <= ((wire_w_lg_nlOOOOii14915w(0) OR nlOOOO0l) OR nlOOOO0i);
	nlOOliOl <= (wire_w_lg_nlOOOO0l14913w(0) OR nlOOOO0i);
	nlOOliOO <= (((((((((wire_w_lg_nlOOlOil14858w(0) OR wire_w_lg_nlOOlO0O14862w(0)) OR wire_w_lg_nlOOlO0i14866w(0)) OR wire_w_lg_nlOOlO1l14869w(0)) OR wire_w_lg_nlOOllOO14873w(0)) OR wire_w_lg_nlOOllOi14877w(0)) OR wire_w_lg_nlOOllll14885w(0)) OR wire_w_lg_nlOOlliO14889w(0)) OR wire_w_lg_nlOOllii14900w(0)) OR nlOOll1i);
	nlOOll0i <= (((((((wire_w_lg_nlOOlO0i14866w(0) OR wire_w_lg_nlOOlO1O14867w(0)) OR wire_w_lg_nlOOlO1l14869w(0)) OR wire_w_lg_nlOOlO1i14871w(0)) OR wire_w_lg_nlOOllOO14873w(0)) OR wire_w_lg_nlOOllOl14875w(0)) OR wire_w_lg_nlOOllOi14877w(0)) OR wire_w_lg_nlOOlllO14879w(0));
	nlOOll0l <= (((wire_w_lg_n1111li14859w(0) OR wire_w_lg_nlOOlOii14860w(0)) OR wire_w_lg_nlOOlO0O14862w(0)) OR wire_w_lg_nlOOlO0l14864w(0));
	nlOOll0O <= ((((((((((((((((((wire_w_lg_n111lll14839w(0) OR n111lli) OR n111liO) OR n111l0O) OR n111l1O) OR n111iOO) OR n111ilO) OR n111iiO) OR n111i0O) OR n111i1O) OR n1110OO) OR n1110lO) OR n1110iO) OR n11100O) OR n11101O) OR n11101i) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOll1i <= ((((((((((((((((((((wire_w_lg_w_pmadwidth_range175w16385w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_nl_w_lg_nlli1Ol16019w(0))) AND wire_w_lg_n111lll14839w(0)) AND wire_w_lg_n111lli14821w(0)) AND wire_w_lg_n111liO14804w(0)) AND wire_w_lg_n111l0O14788w(0)) AND wire_w_lg_n111l1O14773w(0)) AND wire_w_lg_n111iOO14759w(0)) AND wire_w_lg_n111ilO14746w(0)) AND wire_w_lg_n111iiO14734w(0)) AND wire_w_lg_n111i0O14723w(0)) AND wire_w_lg_n111i1O14713w(0)) AND wire_w_lg_n1110OO14704w(0)) AND wire_w_lg_n1110lO14696w(0)) AND wire_w_lg_n1110iO14689w(0)) AND wire_w_lg_n11100O14683w(0)) AND wire_w_lg_n11101O14678w(0)) AND wire_w_lg_n11101i14674w(0)) AND wire_w_lg_n1111Ol14671w(0)) AND wire_w_lg_n1111lO14669w(0)) AND wire_w_lg_n1111li16406w(0));
	nlOOll1l <= (((((((((wire_w_lg_nlOOlOil14858w(0) OR wire_w_lg_nlOOlOii14860w(0)) OR wire_w_lg_nlOOlO0i14866w(0)) OR wire_w_lg_nlOOlO1O14867w(0)) OR wire_w_lg_nlOOllOO14873w(0)) OR wire_w_lg_nlOOllOl14875w(0)) OR wire_w_lg_nlOOllll14885w(0)) OR wire_w_lg_nlOOllli14887w(0)) OR wire_w_lg_nlOOllii14900w(0)) OR wire_w_lg_nlOOll0O14902w(0));
	nlOOll1O <= (((((((wire_w_lg_n1111li14881w(0) OR wire_w_lg_nlOOlO1O14867w(0)) OR wire_w_lg_nlOOlO1l14869w(0)) OR wire_w_lg_nlOOlO1i14871w(0)) OR wire_w_lg_nlOOllll14885w(0)) OR wire_w_lg_nlOOllli14887w(0)) OR wire_w_lg_nlOOlliO14889w(0)) OR wire_w_lg_nlOOllil14891w(0));
	nlOOllii <= (((((((((((((((((wire_w_lg_n111lli14821w(0) OR n111liO) OR n111l0O) OR n111l1O) OR n111iOO) OR n111ilO) OR n111iiO) OR n111i0O) OR n111i1O) OR n1110OO) OR n1110lO) OR n1110iO) OR n11100O) OR n11101O) OR n11101i) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOllil <= ((((((((((((((((wire_w_lg_n111liO14804w(0) OR n111l0O) OR n111l1O) OR n111iOO) OR n111ilO) OR n111iiO) OR n111i0O) OR n111i1O) OR n1110OO) OR n1110lO) OR n1110iO) OR n11100O) OR n11101O) OR n11101i) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOlliO <= (((((((((((((((wire_w_lg_n111l0O14788w(0) OR n111l1O) OR n111iOO) OR n111ilO) OR n111iiO) OR n111i0O) OR n111i1O) OR n1110OO) OR n1110lO) OR n1110iO) OR n11100O) OR n11101O) OR n11101i) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOllli <= ((((((((((((((wire_w_lg_n111l1O14773w(0) OR n111iOO) OR n111ilO) OR n111iiO) OR n111i0O) OR n111i1O) OR n1110OO) OR n1110lO) OR n1110iO) OR n11100O) OR n11101O) OR n11101i) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOllll <= (((((((((((((wire_w_lg_n111iOO14759w(0) OR n111ilO) OR n111iiO) OR n111i0O) OR n111i1O) OR n1110OO) OR n1110lO) OR n1110iO) OR n11100O) OR n11101O) OR n11101i) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOlllO <= ((((((((((((wire_w_lg_n111ilO14746w(0) OR n111iiO) OR n111i0O) OR n111i1O) OR n1110OO) OR n1110lO) OR n1110iO) OR n11100O) OR n11101O) OR n11101i) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOllOi <= (((((((((((wire_w_lg_n111iiO14734w(0) OR n111i0O) OR n111i1O) OR n1110OO) OR n1110lO) OR n1110iO) OR n11100O) OR n11101O) OR n11101i) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOllOl <= ((((((((((wire_w_lg_n111i0O14723w(0) OR n111i1O) OR n1110OO) OR n1110lO) OR n1110iO) OR n11100O) OR n11101O) OR n11101i) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOllOO <= (((((((((wire_w_lg_n111i1O14713w(0) OR n1110OO) OR n1110lO) OR n1110iO) OR n11100O) OR n11101O) OR n11101i) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOlO0i <= (((((wire_w_lg_n11100O14683w(0) OR n11101O) OR n11101i) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOlO0l <= ((((wire_w_lg_n11101O14678w(0) OR n11101i) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOlO0O <= (((wire_w_lg_n11101i14674w(0) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOlO1i <= ((((((((wire_w_lg_n1110OO14704w(0) OR n1110lO) OR n1110iO) OR n11100O) OR n11101O) OR n11101i) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOlO1l <= (((((((wire_w_lg_n1110lO14696w(0) OR n1110iO) OR n11100O) OR n11101O) OR n11101i) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOlO1O <= ((((((wire_w_lg_n1110iO14689w(0) OR n11100O) OR n11101O) OR n11101i) OR n1111Ol) OR n1111lO) OR n1111li);
	nlOOlOii <= ((wire_w_lg_n1111Ol14671w(0) OR n1111lO) OR n1111li);
	nlOOlOil <= (wire_w_lg_n1111lO14669w(0) OR n1111li);
	nlOOlOiO <= (pmadwidth(0) AND nlOOO01i);
	nlOOlOli <= (pmadwidth(0) AND nlOOlOll);
	nlOOlOll <= ((((((((((((((((((nlli01l AND nlli01i) AND nlli1OO) AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOlOlO <= (pmadwidth(0) AND nlOOlOOi);
	nlOOlOOi <= (((((((((((((((((nlli01i AND nlli1OO) AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOlOOl <= (pmadwidth(0) AND nlOOlOOO);
	nlOOlOOO <= ((((((((((((((((nlli1OO AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOO00i <= (pmadwidth(0) AND nlOOO00l);
	nlOOO00l <= ((((((((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i);
	nlOOO00O <= (pmadwidth(0) AND nlOOO0ii);
	nlOOO01i <= ((((((((((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOO01l <= (pmadwidth(0) AND nlOOO01O);
	nlOOO01O <= (((((((((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO);
	nlOOO0ii <= (((((((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l);
	nlOOO0il <= (wire_w_lg_w_pmadwidth_range175w14499w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w14500w(0));
	nlOOO0iO <= ((((((((((((wire_nl_w_lg_w_lg_w_lg_nlli1Ol14429w14434w14439w(0) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOO0li <= ((((((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O);
	nlOOO0ll <= (wire_w_lg_w_pmadwidth_range175w14494w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w14495w(0));
	nlOOO0lO <= (((((((((((wire_nl_w_lg_w_lg_w_lg_nlli1Ol14429w14434w14439w(0) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO);
	nlOOO0Oi <= (((((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i);
	nlOOO0Ol <= (wire_w_lg_w_pmadwidth_range175w14489w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w14490w(0));
	nlOOO0OO <= ((((((((((wire_nl_w_lg_w_lg_w_lg_nlli1Ol14429w14434w14439w(0) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i);
	nlOOO10i <= (((((((((((nlli1li AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOO10l <= ((((((((((nlli1iO AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOO10O <= (((((((((nlli1il AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOO11i <= ((((((((((((((nlli1Oi AND nlli1lO) AND nlli1ll) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOO11l <= (((((((((((((nlli1lO AND nlli1ll) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOO11O <= ((((((((((((nlli1ll AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOO1ii <= ((((((((nlli1ii AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOO1il <= (((((((nlli10O AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOO1iO <= ((((((nlli10l AND nlli10i) AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOO1li <= (((((nlli10i AND nlli11O) AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOO1ll <= ((((nlli11O AND nlli11l) AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOO1lO <= (((nlli11l AND nlli11i) AND nll0OOO) AND nll0OOl);
	nlOOO1Oi <= ((nlli11i AND nll0OOO) AND nll0OOl);
	nlOOO1Ol <= (nll0OOO AND nll0OOl);
	nlOOO1OO <= (pmadwidth(0) AND nlOOO01i);
	nlOOOi0i <= (((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O);
	nlOOOi0l <= (wire_w_lg_w_pmadwidth_range175w14479w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w14480w(0));
	nlOOOi0O <= ((((((((wire_nl_w_lg_w_lg_w_lg_nlli1Ol14429w14434w14439w(0) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O);
	nlOOOi1i <= ((((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l);
	nlOOOi1l <= (wire_w_lg_w_pmadwidth_range175w14484w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w14485w(0));
	nlOOOi1O <= (((((((((wire_nl_w_lg_w_lg_w_lg_nlli1Ol14429w14434w14439w(0) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i) AND nlli11O) AND nlli11l);
	nlOOOiii <= ((((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii);
	nlOOOiil <= (wire_w_lg_w_pmadwidth_range175w14474w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w14475w(0));
	nlOOOiiO <= (((((((wire_nl_w_lg_w_lg_w_lg_nlli1Ol14429w14434w14439w(0) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l) AND nlli10i);
	nlOOOili <= (((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll) AND nlli1li) AND nlli1iO) AND nlli1il);
	nlOOOill <= (wire_w_lg_w_pmadwidth_range175w14469w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w14470w(0));
	nlOOOilO <= ((((((wire_nl_w_lg_w_lg_w_lg_nlli1Ol14429w14434w14439w(0) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O) AND nlli10l);
	nlOOOiOi <= ((((((wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll) AND nlli1li) AND nlli1iO);
	nlOOOiOl <= (wire_w_lg_w_pmadwidth_range175w14464w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w14465w(0));
	nlOOOiOO <= (((((wire_nl_w_lg_w_lg_w_lg_nlli1Ol14429w14434w14439w(0) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii) AND nlli10O);
	nlOOOl0i <= ((((wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll);
	nlOOOl0l <= (wire_w_lg_w_pmadwidth_range175w14454w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w14455w(0));
	nlOOOl0O <= (((wire_nl_w_lg_w_lg_w_lg_nlli1Ol14429w14434w14439w(0) AND nlli1li) AND nlli1iO) AND nlli1il);
	nlOOOl1i <= (((((wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol) AND nlli1Oi) AND nlli1lO) AND nlli1ll) AND nlli1li);
	nlOOOl1l <= (wire_w_lg_w_pmadwidth_range175w14459w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w14460w(0));
	nlOOOl1O <= ((((wire_nl_w_lg_w_lg_w_lg_nlli1Ol14429w14434w14439w(0) AND nlli1li) AND nlli1iO) AND nlli1il) AND nlli1ii);
	nlOOOlii <= (((wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol) AND nlli1Oi) AND nlli1lO);
	nlOOOlil <= (wire_w_lg_w_pmadwidth_range175w14449w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w14450w(0));
	nlOOOliO <= ((wire_nl_w_lg_w_lg_w_lg_nlli1Ol14429w14434w14439w(0) AND nlli1li) AND nlli1iO);
	nlOOOlli <= ((wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol) AND nlli1Oi);
	nlOOOlll <= (wire_w_lg_w_pmadwidth_range175w14444w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w14445w(0));
	nlOOOllO <= (wire_nl_w_lg_w_lg_w_lg_nlli1Ol14429w14434w14439w(0) AND nlli1li);
	nlOOOlOi <= (wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) AND nlli1Ol);
	nlOOOlOl <= (wire_w_lg_w_pmadwidth_range175w14438w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_nl_w_lg_w_lg_w_lg_nlli1Ol14429w14434w14439w(0)));
	nlOOOlOO <= (wire_w_lg_w_pmadwidth_range175w14433w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_nl_w_lg_w_lg_nlli1Ol14429w14434w(0)));
	nlOOOO0i <= wire_w_lg_w_pmadwidth_range175w14262w(0);
	nlOOOO0l <= wire_w_lg_w_pmadwidth_range175w14424w(0);
	nlOOOO0O <= ((((((((((((((((((nlli01l OR nlli01i) OR nlli1OO) OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	nlOOOO1i <= (wire_w_lg_w_pmadwidth_range175w14428w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_nl_w_lg_nlli1Ol14429w(0)));
	nlOOOO1l <= (wire_w_lg_w_pmadwidth_range175w219w(0) AND nlli1Ol);
	nlOOOO1O <= (pmadwidth(0) AND nlli01O);
	nlOOOOii <= wire_w_lg_w_pmadwidth_range175w14404w(0);
	nlOOOOil <= (((((((((((((((((nlli01i OR nlli1OO) OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	nlOOOOiO <= wire_w_lg_w_pmadwidth_range175w14385w(0);
	nlOOOOli <= ((((((((((((((((nlli1OO OR nlli1Ol) OR nlli1Oi) OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	nlOOOOll <= ((((((((((((((nlli1Oi OR nlli1lO) OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	nlOOOOlO <= (((((((((((((nlli1lO OR nlli1ll) OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	nlOOOOOi <= ((((((((((((nlli1ll OR nlli1li) OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	nlOOOOOl <= (((((((((((nlli1li OR nlli1iO) OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	nlOOOOOO <= ((((((((((nlli1iO OR nlli1il) OR nlli1ii) OR nlli10O) OR nlli10l) OR nlli10i) OR nlli11O) OR nlli11l) OR nlli11i) OR nll0OOO) OR nll0OOl);
	rlv <= wire_n0il_dataout;
	rlv_lt <= wire_n0ii_dataout;
	rst1 <= wire_ni0lO_dataout;
	signal_detect_rcvdclk <= signal_detect;
	sudi <= ( wire_nlll_dataout & wire_nlli_dataout & wire_nliO_dataout & wire_nlil_dataout & wire_nlii_dataout & wire_nl0O_dataout & wire_nl0l_dataout & wire_nl0i_dataout & wire_nl1O_dataout & wire_nl1l_dataout & wire_nl1i_dataout & wire_niOO_dataout & wire_niOl_dataout & wire_niOi_dataout & wire_nilO_dataout & wire_nill_dataout & wire_nili_dataout & wire_niiO_dataout & wire_niil_dataout & wire_niii_dataout & wire_ni0O_dataout & wire_ni0l_dataout & wire_ni0i_dataout & wire_ni1O_dataout & wire_ni1l_dataout & wire_ni1i_dataout & wire_n0OO_dataout & wire_n0Ol_dataout & wire_n0Oi_dataout & wire_n0lO_dataout & wire_n0ll_dataout & wire_n0li_dataout);
	sudi_pre <= ( wire_n110ll_dataout & n1ii0iO & wire_w182w & wire_n1l1Ol_w_lg_dataout173w & wire_niOl0l_dataout & wire_niOl0i_dataout & wire_niOl1O_o & wire_niOl1l_o & wire_niOl1i_o & wire_niOiOO_o & wire_niOiOl_o & wire_niOiOi_o & wire_niOilO_o & wire_niOill_o);
	sync_status <= wire_n0iO_dataout;
	testbus <= ( wire_nil_dataout & wire_nii_dataout & wire_n0O_dataout & wire_n0l_dataout & wire_n0i_dataout & wire_n1O_dataout & wire_n1l_dataout & wire_n1i_dataout & wire_nlOO_dataout & wire_nlOl_dataout);
	wa_boundary <= ( wire_nii0l_dataout & wire_nii0i_dataout & wire_nii1O_dataout & wire_nii1l_dataout & wire_nii1i_dataout);
	wire_w_comp_pat_size_range1330w(0) <= comp_pat_size(0);
	wire_w_comp_pat_size_range1331w(0) <= comp_pat_size(1);
	wire_w_ib_invalid_code_range3169w(0) <= ib_invalid_code(0);
	wire_w_ib_invalid_code_range3176w(0) <= ib_invalid_code(1);
	wire_w_pmadwidth_range175w(0) <= pmadwidth(0);
	wire_w_r8b10b_dec_ibm_en_range3034w(0) <= r8b10b_dec_ibm_en(1);
	wire_w_resync_badcg_en_range4511w(0) <= resync_badcg_en(0);
	wire_w_resync_badcg_en_range4513w(0) <= resync_badcg_en(1);
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i00OO49 <= n1i00OO50;
		END IF;
		if (now = 0 ns) then
			n1i00OO49 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i00OO50 <= n1i00OO49;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i0lOi47 <= n1i0lOi48;
		END IF;
		if (now = 0 ns) then
			n1i0lOi47 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i0lOi48 <= n1i0lOi47;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i0O0i43 <= n1i0O0i44;
		END IF;
		if (now = 0 ns) then
			n1i0O0i43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i0O0i44 <= n1i0O0i43;
		END IF;
	END PROCESS;
	wire_n1i0O0i44_w_lg_q340w(0) <= n1i0O0i44 XOR n1i0O0i43;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i0O1l45 <= n1i0O1l46;
		END IF;
		if (now = 0 ns) then
			n1i0O1l45 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i0O1l46 <= n1i0O1l45;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i0Oil41 <= n1i0Oil42;
		END IF;
		if (now = 0 ns) then
			n1i0Oil41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i0Oil42 <= n1i0Oil41;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i0Oli39 <= n1i0Oli40;
		END IF;
		if (now = 0 ns) then
			n1i0Oli39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i0Oli40 <= n1i0Oli39;
		END IF;
	END PROCESS;
	wire_n1i0Oli40_w_lg_q324w(0) <= n1i0Oli40 XOR n1i0Oli39;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i0OlO37 <= n1i0OlO38;
		END IF;
		if (now = 0 ns) then
			n1i0OlO37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i0OlO38 <= n1i0OlO37;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i0OOl35 <= n1i0OOl36;
		END IF;
		if (now = 0 ns) then
			n1i0OOl35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1i0OOl36 <= n1i0OOl35;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii00O19 <= n1ii00O20;
		END IF;
		if (now = 0 ns) then
			n1ii00O19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii00O20 <= n1ii00O19;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii0ii17 <= n1ii0ii18;
		END IF;
		if (now = 0 ns) then
			n1ii0ii17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii0ii18 <= n1ii0ii17;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii0ll15 <= n1ii0ll16;
		END IF;
		if (now = 0 ns) then
			n1ii0ll15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii0ll16 <= n1ii0ll15;
		END IF;
	END PROCESS;
	wire_n1ii0ll16_w_lg_w_lg_q179w180w(0) <= NOT wire_n1ii0ll16_w_lg_q179w(0);
	wire_n1ii0ll16_w_lg_q179w(0) <= n1ii0ll16 XOR n1ii0ll15;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii0OO13 <= n1ii0OO14;
		END IF;
		if (now = 0 ns) then
			n1ii0OO13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii0OO14 <= n1ii0OO13;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii10l33 <= n1ii10l34;
		END IF;
		if (now = 0 ns) then
			n1ii10l33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii10l34 <= n1ii10l33;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii1ii31 <= n1ii1ii32;
		END IF;
		if (now = 0 ns) then
			n1ii1ii31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii1ii32 <= n1ii1ii31;
		END IF;
	END PROCESS;
	wire_n1ii1ii32_w_lg_w_lg_q274w275w(0) <= wire_n1ii1ii32_w_lg_q274w(0) AND nlllOO;
	wire_n1ii1ii32_w_lg_q274w(0) <= n1ii1ii32 XOR n1ii1ii31;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii1il29 <= n1ii1il30;
		END IF;
		if (now = 0 ns) then
			n1ii1il29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii1il30 <= n1ii1il29;
		END IF;
	END PROCESS;
	wire_n1ii1il30_w_lg_w_lg_q270w271w(0) <= wire_n1ii1il30_w_lg_q270w(0) AND nlllOl;
	wire_n1ii1il30_w_lg_q270w(0) <= n1ii1il30 XOR n1ii1il29;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii1iO27 <= n1ii1iO28;
		END IF;
		if (now = 0 ns) then
			n1ii1iO27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii1iO28 <= n1ii1iO27;
		END IF;
	END PROCESS;
	wire_n1ii1iO28_w_lg_w_lg_q258w259w(0) <= wire_n1ii1iO28_w_lg_q258w(0) AND wire_nlll0O_dataout;
	wire_n1ii1iO28_w_lg_q258w(0) <= n1ii1iO28 XOR n1ii1iO27;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii1li25 <= n1ii1li26;
		END IF;
		if (now = 0 ns) then
			n1ii1li25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii1li26 <= n1ii1li25;
		END IF;
	END PROCESS;
	wire_n1ii1li26_w_lg_w_lg_q243w244w(0) <= wire_n1ii1li26_w_lg_q243w(0) AND nllO1l;
	wire_n1ii1li26_w_lg_q243w(0) <= n1ii1li26 XOR n1ii1li25;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii1ll23 <= n1ii1ll24;
		END IF;
		if (now = 0 ns) then
			n1ii1ll23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii1ll24 <= n1ii1ll23;
		END IF;
	END PROCESS;
	wire_n1ii1ll24_w_lg_w_lg_q240w241w(0) <= wire_n1ii1ll24_w_lg_q240w(0) AND nlllOO;
	wire_n1ii1ll24_w_lg_q240w(0) <= n1ii1ll24 XOR n1ii1ll23;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii1Oi21 <= n1ii1Oi22;
		END IF;
		if (now = 0 ns) then
			n1ii1Oi21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1ii1Oi22 <= n1ii1Oi21;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1iii0i11 <= n1iii0i12;
		END IF;
		if (now = 0 ns) then
			n1iii0i11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1iii0i12 <= n1iii0i11;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1iii0O10 <= n1iii0O9;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1iii0O9 <= n1iii0O10;
		END IF;
		if (now = 0 ns) then
			n1iii0O9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1iiiil7 <= n1iiiil8;
		END IF;
		if (now = 0 ns) then
			n1iiiil7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1iiiil8 <= n1iiiil7;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1iiiOl5 <= n1iiiOl6;
		END IF;
		if (now = 0 ns) then
			n1iiiOl5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1iiiOl6 <= n1iiiOl5;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1iil0O1 <= n1iil0O2;
		END IF;
		if (now = 0 ns) then
			n1iil0O1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1iil0O2 <= n1iil0O1;
		END IF;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1iil1i3 <= n1iil1i4;
		END IF;
		if (now = 0 ns) then
			n1iil1i3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk)
	BEGIN
		IF (clk = '1' AND clk'event) THEN n1iil1i4 <= n1iil1i3;
		END IF;
	END PROCESS;
	wire_n1iil1i4_w_lg_q7w(0) <= n1iil1i4 XOR n1iil1i3;
	PROCESS (clk, rst, wire_ni0Oi_CLRN)
	BEGIN
		IF (rst = '1') THEN
				ni0li <= '1';
				ni0Ol <= '1';
		ELSIF (wire_ni0Oi_CLRN = '0') THEN
				ni0li <= '0';
				ni0Ol <= '0';
		ELSIF (clk = '1' AND clk'event) THEN
				ni0li <= ni0Ol;
				ni0Ol <= n1iii1i;
		END IF;
		if (now = 0 ns) then
			ni0li <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			ni0Ol <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_ni0Oi_CLRN <= (n1ii0OO14 XOR n1ii0OO13);
	PROCESS (clk, wire_nl_CLRN)
	BEGIN
		IF (wire_nl_CLRN = '0') THEN
				n01000i <= '0';
				n01000l <= '0';
				n01000O <= '0';
				n01001i <= '0';
				n01001l <= '0';
				n01001O <= '0';
				n0100ii <= '0';
				n0100il <= '0';
				n0101il <= '0';
				n0101iO <= '0';
				n0101li <= '0';
				n0101ll <= '0';
				n0101lO <= '0';
				n0101Oi <= '0';
				n0101Ol <= '0';
				n0101OO <= '0';
				n010Ol <= '0';
				n010OO <= '0';
				n0110i <= '0';
				n0110l <= '0';
				n0110O <= '0';
				n0111i <= '0';
				n0111l <= '0';
				n0111O <= '0';
				n011ii <= '0';
				n011il <= '0';
				n011iO <= '0';
				n011l0i <= '0';
				n011l0l <= '0';
				n011l0O <= '0';
				n011l1l <= '0';
				n011l1O <= '0';
				n011li <= '0';
				n011lii <= '0';
				n011lil <= '0';
				n011liO <= '0';
				n011ll <= '0';
				n011lli <= '0';
				n011lll <= '0';
				n011llO <= '0';
				n011lO <= '0';
				n011lOi <= '0';
				n011lOl <= '0';
				n011lOO <= '0';
				n011O0i <= '0';
				n011O1i <= '0';
				n011O1l <= '0';
				n011O1O <= '0';
				n011Oi <= '0';
				n01i0i <= '0';
				n01i0l <= '0';
				n01i0O <= '0';
				n01i1i <= '0';
				n01i1l <= '0';
				n01i1O <= '0';
				n01iii <= '0';
				n01iil <= '0';
				n01iiO <= '0';
				n01ili <= '0';
				n01ill <= '0';
				n1l00O <= '0';
				n1l0ii <= '0';
				n1l0il <= '0';
				n1l0iO <= '0';
				n1l0li <= '0';
				n1l0ll <= '0';
				n1l0lO <= '0';
				n1l0Oi <= '0';
				n1liii <= '0';
				n1O01i <= '0';
				n1O01O <= '0';
				n1O1ll <= '0';
				n1O1lO <= '0';
				n1O1Oi <= '0';
				n1O1Ol <= '0';
				n1O1OO <= '0';
				n1Oi0i <= '0';
				n1Oi0l <= '0';
				n1Oi0O <= '0';
				n1Oi1O <= '0';
				n1OilO <= '0';
				n1OiOi <= '0';
				n1OiOl <= '0';
				n1OiOO <= '0';
				n1Ol00i <= '0';
				n1Ol00l <= '0';
				n1Ol00O <= '0';
				n1Ol01i <= '0';
				n1Ol01l <= '0';
				n1Ol01O <= '0';
				n1Ol0ii <= '0';
				n1Ol0il <= '0';
				n1Ol1Ol <= '0';
				n1Ol1OO <= '0';
				n1Oli0i <= '0';
				n1OO00i <= '0';
				n1OO01i <= '0';
				n1OO01l <= '0';
				n1OO0iO <= '0';
				n1OO0li <= '0';
				n1OO0ll <= '0';
				n1OO0lO <= '0';
				n1OO1lO <= '0';
				n1OO1Oi <= '0';
				n1OO1Ol <= '0';
				n1OO1OO <= '0';
				n1OOi0i <= '0';
				n1OOi1O <= '0';
				n1OOOl <= '0';
				n1OOOO <= '0';
				ni0iO <= '0';
				ni0OO <= '0';
				niii0i <= '0';
				niii0l <= '0';
				niii0O <= '0';
				niiill <= '0';
				nil00i <= '0';
				nil00l <= '0';
				nil00O <= '0';
				nil01i <= '0';
				nil01l <= '0';
				nil01O <= '0';
				nil0ii <= '0';
				nil0il <= '0';
				nil0iO <= '0';
				nil0li <= '0';
				nil0ll <= '0';
				nil0lO <= '0';
				nil0Oi <= '0';
				nil0Ol <= '0';
				nil0OO <= '0';
				nil1il <= '0';
				nil1iO <= '0';
				nil1li <= '0';
				nil1ll <= '0';
				nil1lO <= '0';
				nil1Ol <= '0';
				nil1OO <= '0';
				nili0i <= '0';
				nili0l <= '0';
				nili0O <= '0';
				nili1i <= '0';
				nili1l <= '0';
				nili1O <= '0';
				niliii <= '0';
				niliil <= '0';
				niliiO <= '0';
				nilili <= '0';
				nilill <= '0';
				nililO <= '0';
				niliOi <= '0';
				niliOl <= '0';
				niliOO <= '0';
				nill0i <= '0';
				nill0l <= '0';
				nill1i <= '0';
				nill1l <= '0';
				nill1O <= '0';
				niOlii <= '0';
				niOlil <= '0';
				niOlli <= '0';
				niOlll <= '0';
				niOllO <= '0';
				niOlOi <= '0';
				niOlOl <= '0';
				niOlOO <= '0';
				niOO0i <= '0';
				niOO1i <= '0';
				niOO1l <= '0';
				niOO1O <= '0';
				niOOOO <= '0';
				nl010il <= '0';
				nl010iO <= '0';
				nl010li <= '0';
				nl010ll <= '0';
				nl010lO <= '0';
				nl010Oi <= '0';
				nl010Ol <= '0';
				nl010OO <= '0';
				nl0110i <= '0';
				nl0110l <= '0';
				nl0110O <= '0';
				nl0111i <= '0';
				nl0111l <= '0';
				nl0111O <= '0';
				nl011ii <= '0';
				nl011il <= '0';
				nl011iO <= '0';
				nl011li <= '0';
				nl011ll <= '0';
				nl011lO <= '0';
				nl01i0i <= '0';
				nl01i0l <= '0';
				nl01i0O <= '0';
				nl01i1i <= '0';
				nl01i1l <= '0';
				nl01i1O <= '0';
				nl01iii <= '0';
				nl01iil <= '0';
				nl01iiO <= '0';
				nl01ili <= '0';
				nl01ill <= '0';
				nl01ilO <= '0';
				nl01iOi <= '0';
				nl01iOl <= '0';
				nl01iOO <= '0';
				nl01l0i <= '0';
				nl01l0l <= '0';
				nl01l0O <= '0';
				nl01l1i <= '0';
				nl01l1l <= '0';
				nl01l1O <= '0';
				nl01lii <= '0';
				nl01lil <= '0';
				nl01liO <= '0';
				nl01lli <= '0';
				nl01lll <= '0';
				nl01llO <= '0';
				nl01lOi <= '0';
				nl01lOl <= '0';
				nl01lOO <= '0';
				nl01O1i <= '0';
				nl01O1l <= '0';
				nl01O1O <= '0';
				nl100l <= '0';
				nl100O <= '0';
				nl10ii <= '0';
				nl10Ol <= '0';
				nl110i <= '0';
				nl110l <= '0';
				nl110O <= '0';
				nl111i <= '0';
				nl111l <= '0';
				nl111O <= '0';
				nl11ii <= '0';
				nl11il <= '0';
				nl11iO <= '0';
				nl1ill <= '0';
				nl1ilO <= '0';
				nl1l1l <= '0';
				nl1lii <= '0';
				nl1liii <= '0';
				nl1liil <= '0';
				nl1lOi <= '0';
				nl1Oiil <= '0';
				nl1OiiO <= '0';
				nl1Oili <= '0';
				nl1Oill <= '0';
				nl1OilO <= '0';
				nl1OiOi <= '0';
				nl1OiOl <= '0';
				nl1OiOO <= '0';
				nl1Ol0i <= '0';
				nl1Ol0l <= '0';
				nl1Ol0O <= '0';
				nl1Ol1i <= '0';
				nl1Ol1l <= '0';
				nl1Ol1O <= '0';
				nl1Olii <= '0';
				nl1Olil <= '0';
				nl1OliO <= '0';
				nl1Olli <= '0';
				nl1Olll <= '0';
				nl1OllO <= '0';
				nl1OlOi <= '0';
				nl1OlOl <= '0';
				nl1OlOO <= '0';
				nl1OO0i <= '0';
				nl1OO0l <= '0';
				nl1OO0O <= '0';
				nl1OO1i <= '0';
				nl1OO1l <= '0';
				nl1OO1O <= '0';
				nl1OOii <= '0';
				nl1OOil <= '0';
				nl1OOiO <= '0';
				nl1OOli <= '0';
				nl1OOll <= '0';
				nl1OOlO <= '0';
				nl1OOOi <= '0';
				nl1OOOl <= '0';
				nl1OOOO <= '0';
				nliiOl <= '0';
				nliiOO <= '0';
				nlil0i <= '0';
				nlil0l <= '0';
				nlil0O <= '0';
				nlil1i <= '0';
				nlil1l <= '0';
				nlil1O <= '0';
				nlilii <= '0';
				nlilll <= '0';
				nlillO <= '0';
				nlilOi <= '0';
				nlilOl <= '0';
				nlilOO <= '0';
				nliO0i <= '0';
				nliO0l <= '0';
				nliO0O <= '0';
				nliO1i <= '0';
				nliO1l <= '0';
				nliO1O <= '0';
				nliOii <= '0';
				nliOil <= '0';
				nliOiO <= '0';
				nliOli <= '0';
				nliOll <= '0';
				nliOlO <= '0';
				nliOOi <= '0';
				nliOOl <= '0';
				nliOOO <= '0';
				nll000i <= '0';
				nll000l <= '0';
				nll000O <= '0';
				nll001i <= '0';
				nll001l <= '0';
				nll001O <= '0';
				nll00ii <= '0';
				nll00il <= '0';
				nll00iO <= '0';
				nll00li <= '0';
				nll00ll <= '0';
				nll00lO <= '0';
				nll00Oi <= '0';
				nll00Ol <= '0';
				nll00OO <= '0';
				nll01ll <= '0';
				nll01lO <= '0';
				nll01Oi <= '0';
				nll01Ol <= '0';
				nll01OO <= '0';
				nll0i0i <= '0';
				nll0i0l <= '0';
				nll0i0O <= '0';
				nll0i1i <= '0';
				nll0i1l <= '0';
				nll0i1O <= '0';
				nll0iii <= '0';
				nll0iil <= '0';
				nll0iiO <= '0';
				nll0ili <= '0';
				nll0ill <= '0';
				nll0ilO <= '0';
				nll0iOi <= '0';
				nll0iOl <= '0';
				nll0iOO <= '0';
				nll0l0i <= '0';
				nll0l0l <= '0';
				nll0l0O <= '0';
				nll0l1i <= '0';
				nll0l1l <= '0';
				nll0l1O <= '0';
				nll0lii <= '0';
				nll0lil <= '0';
				nll0liO <= '0';
				nll0lli <= '0';
				nll0lll <= '0';
				nll0llO <= '0';
				nll0lOi <= '0';
				nll0lOl <= '0';
				nll0lOO <= '0';
				nll0O0i <= '0';
				nll0O0l <= '0';
				nll0O0O <= '0';
				nll0O1i <= '0';
				nll0O1l <= '0';
				nll0O1O <= '0';
				nll0Oii <= '0';
				nll0Oil <= '0';
				nll0OiO <= '0';
				nll0Oli <= '0';
				nll0Oll <= '0';
				nll0OlO <= '0';
				nll0OOi <= '0';
				nll0OOl <= '0';
				nll0OOO <= '0';
				nll10i <= '0';
				nll11i <= '0';
				nll11l <= '0';
				nll11O <= '0';
				nlli00i <= '0';
				nlli00l <= '0';
				nlli00O <= '0';
				nlli01i <= '0';
				nlli01l <= '0';
				nlli01O <= '0';
				nlli0ii <= '0';
				nlli0il <= '0';
				nlli0iO <= '0';
				nlli0li <= '0';
				nlli0ll <= '0';
				nlli0lO <= '0';
				nlli0Oi <= '0';
				nlli0Ol <= '0';
				nlli0OO <= '0';
				nlli10i <= '0';
				nlli10l <= '0';
				nlli10O <= '0';
				nlli11i <= '0';
				nlli11l <= '0';
				nlli11O <= '0';
				nlli1ii <= '0';
				nlli1il <= '0';
				nlli1iO <= '0';
				nlli1li <= '0';
				nlli1ll <= '0';
				nlli1lO <= '0';
				nlli1Oi <= '0';
				nlli1Ol <= '0';
				nlli1OO <= '0';
				nllii0i <= '0';
				nllii0l <= '0';
				nllii1i <= '0';
				nllii1l <= '0';
				nllii1O <= '0';
				nllll1i <= '0';
				nlllOl <= '0';
				nlllOO <= '0';
				nlO <= '0';
				nlO000i <= '0';
				nlO000l <= '0';
				nlO000O <= '0';
				nlO001i <= '0';
				nlO001l <= '0';
				nlO001O <= '0';
				nlO00ii <= '0';
				nlO00il <= '0';
				nlO00iO <= '0';
				nlO00li <= '0';
				nlO00ll <= '0';
				nlO00lO <= '0';
				nlO00Oi <= '0';
				nlO00Ol <= '0';
				nlO00OO <= '0';
				nlO010i <= '0';
				nlO010l <= '0';
				nlO011i <= '0';
				nlO011l <= '0';
				nlO011O <= '0';
				nlO01ii <= '0';
				nlO01il <= '0';
				nlO01iO <= '0';
				nlO01li <= '0';
				nlO01ll <= '0';
				nlO01lO <= '0';
				nlO01Oi <= '0';
				nlO01Ol <= '0';
				nlO01OO <= '0';
				nlO0i0i <= '0';
				nlO0i0l <= '0';
				nlO0i0O <= '0';
				nlO0i1i <= '0';
				nlO0i1l <= '0';
				nlO0i1O <= '0';
				nlO0iii <= '0';
				nlO0iil <= '0';
				nlO0iiO <= '0';
				nlO0ili <= '0';
				nlO0ill <= '0';
				nlO0ilO <= '0';
				nlO0l1i <= '0';
				nlO0l1l <= '0';
				nlO0l1O <= '0';
				nlOi0ll <= '0';
				nlOi0lO <= '0';
				nlOi0Oi <= '0';
				nlOi0Ol <= '0';
				nlOi0OO <= '0';
				nlOii0i <= '0';
				nlOii0l <= '0';
				nlOii0O <= '0';
				nlOii1i <= '0';
				nlOii1l <= '0';
				nlOii1O <= '0';
				nlOiiii <= '0';
				nlOiiil <= '0';
				nlOiiiO <= '0';
				nlOiili <= '0';
				nlOiill <= '0';
				nlOiilO <= '0';
				nlOilOl <= '0';
				nlOilOO <= '0';
				nlOiO0i <= '0';
				nlOiO0l <= '0';
				nlOiO1i <= '0';
				nlOiO1l <= '0';
				nlOiO1O <= '0';
				nO <= '0';
		ELSIF (clk = '1' AND clk'event) THEN
				n01000i <= wire_n010i0O_dataout;
				n01000l <= wire_n010iii_dataout;
				n01000O <= wire_n010iil_dataout;
				n01001i <= wire_n010i1O_dataout;
				n01001l <= wire_n010i0i_dataout;
				n01001O <= wire_n010i0l_dataout;
				n0100ii <= wire_n010iiO_dataout;
				n0100il <= wire_n010ili_dataout;
				n0101il <= wire_n0100li_dataout;
				n0101iO <= wire_n0100ll_dataout;
				n0101li <= wire_n0100lO_dataout;
				n0101ll <= wire_n0100Oi_dataout;
				n0101lO <= wire_n0100Ol_dataout;
				n0101Oi <= wire_n0100OO_dataout;
				n0101Ol <= wire_n010i1i_dataout;
				n0101OO <= wire_n010i1l_dataout;
				n010Ol <= wire_n01iOi_dataout;
				n010OO <= wire_n01iOl_dataout;
				n0110i <= wire_n0100l_dataout;
				n0110l <= wire_n0100O_dataout;
				n0110O <= wire_n010ii_dataout;
				n0111i <= wire_n0101l_dataout;
				n0111l <= wire_n0101O_dataout;
				n0111O <= wire_n0100i_dataout;
				n011ii <= wire_n010il_dataout;
				n011il <= wire_n010iO_dataout;
				n011iO <= wire_n010li_dataout;
				n011l0i <= wire_n011Oil_dataout;
				n011l0l <= wire_n011OiO_dataout;
				n011l0O <= wire_n011Oli_dataout;
				n011l1l <= wire_n011O0O_dataout;
				n011l1O <= wire_n011Oii_dataout;
				n011li <= wire_n010ll_dataout;
				n011lii <= wire_n011Oll_dataout;
				n011lil <= wire_n011OlO_dataout;
				n011liO <= wire_n011OOi_dataout;
				n011ll <= wire_n010lO_dataout;
				n011lli <= wire_n011OOl_dataout;
				n011lll <= wire_n011OOO_dataout;
				n011llO <= wire_n01011i_dataout;
				n011lO <= wire_n010Oi_dataout;
				n011lOi <= wire_n01011l_dataout;
				n011lOl <= wire_n01011O_dataout;
				n011lOO <= wire_n01010i_dataout;
				n011O0i <= wire_n0100iO_dataout;
				n011O1i <= wire_n01010l_dataout;
				n011O1l <= wire_n01010O_dataout;
				n011O1O <= wire_n0101ii_dataout;
				n011Oi <= wire_n01ilO_dataout;
				n01i0i <= wire_n01l1O_dataout;
				n01i0l <= wire_n01l0i_dataout;
				n01i0O <= wire_n01l0l_dataout;
				n01i1i <= wire_n01iOO_dataout;
				n01i1l <= wire_n01l1i_dataout;
				n01i1O <= wire_n01l1l_dataout;
				n01iii <= wire_n01l0O_dataout;
				n01iil <= wire_n01lii_dataout;
				n01iiO <= wire_n01lil_dataout;
				n01ili <= wire_n01liO_dataout;
				n01ill <= wire_n01lli_dataout;
				n1l00O <= wire_n1li0i_o(1);
				n1l0ii <= wire_n1li0i_o(2);
				n1l0il <= wire_n1li0i_o(3);
				n1l0iO <= wire_n1l0Ol_dataout;
				n1l0li <= wire_n1l0OO_dataout;
				n1l0ll <= wire_n1li1i_dataout;
				n1l0lO <= wire_n1li1l_dataout;
				n1l0Oi <= wire_n1ll0O_o;
				n1liii <= wire_n1li0i_o(0);
				n1O01i <= wire_n1llOO_dataout;
				n1O01O <= wire_n1Oiii_dataout;
				n1O1ll <= wire_n1llil_o;
				n1O1lO <= wire_n1lliO_dataout;
				n1O1Oi <= wire_n1llli_o;
				n1O1Ol <= wire_n1lllO_o;
				n1O1OO <= wire_n1llOl_dataout;
				n1Oi0i <= wire_n1OiiO_dataout;
				n1Oi0l <= wire_n1Oili_dataout;
				n1Oi0O <= n1OilO;
				n1Oi1O <= wire_n1Oiil_dataout;
				n1OilO <= (n011Oi OR n1OiOO);
				n1OiOi <= n1OiOl;
				n1OiOl <= rlv_en;
				n1OiOO <= wire_n011Ol_dataout;
				n1Ol00i <= wire_n1Ol0li_dataout;
				n1Ol00l <= wire_n1Ol0ll_dataout;
				n1Ol00O <= wire_n1Ol0lO_dataout;
				n1Ol01i <= wire_n1Ol0OO_o(3);
				n1Ol01l <= wire_n1Ol0OO_o(4);
				n1Ol01O <= wire_n1Ol0iO_dataout;
				n1Ol0ii <= wire_n1Ol0Oi_dataout;
				n1Ol0il <= wire_n1Oll0l_o;
				n1Ol1Ol <= wire_n1Ol0OO_o(1);
				n1Ol1OO <= wire_n1Ol0OO_o(2);
				n1Oli0i <= wire_n1Ol0OO_o(0);
				n1OO00i <= wire_n1OO0Oi_dataout;
				n1OO01i <= wire_n1OllOi_dataout;
				n1OO01l <= wire_n1OllOl_dataout;
				n1OO0iO <= wire_n1OO0Ol_dataout;
				n1OO0li <= wire_n1OO0OO_dataout;
				n1OO0ll <= wire_n1OOi1i_dataout;
				n1OO0lO <= n1OOi1O;
				n1OO1lO <= wire_n1Ollii_o;
				n1OO1Oi <= wire_n1Ollil_dataout;
				n1OO1Ol <= wire_n1OlliO_o;
				n1OO1OO <= wire_n1Ollll_o;
				n1OOi0i <= wire_n011O0l_dataout;
				n1OOi1O <= (n011O0i OR n1OOi0i);
				n1OOOl <= wire_n011OO_dataout;
				n1OOOO <= wire_n0101i_dataout;
				ni0iO <= (rpolinv_en AND polinv_en);
				ni0OO <= nlO;
				niii0i <= wire_n110ll_dataout;
				niii0l <= (wire_w_lg_w_lg_n1i1Oil1323w1324w(0) OR wire_w_lg_w_pmadwidth_range175w1328w(0));
				niii0O <= nil1li;
				niiill <= (((n1i1OlO OR n1i1Oll) OR (wire_niOl0l_w_lg_dataout1312w(0) AND (wire_niOl0i_w_lg_dataout1313w(0) AND wire_niOl1O_w_lg_w_lg_o1314w1315w(0)))) OR wire_niOl0l_w_lg_dataout1321w(0));
				nil00i <= wire_nillOO_dataout;
				nil00l <= wire_nilO1i_dataout;
				nil00O <= wire_nilO1l_dataout;
				nil01i <= wire_nilllO_dataout;
				nil01l <= wire_nillOi_dataout;
				nil01O <= wire_nillOl_dataout;
				nil0ii <= wire_nilO1O_dataout;
				nil0il <= wire_nilO0i_dataout;
				nil0iO <= wire_nilO0l_dataout;
				nil0li <= wire_nilO0O_dataout;
				nil0ll <= wire_n1l1Ol_w_lg_dataout173w(0);
				nil0lO <= (n1ii0li OR (n1ii0Oi OR wire_w_lg_w_pmadwidth_range175w176w(0)));
				nil0Oi <= n1ii0iO;
				nil0Ol <= wire_n110ll_dataout;
				nil0OO <= wire_nillil_dataout;
				nil1il <= nil1ll;
				nil1iO <= nil1lO;
				nil1li <= wire_nil10l_dataout;
				nil1ll <= n1i011O;
				nil1lO <= n1i010i;
				nil1Ol <= nil1OO;
				nil1OO <= nl10Ol;
				nili0i <= wire_niO1ii_dataout;
				nili0l <= wire_niO1il_dataout;
				nili0O <= wire_niO1iO_dataout;
				nili1i <= wire_nillii_dataout;
				nili1l <= wire_niO10l_dataout;
				nili1O <= wire_niO10O_dataout;
				niliii <= wire_niO1li_dataout;
				niliil <= wire_niO1ll_dataout;
				niliiO <= wire_niO1lO_dataout;
				nilili <= nill0i;
				nilill <= wire_niO1Ol_o;
				nililO <= wire_niO1OO_o;
				niliOi <= wire_niO01i_o;
				niliOl <= wire_niO01l_o;
				niliOO <= wire_niO01O_o;
				nill0i <= nl1l1l;
				nill0l <= niOlii;
				nill1i <= wire_niO00i_o;
				nill1l <= wire_niO00l_o;
				nill1O <= wire_niO00O_o;
				niOlii <= (rbitloc_rev_en AND bitloc_rev_en);
				niOlil <= wire_niOO0l_o;
				niOlli <= wire_niOO0O_o;
				niOlll <= wire_niOOii_o;
				niOllO <= wire_niOOil_o;
				niOlOi <= wire_niOOiO_o;
				niOlOl <= wire_niOOli_o;
				niOlOO <= wire_niOOll_o;
				niOO0i <= wire_nl11li_o;
				niOO1i <= wire_niOOlO_o;
				niOO1l <= wire_niOOOi_o;
				niOO1O <= wire_niOOOl_o;
				niOOOO <= wire_nl11ll_o;
				nl010il <= nl01iOi;
				nl010iO <= nl01iOl;
				nl010li <= nl01iOO;
				nl010ll <= nl01l1i;
				nl010lO <= nl01l1l;
				nl010Oi <= nl01l1O;
				nl010Ol <= nl01l0i;
				nl010OO <= nl01l0l;
				nl0110i <= wire_nl1llll_o;
				nl0110l <= wire_nl1lllO_o;
				nl0110O <= wire_nl1llOi_o;
				nl0111i <= wire_nl1llil_o;
				nl0111l <= wire_nl1lliO_o;
				nl0111O <= wire_nl1llli_o;
				nl011ii <= wire_n1Ol10O_w_lg_dataout4507w(0);
				nl011il <= wire_nl0l1OO_dataout;
				nl011iO <= (wire_w_lg_disable_rx_disp1194w(0) AND n10l10l);
				nl011li <= wire_n1O10lO_dataout;
				nl011ll <= wire_nl0l0ii_dataout;
				nl011lO <= wire_nl0l0il_dataout;
				nl01i0i <= nl01liO;
				nl01i0l <= nl01lli;
				nl01i0O <= nl01lll;
				nl01i1i <= nl01l0O;
				nl01i1l <= nl01lii;
				nl01i1O <= nl01lil;
				nl01iii <= nl01llO;
				nl01iil <= nl01lOi;
				nl01iiO <= nl01lOl;
				nl01ili <= nl01lOO;
				nl01ill <= nl01O1i;
				nl01ilO <= nl01O1l;
				nl01iOi <= wire_nl01O0i_dataout;
				nl01iOl <= wire_nl01O0l_dataout;
				nl01iOO <= wire_nl01O0O_dataout;
				nl01l0i <= wire_nl01Oli_dataout;
				nl01l0l <= wire_nl01Oll_dataout;
				nl01l0O <= wire_nl01OlO_dataout;
				nl01l1i <= wire_nl01Oii_dataout;
				nl01l1l <= wire_nl01Oil_dataout;
				nl01l1O <= wire_nl01OiO_dataout;
				nl01lii <= wire_nl01OOi_dataout;
				nl01lil <= wire_nl01OOl_dataout;
				nl01liO <= wire_nl01OOO_dataout;
				nl01lli <= wire_nl0011i_dataout;
				nl01lll <= wire_nl0011l_dataout;
				nl01llO <= wire_nl0011O_dataout;
				nl01lOi <= wire_nl0010i_dataout;
				nl01lOl <= wire_nl0010l_dataout;
				nl01lOO <= wire_nl0010O_dataout;
				nl01O1i <= wire_nl001ii_dataout;
				nl01O1l <= wire_nl001il_dataout;
				nl01O1O <= wire_nll1lOl_dataout;
				nl100l <= nl100O;
				nl100O <= nl10ii;
				nl10ii <= bitslip;
				nl10Ol <= (NOT ((((NOT (nll1il XOR nl1iOi)) AND (NOT (nlli0l XOR nl1iOl))) AND (NOT (nlli0O XOR nl1iOO))) AND (NOT (nlliii XOR nl1l1i))));
				nl110i <= wire_nl11OO_o;
				nl110l <= wire_nl101i_o;
				nl110O <= wire_nl101l_o;
				nl111i <= wire_nl11lO_o;
				nl111l <= wire_nl11Oi_o;
				nl111O <= wire_nl11Ol_o;
				nl11ii <= wire_nl101O_o;
				nl11il <= wire_nl100i_o;
				nl11iO <= (nl100O AND wire_nl_w_lg_nl100l905w(0));
				nl1ill <= nl1ilO;
				nl1ilO <= a1a2_size;
				nl1l1l <= nl1ill;
				nl1lii <= n1ii10O;
				nl1liii <= wire_nl0l0lO_dataout;
				nl1liil <= wire_n1O10lO_dataout;
				nl1lOi <= nliOlO;
				nl1Oiil <= (wire_nll1llO_w_lg_o7418w(0) AND (wire_w_lg_n111lOi7419w(0) AND wire_w_lg_n111O1i7420w(0)));
				nl1OiiO <= wire_nl0l0ll_dataout;
				nl1Oili <= nl1Ol1O;
				nl1Oill <= nl1Ol0i;
				nl1OilO <= nl1Ol0l;
				nl1OiOi <= nl1Ol0O;
				nl1OiOl <= nl1Olii;
				nl1OiOO <= nl1Olil;
				nl1Ol0i <= n1101il;
				nl1Ol0l <= n11001l;
				nl1Ol0O <= n1101Ol;
				nl1Ol1i <= nl1OliO;
				nl1Ol1l <= nl1Olli;
				nl1Ol1O <= n1101ll;
				nl1Olii <= n1100il;
				nl1Olil <= n11000l;
				nl1OliO <= n1100Ol;
				nl1Olli <= n1100ll;
				nl1Olll <= wire_nl1liiO_o;
				nl1OllO <= wire_nl1lili_o;
				nl1OlOi <= wire_nl1lill_o;
				nl1OlOl <= wire_nl1lilO_o;
				nl1OlOO <= wire_nl1liOi_o;
				nl1OO0i <= wire_nl1ll1l_o;
				nl1OO0l <= wire_nl1ll1O_o;
				nl1OO0O <= wire_n1liO0O_w_lg_dataout4506w(0);
				nl1OO1i <= wire_nl1liOl_o;
				nl1OO1l <= wire_nl1liOO_o;
				nl1OO1O <= wire_nl1ll1i_o;
				nl1OOii <= wire_nl0l1ii_dataout;
				nl1OOil <= (wire_w_lg_disable_rx_disp1194w(0) AND n10l10O);
				nl1OOiO <= wire_n1l11lO_dataout;
				nl1OOli <= wire_nl0l1lO_dataout;
				nl1OOll <= wire_nl0l1Oi_dataout;
				nl1OOlO <= wire_nl1ll0i_o;
				nl1OOOi <= wire_nl1ll0l_o;
				nl1OOOl <= wire_nl1ll0O_o;
				nl1OOOO <= wire_nl1llii_o;
				nliiOl <= nliOOi;
				nliiOO <= nliOOl;
				nlil0i <= nll11O;
				nlil0l <= nll10i;
				nlil0O <= nll10l;
				nlil1i <= nliOOO;
				nlil1l <= nll11i;
				nlil1O <= nll11l;
				nlilii <= nll1ii;
				nlilll <= wire_nll1iO_dataout;
				nlillO <= wire_nll1li_dataout;
				nlilOi <= wire_nll1ll_dataout;
				nlilOl <= wire_nll1lO_dataout;
				nlilOO <= wire_nll1Oi_dataout;
				nliO0i <= wire_nll01l_dataout;
				nliO0l <= wire_nll01O_dataout;
				nliO0O <= wire_nll00i_dataout;
				nliO1i <= wire_nll1Ol_dataout;
				nliO1l <= wire_nll1OO_dataout;
				nliO1O <= wire_nll01i_dataout;
				nliOii <= wire_nll00l_dataout;
				nliOil <= wire_nll00O_dataout;
				nliOiO <= wire_nll0ii_dataout;
				nliOli <= wire_nll0il_dataout;
				nliOll <= wire_nll0iO_dataout;
				nliOlO <= wire_nll0li_dataout;
				nliOOi <= wire_nll0ll_dataout;
				nliOOl <= wire_nll0lO_dataout;
				nliOOO <= wire_nll0Oi_dataout;
				nll000i <= nll0iiO;
				nll000l <= nll0ili;
				nll000O <= nll0ill;
				nll001i <= nll0i0O;
				nll001l <= nll0iii;
				nll001O <= nll0iil;
				nll00ii <= nll0ilO;
				nll00il <= nll0iOi;
				nll00iO <= nll0iOl;
				nll00li <= nll0iOO;
				nll00ll <= nll0l1i;
				nll00lO <= nll0l1l;
				nll00Oi <= nll0l1O;
				nll00Ol <= nll0l0i;
				nll00OO <= nll0l0l;
				nll01ll <= wire_nll1O1i_o;
				nll01lO <= nll01Oi;
				nll01Oi <= (signal_detect OR rforce_sig_det_pcs);
				nll01Ol <= nll0i0i;
				nll01OO <= nll0i0l;
				nll0i0i <= nll0liO;
				nll0i0l <= nll0lli;
				nll0i0O <= nll0lll;
				nll0i1i <= nll0l0O;
				nll0i1l <= nll0lii;
				nll0i1O <= nll0lil;
				nll0iii <= nll0llO;
				nll0iil <= nll0lOi;
				nll0iiO <= nll0lOl;
				nll0ili <= nll0lOO;
				nll0ill <= nll0O1i;
				nll0ilO <= nll0O1l;
				nll0iOi <= nll0O1O;
				nll0iOl <= nll0O0i;
				nll0iOO <= nll0O0l;
				nll0l0i <= nll0OiO;
				nll0l0l <= nll0Oli;
				nll0l0O <= nll0Oll;
				nll0l1i <= nll0O0O;
				nll0l1l <= nll0Oii;
				nll0l1O <= nll0Oil;
				nll0lii <= nll0OlO;
				nll0lil <= nll0OOi;
				nll0liO <= nll0OOl;
				nll0lli <= nll0OOO;
				nll0lll <= nlli11i;
				nll0llO <= nlli11l;
				nll0lOi <= nlli11O;
				nll0lOl <= nlli10i;
				nll0lOO <= nlli10l;
				nll0O0i <= nlli1iO;
				nll0O0l <= nlli1li;
				nll0O0O <= nlli1ll;
				nll0O1i <= nlli10O;
				nll0O1l <= nlli1ii;
				nll0O1O <= nlli1il;
				nll0Oii <= nlli1lO;
				nll0Oil <= nlli1Oi;
				nll0OiO <= nlli1Ol;
				nll0Oli <= nlli1OO;
				nll0Oll <= nlli01i;
				nll0OlO <= nlli01l;
				nll0OOi <= nlli01O;
				nll0OOl <= wire_nllii0O_dataout;
				nll0OOO <= wire_nlliiii_dataout;
				nll10i <= wire_nlli1l_dataout;
				nll11i <= wire_nll0Ol_dataout;
				nll11l <= wire_nll0OO_dataout;
				nll11O <= wire_nlli1i_dataout;
				nlli00i <= (nlli00O AND wire_nl_w_lg_nlli00l4491w(0));
				nlli00l <= nlli00O;
				nlli00O <= nlli0ii;
				nlli01i <= wire_nllilil_dataout;
				nlli01l <= wire_nlliliO_dataout;
				nlli01O <= wire_nllilli_dataout;
				nlli0ii <= bitslip;
				nlli0il <= nlli0iO;
				nlli0iO <= (rbyte_rev_en AND byte_rev_en);
				nlli0li <= nlli0ll;
				nlli0ll <= (rbitloc_rev_en AND bitloc_rev_en);
				nlli0lO <= nlli0Oi;
				nlli0Oi <= rlv_en;
				nlli0Ol <= (nllii0i AND wire_nl_w_lg_nllii1O4488w(0));
				nlli0OO <= wire_nllilOO_dataout;
				nlli10i <= wire_nlliill_dataout;
				nlli10l <= wire_nlliilO_dataout;
				nlli10O <= wire_nlliiOi_dataout;
				nlli11i <= wire_nlliiil_dataout;
				nlli11l <= wire_nlliiiO_dataout;
				nlli11O <= wire_nlliili_dataout;
				nlli1ii <= wire_nlliiOl_dataout;
				nlli1il <= wire_nlliiOO_dataout;
				nlli1iO <= wire_nllil1i_dataout;
				nlli1li <= wire_nllil1l_dataout;
				nlli1ll <= wire_nllil1O_dataout;
				nlli1lO <= wire_nllil0i_dataout;
				nlli1Oi <= wire_nllil0l_dataout;
				nlli1Ol <= wire_nllil0O_dataout;
				nlli1OO <= wire_nllilii_dataout;
				nllii0i <= nllii0l;
				nllii0l <= encdt;
				nllii1i <= nllii1l;
				nllii1l <= nllii1O;
				nllii1O <= nllii0i;
				nllll1i <= (((wire_nllO0ii_dataout OR wire_nllO00l_dataout) OR wire_nllO00i_dataout) OR wire_nllO01l_dataout);
				nlllOl <= wire_nlll1l_o;
				nlllOO <= wire_nlll1O_o;
				nlO <= wire_ni_dataout;
				nlO000i <= wire_nlllliO_o;
				nlO000l <= wire_nllllli_o;
				nlO000O <= wire_nllllll_o;
				nlO001i <= wire_nllll0O_o;
				nlO001l <= wire_nllllii_o;
				nlO001O <= wire_nllllil_o;
				nlO00ii <= wire_nllllOl_o;
				nlO00il <= wire_nllllOO_o;
				nlO00iO <= wire_nlllO1i_o;
				nlO00li <= wire_nlllO1l_o;
				nlO00ll <= wire_nlllO1O_o;
				nlO00lO <= wire_nlllO0i_o;
				nlO00Oi <= wire_nlllO0l_o;
				nlO00Ol <= wire_nlllO0O_o;
				nlO00OO <= wire_nlllOii_o;
				nlO010i <= (pipe_loose_sync AND (rforce_sig_det_pcs OR (signal_detect OR lpbk_en)));
				nlO010l <= nlO010i;
				nlO011i <= (((wire_nllO00O_dataout OR wire_nllO00l_dataout) OR wire_nllO01O_dataout) OR wire_nllO01l_dataout);
				nlO011l <= (NOT ((wire_nllO0il_w_lg_dataout3407w(0) OR wire_nllO00O_dataout) OR wire_nllO00l_dataout));
				nlO011O <= wire_nllO01i_dataout;
				nlO01ii <= wire_nllO1iO_o;
				nlO01il <= wire_nlllill_dataout;
				nlO01iO <= wire_nlllilO_dataout;
				nlO01li <= wire_nllliOi_dataout;
				nlO01ll <= wire_nllliOl_dataout;
				nlO01lO <= wire_nllll1l_o;
				nlO01Oi <= wire_nllll1O_o;
				nlO01Ol <= wire_nllll0i_o;
				nlO01OO <= wire_nllll0l_o;
				nlO0i0i <= wire_nlllOOO_o;
				nlO0i0l <= wire_nllO11i_o;
				nlO0i0O <= wire_nllO11l_o;
				nlO0i1i <= wire_nlllOil_o;
				nlO0i1l <= wire_nlllOOi_o;
				nlO0i1O <= wire_nlllOOl_o;
				nlO0iii <= wire_nllO11O_o;
				nlO0iil <= wire_nllO10i_o;
				nlO0iiO <= wire_nllO10l_o;
				nlO0ili <= wire_nllO10O_o;
				nlO0ill <= wire_nllO1ii_o;
				nlO0ilO <= nlO0l1i;
				nlO0l1i <= prbs_en;
				nlO0l1l <= nlO0l1O;
				nlO0l1O <= encdt;
				nlOi0ll <= n1i0l0i;
				nlOi0lO <= wire_nlOi0iO_o;
				nlOi0Oi <= n1i0l0O;
				nlOi0Ol <= wire_nlOi00i_o;
				nlOi0OO <= n1i0lil;
				nlOii0i <= n1i0llO;
				nlOii0l <= wire_nlOi10i_o;
				nlOii0O <= n1i0O1i;
				nlOii1i <= wire_nlOi1Ol_o;
				nlOii1l <= n1i0lli;
				nlOii1O <= wire_nlOi1iO_o;
				nlOiiii <= wire_nlO0OOl_o;
				nlOiiil <= n1i0Oii;
				nlOiiiO <= wire_nlO0OiO_o;
				nlOiili <= n1ii11l;
				nlOiill <= wire_nlO0O0i_o;
				nlOiilO <= n1ii11l;
				nlOilOl <= n1i0Oii;
				nlOilOO <= n1i0O1i;
				nlOiO0i <= n1i0l0O;
				nlOiO0l <= n1i0l0i;
				nlOiO1i <= n1i0llO;
				nlOiO1l <= n1i0lli;
				nlOiO1O <= n1i0lil;
				nO <= ni0iO;
		END IF;
	END PROCESS;
	wire_nl_CLRN <= ((n1iil0O2 XOR n1iil0O1) AND wire_ni0lO_w_lg_dataout2w(0));
	wire_nl_w16422w(0) <= wire_nl_w_lg_w_lg_w_lg_w16418w16419w16420w16421w(0) AND nlOOOOll;
	wire_nl_w_lg_w_lg_w_lg_w16418w16419w16420w16421w(0) <= wire_nl_w_lg_w_lg_w16418w16419w16420w(0) AND nlOOOOlO;
	wire_nl_w_lg_w_lg_w16418w16419w16420w(0) <= wire_nl_w_lg_w16418w16419w(0) AND nlOOOOOi;
	wire_nl_w_lg_w16418w16419w(0) <= wire_nl_w16418w(0) AND nlOOOOOl;
	wire_nl_w16418w(0) <= wire_nl_w_lg_w_lg_w_lg_w16414w16415w16416w16417w(0) AND nlOOOOOO;
	wire_nl_w_lg_w_lg_w_lg_w16414w16415w16416w16417w(0) <= wire_nl_w_lg_w_lg_w16414w16415w16416w(0) AND n11111i;
	wire_nl_w_lg_w_lg_w16414w16415w16416w(0) <= wire_nl_w_lg_w16414w16415w(0) AND n11111l;
	wire_nl_w_lg_w16414w16415w(0) <= wire_nl_w16414w(0) AND n11111O;
	wire_nl_w_lg_w_lg_w_lg_w2928w2929w2930w2931w(0) <= wire_nl_w_lg_w_lg_w2928w2929w2930w(0) AND n1i1ili;
	wire_nl_w16414w(0) <= wire_nl_w_lg_w_lg_w_lg_w16410w16411w16412w16413w(0) AND n11110i;
	wire_nl_w_lg_w_lg_w2928w2929w2930w(0) <= wire_nl_w_lg_w2928w2929w(0) AND n1i1ill;
	wire_nl_w_lg_w_lg_w_lg_w16410w16411w16412w16413w(0) <= wire_nl_w_lg_w_lg_w16410w16411w16412w(0) AND n11110l;
	wire_nl_w_lg_w2928w2929w(0) <= wire_nl_w2928w(0) AND n1i1ilO;
	wire_nl_w_lg_w_lg_w16410w16411w16412w(0) <= wire_nl_w_lg_w16410w16411w(0) AND n11110O;
	wire_nl_w2928w(0) <= wire_nl_w_lg_w_lg_w_lg_w_lg_nl1lOi2612w2925w2926w2927w(0) AND n1i1iOi;
	wire_nl_w_lg_w16410w16411w(0) <= wire_nl_w16410w(0) AND n1111ii;
	wire_nl_w_lg_w_lg_w_lg_w_lg_nl1lOi2612w2925w2926w2927w(0) <= wire_nl_w_lg_w_lg_w_lg_nl1lOi2612w2925w2926w(0) AND n1i1iOl;
	wire_nl_w16410w(0) <= wire_nl_w_lg_w_lg_w_lg_nll0OOl16010w16408w16409w(0) AND n1111il;
	wire_nl_w_lg_w_lg_w_lg_nlil0l2177w2182w2187w(0) <= wire_nl_w_lg_w_lg_nlil0l2177w2182w(0) AND nlil1l;
	wire_nl_w_lg_w_lg_w_lg_nlilii2175w2180w2185w(0) <= wire_nl_w_lg_w_lg_nlilii2175w2180w(0) AND nlil0i;
	wire_nl_w_lg_w_lg_w_lg_nlli01O14427w14432w14437w(0) <= wire_nl_w_lg_w_lg_nlli01O14427w14432w(0) AND nlli1OO;
	wire_nl_w_lg_w_lg_w_lg_nlli1Ol14429w14434w14439w(0) <= wire_nl_w_lg_w_lg_nlli1Ol14429w14434w(0) AND nlli1ll;
	wire_nl_w_lg_w_lg_w_lg_nl1lOi2612w2925w2926w(0) <= wire_nl_w_lg_w_lg_nl1lOi2612w2925w(0) AND n1i1iOO;
	wire_nl_w_lg_w_lg_w_lg_nll0OOl16010w16408w16409w(0) <= wire_nl_w_lg_w_lg_nll0OOl16010w16408w(0) AND n1111iO;
	wire_nl_w_lg_w_lg_nlil0l2177w2182w(0) <= wire_nl_w_lg_nlil0l2177w(0) AND nlil1O;
	wire_nl_w_lg_w_lg_nlilii2175w2180w(0) <= wire_nl_w_lg_nlilii2175w(0) AND nlil0l;
	wire_nl_w_lg_w_lg_nlli01O14427w14432w(0) <= wire_nl_w_lg_nlli01O14427w(0) AND nlli01i;
	wire_nl_w_lg_w_lg_nlli1Ol14429w14434w(0) <= wire_nl_w_lg_nlli1Ol14429w(0) AND nlli1lO;
	wire_nl_w_lg_w_lg_nlOiill322w325w(0) <= wire_nl_w_lg_nlOiill322w(0) AND wire_n1i0Oli40_w_lg_q324w(0);
	wire_nl_w_lg_w_lg_nl1lOi2612w2925w(0) <= wire_nl_w_lg_nl1lOi2612w(0) AND n1i1l0O;
	wire_nl_w_lg_w_lg_nll0OOl16010w16408w(0) <= wire_nl_w_lg_nll0OOl16010w(0) AND n11100i;
	wire_nl_w_lg_niii0i1208w(0) <= niii0i AND wire_w_lg_n1i001l1207w(0);
	wire_nl_w_lg_nl1ill342w(0) <= nl1ill AND wire_w_lg_w_lg_n1i0O0O338w341w(0);
	wire_nl_w_lg_nl1ill389w(0) <= nl1ill AND wire_w_lg_n1i0l0l388w(0);
	wire_nl_w_lg_nl1ill397w(0) <= nl1ill AND wire_w_lg_n1i0l1O396w(0);
	wire_nl_w_lg_nl1ill381w(0) <= nl1ill AND wire_w_lg_n1i0lii380w(0);
	wire_nl_w_lg_nl1ill373w(0) <= nl1ill AND wire_w_lg_n1i0liO372w(0);
	wire_nl_w_lg_nl1ill365w(0) <= nl1ill AND wire_w_lg_n1i0lll364w(0);
	wire_nl_w_lg_nl1ill357w(0) <= nl1ill AND wire_w_lg_n1i0lOO356w(0);
	wire_nl_w_lg_nl1ill327w(0) <= nl1ill AND wire_w_lg_n1ii11i326w(0);
	wire_nl_w_lg_nl1liil17114w(0) <= nl1liil AND wire_w_lg_nlOO1lil17113w(0);
	wire_nl_w_lg_nl1lOi2945w(0) <= nl1lOi AND wire_w_lg_n1i100O2508w(0);
	wire_nl_w_lg_nlil0l2177w(0) <= nlil0l AND nlil0i;
	wire_nl_w_lg_nlilii2175w(0) <= nlilii AND nlil0O;
	wire_nl_w_lg_nll0OOl16448w(0) <= nll0OOl AND wire_w_lg_nlOOO0iO15408w(0);
	wire_nl_w_lg_nlli01O14427w(0) <= nlli01O AND nlli01l;
	wire_nl_w_lg_nlli1Ol14429w(0) <= nlli1Ol AND nlli1Oi;
	wire_nl_w_lg_nlO0l1l232w(0) <= nlO0l1l AND wire_w_lg_n1ii00l231w(0);
	wire_nl_w_lg_nlOi0lO395w(0) <= nlOi0lO AND wire_nl_w_lg_nlOi0ll394w(0);
	wire_nl_w_lg_nlOi0Ol387w(0) <= nlOi0Ol AND wire_nl_w_lg_nlOi0Oi386w(0);
	wire_nl_w_lg_nlOii0l363w(0) <= nlOii0l AND wire_nl_w_lg_nlOii0i362w(0);
	wire_nl_w_lg_nlOii1i379w(0) <= nlOii1i AND wire_nl_w_lg_nlOi0OO378w(0);
	wire_nl_w_lg_nlOii1O371w(0) <= nlOii1O AND wire_nl_w_lg_nlOii1l370w(0);
	wire_nl_w_lg_nlOiiii355w(0) <= nlOiiii AND wire_nl_w_lg_nlOii0O354w(0);
	wire_nl_w_lg_nlOiiiO337w(0) <= nlOiiiO AND wire_nl_w_lg_nlOiiil336w(0);
	wire_nl_w_lg_nlOiill322w(0) <= nlOiill AND wire_nl_w_lg_nlOiili321w(0);
	wire_nl_w_lg_w_lg_w_lg_w_lg_nlilii2087w2094w2101w2102w(0) <= NOT wire_nl_w_lg_w_lg_w_lg_nlilii2087w2094w2101w(0);
	wire_nl_w14161w(0) <= NOT wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0);
	wire_nl_w_lg_w_lg_w_lg_nlilii2087w2094w2095w(0) <= NOT wire_nl_w_lg_w_lg_nlilii2087w2094w(0);
	wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14154w(0) <= NOT wire_nl_w_lg_w_lg_nlli01O14146w14153w(0);
	wire_nl_w_lg_w_lg_nlilii2087w2088w(0) <= NOT wire_nl_w_lg_nlilii2087w(0);
	wire_nl_w_lg_w_lg_nlli01O14146w14147w(0) <= NOT wire_nl_w_lg_nlli01O14146w(0);
	wire_nl_w_lg_n0101il16151w(0) <= NOT n0101il;
	wire_nl_w_lg_n010Ol2709w(0) <= NOT n010Ol;
	wire_nl_w_lg_n011l1l16150w(0) <= NOT n011l1l;
	wire_nl_w_lg_n011l1O16156w(0) <= NOT n011l1O;
	wire_nl_w_lg_n1OiOi2540w(0) <= NOT n1OiOi;
	wire_nl_w_lg_n1OOOl2708w(0) <= NOT n1OOOl;
	wire_nl_w_lg_n1OOOO2714w(0) <= NOT n1OOOO;
	wire_nl_w_lg_niii0i1195w(0) <= NOT niii0i;
	wire_nl_w_lg_niii0l3438w(0) <= NOT niii0l;
	wire_nl_w_lg_niiill3373w(0) <= NOT niiill;
	wire_nl_w_lg_nl100l905w(0) <= NOT nl100l;
	wire_nl_w_lg_nl1ill312w(0) <= NOT nl1ill;
	wire_nl_w_lg_nl1l1l1933w(0) <= NOT nl1l1l;
	wire_nl_w_lg_nl1liil17102w(0) <= NOT nl1liil;
	wire_nl_w_lg_nl1lOi2612w(0) <= NOT nl1lOi;
	wire_nl_w_lg_nliiOl2604w(0) <= NOT nliiOl;
	wire_nl_w_lg_nliiOO2596w(0) <= NOT nliiOO;
	wire_nl_w_lg_nlil0i2588w(0) <= NOT nlil0i;
	wire_nl_w_lg_nlil0l2618w(0) <= NOT nlil0l;
	wire_nl_w_lg_nlil0O2616w(0) <= NOT nlil0O;
	wire_nl_w_lg_nlil1i2594w(0) <= NOT nlil1i;
	wire_nl_w_lg_nlil1l2592w(0) <= NOT nlil1l;
	wire_nl_w_lg_nlil1O2590w(0) <= NOT nlil1O;
	wire_nl_w_lg_nlilii2911w(0) <= NOT nlilii;
	wire_nl_w_lg_nll01ll7899w(0) <= NOT nll01ll;
	wire_nl_w_lg_nll01lO4501w(0) <= NOT nll01lO;
	wire_nl_w_lg_nll0OOl16010w(0) <= NOT nll0OOl;
	wire_nl_w_lg_nll0OOO15999w(0) <= NOT nll0OOO;
	wire_nl_w_lg_nlli00l4491w(0) <= NOT nlli00l;
	wire_nl_w_lg_nlli01i16015w(0) <= NOT nlli01i;
	wire_nl_w_lg_nlli01l16013w(0) <= NOT nlli01l;
	wire_nl_w_lg_nlli01O16384w(0) <= NOT nlli01O;
	wire_nl_w_lg_nlli0lO15746w(0) <= NOT nlli0lO;
	wire_nl_w_lg_nlli0OO4494w(0) <= NOT nlli0OO;
	wire_nl_w_lg_nlli10i15955w(0) <= NOT nlli10i;
	wire_nl_w_lg_nlli10l15944w(0) <= NOT nlli10l;
	wire_nl_w_lg_nlli10O15942w(0) <= NOT nlli10O;
	wire_nl_w_lg_nlli11i15988w(0) <= NOT nlli11i;
	wire_nl_w_lg_nlli11l15977w(0) <= NOT nlli11l;
	wire_nl_w_lg_nlli11O15966w(0) <= NOT nlli11O;
	wire_nl_w_lg_nlli1ii15940w(0) <= NOT nlli1ii;
	wire_nl_w_lg_nlli1il15938w(0) <= NOT nlli1il;
	wire_nl_w_lg_nlli1iO15936w(0) <= NOT nlli1iO;
	wire_nl_w_lg_nlli1li15934w(0) <= NOT nlli1li;
	wire_nl_w_lg_nlli1ll15932w(0) <= NOT nlli1ll;
	wire_nl_w_lg_nlli1lO15930w(0) <= NOT nlli1lO;
	wire_nl_w_lg_nlli1Oi15928w(0) <= NOT nlli1Oi;
	wire_nl_w_lg_nlli1Ol16019w(0) <= NOT nlli1Ol;
	wire_nl_w_lg_nlli1OO16017w(0) <= NOT nlli1OO;
	wire_nl_w_lg_nllii0i4486w(0) <= NOT nllii0i;
	wire_nl_w_lg_nllii1O4488w(0) <= NOT nllii1O;
	wire_nl_w_lg_nlO00il4415w(0) <= NOT nlO00il;
	wire_nl_w_lg_nlO00iO4413w(0) <= NOT nlO00iO;
	wire_nl_w_lg_nlO00li4411w(0) <= NOT nlO00li;
	wire_nl_w_lg_nlO00ll4409w(0) <= NOT nlO00ll;
	wire_nl_w_lg_nlO00lO4407w(0) <= NOT nlO00lO;
	wire_nl_w_lg_nlO00Oi4405w(0) <= NOT nlO00Oi;
	wire_nl_w_lg_nlO00Ol4403w(0) <= NOT nlO00Ol;
	wire_nl_w_lg_nlO00OO4401w(0) <= NOT nlO00OO;
	wire_nl_w_lg_nlO010l3809w(0) <= NOT nlO010l;
	wire_nl_w_lg_nlO0i1i4400w(0) <= NOT nlO0i1i;
	wire_nl_w_lg_nlO0l1l246w(0) <= NOT nlO0l1l;
	wire_nl_w_lg_nlOi0ll394w(0) <= NOT nlOi0ll;
	wire_nl_w_lg_nlOi0Oi386w(0) <= NOT nlOi0Oi;
	wire_nl_w_lg_nlOi0OO378w(0) <= NOT nlOi0OO;
	wire_nl_w_lg_nlOii0i362w(0) <= NOT nlOii0i;
	wire_nl_w_lg_nlOii0O354w(0) <= NOT nlOii0O;
	wire_nl_w_lg_nlOii1l370w(0) <= NOT nlOii1l;
	wire_nl_w_lg_nlOiiil336w(0) <= NOT nlOiiil;
	wire_nl_w_lg_nlOiili321w(0) <= NOT nlOiili;
	wire_nl_w_lg_w_lg_w_lg_nlilii2087w2094w2101w(0) <= wire_nl_w_lg_w_lg_nlilii2087w2094w(0) OR nlil0i;
	wire_nl_w_lg_w_lg_w_lg_nlli01O14146w14153w14160w(0) <= wire_nl_w_lg_w_lg_nlli01O14146w14153w(0) OR nlli1OO;
	wire_nl_w_lg_w_lg_nlilii2087w2094w(0) <= wire_nl_w_lg_nlilii2087w(0) OR nlil0l;
	wire_nl_w_lg_w_lg_nlli01O14146w14153w(0) <= wire_nl_w_lg_nlli01O14146w(0) OR nlli01i;
	wire_nl_w_lg_nlilii2087w(0) <= nlilii OR nlil0O;
	wire_nl_w_lg_nlli01O14146w(0) <= nlli01O OR nlli01l;
	PROCESS (clk, wire_nl10lO_CLRN)
	BEGIN
		IF (wire_nl10lO_CLRN = '0') THEN
				nl10il <= '0';
				nl10li <= '0';
				nl10ll <= '0';
				nl10Oi <= '0';
		ELSIF (clk = '1' AND clk'event) THEN
			IF (nl11iO = '1') THEN
				nl10il <= wire_nl10OO_dataout;
				nl10li <= wire_nl1i1i_dataout;
				nl10ll <= wire_nl1i1l_dataout;
				nl10Oi <= wire_nl1i1O_dataout;
			END IF;
		END IF;
	END PROCESS;
	wire_nl10lO_CLRN <= ((n1i00OO50 XOR n1i00OO49) AND wire_ni0lO_w_lg_dataout2w(0));
	wire_nl10lO_w_lg_nl10il1929w(0) <= NOT nl10il;
	wire_nl10lO_w_lg_nl10li1927w(0) <= NOT nl10li;
	wire_nl10lO_w_lg_nl10ll1925w(0) <= NOT nl10ll;
	wire_nl10lO_w_lg_nl10Oi1924w(0) <= NOT nl10Oi;
	PROCESS (clk, wire_ni0lO_dataout)
	BEGIN
		IF (wire_ni0lO_dataout = '1') THEN
				nl1lil <= '1';
				nl1liO <= '1';
				nl1lli <= '1';
				nl1llO <= '1';
		ELSIF (clk = '1' AND clk'event) THEN
			IF (n1ii10O = '1') THEN
				nl1lil <= wire_w_lg_n1ii1OO229w(0);
				nl1liO <= n1ii01i;
				nl1lli <= n1ii01l;
				nl1llO <= n1ii01O;
			END IF;
		END IF;
		if (now = 0 ns) then
			nl1lil <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl1liO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl1lli <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl1llO <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk, wire_nll10O_PRN, wire_ni0lO_dataout)
	BEGIN
		IF (wire_nll10O_PRN = '0') THEN
				nlilil <= '1';
				nliliO <= '1';
				nlilli <= '1';
				nll10l <= '1';
				nll1ii <= '1';
		ELSIF (wire_ni0lO_dataout = '1') THEN
				nlilil <= '0';
				nliliO <= '0';
				nlilli <= '0';
				nll10l <= '0';
				nll1ii <= '0';
		ELSIF (clk = '1' AND clk'event) THEN
			IF (wire_w_pmadwidth_range175w(0) = '1') THEN
				nlilil <= nliO1O;
				nliliO <= nliO0i;
				nlilli <= nliO0l;
				nll10l <= wire_nlli1O_dataout;
				nll1ii <= wire_nlli0i_dataout;
			END IF;
		END IF;
	END PROCESS;
	wire_nll10O_ENA <= pmadwidth(0);
	wire_nll10O_PRN <= (n1ii10l34 XOR n1ii10l33);
	PROCESS (clk, wire_ni0lO_dataout, wire_nllO1i_CLRN)
	BEGIN
		IF (wire_ni0lO_dataout = '1') THEN
				n1O01l <= '1';
				n1OO01O <= '1';
				nil1Oi <= '1';
				nl0100i <= '1';
				nl0100l <= '1';
				nl0100O <= '1';
				nl0101i <= '1';
				nl0101l <= '1';
				nl0101O <= '1';
				nl010ii <= '1';
				nl011Oi <= '1';
				nl011Ol <= '1';
				nl011OO <= '1';
				nl1iOi <= '1';
				nl1iOl <= '1';
				nl1iOO <= '1';
				nl1l1i <= '1';
				nll01li <= '1';
				nll1il <= '1';
				nlli0l <= '1';
				nlli0O <= '1';
				nlliii <= '1';
				nllO1l <= '1';
				nlO010O <= '1';
		ELSIF (wire_nllO1i_CLRN = '0') THEN
				n1O01l <= '0';
				n1OO01O <= '0';
				nil1Oi <= '0';
				nl0100i <= '0';
				nl0100l <= '0';
				nl0100O <= '0';
				nl0101i <= '0';
				nl0101l <= '0';
				nl0101O <= '0';
				nl010ii <= '0';
				nl011Oi <= '0';
				nl011Ol <= '0';
				nl011OO <= '0';
				nl1iOi <= '0';
				nl1iOl <= '0';
				nl1iOO <= '0';
				nl1l1i <= '0';
				nll01li <= '0';
				nll1il <= '0';
				nlli0l <= '0';
				nlli0O <= '0';
				nlliii <= '0';
				nllO1l <= '0';
				nlO010O <= '0';
		ELSIF (clk = '1' AND clk'event) THEN
				n1O01l <= wire_nl_w_lg_n1OiOi2540w(0);
				n1OO01O <= wire_nl_w_lg_nlli0lO15746w(0);
				nil1Oi <= (n1ii0iO OR wire_n1l1Ol_w_lg_dataout173w(0));
				nl0100i <= wire_nl0i1OO_dataout;
				nl0100l <= wire_nl0i01i_dataout;
				nl0100O <= wire_nl0i01l_dataout;
				nl0101i <= nl0100O;
				nl0101l <= nl010ii;
				nl0101O <= wire_nl0i1Ol_dataout;
				nl010ii <= wire_nl0i01O_dataout;
				nl011Oi <= nl0101O;
				nl011Ol <= nl0100i;
				nl011OO <= nl0100l;
				nl1iOi <= wire_nl1l1O_dataout;
				nl1iOl <= wire_nl1l0i_dataout;
				nl1iOO <= wire_nl1l0l_dataout;
				nl1l1i <= wire_nl1l0O_dataout;
				nll01li <= wire_nll1lOO_o;
				nll1il <= wire_nlliil_dataout;
				nlli0l <= wire_nlliiO_dataout;
				nlli0O <= wire_nllili_dataout;
				nlliii <= wire_nllill_dataout;
				nllO1l <= wire_nlll0i_o;
				nlO010O <= wire_nlllOli_o;
		END IF;
		if (now = 0 ns) then
			n1O01l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n1OO01O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nil1Oi <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl0100i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl0100l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl0100O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl0101i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl0101l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl0101O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl010ii <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl011Oi <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl011Ol <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl011OO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl1iOi <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl1iOl <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl1iOO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nl1l1i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll01li <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll1il <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlli0l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlli0O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlliii <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nllO1l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlO010O <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nllO1i_CLRN <= (n1ii00O20 XOR n1ii00O19);
	wire_nllO1i_w_lg_nil1Oi3372w(0) <= NOT nil1Oi;
	wire_nllO1i_w_lg_nll01li7901w(0) <= NOT nll01li;
	wire_n00i_dataout <= (NOT pudi(15)) WHEN nO = '1'  ELSE pudi(15);
	wire_n00l_dataout <= (NOT pudi(16)) WHEN nO = '1'  ELSE pudi(16);
	wire_n00O_dataout <= (NOT pudi(17)) WHEN nO = '1'  ELSE pudi(17);
	wire_n0100i_dataout <= (((wire_w_lg_n10Ol0l2449w(0) OR wire_w_lg_n10Ol0i2451w(0)) OR wire_w_lg_n10Ol1O2459w(0)) OR wire_w_lg_n10Ol1l2515w(0)) AND n1OiOi;
	wire_n0100iO_dataout <= (wire_w_lg_nlOOil1l15645w(0) OR (wire_w_lg_nlOOil1i15646w(0) OR (wire_w_lg_nlOOiiOO15647w(0) OR (wire_w_lg_nlOOiiOl15648w(0) OR (wire_w_lg_nlOOiiOi15649w(0) OR (wire_w_lg_nlOOiilO15650w(0) OR (wire_w_lg_nlOOiill15651w(0) OR (wire_w_lg_nlOOiili15652w(0) OR (wire_w_lg_nlOOiiiO15653w(0) OR (wire_w_lg_nlOOiiil15654w(0) OR (wire_w_lg_nlOOiiii15655w(0) OR (wire_w_lg_nlOOii0O15656w(0) OR (wire_w_lg_nlOOii0l15657w(0) OR (wire_w_lg_nlOOii0i15658w(0) OR (wire_w_lg_nlOOii1O15659w(0) OR wire_w_lg_nlOOii1l15660w(0)))))))))))))))) AND nlli0lO;
	wire_n0100l_dataout <= (wire_w_lg_n1i11ii2507w(0) OR (NOT ((wire_w_lg_n1i100O2508w(0) OR n1i11il) OR n1i11ii))) AND n1OiOi;
	wire_n0100li_dataout <= (wire_w_lg_w_pmadwidth_range175w15643w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n11100i14248w(0))) AND nlli0lO;
	wire_n0100ll_dataout <= nlOOl00O AND nlli0lO;
	wire_n0100lO_dataout <= nlOOl0il AND nlli0lO;
	wire_n0100O_dataout <= n011iO AND n1OiOi;
	wire_n0100Oi_dataout <= nlOOl0iO AND nlli0lO;
	wire_n0100Ol_dataout <= nlOOl0li AND nlli0lO;
	wire_n0100OO_dataout <= nlOOl0ll AND nlli0lO;
	wire_n01010i_dataout <= nlOOiOOl AND nlli0lO;
	wire_n01010l_dataout <= nlOOiOOO AND nlli0lO;
	wire_n01010O_dataout <= nlOOl11i AND nlli0lO;
	wire_n01011i_dataout <= n011O1l AND nlli0lO;
	wire_n01011l_dataout <= n011O1O AND nlli0lO;
	wire_n01011O_dataout <= nlOOiOlO AND nlli0lO;
	wire_n0101i_dataout <= (wire_w_lg_w_pmadwidth_range175w2517w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w2208w(0)) AND n1OiOi;
	wire_n0101ii_dataout <= nlOOl11l AND nlli0lO;
	wire_n0101l_dataout <= n10OilO AND n1OiOi;
	wire_n0101O_dataout <= n10OiOl AND n1OiOi;
	wire_n010i0i_dataout <= n0100ii AND nlli0lO;
	wire_n010i0l_dataout <= n0100il AND nlli0lO;
	wire_n010i0O_dataout <= nlOOliOO AND nlli0lO;
	wire_n010i1i_dataout <= n01000i AND nlli0lO;
	wire_n010i1l_dataout <= n01000l AND nlli0lO;
	wire_n010i1O_dataout <= n01000O AND nlli0lO;
	wire_n010ii_dataout <= n011li AND n1OiOi;
	wire_n010iii_dataout <= nlOOll1l AND nlli0lO;
	wire_n010iil_dataout <= nlOOll1O AND nlli0lO;
	wire_n010iiO_dataout <= nlOOll0i AND nlli0lO;
	wire_n010il_dataout <= n011ll AND n1OiOi;
	wire_n010ili_dataout <= nlOOll0l AND nlli0lO;
	wire_n010iO_dataout <= n011lO AND n1OiOi;
	wire_n010li_dataout <= n10Olii AND n1OiOi;
	wire_n010ll_dataout <= n10OliO AND n1OiOi;
	wire_n010lO_dataout <= (((wire_w_lg_n10OlOO2394w(0) OR wire_w_lg_n10OlOl2396w(0)) OR wire_w_lg_n10OlOi2404w(0)) OR wire_w_lg_n10OllO2505w(0)) AND n1OiOi;
	wire_n010Oi_dataout <= (wire_w_lg_n1i101i2497w(0) OR (NOT ((wire_w_lg_n1i100l2498w(0) OR n1i101O) OR n1i101i))) AND n1OiOi;
	wire_n0110il_dataout <= nlOOi1Oi WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE nlOOi1Ol;
	wire_n0110il_w_lg_dataout15757w(0) <= NOT wire_n0110il_dataout;
	wire_n0110iO_dataout <= wire_n011ill_dataout AND NOT(wire_w_lg_w_pmadwidth_range175w219w(0));
	wire_n0110iO_w_lg_dataout16493w(0) <= NOT wire_n0110iO_dataout;
	wire_n0110li_dataout <= wire_n011ilO_dataout AND NOT(wire_w_lg_w_pmadwidth_range175w219w(0));
	wire_n0110li_w_lg_dataout16491w(0) <= NOT wire_n0110li_dataout;
	wire_n0110ll_dataout <= wire_n011ill_dataout WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE wire_n011i1O_dataout;
	wire_n0110lO_dataout <= wire_n011ilO_dataout WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE wire_n011i0i_dataout;
	wire_n0110lO_w_lg_dataout16488w(0) <= NOT wire_n0110lO_dataout;
	wire_n0110Oi_dataout <= wire_n011iOi_dataout WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE wire_n011i0l_dataout;
	wire_n0110Oi_w_lg_dataout16486w(0) <= NOT wire_n0110Oi_dataout;
	wire_n0110Ol_dataout <= wire_n011iOl_dataout WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE wire_n011i0O_dataout;
	wire_n0110Ol_w_lg_dataout16484w(0) <= NOT wire_n0110Ol_dataout;
	wire_n0110OO_dataout <= wire_n011iOO_dataout WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE wire_n011iii_dataout;
	wire_n0110OO_w_lg_dataout16482w(0) <= NOT wire_n0110OO_dataout;
	wire_n011i0i_dataout <= wire_n011ili_o(1) AND NOT(nlOOi1OO);
	wire_n011i0l_dataout <= wire_n011ili_o(2) AND NOT(nlOOi1OO);
	wire_n011i0O_dataout <= wire_n011ili_o(3) AND NOT(nlOOi1OO);
	wire_n011i1i_dataout <= wire_n011l1i_dataout WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE wire_n011iil_dataout;
	wire_n011i1i_w_lg_dataout16480w(0) <= NOT wire_n011i1i_dataout;
	wire_n011i1l_dataout <= nlOOi1OO WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE wire_n011iiO_dataout;
	wire_n011i1l_w_lg_w_lg_w_lg_w16485w16487w16489w16490w(0) <= wire_n011i1l_w_lg_w_lg_w16485w16487w16489w(0) AND wire_n0110ll_dataout;
	wire_n011i1l_w_lg_w_lg_w16485w16487w16489w(0) <= wire_n011i1l_w_lg_w16485w16487w(0) AND wire_n0110lO_w_lg_dataout16488w(0);
	wire_n011i1l_w_lg_w16485w16487w(0) <= wire_n011i1l_w16485w(0) AND wire_n0110Oi_w_lg_dataout16486w(0);
	wire_n011i1l_w16485w(0) <= wire_n011i1l_w_lg_w_lg_w_lg_dataout16479w16481w16483w(0) AND wire_n0110Ol_w_lg_dataout16484w(0);
	wire_n011i1l_w_lg_w_lg_w_lg_dataout16479w16481w16483w(0) <= wire_n011i1l_w_lg_w_lg_dataout16479w16481w(0) AND wire_n0110OO_w_lg_dataout16482w(0);
	wire_n011i1l_w_lg_w_lg_dataout16479w16481w(0) <= wire_n011i1l_w_lg_dataout16479w(0) AND wire_n011i1i_w_lg_dataout16480w(0);
	wire_n011i1l_w_lg_dataout16479w(0) <= NOT wire_n011i1l_dataout;
	wire_n011i1O_dataout <= wire_n011ili_o(0) AND NOT(nlOOi1OO);
	wire_n011iii_dataout <= wire_n011ili_o(4) OR nlOOi1OO;
	wire_n011iil_dataout <= wire_n011ili_o(5) AND NOT(nlOOi1OO);
	wire_n011iiO_dataout <= wire_n011ili_o(6) OR nlOOi1OO;
	wire_n011ill_dataout <= max_rlv_sel(0) AND NOT(nlOOi1OO);
	wire_n011ilO_dataout <= max_rlv_sel(1) AND NOT(nlOOi1OO);
	wire_n011iOi_dataout <= max_rlv_sel(2) AND NOT(nlOOi1OO);
	wire_n011iOl_dataout <= max_rlv_sel(3) AND NOT(nlOOi1OO);
	wire_n011iOO_dataout <= max_rlv_sel(4) AND NOT(nlOOi1OO);
	wire_n011l1i_dataout <= max_rlv_sel(5) AND NOT(nlOOi1OO);
	wire_n011O0l_dataout <= (wire_w_lg_nlOOii1i15679w(0) OR (wire_w_lg_nlOOi0OO15680w(0) OR (wire_w_lg_nlOOi0Ol15681w(0) OR (wire_w_lg_nlOOi0Oi15682w(0) OR (wire_w_lg_nlOOi0lO15683w(0) OR (wire_w_lg_nlOOi0ll15684w(0) OR (wire_w_lg_nlOOi0li15685w(0) OR (wire_w_lg_nlOOi0iO15686w(0) OR (wire_w_lg_nlOOi0il15687w(0) OR (wire_w_lg_nlOOi0ii15688w(0) OR (wire_w_lg_nlOOi00O15689w(0) OR (wire_w_lg_nlOOi00l15690w(0) OR (wire_w_lg_nlOOi00i15691w(0) OR (wire_w_lg_nlOOi01O15692w(0) OR (wire_w_lg_nlOOi01l15693w(0) OR wire_w_lg_nlOOi01i15694w(0)))))))))))))))) AND nlli0lO;
	wire_n011O0O_dataout <= (nlOOOO1O OR nlOOOO1l) AND nlli0lO;
	wire_n011Oii_dataout <= (wire_w_lg_w_pmadwidth_range175w15676w(0) OR wire_w_lg_w_lg_w_pmadwidth_range175w219w14500w(0)) AND nlli0lO;
	wire_n011Oil_dataout <= nlOOil1O AND nlli0lO;
	wire_n011OiO_dataout <= nlOOil0l AND nlli0lO;
	wire_n011Ol_dataout <= (wire_w_lg_n10Oi0i2520w(0) OR (wire_w_lg_n10Oi1O2521w(0) OR (wire_w_lg_n10Oi1l2522w(0) OR (wire_w_lg_n10Oi1i2523w(0) OR (wire_w_lg_n10O0OO2524w(0) OR (wire_w_lg_n10O0Ol2525w(0) OR wire_w_lg_n10O0Oi2526w(0))))))) AND n1OiOi;
	wire_n011Oli_dataout <= nlOOil0O AND nlli0lO;
	wire_n011Oll_dataout <= nlOOilii AND nlli0lO;
	wire_n011OlO_dataout <= nlOOilil AND nlli0lO;
	wire_n011OO_dataout <= (n1i1i0O OR n1i1i0l) AND n1OiOi;
	wire_n011OOi_dataout <= n011lOl AND nlli0lO;
	wire_n011OOl_dataout <= n011lOO AND nlli0lO;
	wire_n011OOO_dataout <= n011O1i AND nlli0lO;
	wire_n01i_dataout <= (NOT pudi(12)) WHEN nO = '1'  ELSE pudi(12);
	wire_n01ilO_dataout <= (wire_w_lg_n10Oill2484w(0) OR (wire_w_lg_n10Oili2485w(0) OR (wire_w_lg_n10OiiO2486w(0) OR (wire_w_lg_n10Oiil2487w(0) OR (wire_w_lg_n10Oiii2488w(0) OR (wire_w_lg_n10Oi0O2489w(0) OR wire_w_lg_n10Oi0l2490w(0))))))) AND n1OiOi;
	wire_n01iOi_dataout <= (wire_w_lg_w_pmadwidth_range175w2482w(0) OR (wire_w_lg_w_pmadwidth_range175w219w(0) AND wire_w_lg_n1i1l0O2133w(0))) AND n1OiOi;
	wire_n01iOl_dataout <= n10OO1l AND n1OiOi;
	wire_n01iOO_dataout <= n10OO0i AND n1OiOi;
	wire_n01l_dataout <= (NOT pudi(13)) WHEN nO = '1'  ELSE pudi(13);
	wire_n01l0i_dataout <= n01iiO AND n1OiOi;
	wire_n01l0l_dataout <= n01ili AND n1OiOi;
	wire_n01l0O_dataout <= n01ill AND n1OiOi;
	wire_n01l1i_dataout <= (((wire_w_lg_n10OOli2339w(0) OR wire_w_lg_n10OOiO2341w(0)) OR wire_w_lg_n10OOil2349w(0)) OR wire_w_lg_n10OOii2480w(0)) AND n1OiOi;
	wire_n01l1l_dataout <= (wire_w_lg_n1i1iii2473w(0) OR (NOT ((n1i1l0O OR n1i1iil) OR n1i1iii))) AND n1OiOi;
	wire_n01l1O_dataout <= n01iil AND n1OiOi;
	wire_n01lii_dataout <= n10OOlO AND n1OiOi;
	wire_n01lil_dataout <= n10OOOl AND n1OiOi;
	wire_n01liO_dataout <= (((wire_w_lg_n1i110l2285w(0) OR wire_w_lg_n1i110i2287w(0)) OR wire_w_lg_n1i111O2295w(0)) OR wire_w_lg_n1i111l2471w(0)) AND n1OiOi;
	wire_n01lli_dataout <= (wire_w_lg_n1i1l1i2463w(0) OR (NOT ((wire_w_lg_n1i1l0l2464w(0) OR n1i1l1O) OR n1i1l1i))) AND n1OiOi;
	wire_n01O_dataout <= (NOT pudi(14)) WHEN nO = '1'  ELSE pudi(14);
	wire_n0i_dataout <= nl0101O WHEN wa_6g_en = '1'  ELSE nl1liO;
	wire_n0ii_dataout <= (((n1OO0li OR n1OO0iO) OR (NOT (n1iii0O10 XOR n1iii0O9))) OR ((n1iiiOi AND n1OO00i) AND (n1iii0i12 XOR n1iii0i11))) WHEN wa_6g_en = '1'  ELSE (((n1Oi0i OR n1Oi1O) OR (n1iiiOi AND n1O01O)) OR (NOT (n1iiiil8 XOR n1iiiil7)));
	wire_n0il_dataout <= n1iiili WHEN wa_6g_en = '1'  ELSE n1iiill;
	wire_n0iO_dataout <= nl01O1O WHEN wa_6g_en = '1'  ELSE nlO01ii;
	wire_n0l_dataout <= nl0100i WHEN wa_6g_en = '1'  ELSE nl1lli;
	wire_n0li_dataout <= wire_nl1iOOl_dataout WHEN wa_6g_en = '1'  ELSE wire_nii0ii_dataout;
	wire_n0ll_dataout <= wire_nl1iOOO_dataout WHEN wa_6g_en = '1'  ELSE wire_nii0il_dataout;
	wire_n0lO_dataout <= wire_nl1l11i_dataout WHEN wa_6g_en = '1'  ELSE wire_nii0iO_dataout;
	wire_n0O_dataout <= nl0100l WHEN wa_6g_en = '1'  ELSE nl1llO;
	wire_n0Oi_dataout <= wire_nl1l11l_dataout WHEN wa_6g_en = '1'  ELSE wire_nii0li_dataout;
	wire_n0Ol_dataout <= wire_nl1l11O_dataout WHEN wa_6g_en = '1'  ELSE wire_nii0ll_dataout;
	wire_n0OO_dataout <= wire_nl1l10i_dataout WHEN wa_6g_en = '1'  ELSE wire_nii0lO_dataout;
	wire_n10i_dataout <= (NOT pudi(18)) WHEN nO = '1'  ELSE pudi(18);
	wire_n10l_dataout <= (NOT pudi(19)) WHEN nO = '1'  ELSE pudi(19);
	wire_n10O_dataout <= (NOT pudi(0)) WHEN nO = '1'  ELSE pudi(0);
	wire_n110ll_dataout <= wire_nlOll0O_dataout WHEN ((wire_niOl1O_o XOR wire_niOl1l_o) AND n1i01ll) = '1'  ELSE (n1i01lO OR n1i01OO);
	wire_n11i_dataout <= (NOT pudi(15)) WHEN nO = '1'  ELSE pudi(15);
	wire_n11l_dataout <= (NOT pudi(16)) WHEN nO = '1'  ELSE pudi(16);
	wire_n11O_dataout <= (NOT pudi(17)) WHEN nO = '1'  ELSE pudi(17);
	wire_n1i_dataout <= nll01ll WHEN wa_6g_en = '1'  ELSE nlO011l;
	wire_n1ii_dataout <= (NOT pudi(1)) WHEN nO = '1'  ELSE pudi(1);
	wire_n1il_dataout <= (NOT pudi(2)) WHEN nO = '1'  ELSE pudi(2);
	wire_n1iliii_dataout <= nl1liil WHEN ((wire_nl1lilO_w_lg_w_lg_o16913w17152w(0) OR (wire_nl1lilO_o AND nlOO1lii)) OR (nlOO1llO AND nlOO1lli)) = '1'  ELSE (nlOO1lil OR nlOO1liO);
	wire_n1iliii_w_lg_w_lg_dataout17118w17148w(0) <= wire_n1iliii_w_lg_dataout17118w(0) AND nlOO1l0l;
	wire_n1iliii_w_lg_dataout17118w(0) <= NOT wire_n1iliii_dataout;
	wire_n1iO_dataout <= (NOT pudi(3)) WHEN nO = '1'  ELSE pudi(3);
	wire_n1l_dataout <= wire_nllO_dataout WHEN wa_6g_en = '1'  ELSE nlO011O;
	wire_n1l0Ol_dataout <= wire_n1li1O_o(0) WHEN wire_n1li0i_o(4) = '1'  ELSE wire_n1li0l_dataout;
	wire_n1l0OO_dataout <= wire_n1li1O_o(1) WHEN wire_n1li0i_o(4) = '1'  ELSE wire_n1li0O_dataout;
	wire_n1l11lO_dataout <= wire_n1iliii_dataout WHEN ((wire_nl1ll1i_o XOR wire_nl1liOO_o) AND nlOO1O0i) = '1'  ELSE (nlOO1O0l OR nlOO1O1O);
	wire_n1l11lO_w_lg_dataout16770w(0) <= wire_n1l11lO_dataout AND wire_w_lg_nlOO0i1l16769w(0);
	wire_n1l11lO_w_lg_dataout16758w(0) <= NOT wire_n1l11lO_dataout;
	wire_n1l1Ol_dataout <= (wire_w_lg_n10O1Oi3072w(0) AND ((NOT (wire_w_lg_n10O11i3074w(0) OR wire_w_lg_n1i000i3077w(0))) AND (NOT (((n10lOOi OR n1i01Oi) OR ((NOT (((n1i1OlO OR n1i1Oll) OR n1i1OiO) OR n1i1Oli)) AND (wire_w_lg_n10lOlO3084w(0) AND (wire_niOl1l_w_lg_w_lg_o2983w3085w(0) OR (wire_niOl1l_o AND n1i01Ol))))) OR ((wire_niOl0l_w_lg_w_lg_dataout1312w3091w(0) OR (wire_niOl0l_dataout AND n1i01Ol)) AND wire_w_lg_n1i1Oll3095w(0)))))) WHEN ((NOT r8b10b_dec_ibm_en(0)) AND (NOT r8b10b_dec_ibm_en(1))) = '1'  ELSE (NOT (((((((((((((wire_w_lg_n10O1Oi2971w(0) OR (wire_niOl1i_w_lg_o2972w(0) AND wire_niOiOO_w_lg_w_lg_o2973w2974w(0))) OR wire_niOl1i_w_lg_o2978w(0)) OR (wire_niOl0l_w_lg_dataout2982w(0) OR (wire_niOl0l_w_lg_dataout1312w(0) AND (wire_niOl0i_w_lg_dataout1313w(0) AND wire_niOl1O_w_lg_w_lg_o1314w2984w(0))))) OR (wire_niOl0i_w_lg_dataout1313w(0) AND (wire_niOl1O_w_lg_o1314w(0) AND (wire_niOl1l_w_lg_o2983w(0) AND (wire_niOl1i_w_lg_o2972w(0) AND wire_niOiOO_w_lg_o2973w(0)))))) OR wire_niOl0i_w_lg_dataout2997w(0)) OR (wire_niOl0l_w_lg_dataout1312w(0) AND (wire_niOl0i_w_lg_dataout1313w(0) AND wire_niOl1O_w_lg_w_lg_o1314w2999w(0)))) OR wire_niOl0l_w_lg_dataout3005w(0)) OR (((wire_niOl0l_w_lg_dataout1312w(0) AND (wire_niOl0i_w_lg_dataout1313w(0) AND wire_niOl1O_w_lg_w_lg_o1314w3007w(0))) OR wire_niOl0l_w_lg_dataout3012w(0)) AND wire_w_lg_n10O10O3014w(0))) OR wire_w_lg_n10O10O3020w(0)) OR ((wire_niOl0l_w_lg_dataout1312w(0) AND (wire_niOl0i_w_lg_dataout1313w(0) AND wire_niOl1O_w_lg_w_lg_o1314w3022w(0))) AND wire_w_lg_n10O1iO3025w(0))) OR (wire_niOl0l_w_lg_dataout3030w(0) AND wire_w_lg_n10O1li3031w(0))) OR wire_w_lg_w_r8b10b_dec_ibm_en_range3034w3050w(0)) OR wire_w_lg_w_r8b10b_dec_ibm_en_range3034w3069w(0)));
	wire_n1l1Ol_w_lg_dataout173w(0) <= NOT wire_n1l1Ol_dataout;
	wire_n1li_dataout <= (NOT pudi(4)) WHEN nO = '1'  ELSE pudi(4);
	wire_n1li0l_dataout <= n1l0iO AND n10O1Ol;
	wire_n1li0O_dataout <= n1l0li AND n10O1Ol;
	wire_n1li1i_dataout <= wire_n1li1O_o(2) WHEN wire_n1li0i_o(4) = '1'  ELSE wire_n1liil_dataout;
	wire_n1li1l_dataout <= wire_n1li1O_o(3) WHEN wire_n1li0i_o(4) = '1'  ELSE wire_n1liiO_dataout;
	wire_n1liil_dataout <= n1l0ll AND n10O1Ol;
	wire_n1liiO_dataout <= n1l0lO AND n10O1Ol;
	wire_n1liO0O_dataout <= (wire_w_lg_nlOO00ii16945w(0) AND ((NOT (wire_w_lg_nlOO01li16947w(0) OR wire_w_lg_nlOO01ii16950w(0))) AND (NOT (((nlOO011O OR nlOO011l) OR ((NOT (((nlOO011i OR nlOO1OOO) OR wire_nl1liOl_w_lg_o16956w(0)) OR (wire_nl1liOl_w_lg_o16842w(0) AND (wire_nl1liOi_o AND nlOO1OOi)))) AND (wire_w_lg_nlOO1OlO16962w(0) AND (wire_nl1liOO_w_lg_w_lg_o16856w16963w(0) OR (wire_nl1liOO_o AND nlOO1Oli))))) OR ((wire_nl1ll1O_w_lg_w_lg_o16853w16969w(0) OR (wire_nl1ll1O_o AND nlOO1Oli)) AND wire_w_lg_nlOO1OOO16973w(0)))))) WHEN ((NOT r8b10b_dec_ibm_en(0)) AND (NOT r8b10b_dec_ibm_en(1))) = '1'  ELSE (NOT (((((((((((((wire_w_lg_nlOO00ii16841w(0) OR (wire_nl1liOl_w_lg_o16842w(0) AND wire_nl1liOi_w_lg_w_lg_o16843w16844w(0))) OR wire_nl1liOl_w_lg_o16848w(0)) OR (wire_nl1ll1O_w_lg_o16852w(0) OR (wire_nl1ll1O_w_lg_o16853w(0) AND (wire_nl1ll1l_w_lg_o16854w(0) AND wire_nl1ll1i_w_lg_w_lg_o16855w16857w(0))))) OR (wire_nl1ll1l_w_lg_o16854w(0) AND (wire_nl1ll1i_w_lg_o16855w(0) AND (wire_nl1liOO_w_lg_o16856w(0) AND (wire_nl1liOl_w_lg_o16842w(0) AND wire_nl1liOi_w_lg_o16843w(0)))))) OR wire_nl1ll1l_w_lg_o16870w(0)) OR (wire_nl1ll1O_w_lg_o16853w(0) AND (wire_nl1ll1l_w_lg_o16854w(0) AND wire_nl1ll1i_w_lg_w_lg_o16855w16872w(0)))) OR wire_nl1ll1O_w_lg_o16878w(0)) OR (((wire_nl1ll1O_w_lg_o16853w(0) AND (wire_nl1ll1l_w_lg_o16854w(0) AND wire_nl1ll1i_w_lg_w_lg_o16855w16880w(0))) OR wire_nl1ll1O_w_lg_o16885w(0)) AND wire_w_lg_nlOO01OO16887w(0))) OR wire_w_lg_nlOO01OO16893w(0)) OR ((wire_nl1ll1O_w_lg_o16853w(0) AND (wire_nl1ll1l_w_lg_o16854w(0) AND wire_nl1ll1i_w_lg_w_lg_o16855w16895w(0))) AND wire_w_lg_nlOO001O16898w(0))) OR (wire_nl1ll1O_w_lg_o16903w(0) AND wire_w_lg_nlOO000i16904w(0))) OR wire_w_lg_w_r8b10b_dec_ibm_en_range3034w16923w(0)) OR wire_w_lg_w_r8b10b_dec_ibm_en_range3034w16942w(0)));
	wire_n1liO0O_w_lg_dataout4506w(0) <= NOT wire_n1liO0O_dataout;
	wire_n1ll_dataout <= (NOT pudi(5)) WHEN nO = '1'  ELSE pudi(5);
	wire_n1lliO_dataout <= wire_n1O1iO_dataout AND n1O01i;
	wire_n1lllii_dataout <= wire_n1l11lO_dataout WHEN ((wire_nl1llii_w_lg_w_lg_o16569w16808w(0) OR (wire_nl1llii_o AND nlOO0i1i)) OR (nlOO0i0O AND nlOO0i0i)) = '1'  ELSE (nlOO0i1l OR nlOO0i1O);
	wire_n1lllii_w_lg_w_lg_dataout16774w16804w(0) <= wire_n1lllii_w_lg_dataout16774w(0) AND nlOO00Ol;
	wire_n1lllii_w_lg_dataout16774w(0) <= NOT wire_n1lllii_dataout;
	wire_n1llOl_dataout <= wire_n1O1li_dataout AND n1O01i;
	wire_n1llOO_dataout <= n1OiOi AND n1O01l;
	wire_n1lO_dataout <= (NOT pudi(6)) WHEN nO = '1'  ELSE pudi(6);
	wire_n1lO0i_dataout <= n0110i AND NOT(n10O0ii);
	wire_n1lO0l_dataout <= wire_n1lOil_dataout AND NOT(wire_nl_w_lg_n1OiOi2540w(0));
	wire_n1lO0O_dataout <= n10O00O AND NOT(wire_nl_w_lg_n1OiOi2540w(0));
	wire_n1lO1i_dataout <= n0111i AND NOT(n10O0ii);
	wire_n1lO1l_dataout <= n0111l AND NOT(n10O0ii);
	wire_n1lO1O_dataout <= n0111O AND NOT(n10O0ii);
	wire_n1lOii_dataout <= wire_n1lOiO_dataout AND NOT(wire_nl_w_lg_n1OiOi2540w(0));
	wire_n1lOil_dataout <= wire_w_lg_n10O00l2717w(0) AND NOT(n10O00O);
	wire_n1lOiO_dataout <= n10O00l AND NOT(n10O00O);
	wire_n1lOlO_dataout <= n010OO AND NOT(n10O0ii);
	wire_n1lOOi_dataout <= n01i1i AND NOT(n10O0ii);
	wire_n1lOOl_dataout <= n01i1l AND NOT(n10O0ii);
	wire_n1lOOO_dataout <= n01i1O AND NOT(n10O0ii);
	wire_n1O_dataout <= wire_nlOi_dataout WHEN wa_6g_en = '1'  ELSE nl1lil;
	wire_n1O00i_dataout <= max_rlv_sel(0) AND NOT(wire_w_lg_w_pmadwidth_range175w219w(0));
	wire_n1O00i_w_lg_dataout2967w(0) <= NOT wire_n1O00i_dataout;
	wire_n1O00l_dataout <= max_rlv_sel(1) AND NOT(wire_w_lg_w_pmadwidth_range175w219w(0));
	wire_n1O00l_w_lg_dataout2965w(0) <= NOT wire_n1O00l_dataout;
	wire_n1O00O_dataout <= max_rlv_sel(0) WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE wire_n1O0lO_o(0);
	wire_n1O0ii_dataout <= max_rlv_sel(1) WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE wire_n1O0lO_o(1);
	wire_n1O0ii_w_lg_dataout2962w(0) <= NOT wire_n1O0ii_dataout;
	wire_n1O0il_dataout <= max_rlv_sel(2) WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE wire_n1O0lO_o(2);
	wire_n1O0il_w_lg_dataout2960w(0) <= NOT wire_n1O0il_dataout;
	wire_n1O0iO_dataout <= max_rlv_sel(3) WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE wire_n1O0lO_o(3);
	wire_n1O0iO_w_lg_dataout2958w(0) <= NOT wire_n1O0iO_dataout;
	wire_n1O0li_dataout <= max_rlv_sel(4) WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE wire_n1O0lO_o(4);
	wire_n1O0li_w_lg_dataout2956w(0) <= NOT wire_n1O0li_dataout;
	wire_n1O0ll_dataout <= wire_w_lg_n10O0li2685w(0) WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE wire_n1O0lO_o(5);
	wire_n1O0ll_w_lg_w2963w2964w(0) <= wire_n1O0ll_w2963w(0) AND wire_n1O00O_dataout;
	wire_n1O0ll_w2963w(0) <= wire_n1O0ll_w_lg_w_lg_w_lg_w_lg_dataout2955w2957w2959w2961w(0) AND wire_n1O0ii_w_lg_dataout2962w(0);
	wire_n1O0ll_w_lg_w_lg_w_lg_w_lg_dataout2955w2957w2959w2961w(0) <= wire_n1O0ll_w_lg_w_lg_w_lg_dataout2955w2957w2959w(0) AND wire_n1O0il_w_lg_dataout2960w(0);
	wire_n1O0ll_w_lg_w_lg_w_lg_dataout2955w2957w2959w(0) <= wire_n1O0ll_w_lg_w_lg_dataout2955w2957w(0) AND wire_n1O0iO_w_lg_dataout2958w(0);
	wire_n1O0ll_w_lg_w_lg_dataout2955w2957w(0) <= wire_n1O0ll_w_lg_dataout2955w(0) AND wire_n1O0li_w_lg_dataout2956w(0);
	wire_n1O0ll_w_lg_dataout2955w(0) <= NOT wire_n1O0ll_dataout;
	wire_n1O10i_dataout <= wire_n1O10O_dataout AND NOT(wire_nl_w_lg_n1OiOi2540w(0));
	wire_n1O10l_dataout <= wire_w_lg_n10O0il2712w(0) AND NOT(n10O0iO);
	wire_n1O10lO_dataout <= wire_n1lllii_dataout WHEN ((wire_nl1llll_o XOR wire_nl1llli_o) AND nlOO0iOi) = '1'  ELSE (nlOO0iOl OR nlOO0ilO);
	wire_n1O10O_dataout <= n10O0il AND NOT(n10O0iO);
	wire_n1O11l_dataout <= n10O0iO AND NOT(wire_nl_w_lg_n1OiOi2540w(0));
	wire_n1O11O_dataout <= wire_n1O10l_dataout AND NOT(wire_nl_w_lg_n1OiOi2540w(0));
	wire_n1O1iO_dataout <= n1OOOl AND NOT(wire_nl_w_lg_n1OiOi2540w(0));
	wire_n1O1li_dataout <= wire_nl_w_lg_n1OOOl2708w(0) AND NOT(wire_nl_w_lg_n1OiOi2540w(0));
	wire_n1Oi_dataout <= (NOT pudi(7)) WHEN nO = '1'  ELSE pudi(7);
	wire_n1Oiii_dataout <= n1Oi1O AND n1OiOi;
	wire_n1Oiil_dataout <= n1Oi0i AND n1OiOi;
	wire_n1OiiO_dataout <= n1iiill AND n1OiOi;
	wire_n1Oili_dataout <= wire_n1Oill_o AND n1OiOi;
	wire_n1Ol_dataout <= (NOT pudi(10)) WHEN nO = '1'  ELSE pudi(10);
	wire_n1Ol0iO_dataout <= wire_n1Ol0Ol_o(0) WHEN wire_n1Ol0OO_o(5) = '1'  ELSE wire_n1Oli1i_dataout;
	wire_n1Ol0li_dataout <= wire_n1Ol0Ol_o(1) WHEN wire_n1Ol0OO_o(5) = '1'  ELSE wire_n1Oli1l_dataout;
	wire_n1Ol0ll_dataout <= wire_n1Ol0Ol_o(2) WHEN wire_n1Ol0OO_o(5) = '1'  ELSE wire_n1Oli1O_dataout;
	wire_n1Ol0lO_dataout <= wire_n1Ol0Ol_o(3) WHEN wire_n1Ol0OO_o(5) = '1'  ELSE wire_n1Oli0l_dataout;
	wire_n1Ol0Oi_dataout <= wire_n1Ol0Ol_o(4) WHEN wire_n1Ol0OO_o(5) = '1'  ELSE wire_n1Oli0O_dataout;
	wire_n1Ol10O_dataout <= (wire_w_lg_nlOOi11i16601w(0) AND ((NOT (wire_w_lg_nlOO0O0i16603w(0) OR wire_w_lg_nlOO0O1i16606w(0))) AND (NOT (((nlOO0llO OR nlOO0lll) OR ((NOT (((nlOO0lli OR nlOO0liO) OR wire_nl1lliO_w_lg_o16612w(0)) OR (wire_nl1lliO_w_lg_o16498w(0) AND (wire_nl1llil_o AND nlOO0lii)))) AND (wire_w_lg_nlOO0l0O16618w(0) AND (wire_nl1llli_w_lg_w_lg_o16512w16619w(0) OR (wire_nl1llli_o AND nlOO0l0i))))) OR ((wire_nl1llOi_w_lg_w_lg_o16509w16625w(0) OR (wire_nl1llOi_o AND nlOO0l0i)) AND wire_w_lg_nlOO0liO16629w(0)))))) WHEN ((NOT r8b10b_dec_ibm_en(0)) AND (NOT r8b10b_dec_ibm_en(1))) = '1'  ELSE (NOT (((((((((((((wire_w_lg_nlOOi11i16497w(0) OR (wire_nl1lliO_w_lg_o16498w(0) AND wire_nl1llil_w_lg_w_lg_o16499w16500w(0))) OR wire_nl1lliO_w_lg_o16504w(0)) OR (wire_nl1llOi_w_lg_o16508w(0) OR (wire_nl1llOi_w_lg_o16509w(0) AND (wire_nl1lllO_w_lg_o16510w(0) AND wire_nl1llll_w_lg_w_lg_o16511w16513w(0))))) OR (wire_nl1lllO_w_lg_o16510w(0) AND (wire_nl1llll_w_lg_o16511w(0) AND (wire_nl1llli_w_lg_o16512w(0) AND (wire_nl1lliO_w_lg_o16498w(0) AND wire_nl1llil_w_lg_o16499w(0)))))) OR wire_nl1lllO_w_lg_o16526w(0)) OR (wire_nl1llOi_w_lg_o16509w(0) AND (wire_nl1lllO_w_lg_o16510w(0) AND wire_nl1llll_w_lg_w_lg_o16511w16528w(0)))) OR wire_nl1llOi_w_lg_o16534w(0)) OR (((wire_nl1llOi_w_lg_o16509w(0) AND (wire_nl1lllO_w_lg_o16510w(0) AND wire_nl1llll_w_lg_w_lg_o16511w16536w(0))) OR wire_nl1llOi_w_lg_o16541w(0)) AND wire_w_lg_nlOO0OiO16543w(0))) OR wire_w_lg_nlOO0OiO16549w(0)) OR ((wire_nl1llOi_w_lg_o16509w(0) AND (wire_nl1lllO_w_lg_o16510w(0) AND wire_nl1llll_w_lg_w_lg_o16511w16551w(0))) AND wire_w_lg_nlOO0OlO16554w(0))) OR (wire_nl1llOi_w_lg_o16559w(0) AND wire_w_lg_nlOO0OOi16560w(0))) OR wire_w_lg_w_r8b10b_dec_ibm_en_range3034w16579w(0)) OR wire_w_lg_w_r8b10b_dec_ibm_en_range3034w16598w(0)));
	wire_n1Ol10O_w_lg_dataout4507w(0) <= NOT wire_n1Ol10O_dataout;
	wire_n1Oli0l_dataout <= n1Ol00O AND nlOOi11l;
	wire_n1Oli0O_dataout <= n1Ol0ii AND nlOOi11l;
	wire_n1Oli1i_dataout <= n1Ol01O AND nlOOi11l;
	wire_n1Oli1l_dataout <= n1Ol00i AND nlOOi11l;
	wire_n1Oli1O_dataout <= n1Ol00l AND nlOOi11l;
	wire_n1Ollil_dataout <= wire_n1OO1li_dataout AND n1OO01l;
	wire_n1OllOi_dataout <= wire_n1OO1ll_dataout AND n1OO01l;
	wire_n1OllOl_dataout <= nlli0lO AND n1OO01O;
	wire_n1OllOO_dataout <= n011l0i AND NOT(nlOOi1li);
	wire_n1OlO0i_dataout <= n011lil AND NOT(nlOOi1li);
	wire_n1OlO0l_dataout <= wire_n1OlOil_dataout AND NOT(wire_nl_w_lg_nlli0lO15746w(0));
	wire_n1OlO0O_dataout <= nlOOi1iO AND NOT(wire_nl_w_lg_nlli0lO15746w(0));
	wire_n1OlO1i_dataout <= n011l0l AND NOT(nlOOi1li);
	wire_n1OlO1l_dataout <= n011l0O AND NOT(nlOOi1li);
	wire_n1OlO1O_dataout <= n011lii AND NOT(nlOOi1li);
	wire_n1OlOii_dataout <= wire_n1OlOiO_dataout AND NOT(wire_nl_w_lg_nlli0lO15746w(0));
	wire_n1OlOil_dataout <= wire_w_lg_nlOOi1il16159w(0) AND NOT(nlOOi1iO);
	wire_n1OlOiO_dataout <= nlOOi1il AND NOT(nlOOi1iO);
	wire_n1OlOlO_dataout <= n0101iO AND NOT(nlOOi1li);
	wire_n1OlOOi_dataout <= n0101li AND NOT(nlOOi1li);
	wire_n1OlOOl_dataout <= n0101ll AND NOT(nlOOi1li);
	wire_n1OlOOO_dataout <= n0101lO AND NOT(nlOOi1li);
	wire_n1OO_dataout <= (NOT pudi(11)) WHEN nO = '1'  ELSE pudi(11);
	wire_n1OO0Oi_dataout <= n1OO0iO AND nlli0lO;
	wire_n1OO0Ol_dataout <= n1OO0li AND nlli0lO;
	wire_n1OO0OO_dataout <= n1iiili AND nlli0lO;
	wire_n1OO10i_dataout <= wire_n1OO10O_dataout AND NOT(wire_nl_w_lg_nlli0lO15746w(0));
	wire_n1OO10l_dataout <= wire_n1OO1ii_dataout AND NOT(wire_nl_w_lg_nlli0lO15746w(0));
	wire_n1OO10O_dataout <= wire_w_lg_nlOOi1ll16154w(0) AND NOT(nlOOi1lO);
	wire_n1OO11i_dataout <= n0101Oi AND NOT(nlOOi1li);
	wire_n1OO11O_dataout <= nlOOi1lO AND NOT(wire_nl_w_lg_nlli0lO15746w(0));
	wire_n1OO1ii_dataout <= nlOOi1ll AND NOT(nlOOi1lO);
	wire_n1OO1li_dataout <= n011l1l AND NOT(wire_nl_w_lg_nlli0lO15746w(0));
	wire_n1OO1ll_dataout <= wire_nl_w_lg_n011l1l16150w(0) AND NOT(wire_nl_w_lg_nlli0lO15746w(0));
	wire_n1OOi1i_dataout <= wire_n1OOi1l_o AND nlli0lO;
	wire_n1OOOi_dataout <= n10O0ll WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE n10O0lO;
	wire_n1OOOi_w_lg_dataout2538w(0) <= NOT wire_n1OOOi_dataout;
	wire_ni_dataout <= gen2ngen1 WHEN rindv_rx = '1'  ELSE gen2ngen1_bundle;
	wire_ni0i_dataout <= wire_nl1l1il_dataout WHEN wa_6g_en = '1'  ELSE wire_niii1i_dataout;
	wire_ni0l_dataout <= wire_nl1iOil_dataout WHEN wa_6g_en = '1'  ELSE wire_nii01i_dataout;
	wire_ni0lO_dataout <= ni0li AND NOT(scan_mode);
	wire_ni0lO_w_lg_dataout2w(0) <= NOT wire_ni0lO_dataout;
	wire_ni0O_dataout <= wire_nl1iOiO_dataout WHEN wa_6g_en = '1'  ELSE wire_nii01l_dataout;
	wire_ni1i_dataout <= wire_nl1l10l_dataout WHEN wa_6g_en = '1'  ELSE wire_nii0Oi_dataout;
	wire_ni1l_dataout <= wire_nl1l10O_dataout WHEN wa_6g_en = '1'  ELSE wire_nii0Ol_dataout;
	wire_ni1O_dataout <= wire_nl1l1ii_dataout WHEN wa_6g_en = '1'  ELSE wire_nii0OO_dataout;
	wire_nii_dataout <= nl0100O WHEN wa_6g_en = '1'  ELSE niii0l;
	wire_nii00i_dataout <= nil0Ol AND NOT(rrxpcsbypass_en);
	wire_nii00l_dataout <= nil0OO AND NOT(rrxpcsbypass_en);
	wire_nii00O_dataout <= nili1i AND NOT(rrxpcsbypass_en);
	wire_nii01i_dataout <= nil0ll AND NOT(rrxpcsbypass_en);
	wire_nii01l_dataout <= nil0lO AND NOT(rrxpcsbypass_en);
	wire_nii01O_dataout <= nil0Oi AND NOT(rrxpcsbypass_en);
	wire_nii0i_dataout <= nl0100O WHEN wa_6g_en = '1'  ELSE nl1llO;
	wire_nii0ii_dataout <= nliOlO WHEN rrxpcsbypass_en = '1'  ELSE nil01i;
	wire_nii0il_dataout <= nliOOi WHEN rrxpcsbypass_en = '1'  ELSE nil01l;
	wire_nii0iO_dataout <= nliOOl WHEN rrxpcsbypass_en = '1'  ELSE nil01O;
	wire_nii0l_dataout <= nl010ii AND wa_6g_en;
	wire_nii0li_dataout <= nliOOO WHEN rrxpcsbypass_en = '1'  ELSE nil00i;
	wire_nii0ll_dataout <= nll11i WHEN rrxpcsbypass_en = '1'  ELSE nil00l;
	wire_nii0lO_dataout <= nll11l WHEN rrxpcsbypass_en = '1'  ELSE nil00O;
	wire_nii0O_dataout <= wire_nl1iOlO_dataout WHEN wa_6g_en = '1'  ELSE wire_nii00l_dataout;
	wire_nii0Oi_dataout <= nll11O WHEN rrxpcsbypass_en = '1'  ELSE nil0ii;
	wire_nii0Ol_dataout <= nll10i WHEN rrxpcsbypass_en = '1'  ELSE nil0il;
	wire_nii0OO_dataout <= wire_niii1l_dataout WHEN rrxpcsbypass_en = '1'  ELSE nil0iO;
	wire_nii1i_dataout <= nl0101O WHEN wa_6g_en = '1'  ELSE nl1lil;
	wire_nii1l_dataout <= nl0100i WHEN wa_6g_en = '1'  ELSE nl1liO;
	wire_nii1O_dataout <= nl0100l WHEN wa_6g_en = '1'  ELSE nl1lli;
	wire_niii_dataout <= wire_nl1iOli_dataout WHEN wa_6g_en = '1'  ELSE wire_nii01O_dataout;
	wire_niii1i_dataout <= wire_niii1O_dataout WHEN rrxpcsbypass_en = '1'  ELSE nil0li;
	wire_niii1l_dataout <= nll10l AND NOT(wire_w_lg_w_pmadwidth_range175w219w(0));
	wire_niii1O_dataout <= nll1ii AND NOT(wire_w_lg_w_pmadwidth_range175w219w(0));
	wire_niiii_dataout <= wire_nl1iOOi_dataout WHEN wa_6g_en = '1'  ELSE wire_nii00O_dataout;
	wire_niiil_dataout <= wire_nl1l1OO_dataout AND wa_6g_en;
	wire_niiiO_dataout <= wire_nl1l01i_dataout AND wa_6g_en;
	wire_niiiOO_dataout <= comp_pat(7) WHEN nill0l = '1'  ELSE comp_pat(0);
	wire_niil_dataout <= wire_nl1iOll_dataout WHEN wa_6g_en = '1'  ELSE wire_nii00i_dataout;
	wire_niil0i_dataout <= comp_pat(3) WHEN nill0l = '1'  ELSE comp_pat(4);
	wire_niil0l_dataout <= comp_pat(2) WHEN nill0l = '1'  ELSE comp_pat(5);
	wire_niil0O_dataout <= comp_pat(1) WHEN nill0l = '1'  ELSE comp_pat(6);
	wire_niil1i_dataout <= comp_pat(6) WHEN nill0l = '1'  ELSE comp_pat(1);
	wire_niil1l_dataout <= comp_pat(5) WHEN nill0l = '1'  ELSE comp_pat(2);
	wire_niil1O_dataout <= comp_pat(4) WHEN nill0l = '1'  ELSE comp_pat(3);
	wire_niili_dataout <= (NOT pudr(0)) WHEN nO = '1'  ELSE pudr(0);
	wire_niilii_dataout <= comp_pat(0) WHEN nill0l = '1'  ELSE comp_pat(7);
	wire_niilil_dataout <= comp_pat(15) WHEN nill0l = '1'  ELSE comp_pat(8);
	wire_niiliO_dataout <= comp_pat(14) WHEN nill0l = '1'  ELSE comp_pat(9);
	wire_niill_dataout <= (NOT pudr(1)) WHEN nO = '1'  ELSE pudr(1);
	wire_niilli_dataout <= comp_pat(13) WHEN nill0l = '1'  ELSE comp_pat(10);
	wire_niilll_dataout <= comp_pat(12) WHEN nill0l = '1'  ELSE comp_pat(11);
	wire_niillO_dataout <= comp_pat(11) WHEN nill0l = '1'  ELSE comp_pat(12);
	wire_niilO_dataout <= (NOT pudr(2)) WHEN nO = '1'  ELSE pudr(2);
	wire_niilOi_dataout <= comp_pat(10) WHEN nill0l = '1'  ELSE comp_pat(13);
	wire_niilOl_dataout <= comp_pat(9) WHEN nill0l = '1'  ELSE comp_pat(14);
	wire_niilOO_dataout <= comp_pat(8) WHEN nill0l = '1'  ELSE comp_pat(15);
	wire_niiO_dataout <= wire_nl1iOlO_dataout WHEN wa_6g_en = '1'  ELSE wire_nii00l_dataout;
	wire_niiO0i_dataout <= comp_pat(6) WHEN nill0l = '1'  ELSE comp_pat(3);
	wire_niiO0i_w_lg_dataout2058w(0) <= NOT wire_niiO0i_dataout;
	wire_niiO0l_dataout <= comp_pat(5) WHEN nill0l = '1'  ELSE comp_pat(4);
	wire_niiO0l_w_lg_dataout2062w(0) <= NOT wire_niiO0l_dataout;
	wire_niiO0O_dataout <= comp_pat(4) WHEN nill0l = '1'  ELSE comp_pat(5);
	wire_niiO0O_w_lg_dataout2066w(0) <= NOT wire_niiO0O_dataout;
	wire_niiO1i_dataout <= comp_pat(9) WHEN nill0l = '1'  ELSE comp_pat(0);
	wire_niiO1i_w_lg_dataout2047w(0) <= NOT wire_niiO1i_dataout;
	wire_niiO1l_dataout <= comp_pat(8) WHEN nill0l = '1'  ELSE comp_pat(1);
	wire_niiO1l_w_lg_dataout2050w(0) <= NOT wire_niiO1l_dataout;
	wire_niiO1O_dataout <= comp_pat(7) WHEN nill0l = '1'  ELSE comp_pat(2);
	wire_niiO1O_w_lg_dataout2054w(0) <= NOT wire_niiO1O_dataout;
	wire_niiOi_dataout <= (NOT pudr(3)) WHEN nO = '1'  ELSE pudr(3);
	wire_niiOii_dataout <= comp_pat(3) WHEN nill0l = '1'  ELSE comp_pat(6);
	wire_niiOii_w_lg_dataout2070w(0) <= NOT wire_niiOii_dataout;
	wire_niiOil_dataout <= comp_pat(2) WHEN nill0l = '1'  ELSE comp_pat(7);
	wire_niiOil_w_lg_dataout2074w(0) <= NOT wire_niiOil_dataout;
	wire_niiOiO_dataout <= comp_pat(1) WHEN nill0l = '1'  ELSE comp_pat(8);
	wire_niiOiO_w_lg_dataout2078w(0) <= NOT wire_niiOiO_dataout;
	wire_niiOl_dataout <= (NOT pudr(4)) WHEN nO = '1'  ELSE pudr(4);
	wire_niiOli_dataout <= comp_pat(0) WHEN nill0l = '1'  ELSE comp_pat(9);
	wire_niiOli_w_lg_dataout2082w(0) <= NOT wire_niiOli_dataout;
	wire_niiOO_dataout <= (NOT pudr(5)) WHEN nO = '1'  ELSE pudr(5);
	wire_nil_dataout <= nl010ii WHEN wa_6g_en = '1'  ELSE nlO01ii;
	wire_nil0i_dataout <= (NOT pudr(9)) WHEN nO = '1'  ELSE pudr(9);
	wire_nil0l_dataout <= (NOT pudi(0)) WHEN nO = '1'  ELSE pudi(0);
	wire_nil0O_dataout <= (NOT pudi(1)) WHEN nO = '1'  ELSE pudi(1);
	wire_nil10l_dataout <= (n1i1OOO OR n1i1OOl) WHEN n1i1OOi = '1'  ELSE (n1i011l OR n1i011i);
	wire_nil1i_dataout <= (NOT pudr(6)) WHEN nO = '1'  ELSE pudr(6);
	wire_nil1l_dataout <= (NOT pudr(7)) WHEN nO = '1'  ELSE pudr(7);
	wire_nil1O_dataout <= (NOT pudr(8)) WHEN nO = '1'  ELSE pudr(8);
	wire_nili_dataout <= wire_nl1iOOi_dataout WHEN wa_6g_en = '1'  ELSE wire_nii00O_dataout;
	wire_nilii_dataout <= (NOT pudi(2)) WHEN nO = '1'  ELSE pudi(2);
	wire_nilil_dataout <= (NOT pudi(3)) WHEN nO = '1'  ELSE pudi(3);
	wire_niliO_dataout <= (NOT pudi(4)) WHEN nO = '1'  ELSE pudi(4);
	wire_nill_dataout <= wire_nl1l01l_dataout AND wa_6g_en;
	wire_nilli_dataout <= (NOT pudi(5)) WHEN nO = '1'  ELSE pudi(5);
	wire_nillii_dataout <= ((nil1ll OR n1i011O) OR (n1iiiOi AND nil1il)) AND n1ii10i;
	wire_nillil_dataout <= ((nil1lO OR n1i010i) OR (n1iiiOi AND nil1iO)) WHEN n1ii10i = '1'  ELSE ((nil1li OR wire_nil10l_dataout) OR (n1iiiOi AND niii0O));
	wire_nilll_dataout <= (NOT pudi(6)) WHEN nO = '1'  ELSE pudi(6);
	wire_nilllO_dataout <= wire_niiiOO_dataout WHEN n1i010O = '1'  ELSE wire_nilOii_dataout;
	wire_nillO_dataout <= (NOT pudi(7)) WHEN nO = '1'  ELSE pudi(7);
	wire_nillOi_dataout <= wire_niil1i_dataout WHEN n1i010O = '1'  ELSE wire_nilOil_dataout;
	wire_nillOl_dataout <= wire_niil1l_dataout WHEN n1i010O = '1'  ELSE wire_nilOiO_dataout;
	wire_nillOO_dataout <= wire_niil1O_dataout WHEN n1i010O = '1'  ELSE wire_nilOli_dataout;
	wire_nilO_dataout <= wire_nl1l01O_dataout AND wa_6g_en;
	wire_nilO0i_dataout <= wire_niilii_dataout WHEN n1i010O = '1'  ELSE wire_nilOOl_dataout;
	wire_nilO0l_dataout <= nilili WHEN n1i010O = '1'  ELSE wire_nilOOO_dataout;
	wire_nilO0O_dataout <= wire_niO11i_dataout AND NOT(n1i010O);
	wire_nilO1i_dataout <= wire_niil0i_dataout WHEN n1i010O = '1'  ELSE wire_nilOll_dataout;
	wire_nilO1l_dataout <= wire_niil0l_dataout WHEN n1i010O = '1'  ELSE wire_nilOlO_dataout;
	wire_nilO1O_dataout <= wire_niil0O_dataout WHEN n1i010O = '1'  ELSE wire_nilOOi_dataout;
	wire_nilOi_dataout <= (NOT pudi(8)) WHEN nO = '1'  ELSE pudi(8);
	wire_nilOii_dataout <= nili1l WHEN n1i010l = '1'  ELSE wire_niOill_o;
	wire_nilOil_dataout <= nili1O WHEN n1i010l = '1'  ELSE wire_niOilO_o;
	wire_nilOiO_dataout <= nili0i WHEN n1i010l = '1'  ELSE wire_niOiOi_o;
	wire_nilOl_dataout <= (NOT pudi(9)) WHEN nO = '1'  ELSE pudi(9);
	wire_nilOli_dataout <= nili0l WHEN n1i010l = '1'  ELSE wire_niOiOl_o;
	wire_nilOll_dataout <= nili0O WHEN n1i010l = '1'  ELSE wire_niOiOO_o;
	wire_nilOlO_dataout <= niliii WHEN n1i010l = '1'  ELSE wire_niOl1i_o;
	wire_nilOO_dataout <= wire_nl0li_dataout WHEN n1iii1l = '1'  ELSE wire_nl10l_dataout;
	wire_nilOOi_dataout <= niliil WHEN n1i010l = '1'  ELSE wire_niOl1l_o;
	wire_nilOOl_dataout <= niliiO WHEN n1i010l = '1'  ELSE wire_niOl1O_o;
	wire_nilOOO_dataout <= nilili WHEN n1i010l = '1'  ELSE wire_niOl0i_dataout;
	wire_niO0i_dataout <= wire_nl0Ol_dataout WHEN n1iii1l = '1'  ELSE wire_nl1iO_dataout;
	wire_niO0l_dataout <= wire_nl0OO_dataout WHEN n1iii1l = '1'  ELSE wire_nl1li_dataout;
	wire_niO0O_dataout <= wire_nli1i_dataout WHEN n1iii1l = '1'  ELSE wire_nl1ll_dataout;
	wire_niO10l_dataout <= wire_niiiOO_dataout WHEN n1i01ii = '1'  ELSE nilill;
	wire_niO10O_dataout <= wire_niil1i_dataout WHEN n1i01ii = '1'  ELSE nililO;
	wire_niO11i_dataout <= wire_niOl0l_dataout AND NOT(n1i010l);
	wire_niO1i_dataout <= wire_nl0ll_dataout WHEN n1iii1l = '1'  ELSE wire_nl10O_dataout;
	wire_niO1ii_dataout <= wire_niil1l_dataout WHEN n1i01ii = '1'  ELSE niliOi;
	wire_niO1il_dataout <= wire_niil1O_dataout WHEN n1i01ii = '1'  ELSE niliOl;
	wire_niO1iO_dataout <= wire_niil0i_dataout WHEN n1i01ii = '1'  ELSE niliOO;
	wire_niO1l_dataout <= wire_nl0lO_dataout WHEN n1iii1l = '1'  ELSE wire_nl1ii_dataout;
	wire_niO1li_dataout <= wire_niil0l_dataout WHEN n1i01ii = '1'  ELSE nill1i;
	wire_niO1ll_dataout <= wire_niil0O_dataout WHEN n1i01ii = '1'  ELSE nill1l;
	wire_niO1lO_dataout <= wire_niilii_dataout WHEN n1i01ii = '1'  ELSE nill1O;
	wire_niO1O_dataout <= wire_nl0Oi_dataout WHEN n1iii1l = '1'  ELSE wire_nl1il_dataout;
	wire_niOi_dataout <= wire_nl1l00i_dataout AND wa_6g_en;
	wire_niOi0i_dataout <= niOlOO WHEN nill0l = '1'  ELSE niOllO;
	wire_niOi0l_dataout <= niOlOl WHEN nill0l = '1'  ELSE niOlOi;
	wire_niOi0O_dataout <= niOlOi WHEN nill0l = '1'  ELSE niOlOl;
	wire_niOi1i_dataout <= niOO1O WHEN nill0l = '1'  ELSE niOlil;
	wire_niOi1l_dataout <= niOO1l WHEN nill0l = '1'  ELSE niOlli;
	wire_niOi1O_dataout <= niOO1i WHEN nill0l = '1'  ELSE niOlll;
	wire_niOii_dataout <= wire_nli1l_dataout WHEN n1iii1l = '1'  ELSE wire_nl1lO_dataout;
	wire_niOiii_dataout <= niOllO WHEN nill0l = '1'  ELSE niOlOO;
	wire_niOiil_dataout <= niOlll WHEN nill0l = '1'  ELSE niOO1i;
	wire_niOiiO_dataout <= niOlli WHEN nill0l = '1'  ELSE niOO1l;
	wire_niOil_dataout <= wire_nli1O_dataout WHEN n1iii1l = '1'  ELSE wire_nl1Oi_dataout;
	wire_niOili_dataout <= niOlil WHEN nill0l = '1'  ELSE niOO1O;
	wire_niOiO_dataout <= wire_nli0i_dataout WHEN n1iii1l = '1'  ELSE wire_nl1Ol_dataout;
	wire_niOl_dataout <= wire_nl1l00l_dataout AND wa_6g_en;
	wire_niOl0i_dataout <= niOOOO WHEN n1i00Oi = '1'  ELSE nl11ii;
	wire_niOl0i_w_lg_w_lg_dataout1313w3182w(0) <= wire_niOl0i_w_lg_dataout1313w(0) AND wire_niOl1O_w_lg_w_lg_o1314w3181w(0);
	wire_niOl0i_w_lg_w_lg_dataout1313w3202w(0) <= wire_niOl0i_w_lg_dataout1313w(0) AND n10lO0i;
	wire_niOl0i_w_lg_w_lg_dataout1313w3199w(0) <= wire_niOl0i_w_lg_dataout1313w(0) AND n10lO0l;
	wire_niOl0i_w_lg_w_lg_dataout1313w3221w(0) <= wire_niOl0i_w_lg_dataout1313w(0) AND n10lO1l;
	wire_niOl0i_w_lg_w_lg_dataout1313w3216w(0) <= wire_niOl0i_w_lg_dataout1313w(0) AND n10lO1O;
	wire_niOl0i_w_lg_w_lg_dataout1313w3018w(0) <= wire_niOl0i_w_lg_dataout1313w(0) AND n10O10i;
	wire_niOl0i_w_lg_dataout3205w(0) <= wire_niOl0i_dataout AND wire_niOl1O_w_lg_w_lg_o1314w2984w(0);
	wire_niOl0i_w_lg_dataout3224w(0) <= wire_niOl0i_dataout AND wire_niOl1O_w_lg_w_lg_o1314w3189w(0);
	wire_niOl0i_w_lg_dataout3179w(0) <= wire_niOl0i_dataout AND wire_niOl1O_w_lg_o3178w(0);
	wire_niOl0i_w_lg_dataout2997w(0) <= wire_niOl0i_dataout AND wire_niOl1O_w_lg_o2996w(0);
	wire_niOl0i_w_lg_dataout3011w(0) <= wire_niOl0i_dataout AND wire_niOl1O_w_lg_o3010w(0);
	wire_niOl0i_w_lg_dataout3227w(0) <= wire_niOl0i_dataout AND wire_niOl1O_w_lg_o3190w(0);
	wire_niOl0i_w_lg_dataout3004w(0) <= wire_niOl0i_dataout AND wire_niOl1O_w_lg_o3003w(0);
	wire_niOl0i_w_lg_dataout3029w(0) <= wire_niOl0i_dataout AND wire_niOl1O_w_lg_o3028w(0);
	wire_niOl0i_w_lg_dataout1320w(0) <= wire_niOl0i_dataout AND wire_niOl1O_w_lg_o1319w(0);
	wire_niOl0i_w_lg_dataout2981w(0) <= wire_niOl0i_dataout AND wire_niOl1O_w_lg_o2980w(0);
	wire_niOl0i_w_lg_dataout3017w(0) <= wire_niOl0i_dataout AND n10O10l;
	wire_niOl0i_w_lg_dataout1313w(0) <= NOT wire_niOl0i_dataout;
	wire_niOl0i_w_lg_w_lg_dataout3179w3183w(0) <= wire_niOl0i_w_lg_dataout3179w(0) OR wire_niOl0i_w_lg_w_lg_dataout1313w3182w(0);
	wire_niOl0i_w_lg_w_lg_dataout3017w3019w(0) <= wire_niOl0i_w_lg_dataout3017w(0) OR wire_niOl0i_w_lg_w_lg_dataout1313w3018w(0);
	wire_niOl0l_dataout <= niOO0i WHEN n1i00Oi = '1'  ELSE nl11il;
	wire_niOl0l_w_lg_w_lg_dataout3064w3066w(0) <= wire_niOl0l_w_lg_dataout3064w(0) AND wire_niOl1O_w_lg_o3065w(0);
	wire_niOl0l_w_lg_w_lg_dataout1312w3091w(0) <= wire_niOl0l_w_lg_dataout1312w(0) AND n10lOll;
	wire_niOl0l_w_lg_dataout3203w(0) <= wire_niOl0l_dataout AND wire_niOl0i_w_lg_w_lg_dataout1313w3202w(0);
	wire_niOl0l_w_lg_dataout3200w(0) <= wire_niOl0l_dataout AND wire_niOl0i_w_lg_w_lg_dataout1313w3199w(0);
	wire_niOl0l_w_lg_dataout3222w(0) <= wire_niOl0l_dataout AND wire_niOl0i_w_lg_w_lg_dataout1313w3221w(0);
	wire_niOl0l_w_lg_dataout3217w(0) <= wire_niOl0l_dataout AND wire_niOl0i_w_lg_w_lg_dataout1313w3216w(0);
	wire_niOl0l_w_lg_dataout3206w(0) <= wire_niOl0l_dataout AND wire_niOl0i_w_lg_dataout3205w(0);
	wire_niOl0l_w_lg_dataout3225w(0) <= wire_niOl0l_dataout AND wire_niOl0i_w_lg_dataout3224w(0);
	wire_niOl0l_w_lg_dataout3012w(0) <= wire_niOl0l_dataout AND wire_niOl0i_w_lg_dataout3011w(0);
	wire_niOl0l_w_lg_dataout3228w(0) <= wire_niOl0l_dataout AND wire_niOl0i_w_lg_dataout3227w(0);
	wire_niOl0l_w_lg_dataout3005w(0) <= wire_niOl0l_dataout AND wire_niOl0i_w_lg_dataout3004w(0);
	wire_niOl0l_w_lg_dataout3030w(0) <= wire_niOl0l_dataout AND wire_niOl0i_w_lg_dataout3029w(0);
	wire_niOl0l_w_lg_dataout1321w(0) <= wire_niOl0l_dataout AND wire_niOl0i_w_lg_dataout1320w(0);
	wire_niOl0l_w_lg_dataout2982w(0) <= wire_niOl0l_dataout AND wire_niOl0i_w_lg_dataout2981w(0);
	wire_niOl0l_w_lg_dataout3064w(0) <= wire_niOl0l_dataout AND wire_niOl0i_dataout;
	wire_niOl0l_w_lg_dataout1312w(0) <= NOT wire_niOl0l_dataout;
	wire_niOl0l_w_lg_dataout3061w(0) <= wire_niOl0l_dataout OR wire_niOl0i_dataout;
	wire_niOli_dataout <= wire_nli0l_dataout WHEN n1iii1l = '1'  ELSE wire_nl1OO_dataout;
	wire_niOll_dataout <= wire_nli0O_dataout WHEN n1iii1l = '1'  ELSE wire_nl01i_dataout;
	wire_niOlO_dataout <= wire_nliii_dataout WHEN n1iii1l = '1'  ELSE wire_nl01l_dataout;
	wire_niOO_dataout <= wire_nl1l00O_dataout AND wa_6g_en;
	wire_niOOi_dataout <= wire_nliil_dataout WHEN n1iii1l = '1'  ELSE wire_nl01O_dataout;
	wire_niOOl_dataout <= wire_nliiO_dataout WHEN n1iii1l = '1'  ELSE wire_nl00i_dataout;
	wire_niOOO_dataout <= wire_nlili_dataout WHEN n1iii1l = '1'  ELSE wire_nl00l_dataout;
	wire_nl0000i_dataout <= wire_nl00O1i_o WHEN n111lOl = '1'  ELSE wire_nl00iiO_dataout;
	wire_nl0000l_dataout <= wire_nl00O1l_o WHEN n111lOl = '1'  ELSE wire_nl00ili_dataout;
	wire_nl0000O_dataout <= wire_nl00O1O_o WHEN n111lOl = '1'  ELSE wire_nl00ill_dataout;
	wire_nl0001i_dataout <= wire_nl00lOi_o WHEN n111lOl = '1'  ELSE wire_nl00i0O_dataout;
	wire_nl0001l_dataout <= wire_nl00lOl_o WHEN n111lOl = '1'  ELSE wire_nl00iii_dataout;
	wire_nl0001O_dataout <= wire_nl00lOO_o WHEN n111lOl = '1'  ELSE wire_nl00iil_dataout;
	wire_nl000i_dataout <= ((wire_nl_w_lg_nl1ill312w(0) AND (n1i0lll AND nlOiO1i)) OR wire_nl_w_lg_nl1ill365w(0)) WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE (n1i0llO OR n1i0lll);
	wire_nl000i_w_lg_dataout421w(0) <= NOT wire_nl000i_dataout;
	wire_nl000ii_dataout <= wire_nl00O0i_o WHEN n111lOl = '1'  ELSE wire_nl00ilO_dataout;
	wire_nl000il_dataout <= wire_nl00O0l_o WHEN n111lOl = '1'  ELSE wire_nl00iOi_dataout;
	wire_nl000iO_dataout <= wire_nl00O0O_o WHEN n111lOl = '1'  ELSE wire_nl00iOl_dataout;
	wire_nl000li_dataout <= wire_nl00iOO_dataout AND NOT(n111lOl);
	wire_nl000ll_dataout <= wire_nl00l1i_dataout AND NOT(n111lOl);
	wire_nl000lO_dataout <= wire_nl00l1l_dataout AND NOT(n111lOl);
	wire_nl000Oi_dataout <= wire_nl00l1O_dataout AND NOT(n111lOl);
	wire_nl000Ol_dataout <= wire_nl00OiO_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00lii_o;
	wire_nl000OO_dataout <= wire_nl00Oli_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00lil_o;
	wire_nl0010i_dataout <= wire_nl0i1il_o WHEN n111lOO = '1'  ELSE wire_nl000iO_dataout;
	wire_nl0010l_dataout <= wire_nl0i1iO_o WHEN n111lOO = '1'  ELSE wire_nl000li_dataout;
	wire_nl0010O_dataout <= wire_nl0i1li_o WHEN n111lOO = '1'  ELSE wire_nl000ll_dataout;
	wire_nl0011i_dataout <= wire_nl0i10l_o WHEN n111lOO = '1'  ELSE wire_nl0000O_dataout;
	wire_nl0011l_dataout <= wire_nl0i10O_o WHEN n111lOO = '1'  ELSE wire_nl000ii_dataout;
	wire_nl0011O_dataout <= wire_nl0i1ii_o WHEN n111lOO = '1'  ELSE wire_nl000il_dataout;
	wire_nl001i_dataout <= ((wire_nl_w_lg_nl1ill312w(0) AND (n1i0liO AND nlOiO1l)) OR wire_nl_w_lg_nl1ill373w(0)) WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE (n1i0lli OR n1i0liO);
	wire_nl001i_w_lg_dataout415w(0) <= NOT wire_nl001i_dataout;
	wire_nl001ii_dataout <= wire_nl0i1ll_o WHEN n111lOO = '1'  ELSE wire_nl000lO_dataout;
	wire_nl001il_dataout <= wire_nl0i1lO_o WHEN n111lOO = '1'  ELSE wire_nl000Oi_dataout;
	wire_nl001iO_dataout <= wire_nl00l0O_o WHEN n111lOl = '1'  ELSE wire_nl000Ol_dataout;
	wire_nl001li_dataout <= wire_nl00lii_o WHEN n111lOl = '1'  ELSE wire_nl000OO_dataout;
	wire_nl001ll_dataout <= wire_nl00lil_o WHEN n111lOl = '1'  ELSE wire_nl00i1i_dataout;
	wire_nl001lO_dataout <= wire_nl00liO_o WHEN n111lOl = '1'  ELSE wire_nl00i1l_dataout;
	wire_nl001Oi_dataout <= wire_nl00lli_o WHEN n111lOl = '1'  ELSE wire_nl00i1O_dataout;
	wire_nl001Ol_dataout <= wire_nl00lll_o WHEN n111lOl = '1'  ELSE wire_nl00i0i_dataout;
	wire_nl001OO_dataout <= wire_nl00llO_o WHEN n111lOl = '1'  ELSE wire_nl00i0l_dataout;
	wire_nl00i_dataout <= (NOT pudr(14)) WHEN nO = '1'  ELSE pudr(14);
	wire_nl00i0i_dataout <= wire_nl00OOl_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00llO_o;
	wire_nl00i0l_dataout <= wire_nl00OOO_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00lOi_o;
	wire_nl00i0O_dataout <= wire_nl0i11i_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00lOl_o;
	wire_nl00i1i_dataout <= wire_nl00Oll_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00liO_o;
	wire_nl00i1l_dataout <= wire_nl00OlO_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00lli_o;
	wire_nl00i1O_dataout <= wire_nl00OOi_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00lll_o;
	wire_nl00ii_dataout <= ((wire_nl_w_lg_nl1ill312w(0) AND (n1i0lOO AND nlOilOO)) OR wire_nl_w_lg_nl1ill357w(0)) WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE ((n1i0O1i OR n1i0lOO) OR (NOT (n1i0lOi48 XOR n1i0lOi47)));
	wire_nl00ii_w_lg_dataout428w(0) <= NOT wire_nl00ii_dataout;
	wire_nl00iii_dataout <= wire_nl0i11l_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00lOO_o;
	wire_nl00iil_dataout <= wire_nl0i11O_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00O1i_o;
	wire_nl00iiO_dataout <= wire_nl0i10i_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00O1l_o;
	wire_nl00ili_dataout <= wire_nl0i10l_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00O1O_o;
	wire_nl00ill_dataout <= wire_nl0i10O_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00O0i_o;
	wire_nl00ilO_dataout <= wire_nl0i1ii_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00O0l_o;
	wire_nl00iOi_dataout <= wire_nl0i1il_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00O0O_o;
	wire_nl00iOl_dataout <= wire_nl0i1iO_o WHEN (NOT comp_pat_size(0)) = '1'  ELSE wire_nl00l0i_o;
	wire_nl00iOO_dataout <= wire_nl0i1li_o AND (NOT comp_pat_size(0));
	wire_nl00l_dataout <= (NOT pudr(15)) WHEN nO = '1'  ELSE pudr(15);
	wire_nl00l1i_dataout <= wire_nl0i1ll_o AND (NOT comp_pat_size(0));
	wire_nl00l1l_dataout <= wire_nl0i1lO_o AND (NOT comp_pat_size(0));
	wire_nl00l1O_dataout <= wire_nl00l0l_o AND (NOT comp_pat_size(0));
	wire_nl00li_dataout <= ((wire_nl_w_lg_nl1ill312w(0) AND (n1i0O0O AND nlOilOl)) OR (wire_nl_w_lg_nl1ill342w(0) AND (n1i0O1l46 XOR n1i0O1l45))) WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE (n1i0Oii OR n1i0O0O);
	wire_nl00li_w_lg_dataout436w(0) <= NOT wire_nl00li_dataout;
	wire_nl00O_dataout <= (NOT pudr(16)) WHEN nO = '1'  ELSE pudr(16);
	wire_nl00Oi_dataout <= ((((wire_nl_w_lg_nl1ill312w(0) AND ((n1ii11i AND nlOiilO) AND (n1i0OOl36 XOR n1i0OOl35))) AND (n1i0OlO38 XOR n1i0OlO37)) OR wire_nl_w_lg_nl1ill327w(0)) OR (NOT (n1i0Oil42 XOR n1i0Oil41))) WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE (n1ii11l OR n1ii11i);
	wire_nl00Oi_w_lg_dataout1914w(0) <= wire_nl00Oi_dataout AND wire_nl00li_w_lg_dataout436w(0);
	wire_nl010l_dataout <= (n1i0l1l OR n1i0l1i) AND NOT(wire_w_lg_w_pmadwidth_range175w219w(0));
	wire_nl010l_w_lg_dataout401w(0) <= NOT wire_nl010l_dataout;
	wire_nl011i_dataout <= nl10ll WHEN autobytealign_dis = '1'  ELSE nl1lli;
	wire_nl011l_dataout <= nl10Oi WHEN autobytealign_dis = '1'  ELSE nl1llO;
	wire_nl011O_dataout <= (n1i0iOO OR n1i0iOl) AND NOT(wire_w_lg_w_pmadwidth_range175w219w(0));
	wire_nl011O_w_lg_dataout1922w(0) <= NOT wire_nl011O_dataout;
	wire_nl011O_w_lg_dataout446w(0) <= wire_nl011O_dataout OR wire_w_lg_n1i0iOi445w(0);
	wire_nl01i_dataout <= (NOT pudr(11)) WHEN nO = '1'  ELSE pudr(11);
	wire_nl01ii_dataout <= ((wire_nl_w_lg_nl1ill312w(0) AND (n1i0l1O AND nlOiO0l)) OR wire_nl_w_lg_nl1ill397w(0)) WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE (n1i0l0i OR n1i0l1O);
	wire_nl01ii_w_lg_dataout403w(0) <= NOT wire_nl01ii_dataout;
	wire_nl01l_dataout <= (NOT pudr(12)) WHEN nO = '1'  ELSE pudr(12);
	wire_nl01li_dataout <= ((wire_nl_w_lg_nl1ill312w(0) AND (n1i0l0l AND nlOiO0i)) OR wire_nl_w_lg_nl1ill389w(0)) WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE (n1i0l0O OR n1i0l0l);
	wire_nl01li_w_lg_dataout406w(0) <= NOT wire_nl01li_dataout;
	wire_nl01O_dataout <= (NOT pudr(13)) WHEN nO = '1'  ELSE pudr(13);
	wire_nl01O0i_dataout <= wire_nl00Oil_o WHEN n111lOO = '1'  ELSE wire_nl001iO_dataout;
	wire_nl01O0l_dataout <= wire_nl00OiO_o WHEN n111lOO = '1'  ELSE wire_nl001li_dataout;
	wire_nl01O0O_dataout <= wire_nl00Oli_o WHEN n111lOO = '1'  ELSE wire_nl001ll_dataout;
	wire_nl01Oi_dataout <= ((wire_nl_w_lg_nl1ill312w(0) AND (n1i0lii AND nlOiO1O)) OR wire_nl_w_lg_nl1ill381w(0)) WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE (n1i0lil OR n1i0lii);
	wire_nl01Oi_w_lg_dataout410w(0) <= NOT wire_nl01Oi_dataout;
	wire_nl01Oii_dataout <= wire_nl00Oll_o WHEN n111lOO = '1'  ELSE wire_nl001lO_dataout;
	wire_nl01Oil_dataout <= wire_nl00OlO_o WHEN n111lOO = '1'  ELSE wire_nl001Oi_dataout;
	wire_nl01OiO_dataout <= wire_nl00OOi_o WHEN n111lOO = '1'  ELSE wire_nl001Ol_dataout;
	wire_nl01Oli_dataout <= wire_nl00OOl_o WHEN n111lOO = '1'  ELSE wire_nl001OO_dataout;
	wire_nl01Oll_dataout <= wire_nl00OOO_o WHEN n111lOO = '1'  ELSE wire_nl0001i_dataout;
	wire_nl01OlO_dataout <= wire_nl0i11i_o WHEN n111lOO = '1'  ELSE wire_nl0001l_dataout;
	wire_nl01OOi_dataout <= wire_nl0i11l_o WHEN n111lOO = '1'  ELSE wire_nl0001O_dataout;
	wire_nl01OOl_dataout <= wire_nl0i11O_o WHEN n111lOO = '1'  ELSE wire_nl0000i_dataout;
	wire_nl01OOO_dataout <= wire_nl0i10i_o WHEN n111lOO = '1'  ELSE wire_nl0000l_dataout;
	wire_nl0i_dataout <= wire_nl1l0li_dataout AND wa_6g_en;
	wire_nl0i00i_dataout <= wire_nl0i0iO_dataout WHEN n111O1l = '1'  ELSE nl0101O;
	wire_nl0i00l_dataout <= wire_nl0i0li_dataout WHEN n111O1l = '1'  ELSE nl0100i;
	wire_nl0i00O_dataout <= wire_nl0i0ll_dataout WHEN n111O1l = '1'  ELSE nl0100l;
	wire_nl0i01i_dataout <= n110ill WHEN n111O1O = '1'  ELSE wire_nl0i00O_dataout;
	wire_nl0i01l_dataout <= n110ilO WHEN n111O1O = '1'  ELSE wire_nl0i0ii_dataout;
	wire_nl0i01O_dataout <= n110iOi WHEN n111O1O = '1'  ELSE wire_nl0i0il_dataout;
	wire_nl0i0i_dataout <= nliO0O WHEN n1ii11O = '1'  ELSE wire_nl0iOl_dataout;
	wire_nl0i0ii_dataout <= wire_nl0i0lO_dataout WHEN n111O1l = '1'  ELSE nl0100O;
	wire_nl0i0il_dataout <= wire_nl0i0Oi_dataout WHEN n111O1l = '1'  ELSE nl010ii;
	wire_nl0i0iO_dataout <= wire_nl0i0Ol_o AND NOT(n111O1i);
	wire_nl0i0l_dataout <= nliOii WHEN n1ii11O = '1'  ELSE wire_nl0iOO_dataout;
	wire_nl0i0li_dataout <= wire_nl0i0OO_o AND NOT(n111O1i);
	wire_nl0i0ll_dataout <= wire_nl0ii1i_o AND NOT(n111O1i);
	wire_nl0i0lO_dataout <= wire_nl0ii1l_o AND NOT(n111O1i);
	wire_nl0i0O_dataout <= nliOil WHEN n1ii11O = '1'  ELSE wire_nl0l1i_dataout;
	wire_nl0i0Oi_dataout <= wire_nl0ii1O_o AND NOT(n111O1i);
	wire_nl0i1i_dataout <= nliO1O WHEN n1ii11O = '1'  ELSE wire_nl0ill_dataout;
	wire_nl0i1l_dataout <= nliO0i WHEN n1ii11O = '1'  ELSE wire_nl0ilO_dataout;
	wire_nl0i1O_dataout <= nliO0l WHEN n1ii11O = '1'  ELSE wire_nl0iOi_dataout;
	wire_nl0i1Ol_dataout <= wire_w_lg_n110iiO5931w(0) WHEN n111O1O = '1'  ELSE wire_nl0i00i_dataout;
	wire_nl0i1OO_dataout <= wire_w_lg_n110ili5930w(0) WHEN n111O1O = '1'  ELSE wire_nl0i00l_dataout;
	wire_nl0ii_dataout <= (NOT pudr(17)) WHEN nO = '1'  ELSE pudr(17);
	wire_nl0ii0i_dataout <= wire_nl0iiiO_dataout WHEN nlli00i = '1'  ELSE nl0101O;
	wire_nl0ii0l_dataout <= wire_nl0iili_dataout WHEN nlli00i = '1'  ELSE nl0100i;
	wire_nl0ii0O_dataout <= wire_nl0iill_dataout WHEN nlli00i = '1'  ELSE nl0100l;
	wire_nl0iii_dataout <= nliOiO WHEN n1ii11O = '1'  ELSE wire_nl0l1l_dataout;
	wire_nl0iiii_dataout <= wire_nl0iilO_dataout WHEN nlli00i = '1'  ELSE nl0100O;
	wire_nl0iiil_dataout <= wire_nl0iiOi_dataout WHEN nlli00i = '1'  ELSE nl010ii;
	wire_nl0iiiO_dataout <= wire_nl0iiOl_o(0) AND NOT(wire_nl0iiOO_o);
	wire_nl0iil_dataout <= wire_nl0l1O_dataout AND NOT(n1ii11O);
	wire_nl0iili_dataout <= wire_nl0iiOl_o(1) AND NOT(wire_nl0iiOO_o);
	wire_nl0iill_dataout <= wire_nl0iiOl_o(2) AND NOT(wire_nl0iiOO_o);
	wire_nl0iilO_dataout <= wire_nl0iiOl_o(3) AND NOT(wire_nl0iiOO_o);
	wire_nl0iiO_dataout <= wire_nl0l0i_dataout AND NOT(n1ii11O);
	wire_nl0iiOi_dataout <= wire_nl0iiOl_o(4) AND NOT(wire_nl0iiOO_o);
	wire_nl0il_dataout <= (NOT pudr(18)) WHEN nO = '1'  ELSE pudr(18);
	wire_nl0il0i_dataout <= wire_nl0iliO_dataout WHEN nlli00i = '1'  ELSE nl0100O;
	wire_nl0il0l_dataout <= wire_nl0illi_dataout WHEN nlli00i = '1'  ELSE nl010ii;
	wire_nl0il0O_dataout <= wire_nl0iiOl_o(0) AND NOT(wire_nl0illl_o);
	wire_nl0il1i_dataout <= wire_nl0il0O_dataout WHEN nlli00i = '1'  ELSE nl0101O;
	wire_nl0il1l_dataout <= wire_nl0ilii_dataout WHEN nlli00i = '1'  ELSE nl0100i;
	wire_nl0il1O_dataout <= wire_nl0ilil_dataout WHEN nlli00i = '1'  ELSE nl0100l;
	wire_nl0ili_dataout <= wire_nl0l0l_dataout AND NOT(n1ii11O);
	wire_nl0ilii_dataout <= wire_nl0iiOl_o(1) AND NOT(wire_nl0illl_o);
	wire_nl0ilil_dataout <= wire_nl0iiOl_o(2) AND NOT(wire_nl0illl_o);
	wire_nl0iliO_dataout <= wire_nl0iiOl_o(3) AND NOT(wire_nl0illl_o);
	wire_nl0ill_dataout <= nliO1O AND NOT(n1ii10i);
	wire_nl0illi_dataout <= wire_nl0iiOl_o(4) AND NOT(wire_nl0illl_o);
	wire_nl0illO_dataout <= wire_nl0iO1l_dataout WHEN nlli00i = '1'  ELSE nl0101O;
	wire_nl0ilO_dataout <= nliO0i AND NOT(n1ii10i);
	wire_nl0ilOi_dataout <= wire_nl0iO1O_dataout WHEN nlli00i = '1'  ELSE nl0100i;
	wire_nl0ilOl_dataout <= wire_nl0iO0i_dataout WHEN nlli00i = '1'  ELSE nl0100l;
	wire_nl0ilOO_dataout <= wire_nl0iO0l_dataout WHEN nlli00i = '1'  ELSE nl0100O;
	wire_nl0iO_dataout <= (NOT pudr(19)) WHEN nO = '1'  ELSE pudr(19);
	wire_nl0iO0i_dataout <= wire_nl0iiOl_o(2) AND NOT(wire_nl0iOii_o);
	wire_nl0iO0l_dataout <= wire_nl0iiOl_o(3) AND NOT(wire_nl0iOii_o);
	wire_nl0iO0O_dataout <= wire_nl0iiOl_o(4) AND NOT(wire_nl0iOii_o);
	wire_nl0iO1i_dataout <= wire_nl0iO0O_dataout WHEN nlli00i = '1'  ELSE nl010ii;
	wire_nl0iO1l_dataout <= wire_nl0iiOl_o(0) AND NOT(wire_nl0iOii_o);
	wire_nl0iO1O_dataout <= wire_nl0iiOl_o(1) AND NOT(wire_nl0iOii_o);
	wire_nl0iOi_dataout <= nliO0l AND NOT(n1ii10i);
	wire_nl0iOil_dataout <= wire_nl0iOOi_dataout WHEN nlli00i = '1'  ELSE nl0101O;
	wire_nl0iOiO_dataout <= wire_nl0iOOl_dataout WHEN nlli00i = '1'  ELSE nl0100i;
	wire_nl0iOl_dataout <= nliO0O AND NOT(n1ii10i);
	wire_nl0iOli_dataout <= wire_nl0iOOO_dataout WHEN nlli00i = '1'  ELSE nl0100l;
	wire_nl0iOll_dataout <= wire_nl0l11i_dataout WHEN nlli00i = '1'  ELSE nl0100O;
	wire_nl0iOlO_dataout <= wire_nl0l11l_dataout WHEN nlli00i = '1'  ELSE nl010ii;
	wire_nl0iOO_dataout <= nliOii AND NOT(n1ii10i);
	wire_nl0iOOi_dataout <= wire_nl0iiOl_o(0) AND NOT(wire_nl0l11O_o);
	wire_nl0iOOl_dataout <= wire_nl0iiOl_o(1) AND NOT(wire_nl0l11O_o);
	wire_nl0iOOO_dataout <= wire_nl0iiOl_o(2) AND NOT(wire_nl0l11O_o);
	wire_nl0l_dataout <= wire_nl1l0ll_dataout AND wa_6g_en;
	wire_nl0l00i_dataout <= nl1OiiO WHEN n111O0i = '1'  ELSE nl01O1O;
	wire_nl0l01i_dataout <= nl1Oiil WHEN (n110i0l OR n110i0i) = '1'  ELSE wire_nl0l01l_dataout;
	wire_nl0l01l_dataout <= nl1liii AND n111O0i;
	wire_nl0l0i_dataout <= nliOll AND NOT(n1ii10i);
	wire_nl0l0ii_dataout <= ((n1100ll OR nl1Olli) OR (n1iiiOi AND nl1Ol1l)) WHEN comp_pat_size(0) = '1'  ELSE n11010O;
	wire_nl0l0il_dataout <= ((n11000l OR nl1Olil) OR (n1iiiOi AND nl1OiOO)) WHEN comp_pat_size(0) = '1'  ELSE wire_nl0l0iO_dataout;
	wire_nl0l0iO_dataout <= n11010O WHEN n111O0l = '1'  ELSE ((n1101il OR nl1Ol0i) OR (n1iiiOi AND nl1Oill));
	wire_nl0l0l_dataout <= nliOlO AND NOT(n1ii10i);
	wire_nl0l0ll_dataout <= nl01O1O AND NOT(wire_nll1llO_o);
	wire_nl0l0lO_dataout <= nl1Oiil AND NOT(wire_nll1llO_o);
	wire_nl0l0O_dataout <= nliO0i WHEN n1ii11O = '1'  ELSE wire_nl0ilO_dataout;
	wire_nl0l11i_dataout <= wire_nl0iiOl_o(3) AND NOT(wire_nl0l11O_o);
	wire_nl0l11l_dataout <= wire_nl0iiOl_o(4) AND NOT(wire_nl0l11O_o);
	wire_nl0l1i_dataout <= nliOil AND NOT(n1ii10i);
	wire_nl0l1ii_dataout <= wire_nl0l1il_dataout WHEN sync_sm_dis = '1'  ELSE wire_nl0l00i_dataout;
	wire_nl0l1il_dataout <= nl1Oiil AND ((n110iil OR n110iii) OR n110i0O);
	wire_nl0l1l_dataout <= nliOiO AND NOT(n1ii10i);
	wire_nl0l1lO_dataout <= ((n1100Ol OR nl1OliO) OR (n1iiiOi AND nl1Ol1i)) WHEN comp_pat_size(0) = '1'  ELSE n1101ii;
	wire_nl0l1O_dataout <= nliOli AND NOT(n1ii10i);
	wire_nl0l1Oi_dataout <= ((n1100il OR nl1Olii) OR (n1iiiOi AND nl1OiOl)) WHEN comp_pat_size(0) = '1'  ELSE wire_nl0l1Ol_dataout;
	wire_nl0l1Ol_dataout <= n1101ii WHEN n111O0l = '1'  ELSE ((n1101ll OR nl1Ol1O) OR (n1iiiOi AND nl1Oili));
	wire_nl0l1OO_dataout <= wire_nl0l01i_dataout WHEN sync_sm_dis = '1'  ELSE wire_nl0l00i_dataout;
	wire_nl0li_dataout <= (NOT pudr(0)) WHEN nO = '1'  ELSE pudr(0);
	wire_nl0lii_dataout <= nliO0l WHEN n1ii11O = '1'  ELSE wire_nl0iOi_dataout;
	wire_nl0lil_dataout <= nliO0O WHEN n1ii11O = '1'  ELSE wire_nl0iOl_dataout;
	wire_nl0liO_dataout <= nliOii WHEN n1ii11O = '1'  ELSE wire_nl0iOO_dataout;
	wire_nl0ll_dataout <= (NOT pudr(1)) WHEN nO = '1'  ELSE pudr(1);
	wire_nl0lli_dataout <= nliOil WHEN n1ii11O = '1'  ELSE wire_nl0l1i_dataout;
	wire_nl0lll_dataout <= nliOiO WHEN n1ii11O = '1'  ELSE wire_nl0l1l_dataout;
	wire_nl0llO_dataout <= nliOli WHEN n1ii11O = '1'  ELSE wire_nl0l1O_dataout;
	wire_nl0lO_dataout <= (NOT pudr(2)) WHEN nO = '1'  ELSE pudr(2);
	wire_nl0lOi_dataout <= wire_nl0l0i_dataout AND NOT(n1ii11O);
	wire_nl0lOl_dataout <= wire_nl0l0l_dataout AND NOT(n1ii11O);
	wire_nl0lOO_dataout <= wire_nl0O1i_dataout AND NOT(n1ii11O);
	wire_nl0O_dataout <= wire_nl1l1ll_dataout AND wa_6g_en;
	wire_nl0O0i_dataout <= wire_nl0O0l_dataout AND NOT(n1ii11O);
	wire_nl0O0l_dataout <= nliOOl AND NOT(n1ii10i);
	wire_nl0O0O_dataout <= nliOOi AND NOT(n1ii11O);
	wire_nl0O1i_dataout <= nliOOi AND NOT(n1ii10i);
	wire_nl0O1l_dataout <= nliOlO AND NOT(n1ii11O);
	wire_nl0O1O_dataout <= wire_nl0O1i_dataout AND NOT(n1ii11O);
	wire_nl0Oi_dataout <= (NOT pudr(3)) WHEN nO = '1'  ELSE pudr(3);
	wire_nl0Oii_dataout <= wire_nl0O0l_dataout AND NOT(n1ii11O);
	wire_nl0Oil_dataout <= wire_nl0OiO_dataout AND NOT(n1ii11O);
	wire_nl0OiO_dataout <= nliOOO AND NOT(n1ii10i);
	wire_nl0Ol_dataout <= (NOT pudr(4)) WHEN nO = '1'  ELSE pudr(4);
	wire_nl0Oli_dataout <= nliOOl AND NOT(n1ii11O);
	wire_nl0Oll_dataout <= wire_nl0OiO_dataout AND NOT(n1ii11O);
	wire_nl0OlO_dataout <= wire_nl0OOi_dataout AND NOT(n1ii11O);
	wire_nl0OO_dataout <= (NOT pudr(5)) WHEN nO = '1'  ELSE pudr(5);
	wire_nl0OOi_dataout <= nll11i AND NOT(n1ii10i);
	wire_nl0OOl_dataout <= nliOOO AND NOT(n1ii11O);
	wire_nl0OOO_dataout <= wire_nl0OOi_dataout AND NOT(n1ii11O);
	wire_nl10i_dataout <= wire_nl0iO_dataout AND NOT(n1iii1l);
	wire_nl10l_dataout <= (NOT pudr(0)) WHEN nO = '1'  ELSE pudr(0);
	wire_nl10O_dataout <= (NOT pudr(1)) WHEN nO = '1'  ELSE pudr(1);
	wire_nl10OO_dataout <= wire_nl1i0i_dataout OR n1i0i1l;
	wire_nl11i_dataout <= wire_nl00O_dataout AND NOT(n1iii1l);
	wire_nl11l_dataout <= wire_nl0ii_dataout AND NOT(n1iii1l);
	wire_nl11O_dataout <= wire_nl0il_dataout AND NOT(n1iii1l);
	wire_nl1i_dataout <= wire_nl1l0ii_dataout AND wa_6g_en;
	wire_nl1i0i_dataout <= wire_nl1iil_o(1) OR n1i0i1i;
	wire_nl1i0l_dataout <= wire_nl1iil_o(2) OR n1i0i1i;
	wire_nl1i0O_dataout <= wire_nl1iil_o(3) OR n1i0i1i;
	wire_nl1i1i_dataout <= wire_nl1i0l_dataout AND NOT(n1i0i1l);
	wire_nl1i1l_dataout <= wire_nl1i0O_dataout AND NOT(n1i0i1l);
	wire_nl1i1O_dataout <= wire_nl1iii_dataout OR n1i0i1l;
	wire_nl1ii_dataout <= (NOT pudr(2)) WHEN nO = '1'  ELSE pudr(2);
	wire_nl1iii_dataout <= wire_nl1iil_o(4) AND NOT(n1i0i1i);
	wire_nl1il_dataout <= (NOT pudr(3)) WHEN nO = '1'  ELSE pudr(3);
	wire_nl1iO_dataout <= (NOT pudr(4)) WHEN nO = '1'  ELSE pudr(4);
	wire_nl1iOil_dataout <= nl1OO0O AND NOT(rrxpcsbypass_en);
	wire_nl1iOiO_dataout <= nl1OOii AND NOT(rrxpcsbypass_en);
	wire_nl1iOli_dataout <= nl1OOil AND NOT(rrxpcsbypass_en);
	wire_nl1iOll_dataout <= nl1OOiO AND NOT(rrxpcsbypass_en);
	wire_nl1iOlO_dataout <= nl1OOli AND NOT(rrxpcsbypass_en);
	wire_nl1iOOi_dataout <= nl1OOll AND NOT(rrxpcsbypass_en);
	wire_nl1iOOl_dataout <= nll0OOl WHEN rrxpcsbypass_en = '1'  ELSE nl1Olll;
	wire_nl1iOOO_dataout <= nll0OOO WHEN rrxpcsbypass_en = '1'  ELSE nl1OllO;
	wire_nl1l_dataout <= wire_nl1l0il_dataout AND wa_6g_en;
	wire_nl1l00i_dataout <= wire_nl1l0Ol_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl1OOOl;
	wire_nl1l00l_dataout <= wire_nl1l0OO_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl1OOOO;
	wire_nl1l00O_dataout <= wire_nl1li1i_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0111i;
	wire_nl1l01i_dataout <= nl011lO AND NOT(rrxpcsbypass_en);
	wire_nl1l01l_dataout <= wire_nl1l0lO_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl1OOlO;
	wire_nl1l01O_dataout <= wire_nl1l0Oi_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl1OOOi;
	wire_nl1l0i_dataout <= nlli0l OR wire_nllliil_w_lg_dataout283w(0);
	wire_nl1l0ii_dataout <= wire_nl1li1l_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0111l;
	wire_nl1l0il_dataout <= wire_nl1li1O_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0111O;
	wire_nl1l0iO_dataout <= wire_nl1li0i_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0110i;
	wire_nl1l0l_dataout <= nlli0O OR wire_nllliil_w_lg_dataout283w(0);
	wire_nl1l0li_dataout <= wire_nl1li0l_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0110l;
	wire_nl1l0ll_dataout <= wire_nl1li0O_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl0110O;
	wire_nl1l0lO_dataout <= nlli1ii WHEN n111llO = '1'  ELSE nlli1iO;
	wire_nl1l0O_dataout <= nlliii OR wire_nllliil_w_lg_dataout283w(0);
	wire_nl1l0Oi_dataout <= nlli1il WHEN n111llO = '1'  ELSE nlli1li;
	wire_nl1l0Ol_dataout <= nlli1iO WHEN n111llO = '1'  ELSE nlli1ll;
	wire_nl1l0OO_dataout <= nlli1li WHEN n111llO = '1'  ELSE nlli1lO;
	wire_nl1l10i_dataout <= nlli10i WHEN rrxpcsbypass_en = '1'  ELSE nl1OO1i;
	wire_nl1l10l_dataout <= nlli10l WHEN rrxpcsbypass_en = '1'  ELSE nl1OO1l;
	wire_nl1l10O_dataout <= nlli10O WHEN rrxpcsbypass_en = '1'  ELSE nl1OO1O;
	wire_nl1l11i_dataout <= nlli11i WHEN rrxpcsbypass_en = '1'  ELSE nl1OlOi;
	wire_nl1l11l_dataout <= nlli11l WHEN rrxpcsbypass_en = '1'  ELSE nl1OlOl;
	wire_nl1l11O_dataout <= nlli11O WHEN rrxpcsbypass_en = '1'  ELSE nl1OlOO;
	wire_nl1l1ii_dataout <= wire_nl1l1iO_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl1OO0i;
	wire_nl1l1il_dataout <= wire_nl1l1li_dataout WHEN rrxpcsbypass_en = '1'  ELSE nl1OO0l;
	wire_nl1l1iO_dataout <= nlli1ii AND NOT(n111llO);
	wire_nl1l1li_dataout <= nlli1il AND NOT(n111llO);
	wire_nl1l1ll_dataout <= nl011ii AND NOT(rrxpcsbypass_en);
	wire_nl1l1lO_dataout <= nl011il AND NOT(rrxpcsbypass_en);
	wire_nl1l1O_dataout <= nll1il OR wire_nllliil_w_lg_dataout283w(0);
	wire_nl1l1Oi_dataout <= nl011iO AND NOT(rrxpcsbypass_en);
	wire_nl1l1Ol_dataout <= nl011li AND NOT(rrxpcsbypass_en);
	wire_nl1l1OO_dataout <= nl011ll AND NOT(rrxpcsbypass_en);
	wire_nl1li_dataout <= (NOT pudr(5)) WHEN nO = '1'  ELSE pudr(5);
	wire_nl1li0i_dataout <= nlli1Ol WHEN n111llO = '1'  ELSE nlli01i;
	wire_nl1li0l_dataout <= nlli01l AND NOT(n111llO);
	wire_nl1li0O_dataout <= nlli01O AND NOT(n111llO);
	wire_nl1li1i_dataout <= nlli1ll WHEN n111llO = '1'  ELSE nlli1Oi;
	wire_nl1li1l_dataout <= nlli1lO WHEN n111llO = '1'  ELSE nlli1Ol;
	wire_nl1li1O_dataout <= nlli1Oi WHEN n111llO = '1'  ELSE nlli1OO;
	wire_nl1ll_dataout <= (NOT pudr(6)) WHEN nO = '1'  ELSE pudr(6);
	wire_nl1lO_dataout <= (NOT pudr(7)) WHEN nO = '1'  ELSE pudr(7);
	wire_nl1O_dataout <= wire_nl1l0iO_dataout AND wa_6g_en;
	wire_nl1O00l_dataout <= nl01lii WHEN nlli0li = '1'  ELSE nl01iOi;
	wire_nl1O00O_dataout <= nl01l0O WHEN nlli0li = '1'  ELSE nl01iOl;
	wire_nl1O0ii_dataout <= nl01l0l WHEN nlli0li = '1'  ELSE nl01iOO;
	wire_nl1O0il_dataout <= nl01l0i WHEN nlli0li = '1'  ELSE nl01l1i;
	wire_nl1O0iO_dataout <= nl01l1O WHEN nlli0li = '1'  ELSE nl01l1l;
	wire_nl1O0li_dataout <= nl01l1l WHEN nlli0li = '1'  ELSE nl01l1O;
	wire_nl1O0ll_dataout <= nl01l1i WHEN nlli0li = '1'  ELSE nl01l0i;
	wire_nl1O0lO_dataout <= nl01iOO WHEN nlli0li = '1'  ELSE nl01l0l;
	wire_nl1O0Oi_dataout <= nl01iOl WHEN nlli0li = '1'  ELSE nl01l0O;
	wire_nl1O0Ol_dataout <= nl01iOi WHEN nlli0li = '1'  ELSE nl01lii;
	wire_nl1O0OO_dataout <= nl01l0l WHEN nlli0li = '1'  ELSE nl01iOi;
	wire_nl1Oi_dataout <= (NOT pudr(8)) WHEN nO = '1'  ELSE pudr(8);
	wire_nl1Oi0i_dataout <= nl01l1i WHEN nlli0li = '1'  ELSE nl01l1l;
	wire_nl1Oi0l_dataout <= nl01iOO WHEN nlli0li = '1'  ELSE nl01l1O;
	wire_nl1Oi0O_dataout <= nl01iOl WHEN nlli0li = '1'  ELSE nl01l0i;
	wire_nl1Oi1i_dataout <= nl01l0i WHEN nlli0li = '1'  ELSE nl01iOl;
	wire_nl1Oi1l_dataout <= nl01l1O WHEN nlli0li = '1'  ELSE nl01iOO;
	wire_nl1Oi1O_dataout <= nl01l1l WHEN nlli0li = '1'  ELSE nl01l1i;
	wire_nl1Oiii_dataout <= nl01iOi WHEN nlli0li = '1'  ELSE nl01l0l;
	wire_nl1Ol_dataout <= (NOT pudr(9)) WHEN nO = '1'  ELSE pudr(9);
	wire_nl1OO_dataout <= (NOT pudr(10)) WHEN nO = '1'  ELSE pudr(10);
	wire_nl1OOl_dataout <= nl10il WHEN autobytealign_dis = '1'  ELSE nl1lil;
	wire_nl1OOO_dataout <= nl10li WHEN autobytealign_dis = '1'  ELSE nl1liO;
	wire_nli00i_dataout <= (NOT comp_pat(0)) WHEN n1ii11O = '1'  ELSE wire_nli0Ol_dataout;
	wire_nli00l_dataout <= (NOT comp_pat(1)) WHEN n1ii11O = '1'  ELSE wire_nli0OO_dataout;
	wire_nli00O_dataout <= (NOT comp_pat(2)) WHEN n1ii11O = '1'  ELSE wire_nlii1i_dataout;
	wire_nli01i_dataout <= wire_nli1Ol_dataout AND NOT(n1ii11O);
	wire_nli01l_dataout <= wire_nli01O_dataout AND NOT(n1ii11O);
	wire_nli01O_dataout <= nll1ii AND NOT(n1ii10i);
	wire_nli0i_dataout <= (NOT pudr(11)) WHEN nO = '1'  ELSE pudr(11);
	wire_nli0ii_dataout <= (NOT comp_pat(3)) WHEN n1ii11O = '1'  ELSE wire_nlii1l_dataout;
	wire_nli0il_dataout <= (NOT comp_pat(4)) WHEN n1ii11O = '1'  ELSE wire_nlii1O_dataout;
	wire_nli0iO_dataout <= (NOT comp_pat(5)) WHEN n1ii11O = '1'  ELSE wire_nlii0i_dataout;
	wire_nli0l_dataout <= (NOT pudr(12)) WHEN nO = '1'  ELSE pudr(12);
	wire_nli0li_dataout <= (NOT comp_pat(6)) WHEN n1ii11O = '1'  ELSE wire_nlii0l_dataout;
	wire_nli0ll_dataout <= wire_nlii0O_dataout AND NOT(n1ii11O);
	wire_nli0lO_dataout <= wire_nliiii_dataout AND NOT(n1ii11O);
	wire_nli0O_dataout <= (NOT pudr(13)) WHEN nO = '1'  ELSE pudr(13);
	wire_nli0Oi_dataout <= wire_nliiil_dataout AND NOT(n1ii11O);
	wire_nli0Ol_dataout <= comp_pat(8) WHEN n1ii10i = '1'  ELSE (NOT comp_pat(0));
	wire_nli0OO_dataout <= comp_pat(9) WHEN n1ii10i = '1'  ELSE (NOT comp_pat(1));
	wire_nli10i_dataout <= wire_nli11l_dataout AND NOT(n1ii11O);
	wire_nli10l_dataout <= wire_nli10O_dataout AND NOT(n1ii11O);
	wire_nli10O_dataout <= nll11O AND NOT(n1ii10i);
	wire_nli11i_dataout <= wire_nli11l_dataout AND NOT(n1ii11O);
	wire_nli11l_dataout <= nll11l AND NOT(n1ii10i);
	wire_nli11O_dataout <= nll11i AND NOT(n1ii11O);
	wire_nli1i_dataout <= (NOT pudr(6)) WHEN nO = '1'  ELSE pudr(6);
	wire_nli1ii_dataout <= nll11l AND NOT(n1ii11O);
	wire_nli1il_dataout <= wire_nli10O_dataout AND NOT(n1ii11O);
	wire_nli1iO_dataout <= wire_nli1li_dataout AND NOT(n1ii11O);
	wire_nli1l_dataout <= (NOT pudr(7)) WHEN nO = '1'  ELSE pudr(7);
	wire_nli1li_dataout <= nll10i AND NOT(n1ii10i);
	wire_nli1ll_dataout <= nll11O AND NOT(n1ii11O);
	wire_nli1lO_dataout <= wire_nli1li_dataout AND NOT(n1ii11O);
	wire_nli1O_dataout <= (NOT pudr(10)) WHEN nO = '1'  ELSE pudr(10);
	wire_nli1Oi_dataout <= wire_nli1Ol_dataout AND NOT(n1ii11O);
	wire_nli1Ol_dataout <= nll10l AND NOT(n1ii10i);
	wire_nli1OO_dataout <= nll10i AND NOT(n1ii11O);
	wire_nlii_dataout <= wire_nl1l1lO_dataout AND wa_6g_en;
	wire_nlii0i_dataout <= comp_pat(13) WHEN n1ii10i = '1'  ELSE (NOT comp_pat(5));
	wire_nlii0l_dataout <= comp_pat(14) WHEN n1ii10i = '1'  ELSE (NOT comp_pat(6));
	wire_nlii0O_dataout <= comp_pat(15) WHEN n1ii10i = '1'  ELSE (NOT comp_pat(7));
	wire_nlii1i_dataout <= comp_pat(10) WHEN n1ii10i = '1'  ELSE (NOT comp_pat(2));
	wire_nlii1l_dataout <= comp_pat(11) WHEN n1ii10i = '1'  ELSE (NOT comp_pat(3));
	wire_nlii1O_dataout <= comp_pat(12) WHEN n1ii10i = '1'  ELSE (NOT comp_pat(4));
	wire_nliii_dataout <= (NOT pudr(14)) WHEN nO = '1'  ELSE pudr(14);
	wire_nliiii_dataout <= (NOT comp_pat(8)) AND NOT(n1ii10i);
	wire_nliiil_dataout <= (NOT comp_pat(9)) AND NOT(n1ii10i);
	wire_nliiiO_dataout <= comp_pat(7) AND NOT(n1ii11O);
	wire_nliil_dataout <= (NOT pudr(15)) WHEN nO = '1'  ELSE pudr(15);
	wire_nliili_dataout <= wire_nliilO_dataout AND NOT(n1ii11O);
	wire_nliill_dataout <= wire_nliiOi_dataout AND NOT(n1ii11O);
	wire_nliilO_dataout <= comp_pat(8) AND NOT(n1ii10i);
	wire_nliiO_dataout <= (NOT pudr(16)) WHEN nO = '1'  ELSE pudr(16);
	wire_nliiOi_dataout <= comp_pat(9) AND NOT(n1ii10i);
	wire_nlil_dataout <= wire_nl1l1Oi_dataout AND wa_6g_en;
	wire_nlili_dataout <= (NOT pudr(17)) WHEN nO = '1'  ELSE pudr(17);
	wire_nlill_dataout <= wire_n10O_dataout WHEN n1iii1O = '1'  ELSE wire_nlO1i_dataout;
	wire_nlilO_dataout <= wire_n1ii_dataout WHEN n1iii1O = '1'  ELSE wire_nlO1l_dataout;
	wire_nliO_dataout <= wire_nl1l1Ol_dataout AND wa_6g_en;
	wire_nliOi_dataout <= wire_n1il_dataout WHEN n1iii1O = '1'  ELSE wire_nlO1O_dataout;
	wire_nliOl_dataout <= wire_n1iO_dataout WHEN n1iii1O = '1'  ELSE wire_nlO0i_dataout;
	wire_nliOO_dataout <= wire_n1li_dataout WHEN n1iii1O = '1'  ELSE wire_nlO0l_dataout;
	wire_nll00i_dataout <= nll11i WHEN pmadwidth(0) = '1'  ELSE nliOOl;
	wire_nll00l_dataout <= nll11l WHEN pmadwidth(0) = '1'  ELSE nliOOO;
	wire_nll00O_dataout <= nll11O WHEN pmadwidth(0) = '1'  ELSE nll11i;
	wire_nll01i_dataout <= nliOOi WHEN pmadwidth(0) = '1'  ELSE nliOll;
	wire_nll01l_dataout <= nliOOl WHEN pmadwidth(0) = '1'  ELSE nliOlO;
	wire_nll01O_dataout <= nliOOO WHEN pmadwidth(0) = '1'  ELSE nliOOi;
	wire_nll0i_dataout <= wire_n1Ol_dataout WHEN n1iii1O = '1'  ELSE wire_nlOiO_dataout;
	wire_nll0ii_dataout <= nll10i WHEN pmadwidth(0) = '1'  ELSE nll11l;
	wire_nll0il_dataout <= nll10l WHEN pmadwidth(0) = '1'  ELSE nll11O;
	wire_nll0iO_dataout <= nll1ii WHEN pmadwidth(0) = '1'  ELSE nll10i;
	wire_nll0l_dataout <= wire_n1OO_dataout WHEN n1iii1O = '1'  ELSE wire_nlOli_dataout;
	wire_nll0li_dataout <= wire_niili_dataout WHEN lpbk_en = '1'  ELSE wire_nil0l_dataout;
	wire_nll0ll_dataout <= wire_niill_dataout WHEN lpbk_en = '1'  ELSE wire_nil0O_dataout;
	wire_nll0lO_dataout <= wire_niilO_dataout WHEN lpbk_en = '1'  ELSE wire_nilii_dataout;
	wire_nll0O_dataout <= wire_n01i_dataout WHEN n1iii1O = '1'  ELSE wire_nlOll_dataout;
	wire_nll0Oi_dataout <= wire_niiOi_dataout WHEN lpbk_en = '1'  ELSE wire_nilil_dataout;
	wire_nll0Ol_dataout <= wire_niiOl_dataout WHEN lpbk_en = '1'  ELSE wire_niliO_dataout;
	wire_nll0OO_dataout <= wire_niiOO_dataout WHEN lpbk_en = '1'  ELSE wire_nilli_dataout;
	wire_nll1i_dataout <= wire_n1ll_dataout WHEN n1iii1O = '1'  ELSE wire_nlO0O_dataout;
	wire_nll1iO_dataout <= nliO0O WHEN pmadwidth(0) = '1'  ELSE nliO0i;
	wire_nll1l_dataout <= wire_n1lO_dataout WHEN n1iii1O = '1'  ELSE wire_nlOii_dataout;
	wire_nll1li_dataout <= nliOii WHEN pmadwidth(0) = '1'  ELSE nliO0l;
	wire_nll1ll_dataout <= nliOil WHEN pmadwidth(0) = '1'  ELSE nliO0O;
	wire_nll1lO_dataout <= nliOiO WHEN pmadwidth(0) = '1'  ELSE nliOii;
	wire_nll1lOi_dataout <= n10l1li AND n10l11O;
	wire_nll1lOl_dataout <= wire_nll1O0i_dataout AND n10l11l;
	wire_nll1O_dataout <= wire_n1Oi_dataout WHEN n1iii1O = '1'  ELSE wire_nlOil_dataout;
	wire_nll1O0i_dataout <= wire_w_lg_n10l10i4528w(0) AND NOT(n10l1iO);
	wire_nll1O0l_dataout <= n10l10i OR n10l1iO;
	wire_nll1O0O_dataout <= wire_w_lg_n10l1il4527w(0) AND n10l10i;
	wire_nll1O1O_dataout <= wire_nll1O0O_dataout OR n10l1iO;
	wire_nll1Oi_dataout <= nliOli WHEN pmadwidth(0) = '1'  ELSE nliOil;
	wire_nll1Ol_dataout <= nliOll WHEN pmadwidth(0) = '1'  ELSE nliOiO;
	wire_nll1OO_dataout <= nliOlO WHEN pmadwidth(0) = '1'  ELSE nliOli;
	wire_nlli_dataout <= wire_nl1l1OO_dataout AND wa_6g_en;
	wire_nlli0i_dataout <= wire_nil0i_dataout WHEN lpbk_en = '1'  ELSE wire_nilOl_dataout;
	wire_nlli1i_dataout <= wire_nil1i_dataout WHEN lpbk_en = '1'  ELSE wire_nilll_dataout;
	wire_nlli1l_dataout <= wire_nil1l_dataout WHEN lpbk_en = '1'  ELSE wire_nillO_dataout;
	wire_nlli1O_dataout <= wire_nil1O_dataout WHEN lpbk_en = '1'  ELSE wire_nilOi_dataout;
	wire_nllii_dataout <= wire_n01l_dataout WHEN n1iii1O = '1'  ELSE wire_nlOlO_dataout;
	wire_nllii0O_dataout <= wire_nilOO_dataout WHEN lpbk_en = '1'  ELSE wire_nlill_dataout;
	wire_nlliiii_dataout <= wire_niO1i_dataout WHEN lpbk_en = '1'  ELSE wire_nlilO_dataout;
	wire_nlliiil_dataout <= wire_niO1l_dataout WHEN lpbk_en = '1'  ELSE wire_nliOi_dataout;
	wire_nlliiiO_dataout <= wire_niO1O_dataout WHEN lpbk_en = '1'  ELSE wire_nliOl_dataout;
	wire_nlliil_dataout <= wire_nllilO_dataout OR wire_nllliil_w_lg_dataout283w(0);
	wire_nlliili_dataout <= wire_niO0i_dataout WHEN lpbk_en = '1'  ELSE wire_nliOO_dataout;
	wire_nlliill_dataout <= wire_niO0l_dataout WHEN lpbk_en = '1'  ELSE wire_nll1i_dataout;
	wire_nlliilO_dataout <= wire_niO0O_dataout WHEN lpbk_en = '1'  ELSE wire_nll1l_dataout;
	wire_nlliiO_dataout <= wire_nlliOi_dataout OR wire_nllliil_w_lg_dataout283w(0);
	wire_nlliiOi_dataout <= wire_niOii_dataout WHEN lpbk_en = '1'  ELSE wire_nll1O_dataout;
	wire_nlliiOl_dataout <= wire_niOil_dataout WHEN lpbk_en = '1'  ELSE wire_nll0i_dataout;
	wire_nlliiOO_dataout <= wire_niOiO_dataout WHEN lpbk_en = '1'  ELSE wire_nll0l_dataout;
	wire_nllil_dataout <= wire_n01O_dataout WHEN n1iii1O = '1'  ELSE wire_nlOOi_dataout;
	wire_nllil0i_dataout <= wire_niOOi_dataout WHEN lpbk_en = '1'  ELSE wire_nlliO_dataout;
	wire_nllil0l_dataout <= wire_niOOl_dataout WHEN lpbk_en = '1'  ELSE wire_nllli_dataout;
	wire_nllil0O_dataout <= wire_niOOO_dataout WHEN lpbk_en = '1'  ELSE wire_nllll_dataout;
	wire_nllil1i_dataout <= wire_niOli_dataout WHEN lpbk_en = '1'  ELSE wire_nll0O_dataout;
	wire_nllil1l_dataout <= wire_niOll_dataout WHEN lpbk_en = '1'  ELSE wire_nllii_dataout;
	wire_nllil1O_dataout <= wire_niOlO_dataout WHEN lpbk_en = '1'  ELSE wire_nllil_dataout;
	wire_nllili_dataout <= wire_nlliOl_dataout OR wire_nllliil_w_lg_dataout283w(0);
	wire_nllilii_dataout <= wire_nl11i_dataout WHEN lpbk_en = '1'  ELSE wire_nlllO_dataout;
	wire_nllilil_dataout <= wire_nl11l_dataout WHEN lpbk_en = '1'  ELSE wire_nllOi_dataout;
	wire_nlliliO_dataout <= wire_nl11O_dataout WHEN lpbk_en = '1'  ELSE wire_nllOl_dataout;
	wire_nllill_dataout <= wire_nlliOO_dataout OR wire_nllliil_w_lg_dataout283w(0);
	wire_nllilli_dataout <= wire_nl10i_dataout WHEN lpbk_en = '1'  ELSE wire_nllOO_dataout;
	wire_nllilO_dataout <= wire_w_lg_n1ii1OO229w(0) WHEN n1ii10O = '1'  ELSE nll1il;
	wire_nllilOO_dataout <= wire_nlliO1i_dataout OR (nllii0l AND wire_nl_w_lg_nllii0i4486w(0));
	wire_nlliO_dataout <= wire_n00i_dataout WHEN n1iii1O = '1'  ELSE wire_nlOOl_dataout;
	wire_nlliO1i_dataout <= nlli0OO AND NOT(nllii1i);
	wire_nlliOi_dataout <= n1ii01i WHEN n1ii10O = '1'  ELSE nlli0l;
	wire_nlliOl_dataout <= n1ii01l WHEN n1ii10O = '1'  ELSE nlli0O;
	wire_nlliOO_dataout <= n1ii01O WHEN n1ii10O = '1'  ELSE nlliii;
	wire_nlll_dataout <= wire_nl1l01i_dataout AND wa_6g_en;
	wire_nlll0l_dataout <= n1ii00i OR n1ii1lO;
	wire_nlll0O_dataout <= n1ii00i AND NOT(n1ii1lO);
	wire_nllli_dataout <= wire_n00l_dataout WHEN n1iii1O = '1'  ELSE wire_nlOOO_dataout;
	wire_nlllii_dataout <= wire_w_lg_n1ii00i237w(0) AND NOT(n1ii1lO);
	wire_nllliil_dataout <= encdet_prbs WHEN nlO0ilO = '1'  ELSE wire_nllliiO_dataout;
	wire_nllliil_w_lg_dataout283w(0) <= NOT wire_nllliil_dataout;
	wire_nllliiO_dataout <= wire_nlllili_dataout WHEN sync_sm_dis = '1'  ELSE nlO010O;
	wire_nlllil_dataout <= n1ii1lO OR n1ii00i;
	wire_nlllili_dataout <= wire_nlll1i_o WHEN wire_w_lg_w_pmadwidth_range175w219w(0) = '1'  ELSE nlO0l1l;
	wire_nlllill_dataout <= wire_nlO0l0i_o(0) AND NOT(n10l1ll);
	wire_nlllilO_dataout <= wire_nlO0l0i_o(1) AND NOT(n10l1ll);
	wire_nllliO_dataout <= n1ii1lO AND NOT(n1ii00i);
	wire_nllliOi_dataout <= wire_nlO0l0i_o(2) AND NOT(n10l1ll);
	wire_nllliOl_dataout <= wire_nlO0l0i_o(3) AND NOT(n10l1ll);
	wire_nllll_dataout <= wire_n00O_dataout WHEN n1iii1O = '1'  ELSE wire_n11i_dataout;
	wire_nlllli_dataout <= wire_w_lg_n1ii1lO236w(0) AND NOT(n1ii00i);
	wire_nlllO_dataout <= wire_n11l_dataout AND NOT(n1iii1O);
	wire_nllO_dataout <= wire_nl0l0OO_o WHEN wa_6g_en = '1'  ELSE niii0l;
	wire_nllO00i_dataout <= wire_nllO0lO_o AND NOT(wire_nl_w_lg_nlO010l3809w(0));
	wire_nllO00i_w_lg_w_lg_w_lg_dataout4064w4065w4066w(0) <= wire_nllO00i_w_lg_w_lg_dataout4064w4065w(0) OR wire_w_lg_n10l01l3948w(0);
	wire_nllO00i_w_lg_w_lg_dataout4064w4065w(0) <= wire_nllO00i_w_lg_dataout4064w(0) OR wire_nllO01l_dataout;
	wire_nllO00i_w_lg_dataout4064w(0) <= wire_nllO00i_dataout OR wire_nllO01O_dataout;
	wire_nllO00l_dataout <= wire_nllO0Oi_o AND NOT(wire_nl_w_lg_nlO010l3809w(0));
	wire_nllO00O_dataout <= wire_nllO0Ol_o AND NOT(wire_nl_w_lg_nlO010l3809w(0));
	wire_nllO00O_w_lg_w_lg_w_lg_dataout3960w3961w3962w(0) <= wire_nllO00O_w_lg_w_lg_dataout3960w3961w(0) OR wire_nllO01l_dataout;
	wire_nllO00O_w_lg_w_lg_dataout3960w3961w(0) <= wire_nllO00O_w_lg_dataout3960w(0) OR wire_nllO01O_dataout;
	wire_nllO00O_w_lg_dataout3960w(0) <= wire_nllO00O_dataout OR wire_nllO00i_dataout;
	wire_nllO01i_dataout <= wire_nllO0iO_o AND NOT(wire_nl_w_lg_nlO010l3809w(0));
	wire_nllO01l_dataout <= wire_nllO0li_o AND NOT(wire_nl_w_lg_nlO010l3809w(0));
	wire_nllO01O_dataout <= wire_nllO0ll_o AND NOT(wire_nl_w_lg_nlO010l3809w(0));
	wire_nllO0ii_dataout <= wire_nllO0OO_o AND NOT(wire_nl_w_lg_nlO010l3809w(0));
	wire_nllO0ii_w_lg_w_lg_w_lg_dataout3945w3946w3947w(0) <= wire_nllO0ii_w_lg_w_lg_dataout3945w3946w(0) OR wire_nllO01l_dataout;
	wire_nllO0ii_w_lg_w_lg_dataout3945w3946w(0) <= wire_nllO0ii_w_lg_dataout3945w(0) OR wire_nllO01O_dataout;
	wire_nllO0ii_w_lg_dataout3945w(0) <= wire_nllO0ii_dataout OR wire_nllO00i_dataout;
	wire_nllO0ii_w_lg_dataout4069w(0) <= wire_nllO0ii_dataout OR wire_nllO00O_dataout;
	wire_nllO0il_dataout <= wire_nllOi1i_o OR wire_nl_w_lg_nlO010l3809w(0);
	wire_nllO0il_w_lg_w_lg_dataout3407w4078w(0) <= wire_nllO0il_w_lg_dataout3407w(0) OR wire_nllO01l_dataout;
	wire_nllO0il_w_lg_dataout3407w(0) <= wire_nllO0il_dataout OR wire_nllO0ii_dataout;
	wire_nllOi_dataout <= wire_n11O_dataout AND NOT(n1iii1O);
	wire_nllOi0l_dataout <= wire_nllOill_dataout AND NOT(n10l0li);
	wire_nllOi0O_dataout <= wire_nllOilO_dataout AND NOT(n10l0li);
	wire_nllOi1l_dataout <= n10l01O AND NOT(wire_w_lg_n10lili3500w(0));
	wire_nllOi1O_dataout <= wire_w_lg_n10l01O3545w(0) AND NOT(wire_w_lg_n10lili3500w(0));
	wire_nllOiii_dataout <= wire_nllOiOi_dataout AND NOT(n10l0li);
	wire_nllOiil_dataout <= n10l0il AND NOT(n10l0li);
	wire_nllOiiO_dataout <= wire_nllOiOl_dataout AND NOT(n10l0li);
	wire_nllOili_dataout <= wire_nllOiOO_dataout AND NOT(n10l0li);
	wire_nllOill_dataout <= wire_nllOl1i_dataout AND NOT(n10l0il);
	wire_nllOilO_dataout <= wire_nllOl1l_dataout AND NOT(n10l0il);
	wire_nllOiOi_dataout <= wire_nllOl1O_dataout AND NOT(n10l0il);
	wire_nllOiOl_dataout <= n10l0ii AND NOT(n10l0il);
	wire_nllOiOO_dataout <= wire_nllOl0i_dataout AND NOT(n10l0il);
	wire_nllOl_dataout <= wire_n10i_dataout AND NOT(n1iii1O);
	wire_nllOl0i_dataout <= wire_nllOlii_dataout AND NOT(n10l0ii);
	wire_nllOl0l_dataout <= n10l00l AND NOT(n10l00O);
	wire_nllOl0O_dataout <= wire_nllOlil_dataout AND NOT(n10l00O);
	wire_nllOl1i_dataout <= wire_nllOl0l_dataout AND NOT(n10l0ii);
	wire_nllOl1l_dataout <= n10l00O AND NOT(n10l0ii);
	wire_nllOl1O_dataout <= wire_nllOl0O_dataout AND NOT(n10l0ii);
	wire_nllOlii_dataout <= wire_nllOliO_dataout AND NOT(n10l00O);
	wire_nllOlil_dataout <= n10l00i AND NOT(n10l00l);
	wire_nllOliO_dataout <= wire_w_lg_n10l00i3543w(0) AND NOT(n10l00l);
	wire_nllOO_dataout <= wire_n10l_dataout AND NOT(n1iii1O);
	wire_nllOO0O_dataout <= wire_nllOOli_dataout AND NOT(n10li1i);
	wire_nllOOii_dataout <= wire_nllOOll_dataout AND NOT(n10li1i);
	wire_nllOOil_dataout <= wire_nllOOlO_dataout AND NOT(n10li1i);
	wire_nllOOiO_dataout <= n10li1O AND NOT(n10li1i);
	wire_nllOOli_dataout <= wire_nllOOOi_dataout AND NOT(n10li1O);
	wire_nllOOll_dataout <= n10li1l AND NOT(n10li1O);
	wire_nllOOlO_dataout <= wire_nllOOOl_dataout AND NOT(n10li1O);
	wire_nllOOOi_dataout <= wire_nllOOOO_dataout AND NOT(n10li1l);
	wire_nllOOOl_dataout <= n10liii AND NOT(n10li1l);
	wire_nllOOOO_dataout <= wire_w_lg_n10li0i3455w(0) AND NOT(n10liii);
	wire_nlO0i_dataout <= (NOT pudi(3)) WHEN nO = '1'  ELSE pudi(3);
	wire_nlO0l_dataout <= (NOT pudi(4)) WHEN nO = '1'  ELSE pudi(4);
	wire_nlO0O_dataout <= (NOT pudi(5)) WHEN nO = '1'  ELSE pudi(5);
	wire_nlO0O0l_dataout <= n1ii11i OR n1ii11l;
	wire_nlO0Oli_dataout <= n1i0O0O OR n1i0Oii;
	wire_nlO0OOO_dataout <= n1i0lOO OR n1i0O1i;
	wire_nlO100i_dataout <= n10li0l AND NOT(n10liiO);
	wire_nlO100l_dataout <= wire_w_lg_n10li0i3455w(0) AND NOT(n10li0l);
	wire_nlO101i_dataout <= wire_nlO100i_dataout AND NOT(n10l0ll);
	wire_nlO101l_dataout <= n10liiO AND NOT(n10l0ll);
	wire_nlO101O_dataout <= wire_nlO100l_dataout AND NOT(n10liiO);
	wire_nlO110O_dataout <= wire_nlO11ll_dataout AND NOT(n10l0Ol);
	wire_nlO11ii_dataout <= wire_nlO11lO_dataout AND NOT(n10l0Ol);
	wire_nlO11il_dataout <= n10l0Oi AND NOT(n10l0Ol);
	wire_nlO11iO_dataout <= wire_nlO11Oi_dataout AND NOT(n10l0Ol);
	wire_nlO11li_dataout <= wire_nlO11Ol_dataout AND NOT(n10l0Ol);
	wire_nlO11ll_dataout <= wire_nlO11OO_dataout AND NOT(n10l0Oi);
	wire_nlO11lO_dataout <= wire_nlO101i_dataout AND NOT(n10l0Oi);
	wire_nlO11Oi_dataout <= n10l0ll AND NOT(n10l0Oi);
	wire_nlO11Ol_dataout <= wire_nlO101l_dataout AND NOT(n10l0Oi);
	wire_nlO11OO_dataout <= wire_nlO101O_dataout AND NOT(n10l0ll);
	wire_nlO1i_dataout <= (NOT pudi(0)) WHEN nO = '1'  ELSE pudi(0);
	wire_nlO1i0i_dataout <= wire_nlO1iiO_dataout AND NOT(n10li0l);
	wire_nlO1i0l_dataout <= n10liiO AND NOT(n10li0l);
	wire_nlO1i0O_dataout <= wire_nlO1ili_dataout AND NOT(n10liiO);
	wire_nlO1i1i_dataout <= wire_nlO1i0O_dataout AND NOT(n10li0l);
	wire_nlO1i1l_dataout <= wire_nlO1iii_dataout AND NOT(n10li0l);
	wire_nlO1i1O_dataout <= wire_nlO1iil_dataout AND NOT(n10li0l);
	wire_nlO1iii_dataout <= wire_nlO1ill_dataout AND NOT(n10liiO);
	wire_nlO1iil_dataout <= n10li1i AND NOT(n10liiO);
	wire_nlO1iiO_dataout <= wire_nlO1ilO_dataout AND NOT(n10liiO);
	wire_nlO1ili_dataout <= wire_nlO1iOi_dataout AND NOT(n10li1i);
	wire_nlO1ill_dataout <= n10li1l AND NOT(n10li1i);
	wire_nlO1ilO_dataout <= wire_nlO1iOl_dataout AND NOT(n10li1i);
	wire_nlO1iOi_dataout <= wire_nlO1iOO_dataout AND NOT(n10li1l);
	wire_nlO1iOl_dataout <= n10li1O AND NOT(n10li1l);
	wire_nlO1iOO_dataout <= wire_w_lg_n10li0i3455w(0) AND NOT(n10li1O);
	wire_nlO1l_dataout <= (NOT pudi(1)) WHEN nO = '1'  ELSE pudi(1);
	wire_nlO1l0i_dataout <= n10liiO AND NOT(n10liil);
	wire_nlO1l0l_dataout <= wire_nlO1lil_dataout AND NOT(n10ll0i);
	wire_nlO1l0O_dataout <= wire_nlO1liO_dataout AND NOT(n10ll0i);
	wire_nlO1l1l_dataout <= wire_nlO101O_dataout AND NOT(n10liil);
	wire_nlO1l1O_dataout <= wire_nlO100i_dataout AND NOT(n10liil);
	wire_nlO1lii_dataout <= n10lill AND NOT(n10ll0i);
	wire_nlO1lil_dataout <= wire_w_lg_n10lilO3445w(0) AND NOT(n10lill);
	wire_nlO1liO_dataout <= n10lilO AND NOT(n10lill);
	wire_nlO1O_dataout <= (NOT pudi(2)) WHEN nO = '1'  ELSE pudi(2);
	wire_nlO1O0i_dataout <= n10liOi AND NOT(n10ll1i);
	wire_nlO1O0l_dataout <= wire_w_lg_n10lilO3445w(0) AND NOT(n10liOi);
	wire_nlO1O0O_dataout <= n10lilO AND NOT(n10liOi);
	wire_nlO1O1l_dataout <= wire_nlO1O0l_dataout AND NOT(n10ll1i);
	wire_nlO1O1O_dataout <= wire_nlO1O0O_dataout AND NOT(n10ll1i);
	wire_nlO1Oll_dataout <= n10ll1l AND NOT(wire_nl_w_lg_niii0l3438w(0));
	wire_nlO1OlO_dataout <= wire_w_lg_n10ll1l3437w(0) AND NOT(wire_nl_w_lg_niii0l3438w(0));
	wire_nlOi_dataout <= wire_nl0li1i_o AND wa_6g_en;
	wire_nlOi00l_dataout <= n1i0l0l OR n1i0l0O;
	wire_nlOi0li_dataout <= n1i0l1O OR n1i0l0i;
	wire_nlOi10l_dataout <= n1i0lll OR n1i0llO;
	wire_nlOi1li_dataout <= n1i0liO OR n1i0lli;
	wire_nlOi1OO_dataout <= n1i0lii OR n1i0lil;
	wire_nlOii_dataout <= (NOT pudi(6)) WHEN nO = '1'  ELSE pudi(6);
	wire_nlOil_dataout <= (NOT pudi(7)) WHEN nO = '1'  ELSE pudi(7);
	wire_nlOiO_dataout <= (NOT pudi(8)) WHEN nO = '1'  ELSE pudi(8);
	wire_nlOl_dataout <= n1iiilO WHEN wa_6g_en = '1'  ELSE nllll1i;
	wire_nlOli_dataout <= (NOT pudi(9)) WHEN nO = '1'  ELSE pudi(9);
	wire_nlOll_dataout <= (NOT pudi(10)) WHEN nO = '1'  ELSE pudi(10);
	wire_nlOll0O_dataout <= niii0i WHEN ((wire_niOiOl_w_lg_w_lg_o1205w3260w(0) OR (wire_niOiOl_o AND n1i001i)) OR (n1i00il AND n1i000l)) = '1'  ELSE (n1i001l OR n1i001O);
	wire_nlOll0O_w_lg_w_lg_dataout1212w3256w(0) <= wire_nlOll0O_w_lg_dataout1212w(0) AND n10llOl;
	wire_nlOll0O_w_lg_dataout1212w(0) <= NOT wire_nlOll0O_dataout;
	wire_nlOlO_dataout <= (NOT pudi(11)) WHEN nO = '1'  ELSE pudi(11);
	wire_nlOO_dataout <= nll01li WHEN wa_6g_en = '1'  ELSE nlO011i;
	wire_nlOOi_dataout <= (NOT pudi(12)) WHEN nO = '1'  ELSE pudi(12);
	wire_nlOOl_dataout <= (NOT pudi(13)) WHEN nO = '1'  ELSE pudi(13);
	wire_nlOOO_dataout <= (NOT pudi(14)) WHEN nO = '1'  ELSE pudi(14);
	wire_n011ili_a <= ( "0" & max_rlv_sel(5 DOWNTO 0));
	wire_n011ili_b <= ( "0" & "0" & "0" & max_rlv_sel(5 DOWNTO 2));
	n011ili :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 7,
		width_b => 7,
		width_o => 7
	  )
	  PORT MAP ( 
		a => wire_n011ili_a,
		b => wire_n011ili_b,
		cin => wire_gnd,
		o => wire_n011ili_o
	  );
	wire_n1li0i_a <= ( "0" & wire_n1ll1O_o & wire_n1ll1l_o & wire_n1ll1i_o & wire_n1liOO_o);
	wire_n1li0i_b <= ( "0" & wire_n1liOi_o & wire_n1lilO_o & wire_n1lill_o & wire_n1lili_o);
	n1li0i :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_n1li0i_a,
		b => wire_n1li0i_b,
		cin => wire_gnd,
		o => wire_n1li0i_o
	  );
	wire_n1li1O_a <= ( wire_n1liiO_dataout & wire_n1liil_dataout & wire_n1li0O_dataout & wire_n1li0l_dataout);
	wire_n1li1O_b <= ( "0" & "0" & "0" & "1");
	n1li1O :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 4,
		width_b => 4,
		width_o => 4
	  )
	  PORT MAP ( 
		a => wire_n1li1O_a,
		b => wire_n1li1O_b,
		cin => wire_gnd,
		o => wire_n1li1O_o
	  );
	wire_n1O0lO_a <= ( "0" & "0" & wire_w_lg_n10O0li2685w & max_rlv_sel(4 DOWNTO 2));
	wire_n1O0lO_b <= ( wire_w_lg_n10O0li2685w & max_rlv_sel(4 DOWNTO 0));
	n1O0lO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 6,
		width_b => 6,
		width_o => 6
	  )
	  PORT MAP ( 
		a => wire_n1O0lO_a,
		b => wire_n1O0lO_b,
		cin => wire_gnd,
		o => wire_n1O0lO_o
	  );
	wire_n1Ol0Ol_a <= ( wire_n1Oli0O_dataout & wire_n1Oli0l_dataout & wire_n1Oli1O_dataout & wire_n1Oli1l_dataout & wire_n1Oli1i_dataout);
	wire_n1Ol0Ol_b <= ( "0" & "0" & "0" & "0" & "1");
	n1Ol0Ol :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_n1Ol0Ol_a,
		b => wire_n1Ol0Ol_b,
		cin => wire_gnd,
		o => wire_n1Ol0Ol_o
	  );
	wire_n1Ol0OO_a <= ( "0" & wire_n1Oll1l_o & wire_n1Oll1i_o & wire_n1OliOO_o & wire_n1OliOl_o & wire_n1OliOi_o);
	wire_n1Ol0OO_b <= ( "0" & wire_n1Olill_o & wire_n1Olili_o & wire_n1OliiO_o & wire_n1Oliil_o & wire_n1Oliii_o);
	n1Ol0OO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 6,
		width_b => 6,
		width_o => 6
	  )
	  PORT MAP ( 
		a => wire_n1Ol0OO_a,
		b => wire_n1Ol0OO_b,
		cin => wire_gnd,
		o => wire_n1Ol0OO_o
	  );
	wire_nl0iiOl_a <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	wire_nl0iiOl_b <= ( "0" & "0" & "0" & "0" & "1");
	nl0iiOl :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_nl0iiOl_a,
		b => wire_nl0iiOl_b,
		cin => wire_gnd,
		o => wire_nl0iiOl_o
	  );
	wire_nl1iil_a <= ( nl10Oi & nl10ll & nl10li & nl10il & "1");
	wire_nl1iil_b <= ( "1" & "1" & "1" & "0" & "1");
	nl1iil :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5,
		width_o => 5
	  )
	  PORT MAP ( 
		a => wire_nl1iil_a,
		b => wire_nl1iil_b,
		cin => wire_gnd,
		o => wire_nl1iil_o
	  );
	wire_nllO1lO_a <= ( nlO0i1i & nlO00OO & nlO00Ol & nlO00Oi & nlO00lO & nlO00ll & nlO00li & nlO00iO & nlO00il & nlO00ii & "1");
	wire_nllO1lO_b <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "1" & "0" & "1");
	nllO1lO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 11,
		width_b => 11,
		width_o => 11
	  )
	  PORT MAP ( 
		a => wire_nllO1lO_a,
		b => wire_nllO1lO_b,
		cin => wire_gnd,
		o => wire_nllO1lO_o
	  );
	wire_nllO1Oi_a <= ( nlO000O & nlO000l & nlO000i & nlO001O & nlO001l & nlO001i & nlO01OO & nlO01Ol & nlO01Oi & nlO01lO);
	wire_nllO1Oi_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	nllO1Oi :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 10,
		width_b => 10,
		width_o => 10
	  )
	  PORT MAP ( 
		a => wire_nllO1Oi_a,
		b => wire_nllO1Oi_b,
		cin => wire_gnd,
		o => wire_nllO1Oi_o
	  );
	wire_nllO1Ol_a <= ( nlO0i1i & nlO00OO & nlO00Ol & nlO00Oi & nlO00lO & nlO00ll & nlO00li & nlO00iO & nlO00il & nlO00ii);
	wire_nllO1Ol_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	nllO1Ol :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 10,
		width_b => 10,
		width_o => 10
	  )
	  PORT MAP ( 
		a => wire_nllO1Ol_a,
		b => wire_nllO1Ol_b,
		cin => wire_gnd,
		o => wire_nllO1Ol_o
	  );
	wire_nllO1OO_a <= ( nlO0ill & nlO0ili & nlO0iiO & nlO0iil & nlO0iii & nlO0i0O & nlO0i0l & nlO0i0i & nlO0i1O & nlO0i1l);
	wire_nllO1OO_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	nllO1OO :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 10,
		width_b => 10,
		width_o => 10
	  )
	  PORT MAP ( 
		a => wire_nllO1OO_a,
		b => wire_nllO1OO_b,
		cin => wire_gnd,
		o => wire_nllO1OO_o
	  );
	wire_nlO0l0i_a <= ( nlO01ll & nlO01li & nlO01iO & nlO01il);
	wire_nlO0l0i_b <= ( "0" & "0" & "0" & "1");
	nlO0l0i :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 4,
		width_b => 4,
		width_o => 4
	  )
	  PORT MAP ( 
		a => wire_nlO0l0i_a,
		b => wire_nlO0l0i_b,
		cin => wire_gnd,
		o => wire_nlO0l0i_o
	  );
	wire_n1Oill_a <= ( wire_n1O0ll_dataout & wire_n1O0li_dataout & wire_n1O0iO_dataout & wire_n1O0il_dataout & wire_n1O0ii_dataout & wire_n1O00O_dataout & wire_n1O00l_dataout & wire_n1O00i_dataout);
	wire_n1Oill_b <= ( n1l0lO & n1l0ll & n1l0li & n1l0iO & n1l0il & n1l0ii & n1l00O & n1liii);
	n1Oill :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 8,
		width_b => 8
	  )
	  PORT MAP ( 
		a => wire_n1Oill_a,
		b => wire_n1Oill_b,
		cin => wire_gnd,
		o => wire_n1Oill_o
	  );
	wire_n1OOi1l_a <= ( wire_n011i1l_dataout & wire_n011i1i_dataout & wire_n0110OO_dataout & wire_n0110Ol_dataout & wire_n0110Oi_dataout & wire_n0110lO_dataout & wire_n0110ll_dataout & wire_n0110li_dataout & wire_n0110iO_dataout & "0");
	wire_n1OOi1l_b <= ( n1Ol0ii & n1Ol00O & n1Ol00l & n1Ol00i & n1Ol01O & n1Ol01l & n1Ol01i & n1Ol1OO & n1Ol1Ol & n1Oli0i);
	n1OOi1l :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 10,
		width_b => 10
	  )
	  PORT MAP ( 
		a => wire_n1OOi1l_a,
		b => wire_n1OOi1l_b,
		cin => wire_gnd,
		o => wire_n1OOi1l_o
	  );
	wire_nl0iiOO_a <= ( "1" & "0" & "0" & "1" & "1");
	wire_nl0iiOO_b <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0iiOO :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_nl0iiOO_a,
		b => wire_nl0iiOO_b,
		cin => wire_vcc,
		o => wire_nl0iiOO_o
	  );
	wire_nl0illl_a <= ( "0" & "1" & "1" & "1" & "1");
	wire_nl0illl_b <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0illl :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_nl0illl_a,
		b => wire_nl0illl_b,
		cin => wire_vcc,
		o => wire_nl0illl_o
	  );
	wire_nl0iOii_a <= ( "0" & "1" & "0" & "0" & "1");
	wire_nl0iOii_b <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0iOii :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_nl0iOii_a,
		b => wire_nl0iOii_b,
		cin => wire_vcc,
		o => wire_nl0iOii_o
	  );
	wire_nl0l11O_a <= ( "0" & "0" & "1" & "1" & "1");
	wire_nl0l11O_b <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0l11O :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 5,
		width_b => 5
	  )
	  PORT MAP ( 
		a => wire_nl0l11O_a,
		b => wire_nl0l11O_b,
		cin => wire_vcc,
		o => wire_nl0l11O_o
	  );
	wire_nllOO1l_a <= ( nlO0i1i & nlO00OO & nlO00Ol & nlO00Oi & nlO00lO & nlO00ll & nlO00li & nlO00iO & nlO00il & nlO00ii);
	wire_nllOO1l_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	nllOO1l :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 10,
		width_b => 10
	  )
	  PORT MAP ( 
		a => wire_nllOO1l_a,
		b => wire_nllOO1l_b,
		cin => wire_vcc,
		o => wire_nllOO1l_o
	  );
	wire_nlO10Ol_a <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	wire_nlO10Ol_b <= ( nlO0i1i & nlO00OO & nlO00Ol & nlO00Oi & nlO00lO & nlO00ll & nlO00li & nlO00iO & nlO00il & nlO00ii);
	nlO10Ol :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 10,
		width_b => 10
	  )
	  PORT MAP ( 
		a => wire_nlO10Ol_a,
		b => wire_nlO10Ol_b,
		cin => wire_gnd,
		o => wire_nlO10Ol_o
	  );
	wire_niOO0l_data <= ( nliO1l & nliO1l & nliO1l & nliO1l & nliO1l & nliO1l & nliO1O & nliO0i & nliO0l & nliO0O & nliOii & nliOil & nliOiO & nliOli & nliOll & nliOlO);
	wire_niOO0l_sel <= ( wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	niOO0l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niOO0l_data,
		o => wire_niOO0l_o,
		sel => wire_niOO0l_sel
	  );
	wire_niOO0O_data <= ( nliO1O & nliO1O & nliO1O & nliO1O & nliO1O & nliO1O & nliO0i & nliO0l & nliO0O & nliOii & nliOil & nliOiO & nliOli & nliOll & nliOlO & nliOOi);
	wire_niOO0O_sel <= ( wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	niOO0O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niOO0O_data,
		o => wire_niOO0O_o,
		sel => wire_niOO0O_sel
	  );
	wire_niOOii_data <= ( nliO0i & nliO0i & nliO0i & nliO0i & nliO0i & nliO0i & nliO0l & nliO0O & nliOii & nliOil & nliOiO & nliOli & nliOll & nliOlO & nliOOi & nliOOl);
	wire_niOOii_sel <= ( wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	niOOii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niOOii_data,
		o => wire_niOOii_o,
		sel => wire_niOOii_sel
	  );
	wire_niOOil_data <= ( nliO0l & nliO0l & nliO0l & nliO0l & nliO0l & nliO0l & nliO0O & nliOii & nliOil & nliOiO & nliOli & nliOll & nliOlO & nliOOi & nliOOl & nliOOO);
	wire_niOOil_sel <= ( wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	niOOil :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niOOil_data,
		o => wire_niOOil_o,
		sel => wire_niOOil_sel
	  );
	wire_niOOiO_data <= ( nliO0O & nliO0O & nliO0O & nliO0O & nliO0O & nliO0O & nliOii & nliOil & nliOiO & nliOli & nliOll & nliOlO & nliOOi & nliOOl & nliOOO & nll11i);
	wire_niOOiO_sel <= ( wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	niOOiO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niOOiO_data,
		o => wire_niOOiO_o,
		sel => wire_niOOiO_sel
	  );
	wire_niOOli_data <= ( nliOii & nliOii & nliOii & nliOii & nliOii & nliOii & nliOil & nliOiO & nliOli & nliOll & nliOlO & nliOOi & nliOOl & nliOOO & nll11i & nll11l);
	wire_niOOli_sel <= ( wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	niOOli :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niOOli_data,
		o => wire_niOOli_o,
		sel => wire_niOOli_sel
	  );
	wire_niOOll_data <= ( nliOil & nliOil & nliOil & nliOil & nliOil & nliOil & nliOiO & nliOli & nliOll & nliOlO & nliOOi & nliOOl & nliOOO & nll11i & nll11l & nll11O);
	wire_niOOll_sel <= ( wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	niOOll :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niOOll_data,
		o => wire_niOOll_o,
		sel => wire_niOOll_sel
	  );
	wire_niOOlO_data <= ( nliOiO & nliOiO & nliOiO & nliOiO & nliOiO & nliOiO & nliOli & nliOll & nliOlO & nliOOi & nliOOl & nliOOO & nll11i & nll11l & nll11O & nll10i);
	wire_niOOlO_sel <= ( wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	niOOlO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niOOlO_data,
		o => wire_niOOlO_o,
		sel => wire_niOOlO_sel
	  );
	wire_niOOOi_data <= ( nliOli & nliOli & nliOli & nliOli & nliOli & nliOli & nliOll & nliOlO & nliOOi & nliOOl & nliOOO & nll11i & nll11l & nll11O & nll10i & nll10l);
	wire_niOOOi_sel <= ( wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	niOOOi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niOOOi_data,
		o => wire_niOOOi_o,
		sel => wire_niOOOi_sel
	  );
	wire_niOOOl_data <= ( nliOll & nliOll & nliOll & nliOll & nliOll & nliOll & nliOlO & nliOOi & nliOOl & nliOOO & nll11i & nll11l & nll11O & nll10i & nll10l & nll1ii);
	wire_niOOOl_sel <= ( wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	niOOOl :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_niOOOl_data,
		o => wire_niOOOl_o,
		sel => wire_niOOOl_sel
	  );
	wire_nl00l0i_data <= ( nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0l0i & nll0l1O & nll0l1l & nll0l1i & nll0iOO & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i);
	wire_nl00l0i_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00l0i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00l0i_data,
		o => wire_nl00l0i_o,
		sel => wire_nl00l0i_sel
	  );
	wire_nl00l0l_data <= ( nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0i0i & nll0lil & nll0lii & nll0l0O & nll0l0l & nll0l0i & nll0l1O & nll0l1l & nll0l1i & nll0iOO & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i);
	wire_nl00l0l_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00l0l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00l0l_data,
		o => wire_nl00l0l_o,
		sel => wire_nl00l0l_sel
	  );
	wire_nl00l0O_data <= ( nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O & nll000l & nll000i & nll001O & nll001l & nll001i & nll01OO & nll01Ol);
	wire_nl00l0O_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00l0O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00l0O_data,
		o => wire_nl00l0O_o,
		sel => wire_nl00l0O_sel
	  );
	wire_nl00lii_data <= ( nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll0i0i & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O & nll000l & nll000i & nll001O & nll001l & nll001i & nll01OO);
	wire_nl00lii_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00lii :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00lii_data,
		o => wire_nl00lii_o,
		sel => wire_nl00lii_sel
	  );
	wire_nl00lil_data <= ( nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll0i0l & nll0i0i & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O & nll000l & nll000i & nll001O & nll001l & nll001i);
	wire_nl00lil_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00lil :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00lil_data,
		o => wire_nl00lil_o,
		sel => wire_nl00lil_sel
	  );
	wire_nl00liO_data <= ( nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll0i0O & nll0i0l & nll0i0i & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O & nll000l & nll000i & nll001O & nll001l);
	wire_nl00liO_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00liO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00liO_data,
		o => wire_nl00liO_o,
		sel => wire_nl00liO_sel
	  );
	wire_nl00lli_data <= ( nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O & nll000l & nll000i & nll001O);
	wire_nl00lli_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00lli :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00lli_data,
		o => wire_nl00lli_o,
		sel => wire_nl00lli_sel
	  );
	wire_nl00lll_data <= ( nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O & nll000l & nll000i);
	wire_nl00lll_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00lll :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00lll_data,
		o => wire_nl00lll_o,
		sel => wire_nl00lll_sel
	  );
	wire_nl00llO_data <= ( nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O & nll000l);
	wire_nl00llO_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00llO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00llO_data,
		o => wire_nl00llO_o,
		sel => wire_nl00llO_sel
	  );
	wire_nl00lOi_data <= ( nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O);
	wire_nl00lOi_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00lOi :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00lOi_data,
		o => wire_nl00lOi_o,
		sel => wire_nl00lOi_sel
	  );
	wire_nl00lOl_data <= ( nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii);
	wire_nl00lOl_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00lOl :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00lOl_data,
		o => wire_nl00lOl_o,
		sel => wire_nl00lOl_sel
	  );
	wire_nl00lOO_data <= ( nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il);
	wire_nl00lOO_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00lOO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00lOO_data,
		o => wire_nl00lOO_o,
		sel => wire_nl00lOO_sel
	  );
	wire_nl00O0i_data <= ( nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll0l1i & nll0iOO & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll00Ol & nll00Oi & nll00lO);
	wire_nl00O0i_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00O0i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00O0i_data,
		o => wire_nl00O0i_o,
		sel => wire_nl00O0i_sel
	  );
	wire_nl00O0l_data <= ( nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll0l1l & nll0l1i & nll0iOO & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll00Ol & nll00Oi);
	wire_nl00O0l_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00O0l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00O0l_data,
		o => wire_nl00O0l_o,
		sel => wire_nl00O0l_sel
	  );
	wire_nl00O0O_data <= ( nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll0l1O & nll0l1l & nll0l1i & nll0iOO & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll00Ol);
	wire_nl00O0O_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00O0O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00O0O_data,
		o => wire_nl00O0O_o,
		sel => wire_nl00O0O_sel
	  );
	wire_nl00O1i_data <= ( nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO);
	wire_nl00O1i_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00O1i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00O1i_data,
		o => wire_nl00O1i_o,
		sel => wire_nl00O1i_sel
	  );
	wire_nl00O1l_data <= ( nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li);
	wire_nl00O1l_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00O1l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00O1l_data,
		o => wire_nl00O1l_o,
		sel => wire_nl00O1l_sel
	  );
	wire_nl00O1O_data <= ( nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll0iOO & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll00Ol & nll00Oi & nll00lO & nll00ll);
	wire_nl00O1O_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00O1O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00O1O_data,
		o => wire_nl00O1O_o,
		sel => wire_nl00O1O_sel
	  );
	wire_nl00Oil_data <= ( nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll01Ol & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O & nll000l & nll000i & nll001O & nll001l & nll001i & nll01OO & nll01Ol);
	wire_nl00Oil_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00Oil :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00Oil_data,
		o => wire_nl00Oil_o,
		sel => wire_nl00Oil_sel
	  );
	wire_nl00OiO_data <= ( nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll01OO & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O & nll000l & nll000i & nll001O & nll001l & nll001i & nll01OO);
	wire_nl00OiO_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00OiO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00OiO_data,
		o => wire_nl00OiO_o,
		sel => wire_nl00OiO_sel
	  );
	wire_nl00Oli_data <= ( nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll001i & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O & nll000l & nll000i & nll001O & nll001l & nll001i);
	wire_nl00Oli_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00Oli :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00Oli_data,
		o => wire_nl00Oli_o,
		sel => wire_nl00Oli_sel
	  );
	wire_nl00Oll_data <= ( nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll001l & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O & nll000l & nll000i & nll001O & nll001l);
	wire_nl00Oll_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00Oll :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00Oll_data,
		o => wire_nl00Oll_o,
		sel => wire_nl00Oll_sel
	  );
	wire_nl00OlO_data <= ( nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll001O & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O & nll000l & nll000i & nll001O);
	wire_nl00OlO_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00OlO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00OlO_data,
		o => wire_nl00OlO_o,
		sel => wire_nl00OlO_sel
	  );
	wire_nl00OOi_data <= ( nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll000i & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O & nll000l & nll000i);
	wire_nl00OOi_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00OOi :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00OOi_data,
		o => wire_nl00OOi_o,
		sel => wire_nl00OOi_sel
	  );
	wire_nl00OOl_data <= ( nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll000l & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O & nll000l);
	wire_nl00OOl_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00OOl :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00OOl_data,
		o => wire_nl00OOl_o,
		sel => wire_nl00OOl_sel
	  );
	wire_nl00OOO_data <= ( nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll000O & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii & nll000O);
	wire_nl00OOO_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl00OOO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl00OOO_data,
		o => wire_nl00OOO_o,
		sel => wire_nl00OOO_sel
	  );
	wire_nl0i0Ol_data <= ( wire_nl0ii0i_dataout & wire_nl0il1i_dataout & wire_nl0illO_dataout & wire_nl0iOil_dataout);
	wire_nl0i0Ol_sel <= ( pmadwidth(1 DOWNTO 0));
	nl0i0Ol :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl0i0Ol_data,
		o => wire_nl0i0Ol_o,
		sel => wire_nl0i0Ol_sel
	  );
	wire_nl0i0OO_data <= ( wire_nl0ii0l_dataout & wire_nl0il1l_dataout & wire_nl0ilOi_dataout & wire_nl0iOiO_dataout);
	wire_nl0i0OO_sel <= ( pmadwidth(1 DOWNTO 0));
	nl0i0OO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl0i0OO_data,
		o => wire_nl0i0OO_o,
		sel => wire_nl0i0OO_sel
	  );
	wire_nl0i10i_data <= ( nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll00li & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li);
	wire_nl0i10i_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0i10i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl0i10i_data,
		o => wire_nl0i10i_o,
		sel => wire_nl0i10i_sel
	  );
	wire_nl0i10l_data <= ( nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll00ll & nll0iOO & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol & nll00Oi & nll00lO & nll00ll);
	wire_nl0i10l_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0i10l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl0i10l_data,
		o => wire_nl0i10l_o,
		sel => wire_nl0i10l_sel
	  );
	wire_nl0i10O_data <= ( nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll00lO & nll0l1i & nll0iOO & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol & nll00Oi & nll00lO);
	wire_nl0i10O_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0i10O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl0i10O_data,
		o => wire_nl0i10O_o,
		sel => wire_nl0i10O_sel
	  );
	wire_nl0i11i_data <= ( nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll00ii & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il & nll00ii);
	wire_nl0i11i_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0i11i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl0i11i_data,
		o => wire_nl0i11i_o,
		sel => wire_nl0i11i_sel
	  );
	wire_nl0i11l_data <= ( nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll00il & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO & nll00il);
	wire_nl0i11l_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0i11l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl0i11l_data,
		o => wire_nl0i11l_o,
		sel => wire_nl0i11l_sel
	  );
	wire_nl0i11O_data <= ( nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll00iO & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol & nll00Oi & nll00lO & nll00ll & nll00li & nll00iO);
	wire_nl0i11O_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0i11O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl0i11O_data,
		o => wire_nl0i11O_o,
		sel => wire_nl0i11O_sel
	  );
	wire_nl0i1ii_data <= ( nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll00Oi & nll0l1l & nll0l1i & nll0iOO & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol & nll00Oi);
	wire_nl0i1ii_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0i1ii :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl0i1ii_data,
		o => wire_nl0i1ii_o,
		sel => wire_nl0i1ii_sel
	  );
	wire_nl0i1il_data <= ( nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll00Ol & nll0l1O & nll0l1l & nll0l1i & nll0iOO & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO & nll00Ol);
	wire_nl0i1il_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0i1il :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl0i1il_data,
		o => wire_nl0i1il_o,
		sel => wire_nl0i1il_sel
	  );
	wire_nl0i1iO_data <= ( nll00OO & nll00OO & nll00OO & nll00OO & nll00OO & nll00OO & nll00OO & nll00OO & nll00OO & nll00OO & nll00OO & nll00OO & nll0l0i & nll0l1O & nll0l1l & nll0l1i & nll0iOO & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i & nll00OO);
	wire_nl0i1iO_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0i1iO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl0i1iO_data,
		o => wire_nl0i1iO_o,
		sel => wire_nl0i1iO_sel
	  );
	wire_nl0i1li_data <= ( nll0i1i & nll0i1i & nll0i1i & nll0i1i & nll0i1i & nll0i1i & nll0i1i & nll0i1i & nll0i1i & nll0i1i & nll0i1i & nll0i1i & nll0l0l & nll0l0i & nll0l1O & nll0l1l & nll0l1i & nll0iOO & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l & nll0i1i);
	wire_nl0i1li_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0i1li :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl0i1li_data,
		o => wire_nl0i1li_o,
		sel => wire_nl0i1li_sel
	  );
	wire_nl0i1ll_data <= ( nll0i1l & nll0i1l & nll0i1l & nll0i1l & nll0i1l & nll0i1l & nll0i1l & nll0i1l & nll0i1l & nll0i1l & nll0i1l & nll0i1l & nll0l0O & nll0l0l & nll0l0i & nll0l1O & nll0l1l & nll0l1i & nll0iOO & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O & nll0i1l);
	wire_nl0i1ll_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0i1ll :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl0i1ll_data,
		o => wire_nl0i1ll_o,
		sel => wire_nl0i1ll_sel
	  );
	wire_nl0i1lO_data <= ( nll0i1O & nll0i1O & nll0i1O & nll0i1O & nll0i1O & nll0i1O & nll0i1O & nll0i1O & nll0i1O & nll0i1O & nll0i1O & nll0i1O & nll0lii & nll0l0O & nll0l0l & nll0l0i & nll0l1O & nll0l1l & nll0l1i & nll0iOO & nll0iOl & nll0iOi & nll0ilO & nll0ill & nll0ili & nll0iiO & nll0iil & nll0iii & nll0i0O & nll0i0l & nll0i0i & nll0i1O);
	wire_nl0i1lO_sel <= ( nl010ii & nl0100O & nl0100l & nl0100i & nl0101O);
	nl0i1lO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl0i1lO_data,
		o => wire_nl0i1lO_o,
		sel => wire_nl0i1lO_sel
	  );
	wire_nl0ii1i_data <= ( wire_nl0ii0O_dataout & wire_nl0il1O_dataout & wire_nl0ilOl_dataout & wire_nl0iOli_dataout);
	wire_nl0ii1i_sel <= ( pmadwidth(1 DOWNTO 0));
	nl0ii1i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl0ii1i_data,
		o => wire_nl0ii1i_o,
		sel => wire_nl0ii1i_sel
	  );
	wire_nl0ii1l_data <= ( wire_nl0iiii_dataout & wire_nl0il0i_dataout & wire_nl0ilOO_dataout & wire_nl0iOll_dataout);
	wire_nl0ii1l_sel <= ( pmadwidth(1 DOWNTO 0));
	nl0ii1l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl0ii1l_data,
		o => wire_nl0ii1l_o,
		sel => wire_nl0ii1l_sel
	  );
	wire_nl0ii1O_data <= ( wire_nl0iiil_dataout & wire_nl0il0l_dataout & wire_nl0iO1i_dataout & wire_nl0iOlO_dataout);
	wire_nl0ii1O_sel <= ( pmadwidth(1 DOWNTO 0));
	nl0ii1O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl0ii1O_data,
		o => wire_nl0ii1O_o,
		sel => wire_nl0ii1O_sel
	  );
	wire_nl0l0OO_data <= ( n111OOO & n111OOO & n111O0O & n111OOO & n111O0O & n111OOO & n111O0O & wire_w_lg_w_lg_comp_pat_porn5757w5758w);
	wire_nl0l0OO_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0l0OO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0l0OO_data,
		o => wire_nl0l0OO_o,
		sel => wire_nl0l0OO_sel
	  );
	wire_nl0li1i_data <= ( n11011O & n11011O & n111OiO & n11011O & n111OiO & wire_w_lg_w_lg_comp_pat_porn5743w5744w & n111OlO & wire_w_lg_w_lg_comp_pat_porn5738w5739w);
	wire_nl0li1i_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0li1i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0li1i_data,
		o => wire_nl0li1i_o,
		sel => wire_nl0li1i_sel
	  );
	wire_nl0OiOl_w_lg_o13575w(0) <= NOT wire_nl0OiOl_o;
	wire_nl0OiOl_w_lg_o5684w(0) <= wire_nl0OiOl_o OR wire_w_lg_n110O1i5616w(0);
	wire_nl0OiOl_w_lg_o5615w(0) <= wire_nl0OiOl_o OR wire_w_lg_n110O1l5614w(0);
	wire_nl0OiOl_data <= ( n10iOOi & n101iil & n11iO0i & n1000ll & n11lili & n10i1lO & n11O1Ol & n10iOOi);
	wire_nl0OiOl_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0OiOl :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0OiOl_data,
		o => wire_nl0OiOl_o,
		sel => wire_nl0OiOl_sel
	  );
	wire_nl0OiOO_w_lg_o5429w(0) <= NOT wire_nl0OiOO_o;
	wire_nl0OiOO_data <= ( n10iOli & n101i1O & n11ilOl & n1000il & n11liii & n10i1iO & n11O1ll & n10iOli);
	wire_nl0OiOO_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0OiOO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0OiOO_data,
		o => wire_nl0OiOO_o,
		sel => wire_nl0OiOO_sel
	  );
	wire_nl0Ol0i_w_lg_o5439w(0) <= NOT wire_nl0Ol0i_o;
	wire_nl0Ol0i_data <= ( n10ilOi & n1011Oi & n11iiiO & n1001ll & n11l0li & n100OlO & n11lOOl & n10ilOi);
	wire_nl0Ol0i_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0Ol0i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0Ol0i_data,
		o => wire_nl0Ol0i_o,
		sel => wire_nl0Ol0i_sel
	  );
	wire_nl0Ol0l_w_lg_o5445w(0) <= NOT wire_nl0Ol0l_o;
	wire_nl0Ol0l_data <= ( n10illi & n1011il & n11ii0i & n1001il & n11l0ii & n100OiO & n11lOll & n10illi);
	wire_nl0Ol0l_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0Ol0l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0Ol0l_data,
		o => wire_nl0Ol0l_o,
		sel => wire_nl0Ol0l_sel
	  );
	wire_nl0Ol0O_w_lg_o5452w(0) <= NOT wire_nl0Ol0O_o;
	wire_nl0Ol0O_data <= ( n10ilii & n10111O & n11i0Ol & n10010l & n11l00i & n100O0O & n11lOil & n10ilii);
	wire_nl0Ol0O_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0Ol0O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0Ol0O_data,
		o => wire_nl0Ol0O_o,
		sel => wire_nl0Ol0O_sel
	  );
	wire_nl0Ol1i_w_lg_o5431w(0) <= NOT wire_nl0Ol1i_o;
	wire_nl0Ol1i_data <= ( n10iOii & n1010Oi & n11iliO & n10000l & n11li0i & n10i10O & n11O1il & n10iOii);
	wire_nl0Ol1i_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0Ol1i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0Ol1i_data,
		o => wire_nl0Ol1i_o,
		sel => wire_nl0Ol1i_sel
	  );
	wire_nl0Ol1l_w_lg_o5618w(0) <= NOT wire_nl0Ol1l_o;
	wire_nl0Ol1l_data <= ( n10iO0i & n1010il & n11il0i & n10001l & n11li1i & n10i11O & n11O10l & n10iO0i);
	wire_nl0Ol1l_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0Ol1l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0Ol1l_data,
		o => wire_nl0Ol1l_o,
		sel => wire_nl0Ol1l_sel
	  );
	wire_nl0Ol1O_w_lg_o5434w(0) <= NOT wire_nl0Ol1O_o;
	wire_nl0Ol1O_data <= ( n10iO1i & n10101O & n11iiOl & n1001Ol & n11l0Oi & n100OOO & n11O11l & n10iO1i);
	wire_nl0Ol1O_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0Ol1O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0Ol1O_data,
		o => wire_nl0Ol1O_o,
		sel => wire_nl0Ol1O_sel
	  );
	wire_nl0Olii_w_lg_o5460w(0) <= NOT wire_nl0Olii_o;
	wire_nl0Olii_data <= ( n10il0i & n11OOOi & n11i0iO & n10011l & n11l01i & n100O1O & n11lO0l & n10il0i);
	wire_nl0Olii_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0Olii :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0Olii_data,
		o => wire_nl0Olii_o,
		sel => wire_nl0Olii_sel
	  );
	wire_nl0Olil_w_lg_o5469w(0) <= NOT wire_nl0Olil_o;
	wire_nl0Olil_data <= ( n10il1i & n11OOil & n11i00i & n101OOl & n11l1Oi & n100lOO & n11lO1l & n10il1i);
	wire_nl0Olil_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0Olil :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0Olil_data,
		o => wire_nl0Olil_o,
		sel => wire_nl0Olil_sel
	  );
	wire_nl0OliO_w_lg_o5479w(0) <= NOT wire_nl0OliO_o;
	wire_nl0OliO_data <= ( n10iiOi & n11OO1O & n11i1Ol & n101Oll & n11l1li & n100llO & n11llOl & n10iiOi);
	wire_nl0OliO_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0OliO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0OliO_data,
		o => wire_nl0OliO_o,
		sel => wire_nl0OliO_sel
	  );
	wire_nl0Olli_w_lg_o5490w(0) <= NOT wire_nl0Olli_o;
	wire_nl0Olli_data <= ( n10iili & n11OlOi & n11i1iO & n101Oil & n11l1ii & n100liO & n11llll & n10iili);
	wire_nl0Olli_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0Olli :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0Olli_data,
		o => wire_nl0Olli_o,
		sel => wire_nl0Olli_sel
	  );
	wire_nl0Olll_w_lg_o5502w(0) <= NOT wire_nl0Olll_o;
	wire_nl0Olll_data <= ( n10iiii & n11Olil & n11i10i & n101O0l & n11l10i & n100l0O & n11llil & n10iiii);
	wire_nl0Olll_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0Olll :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0Olll_data,
		o => wire_nl0Olll_o,
		sel => wire_nl0Olll_sel
	  );
	wire_nl0OllO_w_lg_o5515w(0) <= NOT wire_nl0OllO_o;
	wire_nl0OllO_data <= ( n10ii0i & n11Ol1O & n110OOl & n101O1l & n11l11i & n100l1O & n11ll0l & n10ii0i);
	wire_nl0OllO_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0OllO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0OllO_data,
		o => wire_nl0OllO_o,
		sel => wire_nl0OllO_sel
	  );
	wire_nl0OlOi_w_lg_o5529w(0) <= NOT wire_nl0OlOi_o;
	wire_nl0OlOi_data <= ( n10ii1i & n11OiOi & n110OiO & n101lOl & n11iOOi & n100iOO & n11ll1l & n10ii1i);
	wire_nl0OlOi_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0OlOi :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0OlOi_data,
		o => wire_nl0OlOi_o,
		sel => wire_nl0OlOi_sel
	  );
	wire_nl0OlOl_w_lg_o5544w(0) <= NOT wire_nl0OlOl_o;
	wire_nl0OlOl_data <= ( n10i0Oi & n11Oiil & n110O0i & n101lll & n11iOli & n100ilO & n11liOl & n10i0Oi);
	wire_nl0OlOl_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0OlOl :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0OlOl_data,
		o => wire_nl0OlOl_o,
		sel => wire_nl0OlOl_sel
	  );
	wire_nl0OlOO_w_lg_o5560w(0) <= NOT wire_nl0OlOO_o;
	wire_nl0OlOO_data <= ( n10i0li & n11Oi1O & "0" & n101lil & "0" & n100iiO & "0" & n10i0li);
	wire_nl0OlOO_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0OlOO :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0OlOO_data,
		o => wire_nl0OlOO_o,
		sel => wire_nl0OlOO_sel
	  );
	wire_nl0OO1i_w_lg_o5577w(0) <= NOT wire_nl0OO1i_o;
	wire_nl0OO1i_data <= ( n10i0ii & n11O0Oi & "0" & n101l0l & "0" & n100i0O & "0" & n10i0ii);
	wire_nl0OO1i_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0OO1i :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0OO1i_data,
		o => wire_nl0OO1i_o,
		sel => wire_nl0OO1i_sel
	  );
	wire_nl0OO1l_w_lg_o5595w(0) <= NOT wire_nl0OO1l_o;
	wire_nl0OO1l_data <= ( n10i00i & n11O0il & "0" & n101l1l & "0" & n100i1O & "0" & n10i00i);
	wire_nl0OO1l_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0OO1l :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0OO1l_data,
		o => wire_nl0OO1l_o,
		sel => wire_nl0OO1l_sel
	  );
	wire_nl0OO1O_w_lg_o13557w(0) <= wire_nl0OO1O_o AND wire_nl0OO1l_w_lg_o5595w(0);
	wire_nl0OO1O_data <= ( n10i01i & n11O01O & "0" & n101iOl & "0" & n1000OO & "0" & n10i01i);
	wire_nl0OO1O_sel <= ( comp_pat_size(2 DOWNTO 0));
	nl0OO1O :  oper_mux
	  GENERIC MAP (
		width_data => 8,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nl0OO1O_data,
		o => wire_nl0OO1O_o,
		sel => wire_nl0OO1O_sel
	  );
	wire_nl100i_data <= ( nliOll & nliOll & nliOll & nliOll & nliOll & nliOll & nliO1l & nliO1O & nliO0i & nliO0l & nliO0O & nliOii & nliOil & nliOiO & nliOli & nliOll & nliOll & nliOll & nliOll & nliOll & nliOll & nliOll & nliOll & nliOll & nl11il & nl11il & nl11il & nl11il & nl11il & nl11il & nl11il & nl11il);
	wire_nl100i_sel <= ( pmadwidth(0) & wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	nl100i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl100i_data,
		o => wire_nl100i_o,
		sel => wire_nl100i_sel
	  );
	wire_nl101i_data <= ( nliOil & nliOil & nliOil & nliOil & nliOil & nliOil & nlilOl & nlilOO & nliO1i & nliO1l & nliO1O & nliO0i & nliO0l & nliO0O & nliOii & nliOil & nliOil & nliOil & nliOil & nliOil & nliOil & nliOil & nliOil & nliOil & nliO1O & nliO0i & nliO0l & nliO0O & nliOii & nliOil & nliOiO & nliOli);
	wire_nl101i_sel <= ( pmadwidth(0) & wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	nl101i :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl101i_data,
		o => wire_nl101i_o,
		sel => wire_nl101i_sel
	  );
	wire_nl101l_data <= ( nliOiO & nliOiO & nliOiO & nliOiO & nliOiO & nliOiO & nlilOO & nliO1i & nliO1l & nliO1O & nliO0i & nliO0l & nliO0O & nliOii & nliOil & nliOiO & nliOiO & nliOiO & nliOiO & nliOiO & nliOiO & nliOiO & nliOiO & nliOiO & nliO0i & nliO0l & nliO0O & nliOii & nliOil & nliOiO & nliOli & nliOll);
	wire_nl101l_sel <= ( pmadwidth(0) & wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	nl101l :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl101l_data,
		o => wire_nl101l_o,
		sel => wire_nl101l_sel
	  );
	wire_nl101O_data <= ( nliOli & nliOli & nliOli & nliOli & nliOli & nliOli & nliO1i & nliO1l & nliO1O & nliO0i & nliO0l & nliO0O & nliOii & nliOil & nliOiO & nliOli & nliOli & nliOli & nliOli & nliOli & nliOli & nliOli & nliOli & nliOli & nl11ii & nl11ii & nl11ii & nl11ii & nl11ii & nl11ii & nl11ii & nl11ii);
	wire_nl101O_sel <= ( pmadwidth(0) & wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	nl101O :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl101O_data,
		o => wire_nl101O_o,
		sel => wire_nl101O_sel
	  );
	wire_nl11li_data <= ( nliO1l & nliO1l & nliO1l & nliO1l & nliO1l & nliO1l & nlilil & nliliO & nlilli & nlilll & nlillO & nlilOi & nlilOl & nlilOO & nliO1i & nliO1l & nliO1l & nliO1l & nliO1l & nliO1l & nliO1l & nliO1l & nliO1l & nliO1l & nlillO & nlilOi & nlilOl & nlilOO & nliO1i & nliO1l & nliO1O & nliO0i);
	wire_nl11li_sel <= ( pmadwidth(0) & wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	nl11li :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl11li_data,
		o => wire_nl11li_o,
		sel => wire_nl11li_sel
	  );
	wire_nl11ll_data <= ( nliO1O & nliO1O & nliO1O & nliO1O & nliO1O & nliO1O & nliliO & nlilli & nlilll & nlillO & nlilOi & nlilOl & nlilOO & nliO1i & nliO1l & nliO1O & nliO1O & nliO1O & nliO1O & nliO1O & nliO1O & nliO1O & nliO1O & nliO1O & nlilOi & nlilOl & nlilOO & nliO1i & nliO1l & nliO1O & nliO0i & nliO0l);
	wire_nl11ll_sel <= ( pmadwidth(0) & wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	nl11ll :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl11ll_data,
		o => wire_nl11ll_o,
		sel => wire_nl11ll_sel
	  );
	wire_nl11lO_data <= ( nliO0i & nliO0i & nliO0i & nliO0i & nliO0i & nliO0i & nlilli & nlilll & nlillO & nlilOi & nlilOl & nlilOO & nliO1i & nliO1l & nliO1O & nliO0i & nliO0i & nliO0i & nliO0i & nliO0i & nliO0i & nliO0i & nliO0i & nliO0i & nlilOl & nlilOO & nliO1i & nliO1l & nliO1O & nliO0i & nliO0l & nliO0O);
	wire_nl11lO_sel <= ( pmadwidth(0) & wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	nl11lO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl11lO_data,
		o => wire_nl11lO_o,
		sel => wire_nl11lO_sel
	  );
	wire_nl11Oi_data <= ( nliO0l & nliO0l & nliO0l & nliO0l & nliO0l & nliO0l & nlilll & nlillO & nlilOi & nlilOl & nlilOO & nliO1i & nliO1l & nliO1O & nliO0i & nliO0l & nliO0l & nliO0l & nliO0l & nliO0l & nliO0l & nliO0l & nliO0l & nliO0l & nlilOO & nliO1i & nliO1l & nliO1O & nliO0i & nliO0l & nliO0O & nliOii);
	wire_nl11Oi_sel <= ( pmadwidth(0) & wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	nl11Oi :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl11Oi_data,
		o => wire_nl11Oi_o,
		sel => wire_nl11Oi_sel
	  );
	wire_nl11Ol_data <= ( nliO0O & nliO0O & nliO0O & nliO0O & nliO0O & nliO0O & nlillO & nlilOi & nlilOl & nlilOO & nliO1i & nliO1l & nliO1O & nliO0i & nliO0l & nliO0O & nliO0O & nliO0O & nliO0O & nliO0O & nliO0O & nliO0O & nliO0O & nliO0O & nliO1i & nliO1l & nliO1O & nliO0i & nliO0l & nliO0O & nliOii & nliOil);
	wire_nl11Ol_sel <= ( pmadwidth(0) & wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	nl11Ol :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl11Ol_data,
		o => wire_nl11Ol_o,
		sel => wire_nl11Ol_sel
	  );
	wire_nl11OO_data <= ( nliOii & nliOii & nliOii & nliOii & nliOii & nliOii & nlilOi & nlilOl & nlilOO & nliO1i & nliO1l & nliO1O & nliO0i & nliO0l & nliO0O & nliOii & nliOii & nliOii & nliOii & nliOii & nliOii & nliOii & nliOii & nliOii & nliO1l & nliO1O & nliO0i & nliO0l & nliO0O & nliOii & nliOil & nliOiO);
	wire_nl11OO_sel <= ( pmadwidth(0) & wire_nl011l_dataout & wire_nl011i_dataout & wire_nl1OOO_dataout & wire_nl1OOl_dataout);
	nl11OO :  oper_mux
	  GENERIC MAP (
		width_data => 32,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_nl11OO_data,
		o => wire_nl11OO_o,
		sel => wire_nl11OO_sel
	  );
	wire_nl1liiO_w_lg_o16992w(0) <= NOT wire_nl1liiO_o;
	wire_nl1liiO_data <= ( wire_nl1llOl_o & wire_nl1O10i_o & wire_nl1O00l_dataout & wire_nl1O0OO_dataout);
	wire_nl1liiO_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1liiO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1liiO_data,
		o => wire_nl1liiO_o,
		sel => wire_nl1liiO_sel
	  );
	wire_nl1lili_w_lg_w_lg_o16990w17009w(0) <= wire_nl1lili_w_lg_o16990w(0) AND wire_nl1liiO_w_lg_o16992w(0);
	wire_nl1lili_w_lg_w_lg_o16990w16991w(0) <= wire_nl1lili_w_lg_o16990w(0) AND wire_nl1liiO_o;
	wire_nl1lili_w_lg_o16993w(0) <= wire_nl1lili_o AND wire_nl1liiO_w_lg_o16992w(0);
	wire_nl1lili_w_lg_o16990w(0) <= NOT wire_nl1lili_o;
	wire_nl1lili_data <= ( wire_nl1llOO_o & wire_nl1O10l_o & wire_nl1O00O_dataout & wire_nl1Oi1i_dataout);
	wire_nl1lili_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1lili :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lili_data,
		o => wire_nl1lili_o,
		sel => wire_nl1lili_sel
	  );
	wire_nl1lill_w_lg_w_lg_o16982w17179w(0) <= wire_nl1lill_w_lg_o16982w(0) AND nlOO1iOl;
	wire_nl1lill_w_lg_w_lg_o16982w17174w(0) <= wire_nl1lill_w_lg_o16982w(0) AND nlOO1iOO;
	wire_nl1lill_w_lg_w_lg_o16982w17167w(0) <= wire_nl1lill_w_lg_o16982w(0) AND nlOO1l1i;
	wire_nl1lill_w_lg_w_lg_o16982w17164w(0) <= wire_nl1lill_w_lg_o16982w(0) AND nlOO1l1l;
	wire_nl1lill_w_lg_w_lg_o16982w17026w(0) <= wire_nl1lill_w_lg_o16982w(0) AND nlOO1O0O;
	wire_nl1lill_w_lg_w_lg_o16982w17021w(0) <= wire_nl1lill_w_lg_o16982w(0) AND nlOO1Oii;
	wire_nl1lill_w_lg_w_lg_o16982w17006w(0) <= wire_nl1lill_w_lg_o16982w(0) AND nlOO1Oil;
	wire_nl1lill_w_lg_w_lg_o16982w17003w(0) <= wire_nl1lill_w_lg_o16982w(0) AND nlOO1OiO;
	wire_nl1lill_w_lg_o17010w(0) <= wire_nl1lill_o AND wire_nl1lili_w_lg_w_lg_o16990w17009w(0);
	wire_nl1lill_w_lg_o17029w(0) <= wire_nl1lill_o AND wire_nl1lili_w_lg_w_lg_o16990w16991w(0);
	wire_nl1lill_w_lg_o17032w(0) <= wire_nl1lill_o AND wire_nl1lili_w_lg_o16993w(0);
	wire_nl1lill_w_lg_o16982w(0) <= NOT wire_nl1lill_o;
	wire_nl1lill_data <= ( wire_nl1lO1i_o & wire_nl1O10O_o & wire_nl1O0ii_dataout & wire_nl1Oi1l_dataout);
	wire_nl1lill_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1lill :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lill_data,
		o => wire_nl1lill_o,
		sel => wire_nl1lill_sel
	  );
	wire_nl1lilO_w_lg_w_lg_o16913w17152w(0) <= wire_nl1lilO_w_lg_o16913w(0) AND nlOO1l1O;
	wire_nl1lilO_w_lg_w_lg_o16913w17112w(0) <= wire_nl1lilO_w_lg_o16913w(0) AND nlOO1lii;
	wire_nl1lilO_w_lg_o17180w(0) <= wire_nl1lilO_o AND wire_nl1lill_w_lg_w_lg_o16982w17179w(0);
	wire_nl1lilO_w_lg_o17175w(0) <= wire_nl1lilO_o AND wire_nl1lill_w_lg_w_lg_o16982w17174w(0);
	wire_nl1lilO_w_lg_o17168w(0) <= wire_nl1lilO_o AND wire_nl1lill_w_lg_w_lg_o16982w17167w(0);
	wire_nl1lilO_w_lg_o17165w(0) <= wire_nl1lilO_o AND wire_nl1lill_w_lg_w_lg_o16982w17164w(0);
	wire_nl1lilO_w_lg_o17027w(0) <= wire_nl1lilO_o AND wire_nl1lill_w_lg_w_lg_o16982w17026w(0);
	wire_nl1lilO_w_lg_o17022w(0) <= wire_nl1lilO_o AND wire_nl1lill_w_lg_w_lg_o16982w17021w(0);
	wire_nl1lilO_w_lg_o17007w(0) <= wire_nl1lilO_o AND wire_nl1lill_w_lg_w_lg_o16982w17006w(0);
	wire_nl1lilO_w_lg_o17004w(0) <= wire_nl1lilO_o AND wire_nl1lill_w_lg_w_lg_o16982w17003w(0);
	wire_nl1lilO_w_lg_o17011w(0) <= wire_nl1lilO_o AND wire_nl1lill_w_lg_o17010w(0);
	wire_nl1lilO_w_lg_o17030w(0) <= wire_nl1lilO_o AND wire_nl1lill_w_lg_o17029w(0);
	wire_nl1lilO_w_lg_o17033w(0) <= wire_nl1lilO_o AND wire_nl1lill_w_lg_o17032w(0);
	wire_nl1lilO_w_lg_o16979w(0) <= wire_nl1lilO_o AND wire_nl1lill_o;
	wire_nl1lilO_w_lg_o16913w(0) <= NOT wire_nl1lilO_o;
	wire_nl1lilO_data <= ( wire_nl1lO1l_o & wire_nl1O1ii_o & wire_nl1O0il_dataout & wire_nl1Oi1O_dataout);
	wire_nl1lilO_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1lilO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lilO_data,
		o => wire_nl1lilO_o,
		sel => wire_nl1lilO_sel
	  );
	wire_nl1liOi_w_lg_w_lg_o16843w16914w(0) <= wire_nl1liOi_w_lg_o16843w(0) AND wire_nl1lilO_w_lg_o16913w(0);
	wire_nl1liOi_w_lg_w_lg_o16843w16844w(0) <= wire_nl1liOi_w_lg_o16843w(0) AND nlOO000i;
	wire_nl1liOi_w_lg_w_lg_o16843w16907w(0) <= wire_nl1liOi_w_lg_o16843w(0) AND nlOO01lO;
	wire_nl1liOi_w_lg_w_lg_o16843w16955w(0) <= wire_nl1liOi_w_lg_o16843w(0) AND nlOO1OOl;
	wire_nl1liOi_w_lg_o16980w(0) <= wire_nl1liOi_o AND wire_nl1lilO_w_lg_o16979w(0);
	wire_nl1liOi_w_lg_o16847w(0) <= wire_nl1liOi_o AND nlOO001O;
	wire_nl1liOi_w_lg_o16925w(0) <= wire_nl1liOi_o AND nlOO01lO;
	wire_nl1liOi_w_lg_o16931w(0) <= wire_nl1liOi_o AND wire_nl1lilO_o;
	wire_nl1liOi_w_lg_o16843w(0) <= NOT wire_nl1liOi_o;
	wire_nl1liOi_data <= ( wire_nl1lO1O_o & wire_nl1O1il_o & wire_nl1O0iO_dataout & wire_nl1Oi0i_dataout);
	wire_nl1liOi_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1liOi :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1liOi_data,
		o => wire_nl1liOi_o,
		sel => wire_nl1liOi_sel
	  );
	wire_nl1liOl_w_lg_w_lg_o16842w16915w(0) <= wire_nl1liOl_w_lg_o16842w(0) AND wire_nl1liOi_w_lg_w_lg_o16843w16914w(0);
	wire_nl1liOl_w_lg_w_lg_o16842w16908w(0) <= wire_nl1liOl_w_lg_o16842w(0) AND wire_nl1liOi_w_lg_w_lg_o16843w16907w(0);
	wire_nl1liOl_w_lg_w_lg_o16842w16987w(0) <= wire_nl1liOl_w_lg_o16842w(0) AND wire_nl1liOi_o;
	wire_nl1liOl_w_lg_w_lg_w_lg_o16842w16910w16911w(0) <= wire_nl1liOl_w_lg_w_lg_o16842w16910w(0) AND nlOO000i;
	wire_nl1liOl_w_lg_w16916w16922w(0) <= wire_nl1liOl_w16916w(0) AND wire_w_lg_w_lg_nlOO01Oi16918w16921w(0);
	wire_nl1liOl_w16941w(0) <= wire_nl1liOl_w_lg_w_lg_w_lg_w_lg_o16926w16927w16930w16933w(0) AND wire_w_lg_w_lg_nlOO01Ol16936w16940w(0);
	wire_nl1liOl_w_lg_w_lg_o16928w16929w(0) <= wire_nl1liOl_w_lg_o16928w(0) AND nlOO001O;
	wire_nl1liOl_w_lg_o16956w(0) <= wire_nl1liOl_o AND wire_nl1liOi_w_lg_w_lg_o16843w16955w(0);
	wire_nl1liOl_w_lg_o16981w(0) <= wire_nl1liOl_o AND wire_nl1liOi_w_lg_o16980w(0);
	wire_nl1liOl_w_lg_o16848w(0) <= wire_nl1liOl_o AND wire_nl1liOi_w_lg_o16847w(0);
	wire_nl1liOl_w_lg_o16926w(0) <= wire_nl1liOl_o AND wire_nl1liOi_w_lg_o16925w(0);
	wire_nl1liOl_w_lg_o16932w(0) <= wire_nl1liOl_o AND wire_nl1liOi_w_lg_o16931w(0);
	wire_nl1liOl_w_lg_o16988w(0) <= wire_nl1liOl_o AND wire_nl1liOi_w_lg_o16843w(0);
	wire_nl1liOl_w_lg_o16867w(0) <= wire_nl1liOl_o AND wire_nl1liOi_o;
	wire_nl1liOl_w_lg_o16842w(0) <= NOT wire_nl1liOl_o;
	wire_nl1liOl_w_lg_w_lg_w_lg_o16842w16908w16909w(0) <= wire_nl1liOl_w_lg_w_lg_o16842w16908w(0) OR nlOO000l;
	wire_nl1liOl_w_lg_w_lg_o16926w16927w(0) <= wire_nl1liOl_w_lg_o16926w(0) OR nlOO000O;
	wire_nl1liOl_w_lg_w_lg_o16842w16910w(0) <= wire_nl1liOl_w_lg_o16842w(0) OR wire_nl1liOi_w_lg_o16843w(0);
	wire_nl1liOl_w_lg_w_lg_w_lg_w_lg_o16842w16908w16909w16912w(0) <= wire_nl1liOl_w_lg_w_lg_w_lg_o16842w16908w16909w(0) OR wire_nl1liOl_w_lg_w_lg_w_lg_o16842w16910w16911w(0);
	wire_nl1liOl_w_lg_w_lg_w_lg_o16926w16927w16930w(0) <= wire_nl1liOl_w_lg_w_lg_o16926w16927w(0) OR wire_nl1liOl_w_lg_w_lg_o16928w16929w(0);
	wire_nl1liOl_w16916w(0) <= wire_nl1liOl_w_lg_w_lg_w_lg_w_lg_o16842w16908w16909w16912w(0) OR wire_nl1liOl_w_lg_w_lg_o16842w16915w(0);
	wire_nl1liOl_w_lg_w_lg_w_lg_w_lg_o16926w16927w16930w16933w(0) <= wire_nl1liOl_w_lg_w_lg_w_lg_o16926w16927w16930w(0) OR wire_nl1liOl_w_lg_o16932w(0);
	wire_nl1liOl_w_lg_o16928w(0) <= wire_nl1liOl_o OR wire_nl1liOi_o;
	wire_nl1liOl_data <= ( wire_nl1lO0i_o & wire_nl1O1iO_o & wire_nl1O0li_dataout & wire_nl1Oi0l_dataout);
	wire_nl1liOl_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1liOl :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1liOl_data,
		o => wire_nl1liOl_o,
		sel => wire_nl1liOl_sel
	  );
	wire_nl1liOO_w_lg_w_lg_o16856w17040w(0) <= wire_nl1liOO_w_lg_o16856w(0) AND nlOO1O0i;
	wire_nl1liOO_w_lg_w_lg_o16856w16963w(0) <= wire_nl1liOO_w_lg_o16856w(0) AND nlOO1Oll;
	wire_nl1liOO_w_lg_o16868w(0) <= wire_nl1liOO_o AND wire_nl1liOl_w_lg_o16867w(0);
	wire_nl1liOO_w_lg_o17121w(0) <= wire_nl1liOO_o AND nlOO1O0i;
	wire_nl1liOO_w_lg_o16856w(0) <= NOT wire_nl1liOO_o;
	wire_nl1liOO_data <= ( wire_nl1lO0l_o & wire_nl1O1li_o & wire_nl1O0ll_dataout & wire_nl1Oi0O_dataout);
	wire_nl1liOO_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1liOO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1liOO_data,
		o => wire_nl1liOO_o,
		sel => wire_nl1liOO_sel
	  );
	wire_nl1ll0i_w_lg_o16648w(0) <= NOT wire_nl1ll0i_o;
	wire_nl1ll0i_data <= ( wire_nl1lOiO_o & wire_nl1O1lO_o & nl01lil & nl01l0O);
	wire_nl1ll0i_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1ll0i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1ll0i_data,
		o => wire_nl1ll0i_o,
		sel => wire_nl1ll0i_sel
	  );
	wire_nl1ll0l_w_lg_w_lg_o16646w16665w(0) <= wire_nl1ll0l_w_lg_o16646w(0) AND wire_nl1ll0i_w_lg_o16648w(0);
	wire_nl1ll0l_w_lg_w_lg_o16646w16647w(0) <= wire_nl1ll0l_w_lg_o16646w(0) AND wire_nl1ll0i_o;
	wire_nl1ll0l_w_lg_o16649w(0) <= wire_nl1ll0l_o AND wire_nl1ll0i_w_lg_o16648w(0);
	wire_nl1ll0l_w_lg_o16646w(0) <= NOT wire_nl1ll0l_o;
	wire_nl1ll0l_data <= ( wire_nl1lOli_o & wire_nl1O1Oi_o & nl01liO & nl01lii);
	wire_nl1ll0l_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1ll0l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1ll0l_data,
		o => wire_nl1ll0l_o,
		sel => wire_nl1ll0l_sel
	  );
	wire_nl1ll0O_w_lg_w_lg_o16638w16835w(0) <= wire_nl1ll0O_w_lg_o16638w(0) AND nlOO00il;
	wire_nl1ll0O_w_lg_w_lg_o16638w16830w(0) <= wire_nl1ll0O_w_lg_o16638w(0) AND nlOO00iO;
	wire_nl1ll0O_w_lg_w_lg_o16638w16823w(0) <= wire_nl1ll0O_w_lg_o16638w(0) AND nlOO00li;
	wire_nl1ll0O_w_lg_w_lg_o16638w16820w(0) <= wire_nl1ll0O_w_lg_o16638w(0) AND nlOO00ll;
	wire_nl1ll0O_w_lg_w_lg_o16638w16682w(0) <= wire_nl1ll0O_w_lg_o16638w(0) AND nlOO0iOO;
	wire_nl1ll0O_w_lg_w_lg_o16638w16677w(0) <= wire_nl1ll0O_w_lg_o16638w(0) AND nlOO0l1i;
	wire_nl1ll0O_w_lg_w_lg_o16638w16662w(0) <= wire_nl1ll0O_w_lg_o16638w(0) AND nlOO0l1l;
	wire_nl1ll0O_w_lg_w_lg_o16638w16659w(0) <= wire_nl1ll0O_w_lg_o16638w(0) AND nlOO0l1O;
	wire_nl1ll0O_w_lg_o16666w(0) <= wire_nl1ll0O_o AND wire_nl1ll0l_w_lg_w_lg_o16646w16665w(0);
	wire_nl1ll0O_w_lg_o16685w(0) <= wire_nl1ll0O_o AND wire_nl1ll0l_w_lg_w_lg_o16646w16647w(0);
	wire_nl1ll0O_w_lg_o16688w(0) <= wire_nl1ll0O_o AND wire_nl1ll0l_w_lg_o16649w(0);
	wire_nl1ll0O_w_lg_o16638w(0) <= NOT wire_nl1ll0O_o;
	wire_nl1ll0O_data <= ( wire_nl1lOll_o & wire_nl1O1Ol_o & nl01lli & nl01lil);
	wire_nl1ll0O_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1ll0O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1ll0O_data,
		o => wire_nl1ll0O_o,
		sel => wire_nl1ll0O_sel
	  );
	wire_nl1ll1i_w_lg_w_lg_w_lg_o16855w17043w17044w(0) <= wire_nl1ll1i_w_lg_w_lg_o16855w17043w(0) AND nlOO1O1l;
	wire_nl1ll1i_w_lg_w_lg_o17045w17046w(0) <= wire_nl1ll1i_w_lg_o17045w(0) AND nlOO1O1l;
	wire_nl1ll1i_w_lg_w_lg_o16855w17053w(0) <= wire_nl1ll1i_w_lg_o16855w(0) AND wire_w_lg_nlOO1OOO17052w(0);
	wire_nl1ll1i_w_lg_w_lg_o16855w16857w(0) <= wire_nl1ll1i_w_lg_o16855w(0) AND wire_nl1liOO_w_lg_o16856w(0);
	wire_nl1ll1i_w_lg_w_lg_o16855w16895w(0) <= wire_nl1ll1i_w_lg_o16855w(0) AND nlOO001i;
	wire_nl1ll1i_w_lg_w_lg_o16855w16872w(0) <= wire_nl1ll1i_w_lg_o16855w(0) AND nlOO001l;
	wire_nl1ll1i_w_lg_w_lg_o16855w17043w(0) <= wire_nl1ll1i_w_lg_o16855w(0) AND nlOO011i;
	wire_nl1ll1i_w_lg_w_lg_o16855w16880w(0) <= wire_nl1ll1i_w_lg_o16855w(0) AND wire_nl1liOl_o;
	wire_nl1ll1i_w_lg_w_lg_o16855w17061w(0) <= wire_nl1ll1i_w_lg_o16855w(0) AND wire_nl1liOO_o;
	wire_nl1ll1i_w_lg_o17050w(0) <= wire_nl1ll1i_o AND wire_w_lg_nlOO011i17049w(0);
	wire_nl1ll1i_w_lg_o16869w(0) <= wire_nl1ll1i_o AND wire_nl1liOO_w_lg_o16868w(0);
	wire_nl1ll1i_w_lg_o17122w(0) <= wire_nl1ll1i_o AND wire_nl1liOO_w_lg_o17121w(0);
	wire_nl1ll1i_w_lg_o16883w(0) <= wire_nl1ll1i_o AND wire_nl1liOl_w_lg_o16842w(0);
	wire_nl1ll1i_w_lg_o17062w(0) <= wire_nl1ll1i_o AND wire_nl1liOO_w_lg_o16856w(0);
	wire_nl1ll1i_w_lg_o16876w(0) <= wire_nl1ll1i_o AND nlOO001i;
	wire_nl1ll1i_w_lg_o16901w(0) <= wire_nl1ll1i_o AND nlOO001l;
	wire_nl1ll1i_w_lg_o17045w(0) <= wire_nl1ll1i_o AND nlOO1OOO;
	wire_nl1ll1i_w_lg_o16850w(0) <= wire_nl1ll1i_o AND wire_nl1liOO_o;
	wire_nl1ll1i_w_lg_o16855w(0) <= NOT wire_nl1ll1i_o;
	wire_nl1ll1i_w_lg_w_lg_w_lg_w_lg_o16855w17043w17044w17047w(0) <= wire_nl1ll1i_w_lg_w_lg_w_lg_o16855w17043w17044w(0) OR wire_nl1ll1i_w_lg_w_lg_o17045w17046w(0);
	wire_nl1ll1i_w_lg_w_lg_o16855w16919w(0) <= wire_nl1ll1i_w_lg_o16855w(0) OR wire_nl1liOO_w_lg_o16856w(0);
	wire_nl1ll1i_w_lg_o16938w(0) <= wire_nl1ll1i_o OR wire_nl1liOO_o;
	wire_nl1ll1i_data <= ( wire_nl1lO0O_o & wire_nl1O1ll_o & wire_nl1O0lO_dataout & wire_nl1Oiii_dataout);
	wire_nl1ll1i_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1ll1i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1ll1i_data,
		o => wire_nl1ll1i_o,
		sel => wire_nl1ll1i_sel
	  );
	wire_nl1ll1l_w_lg_w_lg_o16854w17054w(0) <= wire_nl1ll1l_w_lg_o16854w(0) AND wire_nl1ll1i_w_lg_w_lg_o16855w17053w(0);
	wire_nl1ll1l_w_lg_w_lg_o16854w16891w(0) <= wire_nl1ll1l_w_lg_o16854w(0) AND nlOO01Oi;
	wire_nl1ll1l_w_lg_w_lg_o16854w17093w(0) <= wire_nl1ll1l_w_lg_o16854w(0) AND nlOO1lOi;
	wire_nl1ll1l_w_lg_w_lg_o16854w17088w(0) <= wire_nl1ll1l_w_lg_o16854w(0) AND nlOO1lOl;
	wire_nl1ll1l_w_lg_w_lg_o16854w17074w(0) <= wire_nl1ll1l_w_lg_o16854w(0) AND nlOO1lOO;
	wire_nl1ll1l_w_lg_w_lg_o16854w17071w(0) <= wire_nl1ll1l_w_lg_o16854w(0) AND nlOO1O1i;
	wire_nl1ll1l_w_lg_o17077w(0) <= wire_nl1ll1l_o AND wire_nl1ll1i_w_lg_w_lg_o16855w16857w(0);
	wire_nl1ll1l_w_lg_o17096w(0) <= wire_nl1ll1l_o AND wire_nl1ll1i_w_lg_w_lg_o16855w17061w(0);
	wire_nl1ll1l_w_lg_o17051w(0) <= wire_nl1ll1l_o AND wire_nl1ll1i_w_lg_o17050w(0);
	wire_nl1ll1l_w_lg_o16870w(0) <= wire_nl1ll1l_o AND wire_nl1ll1i_w_lg_o16869w(0);
	wire_nl1ll1l_w_lg_o16884w(0) <= wire_nl1ll1l_o AND wire_nl1ll1i_w_lg_o16883w(0);
	wire_nl1ll1l_w_lg_o17099w(0) <= wire_nl1ll1l_o AND wire_nl1ll1i_w_lg_o17062w(0);
	wire_nl1ll1l_w_lg_o16877w(0) <= wire_nl1ll1l_o AND wire_nl1ll1i_w_lg_o16876w(0);
	wire_nl1ll1l_w_lg_o16902w(0) <= wire_nl1ll1l_o AND wire_nl1ll1i_w_lg_o16901w(0);
	wire_nl1ll1l_w_lg_o16851w(0) <= wire_nl1ll1l_o AND wire_nl1ll1i_w_lg_o16850w(0);
	wire_nl1ll1l_w_lg_o16890w(0) <= wire_nl1ll1l_o AND nlOO01Ol;
	wire_nl1ll1l_w_lg_o16854w(0) <= NOT wire_nl1ll1l_o;
	wire_nl1ll1l_w_lg_w_lg_o17051w17055w(0) <= wire_nl1ll1l_w_lg_o17051w(0) OR wire_nl1ll1l_w_lg_w_lg_o16854w17054w(0);
	wire_nl1ll1l_w_lg_w_lg_o16890w16892w(0) <= wire_nl1ll1l_w_lg_o16890w(0) OR wire_nl1ll1l_w_lg_w_lg_o16854w16891w(0);
	wire_nl1ll1l_data <= ( wire_nl1lOii_o & "0" & wire_nl1O0Oi_dataout & "0");
	wire_nl1ll1l_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1ll1l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1ll1l_data,
		o => wire_nl1ll1l_o,
		sel => wire_nl1ll1l_sel
	  );
	wire_nl1ll1O_w_lg_w_lg_o16937w16939w(0) <= wire_nl1ll1O_w_lg_o16937w(0) AND wire_nl1ll1i_w_lg_o16938w(0);
	wire_nl1ll1O_w_lg_w_lg_o16853w16969w(0) <= wire_nl1ll1O_w_lg_o16853w(0) AND nlOO1Oll;
	wire_nl1ll1O_w_lg_o17094w(0) <= wire_nl1ll1O_o AND wire_nl1ll1l_w_lg_w_lg_o16854w17093w(0);
	wire_nl1ll1O_w_lg_o17089w(0) <= wire_nl1ll1O_o AND wire_nl1ll1l_w_lg_w_lg_o16854w17088w(0);
	wire_nl1ll1O_w_lg_o17075w(0) <= wire_nl1ll1O_o AND wire_nl1ll1l_w_lg_w_lg_o16854w17074w(0);
	wire_nl1ll1O_w_lg_o17072w(0) <= wire_nl1ll1O_o AND wire_nl1ll1l_w_lg_w_lg_o16854w17071w(0);
	wire_nl1ll1O_w_lg_o17078w(0) <= wire_nl1ll1O_o AND wire_nl1ll1l_w_lg_o17077w(0);
	wire_nl1ll1O_w_lg_o17097w(0) <= wire_nl1ll1O_o AND wire_nl1ll1l_w_lg_o17096w(0);
	wire_nl1ll1O_w_lg_o16885w(0) <= wire_nl1ll1O_o AND wire_nl1ll1l_w_lg_o16884w(0);
	wire_nl1ll1O_w_lg_o17100w(0) <= wire_nl1ll1O_o AND wire_nl1ll1l_w_lg_o17099w(0);
	wire_nl1ll1O_w_lg_o16878w(0) <= wire_nl1ll1O_o AND wire_nl1ll1l_w_lg_o16877w(0);
	wire_nl1ll1O_w_lg_o16903w(0) <= wire_nl1ll1O_o AND wire_nl1ll1l_w_lg_o16902w(0);
	wire_nl1ll1O_w_lg_o16852w(0) <= wire_nl1ll1O_o AND wire_nl1ll1l_w_lg_o16851w(0);
	wire_nl1ll1O_w_lg_o16937w(0) <= wire_nl1ll1O_o AND wire_nl1ll1l_o;
	wire_nl1ll1O_w_lg_o16853w(0) <= NOT wire_nl1ll1O_o;
	wire_nl1ll1O_w_lg_o16934w(0) <= wire_nl1ll1O_o OR wire_nl1ll1l_o;
	wire_nl1ll1O_data <= ( wire_nl1lOil_o & "0" & wire_nl1O0Ol_dataout & "0");
	wire_nl1ll1O_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1ll1O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1ll1O_data,
		o => wire_nl1ll1O_o,
		sel => wire_nl1ll1O_sel
	  );
	wire_nl1llii_w_lg_w_lg_o16569w16808w(0) <= wire_nl1llii_w_lg_o16569w(0) AND nlOO00lO;
	wire_nl1llii_w_lg_w_lg_o16569w16768w(0) <= wire_nl1llii_w_lg_o16569w(0) AND nlOO0i1i;
	wire_nl1llii_w_lg_o16836w(0) <= wire_nl1llii_o AND wire_nl1ll0O_w_lg_w_lg_o16638w16835w(0);
	wire_nl1llii_w_lg_o16831w(0) <= wire_nl1llii_o AND wire_nl1ll0O_w_lg_w_lg_o16638w16830w(0);
	wire_nl1llii_w_lg_o16824w(0) <= wire_nl1llii_o AND wire_nl1ll0O_w_lg_w_lg_o16638w16823w(0);
	wire_nl1llii_w_lg_o16821w(0) <= wire_nl1llii_o AND wire_nl1ll0O_w_lg_w_lg_o16638w16820w(0);
	wire_nl1llii_w_lg_o16683w(0) <= wire_nl1llii_o AND wire_nl1ll0O_w_lg_w_lg_o16638w16682w(0);
	wire_nl1llii_w_lg_o16678w(0) <= wire_nl1llii_o AND wire_nl1ll0O_w_lg_w_lg_o16638w16677w(0);
	wire_nl1llii_w_lg_o16663w(0) <= wire_nl1llii_o AND wire_nl1ll0O_w_lg_w_lg_o16638w16662w(0);
	wire_nl1llii_w_lg_o16660w(0) <= wire_nl1llii_o AND wire_nl1ll0O_w_lg_w_lg_o16638w16659w(0);
	wire_nl1llii_w_lg_o16667w(0) <= wire_nl1llii_o AND wire_nl1ll0O_w_lg_o16666w(0);
	wire_nl1llii_w_lg_o16686w(0) <= wire_nl1llii_o AND wire_nl1ll0O_w_lg_o16685w(0);
	wire_nl1llii_w_lg_o16689w(0) <= wire_nl1llii_o AND wire_nl1ll0O_w_lg_o16688w(0);
	wire_nl1llii_w_lg_o16635w(0) <= wire_nl1llii_o AND wire_nl1ll0O_o;
	wire_nl1llii_w_lg_o16569w(0) <= NOT wire_nl1llii_o;
	wire_nl1llii_data <= ( wire_nl1lOlO_o & wire_nl1O1OO_o & nl01lll & nl01liO);
	wire_nl1llii_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1llii :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1llii_data,
		o => wire_nl1llii_o,
		sel => wire_nl1llii_sel
	  );
	wire_nl1llil_w_lg_w_lg_o16499w16570w(0) <= wire_nl1llil_w_lg_o16499w(0) AND wire_nl1llii_w_lg_o16569w(0);
	wire_nl1llil_w_lg_w_lg_o16499w16611w(0) <= wire_nl1llil_w_lg_o16499w(0) AND nlOO0lil;
	wire_nl1llil_w_lg_w_lg_o16499w16563w(0) <= wire_nl1llil_w_lg_o16499w(0) AND nlOO0O0O;
	wire_nl1llil_w_lg_w_lg_o16499w16500w(0) <= wire_nl1llil_w_lg_o16499w(0) AND nlOO0OOi;
	wire_nl1llil_w_lg_o16636w(0) <= wire_nl1llil_o AND wire_nl1llii_w_lg_o16635w(0);
	wire_nl1llil_w_lg_o16581w(0) <= wire_nl1llil_o AND nlOO0O0O;
	wire_nl1llil_w_lg_o16503w(0) <= wire_nl1llil_o AND nlOO0OlO;
	wire_nl1llil_w_lg_o16587w(0) <= wire_nl1llil_o AND wire_nl1llii_o;
	wire_nl1llil_w_lg_o16499w(0) <= NOT wire_nl1llil_o;
	wire_nl1llil_data <= ( wire_nl1lOOi_o & wire_nl1O01i_o & nl01llO & nl01lli);
	wire_nl1llil_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1llil :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1llil_data,
		o => wire_nl1llil_o,
		sel => wire_nl1llil_sel
	  );
	wire_nl1lliO_w_lg_w_lg_o16498w16571w(0) <= wire_nl1lliO_w_lg_o16498w(0) AND wire_nl1llil_w_lg_w_lg_o16499w16570w(0);
	wire_nl1lliO_w_lg_w_lg_o16498w16564w(0) <= wire_nl1lliO_w_lg_o16498w(0) AND wire_nl1llil_w_lg_w_lg_o16499w16563w(0);
	wire_nl1lliO_w_lg_w_lg_o16498w16643w(0) <= wire_nl1lliO_w_lg_o16498w(0) AND wire_nl1llil_o;
	wire_nl1lliO_w_lg_w_lg_w_lg_o16498w16566w16567w(0) <= wire_nl1lliO_w_lg_w_lg_o16498w16566w(0) AND nlOO0OOi;
	wire_nl1lliO_w_lg_w16572w16578w(0) <= wire_nl1lliO_w16572w(0) AND wire_w_lg_w_lg_nlOO0Oii16574w16577w(0);
	wire_nl1lliO_w16597w(0) <= wire_nl1lliO_w_lg_w_lg_w_lg_w_lg_o16582w16583w16586w16589w(0) AND wire_w_lg_w_lg_nlOO0Oil16592w16596w(0);
	wire_nl1lliO_w_lg_w_lg_o16584w16585w(0) <= wire_nl1lliO_w_lg_o16584w(0) AND nlOO0OlO;
	wire_nl1lliO_w_lg_o16612w(0) <= wire_nl1lliO_o AND wire_nl1llil_w_lg_w_lg_o16499w16611w(0);
	wire_nl1lliO_w_lg_o16637w(0) <= wire_nl1lliO_o AND wire_nl1llil_w_lg_o16636w(0);
	wire_nl1lliO_w_lg_o16582w(0) <= wire_nl1lliO_o AND wire_nl1llil_w_lg_o16581w(0);
	wire_nl1lliO_w_lg_o16504w(0) <= wire_nl1lliO_o AND wire_nl1llil_w_lg_o16503w(0);
	wire_nl1lliO_w_lg_o16588w(0) <= wire_nl1lliO_o AND wire_nl1llil_w_lg_o16587w(0);
	wire_nl1lliO_w_lg_o16644w(0) <= wire_nl1lliO_o AND wire_nl1llil_w_lg_o16499w(0);
	wire_nl1lliO_w_lg_o16523w(0) <= wire_nl1lliO_o AND wire_nl1llil_o;
	wire_nl1lliO_w_lg_o16498w(0) <= NOT wire_nl1lliO_o;
	wire_nl1lliO_w_lg_w_lg_w_lg_o16498w16564w16565w(0) <= wire_nl1lliO_w_lg_w_lg_o16498w16564w(0) OR nlOO0OOl;
	wire_nl1lliO_w_lg_w_lg_o16582w16583w(0) <= wire_nl1lliO_w_lg_o16582w(0) OR nlOO0OOO;
	wire_nl1lliO_w_lg_w_lg_o16498w16566w(0) <= wire_nl1lliO_w_lg_o16498w(0) OR wire_nl1llil_w_lg_o16499w(0);
	wire_nl1lliO_w_lg_w_lg_w_lg_w_lg_o16498w16564w16565w16568w(0) <= wire_nl1lliO_w_lg_w_lg_w_lg_o16498w16564w16565w(0) OR wire_nl1lliO_w_lg_w_lg_w_lg_o16498w16566w16567w(0);
	wire_nl1lliO_w_lg_w_lg_w_lg_o16582w16583w16586w(0) <= wire_nl1lliO_w_lg_w_lg_o16582w16583w(0) OR wire_nl1lliO_w_lg_w_lg_o16584w16585w(0);
	wire_nl1lliO_w16572w(0) <= wire_nl1lliO_w_lg_w_lg_w_lg_w_lg_o16498w16564w16565w16568w(0) OR wire_nl1lliO_w_lg_w_lg_o16498w16571w(0);
	wire_nl1lliO_w_lg_w_lg_w_lg_w_lg_o16582w16583w16586w16589w(0) <= wire_nl1lliO_w_lg_w_lg_w_lg_o16582w16583w16586w(0) OR wire_nl1lliO_w_lg_o16588w(0);
	wire_nl1lliO_w_lg_o16584w(0) <= wire_nl1lliO_o OR wire_nl1llil_o;
	wire_nl1lliO_data <= ( wire_nl1lOOl_o & wire_nl1O01l_o & nl01lOi & nl01lll);
	wire_nl1lliO_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1lliO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lliO_data,
		o => wire_nl1lliO_o,
		sel => wire_nl1lliO_sel
	  );
	wire_nl1llli_w_lg_w_lg_o16512w16696w(0) <= wire_nl1llli_w_lg_o16512w(0) AND nlOO0iOi;
	wire_nl1llli_w_lg_w_lg_o16512w16619w(0) <= wire_nl1llli_w_lg_o16512w(0) AND nlOO0l0l;
	wire_nl1llli_w_lg_o16524w(0) <= wire_nl1llli_o AND wire_nl1lliO_w_lg_o16523w(0);
	wire_nl1llli_w_lg_o16777w(0) <= wire_nl1llli_o AND nlOO0iOi;
	wire_nl1llli_w_lg_o16512w(0) <= NOT wire_nl1llli_o;
	wire_nl1llli_data <= ( wire_nl1lOOO_o & wire_nl1O01O_o & nl01lOl & nl01llO);
	wire_nl1llli_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1llli :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1llli_data,
		o => wire_nl1llli_o,
		sel => wire_nl1llli_sel
	  );
	wire_nl1llll_w_lg_w_lg_w_lg_o16511w16699w16700w(0) <= wire_nl1llll_w_lg_w_lg_o16511w16699w(0) AND nlOO0ill;
	wire_nl1llll_w_lg_w_lg_o16701w16702w(0) <= wire_nl1llll_w_lg_o16701w(0) AND nlOO0ill;
	wire_nl1llll_w_lg_w_lg_o16511w16709w(0) <= wire_nl1llll_w_lg_o16511w(0) AND wire_w_lg_nlOO0liO16708w(0);
	wire_nl1llll_w_lg_w_lg_o16511w16513w(0) <= wire_nl1llll_w_lg_o16511w(0) AND wire_nl1llli_w_lg_o16512w(0);
	wire_nl1llll_w_lg_w_lg_o16511w16699w(0) <= wire_nl1llll_w_lg_o16511w(0) AND nlOO0lli;
	wire_nl1llll_w_lg_w_lg_o16511w16551w(0) <= wire_nl1llll_w_lg_o16511w(0) AND nlOO0Oli;
	wire_nl1llll_w_lg_w_lg_o16511w16528w(0) <= wire_nl1llll_w_lg_o16511w(0) AND nlOO0Oll;
	wire_nl1llll_w_lg_w_lg_o16511w16536w(0) <= wire_nl1llll_w_lg_o16511w(0) AND wire_nl1lliO_o;
	wire_nl1llll_w_lg_w_lg_o16511w16717w(0) <= wire_nl1llll_w_lg_o16511w(0) AND wire_nl1llli_o;
	wire_nl1llll_w_lg_o16706w(0) <= wire_nl1llll_o AND wire_w_lg_nlOO0lli16705w(0);
	wire_nl1llll_w_lg_o16525w(0) <= wire_nl1llll_o AND wire_nl1llli_w_lg_o16524w(0);
	wire_nl1llll_w_lg_o16778w(0) <= wire_nl1llll_o AND wire_nl1llli_w_lg_o16777w(0);
	wire_nl1llll_w_lg_o16539w(0) <= wire_nl1llll_o AND wire_nl1lliO_w_lg_o16498w(0);
	wire_nl1llll_w_lg_o16718w(0) <= wire_nl1llll_o AND wire_nl1llli_w_lg_o16512w(0);
	wire_nl1llll_w_lg_o16701w(0) <= wire_nl1llll_o AND nlOO0liO;
	wire_nl1llll_w_lg_o16532w(0) <= wire_nl1llll_o AND nlOO0Oli;
	wire_nl1llll_w_lg_o16557w(0) <= wire_nl1llll_o AND nlOO0Oll;
	wire_nl1llll_w_lg_o16506w(0) <= wire_nl1llll_o AND wire_nl1llli_o;
	wire_nl1llll_w_lg_o16511w(0) <= NOT wire_nl1llll_o;
	wire_nl1llll_w_lg_w_lg_w_lg_w_lg_o16511w16699w16700w16703w(0) <= wire_nl1llll_w_lg_w_lg_w_lg_o16511w16699w16700w(0) OR wire_nl1llll_w_lg_w_lg_o16701w16702w(0);
	wire_nl1llll_w_lg_w_lg_o16511w16575w(0) <= wire_nl1llll_w_lg_o16511w(0) OR wire_nl1llli_w_lg_o16512w(0);
	wire_nl1llll_w_lg_o16594w(0) <= wire_nl1llll_o OR wire_nl1llli_o;
	wire_nl1llll_data <= ( wire_nl1O11i_o & wire_nl1O00i_o & nl01lOO & nl01lOi);
	wire_nl1llll_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1llll :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1llll_data,
		o => wire_nl1llll_o,
		sel => wire_nl1llll_sel
	  );
	wire_nl1lllO_w_lg_w_lg_o16510w16710w(0) <= wire_nl1lllO_w_lg_o16510w(0) AND wire_nl1llll_w_lg_w_lg_o16511w16709w(0);
	wire_nl1lllO_w_lg_w_lg_o16510w16749w(0) <= wire_nl1lllO_w_lg_o16510w(0) AND nlOO0iii;
	wire_nl1lllO_w_lg_w_lg_o16510w16744w(0) <= wire_nl1lllO_w_lg_o16510w(0) AND nlOO0iil;
	wire_nl1lllO_w_lg_w_lg_o16510w16730w(0) <= wire_nl1lllO_w_lg_o16510w(0) AND nlOO0iiO;
	wire_nl1lllO_w_lg_w_lg_o16510w16727w(0) <= wire_nl1lllO_w_lg_o16510w(0) AND nlOO0ili;
	wire_nl1lllO_w_lg_w_lg_o16510w16547w(0) <= wire_nl1lllO_w_lg_o16510w(0) AND nlOO0Oii;
	wire_nl1lllO_w_lg_o16733w(0) <= wire_nl1lllO_o AND wire_nl1llll_w_lg_w_lg_o16511w16513w(0);
	wire_nl1lllO_w_lg_o16752w(0) <= wire_nl1lllO_o AND wire_nl1llll_w_lg_w_lg_o16511w16717w(0);
	wire_nl1lllO_w_lg_o16707w(0) <= wire_nl1lllO_o AND wire_nl1llll_w_lg_o16706w(0);
	wire_nl1lllO_w_lg_o16526w(0) <= wire_nl1lllO_o AND wire_nl1llll_w_lg_o16525w(0);
	wire_nl1lllO_w_lg_o16540w(0) <= wire_nl1lllO_o AND wire_nl1llll_w_lg_o16539w(0);
	wire_nl1lllO_w_lg_o16755w(0) <= wire_nl1lllO_o AND wire_nl1llll_w_lg_o16718w(0);
	wire_nl1lllO_w_lg_o16533w(0) <= wire_nl1lllO_o AND wire_nl1llll_w_lg_o16532w(0);
	wire_nl1lllO_w_lg_o16558w(0) <= wire_nl1lllO_o AND wire_nl1llll_w_lg_o16557w(0);
	wire_nl1lllO_w_lg_o16507w(0) <= wire_nl1lllO_o AND wire_nl1llll_w_lg_o16506w(0);
	wire_nl1lllO_w_lg_o16546w(0) <= wire_nl1lllO_o AND nlOO0Oil;
	wire_nl1lllO_w_lg_o16510w(0) <= NOT wire_nl1lllO_o;
	wire_nl1lllO_w_lg_w_lg_o16707w16711w(0) <= wire_nl1lllO_w_lg_o16707w(0) OR wire_nl1lllO_w_lg_w_lg_o16510w16710w(0);
	wire_nl1lllO_w_lg_w_lg_o16546w16548w(0) <= wire_nl1lllO_w_lg_o16546w(0) OR wire_nl1lllO_w_lg_w_lg_o16510w16547w(0);
	wire_nl1lllO_data <= ( wire_nl1O11l_o & "0" & nl01O1i & "0");
	wire_nl1lllO_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1lllO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lllO_data,
		o => wire_nl1lllO_o,
		sel => wire_nl1lllO_sel
	  );
	wire_nl1llOi_w_lg_w_lg_o16593w16595w(0) <= wire_nl1llOi_w_lg_o16593w(0) AND wire_nl1llll_w_lg_o16594w(0);
	wire_nl1llOi_w_lg_w_lg_o16509w16625w(0) <= wire_nl1llOi_w_lg_o16509w(0) AND nlOO0l0l;
	wire_nl1llOi_w_lg_o16750w(0) <= wire_nl1llOi_o AND wire_nl1lllO_w_lg_w_lg_o16510w16749w(0);
	wire_nl1llOi_w_lg_o16745w(0) <= wire_nl1llOi_o AND wire_nl1lllO_w_lg_w_lg_o16510w16744w(0);
	wire_nl1llOi_w_lg_o16731w(0) <= wire_nl1llOi_o AND wire_nl1lllO_w_lg_w_lg_o16510w16730w(0);
	wire_nl1llOi_w_lg_o16728w(0) <= wire_nl1llOi_o AND wire_nl1lllO_w_lg_w_lg_o16510w16727w(0);
	wire_nl1llOi_w_lg_o16734w(0) <= wire_nl1llOi_o AND wire_nl1lllO_w_lg_o16733w(0);
	wire_nl1llOi_w_lg_o16753w(0) <= wire_nl1llOi_o AND wire_nl1lllO_w_lg_o16752w(0);
	wire_nl1llOi_w_lg_o16541w(0) <= wire_nl1llOi_o AND wire_nl1lllO_w_lg_o16540w(0);
	wire_nl1llOi_w_lg_o16756w(0) <= wire_nl1llOi_o AND wire_nl1lllO_w_lg_o16755w(0);
	wire_nl1llOi_w_lg_o16534w(0) <= wire_nl1llOi_o AND wire_nl1lllO_w_lg_o16533w(0);
	wire_nl1llOi_w_lg_o16559w(0) <= wire_nl1llOi_o AND wire_nl1lllO_w_lg_o16558w(0);
	wire_nl1llOi_w_lg_o16508w(0) <= wire_nl1llOi_o AND wire_nl1lllO_w_lg_o16507w(0);
	wire_nl1llOi_w_lg_o16593w(0) <= wire_nl1llOi_o AND wire_nl1lllO_o;
	wire_nl1llOi_w_lg_o16509w(0) <= NOT wire_nl1llOi_o;
	wire_nl1llOi_w_lg_o16590w(0) <= wire_nl1llOi_o OR wire_nl1lllO_o;
	wire_nl1llOi_data <= ( wire_nl1O11O_o & "0" & nl01O1l & "0");
	wire_nl1llOi_sel <= ( pmadwidth(1 DOWNTO 0));
	nl1llOi :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1llOi_data,
		o => wire_nl1llOi_o,
		sel => wire_nl1llOi_sel
	  );
	wire_nl1llOl_data <= ( nl01lii & nl01O1l & nl01lil & nl01iOi);
	wire_nl1llOl_sel <= ( nlli0li & nlli0il);
	nl1llOl :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1llOl_data,
		o => wire_nl1llOl_o,
		sel => wire_nl1llOl_sel
	  );
	wire_nl1llOO_data <= ( nl01l0O & nl01O1i & nl01liO & nl01iOl);
	wire_nl1llOO_sel <= ( nlli0li & nlli0il);
	nl1llOO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1llOO_data,
		o => wire_nl1llOO_o,
		sel => wire_nl1llOO_sel
	  );
	wire_nl1lO0i_data <= ( nl01l1l & nl01llO & nl01lOi & nl01l1O);
	wire_nl1lO0i_sel <= ( nlli0li & nlli0il);
	nl1lO0i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lO0i_data,
		o => wire_nl1lO0i_o,
		sel => wire_nl1lO0i_sel
	  );
	wire_nl1lO0l_data <= ( nl01l1i & nl01lll & nl01lOl & nl01l0i);
	wire_nl1lO0l_sel <= ( nlli0li & nlli0il);
	nl1lO0l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lO0l_data,
		o => wire_nl1lO0l_o,
		sel => wire_nl1lO0l_sel
	  );
	wire_nl1lO0O_data <= ( nl01iOO & nl01lli & nl01lOO & nl01l0l);
	wire_nl1lO0O_sel <= ( nlli0li & nlli0il);
	nl1lO0O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lO0O_data,
		o => wire_nl1lO0O_o,
		sel => wire_nl1lO0O_sel
	  );
	wire_nl1lO1i_data <= ( nl01l0l & nl01lOO & nl01lli & nl01iOO);
	wire_nl1lO1i_sel <= ( nlli0li & nlli0il);
	nl1lO1i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lO1i_data,
		o => wire_nl1lO1i_o,
		sel => wire_nl1lO1i_sel
	  );
	wire_nl1lO1l_data <= ( nl01l0i & nl01lOl & nl01lll & nl01l1i);
	wire_nl1lO1l_sel <= ( nlli0li & nlli0il);
	nl1lO1l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lO1l_data,
		o => wire_nl1lO1l_o,
		sel => wire_nl1lO1l_sel
	  );
	wire_nl1lO1O_data <= ( nl01l1O & nl01lOi & nl01llO & nl01l1l);
	wire_nl1lO1O_sel <= ( nlli0li & nlli0il);
	nl1lO1O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lO1O_data,
		o => wire_nl1lO1O_o,
		sel => wire_nl1lO1O_sel
	  );
	wire_nl1lOii_data <= ( nl01iOl & nl01liO & nl01O1i & nl01l0O);
	wire_nl1lOii_sel <= ( nlli0li & nlli0il);
	nl1lOii :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lOii_data,
		o => wire_nl1lOii_o,
		sel => wire_nl1lOii_sel
	  );
	wire_nl1lOil_data <= ( nl01iOi & nl01lil & nl01O1l & nl01lii);
	wire_nl1lOil_sel <= ( nlli0li & nlli0il);
	nl1lOil :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lOil_data,
		o => wire_nl1lOil_o,
		sel => wire_nl1lOil_sel
	  );
	wire_nl1lOiO_data <= ( nl01O1l & nl01lii & nl01iOi & nl01lil);
	wire_nl1lOiO_sel <= ( nlli0li & nlli0il);
	nl1lOiO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lOiO_data,
		o => wire_nl1lOiO_o,
		sel => wire_nl1lOiO_sel
	  );
	wire_nl1lOli_data <= ( nl01O1i & nl01l0O & nl01iOl & nl01liO);
	wire_nl1lOli_sel <= ( nlli0li & nlli0il);
	nl1lOli :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lOli_data,
		o => wire_nl1lOli_o,
		sel => wire_nl1lOli_sel
	  );
	wire_nl1lOll_data <= ( nl01lOO & nl01l0l & nl01iOO & nl01lli);
	wire_nl1lOll_sel <= ( nlli0li & nlli0il);
	nl1lOll :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lOll_data,
		o => wire_nl1lOll_o,
		sel => wire_nl1lOll_sel
	  );
	wire_nl1lOlO_data <= ( nl01lOl & nl01l0i & nl01l1i & nl01lll);
	wire_nl1lOlO_sel <= ( nlli0li & nlli0il);
	nl1lOlO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lOlO_data,
		o => wire_nl1lOlO_o,
		sel => wire_nl1lOlO_sel
	  );
	wire_nl1lOOi_data <= ( nl01lOi & nl01l1O & nl01l1l & nl01llO);
	wire_nl1lOOi_sel <= ( nlli0li & nlli0il);
	nl1lOOi :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lOOi_data,
		o => wire_nl1lOOi_o,
		sel => wire_nl1lOOi_sel
	  );
	wire_nl1lOOl_data <= ( nl01llO & nl01l1l & nl01l1O & nl01lOi);
	wire_nl1lOOl_sel <= ( nlli0li & nlli0il);
	nl1lOOl :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lOOl_data,
		o => wire_nl1lOOl_o,
		sel => wire_nl1lOOl_sel
	  );
	wire_nl1lOOO_data <= ( nl01lll & nl01l1i & nl01l0i & nl01lOl);
	wire_nl1lOOO_sel <= ( nlli0li & nlli0il);
	nl1lOOO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1lOOO_data,
		o => wire_nl1lOOO_o,
		sel => wire_nl1lOOO_sel
	  );
	wire_nl1O00i_data <= ( nl01l0O & nl01iOi & nl01l0l & nl01lOi);
	wire_nl1O00i_sel <= ( nlli0li & nlli0il);
	nl1O00i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O00i_data,
		o => wire_nl1O00i_o,
		sel => wire_nl1O00i_sel
	  );
	wire_nl1O01i_data <= ( nl01liO & nl01l1i & nl01l1l & nl01lli);
	wire_nl1O01i_sel <= ( nlli0li & nlli0il);
	nl1O01i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O01i_data,
		o => wire_nl1O01i_o,
		sel => wire_nl1O01i_sel
	  );
	wire_nl1O01l_data <= ( nl01lil & nl01iOO & nl01l1O & nl01lll);
	wire_nl1O01l_sel <= ( nlli0li & nlli0il);
	nl1O01l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O01l_data,
		o => wire_nl1O01l_o,
		sel => wire_nl1O01l_sel
	  );
	wire_nl1O01O_data <= ( nl01lii & nl01iOl & nl01l0i & nl01llO);
	wire_nl1O01O_sel <= ( nlli0li & nlli0il);
	nl1O01O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O01O_data,
		o => wire_nl1O01O_o,
		sel => wire_nl1O01O_sel
	  );
	wire_nl1O10i_data <= ( nl01l0l & nl01lOi & nl01l0O & nl01iOi);
	wire_nl1O10i_sel <= ( nlli0li & nlli0il);
	nl1O10i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O10i_data,
		o => wire_nl1O10i_o,
		sel => wire_nl1O10i_sel
	  );
	wire_nl1O10l_data <= ( nl01l0i & nl01llO & nl01lii & nl01iOl);
	wire_nl1O10l_sel <= ( nlli0li & nlli0il);
	nl1O10l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O10l_data,
		o => wire_nl1O10l_o,
		sel => wire_nl1O10l_sel
	  );
	wire_nl1O10O_data <= ( nl01l1O & nl01lll & nl01lil & nl01iOO);
	wire_nl1O10O_sel <= ( nlli0li & nlli0il);
	nl1O10O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O10O_data,
		o => wire_nl1O10O_o,
		sel => wire_nl1O10O_sel
	  );
	wire_nl1O11i_data <= ( nl01lli & nl01iOO & nl01l0l & nl01lOO);
	wire_nl1O11i_sel <= ( nlli0li & nlli0il);
	nl1O11i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O11i_data,
		o => wire_nl1O11i_o,
		sel => wire_nl1O11i_sel
	  );
	wire_nl1O11l_data <= ( nl01liO & nl01iOl & nl01l0O & nl01O1i);
	wire_nl1O11l_sel <= ( nlli0li & nlli0il);
	nl1O11l :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O11l_data,
		o => wire_nl1O11l_o,
		sel => wire_nl1O11l_sel
	  );
	wire_nl1O11O_data <= ( nl01lil & nl01iOi & nl01lii & nl01O1l);
	wire_nl1O11O_sel <= ( nlli0li & nlli0il);
	nl1O11O :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O11O_data,
		o => wire_nl1O11O_o,
		sel => wire_nl1O11O_sel
	  );
	wire_nl1O1ii_data <= ( nl01l1l & nl01lli & nl01liO & nl01l1i);
	wire_nl1O1ii_sel <= ( nlli0li & nlli0il);
	nl1O1ii :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O1ii_data,
		o => wire_nl1O1ii_o,
		sel => wire_nl1O1ii_sel
	  );
	wire_nl1O1il_data <= ( nl01l1i & nl01liO & nl01lli & nl01l1l);
	wire_nl1O1il_sel <= ( nlli0li & nlli0il);
	nl1O1il :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O1il_data,
		o => wire_nl1O1il_o,
		sel => wire_nl1O1il_sel
	  );
	wire_nl1O1iO_data <= ( nl01iOO & nl01lil & nl01lll & nl01l1O);
	wire_nl1O1iO_sel <= ( nlli0li & nlli0il);
	nl1O1iO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O1iO_data,
		o => wire_nl1O1iO_o,
		sel => wire_nl1O1iO_sel
	  );
	wire_nl1O1li_data <= ( nl01iOl & nl01lii & nl01llO & nl01l0i);
	wire_nl1O1li_sel <= ( nlli0li & nlli0il);
	nl1O1li :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O1li_data,
		o => wire_nl1O1li_o,
		sel => wire_nl1O1li_sel
	  );
	wire_nl1O1ll_data <= ( nl01iOi & nl01l0O & nl01lOi & nl01l0l);
	wire_nl1O1ll_sel <= ( nlli0li & nlli0il);
	nl1O1ll :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O1ll_data,
		o => wire_nl1O1ll_o,
		sel => wire_nl1O1ll_sel
	  );
	wire_nl1O1lO_data <= ( nl01lOi & nl01l0l & nl01iOi & nl01l0O);
	wire_nl1O1lO_sel <= ( nlli0li & nlli0il);
	nl1O1lO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O1lO_data,
		o => wire_nl1O1lO_o,
		sel => wire_nl1O1lO_sel
	  );
	wire_nl1O1Oi_data <= ( nl01llO & nl01l0i & nl01iOl & nl01lii);
	wire_nl1O1Oi_sel <= ( nlli0li & nlli0il);
	nl1O1Oi :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O1Oi_data,
		o => wire_nl1O1Oi_o,
		sel => wire_nl1O1Oi_sel
	  );
	wire_nl1O1Ol_data <= ( nl01lll & nl01l1O & nl01iOO & nl01lil);
	wire_nl1O1Ol_sel <= ( nlli0li & nlli0il);
	nl1O1Ol :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O1Ol_data,
		o => wire_nl1O1Ol_o,
		sel => wire_nl1O1Ol_sel
	  );
	wire_nl1O1OO_data <= ( nl01lli & nl01l1l & nl01l1i & nl01liO);
	wire_nl1O1OO_sel <= ( nlli0li & nlli0il);
	nl1O1OO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nl1O1OO_data,
		o => wire_nl1O1OO_o,
		sel => wire_nl1O1OO_sel
	  );
	wire_nllO0iO_data <= ( "0" & "0" & "0" & wire_w_lg_n10lili3500w & "0" & "0" & "0" & "0" & wire_nlO110O_dataout & wire_nlO1i1i_dataout & wire_nllOO0O_dataout & wire_nllOi0l_dataout & "0" & wire_nlO1l1l_dataout & "0" & "0");
	wire_nllO0iO_sel <= ( nlO011O & nlO011l & nlO011i & nllll1i);
	nllO0iO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllO0iO_data,
		o => wire_nllO0iO_o,
		sel => wire_nllO0iO_sel
	  );
	wire_nllO0li_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & n10l0Ol & wire_nlO1i1l_dataout & wire_nllOOii_dataout & wire_nllOi0O_dataout & "0" & "0" & "0" & "0");
	wire_nllO0li_sel <= ( nlO011O & nlO011l & nlO011i & nllll1i);
	nllO0li :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllO0li_data,
		o => wire_nllO0li_o,
		sel => wire_nllO0li_sel
	  );
	wire_nllO0ll_data <= ( "0" & "0" & "0" & wire_nllOi1l_dataout & "0" & "0" & "0" & "0" & wire_nlO11ii_dataout & n10li0l & wire_nllOOil_dataout & wire_nllOiii_dataout & "0" & wire_nlO1l1O_dataout & "0" & "0");
	wire_nllO0ll_sel <= ( nlO011O & nlO011l & nlO011i & nllll1i);
	nllO0ll :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllO0ll_data,
		o => wire_nllO0ll_o,
		sel => wire_nllO0ll_sel
	  );
	wire_nllO0lO_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nlO11il_dataout & wire_nlO1i1O_dataout & n10li1i & wire_nllOiil_dataout & "0" & "0" & "0" & "0");
	wire_nllO0lO_sel <= ( nlO011O & nlO011l & nlO011i & nllll1i);
	nllO0lO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllO0lO_data,
		o => wire_nllO0lO_o,
		sel => wire_nllO0lO_sel
	  );
	wire_nllO0Oi_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nlO1l0l_dataout & "0" & wire_nlO1O1l_dataout & "0");
	wire_nllO0Oi_sel <= ( nlO011O & nlO011l & nlO011i & nllll1i);
	nllO0Oi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllO0Oi_data,
		o => wire_nllO0Oi_o,
		sel => wire_nllO0Oi_sel
	  );
	wire_nllO0Ol_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nlO11iO_dataout & wire_nlO1i0i_dataout & wire_nllOOiO_dataout & wire_nllOiiO_dataout & wire_nlO1l0O_dataout & n10liil & wire_nlO1O1O_dataout & wire_nlO1Oll_dataout);
	wire_nllO0Ol_sel <= ( nlO011O & nlO011l & nlO011i & nllll1i);
	nllO0Ol :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllO0Ol_data,
		o => wire_nllO0Ol_o,
		sel => wire_nllO0Ol_sel
	  );
	wire_nllO0OO_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nlO1lii_dataout & "0" & wire_nlO1O0i_dataout & wire_nlO1OlO_dataout);
	wire_nllO0OO_sel <= ( nlO011O & nlO011l & nlO011i & nllll1i);
	nllO0OO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllO0OO_data,
		o => wire_nllO0OO_o,
		sel => wire_nllO0OO_sel
	  );
	wire_nllOi1i_data <= ( "1" & "1" & "1" & wire_nllOi1O_dataout & "1" & "1" & "1" & "1" & wire_nlO11li_dataout & wire_nlO1i0l_dataout & "0" & wire_nllOili_dataout & n10ll0i & wire_nlO1l0i_dataout & n10ll1i & wire_nl_w_lg_niii0l3438w);
	wire_nllOi1i_sel <= ( nlO011O & nlO011l & nlO011i & nllll1i);
	nllOi1i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllOi1i_data,
		o => wire_nllOi1i_o,
		sel => wire_nllOi1i_sel
	  );
	wire_nlO0O0i_data <= ( wire_nlO0O0l_dataout & "0" & n1ii11l & "0");
	wire_nlO0O0i_sel <= ( nlOiill & nlOiili);
	nlO0O0i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlO0O0i_data,
		o => wire_nlO0O0i_o,
		sel => wire_nlO0O0i_sel
	  );
	wire_nlO0OiO_data <= ( wire_nlO0Oli_dataout & "0" & n1i0Oii & "0");
	wire_nlO0OiO_sel <= ( nlOiiiO & nlOiiil);
	nlO0OiO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlO0OiO_data,
		o => wire_nlO0OiO_o,
		sel => wire_nlO0OiO_sel
	  );
	wire_nlO0OOl_data <= ( wire_nlO0OOO_dataout & "0" & n1i0O1i & "0");
	wire_nlO0OOl_sel <= ( nlOiiii & nlOii0O);
	nlO0OOl :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlO0OOl_data,
		o => wire_nlO0OOl_o,
		sel => wire_nlO0OOl_sel
	  );
	wire_nlOi00i_data <= ( wire_nlOi00l_dataout & "0" & n1i0l0O & "0");
	wire_nlOi00i_sel <= ( nlOi0Ol & nlOi0Oi);
	nlOi00i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlOi00i_data,
		o => wire_nlOi00i_o,
		sel => wire_nlOi00i_sel
	  );
	wire_nlOi0iO_data <= ( wire_nlOi0li_dataout & "0" & n1i0l0i & "0");
	wire_nlOi0iO_sel <= ( nlOi0lO & nlOi0ll);
	nlOi0iO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlOi0iO_data,
		o => wire_nlOi0iO_o,
		sel => wire_nlOi0iO_sel
	  );
	wire_nlOi10i_data <= ( wire_nlOi10l_dataout & "0" & n1i0llO & "0");
	wire_nlOi10i_sel <= ( nlOii0l & nlOii0i);
	nlOi10i :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlOi10i_data,
		o => wire_nlOi10i_o,
		sel => wire_nlOi10i_sel
	  );
	wire_nlOi1iO_data <= ( wire_nlOi1li_dataout & "0" & n1i0lli & "0");
	wire_nlOi1iO_sel <= ( nlOii1O & nlOii1l);
	nlOi1iO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlOi1iO_data,
		o => wire_nlOi1iO_o,
		sel => wire_nlOi1iO_sel
	  );
	wire_nlOi1Ol_data <= ( wire_nlOi1OO_dataout & "0" & n1i0lil & "0");
	wire_nlOi1Ol_sel <= ( nlOii1i & nlOi0OO);
	nlOi1Ol :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nlOi1Ol_data,
		o => wire_nlOi1Ol_o,
		sel => wire_nlOi1Ol_sel
	  );
	wire_n1lili_data <= ( "0" & n01i0i & n1liii & n0110l);
	wire_n1lili_sel <= ( n10O00i & n10O01i & n10O1Ol & n10O1OO);
	n1lili :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1lili_data,
		o => wire_n1lili_o,
		sel => wire_n1lili_sel
	  );
	wire_n1lill_data <= ( "0" & n01i0l & n1l00O & n0110O);
	wire_n1lill_sel <= ( n10O00i & n10O01i & n10O1Ol & n10O1OO);
	n1lill :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1lill_data,
		o => wire_n1lill_o,
		sel => wire_n1lill_sel
	  );
	wire_n1lilO_data <= ( "0" & n01i0O & n1l0ii & n011ii);
	wire_n1lilO_sel <= ( n10O00i & n10O01i & n10O1Ol & n10O1OO);
	n1lilO :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1lilO_data,
		o => wire_n1lilO_o,
		sel => wire_n1lilO_sel
	  );
	wire_n1liOi_data <= ( "0" & n01iii & n1l0il & n011il);
	wire_n1liOi_sel <= ( n10O00i & n10O01i & n10O1Ol & n10O1OO);
	n1liOi :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1liOi_data,
		o => wire_n1liOi_o,
		sel => wire_n1liOi_sel
	  );
	wire_n1liOO_data <= ( "0" & n010OO & wire_n1lOlO_dataout & n0111i & wire_n1lO1i_dataout);
	wire_n1liOO_sel <= ( n10O00i & n10O01i & n1O1Oi & n10O1OO & n1l0Oi);
	n1liOO :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n1liOO_data,
		o => wire_n1liOO_o,
		sel => wire_n1liOO_sel
	  );
	wire_n1ll0O_data <= ( "0" & wire_n1lO0l_dataout);
	wire_n1ll0O_sel <= ( n10O01l & wire_w_lg_n10O01l2767w);
	n1ll0O :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_n1ll0O_data,
		o => wire_n1ll0O_o,
		sel => wire_n1ll0O_sel
	  );
	wire_n1ll1i_data <= ( "0" & n01i1i & wire_n1lOOi_dataout & n0111l & wire_n1lO1l_dataout);
	wire_n1ll1i_sel <= ( n10O00i & n10O01i & n1O1Oi & n10O1OO & n1l0Oi);
	n1ll1i :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n1ll1i_data,
		o => wire_n1ll1i_o,
		sel => wire_n1ll1i_sel
	  );
	wire_n1ll1l_data <= ( "0" & n01i1l & wire_n1lOOl_dataout & n0111O & wire_n1lO1O_dataout);
	wire_n1ll1l_sel <= ( n10O00i & n10O01i & n1O1Oi & n10O1OO & n1l0Oi);
	n1ll1l :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n1ll1l_data,
		o => wire_n1ll1l_o,
		sel => wire_n1ll1l_sel
	  );
	wire_n1ll1O_data <= ( "0" & n01i1O & wire_n1lOOO_dataout & n0110i & wire_n1lO0i_dataout);
	wire_n1ll1O_sel <= ( n10O00i & n10O01i & n1O1Oi & n10O1OO & n1l0Oi);
	n1ll1O :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n1ll1O_data,
		o => wire_n1ll1O_o,
		sel => wire_n1ll1O_sel
	  );
	wire_n1llil_data <= ( "0" & wire_n1O11l_dataout & wire_n1O11l_dataout & wire_n1O11l_dataout & wire_n1lO0O_dataout & wire_n1lO0O_dataout & wire_n1lO0O_dataout);
	wire_n1llil_sel <= ( n10O00i & n1O1OO & n1O1Ol & n1O1Oi & n1O1lO & n1O1ll & n1l0Oi);
	n1llil :  oper_selector
	  GENERIC MAP (
		width_data => 7,
		width_sel => 7
	  )
	  PORT MAP ( 
		data => wire_n1llil_data,
		o => wire_n1llil_o,
		sel => wire_n1llil_sel
	  );
	wire_n1llli_data <= ( "0" & wire_n1O11O_dataout);
	wire_n1llli_sel <= ( n10O01O & wire_w_lg_n10O01O2739w);
	n1llli :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_n1llli_data,
		o => wire_n1llli_o,
		sel => wire_n1llli_sel
	  );
	wire_n1lllO_data <= ( "0" & wire_n1O10i_dataout & wire_n1O10i_dataout & wire_n1O10i_dataout & wire_n1lOii_dataout & wire_n1lOii_dataout & wire_n1lOii_dataout);
	wire_n1lllO_sel <= ( n10O00i & n1O1OO & n1O1Ol & n1O1Oi & n1O1lO & n1O1ll & n1l0Oi);
	n1lllO :  oper_selector
	  GENERIC MAP (
		width_data => 7,
		width_sel => 7
	  )
	  PORT MAP ( 
		data => wire_n1lllO_data,
		o => wire_n1lllO_o,
		sel => wire_n1lllO_sel
	  );
	wire_n1Oliii_data <= ( "0" & n0101Ol & n1Oli0i & n011liO);
	wire_n1Oliii_sel <= ( nlOOi1ii & nlOOi10i & nlOOi11l & nlOOi11O);
	n1Oliii :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1Oliii_data,
		o => wire_n1Oliii_o,
		sel => wire_n1Oliii_sel
	  );
	wire_n1Oliil_data <= ( "0" & n0101OO & n1Ol1Ol & n011lli);
	wire_n1Oliil_sel <= ( nlOOi1ii & nlOOi10i & nlOOi11l & nlOOi11O);
	n1Oliil :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1Oliil_data,
		o => wire_n1Oliil_o,
		sel => wire_n1Oliil_sel
	  );
	wire_n1OliiO_data <= ( "0" & n01001i & n1Ol1OO & n011lll);
	wire_n1OliiO_sel <= ( nlOOi1ii & nlOOi10i & nlOOi11l & nlOOi11O);
	n1OliiO :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1OliiO_data,
		o => wire_n1OliiO_o,
		sel => wire_n1OliiO_sel
	  );
	wire_n1Olili_data <= ( "0" & n01001l & n1Ol01i & n011llO);
	wire_n1Olili_sel <= ( nlOOi1ii & nlOOi10i & nlOOi11l & nlOOi11O);
	n1Olili :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1Olili_data,
		o => wire_n1Olili_o,
		sel => wire_n1Olili_sel
	  );
	wire_n1Olill_data <= ( "0" & n01001O & n1Ol01l & n011lOi);
	wire_n1Olill_sel <= ( nlOOi1ii & nlOOi10i & nlOOi11l & nlOOi11O);
	n1Olill :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1Olill_data,
		o => wire_n1Olill_o,
		sel => wire_n1Olill_sel
	  );
	wire_n1OliOi_data <= ( "0" & n0101iO & wire_n1OlOlO_dataout & n011l0i & wire_n1OllOO_dataout);
	wire_n1OliOi_sel <= ( nlOOi1ii & nlOOi10i & n1OO1Ol & nlOOi11O & n1Ol0il);
	n1OliOi :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n1OliOi_data,
		o => wire_n1OliOi_o,
		sel => wire_n1OliOi_sel
	  );
	wire_n1OliOl_data <= ( "0" & n0101li & wire_n1OlOOi_dataout & n011l0l & wire_n1OlO1i_dataout);
	wire_n1OliOl_sel <= ( nlOOi1ii & nlOOi10i & n1OO1Ol & nlOOi11O & n1Ol0il);
	n1OliOl :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n1OliOl_data,
		o => wire_n1OliOl_o,
		sel => wire_n1OliOl_sel
	  );
	wire_n1OliOO_data <= ( "0" & n0101ll & wire_n1OlOOl_dataout & n011l0O & wire_n1OlO1l_dataout);
	wire_n1OliOO_sel <= ( nlOOi1ii & nlOOi10i & n1OO1Ol & nlOOi11O & n1Ol0il);
	n1OliOO :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n1OliOO_data,
		o => wire_n1OliOO_o,
		sel => wire_n1OliOO_sel
	  );
	wire_n1Oll0l_data <= ( "0" & wire_n1OlO0l_dataout);
	wire_n1Oll0l_sel <= ( nlOOi10l & wire_w_lg_nlOOi10l16209w);
	n1Oll0l :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_n1Oll0l_data,
		o => wire_n1Oll0l_o,
		sel => wire_n1Oll0l_sel
	  );
	wire_n1Oll1i_data <= ( "0" & n0101lO & wire_n1OlOOO_dataout & n011lii & wire_n1OlO1O_dataout);
	wire_n1Oll1i_sel <= ( nlOOi1ii & nlOOi10i & n1OO1Ol & nlOOi11O & n1Ol0il);
	n1Oll1i :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n1Oll1i_data,
		o => wire_n1Oll1i_o,
		sel => wire_n1Oll1i_sel
	  );
	wire_n1Oll1l_data <= ( "0" & n0101Oi & wire_n1OO11i_dataout & n011lil & wire_n1OlO0i_dataout);
	wire_n1Oll1l_sel <= ( nlOOi1ii & nlOOi10i & n1OO1Ol & nlOOi11O & n1Ol0il);
	n1Oll1l :  oper_selector
	  GENERIC MAP (
		width_data => 5,
		width_sel => 5
	  )
	  PORT MAP ( 
		data => wire_n1Oll1l_data,
		o => wire_n1Oll1l_o,
		sel => wire_n1Oll1l_sel
	  );
	wire_n1Ollii_data <= ( "0" & wire_n1OO11O_dataout & wire_n1OO11O_dataout & wire_n1OO11O_dataout & wire_n1OlO0O_dataout & wire_n1OlO0O_dataout & wire_n1OlO0O_dataout);
	wire_n1Ollii_sel <= ( nlOOi1ii & n1OO01i & n1OO1OO & n1OO1Ol & n1OO1Oi & n1OO1lO & n1Ol0il);
	n1Ollii :  oper_selector
	  GENERIC MAP (
		width_data => 7,
		width_sel => 7
	  )
	  PORT MAP ( 
		data => wire_n1Ollii_data,
		o => wire_n1Ollii_o,
		sel => wire_n1Ollii_sel
	  );
	wire_n1OlliO_data <= ( "0" & wire_n1OO10i_dataout);
	wire_n1OlliO_sel <= ( nlOOi10O & wire_w_lg_nlOOi10O16181w);
	n1OlliO :  oper_selector
	  GENERIC MAP (
		width_data => 2,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_n1OlliO_data,
		o => wire_n1OlliO_o,
		sel => wire_n1OlliO_sel
	  );
	wire_n1Ollll_data <= ( "0" & wire_n1OO10l_dataout & wire_n1OO10l_dataout & wire_n1OO10l_dataout & wire_n1OlOii_dataout & wire_n1OlOii_dataout & wire_n1OlOii_dataout);
	wire_n1Ollll_sel <= ( nlOOi1ii & n1OO01i & n1OO1OO & n1OO1Ol & n1OO1Oi & n1OO1lO & n1Ol0il);
	n1Ollll :  oper_selector
	  GENERIC MAP (
		width_data => 7,
		width_sel => 7
	  )
	  PORT MAP ( 
		data => wire_n1Ollll_data,
		o => wire_n1Ollll_o,
		sel => wire_n1Ollll_sel
	  );
	wire_niO00i_data <= ( wire_niilOi_dataout & wire_niil0l_dataout & wire_niOl1i_o);
	wire_niO00i_sel <= ( n1i01li & n1i01iO & wire_w_lg_n1i01il1227w);
	niO00i :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niO00i_data,
		o => wire_niO00i_o,
		sel => wire_niO00i_sel
	  );
	wire_niO00l_data <= ( wire_niilOl_dataout & wire_niil0O_dataout & wire_niOl1l_o);
	wire_niO00l_sel <= ( n1i01li & n1i01iO & wire_w_lg_n1i01il1227w);
	niO00l :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niO00l_data,
		o => wire_niO00l_o,
		sel => wire_niO00l_sel
	  );
	wire_niO00O_data <= ( wire_niilOO_dataout & wire_niilii_dataout & wire_niOl1O_o);
	wire_niO00O_sel <= ( n1i01li & n1i01iO & wire_w_lg_n1i01il1227w);
	niO00O :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niO00O_data,
		o => wire_niO00O_o,
		sel => wire_niO00O_sel
	  );
	wire_niO01i_data <= ( wire_niilli_dataout & wire_niil1l_dataout & wire_niOiOi_o);
	wire_niO01i_sel <= ( n1i01li & n1i01iO & wire_w_lg_n1i01il1227w);
	niO01i :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niO01i_data,
		o => wire_niO01i_o,
		sel => wire_niO01i_sel
	  );
	wire_niO01l_data <= ( wire_niilll_dataout & wire_niil1O_dataout & wire_niOiOl_o);
	wire_niO01l_sel <= ( n1i01li & n1i01iO & wire_w_lg_n1i01il1227w);
	niO01l :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niO01l_data,
		o => wire_niO01l_o,
		sel => wire_niO01l_sel
	  );
	wire_niO01O_data <= ( wire_niillO_dataout & wire_niil0i_dataout & wire_niOiOO_o);
	wire_niO01O_sel <= ( n1i01li & n1i01iO & wire_w_lg_n1i01il1227w);
	niO01O :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niO01O_data,
		o => wire_niO01O_o,
		sel => wire_niO01O_sel
	  );
	wire_niO1Ol_data <= ( wire_niilil_dataout & wire_niiiOO_dataout & wire_niOill_o);
	wire_niO1Ol_sel <= ( n1i01li & n1i01iO & wire_w_lg_n1i01il1227w);
	niO1Ol :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niO1Ol_data,
		o => wire_niO1Ol_o,
		sel => wire_niO1Ol_sel
	  );
	wire_niO1OO_data <= ( wire_niiliO_dataout & wire_niil1i_dataout & wire_niOilO_o);
	wire_niO1OO_sel <= ( n1i01li & n1i01iO & wire_w_lg_n1i01il1227w);
	niO1OO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niO1OO_data,
		o => wire_niO1OO_o,
		sel => wire_niO1OO_sel
	  );
	wire_niOill_w_lg_o3118w(0) <= NOT wire_niOill_o;
	wire_niOill_data <= ( nl110O & nl11il & niOO0i);
	wire_niOill_sel <= ( n1i00Ol & n1i00Oi & wire_w_lg_n1i00lO1129w);
	niOill :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niOill_data,
		o => wire_niOill_o,
		sel => wire_niOill_sel
	  );
	wire_niOilO_w_lg_w_lg_o3116w3135w(0) <= wire_niOilO_w_lg_o3116w(0) AND wire_niOill_w_lg_o3118w(0);
	wire_niOilO_w_lg_w_lg_o3116w3117w(0) <= wire_niOilO_w_lg_o3116w(0) AND wire_niOill_o;
	wire_niOilO_w_lg_o3119w(0) <= wire_niOilO_o AND wire_niOill_w_lg_o3118w(0);
	wire_niOilO_w_lg_o3116w(0) <= NOT wire_niOilO_o;
	wire_niOilO_data <= ( nl110l & nl11ii & niOOOO);
	wire_niOilO_sel <= ( n1i00Ol & n1i00Oi & wire_w_lg_n1i00lO1129w);
	niOilO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niOilO_data,
		o => wire_niOilO_o,
		sel => wire_niOilO_sel
	  );
	wire_niOiOi_w_lg_w_lg_o3108w3287w(0) <= wire_niOiOi_w_lg_o3108w(0) AND n10llil;
	wire_niOiOi_w_lg_w_lg_o3108w3282w(0) <= wire_niOiOi_w_lg_o3108w(0) AND n10lliO;
	wire_niOiOi_w_lg_w_lg_o3108w3275w(0) <= wire_niOiOi_w_lg_o3108w(0) AND n10llli;
	wire_niOiOi_w_lg_w_lg_o3108w3272w(0) <= wire_niOiOi_w_lg_o3108w(0) AND n10llll;
	wire_niOiOi_w_lg_w_lg_o3108w3152w(0) <= wire_niOiOi_w_lg_o3108w(0) AND n10lOii;
	wire_niOiOi_w_lg_w_lg_o3108w3147w(0) <= wire_niOiOi_w_lg_o3108w(0) AND n10lOil;
	wire_niOiOi_w_lg_w_lg_o3108w3132w(0) <= wire_niOiOi_w_lg_o3108w(0) AND n10lOiO;
	wire_niOiOi_w_lg_w_lg_o3108w3129w(0) <= wire_niOiOi_w_lg_o3108w(0) AND n10lOli;
	wire_niOiOi_w_lg_o3136w(0) <= wire_niOiOi_o AND wire_niOilO_w_lg_w_lg_o3116w3135w(0);
	wire_niOiOi_w_lg_o3155w(0) <= wire_niOiOi_o AND wire_niOilO_w_lg_w_lg_o3116w3117w(0);
	wire_niOiOi_w_lg_o3158w(0) <= wire_niOiOi_o AND wire_niOilO_w_lg_o3119w(0);
	wire_niOiOi_w_lg_o3108w(0) <= NOT wire_niOiOi_o;
	wire_niOiOi_data <= ( nl110i & nl110O & nl111i);
	wire_niOiOi_sel <= ( n1i00Ol & n1i00Oi & wire_w_lg_n1i00lO1129w);
	niOiOi :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niOiOi_data,
		o => wire_niOiOi_o,
		sel => wire_niOiOi_sel
	  );
	wire_niOiOl_w_lg_w_lg_o1205w3260w(0) <= wire_niOiOl_w_lg_o1205w(0) AND n10lllO;
	wire_niOiOl_w_lg_w_lg_o1205w1206w(0) <= wire_niOiOl_w_lg_o1205w(0) AND n1i001i;
	wire_niOiOl_w_lg_o3288w(0) <= wire_niOiOl_o AND wire_niOiOi_w_lg_w_lg_o3108w3287w(0);
	wire_niOiOl_w_lg_o3283w(0) <= wire_niOiOl_o AND wire_niOiOi_w_lg_w_lg_o3108w3282w(0);
	wire_niOiOl_w_lg_o3276w(0) <= wire_niOiOl_o AND wire_niOiOi_w_lg_w_lg_o3108w3275w(0);
	wire_niOiOl_w_lg_o3273w(0) <= wire_niOiOl_o AND wire_niOiOi_w_lg_w_lg_o3108w3272w(0);
	wire_niOiOl_w_lg_o3153w(0) <= wire_niOiOl_o AND wire_niOiOi_w_lg_w_lg_o3108w3152w(0);
	wire_niOiOl_w_lg_o3148w(0) <= wire_niOiOl_o AND wire_niOiOi_w_lg_w_lg_o3108w3147w(0);
	wire_niOiOl_w_lg_o3133w(0) <= wire_niOiOl_o AND wire_niOiOi_w_lg_w_lg_o3108w3132w(0);
	wire_niOiOl_w_lg_o3130w(0) <= wire_niOiOl_o AND wire_niOiOi_w_lg_w_lg_o3108w3129w(0);
	wire_niOiOl_w_lg_o3137w(0) <= wire_niOiOl_o AND wire_niOiOi_w_lg_o3136w(0);
	wire_niOiOl_w_lg_o3156w(0) <= wire_niOiOl_o AND wire_niOiOi_w_lg_o3155w(0);
	wire_niOiOl_w_lg_o3159w(0) <= wire_niOiOl_o AND wire_niOiOi_w_lg_o3158w(0);
	wire_niOiOl_w_lg_o3105w(0) <= wire_niOiOl_o AND wire_niOiOi_o;
	wire_niOiOl_w_lg_o1205w(0) <= NOT wire_niOiOl_o;
	wire_niOiOl_data <= ( nl111O & nl110l & nl111l);
	wire_niOiOl_sel <= ( n1i00Ol & n1i00Oi & wire_w_lg_n1i00lO1129w);
	niOiOl :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niOiOl_data,
		o => wire_niOiOl_o,
		sel => wire_niOiOl_sel
	  );
	wire_niOiOO_w_lg_w_lg_o2973w3041w(0) <= wire_niOiOO_w_lg_o2973w(0) AND wire_niOiOl_w_lg_o1205w(0);
	wire_niOiOO_w_lg_w_lg_o2973w3035w(0) <= wire_niOiOO_w_lg_o2973w(0) AND n10O11O;
	wire_niOiOO_w_lg_w_lg_o2973w2974w(0) <= wire_niOiOO_w_lg_o2973w(0) AND n10O1li;
	wire_niOiOO_w_lg_o3106w(0) <= wire_niOiOO_o AND wire_niOiOl_w_lg_o3105w(0);
	wire_niOiOO_w_lg_o3052w(0) <= wire_niOiOO_o AND n10O11O;
	wire_niOiOO_w_lg_o2977w(0) <= wire_niOiOO_o AND n10O1iO;
	wire_niOiOO_w_lg_o3058w(0) <= wire_niOiOO_o AND wire_niOiOl_o;
	wire_niOiOO_w_lg_o2973w(0) <= NOT wire_niOiOO_o;
	wire_niOiOO_data <= ( nl111l & nl110i & nl111O);
	wire_niOiOO_sel <= ( n1i00Ol & n1i00Oi & wire_w_lg_n1i00lO1129w);
	niOiOO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niOiOO_data,
		o => wire_niOiOO_o,
		sel => wire_niOiOO_sel
	  );
	wire_niOl1i_w_lg_w_lg_o2972w3042w(0) <= wire_niOl1i_w_lg_o2972w(0) AND wire_niOiOO_w_lg_w_lg_o2973w3041w(0);
	wire_niOl1i_w_lg_w_lg_o2972w3036w(0) <= wire_niOl1i_w_lg_o2972w(0) AND wire_niOiOO_w_lg_w_lg_o2973w3035w(0);
	wire_niOl1i_w_lg_w_lg_o2972w3113w(0) <= wire_niOl1i_w_lg_o2972w(0) AND wire_niOiOO_o;
	wire_niOl1i_w_lg_w_lg_w_lg_o2972w3038w3039w(0) <= wire_niOl1i_w_lg_w_lg_o2972w3038w(0) AND n10O1li;
	wire_niOl1i_w_lg_w3043w3049w(0) <= wire_niOl1i_w3043w(0) AND wire_w_lg_w_lg_n10O10i3045w3048w(0);
	wire_niOl1i_w3068w(0) <= wire_niOl1i_w_lg_w_lg_w_lg_w_lg_o3053w3054w3057w3060w(0) AND wire_w_lg_w_lg_n10O10l3063w3067w(0);
	wire_niOl1i_w_lg_w_lg_o3055w3056w(0) <= wire_niOl1i_w_lg_o3055w(0) AND n10O1iO;
	wire_niOl1i_w_lg_o3107w(0) <= wire_niOl1i_o AND wire_niOiOO_w_lg_o3106w(0);
	wire_niOl1i_w_lg_o3053w(0) <= wire_niOl1i_o AND wire_niOiOO_w_lg_o3052w(0);
	wire_niOl1i_w_lg_o2978w(0) <= wire_niOl1i_o AND wire_niOiOO_w_lg_o2977w(0);
	wire_niOl1i_w_lg_o3059w(0) <= wire_niOl1i_o AND wire_niOiOO_w_lg_o3058w(0);
	wire_niOl1i_w_lg_o3114w(0) <= wire_niOl1i_o AND wire_niOiOO_w_lg_o2973w(0);
	wire_niOl1i_w_lg_o2994w(0) <= wire_niOl1i_o AND wire_niOiOO_o;
	wire_niOl1i_w_lg_o2972w(0) <= NOT wire_niOl1i_o;
	wire_niOl1i_w_lg_w_lg_w_lg_o2972w3036w3037w(0) <= wire_niOl1i_w_lg_w_lg_o2972w3036w(0) OR n10O1ll;
	wire_niOl1i_w_lg_w_lg_o3053w3054w(0) <= wire_niOl1i_w_lg_o3053w(0) OR n10O1lO;
	wire_niOl1i_w_lg_w_lg_o2972w3038w(0) <= wire_niOl1i_w_lg_o2972w(0) OR wire_niOiOO_w_lg_o2973w(0);
	wire_niOl1i_w_lg_w_lg_w_lg_w_lg_o2972w3036w3037w3040w(0) <= wire_niOl1i_w_lg_w_lg_w_lg_o2972w3036w3037w(0) OR wire_niOl1i_w_lg_w_lg_w_lg_o2972w3038w3039w(0);
	wire_niOl1i_w_lg_w_lg_w_lg_o3053w3054w3057w(0) <= wire_niOl1i_w_lg_w_lg_o3053w3054w(0) OR wire_niOl1i_w_lg_w_lg_o3055w3056w(0);
	wire_niOl1i_w3043w(0) <= wire_niOl1i_w_lg_w_lg_w_lg_w_lg_o2972w3036w3037w3040w(0) OR wire_niOl1i_w_lg_w_lg_o2972w3042w(0);
	wire_niOl1i_w_lg_w_lg_w_lg_w_lg_o3053w3054w3057w3060w(0) <= wire_niOl1i_w_lg_w_lg_w_lg_o3053w3054w3057w(0) OR wire_niOl1i_w_lg_o3059w(0);
	wire_niOl1i_w_lg_o3055w(0) <= wire_niOl1i_o OR wire_niOiOO_o;
	wire_niOl1i_data <= ( nl111i & nl111O & nl110i);
	wire_niOl1i_sel <= ( n1i00Ol & n1i00Oi & wire_w_lg_n1i00lO1129w);
	niOl1i :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niOl1i_data,
		o => wire_niOl1i_o,
		sel => wire_niOl1i_sel
	  );
	wire_niOl1l_w_lg_w_lg_o2983w3085w(0) <= wire_niOl1l_w_lg_o2983w(0) AND n10lOll;
	wire_niOl1l_w_lg_w_lg_o2983w3166w(0) <= wire_niOl1l_w_lg_o2983w(0) AND n1i01ll;
	wire_niOl1l_w_lg_o2995w(0) <= wire_niOl1l_o AND wire_niOl1i_w_lg_o2994w(0);
	wire_niOl1l_w_lg_o1215w(0) <= wire_niOl1l_o AND n1i01ll;
	wire_niOl1l_w_lg_o2983w(0) <= NOT wire_niOl1l_o;
	wire_niOl1l_data <= ( niOOOO & nl111l & nl110l);
	wire_niOl1l_sel <= ( n1i00Ol & n1i00Oi & wire_w_lg_n1i00lO1129w);
	niOl1l :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niOl1l_data,
		o => wire_niOl1l_o,
		sel => wire_niOl1l_sel
	  );
	wire_niOl1O_w_lg_w_lg_w_lg_o1314w3170w3171w(0) <= wire_niOl1O_w_lg_w_lg_o1314w3170w(0) AND n10lO0O;
	wire_niOl1O_w_lg_w_lg_o3172w3173w(0) <= wire_niOl1O_w_lg_o3172w(0) AND n10lO0O;
	wire_niOl1O_w_lg_w_lg_o1314w3181w(0) <= wire_niOl1O_w_lg_o1314w(0) AND wire_w_lg_n1i1Oll3180w(0);
	wire_niOl1O_w_lg_w_lg_o1314w2984w(0) <= wire_niOl1O_w_lg_o1314w(0) AND wire_niOl1l_w_lg_o2983w(0);
	wire_niOl1O_w_lg_w_lg_o1314w3022w(0) <= wire_niOl1O_w_lg_o1314w(0) AND n10O1ii;
	wire_niOl1O_w_lg_w_lg_o1314w2999w(0) <= wire_niOl1O_w_lg_o1314w(0) AND n10O1il;
	wire_niOl1O_w_lg_w_lg_o1314w1315w(0) <= wire_niOl1O_w_lg_o1314w(0) AND n1i1Oli;
	wire_niOl1O_w_lg_w_lg_o1314w3170w(0) <= wire_niOl1O_w_lg_o1314w(0) AND n1i1OlO;
	wire_niOl1O_w_lg_w_lg_o1314w3007w(0) <= wire_niOl1O_w_lg_o1314w(0) AND wire_niOl1i_o;
	wire_niOl1O_w_lg_w_lg_o1314w3189w(0) <= wire_niOl1O_w_lg_o1314w(0) AND wire_niOl1l_o;
	wire_niOl1O_w_lg_o3178w(0) <= wire_niOl1O_o AND wire_w_lg_n1i1OlO3177w(0);
	wire_niOl1O_w_lg_o2996w(0) <= wire_niOl1O_o AND wire_niOl1l_w_lg_o2995w(0);
	wire_niOl1O_w_lg_o1216w(0) <= wire_niOl1O_o AND wire_niOl1l_w_lg_o1215w(0);
	wire_niOl1O_w_lg_o3010w(0) <= wire_niOl1O_o AND wire_niOl1i_w_lg_o2972w(0);
	wire_niOl1O_w_lg_o3190w(0) <= wire_niOl1O_o AND wire_niOl1l_w_lg_o2983w(0);
	wire_niOl1O_w_lg_o3003w(0) <= wire_niOl1O_o AND n10O1ii;
	wire_niOl1O_w_lg_o3028w(0) <= wire_niOl1O_o AND n10O1il;
	wire_niOl1O_w_lg_o1319w(0) <= wire_niOl1O_o AND n1i1OiO;
	wire_niOl1O_w_lg_o3172w(0) <= wire_niOl1O_o AND n1i1Oll;
	wire_niOl1O_w_lg_o2980w(0) <= wire_niOl1O_o AND wire_niOl1l_o;
	wire_niOl1O_w_lg_o1314w(0) <= NOT wire_niOl1O_o;
	wire_niOl1O_w_lg_w_lg_w_lg_w_lg_o1314w3170w3171w3174w(0) <= wire_niOl1O_w_lg_w_lg_w_lg_o1314w3170w3171w(0) OR wire_niOl1O_w_lg_w_lg_o3172w3173w(0);
	wire_niOl1O_w_lg_w_lg_o1314w3046w(0) <= wire_niOl1O_w_lg_o1314w(0) OR wire_niOl1l_w_lg_o2983w(0);
	wire_niOl1O_w_lg_o3065w(0) <= wire_niOl1O_o OR wire_niOl1l_o;
	wire_niOl1O_data <= ( niOO0i & nl111i & nl110O);
	wire_niOl1O_sel <= ( n1i00Ol & n1i00Oi & wire_w_lg_n1i00lO1129w);
	niOl1O :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_niOl1O_data,
		o => wire_niOl1O_o,
		sel => wire_niOl1O_sel
	  );
	wire_nll1llO_w_lg_o7418w(0) <= NOT wire_nll1llO_o;
	wire_nll1llO_data <= ( n10l1il & wire_nll1O1O_dataout & "0");
	wire_nll1llO_sel <= ( n10l11O & n10l11l & wire_w_lg_n10l11i4530w);
	nll1llO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nll1llO_data,
		o => wire_nll1llO_o,
		sel => wire_nll1llO_sel
	  );
	wire_nll1lOO_data <= ( wire_w_lg_n10l1li4548w & wire_nll1O0l_dataout & "1");
	wire_nll1lOO_sel <= ( n10l11O & n10l11l & wire_w_lg_n10l11i4530w);
	nll1lOO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nll1lOO_data,
		o => wire_nll1lOO_o,
		sel => wire_nll1lOO_sel
	  );
	wire_nll1O1i_data <= ( n10l1li & wire_nll1O0i_dataout & "0");
	wire_nll1O1i_sel <= ( n10l11O & n10l11l & wire_w_lg_n10l11i4530w);
	nll1O1i :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nll1O1i_data,
		o => wire_nll1O1i_o,
		sel => wire_nll1O1i_sel
	  );
	wire_nlll0i_data <= ( wire_nlllli_dataout & wire_nlllii_dataout & wire_nl_w_lg_nlO0l1l246w);
	wire_nlll0i_sel <= ( wire_n1ii1li26_w_lg_w_lg_q243w244w & wire_n1ii1ll24_w_lg_w_lg_q240w241w & nlllOl);
	nlll0i :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlll0i_data,
		o => wire_nlll0i_o,
		sel => wire_nlll0i_sel
	  );
	wire_nlll1i_data <= ( wire_nlllil_dataout & wire_nlll0l_dataout & "0");
	wire_nlll1i_sel <= ( nllO1l & wire_n1ii1ii32_w_lg_w_lg_q274w275w & wire_n1ii1il30_w_lg_w_lg_q270w271w);
	nlll1i :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlll1i_data,
		o => wire_nlll1i_o,
		sel => wire_nlll1i_sel
	  );
	wire_nlll1l_data <= ( wire_nllliO_dataout & n1ii1lO & nlO0l1l);
	wire_nlll1l_sel <= ( nllO1l & nlllOO & nlllOl);
	nlll1l :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlll1l_data,
		o => wire_nlll1l_o,
		sel => wire_nlll1l_sel
	  );
	wire_nlll1O_data <= ( n1ii00i & wire_n1ii1iO28_w_lg_w_lg_q258w259w & "0");
	wire_nlll1O_sel <= ( nllO1l & nlllOO & nlllOl);
	nlll1O :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlll1O_data,
		o => wire_nlll1O_o,
		sel => wire_nlll1O_sel
	  );
	wire_nllll0i_data <= ( nlO01Ol & gnumber(2) & "0" & wire_nllO1Oi_o(2));
	wire_nllll0i_sel <= ( n10l1Oi & wire_nllO00O_dataout & n10l1lO & wire_nllO01l_dataout);
	nllll0i :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllll0i_data,
		o => wire_nllll0i_o,
		sel => wire_nllll0i_sel
	  );
	wire_nllll0l_data <= ( nlO01OO & gnumber(3) & "0" & wire_nllO1Oi_o(3));
	wire_nllll0l_sel <= ( n10l1Oi & wire_nllO00O_dataout & n10l1lO & wire_nllO01l_dataout);
	nllll0l :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllll0l_data,
		o => wire_nllll0l_o,
		sel => wire_nllll0l_sel
	  );
	wire_nllll0O_data <= ( nlO001i & gnumber(4) & "0" & wire_nllO1Oi_o(4));
	wire_nllll0O_sel <= ( n10l1Oi & wire_nllO00O_dataout & n10l1lO & wire_nllO01l_dataout);
	nllll0O :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllll0O_data,
		o => wire_nllll0O_o,
		sel => wire_nllll0O_sel
	  );
	wire_nllll1l_data <= ( nlO01lO & gnumber(0) & "0" & wire_nllO1Oi_o(0));
	wire_nllll1l_sel <= ( n10l1Oi & wire_nllO00O_dataout & n10l1lO & wire_nllO01l_dataout);
	nllll1l :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllll1l_data,
		o => wire_nllll1l_o,
		sel => wire_nllll1l_sel
	  );
	wire_nllll1O_data <= ( nlO01Oi & gnumber(1) & "0" & wire_nllO1Oi_o(1));
	wire_nllll1O_sel <= ( n10l1Oi & wire_nllO00O_dataout & n10l1lO & wire_nllO01l_dataout);
	nllll1O :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllll1O_data,
		o => wire_nllll1O_o,
		sel => wire_nllll1O_sel
	  );
	wire_nllllii_data <= ( nlO001l & gnumber(5) & "0" & wire_nllO1Oi_o(5));
	wire_nllllii_sel <= ( n10l1Oi & wire_nllO00O_dataout & n10l1lO & wire_nllO01l_dataout);
	nllllii :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllllii_data,
		o => wire_nllllii_o,
		sel => wire_nllllii_sel
	  );
	wire_nllllil_data <= ( nlO001O & gnumber(6) & "0" & wire_nllO1Oi_o(6));
	wire_nllllil_sel <= ( n10l1Oi & wire_nllO00O_dataout & n10l1lO & wire_nllO01l_dataout);
	nllllil :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllllil_data,
		o => wire_nllllil_o,
		sel => wire_nllllil_sel
	  );
	wire_nlllliO_data <= ( nlO000i & gnumber(7) & "0" & wire_nllO1Oi_o(7));
	wire_nlllliO_sel <= ( n10l1Oi & wire_nllO00O_dataout & n10l1lO & wire_nllO01l_dataout);
	nlllliO :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlllliO_data,
		o => wire_nlllliO_o,
		sel => wire_nlllliO_sel
	  );
	wire_nllllli_data <= ( nlO000l & gnumber(8) & "0" & wire_nllO1Oi_o(8));
	wire_nllllli_sel <= ( n10l1Oi & wire_nllO00O_dataout & n10l1lO & wire_nllO01l_dataout);
	nllllli :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllllli_data,
		o => wire_nllllli_o,
		sel => wire_nllllli_sel
	  );
	wire_nllllll_data <= ( nlO000O & gnumber(9) & "0" & wire_nllO1Oi_o(9));
	wire_nllllll_sel <= ( n10l1Oi & wire_nllO00O_dataout & n10l1lO & wire_nllO01l_dataout);
	nllllll :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllllll_data,
		o => wire_nllllll_o,
		sel => wire_nllllll_sel
	  );
	wire_nllllOl_data <= ( nlO00ii & "0" & wire_nllO1Ol_o(0) & wire_nllO1lO_o(1));
	wire_nllllOl_sel <= ( n10l1Ol & wire_nllO00O_dataout & wire_nllO01O_dataout & wire_nllO00i_dataout);
	nllllOl :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllllOl_data,
		o => wire_nllllOl_o,
		sel => wire_nllllOl_sel
	  );
	wire_nllllOO_data <= ( nlO00il & "0" & wire_nllO1Ol_o(1) & wire_nllO1lO_o(2));
	wire_nllllOO_sel <= ( n10l1Ol & wire_nllO00O_dataout & wire_nllO01O_dataout & wire_nllO00i_dataout);
	nllllOO :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nllllOO_data,
		o => wire_nllllOO_o,
		sel => wire_nllllOO_sel
	  );
	wire_nlllO0i_data <= ( nlO00lO & "0" & wire_nllO1Ol_o(5) & wire_nllO1lO_o(6));
	wire_nlllO0i_sel <= ( n10l1Ol & wire_nllO00O_dataout & wire_nllO01O_dataout & wire_nllO00i_dataout);
	nlllO0i :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlllO0i_data,
		o => wire_nlllO0i_o,
		sel => wire_nlllO0i_sel
	  );
	wire_nlllO0l_data <= ( nlO00Oi & "0" & wire_nllO1Ol_o(6) & wire_nllO1lO_o(7));
	wire_nlllO0l_sel <= ( n10l1Ol & wire_nllO00O_dataout & wire_nllO01O_dataout & wire_nllO00i_dataout);
	nlllO0l :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlllO0l_data,
		o => wire_nlllO0l_o,
		sel => wire_nlllO0l_sel
	  );
	wire_nlllO0O_data <= ( nlO00Ol & "0" & wire_nllO1Ol_o(7) & wire_nllO1lO_o(8));
	wire_nlllO0O_sel <= ( n10l1Ol & wire_nllO00O_dataout & wire_nllO01O_dataout & wire_nllO00i_dataout);
	nlllO0O :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlllO0O_data,
		o => wire_nlllO0O_o,
		sel => wire_nlllO0O_sel
	  );
	wire_nlllO1i_data <= ( nlO00iO & "0" & wire_nllO1Ol_o(2) & wire_nllO1lO_o(3));
	wire_nlllO1i_sel <= ( n10l1Ol & wire_nllO00O_dataout & wire_nllO01O_dataout & wire_nllO00i_dataout);
	nlllO1i :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlllO1i_data,
		o => wire_nlllO1i_o,
		sel => wire_nlllO1i_sel
	  );
	wire_nlllO1l_data <= ( nlO00li & "0" & wire_nllO1Ol_o(3) & wire_nllO1lO_o(4));
	wire_nlllO1l_sel <= ( n10l1Ol & wire_nllO00O_dataout & wire_nllO01O_dataout & wire_nllO00i_dataout);
	nlllO1l :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlllO1l_data,
		o => wire_nlllO1l_o,
		sel => wire_nlllO1l_sel
	  );
	wire_nlllO1O_data <= ( nlO00ll & "0" & wire_nllO1Ol_o(4) & wire_nllO1lO_o(5));
	wire_nlllO1O_sel <= ( n10l1Ol & wire_nllO00O_dataout & wire_nllO01O_dataout & wire_nllO00i_dataout);
	nlllO1O :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlllO1O_data,
		o => wire_nlllO1O_o,
		sel => wire_nlllO1O_sel
	  );
	wire_nlllOii_data <= ( nlO00OO & "0" & wire_nllO1Ol_o(8) & wire_nllO1lO_o(9));
	wire_nlllOii_sel <= ( n10l1Ol & wire_nllO00O_dataout & wire_nllO01O_dataout & wire_nllO00i_dataout);
	nlllOii :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlllOii_data,
		o => wire_nlllOii_o,
		sel => wire_nlllOii_sel
	  );
	wire_nlllOil_data <= ( nlO0i1i & "0" & wire_nllO1Ol_o(9) & wire_nllO1lO_o(10));
	wire_nlllOil_sel <= ( n10l1Ol & wire_nllO00O_dataout & wire_nllO01O_dataout & wire_nllO00i_dataout);
	nlllOil :  oper_selector
	  GENERIC MAP (
		width_data => 4,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlllOil_data,
		o => wire_nlllOil_o,
		sel => wire_nlllOil_sel
	  );
	wire_nlllOli_data <= ( "1" & "0" & nlO010O);
	wire_nlllOli_sel <= ( wire_nllO0il_dataout & wire_nllO0ii_w_lg_dataout4069w & wire_nllO00i_w_lg_w_lg_w_lg_dataout4064w4065w4066w);
	nlllOli :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlllOli_data,
		o => wire_nlllOli_o,
		sel => wire_nlllOli_sel
	  );
	wire_nlllOOi_data <= ( "0" & wire_nllO1OO_o(0) & nlO0i1l);
	wire_nlllOOi_sel <= ( wire_nllO0il_dataout & wire_nllO0ii_dataout & n10l1OO);
	nlllOOi :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlllOOi_data,
		o => wire_nlllOOi_o,
		sel => wire_nlllOOi_sel
	  );
	wire_nlllOOl_data <= ( "0" & wire_nllO1OO_o(1) & nlO0i1O);
	wire_nlllOOl_sel <= ( wire_nllO0il_dataout & wire_nllO0ii_dataout & n10l1OO);
	nlllOOl :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlllOOl_data,
		o => wire_nlllOOl_o,
		sel => wire_nlllOOl_sel
	  );
	wire_nlllOOO_data <= ( "0" & wire_nllO1OO_o(2) & nlO0i0i);
	wire_nlllOOO_sel <= ( wire_nllO0il_dataout & wire_nllO0ii_dataout & n10l1OO);
	nlllOOO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nlllOOO_data,
		o => wire_nlllOOO_o,
		sel => wire_nlllOOO_sel
	  );
	wire_nllO10i_data <= ( "0" & wire_nllO1OO_o(6) & nlO0iil);
	wire_nllO10i_sel <= ( wire_nllO0il_dataout & wire_nllO0ii_dataout & n10l1OO);
	nllO10i :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nllO10i_data,
		o => wire_nllO10i_o,
		sel => wire_nllO10i_sel
	  );
	wire_nllO10l_data <= ( "0" & wire_nllO1OO_o(7) & nlO0iiO);
	wire_nllO10l_sel <= ( wire_nllO0il_dataout & wire_nllO0ii_dataout & n10l1OO);
	nllO10l :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nllO10l_data,
		o => wire_nllO10l_o,
		sel => wire_nllO10l_sel
	  );
	wire_nllO10O_data <= ( "0" & wire_nllO1OO_o(8) & nlO0ili);
	wire_nllO10O_sel <= ( wire_nllO0il_dataout & wire_nllO0ii_dataout & n10l1OO);
	nllO10O :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nllO10O_data,
		o => wire_nllO10O_o,
		sel => wire_nllO10O_sel
	  );
	wire_nllO11i_data <= ( "0" & wire_nllO1OO_o(3) & nlO0i0l);
	wire_nllO11i_sel <= ( wire_nllO0il_dataout & wire_nllO0ii_dataout & n10l1OO);
	nllO11i :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nllO11i_data,
		o => wire_nllO11i_o,
		sel => wire_nllO11i_sel
	  );
	wire_nllO11l_data <= ( "0" & wire_nllO1OO_o(4) & nlO0i0O);
	wire_nllO11l_sel <= ( wire_nllO0il_dataout & wire_nllO0ii_dataout & n10l1OO);
	nllO11l :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nllO11l_data,
		o => wire_nllO11l_o,
		sel => wire_nllO11l_sel
	  );
	wire_nllO11O_data <= ( "0" & wire_nllO1OO_o(5) & nlO0iii);
	wire_nllO11O_sel <= ( wire_nllO0il_dataout & wire_nllO0ii_dataout & n10l1OO);
	nllO11O :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nllO11O_data,
		o => wire_nllO11O_o,
		sel => wire_nllO11O_sel
	  );
	wire_nllO1ii_data <= ( "0" & wire_nllO1OO_o(9) & nlO0ill);
	wire_nllO1ii_sel <= ( wire_nllO0il_dataout & wire_nllO0ii_dataout & n10l1OO);
	nllO1ii :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nllO1ii_data,
		o => wire_nllO1ii_o,
		sel => wire_nllO1ii_sel
	  );
	wire_nllO1iO_data <= ( "0" & nlO01ii & "1");
	wire_nllO1iO_sel <= ( wire_nllO0il_dataout & n10l01i & wire_nllO00O_dataout);
	nllO1iO :  oper_selector
	  GENERIC MAP (
		width_data => 3,
		width_sel => 3
	  )
	  PORT MAP ( 
		data => wire_nllO1iO_data,
		o => wire_nllO1iO_o,
		sel => wire_nllO1iO_sel
	  );

 END RTL; --stratixiv_hssi_rx_digi_wordalign
--synopsys translate_on
--VALID FILE

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_rx_digi IS
   PORT (
      -- S. Park 3/21/08 - Removed following ports
      -- disable_fifo_rd_0,
      -- disable_fifo_wr_0,
      -- disable_fifo_rd, 
      -- disable_fifo_wr,
      --new for auto-nego
      -- new MDIO inputs for bundling and auto speed
      -- new outputs for bundling and auto speed
      --new for Eidle inference
      -- CDR control
      -- S. Park 3/13/08 - Added for XAUI compliance
      -- S. Park 3/21/08 - Added for XAUI compliance
      
      -- Reset inputs
      hard_reset                       : IN STD_LOGIC;		-- From MDIO_REG.V Complex function of NPOR, ENTEST etc.,
      rxpcs_rst                        : IN STD_LOGIC;		-- RX PCS resets
      rxpma_rst                        : IN STD_LOGIC;		-- RX PMA reset for PPM Detect
      cmpfifourst                      : IN STD_LOGIC;		-- User reset exclusive to comp_chnl_top & below
      phfifourst_rx                    : IN STD_LOGIC;		-- User reset exclusive to rx_ctrl & below
      
      -- Scan inputs
      scan_mode                        : IN STD_LOGIC;		-- 1'b1 = scan mode active; 
      -- 1'b0 = normal mode
      -- RX PCS channel inputs/outputs
      encdt                            : IN STD_LOGIC;		-- Comma Detect enable control signal from PLD
      a1a2_size                        : IN STD_LOGIC;		-- A1A2 size control signal for byte sync block
      bitslip                          : IN STD_LOGIC;		-- Bitslip control signal from PLD
      rdenable_rmf                     : IN STD_LOGIC;		-- Read enable control signal for CompFIFO
      wrenable_rmf                     : IN STD_LOGIC;		-- Write enable control signal for CompFIFO
      pld_rx_clk                       : IN STD_LOGIC;		-- Parallel receive clock from PLD
      soft_reset_rclk1                 : OUT STD_LOGIC;		-- Synchronized reset
      polinv_rx                        : IN STD_LOGIC;		-- RX polarity inversion dynamic control signal
      bitloc_rev_en                    : IN STD_LOGIC;		-- RX bit reversal dynamic control signal
      byte_rev_en                      : IN STD_LOGIC;		-- RX byte swap dynamic control signal
      rcvd_clk_pma                     : IN STD_LOGIC;
      pudi                             : IN STD_LOGIC_VECTOR(19 DOWNTO 0);		-- RX 10-bit code group bus from RX PMA
      sigdetni                         : IN STD_LOGIC;		-- rx signal detected from PMA
      fifo_rst_rd_qd                   : IN STD_LOGIC;		-- from master deskew sm
      fifo_rst_rd_gp                   : IN STD_LOGIC;		-- from grouping deskew sm
      en_dskw_qd                       : IN STD_LOGIC;		-- from master deskew sm
      en_dskw_gp                       : IN STD_LOGIC;		-- from grouping deskew sm
      is_lane0                         : IN STD_LOGIC;		-- This is lane 0 if 1'b1. Hard-wired
      -- when chnl_top is instantiated
      align_status                     : IN STD_LOGIC;		-- Indicate that four lanes are now 
      -- aligned in dskw_top
      align_status_sync_0              : IN STD_LOGIC;		-- Synced to clk_2 from channel 0
      align_status_sync_2              : IN STD_LOGIC;		-- Synced to clk_2 from channel 2
      -- S. Park 3/21/08 - Removed below two ports
      -- input          disable_fifo_rd_0;     // disable_fifo_rd from channel 0
      -- input          disable_fifo_wr_0;     // disable_fifo_wr from channel 0
      rx_data_rs                       : IN STD_LOGIC_VECTOR(7 DOWNTO 0);		-- rx data from 10G ethernet rx state machine
      rx_control_rs                    : IN STD_LOGIC;		-- rx control from 10G ethernet rx state machine
      rcvd_clk0_pma                    : IN STD_LOGIC;		-- Recovered clock from PMA channel0
      fifo_rd_in_comp_0                : IN STD_LOGIC;		-- fifo_rd_in_comp from channel 0
      fifo_rd_in_comp_2                : IN STD_LOGIC;		-- fifo_rd_in_comp from channel 2
      txlp20b                          : IN STD_LOGIC_VECTOR(19 DOWNTO 0);		-- tx 20-bit code group bus to PMA
      refclk_pma                       : IN STD_LOGIC;		-- Global parallel TX PLL clock
      tx_pma_clk                       : IN STD_LOGIC;		-- Per channel TX PMA clock
      fref                             : IN STD_LOGIC;		-- Reference clock for FREQDET module
      clklow                           : IN STD_LOGIC;		-- Divided clock for FREQDET module
      bytordpld                        : IN STD_LOGIC;		-- Byte ordering dynamic control signal from PLD
      wrdisable_rx                     : IN STD_LOGIC;		-- RX phase comp. FIFO write disable control signal
      rdenable_rx                      : IN STD_LOGIC;		-- RX phase comp. FIFO read enable control signal
      pma_testbus                      : IN STD_LOGIC_VECTOR(7 DOWNTO 0);		-- PMA digital testbus output
      encoder_testbus                  : IN STD_LOGIC_VECTOR(9 DOWNTO 0);		-- Test bus from 8B10B encoder
      tx_ctrl_testbus                  : IN STD_LOGIC_VECTOR(9 DOWNTO 0);		-- Test bus from TX FIFO
      -- Removed old bundling mode inputs
      -- input   [3:0]  rxfifo_shared_sig_in_ch0;    // TX FIFO shared signal from channel 0
      -- input   [3:0]  rxfifo_shared_sig_in_q0_ch0; // TX FIFO shared signal from channel 0 of Quad 0
      
      phystatus_int                    : IN STD_LOGIC;
      rxvalid_int                      : IN STD_LOGIC;
      rxstatus_int                     : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      powerdown                        : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      
      -- rate change output from upper layers.
      -- frequency switch done from PMA (rising edge of old clock to rising edge of new clock)
      -- for bundle
      -- Electrical Idle inference mechanism select
      
      -- reverse parallel loopback requires 4 EIOS to be transmitted up to the upper layer. Used in the CDR
      -- control block and electrical idle inference module
      -- LMC 01/21/08
      
      -- CDR control
      -- PLD control of the CDR when rcdr_ctrl_en = 1'b0
      
      -- PLD control of PRBS-CID enable
      
      -- S. Park 3/13/08 - Added for XAUI compliance
      
      -- S. Park 3/21/08 - Added for XAUI compliance
      
      -- removed old bundling mode outputs 
      -- output  [3:0]  rxfifo_shared_sig_out; // TX FIFO shared signal output
      fifo_rd_out_comp                 : OUT STD_LOGIC;
      rxd                              : OUT STD_LOGIC_VECTOR(63 DOWNTO 0);		-- XGMII rx data to PLD
      rev_loop_data                    : OUT STD_LOGIC_VECTOR(19 DOWNTO 0);		-- 10 bit data from RX rate matching 
      -- FIFO, reverse loopback
      rx_clk                           : OUT STD_LOGIC;		-- XGMII rx clock to PLD
      bisterr                          : OUT STD_LOGIC;		-- BIST or PRBS done status signal
      cg_comma                         : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);		-- comma is detected in sync_chnl_top to PMA
      clk_2_b                          : OUT STD_LOGIC;		-- clk_2 to rcv_sm
      rcvd_clk_pma_b                   : OUT STD_LOGIC;
      sync_status                      : OUT STD_LOGIC;		-- Indicate that this lane is now synchronized
      -- S. Park 3/21/08 - Removed below two ports
      -- output         disable_fifo_rd;       // disable_fifo_rd from this lane
      -- output         disable_fifo_wr;       // disable_fifo_wr from this lane
      align_status_sync                : OUT STD_LOGIC;		-- synced to clk_2
      dec_data_valid                   : OUT STD_LOGIC;
      dec_data                         : OUT STD_LOGIC_VECTOR(7 DOWNTO 0);		-- decoded 8-bit RX data to XAUI RX SM
      dec_ctl                          : OUT STD_LOGIC;		-- decoded RX control to XAUI RX SM
      running_disp                     : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);		-- indicate that dec_data/dec_ctl is 
      -- either not valid or having disparity error
      selftest_done                    : OUT STD_LOGIC;		-- Status shows that the self test checking is done
      selftest_err                     : OUT STD_LOGIC;		-- Status shows that the selftest is successful
      err_data                         : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);		-- When the self test fails, this records
      -- the first byte that error occurs to.
      err_ctl                          : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);		-- When the self test fails, this records
      -- the first byte that error occurs to.
      prbs_done                        : OUT STD_LOGIC;		-- Indicate that prbs verification is done
      prbs_err_lt                      : OUT STD_LOGIC;		-- Indicate that prbs verification is OK 
      -- - latched version, cleared when reset
      signal_detect_out                : OUT STD_LOGIC;		-- SIGDET out to PLD
      align_det_sync                   : OUT STD_LOGIC;		-- Channel is aligned, present for 10 clocks
      rd_align                         : OUT STD_LOGIC;		-- Read data has an Align code group
      bistdone                         : OUT STD_LOGIC;
      rlv                              : OUT STD_LOGIC;
      rlv_lt                           : OUT STD_LOGIC;		-- RLV status signal to PLD
      almost_fl_rmf                    : OUT STD_LOGIC;		-- Comp FIFO almost full flag
      full_rmf                         : OUT STD_LOGIC;		-- Comp FIFO full flag
      almost_mt_rmf                    : OUT STD_LOGIC;		-- Comp FIFO almost empty flag
      empty_rmf                        : OUT STD_LOGIC;		-- Comp FIFO empty flag
      freq_lock                        : OUT STD_LOGIC;		-- Frequency lock output flag for PMA
      full_rx                          : OUT STD_LOGIC;		-- RX Phase comp. FIFO full flag
      empty_rx                         : OUT STD_LOGIC;		-- RX Phase comp. FIFO empty flag
      a1a2_k1k2_flag                   : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);		-- A1A2K1K2 output flag
      byteord_flag                     : OUT STD_LOGIC;		-- Byte ordering successfull output flag
      rx_pipe_clk                      : OUT STD_LOGIC;		-- Output clock for RX PIPE interface
      chnl_test_bus_out                : OUT STD_LOGIC_VECTOR(9 DOWNTO 0);		-- Channel digital testbus output
      rx_pipe_soft_reset               : OUT STD_LOGIC;		-- RX PIPE soft reset
      
      phystatus                        : OUT STD_LOGIC;
      rxvalid                          : OUT STD_LOGIC;
      rxstatus                         : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      pipe_data                        : OUT STD_LOGIC_VECTOR(63 DOWNTO 0);
      
      -- speed change done to PIPE interface (i.e. auto negotiation done)
      
      -- Asserted when Electrical Idle is detected
      
      --describes word boundary
      
      -- CDR control
      -- Asserted when K_I or K_X_I is detected on the incoming data
      -- force CDR to LTR mode
      
      -- RX PCS CRAMs
      rskpsetbased                     : IN STD_LOGIC;		-- Enable rate matching for PCI-E/PIPE-or
      -- other standards based on COMMA DEL DEL..
      rtruebac2bac                     : IN STD_LOGIC;		-- Should be high for all standards 
      -- except PIPE. Back to back rate matching enable.
      rcmpfifourst                     : IN STD_LOGIC;		-- Enable cmpfifourst
      rphfifourstrx                    : IN STD_LOGIC;		-- Enable phfifourst_rx
      rcomp_size                       : IN STD_LOGIC_VECTOR(2 DOWNTO 0);		-- Pattern comparision length CRAMs
      rcomp_pat                        : IN STD_LOGIC_VECTOR(39 DOWNTO 0);		-- Sync pattern CRAMs
      rrundisp                         : IN STD_LOGIC_VECTOR(5 DOWNTO 0);		-- Run lengh violation setting CRAMs
      rib_inv_cd                       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Invalid code setting CRAMs for IB
      rrlv_en                          : IN STD_LOGIC;		-- RLV enable CRAM
      rsync_sm_dis                     : IN STD_LOGIC;		-- GIGE/XAUI Sync SM disable CRAM
      rautobtalg_dis                   : IN STD_LOGIC;		-- BITSLIP mode enable CRAM
      rdis_rx_disp                     : IN STD_LOGIC;		-- Receive running disparity calculation disable CRAM
      rmatchen                         : IN STD_LOGIC;		-- Clock compensation enable CRAM
      rgenericfifo                     : IN STD_LOGIC;		-- GenericFIFO mode enable CRAM
      rendec_rx                        : IN STD_LOGIC;		-- 10B/8B decoder enable CRAM
      rdwidth_rx                       : IN STD_LOGIC;		-- RX parallel interface data width selection CRAM
      rlp20ben                         : IN STD_LOGIC;		-- 20-b loopback enable CRAM
      rrxfifo_dis                      : IN STD_LOGIC;		-- RX FIFO bypassing CRAM
      rpmadwidth_rx                    : IN STD_LOGIC;		-- RX PMA to RX PCS data width selection CRAM
      rpma_doublewidth_rx              : IN STD_LOGIC;		-- RX PMA/PCS double width (16/20) sel CRAM
      renumber                         : IN STD_LOGIC_VECTOR(5 DOWNTO 0);		-- Number of consecutive errors without
      -- valid data to goto LOSS_OF_SYNC
      rknumber                         : IN STD_LOGIC_VECTOR(7 DOWNTO 0);		-- Number of consecutive commas to reach 
      -- SYNC_ACQ from LOSS_OF_SYNC
      renpolinv_rx                     : IN STD_LOGIC;		-- Allow polarity inversion
      rgnumber                         : IN STD_LOGIC_VECTOR(7 DOWNTO 0);		-- Number of consecutive good data to approach SYNC_ACQ
      rclkcmpsqmd                      : IN STD_LOGIC;		-- How many characters to match
      rclkcmpsq1p                      : IN STD_LOGIC_VECTOR(19 DOWNTO 0);		-- Programmable 20-bit encoded comp sequence pos. disp.
      rclkcmpsq1n                      : IN STD_LOGIC_VECTOR(19 DOWNTO 0);		-- Programmable 20-bit encoded comp sequence neg. disp.
      rclkcmp_pipe_en                  : IN STD_LOGIC;		-- RM PIPE-compatible mode enable 
      rosnumber                        : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Length of the ordered set
      rosbased                         : IN STD_LOGIC;		-- Enable ordered-set based algorithm
      rkchar                           : IN STD_LOGIC;		-- use kchar at cg_bad logic calculation
      rcascaded_8b10b_en_rx            : IN STD_LOGIC;		-- Cascaded 8B/10B decoder enable CRAM
      resync_badcg_en                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		--
      rencdt_rising                    : IN STD_LOGIC;		-- encdt on rising edge enable CRAM
      rcomp_pat_porn                   : IN STD_LOGIC;		-- Positive and negative match enable CRAM
      rprbsen_rx                       : IN STD_LOGIC;		-- PRBS Verifier enable CRAM
      rprbs_clr_rslt_rx                : IN STD_LOGIC;		-- PRBS pass/fail flag clear CRAM
      rbisten_rx                       : IN STD_LOGIC;		-- BIST Verifier enable CRAM
      rbist_clr_rx                     : IN STD_LOGIC;		-- BIST pass/fail flag clear CRAM
      rwa_6g_en                        : IN STD_LOGIC;		-- 6G word alignment enable CRAM
      rbytord_2sym_en                  : IN STD_LOGIC;		-- Enable 2 symbols byte orderring CRAM
      rbysync_polinv_en                : IN STD_LOGIC;		-- Word alignment polarity inversion enable CRAM
      rbytord_6g_mask_en               : IN STD_LOGIC;		-- Mask out upper byte in 6G 2 symbol comparison
      rbytord_s2gx                     : IN STD_LOGIC;		-- Byte ordering like s2gx, only once per PCS reset
      rbitloc_rev_en                   : IN STD_LOGIC;		-- Bit reversal enable CRAM
      rbyte_rev_en                     : IN STD_LOGIC;		-- Byte swap enable CRAM
      rbyteorden                       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Byte ordering enable CRAM
      rbytordplden                     : IN STD_LOGIC;		-- PLD control signal BYTEORDPLD enable CRAM
      rphfifopldenrx                   : IN STD_LOGIC;		-- RX phase comp. FIFO read/write enable CRAM
      rautoinsdis                      : IN STD_LOGIC;		-- Disable CRAM for auto insertion of 8'h9C
      rppmsel                          : IN STD_LOGIC_VECTOR(5 DOWNTO 0);		-- Programmable PPM ajustment CRAM
      rforce0_freqdet                  : IN STD_LOGIC;		-- Forcing FREQDET signal to low CRAM
      rforce1_freqdet                  : IN STD_LOGIC;		-- Forcing FREQDET signal to high CRAM
      rbytordpat                       : IN STD_LOGIC_VECTOR(19 DOWNTO 0);		-- Byte ordering pattern CRAM
      rbytordpad                       : IN STD_LOGIC_VECTOR(9 DOWNTO 0);		-- Byte ordering pad pattern CRAM
      rforce_sig_det_pcs               : IN STD_LOGIC;		-- Forcing sigdet to high in PCS CRAM
      rfreerun_rx                      : IN STD_LOGIC;		-- RX_CLK out free running during RX PCS reset enable CRAM
      rrcvd_clk_sel                    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- RCVD_CLK domain selection CRAM
      rclk_1_sel                       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- CLK_1 domain selection CRAM
      rclk_2_sel                       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- CLK_2 domain selection CRAM
      rrx_rd_clk_sel                   : IN STD_LOGIC;		-- RX FIFO read clock selection CRAM
      rall_one_dect_only               : IN STD_LOGIC;		-- PRBS Verifier detect all one only  enable CRAM
      rtest_bus_sel                    : IN STD_LOGIC_VECTOR(3 DOWNTO 0);		-- Per channel test bus selection CRAMs
      r8b10b_dec_ibm_en                : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- 8B10B Decoder fix enable CRAM
      rrxfifo_lowlatency_en            : IN STD_LOGIC;		-- RX FIFO low latency enable CRAM
      rppm_cnt_reset                   : IN STD_LOGIC;		-- PPM counter reset CRAM (latched version on Test bus)
      sel_gp_md                        : IN STD_LOGIC;		-- Select Quad or Group Mode
      rclkcmpinsertpad                 : IN STD_LOGIC;		-- Rate matching pad insertion enable CRAM
      
      -- CRAM for enable low-latency PCS bypass mode
      -- Programmable 4 us (Gen1) of 2 us (Gen2) timer during which CDR control block controls the PPM detector. 
      -- Enables PCS Wrapback mode
      -- CID pattern to be 0 or 1
      -- Length of CID pattern in cycles
      
      -- Common PCS CRAMs
      rindv_rx                         : IN STD_LOGIC;		-- RX SM bypassing CRAM
      dskwclksel                       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Select Deskew Clock
      rdskposdisp                      : IN STD_LOGIC;		-- Match the programmed de-skew pattern only
      rdskchrp                         : IN STD_LOGIC_VECTOR(9 DOWNTO 0);		-- Programmable Deskew Char. Pos. Disp.
      rendec_data_sel_rx               : IN STD_LOGIC;		-- RX 8B10B decoder data out selection CRAM
      -- Removed old bundling mode MDIOs
      -- input          rphfifo_master_sel_rx; // TX Phase comp. FIFO pointers selection CRAM
      
      -- Common TX RX CRAM for BIST/PRBS
      rprbs_sel                        : IN STD_LOGIC_VECTOR(2 DOWNTO 0);		-- PRBS selection CRAM
      rbist_sel                        : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- BIST selection CRAM
      rcxpat_chnl_en                   : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- CRPAT or CJPAT selection CRAM
      rstart_threshold                 : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      rins_threshold                   : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
      rdel_threshold                   : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
      rfull_threshold                  : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
      rempty_threshold                 : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      rinvalid_code_err_only           : IN STD_LOGIC;
      rrx_pipe_enable                  : IN STD_LOGIC;
      rrxpcsbypass_en                  : IN STD_LOGIC;
      rfts_count                       : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
      rpcs_wrapback_en                 : IN STD_LOGIC;
      rcid_pattern_rx                  : IN STD_LOGIC;
      rcid_len_rx                      : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
      
      -- CRAM for auto negotiation module
      rauto_speed_ena                  : IN STD_LOGIC;
      rphfifo_regmode_rx               : IN STD_LOGIC;
      rfreq_sel                        : IN STD_LOGIC;
      rate                             : IN STD_LOGIC;
      gen2ngen1                        : IN STD_LOGIC;
      gen2ngen1_bundle                 : IN STD_LOGIC;
      speed_change                     : OUT STD_LOGIC;
      -- Programmable counter threshold for pma_done_int (1ms)
      -- disable EIOS priority over eidle inference
      -- enable usage of signal detect under gen1 conditions when eidle
      -- is enabled, eidle inference when gen2 is enabled
      
      -- CRAM for Eidle Inference
      -- Enable/disable Electrical Idle Inference module
      -- The number of COMs required to enter/exit Eidle
      -- values greater than 2 entails that syncstatus is used
      
      -- CDR control CRAMS
      -- Enable/Disable CDR control block
      -- Enable CID mode (CDR)
      -- Enable masking of rxvalid logic
      -- Minimum programmable period of time that LTR is asserted when the CDR control block is enabled.
      -- Masking period of data upon exiting EIdle; for high BER period
      
      -- new signal inputs for bundling
      rx_div2_sync_in_centrl           : IN STD_LOGIC;
      rx_div2_sync_in_quad_up          : IN STD_LOGIC;
      rx_div2_sync_in_quad_down        : IN STD_LOGIC;
      reset_pc_ptrs_in_centrl          : IN STD_LOGIC;
      reset_pc_ptrs_in_quad_up         : IN STD_LOGIC;
      reset_pc_ptrs_in_quad_down       : IN STD_LOGIC;
      wr_enable_in_centrl              : IN STD_LOGIC;
      wr_enable_in_quad_up             : IN STD_LOGIC;
      wr_enable_in_quad_down           : IN STD_LOGIC;
      rd_enable_in_centrl              : IN STD_LOGIC;
      rd_enable_in_quad_up             : IN STD_LOGIC;
      rd_enable_in_quad_down           : IN STD_LOGIC;
      rx_we_in_centrl                  : IN STD_LOGIC;
      rx_we_in_quad_up                 : IN STD_LOGIC;
      rx_we_in_quad_down               : IN STD_LOGIC;
      speed_change_in_centrl           : IN STD_LOGIC;
      -- pipeline inputs for bundling
      rx_div2_sync_in_pipe_quad_up     : IN STD_LOGIC;
      rx_div2_sync_in_pipe_quad_down   : IN STD_LOGIC;
      reset_pc_ptrs_in_pipe_quad_up    : IN STD_LOGIC;
      reset_pc_ptrs_in_pipe_quad_down  : IN STD_LOGIC;
      wr_enable_in_pipe_quad_up        : IN STD_LOGIC;
      wr_enable_in_pipe_quad_down      : IN STD_LOGIC;
      rd_enable_in_pipe_quad_up        : IN STD_LOGIC;
      rd_enable_in_pipe_quad_down      : IN STD_LOGIC;
      rx_we_in_pipe_quad_up            : IN STD_LOGIC;
      rx_we_in_pipe_quad_down          : IN STD_LOGIC;
      speed_change_in_pipe_quad_up     : IN STD_LOGIC;
      speed_change_in_pipe_quad_down   : IN STD_LOGIC;
      -- Bundle Mode Inputs for config_sel
      config_sel_centrl                : IN STD_LOGIC;
      config_sel_quad_up               : IN STD_LOGIC;
      config_sel_quad_down             : IN STD_LOGIC;
      
      -- new MDIO inputs for bundling and auto speed
      rmaster_rx                       : IN STD_LOGIC;
      rmaster_up_rx                    : IN STD_LOGIC;
      rpipeline_bypass_rx              : IN STD_LOGIC;
      rauto_deassert_pc_rst_cnt        : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      rauto_pc_en_cnt                  : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
      rself_sw_en_rx                   : IN STD_LOGIC;
      
      -- S. Park 2/8/08 - New CRAM inputs for PPM Detector
      
      -- new outputs for bundling and auto speed
      rx_div2_sync_out_pipe_up         : OUT STD_LOGIC;
      rx_we_out_pipe_up                : OUT STD_LOGIC;
      wr_enable_out_pipe_up            : OUT STD_LOGIC;
      rd_enable_out_pipe_up            : OUT STD_LOGIC;
      reset_pc_ptrs_out_pipe_up        : OUT STD_LOGIC;
      speed_change_out_pipe_up         : OUT STD_LOGIC;
      rx_div2_sync_out_pipe_down       : OUT STD_LOGIC;
      rx_we_out_pipe_down              : OUT STD_LOGIC;
      wr_enable_out_pipe_down          : OUT STD_LOGIC;
      rd_enable_out_pipe_down          : OUT STD_LOGIC;
      reset_pc_ptrs_out_pipe_down      : OUT STD_LOGIC;
      speed_change_out_pipe_down       : OUT STD_LOGIC;
      
      dis_pc_byte                      : OUT STD_LOGIC;
      reset_pc_ptrs                    : OUT STD_LOGIC;
      
      -- S. Park 3/13/08 - Added for XAUI compliance
      
      -- S. Park 3/21/08 - Added for XAUI compliance
      
      -- PMA rate change control
      pcie_switch                      : OUT STD_LOGIC;
      reidleinferenable                : IN STD_LOGIC;
      reidle_com_detect                : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      eidleinfersel                    : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      pipe_loopbk                      : IN STD_LOGIC;
      rxelecidle_int                   : OUT STD_LOGIC;
      rpma_done_count                  : IN STD_LOGIC_VECTOR(17 DOWNTO 0);
      riei_eios_priority_dis           : IN STD_LOGIC;
      rgen1_sigdet_ena                 : IN STD_LOGIC;
      rerr_flags_sel                   : IN STD_LOGIC;
      rrxpcsclkpwdn                    : IN STD_LOGIC;
      rcdr_ctrl_en                     : IN STD_LOGIC;
      rcid_en                          : IN STD_LOGIC;
      rrxvalid_mask                    : IN STD_LOGIC;
      rwait_count                      : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
      rmask_count                      : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
      pld_ltr                          : IN STD_LOGIC;
      early_eios                       : OUT STD_LOGIC;
      ltr                              : OUT STD_LOGIC;
      prbs_cid_en                      : IN STD_LOGIC;
      wa_boundary                      : OUT STD_LOGIC_VECTOR(4 DOWNTO 0);
      tx_div2_sync_out_pipe_up         : IN STD_LOGIC;
      fifo_select_out_pipe_up          : IN STD_LOGIC;
      tx_wr_enable_out_pipe_up         : IN STD_LOGIC;
      tx_rd_enable_out_pipe_up         : IN STD_LOGIC;
      tx_div2_sync_out_pipe_down       : IN STD_LOGIC;
      fifo_select_out_pipe_down        : IN STD_LOGIC;
      tx_wr_enable_out_pipe_down       : IN STD_LOGIC;
      tx_rd_enable_out_pipe_down       : IN STD_LOGIC;
      rwait_for_phfifo_cnt             : IN STD_LOGIC_VECTOR(5 DOWNTO 0);
      rppm_post_eidle_del              : IN STD_LOGIC;
      rppm_gen1_2xcnt_en               : IN STD_LOGIC;
      cg_comp_rd_d_ch0                 : IN STD_LOGIC;
      cg_comp_rd_d_ch1                 : IN STD_LOGIC;
      cg_comp_rd_d_ch2                 : IN STD_LOGIC;
      cg_comp_rd_d_ch3                 : IN STD_LOGIC;
      cg_comp_wr_ch0                   : IN STD_LOGIC;
      cg_comp_wr_ch1                   : IN STD_LOGIC;
      cg_comp_wr_ch2                   : IN STD_LOGIC;
      cg_comp_wr_ch3                   : IN STD_LOGIC;
      cg_comp_rd_d_out                 : OUT STD_LOGIC;
      cg_comp_wr_out                   : OUT STD_LOGIC;
      del_cond_met_0                   : IN STD_LOGIC;
      fifo_ovr_0                       : IN STD_LOGIC;
      latency_comp_0                   : IN STD_LOGIC;
      insert_incomplete_0              : IN STD_LOGIC;
      del_cond_met_out                 : OUT STD_LOGIC;
      fifo_ovr_out                     : OUT STD_LOGIC;
      latency_comp_out                 : OUT STD_LOGIC;
      insert_incomplete_out            : OUT STD_LOGIC;
      pcs_wrapback_in                  : IN STD_LOGIC_VECTOR(69 DOWNTO 0)
   );
END stratixiv_hssi_rx_digi;

ARCHITECTURE trans OF stratixiv_hssi_rx_digi IS
   COMPONENT stratixiv_hssi_rx_digi_bist_ver
      PORT (
         clk_2                            : IN STD_LOGIC;
         soft_reset                       : IN STD_LOGIC;
         sync_status                      : IN STD_LOGIC;
         rbisten_rx                       : IN STD_LOGIC;
         rpmadwidth_rx                    : IN STD_LOGIC;
         rpma_doublewidth_rx              : IN STD_LOGIC;
         rdwidth_rx                       : IN STD_LOGIC;
         rbist_sel                        : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rcxpat_chnl_sel                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rbist_clr_rx                     : IN STD_LOGIC;
         rxd                              : IN STD_LOGIC_VECTOR(63 DOWNTO 0);
         rxc                              : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         prbs_done                        : IN STD_LOGIC;
         prbs_err                         : IN STD_LOGIC;
         cur_state                        : OUT STD_LOGIC_VECTOR(4 DOWNTO 0);
         selftest_err                     : OUT STD_LOGIC;
         selftest_done                    : OUT STD_LOGIC;
         bisterr                          : OUT STD_LOGIC;
         bistdone                         : OUT STD_LOGIC;
         err_data                         : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         err_ctl                          : OUT STD_LOGIC_VECTOR(1 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_rx_digi_auto_speed_neg
      PORT (
         refclk                           : IN STD_LOGIC;
         rxpcs_rst_int                    : IN STD_LOGIC;
         rate                             : IN STD_LOGIC;
         gen2ngen1                        : IN STD_LOGIC;
         config_sel_centrl                : IN STD_LOGIC;
         config_sel_quad_up               : IN STD_LOGIC;
         config_sel_quad_down             : IN STD_LOGIC;
         rindv_rx                         : IN STD_LOGIC;
         rmaster_rx                       : IN STD_LOGIC;
         rmaster_up_rx                    : IN STD_LOGIC;
         rauto_speed_ena                  : IN STD_LOGIC;
         singleorbundle                   : IN STD_LOGIC;
         rphfifo_regmode_rx               : IN STD_LOGIC;
         rpma_done_count                  : IN STD_LOGIC_VECTOR(17 DOWNTO 0);
         rauto_deassert_pc_rst_cnt        : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         rauto_pc_en_cnt                  : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         rwait_for_phfifo_cnt             : IN STD_LOGIC_VECTOR(5 DOWNTO 0);
         config_sel                       : OUT STD_LOGIC;
         pcie_switch                      : OUT STD_LOGIC;
         speed_change                     : OUT STD_LOGIC;
         dis_pc_byte                      : OUT STD_LOGIC;
         reset_pc_ptrs                    : OUT STD_LOGIC;
         cs                               : OUT STD_LOGIC_VECTOR(3 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_rx_digi_rx_ctrl
      PORT (
         soft_reset                       : IN STD_LOGIC;
         clk_2                            : IN STD_LOGIC;
         rx_wr_clk                        : IN STD_LOGIC;
         rx_rd_clk                        : IN STD_LOGIC;
         scan_mode                        : IN STD_LOGIC;
         rrxfifo_dis                      : IN STD_LOGIC;
         rindv_rx                         : IN STD_LOGIC;
         rendec_data_sel_rx               : IN STD_LOGIC;
         rwa_6g_en                        : IN STD_LOGIC;
         rrxfifo_lowlatency_en            : IN STD_LOGIC;
         endec_rx                         : IN STD_LOGIC;
         rinvalid_code_err_only           : IN STD_LOGIC;
         rrx_pipe_enable                  : IN STD_LOGIC;
         rpmadatawidth                    : IN STD_LOGIC;
         rdwidth                          : IN STD_LOGIC;
         rautoinsdis                      : IN STD_LOGIC;
         rbytorden                        : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rbytord_2sym_en                  : IN STD_LOGIC;
         rbytordpat                       : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
         rbytordpadval                    : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         rbytordplden                     : IN STD_LOGIC;
         bytordplden                      : IN STD_LOGIC;
         rsync_comp_size                  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rsync_comp_pat                   : IN STD_LOGIC_VECTOR(39 DOWNTO 0);
         rsync_comp_porn                  : IN STD_LOGIC;
         rsync_sm_dis                     : IN STD_LOGIC;
         rclkcmpinsertpad                 : IN STD_LOGIC;
         rbytord_6g_mask_en               : IN STD_LOGIC;
         rbytord_s2gx                     : IN STD_LOGIC;
         invalid_code_delay               : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         sigdetni                         : IN STD_LOGIC;
         dec_data_valid_pre               : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         dec_data_valid                   : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rx_data_rs                       : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         rx_control_rs                    : IN STD_LOGIC;
         rx_data_dt                       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         rx_control_dt                    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         tenb_data                        : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
         sync_resync_pre                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         sync_resync_delay                : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         disp_err_delay                   : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         disp_val_delay                   : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         ovr_undflow                      : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         rrxfifo_urst_en                  : IN STD_LOGIC;
         rxfifo_urst                      : IN STD_LOGIC;
         rrxphfifopldctl_en               : IN STD_LOGIC;
         pld_wr_dis                       : IN STD_LOGIC;
         pld_re                           : IN STD_LOGIC;
         rrxpcsbypass_en                  : IN STD_LOGIC;
         phystatus_int                    : IN STD_LOGIC;
         rxvalid_int                      : IN STD_LOGIC;
         rxstatus_int                     : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         powerdown                        : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         reset_pc_ptrs                    : IN STD_LOGIC;
         reset_pc_ptrs_centrl             : IN STD_LOGIC;
         reset_pc_ptrs_quad_up            : IN STD_LOGIC;
         reset_pc_ptrs_quad_down          : IN STD_LOGIC;
         gen2ngen1                        : IN STD_LOGIC;
         gen2ngen1_bundle                 : IN STD_LOGIC;
         dis_pc_byte                      : IN STD_LOGIC;
         wr_enable_centrl                 : IN STD_LOGIC;
         wr_enable_quad_up                : IN STD_LOGIC;
         wr_enable_quad_down              : IN STD_LOGIC;
         rd_enable_centrl                 : IN STD_LOGIC;
         rd_enable_quad_up                : IN STD_LOGIC;
         rd_enable_quad_down              : IN STD_LOGIC;
         rx_we_in_centrl                  : IN STD_LOGIC;
         rx_we_in_quad_up                 : IN STD_LOGIC;
         rx_we_in_quad_down               : IN STD_LOGIC;
         rauto_speed_ena                  : IN STD_LOGIC;
         rfreq_sel                        : IN STD_LOGIC;
         rphfifo_regmode_rx               : IN STD_LOGIC;
         rmaster_rx                       : IN STD_LOGIC;
         rmaster_up_rx                    : IN STD_LOGIC;
         rxd                              : OUT STD_LOGIC_VECTOR(63 DOWNTO 0);
         rxd_9                            : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         rxd_19                           : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         rxc                              : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
         running_disp                     : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         signal_detect_out                : OUT STD_LOGIC;
         rxd_lpbk                         : OUT STD_LOGIC_VECTOR(39 DOWNTO 0);
         rx_we_out                        : OUT STD_LOGIC;
         ph_fifo_empty                    : OUT STD_LOGIC;
         ph_fifo_full                     : OUT STD_LOGIC;
         wr_enable_out                    : OUT STD_LOGIC;
         rd_enable_out                    : OUT STD_LOGIC;
         bytord_valid_out                 : OUT STD_LOGIC;
         soft_reset_rclk1                 : OUT STD_LOGIC;
         soft_reset_wclk1                 : OUT STD_LOGIC;
         phystatus                        : OUT STD_LOGIC;
         rxvalid                          : OUT STD_LOGIC;
         rxstatus                         : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         pipe_data                        : OUT STD_LOGIC_VECTOR(63 DOWNTO 0);
         wr_enable2                       : OUT STD_LOGIC;
         wptr_bin                         : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         rd_enable2                       : OUT STD_LOGIC;
         rptr_bin                         : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         pcs_wrapback_in                  : IN STD_LOGIC_VECTOR(69 DOWNTO 0);
         rpcs_wrapback_en                 : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_rx_digi_dskw_fifo
      PORT (
         rcvd_clk                         : IN STD_LOGIC;
         sudi                             : IN STD_LOGIC_VECTOR(13 DOWNTO 0);
         soft_reset                       : IN STD_LOGIC;
         fifo_rst_rd_qd                   : IN STD_LOGIC;
         fifo_rst_rd_gp                   : IN STD_LOGIC;
         clk_1                            : IN STD_LOGIC;
         en_dskw_qd                       : IN STD_LOGIC;
         en_dskw_gp                       : IN STD_LOGIC;
         sel_gp_md                        : IN STD_LOGIC;
         rdskposdisp                      : IN STD_LOGIC;
         rdskchrp                         : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         align_det_sync                   : OUT STD_LOGIC;
         rd_align                         : OUT STD_LOGIC;
         audi                             : OUT STD_LOGIC_VECTOR(13 DOWNTO 0);
         audi_pre                         : OUT STD_LOGIC_VECTOR(13 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_rx_digi_prbs_ver
      PORT (
         rcvd_clk                         : IN STD_LOGIC;
         soft_reset                       : IN STD_LOGIC;
         scan_mode                        : IN STD_LOGIC;
         rprbs_clr_rslt_rx                : IN STD_LOGIC;
         rprbs_en_rx                      : IN STD_LOGIC;
         rpmadwidth_rx                    : IN STD_LOGIC;
         rpma_doublewidth_rx              : IN STD_LOGIC;
         rprbs_sel                        : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rall_one_dect_only               : IN STD_LOGIC;
         data_in                          : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
         sync_status                      : IN STD_LOGIC;
         verify_on                        : OUT STD_LOGIC;
         prbs_done                        : OUT STD_LOGIC;
         prbs_err                         : OUT STD_LOGIC;
         encdet_prbs                      : OUT STD_LOGIC;
         cid_en                           : IN STD_LOGIC;
         rcid_len                         : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         rcid_pattern                     : IN STD_LOGIC;
         prbs_err_lt                      : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_rx_digi_freqdet
      PORT (
         scan_mode                        : IN STD_LOGIC;
         ppmsel                           : IN STD_LOGIC_VECTOR(5 DOWNTO 0);
         fref                             : IN STD_LOGIC;
         fvcobyn                          : IN STD_LOGIC;
         pd                               : IN STD_LOGIC;
         rforcehigh                       : IN STD_LOGIC;
         rforcelow                        : IN STD_LOGIC;
         hard_reset                       : IN STD_LOGIC;
         ppm_cnt_reset                    : IN STD_LOGIC;
         gen2ngen1_indv                   : IN STD_LOGIC;
         gen2ngen1_bundle                 : IN STD_LOGIC;
         rindv_rx                         : IN STD_LOGIC;
         rauto_speed_ena                  : IN STD_LOGIC;
         rppm_gen1_2xcnt_en               : IN STD_LOGIC;
         eidle_exit                       : IN STD_LOGIC;
         rppm_post_eidle_del              : IN STD_LOGIC;
         freq_lock                        : OUT STD_LOGIC;
         ppm_cnt_latch                    : OUT STD_LOGIC_VECTOR(7 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_rx_digi_pcs_channel_testbus
      PORT (
         test_bus_in0                     : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         test_bus_in1                     : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         test_bus_in2                     : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         test_bus_in3                     : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         test_bus_in4                     : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         test_bus_in5                     : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         test_bus_in6                     : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         test_bus_in7                     : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         test_bus_in10                    : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         test_bus_in11                    : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         test_bus_in13                    : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         test_bus_in14                    : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         rtest_bus_sel                    : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         chnl_test_bus_out                : OUT STD_LOGIC_VECTOR(9 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_rx_digi_wordalign
      PORT (
         rst                              : IN STD_LOGIC;
         clk                              : IN STD_LOGIC;
         scan_mode                        : IN STD_LOGIC;
         wa_6g_en                         : IN STD_LOGIC;
         signal_detect                    : IN STD_LOGIC;
         rforce_sig_det_pcs               : IN STD_LOGIC;
         lpbk_en                          : IN STD_LOGIC;
         pmadwidth                        : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         dwidth                           : IN STD_LOGIC;
         gen2ngen1                        : IN STD_LOGIC;
         gen2ngen1_bundle                 : IN STD_LOGIC;
         rauto_speed_ena                  : IN STD_LOGIC;
         rfreq_sel                        : IN STD_LOGIC;
         rindv_rx                         : IN STD_LOGIC;
         pudi                             : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
         pudr                             : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
         rencdt_rising                    : IN STD_LOGIC;
         encdt                            : IN STD_LOGIC;
         comp_pat_porn                    : IN STD_LOGIC;
         comp_pat                         : IN STD_LOGIC_VECTOR(39 DOWNTO 0);
         comp_pat_size                    : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         resync_badcg_en                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         r8b10b_dec_ibm_en                : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         autobytealign_dis                : IN STD_LOGIC;
         rrxpcsbypass_en                  : IN STD_LOGIC;
         bitslip                          : IN STD_LOGIC;
         rlv_en                           : IN STD_LOGIC;
         max_rlv_sel                      : IN STD_LOGIC_VECTOR(5 DOWNTO 0);
         disable_rx_disp                  : IN STD_LOGIC;
         ib_invalid_code                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rpolinv_en                       : IN STD_LOGIC;
         rbitloc_rev_en                   : IN STD_LOGIC;
         rbyte_rev_en                     : IN STD_LOGIC;
         polinv_en                        : IN STD_LOGIC;
         bitloc_rev_en                    : IN STD_LOGIC;
         byte_rev_en                      : IN STD_LOGIC;
         sync_sm_dis                      : IN STD_LOGIC;
         prbs_en                          : IN STD_LOGIC;
         encdet_prbs                      : IN STD_LOGIC;
         a1a2_size                        : IN STD_LOGIC;
         knumber                          : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         gnumber                          : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         enumber                          : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         rosnumber                        : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         rosbased                         : IN STD_LOGIC;
         rkchar                           : IN STD_LOGIC;
         pipe_loose_sync                  : IN STD_LOGIC;  -- ww35.2008
         signal_detect_rcvdclk            : OUT STD_LOGIC;
         sudi                             : OUT STD_LOGIC_VECTOR(31 DOWNTO 0);
         sync_status                      : OUT STD_LOGIC;
         cg_syncpat                       : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         rlv                              : OUT STD_LOGIC;
         rlv_lt                           : OUT STD_LOGIC;
         a1a2_k1k2_flag                   : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
         kchar                            : OUT STD_LOGIC;
         wa_boundary                      : OUT STD_LOGIC_VECTOR(4 DOWNTO 0);
         sudi_pre                         : OUT STD_LOGIC_VECTOR(13 DOWNTO 0);
         adata                            : OUT STD_LOGIC_VECTOR(9 DOWNTO 0);
         adata_valid                      : OUT STD_LOGIC;
         rst1                             : OUT STD_LOGIC;
         testbus                          : OUT STD_LOGIC_VECTOR(9 DOWNTO 0);
         kcount                           : OUT STD_LOGIC_VECTOR(9 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_rx_digi_eii_module
      PORT (
         rcvd_clk                         : IN STD_LOGIC;
         rxpcsrst                         : IN STD_LOGIC;
         reidleinferenable                : IN STD_LOGIC;
         reidle_com_detect                : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rindv_rx                         : IN STD_LOGIC;
         riei_eios_priority_dis           : IN STD_LOGIC;
         rgen1_sigdet_ena                 : IN STD_LOGIC;
         rwait_count                      : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         eidleinfersel                    : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         skposdetect                      : IN STD_LOGIC;
         syncstatus                       : IN STD_LOGIC;
         sudi                             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         kflag                            : IN STD_LOGIC;
         kcount                           : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         eiosdetect_int                   : IN STD_LOGIC;
         inferred_rxvalid                 : IN STD_LOGIC;
         signaldetect                     : IN STD_LOGIC;
         gen2ngen1                        : IN STD_LOGIC;
         gen2ngen1_bundle                 : IN STD_LOGIC;
         pipe_loopbk                      : IN STD_LOGIC;
         rxelecidle_int                   : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_rx_digi_rxclk_ctl
      PORT (
         pld_rx_clk                       : IN STD_LOGIC;
         rcvd_clk_pma                     : IN STD_LOGIC;
         rcvd_clk0_pma                    : IN STD_LOGIC;
         tx_pma_clk                       : IN STD_LOGIC;
         refclk_pma                       : IN STD_LOGIC;
         fref                             : IN STD_LOGIC;
         clklow                           : IN STD_LOGIC;
         scan_mode                        : IN STD_LOGIC;
         gen2ngen1                        : IN STD_LOGIC;
         gen2ngen1_bundle                 : IN STD_LOGIC;
         rx_div2_sync_centrl              : IN STD_LOGIC;
         rx_div2_sync_quad_up             : IN STD_LOGIC;
         rx_div2_sync_quad_down           : IN STD_LOGIC;
         rrcvd_clk_sel                    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rclk_1_sel                       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rclk_2_sel                       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rrx_rd_clk_sel                   : IN STD_LOGIC;
         rxrst                            : IN STD_LOGIC;
         rindv_rx                         : IN STD_LOGIC;
         rdwidth_rx                       : IN STD_LOGIC;
         rfreerun_rx                      : IN STD_LOGIC;
         rauto_speed_ena                  : IN STD_LOGIC;
         rfreq_sel                        : IN STD_LOGIC;
         rrxpcsclkpwdn                    : IN STD_LOGIC;
         rmaster_rx                       : IN STD_LOGIC;
         rmaster_up_rx                    : IN STD_LOGIC;
         rself_sw_en_rx                   : IN STD_LOGIC;
         fref_muxed                       : OUT STD_LOGIC;
         clklow_muxed                     : OUT STD_LOGIC;
         rcvd_clk                         : OUT STD_LOGIC;
         clk_1_b                          : OUT STD_LOGIC;
         clk_2_b                          : OUT STD_LOGIC;
         rx_wr_clk                        : OUT STD_LOGIC;
         rx_rd_clk                        : OUT STD_LOGIC;
         rx_clk                           : OUT STD_LOGIC;
         rcvd_clk_pma_b                   : OUT STD_LOGIC;
         clk_2_b_raw                      : OUT STD_LOGIC;
         rx_wr_clk_raw                    : OUT STD_LOGIC;
         rx_rd_clk_raw                    : OUT STD_LOGIC;
         rx_div2_sync_out                 : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_rx_digi_comp_chnl_top
      PORT (
		 align_status	:	IN  STD_LOGIC;
		 align_status_sync	:	OUT  STD_LOGIC;
		 align_status_sync_0	:	IN  STD_LOGIC;
		 align_status_sync_2	:	IN  STD_LOGIC;
		 audi	:	IN  STD_LOGIC_VECTOR (13 DOWNTO 0);
		 audi_pre	:	IN  STD_LOGIC_VECTOR (13 DOWNTO 0);
		 cg_comp_rd_d_ch0	:	IN  STD_LOGIC;
		 cg_comp_rd_d_ch1	:	IN  STD_LOGIC;
		 cg_comp_rd_d_ch2	:	IN  STD_LOGIC;
		 cg_comp_rd_d_ch3	:	IN  STD_LOGIC;
		 cg_comp_rd_d_out	:	OUT  STD_LOGIC;
		 cg_comp_wr_ch0	:	IN  STD_LOGIC;
		 cg_comp_wr_ch1	:	IN  STD_LOGIC;
		 cg_comp_wr_ch2	:	IN  STD_LOGIC;
		 cg_comp_wr_ch3	:	IN  STD_LOGIC;
		 cg_comp_wr_out	:	OUT  STD_LOGIC;
		 clk_1	:	IN  STD_LOGIC;
		 clk_2	:	IN  STD_LOGIC;
		 cmpfifourst	:	IN  STD_LOGIC;
		 comp_curr_st	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 cudi	:	OUT  STD_LOGIC_VECTOR (31 DOWNTO 0);
		 cudi_valid	:	OUT  STD_LOGIC;
		 del_cond_met_0	:	IN  STD_LOGIC;
		 del_cond_met_out	:	OUT  STD_LOGIC;
		 dskwclksel	:	IN  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 fifo_cnt	:	OUT  STD_LOGIC_VECTOR (4 DOWNTO 0);
		 fifo_ovr_0	:	IN  STD_LOGIC;
		 fifo_ovr_out	:	OUT  STD_LOGIC;
		 fifo_rd_in_comp_0	:	IN  STD_LOGIC;
		 fifo_rd_in_comp_2	:	IN  STD_LOGIC;
		 fifo_rd_out_comp	:	OUT  STD_LOGIC;
		 gen2ngen1	:	IN  STD_LOGIC;
		 gen2ngen1_bundle	:	IN  STD_LOGIC;
		 hard_reset	:	IN  STD_LOGIC;
		 inferred_rxvalid	:	IN  STD_LOGIC;
		 insert_incomplete_0	:	IN  STD_LOGIC;
		 insert_incomplete_out	:	OUT  STD_LOGIC;
		 is_lane0	:	IN  STD_LOGIC;
		 latency_comp_0	:	IN  STD_LOGIC;
		 latency_comp_out	:	OUT  STD_LOGIC;
		 rauto_speed_ena	:	IN  STD_LOGIC;
		 rclkcmpinsertpad	:	IN  STD_LOGIC;
		 rclkcmpsq1n	:	IN  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 rclkcmpsq1p	:	IN  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 rclkcmpsqmd	:	IN  STD_LOGIC;
		 rcmpfifourst	:	IN  STD_LOGIC;
		 rdel_threshold	:	IN  STD_LOGIC_VECTOR (4 DOWNTO 0);
		 rdenable	:	IN  STD_LOGIC;
		 rdfifo_almost_empty	:	OUT  STD_LOGIC;
		 rdfifo_almost_full	:	OUT  STD_LOGIC;
		 rdfifo_empty	:	OUT  STD_LOGIC;
		 rdfifo_full	:	OUT  STD_LOGIC;
		 rdwidth_rx	:	IN  STD_LOGIC;
		 rempty_threshold	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 rev_loop_data	:	OUT  STD_LOGIC_VECTOR (19 DOWNTO 0);
		 rfreq_sel	:	IN  STD_LOGIC;
		 rfull_threshold	:	IN  STD_LOGIC_VECTOR (4 DOWNTO 0);
		 rgenericfifo	:	IN  STD_LOGIC;
		 rindv_rx	:	IN  STD_LOGIC;
		 rins_threshold	:	IN  STD_LOGIC_VECTOR (4 DOWNTO 0);
		 rmatchen	:	IN  STD_LOGIC;
		 rrx_pipe_enable	:	IN  STD_LOGIC;
		 rskpsetbased	:	IN  STD_LOGIC;
		 rstart_threshold	:	IN  STD_LOGIC_VECTOR (2 DOWNTO 0);
		 rtruebac2bac	:	IN  STD_LOGIC;
		 rwa_6g_en	:	IN  STD_LOGIC;
		 scan_mode	:	IN  STD_LOGIC;
		 skpos_det	:	OUT  STD_LOGIC;
		 soft_reset	:	IN  STD_LOGIC;
		 sudi	:	IN  STD_LOGIC_VECTOR (27 DOWNTO 0);
		 sudi_pre	:	IN  STD_LOGIC_VECTOR (13 DOWNTO 0);
		 sync_status	:	IN  STD_LOGIC;
		 wrenable	:	IN  STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_rx_digi_dec_chnl_top
      PORT (
         rst                              : IN STD_LOGIC;
         clk_2                            : IN STD_LOGIC;
         cascaded_8b10b_en                : IN STD_LOGIC;
         r8b10b_dec_ibm_en                : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         data_in                          : IN STD_LOGIC_VECTOR(31 DOWNTO 0);
         data_in_valid                    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         renpolinv                        : IN STD_LOGIC;
         rerr_flags_sel                   : IN STD_LOGIC;
         polinv                           : IN STD_LOGIC;
         rrxpcsbypass_en                  : IN STD_LOGIC;
         dec_data                         : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         disp_err_delay                   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         disp_val_delay                   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         sync_resync_delay                : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         dec_data_valid                   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         dec_ctl                          : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         invalid_code_delay               : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         ovr_undflow                      : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
         tenb_data                        : OUT STD_LOGIC_VECTOR(19 DOWNTO 0);
         rlb_data                         : OUT STD_LOGIC_VECTOR(19 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_rx_digi_cdr_ctrl
      PORT (
         rcvd_clk                         : IN STD_LOGIC;
         rxpcs_reset_int                  : IN STD_LOGIC;
         rcdr_ctrl_en                     : IN STD_LOGIC;
         rcid_en                          : IN STD_LOGIC;
         rrxvalid_mask                    : IN STD_LOGIC;
         rwait_count                      : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         rmask_count                      : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         rindv_rx                         : IN STD_LOGIC;
         pld_ltr                          : IN STD_LOGIC;
         pipe_loopbk                      : IN STD_LOGIC;
         adata                            : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         adata_valid                      : IN STD_LOGIC;
         inferred_rxvalid                 : OUT STD_LOGIC;
         eiosdetect_int                   : OUT STD_LOGIC;
         gen2ngen1                        : IN STD_LOGIC;
         gen2ngen1_bundle                 : IN STD_LOGIC;
         eidle_exit                       : OUT STD_LOGIC;
         sigdet                           : IN STD_LOGIC;
         early_eios                       : OUT STD_LOGIC;
         ltr                              : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_rx_digi_iq_pipe_rx
      PORT (
         clk_2_b_raw                      : IN STD_LOGIC;
         rx_wr_clk_raw                    : IN STD_LOGIC;
         rx_rd_clk_raw                    : IN STD_LOGIC;
         rxrst                            : IN STD_LOGIC;
         soft_reset_rclk1                 : IN STD_LOGIC;
         soft_reset_wclk1                 : IN STD_LOGIC;
         rx_div2_sync_in_centrl           : IN STD_LOGIC;
         rx_div2_sync_in_pipe_quad_up     : IN STD_LOGIC;
         rx_div2_sync_in_pipe_quad_down   : IN STD_LOGIC;
         reset_pc_ptrs_in_centrl          : IN STD_LOGIC;
         reset_pc_ptrs_in_pipe_quad_up    : IN STD_LOGIC;
         reset_pc_ptrs_in_pipe_quad_down  : IN STD_LOGIC;
         wr_enable_in_centrl              : IN STD_LOGIC;
         wr_enable_in_pipe_quad_up        : IN STD_LOGIC;
         wr_enable_in_pipe_quad_down      : IN STD_LOGIC;
         rd_enable_in_centrl              : IN STD_LOGIC;
         rd_enable_in_pipe_quad_up        : IN STD_LOGIC;
         rd_enable_in_pipe_quad_down      : IN STD_LOGIC;
         rx_we_in_centrl                  : IN STD_LOGIC;
         rx_we_in_pipe_quad_up            : IN STD_LOGIC;
         rx_we_in_pipe_quad_down          : IN STD_LOGIC;
         speed_change_in_centrl           : IN STD_LOGIC;
         speed_change_in_pipe_quad_up     : IN STD_LOGIC;
         speed_change_in_pipe_quad_down   : IN STD_LOGIC;
         rmaster_rx                       : IN STD_LOGIC;
         rmaster_up_rx                    : IN STD_LOGIC;
         rpipeline_bypass_rx              : IN STD_LOGIC;
         rfreerun_rx                      : IN STD_LOGIC;
         rx_div2_sync_out_pipe            : OUT STD_LOGIC;
         rx_we_out_pipe                   : OUT STD_LOGIC;
         wr_enable_out_pipe               : OUT STD_LOGIC;
         rd_enable_out_pipe               : OUT STD_LOGIC;
         reset_pc_ptrs_out_pipe           : OUT STD_LOGIC;
         speed_change_out_pipe            : OUT STD_LOGIC
      );
   END COMPONENT;
   
   
   -- new signals in this module for bundling and auto speed
   SIGNAL clk_2_b_raw                        : STD_LOGIC;
   SIGNAL rx_wr_clk_raw                      : STD_LOGIC;
   SIGNAL rx_rd_clk_raw                      : STD_LOGIC;
   SIGNAL nc_new_bundle1                     : STD_LOGIC;
   SIGNAL nc_new_bundle2                     : STD_LOGIC;
   SIGNAL nc_new_bundle3                     : STD_LOGIC;
   SIGNAL rx_we_out_testbus                  : STD_LOGIC;
   SIGNAL config_sel_nc                      : STD_LOGIC;
   
   -- Wiring Section
   -- to rcv_sm in centrl_macro
   SIGNAL rcvd_clk                           : STD_LOGIC;		-- Recovered data clock
   SIGNAL rx_rd_clk                          : STD_LOGIC;
   SIGNAL rx_data_9_rc                       : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- rx data bit 9 from rx_ctrl 
   -- when 10-bit code-group is passing 
   -- over XGMII
   SIGNAL rx_data_19_rc                      : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- rx data bit 19 from rx_ctrl 
   -- when 10-bit code-group is passing 
   -- over XGMII
   SIGNAL rx_control_rc_16                   : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- XGMII rx control from rx_ctrl
   SIGNAL sync_status_st                     : STD_LOGIC;		-- Indicate that this lane is 
   -- now synchronized
   SIGNAL sudi                               : STD_LOGIC_VECTOR(31 DOWNTO 0);		-- Synchronized code group + parity 
   -- error status from sync_chnl_top
   SIGNAL sudi_pre                           : STD_LOGIC_VECTOR(13 DOWNTO 0);		-- 13-bit data one cycle earlier
   SIGNAL cudi                               : STD_LOGIC_VECTOR(31 DOWNTO 0);		-- Clock-compensated code group 
   -- + parity
   -- error status from sync_chnl_top
   SIGNAL rx_data_dt                         : STD_LOGIC_VECTOR(15 DOWNTO 0);		-- 2 decoded 8-bit rx data
   SIGNAL rx_ctl_dt                          : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- 2 decoded rx controls
   SIGNAL tenb_data                          : STD_LOGIC_VECTOR(19 DOWNTO 0);		-- rx 20-bit code group bus used when 
   -- ENDEC is 1'b0
   SIGNAL audi                               : STD_LOGIC_VECTOR(13 DOWNTO 0);		-- Aligned code group + parity error 
   -- status from dskw_top
   SIGNAL audi_pre                           : STD_LOGIC_VECTOR(13 DOWNTO 0);
   -- comma is detected in sync_chnl_top
   SIGNAL disable_fifo_rd                    : STD_LOGIC;		-- disable_fifo_rd from this lane
   SIGNAL disable_fifo_wr                    : STD_LOGIC;		-- disable_fifo_wr from this lane
   -- Indicate that this lane is now 
   -- synchronized
   -- decoded 8-bit rx data
   -- decoded rx control
   -- indicate that dec_data/dec_ctl 
   -- is either not valid or having 
   -- disparity error
   SIGNAL invalid_code_delay                 : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- indicate that dec_data/dec_ctl is 
   -- having diparity error
   -- Status shows that the self test 
   -- checking is done
   -- Status shows that the selftest is 
   -- successful
   -- When the self test fails, this 
   -- records the first byte that error 
   -- occurs to.
   -- When the self test fails, this 
   -- records the first byte that error 
   -- occurs to.
   -- Indicate that prbs verification is 
   -- done
   -- Indicate that prbs verification is 
   -- OK - latched version, cleared when 
   -- ENBIST is cleared.
   SIGNAL prbs_err                           : STD_LOGIC;
   -- signal_detect to status pin/bit for
   -- PMA-only operation
   SIGNAL signal_detect                      : STD_LOGIC;
   SIGNAL disp_err_delay                     : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL disp_val_delay                     : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL sync_resync_delay                  : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL high_dec_data_valid                : STD_LOGIC;
   SIGNAL soft_reset_int                     : STD_LOGIC;
   SIGNAL cudi_valid                         : STD_LOGIC;
   SIGNAL encdet_prbs                        : STD_LOGIC;
   SIGNAL ovr_undflow                        : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- Signals over or underflow
   -- Merged to save bit in the synchronous 
   -- datapath
   SIGNAL clk_1_b                            : STD_LOGIC;
   -- 10 bit data from RX rate matching 
   -- FIFO, reverse loopback
   SIGNAL rxd_lpbk                           : STD_LOGIC_VECTOR(39 DOWNTO 0);
   SIGNAL rx_wr_clk                          : STD_LOGIC;
   
   SIGNAL fref_muxed                         : STD_LOGIC;
   SIGNAL clklow_muxed                       : STD_LOGIC;
   SIGNAL skposdetect                        : STD_LOGIC;
   
   SIGNAL ausm_cs                            : STD_LOGIC_VECTOR(3 DOWNTO 0);
   
   -- Wire for test bus
   SIGNAL prbs_verify_on                     : STD_LOGIC;
   SIGNAL word_align_testbus                 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL bist_cur_state                     : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL wr_enable2                         : STD_LOGIC;
   SIGNAL rd_enable2                         : STD_LOGIC;
   SIGNAL wptr_bin                           : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rptr_bin                           : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL comp_fifo_cnt                      : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL ppm_cnt                            : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL comp_curr_st                       : STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   SIGNAL kcount                             : STD_LOGIC_VECTOR(9 DOWNTO 0);
   
   --shawn: unused wire to fix open connections ()
   SIGNAL rev_loop_data_enc                  : STD_LOGIC_VECTOR(19 DOWNTO 0);		-- unused from encoder 
   SIGNAL signal_detect_rcvdclk_dummy        : STD_LOGIC;
   
   --shawn: implicit declaration
   SIGNAL rst1                               : STD_LOGIC;
   
   -- S. Park 3/13/08 - New wires added for connectivity to comp_chnl_top
   
   -- S. Park 3/21/08 - Added wires for XAUI compliance
   
   --assign soft_reset_int   = (scan_mode) ? 1'b0 : rxpcs_rst ;
   
   -- WA
   SIGNAL adata                              : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL adata_valid                        : STD_LOGIC;
   SIGNAL kchar                              : STD_LOGIC;
   -- CDR control block
   SIGNAL eiosdetect_int                     : STD_LOGIC;
   SIGNAL inferred_rxvalid                   : STD_LOGIC;
   SIGNAL eidle_exit                         : STD_LOGIC;
   SIGNAL dec_data_valid_temp                : STD_LOGIC_VECTOR(1 DOWNTO 0);		--shawn - VHDL translation                          
   -- X-HDL generated signals

   SIGNAL xhdl65 : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL xhdl66 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL xhdl67 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL xhdl68 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL xhdl69 : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL xhdl70 : STD_LOGIC_VECTOR(19 DOWNTO 0);
   SIGNAL xhdl71 : STD_LOGIC_VECTOR(27 DOWNTO 0);
   SIGNAL xhdl72 : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL xhdl73 : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL xhdl74 : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL xhdl75 : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL xhdl76 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL xhdl77 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL xhdl78 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL xhdl79 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL xhdl80 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL xhdl81 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL xhdl82 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL xhdl83 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL xhdl84 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL soft_reset_rclk1_xhdl58            : STD_LOGIC;
   SIGNAL fifo_rd_out_comp_xhdl22            : STD_LOGIC;
   SIGNAL rxd_xhdl51                         : STD_LOGIC_VECTOR(63 DOWNTO 0);
   SIGNAL rev_loop_data_xhdl41               : STD_LOGIC_VECTOR(19 DOWNTO 0);
   SIGNAL rx_clk_xhdl45                      : STD_LOGIC;
   SIGNAL bisterr_xhdl6                      : STD_LOGIC;
   SIGNAL cg_comma_xhdl8                     : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL clk_2_b_xhdl12                     : STD_LOGIC;
   SIGNAL rcvd_clk_pma_b_xhdl34              : STD_LOGIC;
   SIGNAL align_status_sync_xhdl2            : STD_LOGIC;
   SIGNAL dec_data_valid_xhdl13              : STD_LOGIC;
   SIGNAL running_disp_xhdl44                : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL selftest_done_xhdl55               : STD_LOGIC;
   SIGNAL selftest_err_xhdl56                : STD_LOGIC;
   SIGNAL err_data_xhdl20                    : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL err_ctl_xhdl19                     : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL prbs_done_xhdl32                   : STD_LOGIC;
   SIGNAL prbs_err_lt_xhdl33                 : STD_LOGIC;
   SIGNAL signal_detect_out_xhdl57           : STD_LOGIC;
   SIGNAL align_det_sync_xhdl1               : STD_LOGIC;
   SIGNAL rd_align_xhdl35                    : STD_LOGIC;
   SIGNAL bistdone_xhdl5                     : STD_LOGIC;
   SIGNAL rlv_xhdl42                         : STD_LOGIC;
   SIGNAL rlv_lt_xhdl43                      : STD_LOGIC;
   SIGNAL almost_fl_rmf_xhdl3                : STD_LOGIC;
   SIGNAL full_rmf_xhdl24                    : STD_LOGIC;
   SIGNAL almost_mt_rmf_xhdl4                : STD_LOGIC;
   SIGNAL empty_rmf_xhdl17                   : STD_LOGIC;
   SIGNAL freq_lock_xhdl23                   : STD_LOGIC;
   SIGNAL full_rx_xhdl25                     : STD_LOGIC;
   SIGNAL empty_rx_xhdl18                    : STD_LOGIC;
   SIGNAL a1a2_k1k2_flag_xhdl0               : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL byteord_flag_xhdl7                 : STD_LOGIC;
   SIGNAL chnl_test_bus_out_xhdl11           : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL rx_pipe_soft_reset_xhdl48          : STD_LOGIC;
   SIGNAL phystatus_xhdl30                   : STD_LOGIC;
   SIGNAL rxvalid_xhdl54                     : STD_LOGIC;
   SIGNAL rxstatus_xhdl53                    : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL pipe_data_xhdl31                   : STD_LOGIC_VECTOR(63 DOWNTO 0);
   SIGNAL speed_change_xhdl59                : STD_LOGIC;
   SIGNAL rx_div2_sync_out_pipe_up_xhdl47    : STD_LOGIC;
   SIGNAL rx_we_out_pipe_up_xhdl50           : STD_LOGIC;
   SIGNAL wr_enable_out_pipe_up_xhdl64       : STD_LOGIC;
   SIGNAL rd_enable_out_pipe_up_xhdl37       : STD_LOGIC;
   SIGNAL reset_pc_ptrs_out_pipe_up_xhdl40   : STD_LOGIC;
   SIGNAL speed_change_out_pipe_up_xhdl61    : STD_LOGIC;
   SIGNAL rx_div2_sync_out_pipe_down_xhdl46  : STD_LOGIC;
   SIGNAL rx_we_out_pipe_down_xhdl49         : STD_LOGIC;
   SIGNAL wr_enable_out_pipe_down_xhdl63     : STD_LOGIC;
   SIGNAL rd_enable_out_pipe_down_xhdl36     : STD_LOGIC;
   SIGNAL reset_pc_ptrs_out_pipe_down_xhdl39 : STD_LOGIC;
   SIGNAL speed_change_out_pipe_down_xhdl60  : STD_LOGIC;
   SIGNAL dis_pc_byte_xhdl15                 : STD_LOGIC;
   SIGNAL reset_pc_ptrs_xhdl38               : STD_LOGIC;
   SIGNAL pcie_switch_xhdl29                 : STD_LOGIC;
   SIGNAL rxelecidle_int_xhdl52              : STD_LOGIC;
   SIGNAL early_eios_xhdl16                  : STD_LOGIC;
   SIGNAL ltr_xhdl28                         : STD_LOGIC;
   SIGNAL wa_boundary_xhdl62                 : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL cg_comp_rd_d_out_xhdl9             : STD_LOGIC;
   SIGNAL cg_comp_wr_out_xhdl10              : STD_LOGIC;
   SIGNAL del_cond_met_out_xhdl14            : STD_LOGIC;
   SIGNAL fifo_ovr_out_xhdl21                : STD_LOGIC;
   SIGNAL latency_comp_out_xhdl27            : STD_LOGIC;
   SIGNAL insert_incomplete_out_xhdl26       : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   soft_reset_rclk1 <= soft_reset_rclk1_xhdl58;
   fifo_rd_out_comp <= fifo_rd_out_comp_xhdl22;
   rxd <= rxd_xhdl51;
   rev_loop_data <= rev_loop_data_xhdl41;
   rx_clk <= rx_clk_xhdl45;
   bisterr <= bisterr_xhdl6;
   cg_comma <= cg_comma_xhdl8;
   clk_2_b <= clk_2_b_xhdl12;
   rcvd_clk_pma_b <= rcvd_clk_pma_b_xhdl34;
   align_status_sync <= align_status_sync_xhdl2;
   dec_data_valid <= dec_data_valid_xhdl13;
   running_disp <= running_disp_xhdl44;
   selftest_done <= selftest_done_xhdl55;
   selftest_err <= selftest_err_xhdl56;
   err_data <= err_data_xhdl20;
   err_ctl <= err_ctl_xhdl19;
   prbs_done <= prbs_done_xhdl32;
   prbs_err_lt <= prbs_err_lt_xhdl33;
   signal_detect_out <= signal_detect_out_xhdl57;
   align_det_sync <= align_det_sync_xhdl1;
   rd_align <= rd_align_xhdl35;
   bistdone <= bistdone_xhdl5;
   rlv <= rlv_xhdl42;
   rlv_lt <= rlv_lt_xhdl43;
   almost_fl_rmf <= almost_fl_rmf_xhdl3;
   full_rmf <= full_rmf_xhdl24;
   almost_mt_rmf <= almost_mt_rmf_xhdl4;
   empty_rmf <= empty_rmf_xhdl17;
   freq_lock <= freq_lock_xhdl23;
   full_rx <= full_rx_xhdl25;
   empty_rx <= empty_rx_xhdl18;
   a1a2_k1k2_flag <= a1a2_k1k2_flag_xhdl0;
   byteord_flag <= byteord_flag_xhdl7;
   chnl_test_bus_out <= chnl_test_bus_out_xhdl11;
   rx_pipe_soft_reset <= rx_pipe_soft_reset_xhdl48;
   phystatus <= phystatus_xhdl30;
   rxvalid <= rxvalid_xhdl54;
   rxstatus <= rxstatus_xhdl53;
   pipe_data <= pipe_data_xhdl31;
   speed_change <= speed_change_xhdl59;
   rx_div2_sync_out_pipe_up <= rx_div2_sync_out_pipe_up_xhdl47;
   rx_we_out_pipe_up <= rx_we_out_pipe_up_xhdl50;
   wr_enable_out_pipe_up <= wr_enable_out_pipe_up_xhdl64;
   rd_enable_out_pipe_up <= rd_enable_out_pipe_up_xhdl37;
   reset_pc_ptrs_out_pipe_up <= reset_pc_ptrs_out_pipe_up_xhdl40;
   speed_change_out_pipe_up <= speed_change_out_pipe_up_xhdl61;
   rx_div2_sync_out_pipe_down <= rx_div2_sync_out_pipe_down_xhdl46;
   rx_we_out_pipe_down <= rx_we_out_pipe_down_xhdl49;
   wr_enable_out_pipe_down <= wr_enable_out_pipe_down_xhdl63;
   rd_enable_out_pipe_down <= rd_enable_out_pipe_down_xhdl36;
   reset_pc_ptrs_out_pipe_down <= reset_pc_ptrs_out_pipe_down_xhdl39;
   speed_change_out_pipe_down <= speed_change_out_pipe_down_xhdl60;
   dis_pc_byte <= dis_pc_byte_xhdl15;
   reset_pc_ptrs <= reset_pc_ptrs_xhdl38;
   pcie_switch <= pcie_switch_xhdl29;
   rxelecidle_int <= rxelecidle_int_xhdl52;
   early_eios <= early_eios_xhdl16;
   ltr <= ltr_xhdl28;
   wa_boundary <= wa_boundary_xhdl62;
   cg_comp_rd_d_out <= cg_comp_rd_d_out_xhdl9;
   cg_comp_wr_out <= cg_comp_wr_out_xhdl10;
   del_cond_met_out <= del_cond_met_out_xhdl14;
   fifo_ovr_out <= fifo_ovr_out_xhdl21;
   latency_comp_out <= latency_comp_out_xhdl27;
   insert_incomplete_out <= insert_incomplete_out_xhdl26;
   dec_data <= rx_data_dt(7 DOWNTO 0);
   dec_ctl <= rx_ctl_dt(0);
   sync_status <= sync_status_st;
   signal_detect <= sigdetni;
   soft_reset_int <= rxpcs_rst;
   
   -- S. Park 2/8/08 - New wires for new PPM Detector CRAMs
   
   -- RX PIPE interface clock
   --assign rx_pipe_clk = rx_rd_clk;
   rx_pipe_clk <= rx_wr_clk;
   
   -- Clock selection module
   
   
   rxclk_ctl_1 : stratixiv_hssi_rx_digi_rxclk_ctl
      PORT MAP (
         pld_rx_clk              => pld_rx_clk,
         rcvd_clk_pma            => rcvd_clk_pma,
         rcvd_clk0_pma           => rcvd_clk0_pma,
         tx_pma_clk              => tx_pma_clk,
         refclk_pma              => refclk_pma,
         fref                    => fref,
         clklow                  => clklow,
         scan_mode               => scan_mode,
         gen2ngen1               => gen2ngen1,
         gen2ngen1_bundle        => gen2ngen1_bundle,
         rx_div2_sync_centrl     => rx_div2_sync_in_centrl,
         rx_div2_sync_quad_up    => rx_div2_sync_in_quad_up,
         rx_div2_sync_quad_down  => rx_div2_sync_in_quad_down,
         rrcvd_clk_sel           => rrcvd_clk_sel,
         rclk_1_sel              => rclk_1_sel,
         rclk_2_sel              => rclk_2_sel,
         rrx_rd_clk_sel          => rrx_rd_clk_sel,
         rxrst                   => rxpcs_rst,
         rindv_rx                => rindv_rx,
         rdwidth_rx              => rdwidth_rx,
         rfreerun_rx             => rfreerun_rx,
         rauto_speed_ena         => rauto_speed_ena,
         rfreq_sel               => rfreq_sel,
         rrxpcsclkpwdn           => rrxpcsclkpwdn,
         rmaster_rx              => rmaster_rx,
         rmaster_up_rx           => rmaster_up_rx,
         rself_sw_en_rx          => rself_sw_en_rx,
         fref_muxed              => fref_muxed,
         clklow_muxed            => clklow_muxed,
         rcvd_clk                => rcvd_clk,
         clk_1_b                 => clk_1_b,
         clk_2_b                 => clk_2_b_xhdl12,
         rx_wr_clk               => rx_wr_clk,
         rx_rd_clk               => rx_rd_clk,
         rx_clk                  => rx_clk_xhdl45,
         rcvd_clk_pma_b          => rcvd_clk_pma_b_xhdl34,
         clk_2_b_raw             => clk_2_b_raw,
         rx_wr_clk_raw           => rx_wr_clk_raw,
         rx_rd_clk_raw           => rx_rd_clk_raw,
         rx_div2_sync_out        => nc_new_bundle1
      );
   
   -- Word alignment module
   
   
   xhdl65 <= (rpma_doublewidth_rx & rpmadwidth_rx);
   xhdl66 <= ("00" & rknumber);
   xhdl67 <= ("00" & rgnumber);
   xhdl68 <= ("0000" & renumber);
   xhdl69 <= ("00" & rosnumber);
   wordalign_1 : stratixiv_hssi_rx_digi_wordalign
      PORT MAP (
         rst                    => soft_reset_int,
         clk                    => rcvd_clk,
         scan_mode              => scan_mode,
         wa_6g_en               => rwa_6g_en,
         signal_detect          => signal_detect,
         rforce_sig_det_pcs     => rforce_sig_det_pcs,
         lpbk_en                => rlp20ben,
         pmadwidth              => xhdl65,
         dwidth                 => rdwidth_rx,
         gen2ngen1              => gen2ngen1,
         gen2ngen1_bundle       => gen2ngen1_bundle,
         rauto_speed_ena        => rauto_speed_ena,
         rfreq_sel              => rfreq_sel,
         rindv_rx               => rindv_rx,
         pudi                   => pudi,
         pudr                   => txlp20b,
         rencdt_rising          => rencdt_rising,
         encdt                  => encdt,
         comp_pat_porn          => rcomp_pat_porn,
         comp_pat               => rcomp_pat,
         comp_pat_size          => rcomp_size,
         resync_badcg_en        => resync_badcg_en,
         r8b10b_dec_ibm_en      => r8b10b_dec_ibm_en,
         autobytealign_dis      => rautobtalg_dis,
         bitslip                => bitslip,
         rlv_en                 => rrlv_en,
         max_rlv_sel            => rrundisp,
         disable_rx_disp        => rdis_rx_disp,
         ib_invalid_code        => rib_inv_cd,
         rpolinv_en             => rbysync_polinv_en,
         rbitloc_rev_en         => rbitloc_rev_en,
         rbyte_rev_en           => rbyte_rev_en,
         polinv_en              => polinv_rx,
         bitloc_rev_en          => bitloc_rev_en,
         byte_rev_en            => byte_rev_en,
         sync_sm_dis            => rsync_sm_dis,
         prbs_en                => rprbsen_rx,
         encdet_prbs            => encdet_prbs,
         a1a2_size              => a1a2_size,
         knumber                => xhdl66,
         gnumber                => xhdl67,
         enumber                => xhdl68,
         rosnumber              => xhdl69,
         rosbased               => rosbased,
         rkchar                 => rkchar,
         kchar                  => kchar,
         signal_detect_rcvdclk  => signal_detect_rcvdclk_dummy,
         sudi                   => sudi,
         sync_status            => sync_status_st,
         cg_syncpat             => cg_comma_xhdl8,
         rlv                    => rlv_xhdl42,
         rlv_lt                 => rlv_lt_xhdl43,
         a1a2_k1k2_flag         => a1a2_k1k2_flag_xhdl0,
         sudi_pre               => sudi_pre,
         testbus                => word_align_testbus,
         kcount                 => kcount,		--new brought out from PIPE sync SM
         rrxpcsbypass_en        => rrxpcsbypass_en,
         adata                  => adata,		-- CDR control
         adata_valid            => adata_valid,
         rst1                   => rst1,
         pipe_loose_sync        => pcs_wrapback_in(60),  
         wa_boundary            => wa_boundary_xhdl62
      );
   
   -- De-skew FIFO module
   
   
   dskw_fifo_1 : stratixiv_hssi_rx_digi_dskw_fifo
      PORT MAP (
         rcvd_clk        => rcvd_clk,
         -- 01/07/05 VC: Increased bus width from 13 to 14
         --                        .sudi (sudi[12:0]),
         sudi            => sudi(13 DOWNTO 0),
         soft_reset      => soft_reset_int,
         fifo_rst_rd_qd  => fifo_rst_rd_qd,
         fifo_rst_rd_gp  => fifo_rst_rd_gp,
         clk_1           => clk_1_b,
         en_dskw_qd      => en_dskw_qd,
         en_dskw_gp      => en_dskw_gp,
         sel_gp_md       => sel_gp_md,
         rdskposdisp     => rdskposdisp,
         rdskchrp        => rdskchrp,
         align_det_sync  => align_det_sync_xhdl1,
         rd_align        => rd_align_xhdl35,
         audi            => audi,
         audi_pre        => audi_pre
      );
   
   -- PRBS verifier module
   
   
   xhdl70 <= (sudi(25 DOWNTO 16) & sudi(9 DOWNTO 0));
   prbs_ver_1 : stratixiv_hssi_rx_digi_prbs_ver
      PORT MAP (
         rcvd_clk             => rcvd_clk,
         soft_reset           => soft_reset_int,
         scan_mode            => scan_mode,
         rprbs_clr_rslt_rx    => rprbs_clr_rslt_rx,
         rprbs_en_rx          => rprbsen_rx,
         rpmadwidth_rx        => rpmadwidth_rx,
         rpma_doublewidth_rx  => rpma_doublewidth_rx,
         rprbs_sel            => rprbs_sel,
         rall_one_dect_only   => rall_one_dect_only,
         verify_on            => prbs_verify_on,
         cid_en               => prbs_cid_en,
         rcid_len             => rcid_len_rx,
         rcid_pattern         => rcid_pattern_rx,
         sync_status          => sudi(11),
         data_in              => xhdl70,
         prbs_done            => prbs_done_xhdl32,
         prbs_err             => prbs_err,
         encdet_prbs          => encdet_prbs,
         prbs_err_lt          => prbs_err_lt_xhdl33
      );
   
   -- Rate matching module
   
   
   -- 01/07/05 VC: Increased bus width from 26 to 28
   --              to pass running disparity polarity bits
   --                             .sudi ({sudi[28:16], sudi[12:0]}),
   xhdl71 <= (sudi(29 DOWNTO 16) & sudi(13 DOWNTO 0));
   comp_chnl_top_1 : stratixiv_hssi_rx_digi_comp_chnl_top
      PORT MAP (
         hard_reset             => hard_reset,
         soft_reset             => soft_reset_int,
         cmpfifourst            => cmpfifourst,
         rcmpfifourst           => rcmpfifourst,
         scan_mode              => scan_mode,
         clk_1                  => clk_1_b,
         clk_2                  => clk_2_b_xhdl12,
         sudi                   => xhdl71,
         sudi_pre               => sudi_pre,
         audi                   => audi,
         audi_pre               => audi_pre,
         align_status           => align_status,
         align_status_sync_0    => align_status_sync_0,
         align_status_sync_2    => align_status_sync_2,
         sync_status            => sync_status_st,
         inferred_rxvalid       => inferred_rxvalid,
         -- S. Park 3/21/08 - Removed below two ports
         -- .disable_fifo_rd_0 (disable_fifo_rd_0),
         -- .disable_fifo_wr_0 (disable_fifo_wr_0),
         is_lane0               => is_lane0,
         rdfifo_almost_full     => almost_fl_rmf_xhdl3,
         rdfifo_full            => full_rmf_xhdl24,
         rdfifo_almost_empty    => almost_mt_rmf_xhdl4,
         rdfifo_empty           => empty_rmf_xhdl17,
         dskwclksel             => dskwclksel,
         rmatchen               => rmatchen,
         rwa_6g_en              => rwa_6g_en,
         rgenericfifo           => rgenericfifo,
         rdenable               => rdenable_rmf,
         wrenable               => wrenable_rmf,
         fifo_rd_in_comp_0      => fifo_rd_in_comp_0,
         fifo_rd_in_comp_2      => fifo_rd_in_comp_2,
         rskpsetbased           => rskpsetbased,
         rtruebac2bac           => rtruebac2bac,
         rclkcmpsqmd            => rclkcmpsqmd,
         rclkcmpsq1p            => rclkcmpsq1p,
         rclkcmpsq1n            => rclkcmpsq1n,
         rclkcmpinsertpad       => rclkcmpinsertpad,
         rrx_pipe_enable        => rclkcmp_pipe_en,
         rdwidth_rx             => rdwidth_rx,
         gen2ngen1              => gen2ngen1,
         gen2ngen1_bundle       => gen2ngen1_bundle,
         rauto_speed_ena        => rauto_speed_ena,
         rfreq_sel              => rfreq_sel,
         rindv_rx               => rindv_rx,
         fifo_rd_out_comp       => fifo_rd_out_comp_xhdl22,
         -- S. Park 3/21/08 - Removed below two ports
         -- .disable_fifo_rd (disable_fifo_rd),
         -- .disable_fifo_wr (disable_fifo_wr),
         align_status_sync      => align_status_sync_xhdl2,
         cudi                   => cudi,
         rev_loop_data          => rev_loop_data_enc,
         comp_curr_st           => comp_curr_st,
         cudi_valid             => cudi_valid,
         fifo_cnt               => comp_fifo_cnt,
         rstart_threshold       => rstart_threshold,
         rins_threshold         => rins_threshold,
         rdel_threshold         => rdel_threshold,
         rfull_threshold        => rfull_threshold,
         rempty_threshold       => rempty_threshold,
         --Eidle Infer
         skpos_det              => skposdetect,
         -- S. Park 3/13/08 - Added new ports for XAUI compliance
         cg_comp_rd_d_ch0       => cg_comp_rd_d_ch0,
         cg_comp_rd_d_ch1       => cg_comp_rd_d_ch1,
         cg_comp_rd_d_ch2       => cg_comp_rd_d_ch2,
         cg_comp_rd_d_ch3       => cg_comp_rd_d_ch3,
         cg_comp_wr_ch0         => cg_comp_wr_ch0,
         cg_comp_wr_ch1         => cg_comp_wr_ch1,
         cg_comp_wr_ch2         => cg_comp_wr_ch2,
         cg_comp_wr_ch3         => cg_comp_wr_ch3,
         cg_comp_rd_d_out       => cg_comp_rd_d_out_xhdl9,
         cg_comp_wr_out         => cg_comp_wr_out_xhdl10,
         -- S. Park 3/21/08 - Added new ports for XAUI compliance
         del_cond_met_0         => del_cond_met_0,
         fifo_ovr_0             => fifo_ovr_0,
         latency_comp_0         => latency_comp_0,
         insert_incomplete_0    => insert_incomplete_0,
         del_cond_met_out       => del_cond_met_out_xhdl14,
         fifo_ovr_out           => fifo_ovr_out_xhdl21,
         latency_comp_out       => latency_comp_out_xhdl27,
         insert_incomplete_out  => insert_incomplete_out_xhdl26
      );
   
   -- 10B-8B Decoder module
   
   
   -- 01/07/05 VC: Increased bus width of cudi from 30 to 32
   --              to pass running disp polarity bit
   --                             .data_in({cudi[29:28],1'b0,cudi[27:15],
   --                                       cudi[14:13],1'b0,cudi[12:0]}),
   xhdl72 <= (cudi_valid & cudi_valid);
   dec_chnl_top_1 : stratixiv_hssi_rx_digi_dec_chnl_top
      PORT MAP (
         rst                 => soft_reset_int,
         clk_2               => clk_2_b_xhdl12,
         cascaded_8b10b_en   => rcascaded_8b10b_en_rx,
         r8b10b_dec_ibm_en   => r8b10b_dec_ibm_en,
         data_in             => cudi,
         data_in_valid       => xhdl72,
         renpolinv           => renpolinv_rx,
         rerr_flags_sel      => rerr_flags_sel,
         polinv              => polinv_rx,
         dec_data            => rx_data_dt,
         disp_err_delay      => disp_err_delay,
         disp_val_delay      => disp_val_delay,
         sync_resync_delay   => sync_resync_delay,
         dec_data_valid      => dec_data_valid_temp,
         dec_ctl             => rx_ctl_dt,
         invalid_code_delay  => invalid_code_delay,
         ovr_undflow         => ovr_undflow,
         tenb_data           => tenb_data,
         rlb_data            => rev_loop_data_xhdl41,
         rrxpcsbypass_en     => rrxpcsbypass_en
      );
   high_dec_data_valid <= dec_data_valid_temp(1);
   dec_data_valid_xhdl13 <= dec_data_valid_temp(0);
   -- BIST Verifier module
   
   
   selftest_ver_1 : stratixiv_hssi_rx_digi_bist_ver
      PORT MAP (
         clk_2                => rx_rd_clk,
         soft_reset           => soft_reset_rclk1_xhdl58,
         sync_status          => sync_status_st,
         rbisten_rx           => rbisten_rx,
         rpmadwidth_rx        => rpmadwidth_rx,
         rpma_doublewidth_rx  => rpma_doublewidth_rx,
         rdwidth_rx           => rdwidth_rx,
         rbist_sel            => rbist_sel,
         rcxpat_chnl_sel      => rcxpat_chnl_en,
         rbist_clr_rx         => rbist_clr_rx,
         rxd                  => rxd_xhdl51,
         rxc                  => rx_control_rc_16,
         prbs_done            => prbs_done_xhdl32,
         prbs_err             => prbs_err,
         cur_state            => bist_cur_state,
         selftest_err         => selftest_err_xhdl56,
         selftest_done        => selftest_done_xhdl55,
         bisterr              => bisterr_xhdl6,
         bistdone             => bistdone_xhdl5,
         err_data             => err_data_xhdl20,
         err_ctl              => err_ctl_xhdl19
      );
   
   -- RX Phase compensation FIFO module        
   
   
   -- S. Park 11/29/07 - Phase FIFO bypass feature removed
   -- .rrxfifo_dis (rrxfifo_dis),
   xhdl73 <= (cudi_valid & cudi_valid);
   xhdl74 <= (high_dec_data_valid & dec_data_valid_xhdl13);
   xhdl75 <= (cudi(27) & cudi(11));
   rx_ctrl_1 : stratixiv_hssi_rx_digi_rx_ctrl
      PORT MAP (
         soft_reset               => soft_reset_int,
         clk_2                    => clk_2_b_xhdl12,
         rx_wr_clk                => rx_wr_clk,
         rx_rd_clk                => rx_rd_clk,
         scan_mode                => scan_mode,
         rrxfifo_dis              => '0',
         rindv_rx                 => rindv_rx,
         rendec_data_sel_rx       => rendec_data_sel_rx,
         rwa_6g_en                => rwa_6g_en,
         rrxfifo_lowlatency_en    => rrxfifo_lowlatency_en,
         endec_rx                 => rendec_rx,
         rinvalid_code_err_only   => rinvalid_code_err_only,
         rrx_pipe_enable          => rrx_pipe_enable,
         rpmadatawidth            => rpmadwidth_rx,
         rdwidth                  => rdwidth_rx,
         rautoinsdis              => rautoinsdis,
         rbytorden                => rbyteorden,
         rbytord_2sym_en          => rbytord_2sym_en,
         rbytordpat               => rbytordpat,
         rbytordpadval            => rbytordpad,
         rbytordplden             => rbytordplden,
         bytordplden              => bytordpld,
         rbytord_6g_mask_en       => rbytord_6g_mask_en,
         rbytord_s2gx             => rbytord_s2gx,
         rsync_comp_size          => rcomp_size,
         rsync_comp_pat           => rcomp_pat,
         rsync_comp_porn          => rcomp_pat_porn,
         rsync_sm_dis             => rsync_sm_dis,
         rclkcmpinsertpad         => rclkcmpinsertpad,
         invalid_code_delay       => invalid_code_delay,
         sigdetni                 => sigdetni,
         dec_data_valid_pre       => xhdl73,
         dec_data_valid           => xhdl74,
         rx_data_rs               => rx_data_rs,
         rx_control_rs            => rx_control_rs,
         rx_data_dt               => rx_data_dt,
         rx_control_dt            => rx_ctl_dt,
         tenb_data                => tenb_data,
         sync_resync_pre          => xhdl75,
         sync_resync_delay        => sync_resync_delay,
         disp_err_delay           => disp_err_delay,
         disp_val_delay           => disp_val_delay,
         ovr_undflow              => ovr_undflow,
         rrxfifo_urst_en          => rphfifourstrx,
         rxfifo_urst              => phfifourst_rx,
         rrxphfifopldctl_en       => rphfifopldenrx,
         pld_wr_dis               => wrdisable_rx,
         pld_re                   => rdenable_rx,
         -- PIPE signals
         phystatus_int            => phystatus_int,
         rxvalid_int              => rxvalid_int,
         rxstatus_int             => rxstatus_int,
         powerdown                => powerdown,
         rxd                      => rxd_xhdl51,
         rxd_9                    => rx_data_9_rc,
         rxd_19                   => rx_data_19_rc,
         rxc                      => rx_control_rc_16,
         running_disp             => running_disp_xhdl44,
         signal_detect_out        => signal_detect_out_xhdl57,
         rxd_lpbk                 => rxd_lpbk,
         ph_fifo_empty            => empty_rx_xhdl18,
         ph_fifo_full             => full_rx_xhdl25,
         wr_enable_out            => nc_new_bundle2,
         rd_enable_out            => nc_new_bundle3,
         rx_we_out                => rx_we_out_testbus,
         bytord_valid_out         => byteord_flag_xhdl7,
         soft_reset_rclk1         => soft_reset_rclk1_xhdl58,
         soft_reset_wclk1         => rx_pipe_soft_reset_xhdl48,
         -- PIPE signals
         phystatus                => phystatus_xhdl30,
         rxvalid                  => rxvalid_xhdl54,
         rxstatus                 => rxstatus_xhdl53,
         pipe_data                => pipe_data_xhdl31,
         wr_enable2               => wr_enable2,
         wptr_bin                 => wptr_bin,
         rd_enable2               => rd_enable2,
         rptr_bin                 => rptr_bin,
         rrxpcsbypass_en          => rrxpcsbypass_en,
         reset_pc_ptrs            => reset_pc_ptrs_xhdl38,
         reset_pc_ptrs_centrl     => reset_pc_ptrs_in_centrl,
         reset_pc_ptrs_quad_up    => reset_pc_ptrs_in_quad_up,
         reset_pc_ptrs_quad_down  => reset_pc_ptrs_in_quad_down,
         gen2ngen1                => gen2ngen1,
         gen2ngen1_bundle         => gen2ngen1_bundle,
         dis_pc_byte              => dis_pc_byte_xhdl15,
         wr_enable_centrl         => wr_enable_in_centrl,
         wr_enable_quad_up        => wr_enable_in_quad_up,
         wr_enable_quad_down      => wr_enable_in_quad_down,
         rd_enable_centrl         => rd_enable_in_centrl,
         rd_enable_quad_up        => rd_enable_in_quad_up,
         rd_enable_quad_down      => rd_enable_in_quad_down,
         rx_we_in_centrl          => rx_we_in_centrl,
         rx_we_in_quad_up         => rx_we_in_quad_up,
         rx_we_in_quad_down       => rx_we_in_quad_down,
         -- New MDIO for new bundling scheme and new PCIE features like autospeed
         rauto_speed_ena          => rauto_speed_ena,
         rfreq_sel                => rfreq_sel,
         rphfifo_regmode_rx       => rphfifo_regmode_rx,
         rmaster_rx               => rmaster_rx,
         rmaster_up_rx            => rmaster_up_rx,
         pcs_wrapback_in          => pcs_wrapback_in,
         rpcs_wrapback_en         => rpcs_wrapback_en
      );
   
   -- PCS channel test bus
   
   
   xhdl76 <= (bistdone_xhdl5 & bisterr_xhdl6 & bist_cur_state & prbs_verify_on & encdet_prbs & prbs_err_lt_xhdl33);
   xhdl77 <= ('0' & rx_we_out_testbus & wr_enable2 & wptr_bin & rd_enable2 & rptr_bin);
   xhdl78 <= ("00" & skposdetect & comp_curr_st & comp_fifo_cnt);
   xhdl79 <= ('0' & freq_lock_xhdl23 & ppm_cnt);
   xhdl80 <= ("00" & pma_testbus);
   xhdl81 <= (ausm_cs & reset_pc_ptrs_xhdl38 & dis_pc_byte_xhdl15 & speed_change_xhdl59 & pcie_switch_xhdl29 & gen2ngen1 & rate);
   xhdl82 <= ("00000" & inferred_rxvalid & ltr_xhdl28 & eidle_exit & early_eios_xhdl16 & eiosdetect_int);
   xhdl83 <= (tx_rd_enable_out_pipe_up & tx_wr_enable_out_pipe_up & fifo_select_out_pipe_up & tx_div2_sync_out_pipe_up & reset_pc_ptrs_out_pipe_up_xhdl40 & speed_change_out_pipe_up_xhdl61 & rd_enable_out_pipe_up_xhdl37 & wr_enable_out_pipe_up_xhdl64 & rx_we_out_pipe_up_xhdl50 & rx_div2_sync_out_pipe_up_xhdl47);
   xhdl84 <= (tx_rd_enable_out_pipe_down & tx_wr_enable_out_pipe_down & fifo_select_out_pipe_down & tx_div2_sync_out_pipe_down & reset_pc_ptrs_out_pipe_down_xhdl39 & speed_change_out_pipe_down_xhdl60 & rd_enable_out_pipe_down_xhdl36 & wr_enable_out_pipe_down_xhdl63 & rx_we_out_pipe_down_xhdl49 & rx_div2_sync_out_pipe_down_xhdl46);
   pcs_channel_testbus_1 : stratixiv_hssi_rx_digi_pcs_channel_testbus
      PORT MAP (
         test_bus_in0       => xhdl76,
         test_bus_in1       => word_align_testbus,
         test_bus_in2       => encoder_testbus,
         test_bus_in3       => tx_ctrl_testbus,
         test_bus_in4       => xhdl77,
         test_bus_in5       => xhdl78,
         test_bus_in6       => xhdl79,
         test_bus_in7       => xhdl80,
         test_bus_in10      => xhdl81,
         test_bus_in11      => xhdl82,
         test_bus_in13      => xhdl83,
         test_bus_in14      => xhdl84,
         rtest_bus_sel      => rtest_bus_sel,
         chnl_test_bus_out  => chnl_test_bus_out_xhdl11
      );
   
   -- Frequency detector module
   
   
   freq_det_1 : stratixiv_hssi_rx_digi_freqdet
      PORT MAP (
         scan_mode            => scan_mode,
         ppmsel               => rppmsel,
         fref                 => fref_muxed,
         fvcobyn              => clklow_muxed,
         pd                   => '0',
         rforcehigh           => rforce1_freqdet,
         rforcelow            => rforce0_freqdet,
         hard_reset           => rxpma_rst,
         ppm_cnt_reset        => rppm_cnt_reset,
         gen2ngen1_indv       => gen2ngen1,
         gen2ngen1_bundle     => gen2ngen1_bundle,
         rindv_rx             => rindv_rx,
         rauto_speed_ena      => rauto_speed_ena,
         rppm_gen1_2xcnt_en   => rppm_gen1_2xcnt_en,
         eidle_exit           => eidle_exit,
         rppm_post_eidle_del  => rppm_post_eidle_del,
         freq_lock            => freq_lock_xhdl23,
         ppm_cnt_latch        => ppm_cnt
      );
   
   -- Auto negotiation module
   
   
   auto_speed_neg_1 : stratixiv_hssi_rx_digi_auto_speed_neg
      PORT MAP (
         refclk                     => clk_2_b_xhdl12,
         rxpcs_rst_int              => soft_reset_int,
         rauto_speed_ena            => rauto_speed_ena,
         singleorbundle             => rindv_rx,
         config_sel_centrl          => config_sel_centrl,
         config_sel_quad_up         => config_sel_quad_up,
         config_sel_quad_down       => config_sel_quad_down,
         rindv_rx                   => rindv_rx,
         rmaster_rx                 => rmaster_rx,
         rmaster_up_rx              => rmaster_up_rx,
         rphfifo_regmode_rx         => rphfifo_regmode_rx,
         rate                       => rate,
         cs                         => ausm_cs,
         gen2ngen1                  => gen2ngen1,		--from PMA
         speed_change               => speed_change_xhdl59,		--to RX PIPE, phystatus gen.
         rpma_done_count            => rpma_done_count,
         rauto_deassert_pc_rst_cnt  => rauto_deassert_pc_rst_cnt,
         rauto_pc_en_cnt            => rauto_pc_en_cnt,
         rwait_for_phfifo_cnt       => rwait_for_phfifo_cnt,
         config_sel                 => config_sel_nc,
         pcie_switch                => pcie_switch_xhdl29,
         dis_pc_byte                => dis_pc_byte_xhdl15,
         reset_pc_ptrs              => reset_pc_ptrs_xhdl38
      );
   
   
   
   electrical_idle_inference_module_1 : stratixiv_hssi_rx_digi_eii_module
      PORT MAP (
         rcvd_clk                => rcvd_clk,
         rxpcsrst                => rst1,		-- synchronized reset in rcvd_clk domain from wordalign block
         reidleinferenable       => reidleinferenable,
         reidle_com_detect       => reidle_com_detect,
         rindv_rx                => rindv_rx,
         riei_eios_priority_dis  => riei_eios_priority_dis,
         rgen1_sigdet_ena        => rgen1_sigdet_ena,
         eidleinfersel           => eidleinfersel,		--
         skposdetect             => skposdetect,
         syncstatus              => sync_status_st,
         sudi                    => sudi(15 DOWNTO 0),
         kflag                   => kchar,
         kcount                  => kcount(1 DOWNTO 0),		--new brought out from PIPE sync SM
         eiosdetect_int          => eiosdetect_int,		--CDR control
         inferred_rxvalid        => inferred_rxvalid,
         signaldetect            => sigdetni,
         gen2ngen1               => gen2ngen1,
         gen2ngen1_bundle        => gen2ngen1_bundle,
         pipe_loopbk             => pipe_loopbk,
         rwait_count             => rwait_count,
         rxelecidle_int          => rxelecidle_int_xhdl52
      );
   
   
   
   cdr_ctrl_1 : stratixiv_hssi_rx_digi_cdr_ctrl
      PORT MAP (
         
         -- General signals
         rcvd_clk          => rcvd_clk,
         rxpcs_reset_int   => rst1,		-- synchronized reset in rcvd_clk domain from wordalign block
         
         -- CRAM 
         rcdr_ctrl_en      => rcdr_ctrl_en,
         rcid_en           => rcid_en,
         rrxvalid_mask     => rrxvalid_mask,
         
         rwait_count       => rwait_count,
         rmask_count       => rmask_count(9 DOWNTO 0),
         
         rindv_rx          => rindv_rx,
         
         -- PLD interface
         pld_ltr           => pld_ltr,
         pipe_loopbk       => pipe_loopbk,
         
         -- Word aligner
         adata             => adata,
         adata_valid       => adata_valid,
         inferred_rxvalid  => inferred_rxvalid,
         
         -- EIdle Inference
         eiosdetect_int    => eiosdetect_int,
         
         -- Auto Speed
         gen2ngen1         => gen2ngen1,
         gen2ngen1_bundle  => gen2ngen1_bundle,
         
         -- PPM detector
         eidle_exit        => eidle_exit,
         
         -- PMA
         sigdet            => sigdetni,
         early_eios        => early_eios_xhdl16,
         ltr               => ltr_xhdl28
      );
   
   
   
   iqp_out_up : stratixiv_hssi_rx_digi_iq_pipe_rx
      PORT MAP (
         clk_2_b_raw                      => clk_2_b_raw,
         rx_wr_clk_raw                    => rx_wr_clk_raw,
         rx_rd_clk_raw                    => rx_rd_clk_raw,
         rxrst                            => rxpcs_rst,
         soft_reset_rclk1                 => soft_reset_rclk1_xhdl58,
         soft_reset_wclk1                 => rx_pipe_soft_reset_xhdl48,
         rmaster_rx                       => rmaster_rx,
         rmaster_up_rx                    => rmaster_up_rx,
         rpipeline_bypass_rx              => rpipeline_bypass_rx,
         rfreerun_rx                      => rfreerun_rx,
         
         rx_div2_sync_in_centrl           => rx_div2_sync_in_centrl,
         rx_div2_sync_in_pipe_quad_up     => '0',
         rx_div2_sync_in_pipe_quad_down   => rx_div2_sync_in_pipe_quad_down,
         reset_pc_ptrs_in_centrl          => reset_pc_ptrs_in_centrl,
         reset_pc_ptrs_in_pipe_quad_up    => '0',
         reset_pc_ptrs_in_pipe_quad_down  => reset_pc_ptrs_in_pipe_quad_down,
         wr_enable_in_centrl              => wr_enable_in_centrl,
         wr_enable_in_pipe_quad_up        => '0',
         wr_enable_in_pipe_quad_down      => wr_enable_in_pipe_quad_down,
         rd_enable_in_centrl              => rd_enable_in_centrl,
         rd_enable_in_pipe_quad_up        => '0',
         rd_enable_in_pipe_quad_down      => rd_enable_in_pipe_quad_down,
         rx_we_in_centrl                  => rx_we_in_centrl,
         rx_we_in_pipe_quad_up            => '0',
         rx_we_in_pipe_quad_down          => rx_we_in_pipe_quad_down,
         speed_change_in_centrl           => speed_change_in_centrl,
         speed_change_in_pipe_quad_up     => '0',
         speed_change_in_pipe_quad_down   => speed_change_in_pipe_quad_down,
         
         rx_div2_sync_out_pipe            => rx_div2_sync_out_pipe_up_xhdl47,
         rx_we_out_pipe                   => rx_we_out_pipe_up_xhdl50,
         wr_enable_out_pipe               => wr_enable_out_pipe_up_xhdl64,
         rd_enable_out_pipe               => rd_enable_out_pipe_up_xhdl37,
         reset_pc_ptrs_out_pipe           => reset_pc_ptrs_out_pipe_up_xhdl40,
         speed_change_out_pipe            => speed_change_out_pipe_up_xhdl61
      );
   
   
   
   iqp_out_down : stratixiv_hssi_rx_digi_iq_pipe_rx
      PORT MAP (
         clk_2_b_raw                      => clk_2_b_raw,
         rx_wr_clk_raw                    => rx_wr_clk_raw,
         rx_rd_clk_raw                    => rx_rd_clk_raw,
         rxrst                            => rxpcs_rst,
         soft_reset_rclk1                 => soft_reset_rclk1_xhdl58,
         soft_reset_wclk1                 => rx_pipe_soft_reset_xhdl48,
         rmaster_rx                       => rmaster_rx,
         rmaster_up_rx                    => rmaster_up_rx,
         rpipeline_bypass_rx              => rpipeline_bypass_rx,
         rfreerun_rx                      => rfreerun_rx,
         
         rx_div2_sync_in_centrl           => rx_div2_sync_in_centrl,
         rx_div2_sync_in_pipe_quad_up     => rx_div2_sync_in_pipe_quad_up,
         rx_div2_sync_in_pipe_quad_down   => '0',
         reset_pc_ptrs_in_centrl          => reset_pc_ptrs_in_centrl,
         reset_pc_ptrs_in_pipe_quad_up    => reset_pc_ptrs_in_pipe_quad_up,
         reset_pc_ptrs_in_pipe_quad_down  => '0',
         wr_enable_in_centrl              => wr_enable_in_centrl,
         wr_enable_in_pipe_quad_up        => wr_enable_in_pipe_quad_up,
         wr_enable_in_pipe_quad_down      => '0',
         rd_enable_in_centrl              => rd_enable_in_centrl,
         rd_enable_in_pipe_quad_up        => rd_enable_in_pipe_quad_up,
         rd_enable_in_pipe_quad_down      => '0',
         rx_we_in_centrl                  => rx_we_in_centrl,
         rx_we_in_pipe_quad_up            => rx_we_in_pipe_quad_up,
         rx_we_in_pipe_quad_down          => '0',
         speed_change_in_centrl           => speed_change_in_centrl,
         speed_change_in_pipe_quad_up     => speed_change_in_pipe_quad_up,
         speed_change_in_pipe_quad_down   => '0',
         
         rx_div2_sync_out_pipe            => rx_div2_sync_out_pipe_down_xhdl46,
         rx_we_out_pipe                   => rx_we_out_pipe_down_xhdl49,
         wr_enable_out_pipe               => wr_enable_out_pipe_down_xhdl63,
         rd_enable_out_pipe               => rd_enable_out_pipe_down_xhdl36,
         reset_pc_ptrs_out_pipe           => reset_pc_ptrs_out_pipe_down_xhdl39,
         speed_change_out_pipe            => speed_change_out_pipe_down_xhdl60
      );
   
END trans;



-- digi_rx--///////////////////////////////////////////////////////////////////////////////
-- hssi_module: receiver ******************************************************//
--///////////////////////////////////////////////////////////////////////////////

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

USE IEEE.VITAL_Timing.all;
USE IEEE.VITAL_Primitives.all;
ENTITY stratixiv_hssi_rx_pcs IS
   GENERIC (

          --  generic control parameters  --
       MsgOn                   : Boolean := DefGlitchMsgOn;
       XOn                     : Boolean := DefGlitchXOn;
       MsgOnChecks             : Boolean := DefMsgOnChecks;
       XOnChecks               : Boolean := DefXOnChecks;
       InstancePath            : String := "*";
       TimingChecksOn          : Boolean := True;
          --  tipd  :interconnect path delays --
      tipd_phfifox8bytesel                : VitalDelayType01 := DefpropDelay01;
      tipd_xgmctrlin                : VitalDelayType01 := DefpropDelay01;
      tipd_pipepowerdown               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_parallelfdbk               :VitalDelayArrayType01(19 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_masterclk                : VitalDelayType01 := DefpropDelay01;
      tipd_iqpphfifoxnwrclk               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rxelecidlerateswitch                : VitalDelayType01 := DefpropDelay01;
      tipd_pipepowerstate               :VitalDelayArrayType01(3 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_alignstatussync                : VitalDelayType01 := DefpropDelay01;
      tipd_powerdn               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_refclk                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifox4bytesel                : VitalDelayType01 := DefpropDelay01;
      tipd_bitslip                : VitalDelayType01 := DefpropDelay01;
      tipd_phfiforeset                : VitalDelayType01 := DefpropDelay01;
      tipd_dprioin               :VitalDelayArrayType01(399 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_disablefifowrin                : VitalDelayType01 := DefpropDelay01;
      tipd_ppmdetectdividedclk                : VitalDelayType01 := DefpropDelay01;
      tipd_datain               :VitalDelayArrayType01(19 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_enabledeskew                : VitalDelayType01 := DefpropDelay01;
      tipd_hippowerdown               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_revbyteorderwa                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifox4wrenable                : VitalDelayType01 := DefpropDelay01;
      tipd_dpriodisable                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifox8wrclk                : VitalDelayType01 := DefpropDelay01;
      tipd_enabyteord                : VitalDelayType01 := DefpropDelay01;
      tipd_invpol                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifox8rdenable                : VitalDelayType01 := DefpropDelay01;
      tipd_revbitorderwa                : VitalDelayType01 := DefpropDelay01;
      tipd_localrefclk                : VitalDelayType01 := DefpropDelay01;
      tipd_enapatternalign                : VitalDelayType01 := DefpropDelay01;
      tipd_iqpphfifoxnrdenable               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_iqpphfifoxnptrsreset               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_phfifowrdisable                : VitalDelayType01 := DefpropDelay01;
      tipd_signaldetected                : VitalDelayType01 := DefpropDelay01;
      tipd_alignstatus                : VitalDelayType01 := DefpropDelay01;
      tipd_rxdetectvalid                : VitalDelayType01 := DefpropDelay01;
      tipd_quadreset                : VitalDelayType01 := DefpropDelay01;
      tipd_autospdxnconfigsel               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_recoveredclk                : VitalDelayType01 := DefpropDelay01;
      tipd_hiprateswitch                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifordenable                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifox4wrclk                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifoxnbytesel               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rmfifowrena                : VitalDelayType01 := DefpropDelay01;
      tipd_a1a2size                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifox8wrenable                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifoxnptrsreset               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_iqpphfifoxnwrenable               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_phfifoxnrdenable               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rateswitchisdone                : VitalDelayType01 := DefpropDelay01;
      tipd_elecidleinfersel               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_hip8b10binvpolarity                : VitalDelayType01 := DefpropDelay01;
      tipd_rateswitchxndone                : VitalDelayType01 := DefpropDelay01;
      tipd_iqpautospdxnspgchg               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rmfiforeset                : VitalDelayType01 := DefpropDelay01;
      tipd_coreclk                : VitalDelayType01 := DefpropDelay01;
      tipd_rmfifordena                : VitalDelayType01 := DefpropDelay01;
      tipd_disablefifordin                : VitalDelayType01 := DefpropDelay01;
      tipd_rateswitch                : VitalDelayType01 := DefpropDelay01;
      tipd_hipelecidleinfersel               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_phfifox4rdenable                : VitalDelayType01 := DefpropDelay01;
      tipd_pipe8b10binvpolarity                : VitalDelayType01 := DefpropDelay01;
      tipd_fifordin                : VitalDelayType01 := DefpropDelay01;
      tipd_ppmdetectrefclk                : VitalDelayType01 := DefpropDelay01;
      tipd_prbscidenable                : VitalDelayType01 := DefpropDelay01;
      tipd_digitalreset                : VitalDelayType01 := DefpropDelay01;
      tipd_rxfound               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_cdrctrllocktorefcl                : VitalDelayType01 := DefpropDelay01;
      tipd_phfifoxnwrclk               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_iqpphfifoxnbytesel               :VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_autospdxnspdchg               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_phfifoxnwrenable               :VitalDelayArrayType01(2 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_fiforesetrd                : VitalDelayType01 := DefpropDelay01;
      tipd_xgmdatain               :VitalDelayArrayType01(7 DOWNTO 0)   := (OTHERS => DefPropDelay01);
     
        -- TSU/TH section
        tsetup_phfifordenable_coreclk_noedge_posedge: VitalDelayType := DefSetupHoldCnst;
        thold_phfifordenable_coreclk_noedge_posedge: VitalDelayType := DefSetupHoldCnst;
        -- TCO section
        tpd_coreclk_a1a2sizeout_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_ctrldetect_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_dataout_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_dataoutfull_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_disperr_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_errdetect_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_patterndetect_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_rmfifodatadeleted_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_rmfifodatainserted_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_runningdisp_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_syncstatus_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_pipebufferstat_posedge : VitalDelayArrayType01(3 downto 0) := (OTHERS => DefPropDelay01);
        tpd_coreclk_byteorderalignstatus_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_phfifooverflow_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_phfifounderflow_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_pipestatus_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_pipephydonestatus_posedge: VitalDelayType01 := DefPropDelay01;
        tpd_coreclk_pipedatavalid_posedge: VitalDelayType01 := DefPropDelay01;
 
      --////////////////////////////////////////////////////////////////////////////
      --////////////////////////////////////////////////////////////////////////////
      
      lpm_type                                    : STRING := "stratixiv_hssi_rx_pcs";
      align_ordered_set_based                     : STRING := "false";           
      align_pattern                               : STRING := "0101111100";	--  word align: size of align_pattern_length; 
      align_pattern_length                        : INTEGER := 10;			-- <7, 8, 10, 16, 20, 32, 40>; 
      align_to_deskew_pattern_pos_disp_only       : STRING := "false";		-- <true/false>;
      allow_align_polarity_inversion              : STRING := "false"; 
      allow_pipe_polarity_inversion               : STRING := "false";
      auto_spd_deassert_ph_fifo_rst_count         : INTEGER := 0;		
      auto_spd_phystatus_notify_count             : INTEGER := 0;		
      auto_spd_self_switch_enable                 : STRING := "false";		
      bit_slip_enable                             : STRING := "false";
      byte_order_back_compat_enable               : STRING := "false";		
      byte_order_double_data_mode_mask_enable     : STRING := "false";		
      byte_order_invalid_code_or_run_disp_error   : STRING := "false";		
      byte_order_mode                             : STRING := "none";		--NEW_PARAM_replace byte_ordering_mode
      byte_order_pad_pattern                      : STRING := "0101111100";	-- <10-bit binary string>;            
      byte_order_pattern                          : STRING := "0101111100";	-- <10-bit binary string>;
      byte_order_pld_ctrl_enable                  : STRING := "false";		--ww47_cram added in build 165
      cdrctrl_bypass_ppm_detector_cycle           : INTEGER := 0;		
      cdrctrl_cid_mode_enable                     : STRING := "false";		
      cdrctrl_enable                              : STRING := "false";		
      cdrctrl_mask_cycle                          : INTEGER := 0;		
      cdrctrl_min_lock_to_ref_cycle               : INTEGER := 0;		
      cdrctrl_rxvalid_mask                        : STRING := "false";		
      channel_bonding                             : STRING := "none";		-- <none, x4, x8>;
      channel_number                              : INTEGER := 0;			-- <integer 0-3>;
      channel_width                               : INTEGER := 10;			-- <integer 8,10,16,20,32,40>;
      clk1_mux_select                             : STRING := "recvd_clk";	-- <RECVD_CLK, MASTER_CLK, LOCAL_REFCLK, DIGITAL_REFCLK>;      
      clk2_mux_select                             : STRING := "recvd_clk";	-- <RECVD_CLK, LOCAL_REFCLK, DIGITAL_REFCLK, CORE_CLK>;
      clk_pd_enable                               : STRING := "false";		--ww47_cram_p1
      core_clock_0ppm                             : STRING := "false";		
      datapath_low_latency_mode                   : STRING := "false";		
      datapath_protocol                           : STRING := "basic";		-- <basic/pipe/xaui> replaced by protocol_hint
      dec_8b_10b_compatibility_mode               : STRING := "true";
      dec_8b_10b_mode                             : STRING := "none";		-- <normal/cascaded/none>;
      dec_8b_10b_polarity_inv_enable              : STRING := "false";		
      deskew_pattern                              : STRING := "1100111100";	-- K28.3
      disable_auto_idle_insertion                 : STRING := "false";  
      disable_running_disp_in_word_align          : STRING := "false"; 
      disallow_kchar_after_pattern_ordered_set    : STRING := "false";
      dprio_config_mode                           : STD_LOGIC_VECTOR(5 DOWNTO 0) := "000000";
      elec_idle_eios_detect_priority_over_eidle_disable : STRING := "false";
      elec_idle_gen1_sigdet_enable                : STRING := "false";		
      elec_idle_infer_enable                      : STRING := "false";		
      elec_idle_k_detect                          : STRING := "false";		
      elec_idle_num_com_detect                    : INTEGER := 0;		
      enable_bit_reversal                         : STRING := "false";
      enable_deep_align                           : STRING := "false";                          
      enable_deep_align_byte_swap                 : STRING := "false";
      enable_self_test_mode                       : STRING := "false";
      enable_true_complement_match_in_word_align  : STRING := "true"; 
      error_from_wa_or_8b_10b_select               : STRING := "false"; 
      force_signal_detect_dig                     : STRING := "false";
      hip_enable                                  : STRING := "false";		
      infiniband_invalid_code                     : INTEGER := 0;			-- <integer 0-3>;
      insert_pad_on_underflow                     : STRING := "false";
      iqp_bypass                                  : STRING := "false";		
      iqp_ph_fifo_xn_select                       : INTEGER := 9999;		
      logical_channel_address                     : INTEGER := 0;		
      migrated_from_prev_family                   : STRING := "false";		-- b165
      num_align_code_groups_in_ordered_set        : INTEGER := 1;			-- <integer 0-3>;   
      num_align_cons_good_data                    : INTEGER := 3;			-- wordalign<Integer 1-256>;
      num_align_cons_pat                          : INTEGER := 4;			-- <Integer 1-256>;
      num_align_loss_sync_error                   : INTEGER := 1;			--NEW_PARAM_replace align_loss_sync_error_num
      ph_fifo_disable                             : STRING := "false";		
      ph_fifo_low_latency_enable                  : STRING := "false";		
      ph_fifo_reg_mode                            : STRING := "false";		
      ph_fifo_reset_enable                        : STRING := "false";		
      ph_fifo_user_ctrl_enable                    : STRING := "false";		
      ph_fifo_xn_mapping0                         : STRING := "none";		--ww47_cram_p1
      ph_fifo_xn_mapping1                         : STRING := "none";		--ww47_cram_p1
      ph_fifo_xn_mapping2                         : STRING := "none";		--ww47_cram_p1
      ph_fifo_xn_select                           : INTEGER := 9999;		
      phystatus_delay                             : INTEGER := 0;		
      phystatus_reset_toggle                      : STRING := "false";
      pipe_auto_speed_nego_enable                 : STRING := "false";		
      pipe_freq_scale_mode                        : STRING := "Data width";	
      pipe_hip_enable                             : STRING := "false";		--NEW_PARAM  todo: remove
      pma_done_count                              : INTEGER := 53392;		--ww47_cram_p1
      prbs_all_one_detect                         : STRING := "false";
      prbs_cid_pattern                            : STRING := "false";		
      prbs_cid_pattern_length                     : INTEGER := 0;		
      protocol_hint                               : STRING := "basic";
      rate_match_almost_empty_threshold           : INTEGER := 11;			-- <integer 0-15>;           
      rate_match_almost_full_threshold            : INTEGER := 13;			-- <integer 0-15>;           
      rate_match_back_to_back                     : STRING := "false";           
      rate_match_delete_threshold                 : INTEGER := 13;		
      rate_match_empty_threshold                  : INTEGER := 5;		
      rate_match_fifo_mode                        : STRING := "false";		-- <normal/cascaded/generic/cascaded_generic/none> in s2gx, bool in s4gx;
      rate_match_full_threshold                   : INTEGER := 20;		
      rate_match_insert_threshold                 : INTEGER := 11;		
      rate_match_ordered_set_based                : STRING := "false";		-- <integer 10 or 20>;
      rate_match_pattern1                         : STRING := "00000000000010111100";		-- <20-bit binary string>;           
      rate_match_pattern2                         : STRING := "00000000000010111100";		-- <20-bit binary string>;           
      rate_match_pattern_size                     : INTEGER := 10;			-- <integer 10 or 20>;
      rate_match_pipe_enable                      : STRING := "false";  	
      rate_match_reset_enable                     : STRING := "true";		--NEW_PARAM - default diff from atom
      rate_match_skip_set_based                   : STRING := "false";
      rate_match_start_threshold                  : INTEGER := 7;			
      rd_clk_mux_select                           : STRING := "int_clk";	-- <INT_CLK, CORE_CLK>;
      recovered_clk_mux_select                    : STRING := "recvd_clk";	-- <RECVD_CLK, LOCAL_REFCLK, DIGITAL_REFCLK>; 
      reset_clock_output_during_digital_reset     : STRING := "false";	
      run_length                                  : INTEGER := 200;			-- <5-320 or 4-254 depending on the deserialization factor>; 
      run_length_enable                           : STRING := "false";	 
      rx_detect_bypass                            : STRING := "false";
      rx_phfifo_wait_cnt                          : INTEGER := 32;		
      rxstatus_error_report_mode                  : INTEGER := 0;		
      self_test_mode                              : STRING := "incremental"; -- <PRBS_7,PRBS_8,PRBS_10,PRBS_23,low_freq,mixed_freq,high_freq,incremental,cjpat,crpat>;
      test_bus_sel                                : INTEGER := 0;		
      use_alignment_state_machine                 : STRING := "false";	
      use_deserializer_double_data_mode           : STRING := "false";	
      use_deskew_fifo                             : STRING := "false";	                                                 
      use_double_data_mode                        : STRING := "false";	 
      use_parallel_loopback                       : STRING := "false";	
      use_rising_edge_triggered_pattern_align     : STRING := "false";		-- <true/false>;    //83 para: new=23 rem=40
      enable_phfifo_bypass                        : STRING := "false"
   );
   PORT (
      a1a2size                                    : IN STD_LOGIC := '0';
      alignstatus                                 : IN STD_LOGIC := '0';
      alignstatussync                             : IN STD_LOGIC := '0';
      autospdxnconfigsel                          : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');		-- config_sel_centrl, quad_up, quad_down
      autospdxnspdchg                             : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');		-- From CMU.spped-change_centrl, rx3(up), rx0(down)
      bitslip                                     : IN STD_LOGIC := '0';
      cdrctrllocktorefcl                          : IN STD_LOGIC := '0';		-- pld_ltr
      coreclk                                     : IN STD_LOGIC := '0';
      datain                                      : IN STD_LOGIC_VECTOR(19 DOWNTO 0) := (others => '0');		--NEW: updated width
      digitalreset                                : IN STD_LOGIC := '0';
      disablefifordin                             : IN STD_LOGIC := '0';
      disablefifowrin                             : IN STD_LOGIC := '0';
      dpriodisable                                : IN STD_LOGIC := '1';
      dprioin                                     : IN STD_LOGIC_VECTOR(399 DOWNTO 0) := (others => '0');
      elecidleinfersel                            : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');
      enabledeskew                                : IN STD_LOGIC := '0';
      enabyteord                                  : IN STD_LOGIC := '0';
      enapatternalign                             : IN STD_LOGIC := '0';
      fifordin                                    : IN STD_LOGIC := '0';
      fiforesetrd                                 : IN STD_LOGIC := '0';
      grayelecidleinferselfromtx                  : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0'); 
      hip8b10binvpolarity                         : IN STD_LOGIC := '0';		-- hip_rxpolarity
      hipelecidleinfersel                         : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');		-- hip_eidleinfersel_ch
      hippowerdown                                : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');		-- hip_powerdown_ch
      hiprateswitch                               : IN STD_LOGIC := '0';		-- hip_rate
      invpol                                      : IN STD_LOGIC := '0';
      iqpautospdxnspgchg                          : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');		-- speed_change_in_pipe_quad_up, down
      iqpphfifoxnbytesel                          : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');		-- wr_enable_ptrs_in_pipe_quad_up, down
      iqpphfifoxnptrsreset                        : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');		-- reset_pc_ptrs_in_pipe_quad_up, down
      iqpphfifoxnrdenable                         : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');		-- rd_enable_ptrs_in_pipe_quad_up, down
      iqpphfifoxnwrclk                            : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');		-- rx_div2_sync_in_pipe_quad_up, down
      iqpphfifoxnwrenable                         : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');		-- wr_enable_ptrs_in_pipe_quad_up, down
      localrefclk                                 : IN STD_LOGIC := '0';
      masterclk                                   : IN STD_LOGIC := '0';
      parallelfdbk                                : IN STD_LOGIC_VECTOR(19 DOWNTO 0) := (others => '0');
      phfifordenable                              : IN STD_LOGIC := '1';
      phfiforeset                                 : IN STD_LOGIC := '0';
      phfifowrdisable                             : IN STD_LOGIC := '0';
      phfifox4bytesel                             : IN STD_LOGIC := '0';
      phfifox4rdenable                            : IN STD_LOGIC := '0';
      phfifox4wrclk                               : IN STD_LOGIC := '0';
      phfifox4wrenable                            : IN STD_LOGIC := '0';
      phfifox8bytesel                             : IN STD_LOGIC := '0';
      phfifox8rdenable                            : IN STD_LOGIC := '0';
      phfifox8wrclk                               : IN STD_LOGIC := '0';
      phfifox8wrenable                            : IN STD_LOGIC := '0';
      phfifoxnbytesel                             : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');		-- rx_we_in_centrl, quad_up, quad_down
      phfifoxnptrsreset                           : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');		-- ph fifo. From CMU to both RX & TX.
      phfifoxnrdenable                            : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');		-- rd_enable_in_centrl, quad_up, quad_down
      phfifoxnwrclk                               : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');		-- ph fifo. From CMU to RX.
      phfifoxnwrenable                            : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');		-- wr_enable_in_centrl, quad_up, quad_down
      pipe8b10binvpolarity                        : IN STD_LOGIC := '0';
      pipeenrevparallellpbkfromtx                 : IN STD_LOGIC := '0';  
      pipepowerdown                               : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');
      pipepowerstate                              : IN STD_LOGIC_VECTOR(3 DOWNTO 0) := (others => '0');
      pmatestbusin                                : IN STD_LOGIC_VECTOR(7 DOWNTO 0) := (others => '0');
      powerdn                                     : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');
      ppmdetectdividedclk                         : IN STD_LOGIC := '0';
      ppmdetectrefclk                             : IN STD_LOGIC := '0';
      prbscidenable                               : IN STD_LOGIC := '0';		-- prbs_cid_en
      quadreset                                   : IN STD_LOGIC := '0';
      rateswitch                                  : IN STD_LOGIC := '0';
      rateswitchisdone                            : IN STD_LOGIC := '0';
      rateswitchxndone                            : IN STD_LOGIC := '0';
      recoveredclk                                : IN STD_LOGIC := '0';
      refclk                                      : IN STD_LOGIC := '0';
      revbitorderwa                               : IN STD_LOGIC := '0';
      revbyteorderwa                              : IN STD_LOGIC := '0';
      rmfifordena                                 : IN STD_LOGIC := '0';
      rmfiforeset                                 : IN STD_LOGIC := '0';
      rmfifowrena                                 : IN STD_LOGIC := '0';
      rxdetectvalid                               : IN STD_LOGIC := '0';
      rxelecidlerateswitch                        : IN STD_LOGIC := '0';	
      rxfound                                     : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');
      signaldetected                              : IN STD_LOGIC := '0';	
      wareset                                     : IN STD_LOGIC := '0';	-- new in 9.1
      xauidelcondmet                              : IN STD_LOGIC := '0';  
      xauififoovr                                 : IN STD_LOGIC := '0';  
      xauiinsertincomplete                        : IN STD_LOGIC := '0';  
      xauilatencycomp                             : IN STD_LOGIC := '0';  
      xgmctrlin                                   : IN STD_LOGIC := '0';
      xgmdatain                                   : IN STD_LOGIC_VECTOR(7 DOWNTO 0) := (others => '0');		--54 ins ---
      
      a1a2sizeout                                 : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      a1detect                                    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      a2detect                                    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      adetectdeskew                               : OUT STD_LOGIC;
      alignstatussyncout                          : OUT STD_LOGIC;
      autospdrateswitchout                        : OUT STD_LOGIC;
      autospdspdchgout                            : OUT STD_LOGIC;		--ww47_out speed_chang_out_pipe
      bistdone                                    : OUT STD_LOGIC;
      bisterr                                     : OUT STD_LOGIC;
      bitslipboundaryselectout                    : OUT STD_LOGIC_VECTOR(4 DOWNTO 0);		--ww47_out wa_boundary
      byteorderalignstatus                        : OUT STD_LOGIC;
      cdrctrlearlyeios                            : OUT STD_LOGIC;		--ww47_out Asserted when K_I or K_X_I is detected on the incoming data. To PMA and/or PLD?
      cdrctrllocktorefclkout                      : OUT STD_LOGIC;		--ww47_out Force CDR(RX PLL) to LTR.
      clkout                                      : OUT STD_LOGIC;
      coreclkout                                  : OUT STD_LOGIC;		--ww47_out Sim Only. From RX Ch0 to CMU
      ctrldetect                                  : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      dataout                                     : OUT STD_LOGIC_VECTOR(39 DOWNTO 0);
      dataoutfull                                 : OUT STD_LOGIC_VECTOR(63 DOWNTO 0);		-- new in 6.1
      digitaltestout                              : OUT STD_LOGIC_VECTOR(9 DOWNTO 0);	      
      disablefifordout                            : OUT STD_LOGIC;
      disablefifowrout                            : OUT STD_LOGIC;
      disperr                                     : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      dprioout                                    : OUT STD_LOGIC_VECTOR(399 DOWNTO 0);
      errdetect                                   : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      fifordout                                   : OUT STD_LOGIC;
      hipdataout                                  : OUT STD_LOGIC_VECTOR(8 DOWNTO 0);		--ww47_out hip_rxd_ch(8:0)
      hipdatavalid                                : OUT STD_LOGIC;		--ww47_out hip_rxvalid
      hipelecidle                                 : OUT STD_LOGIC;		--ww47_out hip_rxelecidle
      hipphydonestatus                            : OUT STD_LOGIC;		--ww47_out hip_phystatus
      hipstatus                                   : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);		--ww47_out hip_rxstatus_ch(2:0)
      iqpphfifobyteselout                         : OUT STD_LOGIC;		--ww47_out rx_we_out_pipe
      iqpphfifoptrsresetout                       : OUT STD_LOGIC;		--ww47_out reset_pc_pters_out_pipe
      iqpphfifordenableout                        : OUT STD_LOGIC;		--ww47_out rd_enable_pipe_out
      iqpphfifowrclkout                           : OUT STD_LOGIC;		--ww47_out rx_div2_sync_out_pipe
      iqpphfifowrenableout                        : OUT STD_LOGIC;		--ww47_out wr_enable_out_pipe
      k1detect                                    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      k2detect                                    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      patterndetect                               : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      phfifobyteselout                            : OUT STD_LOGIC;
      phfifobyteserdisableout                     : OUT STD_LOGIC;		--ww47_out From Auto Speed Neg to TX
      phfifooverflow                              : OUT STD_LOGIC;
      phfifoptrsresetout                          : OUT STD_LOGIC;		--ww47_out From Auto Speed Neg to TX
      phfifordenableout                           : OUT STD_LOGIC;
      phfiforesetout                              : OUT STD_LOGIC;		--ww47_out Sim Only. From RX Ch0 to CMU
      phfifounderflow                             : OUT STD_LOGIC;
      phfifowrclkout                              : OUT STD_LOGIC;
      phfifowrdisableout                          : OUT STD_LOGIC;		--ww47_out Sim Only. From RX Ch0 to CMU
      phfifowrenableout                           : OUT STD_LOGIC;
      pipebufferstat                              : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      pipedatavalid                               : OUT STD_LOGIC;
      pipeelecidle                                : OUT STD_LOGIC;
      pipephydonestatus                           : OUT STD_LOGIC;
      pipestatus                                  : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      pipestatetransdoneout                       : OUT STD_LOGIC;
      rateswitchout                               : OUT STD_LOGIC;
      rdalign                                     : OUT STD_LOGIC;
      revparallelfdbkdata                         : OUT STD_LOGIC_VECTOR(19 DOWNTO 0);
      rlv                                         : OUT STD_LOGIC;
      rmfifoalmostempty                           : OUT STD_LOGIC;
      rmfifoalmostfull                            : OUT STD_LOGIC;
      rmfifodatadeleted                           : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      rmfifodatainserted                          : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      rmfifoempty                                 : OUT STD_LOGIC;
      rmfifofull                                  : OUT STD_LOGIC;
      runningdisp                                 : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      signaldetect                                : OUT STD_LOGIC;
      syncstatus                                  : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      syncstatusdeskew                            : OUT STD_LOGIC; 
      xauidelcondmetout                           : OUT STD_LOGIC; 
      xauififoovrout                              : OUT STD_LOGIC; 
      xauiinsertincompleteout                     : OUT STD_LOGIC; 
      xauilatencycompout                          : OUT STD_LOGIC; 
      xgmctrldet                                  : OUT STD_LOGIC;
      xgmdataout                                  : OUT STD_LOGIC_VECTOR(7 DOWNTO 0);
      xgmdatavalid                                : OUT STD_LOGIC;
      xgmrunningdisp                              : OUT STD_LOGIC	
    );
END stratixiv_hssi_rx_pcs;

ARCHITECTURE trans OF stratixiv_hssi_rx_pcs IS

  signal phfifox8bytesel_ipd  :STD_LOGIC;
  signal xgmctrlin_ipd  :STD_LOGIC;
  signal pipepowerdown_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal parallelfdbk_ipd  :STD_LOGIC_VECTOR(19 DOWNTO 0);
  signal masterclk_ipd  :STD_LOGIC;
  signal iqpphfifoxnwrclk_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal rxelecidlerateswitch_ipd  :STD_LOGIC;
  signal pipepowerstate_ipd  :STD_LOGIC_VECTOR(3 DOWNTO 0);
  signal alignstatussync_ipd  :STD_LOGIC;
  signal powerdn_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal refclk_ipd  :STD_LOGIC;
  signal phfifox4bytesel_ipd  :STD_LOGIC;
  signal bitslip_ipd  :STD_LOGIC;
  signal phfiforeset_ipd  :STD_LOGIC;
  signal dprioin_ipd  :STD_LOGIC_VECTOR(399 DOWNTO 0);
  signal disablefifowrin_ipd  :STD_LOGIC;
  signal ppmdetectdividedclk_ipd  :STD_LOGIC;
  signal datain_ipd  :STD_LOGIC_VECTOR(19 DOWNTO 0);
  signal enabledeskew_ipd  :STD_LOGIC;
  signal hippowerdown_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal revbyteorderwa_ipd  :STD_LOGIC;
  signal phfifox4wrenable_ipd  :STD_LOGIC;
  signal dpriodisable_ipd  :STD_LOGIC;
  signal phfifox8wrclk_ipd  :STD_LOGIC;
  signal enabyteord_ipd  :STD_LOGIC;
  signal invpol_ipd  :STD_LOGIC;
  signal phfifox8rdenable_ipd  :STD_LOGIC;
  signal revbitorderwa_ipd  :STD_LOGIC;
  signal localrefclk_ipd  :STD_LOGIC;
  signal enapatternalign_ipd  :STD_LOGIC;
  signal iqpphfifoxnrdenable_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal iqpphfifoxnptrsreset_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal phfifowrdisable_ipd  :STD_LOGIC;
  signal signaldetected_ipd  :STD_LOGIC;
  signal alignstatus_ipd  :STD_LOGIC;
  signal rxdetectvalid_ipd  :STD_LOGIC;
  signal quadreset_ipd  :STD_LOGIC;
  signal autospdxnconfigsel_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal recoveredclk_ipd  :STD_LOGIC;
  signal hiprateswitch_ipd  :STD_LOGIC;
  signal phfifordenable_ipd  :STD_LOGIC;
  signal phfifox4wrclk_ipd  :STD_LOGIC;
  signal phfifoxnbytesel_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal rmfifowrena_ipd  :STD_LOGIC;
  signal a1a2size_ipd  :STD_LOGIC;
  signal phfifox8wrenable_ipd  :STD_LOGIC;
  signal phfifoxnptrsreset_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal iqpphfifoxnwrenable_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal phfifoxnrdenable_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal rateswitchisdone_ipd  :STD_LOGIC;
  signal elecidleinfersel_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal hip8b10binvpolarity_ipd  :STD_LOGIC;
  signal rateswitchxndone_ipd  :STD_LOGIC;
  signal iqpautospdxnspgchg_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal rmfiforeset_ipd  :STD_LOGIC;
  signal coreclk_ipd  :STD_LOGIC;
  signal rmfifordena_ipd  :STD_LOGIC;
  signal disablefifordin_ipd  :STD_LOGIC;
  signal rateswitch_ipd  :STD_LOGIC;
  signal hipelecidleinfersel_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal phfifox4rdenable_ipd  :STD_LOGIC;
  signal pipe8b10binvpolarity_ipd  :STD_LOGIC;
  signal fifordin_ipd  :STD_LOGIC;
  signal ppmdetectrefclk_ipd  :STD_LOGIC;
  signal prbscidenable_ipd  :STD_LOGIC;
  signal digitalreset_ipd  :STD_LOGIC;
  signal rxfound_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal cdrctrllocktorefcl_ipd  :STD_LOGIC;
  signal phfifoxnwrclk_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal iqpphfifoxnbytesel_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal autospdxnspdchg_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal phfifoxnwrenable_ipd  :STD_LOGIC_VECTOR(2 DOWNTO 0);
  signal fiforesetrd_ipd  :STD_LOGIC;
  signal xgmdatain_ipd  :STD_LOGIC_VECTOR(7 DOWNTO 0);
   COMPONENT stratixiv_hssi_rx_digi
      PORT (
         hard_reset                                  : IN STD_LOGIC;
         rxpcs_rst                                   : IN STD_LOGIC;
         rxpma_rst                                   : IN STD_LOGIC;
         cmpfifourst                                 : IN STD_LOGIC;
         phfifourst_rx                               : IN STD_LOGIC;
         scan_mode                                   : IN STD_LOGIC;
         encdt                                       : IN STD_LOGIC;
         a1a2_size                                   : IN STD_LOGIC;
         bitslip                                     : IN STD_LOGIC;
         rdenable_rmf                                : IN STD_LOGIC;
         wrenable_rmf                                : IN STD_LOGIC;
         pld_rx_clk                                  : IN STD_LOGIC;
         soft_reset_rclk1                            : OUT STD_LOGIC;
         polinv_rx                                   : IN STD_LOGIC;
         bitloc_rev_en                               : IN STD_LOGIC;
         byte_rev_en                                 : IN STD_LOGIC;
         rcvd_clk_pma                                : IN STD_LOGIC;
         pudi                                        : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
         sigdetni                                    : IN STD_LOGIC;
         fifo_rst_rd_qd                              : IN STD_LOGIC;
         fifo_rst_rd_gp                              : IN STD_LOGIC;
         en_dskw_qd                                  : IN STD_LOGIC;
         en_dskw_gp                                  : IN STD_LOGIC;
         is_lane0                                    : IN STD_LOGIC;
         align_status                                : IN STD_LOGIC;
         align_status_sync_0                         : IN STD_LOGIC;
         align_status_sync_2                         : IN STD_LOGIC;
         rx_data_rs                                  : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         rx_control_rs                               : IN STD_LOGIC;
         rcvd_clk0_pma                               : IN STD_LOGIC;
         fifo_rd_in_comp_0                           : IN STD_LOGIC;
         fifo_rd_in_comp_2                           : IN STD_LOGIC;
         txlp20b                                     : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
         refclk_pma                                  : IN STD_LOGIC;
         tx_pma_clk                                  : IN STD_LOGIC;
         fref                                        : IN STD_LOGIC;
         clklow                                      : IN STD_LOGIC;
         bytordpld                                   : IN STD_LOGIC;
         wrdisable_rx                                : IN STD_LOGIC;
         rdenable_rx                                 : IN STD_LOGIC;
         pma_testbus                                 : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         encoder_testbus                             : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         tx_ctrl_testbus                             : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         phystatus_int                               : IN STD_LOGIC;
         rxvalid_int                                 : IN STD_LOGIC;
         rxstatus_int                                : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         powerdown                                   : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         fifo_rd_out_comp                            : OUT STD_LOGIC;
         rxd                                         : OUT STD_LOGIC_VECTOR(63 DOWNTO 0);
         rev_loop_data                               : OUT STD_LOGIC_VECTOR(19 DOWNTO 0);
         rx_clk                                      : OUT STD_LOGIC;
         bisterr                                     : OUT STD_LOGIC;
         cg_comma                                    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         clk_2_b                                     : OUT STD_LOGIC;
         rcvd_clk_pma_b                              : OUT STD_LOGIC;
         sync_status                                 : OUT STD_LOGIC;
         align_status_sync                           : OUT STD_LOGIC;
         dec_data_valid                              : OUT STD_LOGIC;
         dec_data                                    : OUT STD_LOGIC_VECTOR(7 DOWNTO 0);
         dec_ctl                                     : OUT STD_LOGIC;
         running_disp                                : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         selftest_done                               : OUT STD_LOGIC;
         selftest_err                                : OUT STD_LOGIC;
         err_data                                    : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         err_ctl                                     : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         prbs_done                                   : OUT STD_LOGIC;
         prbs_err_lt                                 : OUT STD_LOGIC;
         signal_detect_out                           : OUT STD_LOGIC;
         align_det_sync                              : OUT STD_LOGIC;
         rd_align                                    : OUT STD_LOGIC;
         bistdone                                    : OUT STD_LOGIC;
         rlv                                         : OUT STD_LOGIC;
         rlv_lt                                      : OUT STD_LOGIC;
         almost_fl_rmf                               : OUT STD_LOGIC;
         full_rmf                                    : OUT STD_LOGIC;
         almost_mt_rmf                               : OUT STD_LOGIC;
         empty_rmf                                   : OUT STD_LOGIC;
         freq_lock                                   : OUT STD_LOGIC;
         full_rx                                     : OUT STD_LOGIC;
         empty_rx                                    : OUT STD_LOGIC;
         a1a2_k1k2_flag                              : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
         byteord_flag                                : OUT STD_LOGIC;
         rx_pipe_clk                                 : OUT STD_LOGIC;
         chnl_test_bus_out                           : OUT STD_LOGIC_VECTOR(9 DOWNTO 0);
         rx_pipe_soft_reset                          : OUT STD_LOGIC;
         phystatus                                   : OUT STD_LOGIC;
         rxvalid                                     : OUT STD_LOGIC;
         rxstatus                                    : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         pipe_data                                   : OUT STD_LOGIC_VECTOR(63 DOWNTO 0);
         rskpsetbased                                : IN STD_LOGIC;
         rtruebac2bac                                : IN STD_LOGIC;
         rcmpfifourst                                : IN STD_LOGIC;
         rphfifourstrx                               : IN STD_LOGIC;
         rcomp_size                                  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rcomp_pat                                   : IN STD_LOGIC_VECTOR(39 DOWNTO 0);
         rrundisp                                    : IN STD_LOGIC_VECTOR(5 DOWNTO 0);
         rib_inv_cd                                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rrlv_en                                     : IN STD_LOGIC;
         rsync_sm_dis                                : IN STD_LOGIC;
         rautobtalg_dis                              : IN STD_LOGIC;
         rdis_rx_disp                                : IN STD_LOGIC;
         rmatchen                                    : IN STD_LOGIC;
         rgenericfifo                                : IN STD_LOGIC;
         rendec_rx                                   : IN STD_LOGIC;
         rdwidth_rx                                  : IN STD_LOGIC;
         rlp20ben                                    : IN STD_LOGIC;
         rrxfifo_dis                                 : IN STD_LOGIC;
         rpmadwidth_rx                               : IN STD_LOGIC;
         rpma_doublewidth_rx                         : IN STD_LOGIC;
         renumber                                    : IN STD_LOGIC_VECTOR(5 DOWNTO 0);
         rknumber                                    : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         renpolinv_rx                                : IN STD_LOGIC;
         rgnumber                                    : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         rclkcmpsqmd                                 : IN STD_LOGIC;
         rclkcmpsq1p                                 : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
         rclkcmpsq1n                                 : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
         rclkcmp_pipe_en                             : IN STD_LOGIC;
         rosnumber                                   : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rosbased                                    : IN STD_LOGIC;
         rkchar                                      : IN STD_LOGIC;
         rcascaded_8b10b_en_rx                       : IN STD_LOGIC;
         resync_badcg_en                             : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rencdt_rising                               : IN STD_LOGIC;
         rcomp_pat_porn                              : IN STD_LOGIC;
         rprbsen_rx                                  : IN STD_LOGIC;
         rprbs_clr_rslt_rx                           : IN STD_LOGIC;
         rbisten_rx                                  : IN STD_LOGIC;
         rbist_clr_rx                                : IN STD_LOGIC;
         rwa_6g_en                                   : IN STD_LOGIC;
         rbytord_2sym_en                             : IN STD_LOGIC;
         rbysync_polinv_en                           : IN STD_LOGIC;
         rbytord_6g_mask_en                          : IN STD_LOGIC;
         rbytord_s2gx                                : IN STD_LOGIC;
         rbitloc_rev_en                              : IN STD_LOGIC;
         rbyte_rev_en                                : IN STD_LOGIC;
         rbyteorden                                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rbytordplden                                : IN STD_LOGIC;
         rphfifopldenrx                              : IN STD_LOGIC;
         rautoinsdis                                 : IN STD_LOGIC;
         rppmsel                                     : IN STD_LOGIC_VECTOR(5 DOWNTO 0);
         rforce0_freqdet                             : IN STD_LOGIC;
         rforce1_freqdet                             : IN STD_LOGIC;
         rbytordpat                                  : IN STD_LOGIC_VECTOR(19 DOWNTO 0);
         rbytordpad                                  : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         rforce_sig_det_pcs                          : IN STD_LOGIC;
         rfreerun_rx                                 : IN STD_LOGIC;
         rrcvd_clk_sel                               : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rclk_1_sel                                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rclk_2_sel                                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rrx_rd_clk_sel                              : IN STD_LOGIC;
         rall_one_dect_only                          : IN STD_LOGIC;
         rtest_bus_sel                               : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         r8b10b_dec_ibm_en                           : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rrxfifo_lowlatency_en                       : IN STD_LOGIC;
         rppm_cnt_reset                              : IN STD_LOGIC;
         sel_gp_md                                   : IN STD_LOGIC;
         rclkcmpinsertpad                            : IN STD_LOGIC;
         rindv_rx                                    : IN STD_LOGIC;
         dskwclksel                                  : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rdskposdisp                                 : IN STD_LOGIC;
         rdskchrp                                    : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         rendec_data_sel_rx                          : IN STD_LOGIC;
         rprbs_sel                                   : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rbist_sel                                   : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rcxpat_chnl_en                              : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rstart_threshold                            : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rins_threshold                              : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         rdel_threshold                              : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         rfull_threshold                             : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         rempty_threshold                            : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rinvalid_code_err_only                      : IN STD_LOGIC;
         rrxpcsbypass_en                             : IN STD_LOGIC;
         rfts_count                                  : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         rcid_pattern_rx                             : IN STD_LOGIC;
         rcid_len_rx                                 : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         rauto_speed_ena                             : IN STD_LOGIC;
         rphfifo_regmode_rx                          : IN STD_LOGIC;
         rfreq_sel                                   : IN STD_LOGIC;
         rate                                        : IN STD_LOGIC;
         gen2ngen1                                   : IN STD_LOGIC;
         gen2ngen1_bundle                            : IN STD_LOGIC;
         speed_change                                : OUT STD_LOGIC;
         rx_div2_sync_in_centrl                      : IN STD_LOGIC;
         rx_div2_sync_in_quad_up                     : IN STD_LOGIC;
         rx_div2_sync_in_quad_down                   : IN STD_LOGIC;
         reset_pc_ptrs_in_centrl                     : IN STD_LOGIC;
         reset_pc_ptrs_in_quad_up                    : IN STD_LOGIC;
         reset_pc_ptrs_in_quad_down                  : IN STD_LOGIC;
         wr_enable_in_centrl                         : IN STD_LOGIC;
         wr_enable_in_quad_up                        : IN STD_LOGIC;
         wr_enable_in_quad_down                      : IN STD_LOGIC;
         rd_enable_in_centrl                         : IN STD_LOGIC;
         rd_enable_in_quad_up                        : IN STD_LOGIC;
         rd_enable_in_quad_down                      : IN STD_LOGIC;
         rx_we_in_centrl                             : IN STD_LOGIC;
         rx_we_in_quad_up                            : IN STD_LOGIC;
         rx_we_in_quad_down                          : IN STD_LOGIC;
         speed_change_in_centrl                      : IN STD_LOGIC;
         rx_div2_sync_in_pipe_quad_up                : IN STD_LOGIC;
         rx_div2_sync_in_pipe_quad_down              : IN STD_LOGIC;
         reset_pc_ptrs_in_pipe_quad_up               : IN STD_LOGIC;
         reset_pc_ptrs_in_pipe_quad_down             : IN STD_LOGIC;
         wr_enable_in_pipe_quad_up                   : IN STD_LOGIC;
         wr_enable_in_pipe_quad_down                 : IN STD_LOGIC;
         rd_enable_in_pipe_quad_up                   : IN STD_LOGIC;
         rd_enable_in_pipe_quad_down                 : IN STD_LOGIC;
         rx_we_in_pipe_quad_up                       : IN STD_LOGIC;
         rx_we_in_pipe_quad_down                     : IN STD_LOGIC;
         speed_change_in_pipe_quad_up                : IN STD_LOGIC;
         speed_change_in_pipe_quad_down              : IN STD_LOGIC;
         config_sel_centrl                           : IN STD_LOGIC;
         config_sel_quad_up                          : IN STD_LOGIC;
         config_sel_quad_down                        : IN STD_LOGIC;
         rmaster_rx                                  : IN STD_LOGIC;
         rmaster_up_rx                               : IN STD_LOGIC;
         rpipeline_bypass_rx                         : IN STD_LOGIC;
         rauto_deassert_pc_rst_cnt                   : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         rauto_pc_en_cnt                             : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         rself_sw_en_rx                              : IN STD_LOGIC;
         rx_div2_sync_out_pipe_up                    : OUT STD_LOGIC;
         rx_we_out_pipe_up                           : OUT STD_LOGIC;
         wr_enable_out_pipe_up                       : OUT STD_LOGIC;
         rd_enable_out_pipe_up                       : OUT STD_LOGIC;
         reset_pc_ptrs_out_pipe_up                   : OUT STD_LOGIC;
         speed_change_out_pipe_up                    : OUT STD_LOGIC;
         rx_div2_sync_out_pipe_down                  : OUT STD_LOGIC;
         rx_we_out_pipe_down                         : OUT STD_LOGIC;
         wr_enable_out_pipe_down                     : OUT STD_LOGIC;
         rd_enable_out_pipe_down                     : OUT STD_LOGIC;
         reset_pc_ptrs_out_pipe_down                 : OUT STD_LOGIC;
         speed_change_out_pipe_down                  : OUT STD_LOGIC;
         dis_pc_byte                                 : OUT STD_LOGIC;
         reset_pc_ptrs                               : OUT STD_LOGIC;
         pcie_switch                                 : OUT STD_LOGIC;
         reidleinferenable                           : IN STD_LOGIC;
         reidle_com_detect                           : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         eidleinfersel                               : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         pipe_loopbk                                 : IN STD_LOGIC;
         rxelecidle_int                              : OUT STD_LOGIC;
         rpma_done_count                             : IN STD_LOGIC_VECTOR(17 DOWNTO 0);
         riei_eios_priority_dis                      : IN STD_LOGIC;
         rgen1_sigdet_ena                            : IN STD_LOGIC;
         rrxpcsclkpwdn                               : IN STD_LOGIC;
         rcdr_ctrl_en                                : IN STD_LOGIC;
         rcid_en                                     : IN STD_LOGIC;
         rrxvalid_mask                               : IN STD_LOGIC;
         rwait_count                                 : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         rmask_count                                 : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         pld_ltr                                     : IN STD_LOGIC;
         early_eios                                  : OUT STD_LOGIC;
         ltr                                         : OUT STD_LOGIC;
         prbs_cid_en                                 : IN STD_LOGIC;
         wa_boundary                                 : OUT STD_LOGIC_VECTOR(4 DOWNTO 0);
         tx_div2_sync_out_pipe_up                    : IN STD_LOGIC;
         fifo_select_out_pipe_up                     : IN STD_LOGIC;
         tx_wr_enable_out_pipe_up                    : IN STD_LOGIC;
         tx_rd_enable_out_pipe_up                    : IN STD_LOGIC;
         tx_div2_sync_out_pipe_down                  : IN STD_LOGIC;
         fifo_select_out_pipe_down                   : IN STD_LOGIC;
         tx_wr_enable_out_pipe_down                  : IN STD_LOGIC;
         tx_rd_enable_out_pipe_down                  : IN STD_LOGIC;
         rwait_for_phfifo_cnt                        : IN STD_LOGIC_VECTOR(5 DOWNTO 0);
         rppm_post_eidle_del                         : IN STD_LOGIC;
         rppm_gen1_2xcnt_en                          : IN STD_LOGIC;
         cg_comp_rd_d_ch0                            : IN STD_LOGIC;
         cg_comp_rd_d_ch1                            : IN STD_LOGIC;
         cg_comp_rd_d_ch2                            : IN STD_LOGIC;
         cg_comp_rd_d_ch3                            : IN STD_LOGIC;
         cg_comp_wr_ch0                              : IN STD_LOGIC;
         cg_comp_wr_ch1                              : IN STD_LOGIC;
         cg_comp_wr_ch2                              : IN STD_LOGIC;
         cg_comp_wr_ch3                              : IN STD_LOGIC;
         cg_comp_rd_d_out                            : OUT STD_LOGIC;
         cg_comp_wr_out                              : OUT STD_LOGIC;
         del_cond_met_0                              : IN STD_LOGIC;
         fifo_ovr_0                                  : IN STD_LOGIC;
         latency_comp_0                              : IN STD_LOGIC;
         insert_incomplete_0                         : IN STD_LOGIC;
         del_cond_met_out                            : OUT STD_LOGIC;
         fifo_ovr_out                                : OUT STD_LOGIC;
         latency_comp_out                            : OUT STD_LOGIC;
         insert_incomplete_out                       : OUT STD_LOGIC;
         
         -- ww25.2008
         rrx_pipe_enable                             : IN STD_LOGIC;
         rpcs_wrapback_en                            : IN STD_LOGIC;
         rerr_flags_sel                              : IN STD_LOGIC;
         pcs_wrapback_in                             : IN STD_LOGIC_VECTOR(69 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_digi_chnl_hip_spt
      PORT (
         rhip_ena                                    : IN STD_LOGIC;
         pcs_rxd_ch                                  : IN STD_LOGIC_VECTOR(8 DOWNTO 0);
         pcs_rxvalid                                 : IN STD_LOGIC;
         pcs_rxelecidle                              : IN STD_LOGIC;
         pcs_rxstatus_ch                             : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         pcs_phystatus                               : IN STD_LOGIC;
         txpma_local_clk                             : IN STD_LOGIC;
         txd_ch                                      : IN STD_LOGIC_VECTOR(10 DOWNTO 0);
         hip_txd_ch                                  : IN STD_LOGIC_VECTOR(9 DOWNTO 0);
         txdetectrxloopback                          : IN STD_LOGIC;
         hip_txdetectrxloopback                      : IN STD_LOGIC;
         rxpolarity                                  : IN STD_LOGIC;
         hip_rxpolarity                              : IN STD_LOGIC;
         powerdown_ch                                : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         hip_powerdown_ch                            : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         txdeemph                                    : IN STD_LOGIC;
         hip_txdeemph                                : IN STD_LOGIC;
         txmargin_ch                                 : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         hip_txmargin_ch                             : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         eidleinfersel_ch                            : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         hip_eidleinfersel_ch                        : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rate                                        : IN STD_LOGIC;
         hip_rate                                    : IN STD_LOGIC;
         hip_txelecidle                              : IN STD_LOGIC;
         rxd_ch                                      : OUT STD_LOGIC_VECTOR(8 DOWNTO 0);
         hip_rxd_ch                                  : OUT STD_LOGIC_VECTOR(8 DOWNTO 0);
         rxvalid                                     : OUT STD_LOGIC;
         hip_rxvalid                                 : OUT STD_LOGIC;
         rxelecidle                                  : OUT STD_LOGIC;
         hip_rxelecidle                              : OUT STD_LOGIC;
         rxstatus_ch                                 : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         hip_rxstatus_ch                             : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         phystatus                                   : OUT STD_LOGIC;
         hip_phystatus                               : OUT STD_LOGIC;
         hip_tx_clk                                  : OUT STD_LOGIC;
         pcs_txd_ch                                  : OUT STD_LOGIC_VECTOR(10 DOWNTO 0);
         pcs_txdetectrxloopback                      : OUT STD_LOGIC;
         pcs_rxpolarity                              : OUT STD_LOGIC;
         pcs_powerdown_ch                            : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         pcs_txdeemph                                : OUT STD_LOGIC;
         pcs_txmargin_ch                             : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         pcs_eidleinfersel_ch                        : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         pcs_rate                                    : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_q_pipe_interface_top
      PORT (
         pipe_tx_clk                                 : IN STD_LOGIC;
         pipe_rx_clk                                 : IN STD_LOGIC;
         refclk_b                                    : IN STD_LOGIC;
         tx_pipe_reset                               : IN STD_LOGIC;
         rx_pipe_reset                               : IN STD_LOGIC;
         refclk_b_reset                              : IN STD_LOGIC;
         rtx_pipe_enable                             : IN STD_LOGIC;
         rrx_pipe_enable                             : IN STD_LOGIC;
         rrdwidth_rx                                 : IN STD_LOGIC;
         rtx_elec_idle_delay                         : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         rtxswing_sel_ena                            : IN STD_LOGIC;
         rrx_detect_bypass                           : IN STD_LOGIC;
         rclkcmpinsertpad                            : IN STD_LOGIC;
         rind_error_reporting                        : IN STD_LOGIC;
         rphystatus_rst_toggle                       : IN STD_LOGIC;
         rphystatus_delay                            : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         txdetectrxloopback                          : IN STD_LOGIC;
         txelecidle                                  : IN STD_LOGIC;
         powerdown                                   : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         txdeemph                                    : IN STD_LOGIC;
         txmargin                                    : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
         txswing                                     : IN STD_LOGIC;
         txd_ch                                      : IN STD_LOGIC_VECTOR(43 DOWNTO 0);
         rxpolarity                                  : IN STD_LOGIC;
         rxvalid                                     : OUT STD_LOGIC;
         rxelecidle                                  : OUT STD_LOGIC;
         rxstatus                                    : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         rxd_ch                                      : OUT STD_LOGIC_VECTOR(63 DOWNTO 0);
         phystatus                                   : OUT STD_LOGIC;
         revloopback                                 : IN STD_LOGIC;
         polinv_rx                                   : IN STD_LOGIC;
         txd                                         : OUT STD_LOGIC_VECTOR(43 DOWNTO 0);
         rev_loopbk                                  : OUT STD_LOGIC;
         tx_elec_idle_comp                           : IN STD_LOGIC;
         rindv_rx                                    : IN STD_LOGIC;
         rmaster_rx                                  : IN STD_LOGIC;
         rmaster_up_rx                               : IN STD_LOGIC;
         speed_change                                : IN STD_LOGIC;
         speed_change_centrl                         : IN STD_LOGIC;
         speed_change_quad_up                        : IN STD_LOGIC;
         speed_change_quad_down                      : IN STD_LOGIC;
         rxd                                         : IN STD_LOGIC_VECTOR(63 DOWNTO 0);
         polinv_rx_int                               : OUT STD_LOGIC;
         tx_elec_idle                                : OUT STD_LOGIC;
         txdetectrx                                  : OUT STD_LOGIC;
         powerstate                                  : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
         sigdetni                                    : IN STD_LOGIC;  -- ww25_2008
         rx_found                                    : IN STD_LOGIC;
         rx_detect_valid                             : IN STD_LOGIC;
         rxelectricalidle                            : IN STD_LOGIC;
         txdetectrxin                                : IN STD_LOGIC;
         powerstatein                                : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         use_powerstatein                            : IN STD_LOGIC;
         power_state_transition_done                 : IN STD_LOGIC;
         power_state_transition_done_ena             : IN STD_LOGIC;
         txdeemph_int                                : OUT STD_LOGIC;
         txmargin_int                                : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
         txswing_int                                 : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_pcs_reset
      PORT (
         hard_reset                                  : IN STD_LOGIC;
         clk_2_b                                     : IN STD_LOGIC;
         refclk_b_in                                 : IN STD_LOGIC;
         scan_mode                                   : IN STD_LOGIC;
         rxpcs_rst                                   : IN STD_LOGIC;
         txpcs_rst                                   : IN STD_LOGIC;
         rxrst_int                                   : OUT STD_LOGIC;
         txrst_int                                   : OUT STD_LOGIC
      );
   END COMPONENT;
   
   --///////////////////////////////////////////////////////////////////////////
   -- Temp registers to reslove fixed width => varaiable width output transfer --//
   --///////////////////////////////////////////////////////////////////////////
   
   SIGNAL a1a2sizeout_reg                       : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL a1detect_reg                          : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL a2detect_reg                          : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL ctrldetect_reg                        : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL dataout_reg                           : STD_LOGIC_VECTOR(39 DOWNTO 0);
   SIGNAL disperr_reg                           : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL errdetect_reg                         : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL k1detect_reg                          : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL k2detect_reg                          : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL patterndetect_reg                     : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rmfifodatadeleted_reg                 : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rmfifodatainserted_reg                : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL runningdisp_reg                       : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL syncstatus_reg                        : STD_LOGIC_VECTOR(3 DOWNTO 0);
   
   	-- new dprio model --
   	-- Table5: PCS Per Channel RX Control Register 1 for Channel 0
	constant rrxpcsbypass_en_RXPCS_IDX_0	: integer := 0;
	constant rall_one_dect_only_RXPCS_IDX_0	: integer := 1;
	constant rbist_clr_rx_RXPCS_IDX_0	: integer := 2;
	constant rbisten_rx_RXPCS_IDX_0	: integer := 3;
	constant rprbs_clr_rslt_rx_RXPCS_IDX_0	: integer := 4;
	constant rprbsen_rx_RXPCS_IDX_0	: integer := 5;
	constant rrx_rd_clk_sel_RXPCS_IDX_0	: integer := 6;
	constant rclk_2_sel_RXPCS_IDX_0	: integer := 7;
	constant rclk_2_sel_RXPCS_IDX_1	: integer := 8;
	constant rclk_1_sel_RXPCS_IDX_0	: integer := 9;
	constant rclk_1_sel_RXPCS_IDX_1	: integer := 10;
	constant rrcvd_clk_sel_RXPCS_IDX_0	: integer := 11;
	constant rrcvd_clk_sel_RXPCS_IDX_1	: integer := 12;
	constant rfreerun_rx_RXPCS_IDX_0	: integer := 13;
	constant rrxurstpcs_RXPCS_IDX_0	: integer := 14;
	constant reserved_0_TB5_RXPCS_IDX_0	: integer := 15;
	
	-- Table6: PCS Per Channel RX Control Register 2 for Channel 0
	constant rcomp_pat_32_RXPCS_IDX_0	: integer := 16;
	constant rcomp_pat_33_RXPCS_IDX_0	: integer := 17;
	constant rcomp_pat_34_RXPCS_IDX_0	: integer := 18;
	constant rcomp_pat_35_RXPCS_IDX_0	: integer := 19;
	constant rcomp_pat_36_RXPCS_IDX_0	: integer := 20;
	constant rcomp_pat_37_RXPCS_IDX_0	: integer := 21;
	constant rcomp_pat_38_RXPCS_IDX_0	: integer := 22;
	constant rcomp_pat_39_RXPCS_IDX_0	: integer := 23;
	constant rcomp_size_RXPCS_IDX_0	: integer := 24;
	constant rcomp_size_RXPCS_IDX_1	: integer := 25;
	constant rcomp_size_RXPCS_IDX_2	: integer := 26;
	constant rcomp_pat_porn_RXPCS_IDX_0	: integer := 27;
	constant rdis_rx_disp_RXPCS_IDX_0	: integer := 28;
	constant rencdt_rising_RXPCS_IDX_0	: integer := 29;
	constant resync_badcg_en_RXPCS_IDX_0	: integer := 30;
	constant resync_badcg_en_RXPCS_IDX_1	: integer := 31;
	
	-- Table7: PCS Per Channel RX Control Register 3 for Channel 0
	constant rcomp_pat_16_RXPCS_IDX_0	: integer := 32;
	constant rcomp_pat_17_RXPCS_IDX_0	: integer := 33;
	constant rcomp_pat_18_RXPCS_IDX_0	: integer := 34;
	constant rcomp_pat_19_RXPCS_IDX_0	: integer := 35;
	constant rcomp_pat_20_RXPCS_IDX_0	: integer := 36;
	constant rcomp_pat_21_RXPCS_IDX_0	: integer := 37;
	constant rcomp_pat_22_RXPCS_IDX_0	: integer := 38;
	constant rcomp_pat_23_RXPCS_IDX_0	: integer := 39;
	constant rcomp_pat_24_RXPCS_IDX_0	: integer := 40;
	constant rcomp_pat_25_RXPCS_IDX_0	: integer := 41;
	constant rcomp_pat_26_RXPCS_IDX_0	: integer := 42;
	constant rcomp_pat_27_RXPCS_IDX_0	: integer := 43;
	constant rcomp_pat_28_RXPCS_IDX_0	: integer := 44;
	constant rcomp_pat_29_RXPCS_IDX_0	: integer := 45;
	constant rcomp_pat_30_RXPCS_IDX_0	: integer := 46;
	constant rcomp_pat_31_RXPCS_IDX_0	: integer := 47;
	
	-- Table8: PCS Per Channel RX Control Register 4 for Channel 0
	constant rcomp_pat_0_RXPCS_IDX_0	: integer := 48;
	constant rcomp_pat_1_RXPCS_IDX_0	: integer := 49;
	constant rcomp_pat_2_RXPCS_IDX_0	: integer := 50;
	constant rcomp_pat_3_RXPCS_IDX_0	: integer := 51;
	constant rcomp_pat_4_RXPCS_IDX_0	: integer := 52;
	constant rcomp_pat_5_RXPCS_IDX_0	: integer := 53;
	constant rcomp_pat_6_RXPCS_IDX_0	: integer := 54;
	constant rcomp_pat_7_RXPCS_IDX_0	: integer := 55;
	constant rcomp_pat_8_RXPCS_IDX_0	: integer := 56;
	constant rcomp_pat_9_RXPCS_IDX_0	: integer := 57;
	constant rcomp_pat_10_RXPCS_IDX_0	: integer := 58;
	constant rcomp_pat_11_RXPCS_IDX_0	: integer := 59;
	constant rcomp_pat_12_RXPCS_IDX_0	: integer := 60;
	constant rcomp_pat_13_RXPCS_IDX_0	: integer := 61;
	constant rcomp_pat_14_RXPCS_IDX_0	: integer := 62;
	constant rcomp_pat_15_RXPCS_IDX_0	: integer := 63;
	
	-- Table9: PCS Per Channel RX Control Register 5 for Channel 0
	constant rbitloc_rev_en_RXPCS_IDX_0	: integer := 64;
	constant rbysync_polinv_en_RXPCS_IDX_0	: integer := 65;
	constant rwa_6g_en_RXPCS_IDX_0	: integer := 66;
	constant rosnumber_RXPCS_IDX_0	: integer := 67;
	constant rosnumber_RXPCS_IDX_1	: integer := 68;
	constant rosbased_RXPCS_IDX_0	: integer := 69;
	constant rkchar_RXPCS_IDX_0	: integer := 70;
	constant renumber_RXPCS_IDX_0	: integer := 71;
	constant renumber_RXPCS_IDX_1	: integer := 72;
	constant renumber_RXPCS_IDX_2	: integer := 73;
	constant renumber_RXPCS_IDX_3	: integer := 74;
	constant renumber_RXPCS_IDX_4	: integer := 75;
	constant renumber_RXPCS_IDX_5	: integer := 76;
	constant rib_inv_cd_RXPCS_IDX_0	: integer := 77;
	constant rib_inv_cd_RXPCS_IDX_1	: integer := 78;
	constant rsync_sm_dis_RXPCS_IDX_0	: integer := 79;
	
	-- Table10: PCS Per Channel RX Control Register 6 for Channel 0
	constant rknumber_RXPCS_IDX_0	: integer := 80;
	constant rknumber_RXPCS_IDX_1	: integer := 81;
	constant rknumber_RXPCS_IDX_2	: integer := 82;
	constant rknumber_RXPCS_IDX_3	: integer := 83;
	constant rknumber_RXPCS_IDX_4	: integer := 84;
	constant rknumber_RXPCS_IDX_5	: integer := 85;
	constant rknumber_RXPCS_IDX_6	: integer := 86;
	constant rknumber_RXPCS_IDX_7	: integer := 87;
	constant rgnumber_RXPCS_IDX_0	: integer := 88;
	constant rgnumber_RXPCS_IDX_1	: integer := 89;
	constant rgnumber_RXPCS_IDX_2	: integer := 90;
	constant rgnumber_RXPCS_IDX_3	: integer := 91;
	constant rgnumber_RXPCS_IDX_4	: integer := 92;
	constant rgnumber_RXPCS_IDX_5	: integer := 93;
	constant rgnumber_RXPCS_IDX_6	: integer := 94;
	constant rgnumber_RXPCS_IDX_7	: integer := 95;
	
	-- Table11: PCS Per Channel RX Control Register 7 for Channel 0
	constant renpolinv_rx_RXPCS_IDX_0	: integer := 96;
	constant rcascaded_8b10b_en_rx_RXPCS_IDX_0	: integer := 97;
	constant r8b10b_dec_ibm_en_RXPCS_IDX_0	: integer := 98;
	constant r8b10b_dec_ibm_en_RXPCS_IDX_1	: integer := 99;
	constant rendec_rx_RXPCS_IDX_0	: integer := 100;
	constant rautobtalg_dis_RXPCS_IDX_0	: integer := 101;
	constant rrlv_en_RXPCS_IDX_0	: integer := 102;
	constant rlp20ben_RXPCS_IDX_0	: integer := 103;
	constant rforce_sig_det_pcs_RXPCS_IDX_0	: integer := 104;
	constant rbyte_rev_en_RXPCS_IDX_0	: integer := 105;
	constant rrundisp_RXPCS_IDX_0	: integer := 106;
	constant rrundisp_RXPCS_IDX_1	: integer := 107;
	constant rrundisp_RXPCS_IDX_2	: integer := 108;
	constant rrundisp_RXPCS_IDX_3	: integer := 109;
	constant rrundisp_RXPCS_IDX_4	: integer := 110;
	constant rrundisp_RXPCS_IDX_5	: integer := 111;
	
	-- Table12: PCS Per Channel RX Control Register 8 for Channel 0
	constant rclkcmpsq1p_0_RXPCS_IDX_0	: integer := 112;
	constant rclkcmpsq1p_1_RXPCS_IDX_0	: integer := 113;
	constant rclkcmpsq1p_2_RXPCS_IDX_0	: integer := 114;
	constant rclkcmpsq1p_3_RXPCS_IDX_0	: integer := 115;
	constant rclkcmpsq1p_4_RXPCS_IDX_0	: integer := 116;
	constant rclkcmpsq1p_5_RXPCS_IDX_0	: integer := 117;
	constant rclkcmpsq1p_6_RXPCS_IDX_0	: integer := 118;
	constant rclkcmpsq1p_7_RXPCS_IDX_0	: integer := 119;
	constant rclkcmpsq1p_8_RXPCS_IDX_0	: integer := 120;
	constant rclkcmpsq1p_9_RXPCS_IDX_0	: integer := 121;
	constant rclkcmpsqmd_RXPCS_IDX_0	: integer := 122;
	constant rclkcmpinsertpad_RXPCS_IDX_0	: integer := 123;
	constant rtruebac2bac_RXPCS_IDX_0	: integer := 124;
	constant rskpsetbased_RXPCS_IDX_0	: integer := 125;
	constant rgenericfifo_RXPCS_IDX_0	: integer := 126;
	constant rmatchen_RXPCS_IDX_0	: integer := 127;
	
	-- Table13: PCS Per Channel RX Control Register 9 for Channel 0
	constant rclkcmpsq1p_10_RXPCS_IDX_0	: integer := 128;
	constant rclkcmpsq1p_11_RXPCS_IDX_0	: integer := 129;
	constant rclkcmpsq1p_12_RXPCS_IDX_0	: integer := 130;
	constant rclkcmpsq1p_13_RXPCS_IDX_0	: integer := 131;
	constant rclkcmpsq1p_14_RXPCS_IDX_0	: integer := 132;
	constant rclkcmpsq1p_15_RXPCS_IDX_0	: integer := 133;
	constant rclkcmpsq1p_16_RXPCS_IDX_0	: integer := 134;
	constant rclkcmpsq1p_17_RXPCS_IDX_0	: integer := 135;
	constant rclkcmpsq1p_18_RXPCS_IDX_0	: integer := 136;
	constant rclkcmpsq1p_19_RXPCS_IDX_0	: integer := 137;
	constant reserved_0_TB13_RXPCS_IDX_0	: integer := 138;
	constant rclkcmpsq1n_15_RXPCS_IDX_0	: integer := 139;
	constant rclkcmpsq1n_16_RXPCS_IDX_0	: integer := 140;
	constant rclkcmpsq1n_17_RXPCS_IDX_0	: integer := 141;
	constant rclkcmpsq1n_18_RXPCS_IDX_0	: integer := 142;
	constant rclkcmpsq1n_19_RXPCS_IDX_0	: integer := 143;
	
	-- Table14: PCS Per Channel RX Control Register 10 for Channel 0
	constant rclkcmpsq1n_0_RXPCS_IDX_0	: integer := 144;
	constant rclkcmpsq1n_1_RXPCS_IDX_0	: integer := 145;
	constant rclkcmpsq1n_2_RXPCS_IDX_0	: integer := 146;
	constant rclkcmpsq1n_3_RXPCS_IDX_0	: integer := 147;
	constant rclkcmpsq1n_4_RXPCS_IDX_0	: integer := 148;
	constant rclkcmpsq1n_5_RXPCS_IDX_0	: integer := 149;
	constant rclkcmpsq1n_6_RXPCS_IDX_0	: integer := 150;
	constant rclkcmpsq1n_7_RXPCS_IDX_0	: integer := 151;
	constant rclkcmpsq1n_8_RXPCS_IDX_0	: integer := 152;
	constant rclkcmpsq1n_9_RXPCS_IDX_0	: integer := 153;
	constant reserved_0_TB14_RXPCS_IDX_0	: integer := 154;
	constant rclkcmpsq1n_10_RXPCS_IDX_0	: integer := 155;
	constant rclkcmpsq1n_11_RXPCS_IDX_0	: integer := 156;
	constant rclkcmpsq1n_12_RXPCS_IDX_0	: integer := 157;
	constant rclkcmpsq1n_13_RXPCS_IDX_0	: integer := 158;
	constant rclkcmpsq1n_14_RXPCS_IDX_0	: integer := 159;
	
	-- Table15: PCS Per Channel RX Control Register 11 for Channel 0
	constant rfull_threshold_RXPCS_IDX_0	: integer := 160;
	constant rfull_threshold_RXPCS_IDX_1	: integer := 161;
	constant rfull_threshold_RXPCS_IDX_2	: integer := 162;
	constant rfull_threshold_RXPCS_IDX_3	: integer := 163;
	constant rfull_threshold_RXPCS_IDX_4	: integer := 164;
	constant rdel_threshold_RXPCS_IDX_0	: integer := 165;
	constant rdel_threshold_RXPCS_IDX_1	: integer := 166;
	constant rdel_threshold_RXPCS_IDX_2	: integer := 167;
	constant rdel_threshold_RXPCS_IDX_3	: integer := 168;
	constant rdel_threshold_RXPCS_IDX_4	: integer := 169;
	constant rins_threshold_RXPCS_IDX_0	: integer := 170;
	constant rins_threshold_RXPCS_IDX_1	: integer := 171;
	constant rins_threshold_RXPCS_IDX_2	: integer := 172;
	constant rins_threshold_RXPCS_IDX_3	: integer := 173;
	constant rins_threshold_RXPCS_IDX_4	: integer := 174;
	constant rclkcmp_pipe_en_RXPCS_IDX_0	: integer := 175;
	
	-- Table16: PCS Per Channel RX Control Register 12 for Channel 0
	constant rfreq_sel_RXPCS_IDX_0	: integer := 176;
	constant rauto_speed_ena_RXPCS_IDX_0	: integer := 177;
	constant rhip_ena_RXPCS_IDX_0	: integer := 178;
	constant rpma_done_gen_ena_RXPCS_IDX_0	: integer := 179;
	constant rpma_done_count_16_RXPCS_IDX_0	: integer := 180;
	constant rpma_done_count_17_RXPCS_IDX_0	: integer := 181;
	constant reserved_0_TB16_RXPCS_IDX_0	: integer := 182;
	constant reserved_0_TB16_RXPCS_IDX_1	: integer := 183;
	constant reserved_0_TB16_RXPCS_IDX_2	: integer := 184;
	constant reserved_0_TB16_RXPCS_IDX_3	: integer := 185;
	constant rstart_threshold_RXPCS_IDX_0	: integer := 186;
	constant rstart_threshold_RXPCS_IDX_1	: integer := 187;
	constant rstart_threshold_RXPCS_IDX_2	: integer := 188;
	constant rempty_threshold_RXPCS_IDX_0	: integer := 189;
	constant rempty_threshold_RXPCS_IDX_1	: integer := 190;
	constant rempty_threshold_RXPCS_IDX_2	: integer := 191;
	
	-- Table17: PCS Per Channel RX Control Register 13 for Channel 0
	constant rtest_bus_sel_RXPCS_IDX_0	: integer := 192;
	constant rtest_bus_sel_RXPCS_IDX_1	: integer := 193;
	constant rtest_bus_sel_RXPCS_IDX_2	: integer := 194;
	constant rtest_bus_sel_RXPCS_IDX_3	: integer := 195;
	constant rautoinsdis_RXPCS_IDX_0	: integer := 196;
	constant rphfifopldenrx_RXPCS_IDX_0	: integer := 197;
	constant rbytordplden_RXPCS_IDX_0	: integer := 198;
	constant rbyteorden_RXPCS_IDX_0	: integer := 199;
	constant rbyteorden_RXPCS_IDX_1	: integer := 200;
	constant rbytord_2sym_en_RXPCS_IDX_0	: integer := 201;
	constant rinvalid_code_err_only_RXPCS_IDX_0	: integer := 202;
	constant rcmpfifourst_RXPCS_IDX_0	: integer := 203;
	constant rphfifourstrx_RXPCS_IDX_0	: integer := 204;
	constant rdwidth_rx_RXPCS_IDX_0	: integer := 205;
	constant rrxfifo_lowlatency_en_RXPCS_IDX_0	: integer := 206;
	constant rrxfifo_dis_RXPCS_IDX_0	: integer := 207;
	
	-- Table18: PCS Per Channel RX Control Register 14 for Channel 0
	constant rbytordpat_0_RXPCS_IDX_0	: integer := 208;
	constant rbytordpat_1_RXPCS_IDX_0	: integer := 209;
	constant rbytordpat_2_RXPCS_IDX_0	: integer := 210;
	constant rbytordpat_3_RXPCS_IDX_0	: integer := 211;
	constant rbytordpat_4_RXPCS_IDX_0	: integer := 212;
	constant rbytordpat_5_RXPCS_IDX_0	: integer := 213;
	constant rbytordpat_6_RXPCS_IDX_0	: integer := 214;
	constant rbytordpat_7_RXPCS_IDX_0	: integer := 215;
	constant rbytordpat_8_RXPCS_IDX_0	: integer := 216;
	constant rbytordpat_9_RXPCS_IDX_0	: integer := 217;
	constant reserved_0_TB18_RXPCS_IDX_0	: integer := 218;
	constant reserved_0_TB18_RXPCS_IDX_1	: integer := 219;
	constant reserved_0_TB18_RXPCS_IDX_2	: integer := 220;
	constant reserved_0_TB18_RXPCS_IDX_3	: integer := 221;
	constant reserved_0_TB18_RXPCS_IDX_4	: integer := 222;
	constant reserved_0_TB18_RXPCS_IDX_5	: integer := 223;
	
	-- Table19: PCS Per Channel RX Control Register 15 for Channel 0
	constant rbytordpad_RXPCS_IDX_0	: integer := 224;
	constant rbytordpad_RXPCS_IDX_1	: integer := 225;
	constant rbytordpad_RXPCS_IDX_2	: integer := 226;
	constant rbytordpad_RXPCS_IDX_3	: integer := 227;
	constant rbytordpad_RXPCS_IDX_4	: integer := 228;
	constant rbytordpad_RXPCS_IDX_5	: integer := 229;
	constant rbytordpad_RXPCS_IDX_6	: integer := 230;
	constant rbytordpad_RXPCS_IDX_7	: integer := 231;
	constant rbytordpad_RXPCS_IDX_8	: integer := 232;
	constant rbytordpad_RXPCS_IDX_9	: integer := 233;
	constant reserved_0_TB19_RXPCS_IDX_0	: integer := 234;
	constant reserved_0_TB19_RXPCS_IDX_1	: integer := 235;
	constant reserved_0_TB19_RXPCS_IDX_2	: integer := 236;
	constant reserved_0_TB19_RXPCS_IDX_3	: integer := 237;
	constant reserved_0_TB19_RXPCS_IDX_4	: integer := 238;
	constant reserved_0_TB19_RXPCS_IDX_5	: integer := 239;
	
	-- Table20: PCS Per Channel RX Control Register 16 for Channel 0
	constant rload_shreg_del_RXPCS_IDX_0	: integer := 240;
	constant rload_shreg_del_RXPCS_IDX_1	: integer := 241;
	constant rload_shreg_del_RXPCS_IDX_2	: integer := 242;
	constant rload_shreg_del_RXPCS_IDX_3	: integer := 243;
	constant rload_shreg_del_RXPCS_IDX_4	: integer := 244;
	constant rphystatus_rst_toggle_RXPCS_IDX_0	: integer := 245;
	constant reidle_com_detect_RXPCS_IDX_0	: integer := 246;
	constant reidle_com_detect_RXPCS_IDX_1	: integer := 247;
	constant rk285detect_RXPCS_IDX_0	: integer := 248;
	constant reidleinferenable_RXPCS_IDX_0	: integer := 249;
	constant rphystatus_delay_RXPCS_IDX_0	: integer := 250;
	constant rphystatus_delay_RXPCS_IDX_1	: integer := 251;
	constant rphystatus_delay_RXPCS_IDX_2	: integer := 252;
	constant rind_error_reporting_RXPCS_IDX_0	: integer := 253;
	constant rrx_detect_bypass_RXPCS_IDX_0	: integer := 254;
	constant rrx_pipe_enable_RXPCS_IDX_0	: integer := 255;
	
	-- Table21: PCS Per Channel RX Control Register 17 for Channel 0
	constant rpma_done_count_0_RXPCS_IDX_0	: integer := 256;
	constant rpma_done_count_1_RXPCS_IDX_0	: integer := 257;
	constant rpma_done_count_2_RXPCS_IDX_0	: integer := 258;
	constant rpma_done_count_3_RXPCS_IDX_0	: integer := 259;
	constant rpma_done_count_4_RXPCS_IDX_0	: integer := 260;
	constant rpma_done_count_5_RXPCS_IDX_0	: integer := 261;
	constant rpma_done_count_6_RXPCS_IDX_0	: integer := 262;
	constant rpma_done_count_7_RXPCS_IDX_0	: integer := 263;
	constant rpma_done_count_8_RXPCS_IDX_0	: integer := 264;
	constant rpma_done_count_9_RXPCS_IDX_0	: integer := 265;
	constant rpma_done_count_10_RXPCS_IDX_0	: integer := 266;
	constant rpma_done_count_11_RXPCS_IDX_0	: integer := 267;
	constant rpma_done_count_12_RXPCS_IDX_0	: integer := 268;
	constant rpma_done_count_13_RXPCS_IDX_0	: integer := 269;
	constant rpma_done_count_14_RXPCS_IDX_0	: integer := 270;
	constant rpma_done_count_15_RXPCS_IDX_0	: integer := 271;
	
	-- Table22: PCS Per Channel RX Control Register 18 for Channel 0
	constant rbytordpat_10_RXPCS_IDX_0	: integer := 272;
	constant rbytordpat_11_RXPCS_IDX_0	: integer := 273;
	constant rbytordpat_12_RXPCS_IDX_0	: integer := 274;
	constant rbytordpat_13_RXPCS_IDX_0	: integer := 275;
	constant rbytordpat_14_RXPCS_IDX_0	: integer := 276;
	constant rbytordpat_15_RXPCS_IDX_0	: integer := 277;
	constant rbytordpat_16_RXPCS_IDX_0	: integer := 278;
	constant rbytordpat_17_RXPCS_IDX_0	: integer := 279;
	constant rbytordpat_18_RXPCS_IDX_0	: integer := 280;
	constant rbytordpat_19_RXPCS_IDX_0	: integer := 281;
	constant rbytord_6g_mask_en_RXPCS_IDX_0	: integer := 282;
	constant rbytord_s2gx_RXPCS_IDX_0	: integer := 283;
	constant reserved_0_TB22_RXPCS_IDX_0	: integer := 284;
	constant rcdr_ctrl_en_RXPCS_IDX_0	: integer := 285;
	constant rrxpcsclkpwdn_RXPCS_IDX_0	: integer := 286;
	constant rerr_flags_sel_RXPCS_IDX_0	: integer := 287;
	
	-- Table23: PCS Per Channel RX Control Register 19 for Channel 0
	constant rwait_count_RXPCS_IDX_0	: integer := 288;
	constant rwait_count_RXPCS_IDX_1	: integer := 289;
	constant rwait_count_RXPCS_IDX_2	: integer := 290;
	constant rwait_count_RXPCS_IDX_3	: integer := 291;
	constant rwait_count_RXPCS_IDX_4	: integer := 292;
	constant rwait_count_RXPCS_IDX_5	: integer := 293;
	constant rwait_count_RXPCS_IDX_6	: integer := 294;
	constant rwait_count_RXPCS_IDX_7	: integer := 295;
	constant reserved_0_TB23_RXPCS_IDX_0	: integer := 296;
	constant reserved_0_TB23_RXPCS_IDX_1	: integer := 297;
	constant reserved_0_TB23_RXPCS_IDX_2	: integer := 298;
	constant reserved_0_TB23_RXPCS_IDX_3	: integer := 299;
	constant reserved_0_TB23_RXPCS_IDX_4	: integer := 300;
	constant reserved_0_TB23_RXPCS_IDX_5	: integer := 301;
	constant reserved_0_TB23_RXPCS_IDX_6	: integer := 302;
	constant reserved_0_TB23_RXPCS_IDX_7	: integer := 303;
	
	-- Table24: PCS Per Channel RX Control Register 20 for Channel 0
	constant rfts_count_RXPCS_IDX_0	: integer := 304;
	constant rfts_count_RXPCS_IDX_1	: integer := 305;
	constant rfts_count_RXPCS_IDX_2	: integer := 306;
	constant rfts_count_RXPCS_IDX_3	: integer := 307;
	constant rfts_count_RXPCS_IDX_4	: integer := 308;
	constant rfts_count_RXPCS_IDX_5	: integer := 309;
	constant rfts_count_RXPCS_IDX_6	: integer := 310;
	constant rfts_count_RXPCS_IDX_7	: integer := 311;
	constant rfts_count_RXPCS_IDX_8	: integer := 312;
	constant rfts_count_RXPCS_IDX_9	: integer := 313;
	constant rwait_for_phfifo_cnt_RXPCS_IDX_0	: integer := 314;
	constant rwait_for_phfifo_cnt_RXPCS_IDX_1	: integer := 315;
	constant rwait_for_phfifo_cnt_RXPCS_IDX_2	: integer := 316;
	constant rwait_for_phfifo_cnt_RXPCS_IDX_3	: integer := 317;
	constant rwait_for_phfifo_cnt_RXPCS_IDX_4	: integer := 318;
	constant rwait_for_phfifo_cnt_RXPCS_IDX_5	: integer := 319;
	
	-- Table25: PCS Per Channel RX Control Register 21 for Channel 0
	constant rppm_meas_delay_RXPCS_IDX_0	: integer := 320;
	constant rcid_len_rx_RXPCS_IDX_0	: integer := 321;
	constant rcid_len_rx_RXPCS_IDX_1	: integer := 322;
	constant rcid_len_rx_RXPCS_IDX_2	: integer := 323;
	constant rcid_len_rx_RXPCS_IDX_3	: integer := 324;
	constant rcid_len_rx_RXPCS_IDX_4	: integer := 325;
	constant rcid_len_rx_RXPCS_IDX_5	: integer := 326;
	constant rcid_len_rx_RXPCS_IDX_6	: integer := 327;
	constant rcid_len_rx_RXPCS_IDX_7	: integer := 328;
	constant rcid_pattern_rx_RXPCS_IDX_0	: integer := 329;
	constant rpcs_wrapback_en_RXPCS_IDX_0	: integer := 330;
	constant reserved_0_TB25_RXPCS_IDX_0	: integer := 331;
	constant reserved_0_TB25_RXPCS_IDX_1	: integer := 332;
	constant reserved_0_TB25_RXPCS_IDX_2	: integer := 333;
	constant reserved_0_TB25_RXPCS_IDX_3	: integer := 334;
	constant reserved_0_TB25_RXPCS_IDX_4	: integer := 335;
	
	-- Table26: PCS Per Channel RX Control Register 22 for Channel 0
	constant rauto_pc_en_cnt_RXPCS_IDX_0	: integer := 336;
	constant rauto_pc_en_cnt_RXPCS_IDX_1	: integer := 337;
	constant rauto_pc_en_cnt_RXPCS_IDX_2	: integer := 338;
	constant rauto_pc_en_cnt_RXPCS_IDX_3	: integer := 339;
	constant rauto_pc_en_cnt_RXPCS_IDX_4	: integer := 340;
	constant reserved_1_TB26_RXPCS_IDX_0	: integer := 341;
	constant rauto_deassert_pc_rst_cnt_RXPCS_IDX_0	: integer := 342;
	constant rauto_deassert_pc_rst_cnt_RXPCS_IDX_1	: integer := 343;
	constant rauto_deassert_pc_rst_cnt_RXPCS_IDX_2	: integer := 344;
	constant rauto_deassert_pc_rst_cnt_RXPCS_IDX_3	: integer := 345;
	constant reserved_0_TB26_RXPCS_IDX_0	: integer := 346;
	constant rpipeline_bypass_rx_RXPCS_IDX_0	: integer := 347;
	constant rself_sw_en_rx_RXPCS_IDX_0	: integer := 348;
	constant rrxvalid_mask_RXPCS_IDX_0	: integer := 349;
	constant rcid_en_RXPCS_IDX_0	: integer := 350;
	constant rphfifo_regmode_rx_RXPCS_IDX_0	: integer := 351;
	
	-- Table27: PCS Per Channel RX Control Register 23 for Channel 0
	constant rmask_count_RXPCS_IDX_0	: integer := 352;
	constant rmask_count_RXPCS_IDX_1	: integer := 353;
	constant rmask_count_RXPCS_IDX_2	: integer := 354;
	constant rmask_count_RXPCS_IDX_3	: integer := 355;
	constant rmask_count_RXPCS_IDX_4	: integer := 356;
	constant rmask_count_RXPCS_IDX_5	: integer := 357;
	constant rmask_count_RXPCS_IDX_6	: integer := 358;
	constant rmask_count_RXPCS_IDX_7	: integer := 359;
	constant rmask_count_RXPCS_IDX_8	: integer := 360;
	constant rmask_count_RXPCS_IDX_9	: integer := 361;
	constant rgen1_sigdet_ena_RXPCS_IDX_0	: integer := 362;
	constant riei_eios_priority_dis_RXPCS_IDX_0	: integer := 363;
	constant reserved_0_TB27_RXPCS_IDX_0	: integer := 364;
	constant reserved_0_TB27_RXPCS_IDX_1	: integer := 365;
	constant reserved_0_TB27_RXPCS_IDX_2	: integer := 366;
	constant reserved_0_TB27_RXPCS_IDX_3	: integer := 367;
  	
	-- Manual section ----------------------------------
	constant rpmadwidth_rx_RX_IDX          : integer := 368;
	constant rpma_doublewidth_rx_RX_IDX    : integer := 369;
	
	-- RX portion of global_ctrl 1
	--constant rphfifo_master_sel_rx_TX_IDX 
	constant rendec_data_sel_rx_RX_IDX  : integer := 370;
	constant rdeskewen_RX_IDX           : integer := 371;
	constant rindv_rx_RX_IDX            : integer := 372;
	
	-- RX portion of global_ctrl 2
	constant rdskposdisp_RX_IDX         : integer := 373;
	--constant ralgnopt_RX_IDX        
	--constant rdskchrp[9:0]
	
	-- RX portion of global_ctrl 3
	constant rmaster_rx_RX_IDX          : integer := 374;
	constant rmaster_up_rx_RX_IDX       : integer := 375;
	
	-- not used - legacy from rx_pcs.v
	constant rdwidth_rx_RX_IDX          : integer := 380;
	constant rtx_idle_delay_RX_IDX_0    : integer := 381;
	constant rtx_idle_delay_RX_IDX_1    : integer := 382;
	constant rclkcmppos_RX_IDX          : integer := 383;
	constant rppmsel_RX_IDX_0           : integer := 384;
	constant rppmsel_RX_IDX_5           : integer := 389;
	constant rforce0_freqdet_RX_IDX     : integer := 390;
	constant rforce1_freqdet_RX_IDX     : integer := 391;
	constant rs_lpbk_RX_IDX             : integer := 392;
	constant rrx_revlb_sw_RX_IDX        : integer := 393;

	-- ---------------------------------------------------------------------------
	-- DPRIO input CRAM  
	-- ---------------------------------------------------------------------------
	-- Manual section
	SIGNAL dprioin_rpmadwidth_rx: STD_LOGIC;
	SIGNAL dprioin_rpma_doublewidth_rx: STD_LOGIC;
	SIGNAL dprioin_rendec_data_sel_rx: STD_LOGIC;
	SIGNAL dprioin_rdeskewen: STD_LOGIC;
	SIGNAL dprioin_rindv_rx: STD_LOGIC;    
	SIGNAL dprioin_rmaster_rx: STD_LOGIC;
	SIGNAL dprioin_rmaster_up_rx: STD_LOGIC;
	SIGNAL dprioin_rdskposdisp: STD_LOGIC; 

	SIGNAL dprioin_dskwclksel: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL dprioin_is_lane0: STD_LOGIC;         
	SIGNAL dprioin_rbist_sel: STD_LOGIC_VECTOR(1 DOWNTO 0);            
	SIGNAL dprioin_rbitslip_size: STD_LOGIC_VECTOR(1 DOWNTO 0);        
	SIGNAL dprioin_rclkcmppos: STD_LOGIC;
	SIGNAL dprioin_rcxpat_chnl_en: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL dprioin_rdskchrp: STD_LOGIC_VECTOR(9 DOWNTO 0);
	SIGNAL dprioin_rforce0_freqdet: STD_LOGIC;
	SIGNAL dprioin_rforce1_freqdet: STD_LOGIC; 
	SIGNAL dprioin_rphfifo_master_sel_rx: STD_LOGIC;

	SIGNAL dprioin_rppm_cnt_reset: STD_LOGIC;
	SIGNAL dprioin_rppmsel: STD_LOGIC_VECTOR(5 DOWNTO 0);
	SIGNAL dprioin_rprbs_sel: STD_LOGIC_VECTOR(2 DOWNTO 0);            
	SIGNAL dprioin_rrdwidth_rx: STD_LOGIC;              -- rx only
	SIGNAL dprioin_rrx_revlb_sw: STD_LOGIC;
	SIGNAL dprioin_rs_lpbk: STD_LOGIC;
	SIGNAL dprioin_rtx_elec_idle_delay: STD_LOGIC_VECTOR(1 DOWNTO 0);      -- rx only
	SIGNAL dprioin_rtx_pipe_enable: STD_LOGIC;
	SIGNAL dprioin_scan_mode: STD_LOGIC;                     
	SIGNAL dprioin_sel_gp_md: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 1 for Channel 0
	SIGNAL dprioin_rrxpcsbypass_en	: STD_LOGIC;
	SIGNAL dprioin_rall_one_dect_only	: STD_LOGIC;
	SIGNAL dprioin_rbist_clr_rx	: STD_LOGIC;
	SIGNAL dprioin_rbisten_rx	: STD_LOGIC;
	SIGNAL dprioin_rprbs_clr_rslt_rx	: STD_LOGIC;
	SIGNAL dprioin_rprbsen_rx	: STD_LOGIC;
	SIGNAL dprioin_rrx_rd_clk_sel	: STD_LOGIC;
	SIGNAL dprioin_rclk_2_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL dprioin_rclk_1_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL dprioin_rrcvd_clk_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL dprioin_rfreerun_rx	: STD_LOGIC;
	SIGNAL dprioin_rrxurstpcs	: STD_LOGIC;
	SIGNAL dprioin_reserved_0_TB5	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 2 for Channel 0
	SIGNAL dprioin_rcomp_pat_32	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_33	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_34	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_35	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_36	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_37	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_38	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_39	: STD_LOGIC;
	SIGNAL dprioin_rcomp_size	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	SIGNAL dprioin_rcomp_pat_porn	: STD_LOGIC;
	SIGNAL dprioin_rdis_rx_disp	: STD_LOGIC;
	SIGNAL dprioin_rencdt_rising	: STD_LOGIC;
	SIGNAL dprioin_resync_badcg_en	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 3 for Channel 0
	SIGNAL dprioin_rcomp_pat_16	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_17	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_18	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_19	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_20	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_21	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_22	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_23	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_24	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_25	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_26	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_27	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_28	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_29	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_30	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_31	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 4 for Channel 0
	SIGNAL dprioin_rcomp_pat_0	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_1	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_2	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_3	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_4	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_5	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_6	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_7	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_8	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_9	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_10	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_11	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_12	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_13	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_14	: STD_LOGIC;
	SIGNAL dprioin_rcomp_pat_15	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 5 for Channel 0
	SIGNAL dprioin_rbitloc_rev_en	: STD_LOGIC;
	SIGNAL dprioin_rbysync_polinv_en	: STD_LOGIC;
	SIGNAL dprioin_rwa_6g_en	: STD_LOGIC;
	SIGNAL dprioin_rosnumber	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL dprioin_rosbased	: STD_LOGIC;
	SIGNAL dprioin_rkchar	: STD_LOGIC;
	SIGNAL dprioin_renumber	: STD_LOGIC_VECTOR(5 DOWNTO 0);
	SIGNAL dprioin_rib_inv_cd	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL dprioin_rsync_sm_dis	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 6 for Channel 0
	SIGNAL dprioin_rknumber	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	SIGNAL dprioin_rgnumber	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 7 for Channel 0
	SIGNAL dprioin_renpolinv_rx	: STD_LOGIC;
	SIGNAL dprioin_rcascaded_8b10b_en_rx	: STD_LOGIC;
	SIGNAL dprioin_r8b10b_dec_ibm_en	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL dprioin_rendec_rx	: STD_LOGIC;
	SIGNAL dprioin_rautobtalg_dis	: STD_LOGIC;
	SIGNAL dprioin_rrlv_en	: STD_LOGIC;
	SIGNAL dprioin_rlp20ben	: STD_LOGIC;
	SIGNAL dprioin_rforce_sig_det_pcs	: STD_LOGIC;
	SIGNAL dprioin_rbyte_rev_en	: STD_LOGIC;
	SIGNAL dprioin_rrundisp	: STD_LOGIC_VECTOR(5 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 8 for Channel 0
	SIGNAL dprioin_rclkcmpsq1p_0	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_1	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_2	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_3	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_4	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_5	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_6	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_7	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_8	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_9	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsqmd	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpinsertpad	: STD_LOGIC;
	SIGNAL dprioin_rtruebac2bac	: STD_LOGIC;
	SIGNAL dprioin_rskpsetbased	: STD_LOGIC;
	SIGNAL dprioin_rgenericfifo	: STD_LOGIC;
	SIGNAL dprioin_rmatchen	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 9 for Channel 0
	SIGNAL dprioin_rclkcmpsq1p_10	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_11	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_12	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_13	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_14	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_15	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_16	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_17	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_18	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1p_19	: STD_LOGIC;
	SIGNAL dprioin_reserved_0_TB13	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_15	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_16	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_17	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_18	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_19	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 10 for Channel 0
	SIGNAL dprioin_rclkcmpsq1n_0	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_1	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_2	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_3	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_4	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_5	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_6	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_7	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_8	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_9	: STD_LOGIC;
	SIGNAL dprioin_reserved_0_TB14	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_10	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_11	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_12	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_13	: STD_LOGIC;
	SIGNAL dprioin_rclkcmpsq1n_14	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 11 for Channel 0
	SIGNAL dprioin_rfull_threshold	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	SIGNAL dprioin_rdel_threshold	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	SIGNAL dprioin_rins_threshold	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	SIGNAL dprioin_rclkcmp_pipe_en	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 12 for Channel 0
	SIGNAL dprioin_rfreq_sel	: STD_LOGIC;
	SIGNAL dprioin_rauto_speed_ena	: STD_LOGIC;
	SIGNAL dprioin_rhip_ena	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_gen_ena	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_16	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_17	: STD_LOGIC;
	SIGNAL dprioin_reserved_0_TB16	: STD_LOGIC_VECTOR(3 DOWNTO 0);
	SIGNAL dprioin_rstart_threshold	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	SIGNAL dprioin_rempty_threshold	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 13 for Channel 0
	SIGNAL dprioin_rtest_bus_sel	: STD_LOGIC_VECTOR(3 DOWNTO 0);
	SIGNAL dprioin_rautoinsdis	: STD_LOGIC;
	SIGNAL dprioin_rphfifopldenrx	: STD_LOGIC;
	SIGNAL dprioin_rbytordplden	: STD_LOGIC;
	SIGNAL dprioin_rbyteorden	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL dprioin_rbytord_2sym_en	: STD_LOGIC;
	SIGNAL dprioin_rinvalid_code_err_only	: STD_LOGIC;
	SIGNAL dprioin_rcmpfifourst	: STD_LOGIC;
	SIGNAL dprioin_rphfifourstrx	: STD_LOGIC;
	SIGNAL dprioin_rdwidth_rx	: STD_LOGIC;
	SIGNAL dprioin_rrxfifo_lowlatency_en	: STD_LOGIC;
	SIGNAL dprioin_rrxfifo_dis	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 14 for Channel 0
	SIGNAL dprioin_rbytordpat_0	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_1	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_2	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_3	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_4	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_5	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_6	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_7	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_8	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_9	: STD_LOGIC;
	SIGNAL dprioin_reserved_0_TB18	: STD_LOGIC_VECTOR(5 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 15 for Channel 0
	SIGNAL dprioin_rbytordpad	: STD_LOGIC_VECTOR(9 DOWNTO 0);
	SIGNAL dprioin_reserved_0_TB19	: STD_LOGIC_VECTOR(5 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 16 for Channel 0
	SIGNAL dprioin_rload_shreg_del	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	SIGNAL dprioin_rphystatus_rst_toggle	: STD_LOGIC;
	SIGNAL dprioin_reidle_com_detect	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL dprioin_rk285detect	: STD_LOGIC;
	SIGNAL dprioin_reidleinferenable	: STD_LOGIC;
	SIGNAL dprioin_rphystatus_delay	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	SIGNAL dprioin_rind_error_reporting	: STD_LOGIC;
	SIGNAL dprioin_rrx_detect_bypass	: STD_LOGIC;
	SIGNAL dprioin_rrx_pipe_enable	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 17 for Channel 0
	SIGNAL dprioin_rpma_done_count_0	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_1	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_2	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_3	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_4	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_5	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_6	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_7	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_8	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_9	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_10	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_11	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_12	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_13	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_14	: STD_LOGIC;
	SIGNAL dprioin_rpma_done_count_15	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 18 for Channel 0
	SIGNAL dprioin_rbytordpat_10	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_11	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_12	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_13	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_14	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_15	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_16	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_17	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_18	: STD_LOGIC;
	SIGNAL dprioin_rbytordpat_19	: STD_LOGIC;
	SIGNAL dprioin_rbytord_6g_mask_en	: STD_LOGIC;
	SIGNAL dprioin_rbytord_s2gx	: STD_LOGIC;
	SIGNAL dprioin_reserved_0_TB22	: STD_LOGIC;
	SIGNAL dprioin_rcdr_ctrl_en	: STD_LOGIC;
	SIGNAL dprioin_rrxpcsclkpwdn	: STD_LOGIC;
	SIGNAL dprioin_rerr_flags_sel	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 19 for Channel 0
	SIGNAL dprioin_rwait_count	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	SIGNAL dprioin_reserved_0_TB23	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 20 for Channel 0
	SIGNAL dprioin_rfts_count	: STD_LOGIC_VECTOR(9 DOWNTO 0);
	SIGNAL dprioin_rwait_for_phfifo_cnt	: STD_LOGIC_VECTOR(5 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 21 for Channel 0
	SIGNAL dprioin_rppm_meas_delay	: STD_LOGIC;
	SIGNAL dprioin_rcid_len_rx	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	SIGNAL dprioin_rcid_pattern_rx	: STD_LOGIC;
	SIGNAL dprioin_rpcs_wrapback_en	: STD_LOGIC;
	SIGNAL dprioin_reserved_0_TB25	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 22 for Channel 0
	SIGNAL dprioin_rauto_pc_en_cnt	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	SIGNAL dprioin_reserved_1_TB26	: STD_LOGIC;
	SIGNAL dprioin_rauto_deassert_pc_rst_cnt	: STD_LOGIC_VECTOR(3 DOWNTO 0);
	SIGNAL dprioin_reserved_0_TB26	: STD_LOGIC;
	SIGNAL dprioin_rpipeline_bypass_rx	: STD_LOGIC;
	SIGNAL dprioin_rself_sw_en_rx	: STD_LOGIC;
	SIGNAL dprioin_rrxvalid_mask	: STD_LOGIC;
	SIGNAL dprioin_rcid_en	: STD_LOGIC;
	SIGNAL dprioin_rphfifo_regmode_rx	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 23 for Channel 0
	SIGNAL dprioin_rmask_count	: STD_LOGIC_VECTOR(9 DOWNTO 0);
	SIGNAL dprioin_rgen1_sigdet_ena	: STD_LOGIC;
	SIGNAL dprioin_riei_eios_priority_dis	: STD_LOGIC;
	SIGNAL dprioin_reserved_0_TB27	: STD_LOGIC_VECTOR(3 DOWNTO 0);
	
	-- ---------------------------------------------------------------------------
	-- Initial CRAM  
	-- ---------------------------------------------------------------------------
	-- Existing
	-- Manual sections
	SIGNAL init_rpmadwidth_rx: STD_LOGIC;
	SIGNAL init_rpma_doublewidth_rx: STD_LOGIC;
	SIGNAL init_rendec_data_sel_rx: STD_LOGIC;
	SIGNAL init_rdeskewen: STD_LOGIC;
	SIGNAL init_rindv_rx: STD_LOGIC;            
	SIGNAL init_rdskposdisp: STD_LOGIC;  
	
	SIGNAL init_dskwclksel: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL init_is_lane0: STD_LOGIC;         
	SIGNAL init_rbist_sel: STD_LOGIC_VECTOR(1 DOWNTO 0);            
	SIGNAL init_rbitslip_size: STD_LOGIC_VECTOR(1 DOWNTO 0);        
	SIGNAL init_rclkcmppos: STD_LOGIC;
	SIGNAL init_rcxpat_chnl_en: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL init_rdskchrp: STD_LOGIC_VECTOR(9 DOWNTO 0);
	SIGNAL init_renpolinv_en: STD_LOGIC;
	SIGNAL init_rforce0_freqdet: STD_LOGIC;
	SIGNAL init_rforce1_freqdet: STD_LOGIC;
	SIGNAL init_rphfifo_master_sel_rx: STD_LOGIC;

	SIGNAL init_rppm_cnt_reset: STD_LOGIC;
	SIGNAL init_rppmsel: STD_LOGIC_VECTOR(5 DOWNTO 0);
	SIGNAL init_rprbs_sel: STD_LOGIC_VECTOR(2 DOWNTO 0);            
	SIGNAL init_rrdwidth_rx: STD_LOGIC;                  -- rx only 
	SIGNAL init_rrx_revlb_sw: STD_LOGIC;
	SIGNAL init_rs_lpbk: STD_LOGIC;
	SIGNAL init_rtx_elec_idle_delay: STD_LOGIC_VECTOR(1 DOWNTO 0);          -- rx only
	SIGNAL init_rtx_pipe_enable: STD_LOGIC;              -- tx pipe
	SIGNAL init_scan_mode: STD_LOGIC;                     
	SIGNAL init_sel_gp_md: STD_LOGIC;

	-- PCS Per Channel RX Control Register 1 for Channel 0
	SIGNAL init_rrxpcsbypass_en	: STD_LOGIC;
	SIGNAL init_rall_one_dect_only	: STD_LOGIC;
	SIGNAL init_rbist_clr_rx	: STD_LOGIC;
	SIGNAL init_rbisten_rx	: STD_LOGIC;
	SIGNAL init_rprbs_clr_rslt_rx	: STD_LOGIC;
	SIGNAL init_rprbsen_rx	: STD_LOGIC;
	SIGNAL init_rrx_rd_clk_sel	: STD_LOGIC;
	SIGNAL init_rclk_2_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL init_rclk_1_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL init_rrcvd_clk_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL init_rfreerun_rx	: STD_LOGIC;
	SIGNAL init_rrxurstpcs	: STD_LOGIC;
	SIGNAL init_reserved_0_TB5	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 2 for Channel 0
	SIGNAL init_rcomp_pat_32	: STD_LOGIC;
	SIGNAL init_rcomp_pat_33	: STD_LOGIC;
	SIGNAL init_rcomp_pat_34	: STD_LOGIC;
	SIGNAL init_rcomp_pat_35	: STD_LOGIC;
	SIGNAL init_rcomp_pat_36	: STD_LOGIC;
	SIGNAL init_rcomp_pat_37	: STD_LOGIC;
	SIGNAL init_rcomp_pat_38	: STD_LOGIC;
	SIGNAL init_rcomp_pat_39	: STD_LOGIC;
	SIGNAL init_rcomp_size	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	SIGNAL init_rcomp_pat_porn	: STD_LOGIC;
	SIGNAL init_rdis_rx_disp	: STD_LOGIC;
	SIGNAL init_rencdt_rising	: STD_LOGIC;
	SIGNAL init_resync_badcg_en	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 3 for Channel 0
	SIGNAL init_rcomp_pat_16	: STD_LOGIC;
	SIGNAL init_rcomp_pat_17	: STD_LOGIC;
	SIGNAL init_rcomp_pat_18	: STD_LOGIC;
	SIGNAL init_rcomp_pat_19	: STD_LOGIC;
	SIGNAL init_rcomp_pat_20	: STD_LOGIC;
	SIGNAL init_rcomp_pat_21	: STD_LOGIC;
	SIGNAL init_rcomp_pat_22	: STD_LOGIC;
	SIGNAL init_rcomp_pat_23	: STD_LOGIC;
	SIGNAL init_rcomp_pat_24	: STD_LOGIC;
	SIGNAL init_rcomp_pat_25	: STD_LOGIC;
	SIGNAL init_rcomp_pat_26	: STD_LOGIC;
	SIGNAL init_rcomp_pat_27	: STD_LOGIC;
	SIGNAL init_rcomp_pat_28	: STD_LOGIC;
	SIGNAL init_rcomp_pat_29	: STD_LOGIC;
	SIGNAL init_rcomp_pat_30	: STD_LOGIC;
	SIGNAL init_rcomp_pat_31	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 4 for Channel 0
	SIGNAL init_rcomp_pat_0	: STD_LOGIC;
	SIGNAL init_rcomp_pat_1	: STD_LOGIC;
	SIGNAL init_rcomp_pat_2	: STD_LOGIC;
	SIGNAL init_rcomp_pat_3	: STD_LOGIC;
	SIGNAL init_rcomp_pat_4	: STD_LOGIC;
	SIGNAL init_rcomp_pat_5	: STD_LOGIC;
	SIGNAL init_rcomp_pat_6	: STD_LOGIC;
	SIGNAL init_rcomp_pat_7	: STD_LOGIC;
	SIGNAL init_rcomp_pat_8	: STD_LOGIC;
	SIGNAL init_rcomp_pat_9	: STD_LOGIC;
	SIGNAL init_rcomp_pat_10	: STD_LOGIC;
	SIGNAL init_rcomp_pat_11	: STD_LOGIC;
	SIGNAL init_rcomp_pat_12	: STD_LOGIC;
	SIGNAL init_rcomp_pat_13	: STD_LOGIC;
	SIGNAL init_rcomp_pat_14	: STD_LOGIC;
	SIGNAL init_rcomp_pat_15	: STD_LOGIC;
	
	SIGNAL init_rcomp_pat : STD_LOGIC_VECTOR(39 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 5 for Channel 0
	SIGNAL init_rbitloc_rev_en	: STD_LOGIC;
	SIGNAL init_rbysync_polinv_en	: STD_LOGIC;
	SIGNAL init_rwa_6g_en	: STD_LOGIC;
	SIGNAL init_rosnumber	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL init_rosbased	: STD_LOGIC;
	SIGNAL init_rkchar	: STD_LOGIC;
	SIGNAL init_renumber	: STD_LOGIC_VECTOR(5 DOWNTO 0);
	SIGNAL init_rib_inv_cd	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL init_rsync_sm_dis	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 6 for Channel 0
	SIGNAL init_rknumber	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	SIGNAL init_rgnumber	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 7 for Channel 0
	SIGNAL init_renpolinv_rx	: STD_LOGIC;
	SIGNAL init_rcascaded_8b10b_en_rx	: STD_LOGIC;
	SIGNAL init_r8b10b_dec_ibm_en	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL init_rendec_rx	: STD_LOGIC;
	SIGNAL init_rautobtalg_dis	: STD_LOGIC;
	SIGNAL init_rrlv_en	: STD_LOGIC;
	SIGNAL init_rlp20ben	: STD_LOGIC;
	SIGNAL init_rforce_sig_det_pcs	: STD_LOGIC;
	SIGNAL init_rbyte_rev_en	: STD_LOGIC;
	SIGNAL init_rrundisp	: STD_LOGIC_VECTOR(5 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 8 for Channel 0
	SIGNAL init_rclkcmpsq1p_0	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_1	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_2	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_3	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_4	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_5	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_6	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_7	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_8	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_9	: STD_LOGIC;
	SIGNAL init_rclkcmpsqmd	: STD_LOGIC;
	SIGNAL init_rclkcmpinsertpad	: STD_LOGIC;
	SIGNAL init_rtruebac2bac	: STD_LOGIC;
	SIGNAL init_rskpsetbased	: STD_LOGIC;
	SIGNAL init_rgenericfifo	: STD_LOGIC;
	SIGNAL init_rmatchen	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 9 for Channel 0
	SIGNAL init_rclkcmpsq1p_10	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_11	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_12	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_13	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_14	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_15	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_16	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_17	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_18	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1p_19	: STD_LOGIC;
	SIGNAL init_reserved_0_TB13	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_15	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_16	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_17	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_18	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_19	: STD_LOGIC;
	
	SIGNAL init_rclkcmpsq1p	: STD_LOGIC_VECTOR(19 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 10 for Channel 0
	SIGNAL init_rclkcmpsq1n_0	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_1	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_2	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_3	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_4	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_5	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_6	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_7	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_8	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_9	: STD_LOGIC;
	SIGNAL init_reserved_0_TB14	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_10	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_11	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_12	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_13	: STD_LOGIC;
	SIGNAL init_rclkcmpsq1n_14	: STD_LOGIC;
	
	SIGNAL init_rclkcmpsq1n	: STD_LOGIC_VECTOR(19 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 11 for Channel 0
	SIGNAL init_rfull_threshold	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	SIGNAL init_rdel_threshold	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	SIGNAL init_rins_threshold	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	SIGNAL init_rclkcmp_pipe_en	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 12 for Channel 0
	SIGNAL init_rfreq_sel	: STD_LOGIC;
	SIGNAL init_rauto_speed_ena	: STD_LOGIC;
	SIGNAL init_rhip_ena	: STD_LOGIC;
	SIGNAL init_rpma_done_gen_ena	: STD_LOGIC;
	SIGNAL init_rpma_done_count_16	: STD_LOGIC;
	SIGNAL init_rpma_done_count_17	: STD_LOGIC;
	SIGNAL init_reserved_0_TB16	: STD_LOGIC_VECTOR(3 DOWNTO 0);
	SIGNAL init_rstart_threshold	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	SIGNAL init_rempty_threshold	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 13 for Channel 0
	SIGNAL init_rtest_bus_sel	: STD_LOGIC_VECTOR(3 DOWNTO 0);
	SIGNAL init_rautoinsdis	: STD_LOGIC;
	SIGNAL init_rphfifopldenrx	: STD_LOGIC;
	SIGNAL init_rbytordplden	: STD_LOGIC;
	SIGNAL init_rbyteorden	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL init_rbytord_2sym_en	: STD_LOGIC;
	SIGNAL init_rinvalid_code_err_only	: STD_LOGIC;
	SIGNAL init_rcmpfifourst	: STD_LOGIC;
	SIGNAL init_rphfifourstrx	: STD_LOGIC;
	SIGNAL init_rdwidth_rx	: STD_LOGIC;
	SIGNAL init_rrxfifo_lowlatency_en	: STD_LOGIC;
	SIGNAL init_rrxfifo_dis	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 14 for Channel 0
	SIGNAL init_rbytordpat_0	: STD_LOGIC;
	SIGNAL init_rbytordpat_1	: STD_LOGIC;
	SIGNAL init_rbytordpat_2	: STD_LOGIC;
	SIGNAL init_rbytordpat_3	: STD_LOGIC;
	SIGNAL init_rbytordpat_4	: STD_LOGIC;
	SIGNAL init_rbytordpat_5	: STD_LOGIC;
	SIGNAL init_rbytordpat_6	: STD_LOGIC;
	SIGNAL init_rbytordpat_7	: STD_LOGIC;
	SIGNAL init_rbytordpat_8	: STD_LOGIC;
	SIGNAL init_rbytordpat_9	: STD_LOGIC;
	SIGNAL init_reserved_0_TB18	: STD_LOGIC_VECTOR(5 DOWNTO 0);
	
	SIGNAL init_rbytordpat	: STD_LOGIC_VECTOR(19 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 15 for Channel 0
	SIGNAL init_rbytordpad	: STD_LOGIC_VECTOR(9 DOWNTO 0);
	SIGNAL init_reserved_0_TB19	: STD_LOGIC_VECTOR(5 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 16 for Channel 0
	SIGNAL init_rload_shreg_del	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	SIGNAL init_rphystatus_rst_toggle	: STD_LOGIC;
	SIGNAL init_reidle_com_detect	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL init_rk285detect	: STD_LOGIC;
	SIGNAL init_reidleinferenable	: STD_LOGIC;
	SIGNAL init_rphystatus_delay	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	SIGNAL init_rind_error_reporting	: STD_LOGIC;
	SIGNAL init_rrx_detect_bypass	: STD_LOGIC;
	SIGNAL init_rrx_pipe_enable	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 17 for Channel 0
	SIGNAL init_rpma_done_count_0	: STD_LOGIC;
	SIGNAL init_rpma_done_count_1	: STD_LOGIC;
	SIGNAL init_rpma_done_count_2	: STD_LOGIC;
	SIGNAL init_rpma_done_count_3	: STD_LOGIC;
	SIGNAL init_rpma_done_count_4	: STD_LOGIC;
	SIGNAL init_rpma_done_count_5	: STD_LOGIC;
	SIGNAL init_rpma_done_count_6	: STD_LOGIC;
	SIGNAL init_rpma_done_count_7	: STD_LOGIC;
	SIGNAL init_rpma_done_count_8	: STD_LOGIC;
	SIGNAL init_rpma_done_count_9	: STD_LOGIC;
	SIGNAL init_rpma_done_count_10	: STD_LOGIC;
	SIGNAL init_rpma_done_count_11	: STD_LOGIC;
	SIGNAL init_rpma_done_count_12	: STD_LOGIC;
	SIGNAL init_rpma_done_count_13	: STD_LOGIC;
	SIGNAL init_rpma_done_count_14	: STD_LOGIC;
	SIGNAL init_rpma_done_count_15	: STD_LOGIC;
	
	SIGNAL init_rpma_done_count : STD_LOGIC_VECTOR(17 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 18 for Channel 0
	SIGNAL init_rbytordpat_10	: STD_LOGIC;
	SIGNAL init_rbytordpat_11	: STD_LOGIC;
	SIGNAL init_rbytordpat_12	: STD_LOGIC;
	SIGNAL init_rbytordpat_13	: STD_LOGIC;
	SIGNAL init_rbytordpat_14	: STD_LOGIC;
	SIGNAL init_rbytordpat_15	: STD_LOGIC;
	SIGNAL init_rbytordpat_16	: STD_LOGIC;
	SIGNAL init_rbytordpat_17	: STD_LOGIC;
	SIGNAL init_rbytordpat_18	: STD_LOGIC;
	SIGNAL init_rbytordpat_19	: STD_LOGIC;
	SIGNAL init_rbytord_6g_mask_en	: STD_LOGIC;
	SIGNAL init_rbytord_s2gx	: STD_LOGIC;
	SIGNAL init_reserved_0_TB22	: STD_LOGIC;
	SIGNAL init_rcdr_ctrl_en	: STD_LOGIC;
	SIGNAL init_rrxpcsclkpwdn	: STD_LOGIC;
	SIGNAL init_rerr_flags_sel	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 19 for Channel 0
	SIGNAL init_rwait_count	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	SIGNAL init_reserved_0_TB23	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 20 for Channel 0
	SIGNAL init_rfts_count	: STD_LOGIC_VECTOR(9 DOWNTO 0);
	SIGNAL init_rwait_for_phfifo_cnt	: STD_LOGIC_VECTOR(5 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 21 for Channel 0
	SIGNAL init_rppm_meas_delay	: STD_LOGIC;
	SIGNAL init_rcid_len_rx	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	SIGNAL init_rcid_pattern_rx	: STD_LOGIC;
	SIGNAL init_rpcs_wrapback_en	: STD_LOGIC;
	SIGNAL init_reserved_0_TB25	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 22 for Channel 0
	SIGNAL init_rauto_pc_en_cnt	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	SIGNAL init_reserved_1_TB26	: STD_LOGIC;
	SIGNAL init_rauto_deassert_pc_rst_cnt	: STD_LOGIC_VECTOR(3 DOWNTO 0);
	SIGNAL init_reserved_0_TB26	: STD_LOGIC;
	SIGNAL init_rpipeline_bypass_rx	: STD_LOGIC;
	SIGNAL init_rself_sw_en_rx	: STD_LOGIC;
	SIGNAL init_rrxvalid_mask	: STD_LOGIC;
	SIGNAL init_rcid_en	: STD_LOGIC;
	SIGNAL init_rphfifo_regmode_rx	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 23 for Channel 0
	SIGNAL init_rmask_count	: STD_LOGIC_VECTOR(9 DOWNTO 0);
	SIGNAL init_rgen1_sigdet_ena	: STD_LOGIC;
	SIGNAL init_riei_eios_priority_dis	: STD_LOGIC;
	SIGNAL init_reserved_0_TB27	: STD_LOGIC_VECTOR(3 DOWNTO 0);
	
	-- ---------------------------------------------------------------------------
	-- CRAM  
	-- ---------------------------------------------------------------------------
	-- Manual section
	SIGNAL cram_rpmadwidth_rx: STD_LOGIC;
	SIGNAL cram_rpma_doublewidth_rx: STD_LOGIC;
	SIGNAL cram_rendec_data_sel_rx: STD_LOGIC;
	SIGNAL cram_rdeskewen: STD_LOGIC;
	SIGNAL cram_rindv_rx: STD_LOGIC;       
	SIGNAL cram_rdskposdisp: STD_LOGIC; 
	SIGNAL cram_rmaster_rx: STD_LOGIC;
	SIGNAL cram_rmaster_up_rx: STD_LOGIC;

	SIGNAL cram_dskwclksel: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL cram_is_lane0: STD_LOGIC;         
	SIGNAL cram_rbist_sel: STD_LOGIC_VECTOR(1 DOWNTO 0);            
	SIGNAL cram_rbitslip_size: STD_LOGIC_VECTOR(1 DOWNTO 0);        
	SIGNAL cram_rclkcmppos: STD_LOGIC;
	SIGNAL cram_rcxpat_chnl_en: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL cram_rdskchrp: STD_LOGIC_VECTOR(9 DOWNTO 0);
	SIGNAL cram_rforce0_freqdet: STD_LOGIC;
	SIGNAL cram_rforce1_freqdet: STD_LOGIC;  
	SIGNAL cram_rphfifo_master_sel_rx: STD_LOGIC;

	SIGNAL cram_rppm_cnt_reset: STD_LOGIC;
	SIGNAL cram_rppmsel: STD_LOGIC_VECTOR(5 DOWNTO 0);
	SIGNAL cram_rprbs_sel: STD_LOGIC_VECTOR(2 DOWNTO 0);            
	SIGNAL cram_rrdwidth_rx: STD_LOGIC;                  -- rx only
	SIGNAL cram_rrx_revlb_sw: STD_LOGIC;
	SIGNAL cram_rs_lpbk: STD_LOGIC;
	SIGNAL cram_rtx_elec_idle_delay: STD_LOGIC_VECTOR(1 DOWNTO 0);          -- rx only
	SIGNAL cram_rtx_pipe_enable: STD_LOGIC;
	SIGNAL cram_scan_mode: STD_LOGIC;                     
	SIGNAL cram_sel_gp_md: STD_LOGIC;
	
	-- Existing (2)
	SIGNAL dprioin_renpolinv_en: STD_LOGIC;
	SIGNAL cram_renpolinv_en: STD_LOGIC;
	SIGNAL init_rmaster_rx: STD_LOGIC;

	SIGNAL init_rmaster_up_rx: STD_LOGIC;
	SIGNAL init_rphfifourstenrx: STD_LOGIC;
	SIGNAL dprioin_rphfifourstenrx: STD_LOGIC;
	SIGNAL cram_rphfifourstenrx: STD_LOGIC;
	SIGNAL init_rppm_gen1_2xcnt_en: STD_LOGIC;
	SIGNAL dprioin_rppm_gen1_2xcnt_en: STD_LOGIC;
	SIGNAL cram_rppm_gen1_2xcnt_en: STD_LOGIC;
	SIGNAL init_rppm_post_eidle_del: STD_LOGIC;
	SIGNAL dprioin_rppm_post_eidle_del: STD_LOGIC;
	SIGNAL cram_rppm_post_eidle_del: STD_LOGIC;
	SIGNAL init_rrx_fifo_dis: STD_LOGIC;
	SIGNAL dprioin_rrx_fifo_dis: STD_LOGIC;
	SIGNAL cram_rrx_fifo_dis: STD_LOGIC;

	-- PCS Per Channel RX Control Register 1 for Channel 0
	SIGNAL cram_rrxpcsbypass_en	: STD_LOGIC;
	SIGNAL cram_rall_one_dect_only	: STD_LOGIC;
	SIGNAL cram_rbist_clr_rx	: STD_LOGIC;
	SIGNAL cram_rbisten_rx	: STD_LOGIC;
	SIGNAL cram_rprbs_clr_rslt_rx	: STD_LOGIC;
	SIGNAL cram_rprbsen_rx	: STD_LOGIC;
	SIGNAL cram_rrx_rd_clk_sel	: STD_LOGIC;
	SIGNAL cram_rclk_2_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL cram_rclk_1_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL cram_rrcvd_clk_sel	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL cram_rfreerun_rx	: STD_LOGIC;
	SIGNAL cram_rrxurstpcs	: STD_LOGIC;
	SIGNAL cram_reserved_0_TB5	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 2 for Channel 0
	SIGNAL cram_rcomp_pat_32	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_33	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_34	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_35	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_36	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_37	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_38	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_39	: STD_LOGIC;
	SIGNAL cram_rcomp_size	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	SIGNAL cram_rcomp_pat_porn	: STD_LOGIC;
	SIGNAL cram_rdis_rx_disp	: STD_LOGIC;
	SIGNAL cram_rencdt_rising	: STD_LOGIC;
	SIGNAL cram_resync_badcg_en	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 3 for Channel 0
	SIGNAL cram_rcomp_pat_16	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_17	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_18	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_19	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_20	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_21	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_22	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_23	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_24	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_25	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_26	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_27	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_28	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_29	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_30	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_31	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 4 for Channel 0
	SIGNAL cram_rcomp_pat_0	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_1	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_2	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_3	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_4	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_5	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_6	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_7	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_8	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_9	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_10	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_11	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_12	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_13	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_14	: STD_LOGIC;
	SIGNAL cram_rcomp_pat_15	: STD_LOGIC;
	
	SIGNAL cram_rcomp_pat : STD_LOGIC_VECTOR(39 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 5 for Channel 0
	SIGNAL cram_rbitloc_rev_en	: STD_LOGIC;
	SIGNAL cram_rbysync_polinv_en	: STD_LOGIC;
	SIGNAL cram_rwa_6g_en	: STD_LOGIC;
	SIGNAL cram_rosnumber	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL cram_rosbased	: STD_LOGIC;
	SIGNAL cram_rkchar	: STD_LOGIC;
	SIGNAL cram_renumber	: STD_LOGIC_VECTOR(5 DOWNTO 0);
	SIGNAL cram_rib_inv_cd	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL cram_rsync_sm_dis	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 6 for Channel 0
	SIGNAL cram_rknumber	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	SIGNAL cram_rgnumber	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 7 for Channel 0
	SIGNAL cram_renpolinv_rx	: STD_LOGIC;
	SIGNAL cram_rcascaded_8b10b_en_rx	: STD_LOGIC;
	SIGNAL cram_r8b10b_dec_ibm_en	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL cram_rendec_rx	: STD_LOGIC;
	SIGNAL cram_rautobtalg_dis	: STD_LOGIC;
	SIGNAL cram_rrlv_en	: STD_LOGIC;
	SIGNAL cram_rlp20ben	: STD_LOGIC;
	SIGNAL cram_rforce_sig_det_pcs	: STD_LOGIC;
	SIGNAL cram_rbyte_rev_en	: STD_LOGIC;
	SIGNAL cram_rrundisp	: STD_LOGIC_VECTOR(5 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 8 for Channel 0
	SIGNAL cram_rclkcmpsq1p_0	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_1	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_2	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_3	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_4	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_5	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_6	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_7	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_8	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_9	: STD_LOGIC;
	SIGNAL cram_rclkcmpsqmd	: STD_LOGIC;
	SIGNAL cram_rclkcmpinsertpad	: STD_LOGIC;
	SIGNAL cram_rtruebac2bac	: STD_LOGIC;
	SIGNAL cram_rskpsetbased	: STD_LOGIC;
	SIGNAL cram_rgenericfifo	: STD_LOGIC;
	SIGNAL cram_rmatchen	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 9 for Channel 0
	SIGNAL cram_rclkcmpsq1p_10	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_11	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_12	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_13	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_14	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_15	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_16	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_17	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_18	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1p_19	: STD_LOGIC;
	SIGNAL cram_reserved_0_TB13	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_15	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_16	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_17	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_18	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_19	: STD_LOGIC;
	
	SIGNAL cram_rclkcmpsq1p	: STD_LOGIC_VECTOR(19 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 10 for Channel 0
	SIGNAL cram_rclkcmpsq1n_0	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_1	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_2	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_3	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_4	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_5	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_6	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_7	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_8	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_9	: STD_LOGIC;
	SIGNAL cram_reserved_0_TB14	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_10	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_11	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_12	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_13	: STD_LOGIC;
	SIGNAL cram_rclkcmpsq1n_14	: STD_LOGIC;
	
	SIGNAL cram_rclkcmpsq1n	: STD_LOGIC_VECTOR(19 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 11 for Channel 0
	SIGNAL cram_rfull_threshold	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	SIGNAL cram_rdel_threshold	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	SIGNAL cram_rins_threshold	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	SIGNAL cram_rclkcmp_pipe_en	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 12 for Channel 0
	SIGNAL cram_rfreq_sel	: STD_LOGIC;
	SIGNAL cram_rauto_speed_ena	: STD_LOGIC;
	SIGNAL cram_rhip_ena	: STD_LOGIC;
	SIGNAL cram_rpma_done_gen_ena	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_16	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_17	: STD_LOGIC;
	SIGNAL cram_reserved_0_TB16	: STD_LOGIC_VECTOR(3 DOWNTO 0);
	SIGNAL cram_rstart_threshold	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	SIGNAL cram_rempty_threshold	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 13 for Channel 0
	SIGNAL cram_rtest_bus_sel	: STD_LOGIC_VECTOR(3 DOWNTO 0);
	SIGNAL cram_rautoinsdis	: STD_LOGIC;
	SIGNAL cram_rphfifopldenrx	: STD_LOGIC;
	SIGNAL cram_rbytordplden	: STD_LOGIC;
	SIGNAL cram_rbyteorden	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL cram_rbytord_2sym_en	: STD_LOGIC;
	SIGNAL cram_rinvalid_code_err_only	: STD_LOGIC;
	SIGNAL cram_rcmpfifourst	: STD_LOGIC;
	SIGNAL cram_rphfifourstrx	: STD_LOGIC;
	SIGNAL cram_rdwidth_rx	: STD_LOGIC;
	SIGNAL cram_rrxfifo_lowlatency_en	: STD_LOGIC;
	SIGNAL cram_rrxfifo_dis	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 14 for Channel 0
	SIGNAL cram_rbytordpat_0	: STD_LOGIC;
	SIGNAL cram_rbytordpat_1	: STD_LOGIC;
	SIGNAL cram_rbytordpat_2	: STD_LOGIC;
	SIGNAL cram_rbytordpat_3	: STD_LOGIC;
	SIGNAL cram_rbytordpat_4	: STD_LOGIC;
	SIGNAL cram_rbytordpat_5	: STD_LOGIC;
	SIGNAL cram_rbytordpat_6	: STD_LOGIC;
	SIGNAL cram_rbytordpat_7	: STD_LOGIC;
	SIGNAL cram_rbytordpat_8	: STD_LOGIC;
	SIGNAL cram_rbytordpat_9	: STD_LOGIC;
	SIGNAL cram_reserved_0_TB18	: STD_LOGIC_VECTOR(5 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 15 for Channel 0
	SIGNAL cram_rbytordpad	: STD_LOGIC_VECTOR(9 DOWNTO 0);
	SIGNAL cram_reserved_0_TB19	: STD_LOGIC_VECTOR(5 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 16 for Channel 0
	SIGNAL cram_rload_shreg_del	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	SIGNAL cram_rphystatus_rst_toggle	: STD_LOGIC;
	SIGNAL cram_reidle_com_detect	: STD_LOGIC_VECTOR(1 DOWNTO 0);
	SIGNAL cram_rk285detect	: STD_LOGIC;
	SIGNAL cram_reidleinferenable	: STD_LOGIC;
	SIGNAL cram_rphystatus_delay	: STD_LOGIC_VECTOR(2 DOWNTO 0);
	SIGNAL cram_rind_error_reporting	: STD_LOGIC;
	SIGNAL cram_rrx_detect_bypass	: STD_LOGIC;
	SIGNAL cram_rrx_pipe_enable	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 17 for Channel 0
	SIGNAL cram_rpma_done_count_0	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_1	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_2	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_3	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_4	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_5	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_6	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_7	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_8	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_9	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_10	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_11	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_12	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_13	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_14	: STD_LOGIC;
	SIGNAL cram_rpma_done_count_15	: STD_LOGIC;
	
	SIGNAL cram_rpma_done_count	: STD_LOGIC_VECTOR(17 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 18 for Channel 0
	SIGNAL cram_rbytordpat_10	: STD_LOGIC;
	SIGNAL cram_rbytordpat_11	: STD_LOGIC;
	SIGNAL cram_rbytordpat_12	: STD_LOGIC;
	SIGNAL cram_rbytordpat_13	: STD_LOGIC;
	SIGNAL cram_rbytordpat_14	: STD_LOGIC;
	SIGNAL cram_rbytordpat_15	: STD_LOGIC;
	SIGNAL cram_rbytordpat_16	: STD_LOGIC;
	SIGNAL cram_rbytordpat_17	: STD_LOGIC;
	SIGNAL cram_rbytordpat_18	: STD_LOGIC;
	SIGNAL cram_rbytordpat_19	: STD_LOGIC;
	SIGNAL cram_rbytord_6g_mask_en	: STD_LOGIC;
	SIGNAL cram_rbytord_s2gx	: STD_LOGIC;
	SIGNAL cram_reserved_0_TB22	: STD_LOGIC;
	SIGNAL cram_rcdr_ctrl_en	: STD_LOGIC;
	SIGNAL cram_rrxpcsclkpwdn	: STD_LOGIC;
	SIGNAL cram_rerr_flags_sel	: STD_LOGIC;
	
	SIGNAL cram_rbytordpat	: STD_LOGIC_VECTOR(19 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 19 for Channel 0
	SIGNAL cram_rwait_count	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	SIGNAL cram_reserved_0_TB23	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 20 for Channel 0
	SIGNAL cram_rfts_count	: STD_LOGIC_VECTOR(9 DOWNTO 0);
	SIGNAL cram_rwait_for_phfifo_cnt	: STD_LOGIC_VECTOR(5 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 21 for Channel 0
	SIGNAL cram_rppm_meas_delay	: STD_LOGIC;
	SIGNAL cram_rcid_len_rx	: STD_LOGIC_VECTOR(7 DOWNTO 0);
	SIGNAL cram_rcid_pattern_rx	: STD_LOGIC;
	SIGNAL cram_rpcs_wrapback_en	: STD_LOGIC;
	SIGNAL cram_reserved_0_TB25	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	
	-- PCS Per Channel RX Control Register 22 for Channel 0
	SIGNAL cram_rauto_pc_en_cnt	: STD_LOGIC_VECTOR(4 DOWNTO 0);
	SIGNAL cram_reserved_1_TB26	: STD_LOGIC;
	SIGNAL cram_rauto_deassert_pc_rst_cnt	: STD_LOGIC_VECTOR(3 DOWNTO 0);
	SIGNAL cram_reserved_0_TB26	: STD_LOGIC;
	SIGNAL cram_rpipeline_bypass_rx	: STD_LOGIC;
	SIGNAL cram_rself_sw_en_rx	: STD_LOGIC;
	SIGNAL cram_rrxvalid_mask	: STD_LOGIC;
	SIGNAL cram_rcid_en	: STD_LOGIC;
	SIGNAL cram_rphfifo_regmode_rx	: STD_LOGIC;
	
	-- PCS Per Channel RX Control Register 23 for Channel 0
	SIGNAL cram_rmask_count	: STD_LOGIC_VECTOR(9 DOWNTO 0);
	SIGNAL cram_rgen1_sigdet_ena	: STD_LOGIC;
	SIGNAL cram_riei_eios_priority_dis	: STD_LOGIC;
	SIGNAL cram_reserved_0_TB27	: STD_LOGIC_VECTOR(3 DOWNTO 0);

	-- new dprio model end --
   
   --///////////////////////////////////////////////////////////////////////////
   -- sub-block interface: pcs_reset (pr)  -----------------------------------//
   --///////////////////////////////////////////////////////////////////////////
   
   SIGNAL pr_in_hard_reset                      : STD_LOGIC;
   SIGNAL pr_in_clk_2_b                         : STD_LOGIC;
   SIGNAL pr_in_refclk_b_in                     : STD_LOGIC;
   SIGNAL pr_in_scan_mode                       : STD_LOGIC;
   SIGNAL pr_in_rxpcs_rst                       : STD_LOGIC;
   SIGNAL pr_in_txpcs_rst                       : STD_LOGIC;
   
   SIGNAL pr_out_rxrst_int                      : STD_LOGIC;
   SIGNAL pr_out_txrst_int                      : STD_LOGIC;
   
   --///////////////////////////////////////////////////////////////////////////
   -- sub-block interface: chnl_hip_spt  -------------------------------------//
   --///////////////////////////////////////////////////////////////////////////
   
   SIGNAL hs_in_eidleinfersel_ch                : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_in_hip_eidleinfersel_ch            : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_in_hip_powerdown_ch                : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL hs_in_hip_rate                        : STD_LOGIC;
   SIGNAL hs_in_hip_rxpolarity                  : STD_LOGIC;
   SIGNAL hs_in_hip_txd_ch                      : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL hs_in_hip_txdeemph                    : STD_LOGIC;
   SIGNAL hs_in_hip_txdetectrxloopback          : STD_LOGIC;
   SIGNAL hs_in_hip_txelecidle                  : STD_LOGIC;
   SIGNAL hs_in_hip_txmargin_ch                 : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_in_pcs_phystatus                   : STD_LOGIC;
   SIGNAL hs_in_pcs_rxd_ch                      : STD_LOGIC_VECTOR(8 DOWNTO 0);
   SIGNAL hs_in_pcs_rxelecidle                  : STD_LOGIC;
   SIGNAL hs_in_pcs_rxstatus_ch                 : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_in_pcs_rxvalid                     : STD_LOGIC;
   SIGNAL hs_in_powerdown_ch                    : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL hs_in_rate                            : STD_LOGIC;
   SIGNAL hs_in_rhip_ena                        : STD_LOGIC;
   SIGNAL hs_in_rxpolarity                      : STD_LOGIC;
   SIGNAL hs_in_txd_ch                          : STD_LOGIC_VECTOR(10 DOWNTO 0);
   SIGNAL hs_in_txdeemph                        : STD_LOGIC;
   SIGNAL hs_in_txdetectrxloopback              : STD_LOGIC;
   SIGNAL hs_in_txmargin_ch                     : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_in_txpma_local_clk                 : STD_LOGIC;
   
   SIGNAL hs_out_hip_phystatus                  : STD_LOGIC;
   SIGNAL hs_out_hip_rxd_ch                     : STD_LOGIC_VECTOR(8 DOWNTO 0);
   SIGNAL hs_out_hip_rxelecidle                 : STD_LOGIC;
   SIGNAL hs_out_hip_rxstatus_ch                : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_out_hip_rxvalid                    : STD_LOGIC;
   SIGNAL hs_out_hip_tx_clk                     : STD_LOGIC;
   SIGNAL hs_out_pcs_eidleinfersel_ch           : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_out_pcs_powerdown_ch               : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL hs_out_pcs_rate                       : STD_LOGIC;		--feed rx0.pcs_rate to cmu
   SIGNAL hs_out_pcs_rxpolarity                 : STD_LOGIC;
   SIGNAL hs_out_pcs_txd_ch                     : STD_LOGIC_VECTOR(10 DOWNTO 0);
   SIGNAL hs_out_pcs_txdeemph                   : STD_LOGIC;
   SIGNAL hs_out_pcs_txdetectrxloopback         : STD_LOGIC;
   SIGNAL hs_out_pcs_txmargin_ch                : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_out_phystatus                      : STD_LOGIC;
   SIGNAL hs_out_rxd_ch                         : STD_LOGIC_VECTOR(8 DOWNTO 0);
   SIGNAL hs_out_rxelecidle                     : STD_LOGIC;
   SIGNAL hs_out_rxstatus_ch                    : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL hs_out_rxvalid                        : STD_LOGIC;
   
   --///////////////////////////////////////////////////////////////////////////
   -- sub-block interface: pipe_interface (pi)  ------------------------------//
   --///////////////////////////////////////////////////////////////////////////
   
   SIGNAL pi_in_pipe_rx_clk                     : STD_LOGIC;		-- beginning input
   SIGNAL pi_in_pipe_tx_clk                     : STD_LOGIC;
   SIGNAL pi_in_polinv_rx                       : STD_LOGIC;
   SIGNAL pi_in_power_state_transition_done     : STD_LOGIC;
   SIGNAL pi_in_power_state_transition_done_ena : STD_LOGIC;
   SIGNAL pi_in_powerdown                       : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL pi_in_refclk_b                        : STD_LOGIC;
   SIGNAL pi_in_refclk_b_reset                  : STD_LOGIC;
   SIGNAL pi_in_revloopback                     : STD_LOGIC;
   SIGNAL pi_in_rx_detect_valid                 : STD_LOGIC;
   SIGNAL pi_in_rx_found                        : STD_LOGIC;
   SIGNAL pi_in_rx_pipe_reset                   : STD_LOGIC;
   SIGNAL pi_in_rxbeacon                        : STD_LOGIC;
   SIGNAL pi_in_rxd                             : STD_LOGIC_VECTOR(63 DOWNTO 0);
   SIGNAL pi_in_rxelectricalidle                : STD_LOGIC;
   SIGNAL pi_in_rxpolarity                      : STD_LOGIC;
   SIGNAL pi_in_tx_elec_idle_comp               : STD_LOGIC;
   SIGNAL pi_in_tx_pipe_reset                   : STD_LOGIC;
   SIGNAL pi_in_txcompliance                    : STD_LOGIC;
   SIGNAL pi_in_txd_ch                          : STD_LOGIC_VECTOR(43 DOWNTO 0);
   SIGNAL pi_in_txdetectrxloopback              : STD_LOGIC;
   SIGNAL pi_in_txelecidle                      : STD_LOGIC;
   SIGNAL pi_in_powerstatein                    : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL pi_in_txdetectrxin                    : STD_LOGIC;
   
   -- new stratixiv input interfaces - ww26.5
   SIGNAL pi_in_speed_change                    : STD_LOGIC;		-- from rx_digi - Auto Speed Negotiation Module
   SIGNAL pi_in_txdeemph                        : STD_LOGIC;		-- tx_only
   SIGNAL pi_in_txmargin                        : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- tx only
   SIGNAL pi_in_txswing                         : STD_LOGIC;		-- tx only
   
   -- ww47 input interfaces 
   SIGNAL pi_in_speed_change_centrl             : STD_LOGIC;
   SIGNAL pi_in_speed_change_quad_up            : STD_LOGIC;
   SIGNAL pi_in_speed_change_quad_down          : STD_LOGIC;
   
   -- ww25.2008
   SIGNAL pi_in_sigdetni                        : STD_LOGIC;

   SIGNAL pi_out_phystatus                      : STD_LOGIC;		-- beginning output
   SIGNAL pi_out_sim_state_transition_done      : STD_LOGIC;
   SIGNAL pi_out_polinv_rx_int                  : STD_LOGIC;
   SIGNAL pi_out_powerstate                     : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- to both cmu and rx
   SIGNAL pi_out_rev_loopbk                     : STD_LOGIC;
   SIGNAL pi_out_rxd_ch                         : STD_LOGIC_VECTOR(63 DOWNTO 0);
   SIGNAL pi_out_rxelecidle                     : STD_LOGIC;
   SIGNAL pi_out_rxstatus                       : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL pi_out_rxvalid                        : STD_LOGIC;
   SIGNAL pi_out_tx_elec_idle                   : STD_LOGIC;
   SIGNAL pi_out_txbeacon                       : STD_LOGIC;
   SIGNAL pi_out_txd                            : STD_LOGIC_VECTOR(43 DOWNTO 0);
   SIGNAL pi_out_txdetectrx                     : STD_LOGIC;
   
   -- new stratixiv output interfaces - ww26.5
   SIGNAL pi_out_txdeemph_int                   : STD_LOGIC;		--tx only
   SIGNAL pi_out_txmargin_int                   : STD_LOGIC_VECTOR(2 DOWNTO 0);		--tx only
   SIGNAL pi_out_txswing_int                    : STD_LOGIC;		--tx only
   
   -- ignoring crams
   SIGNAL tmp_cram_rtx_elec_idle_delay          : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- tx_only
   SIGNAL tmp_cram_rtxswing_sel_ena             : STD_LOGIC;		-- tx_only
   
   --///////////////////////////////////////////////////////////////////////////
   -- sub-block interface: rx_digi (rd)  -------------------------------------//
   --///////////////////////////////////////////////////////////////////////////
   
   SIGNAL rd_in_a1a2_size                       : STD_LOGIC;		-- begin input
   SIGNAL rd_in_align_status                    : STD_LOGIC;
   SIGNAL rd_in_align_status_sync_0             : STD_LOGIC;
   SIGNAL rd_in_align_status_sync_2             : STD_LOGIC;
   SIGNAL rd_in_bitloc_rev_en                   : STD_LOGIC;
   SIGNAL rd_in_bitslip                         : STD_LOGIC;
   SIGNAL rd_in_byte_rev_en                     : STD_LOGIC;
   SIGNAL rd_in_bytordpld                       : STD_LOGIC;
   SIGNAL rd_in_clklow                          : STD_LOGIC;
   SIGNAL rd_in_cmpfifourst                     : STD_LOGIC;
   SIGNAL rd_in_en_dskw_gp                      : STD_LOGIC;
   SIGNAL rd_in_en_dskw_qd                      : STD_LOGIC;
   SIGNAL rd_in_encdt                           : STD_LOGIC;
   SIGNAL rd_in_encoder_testbus                 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL rd_in_fifo_rd_in_comp_0               : STD_LOGIC;
   SIGNAL rd_in_fifo_rd_in_comp_2               : STD_LOGIC;
   SIGNAL rd_in_fifo_rst_rd_gp                  : STD_LOGIC;
   SIGNAL rd_in_fifo_rst_rd_qd                  : STD_LOGIC;
   SIGNAL rd_in_fref                            : STD_LOGIC;
   SIGNAL rd_in_hard_reset                      : STD_LOGIC;
   SIGNAL rd_in_phfifourst_rx                   : STD_LOGIC;
   SIGNAL rd_in_pld_rx_clk                      : STD_LOGIC;
   SIGNAL rd_in_pma_testbus                     : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL rd_in_polinv_rx                       : STD_LOGIC;
   SIGNAL rd_in_pudi                            : STD_LOGIC_VECTOR(19 DOWNTO 0);
   SIGNAL rd_in_rcvd_clk_pma                    : STD_LOGIC;
   SIGNAL rd_in_rcvd_clk0_pma                   : STD_LOGIC;
   SIGNAL rd_in_rdenable_rmf                    : STD_LOGIC;
   SIGNAL rd_in_rdenable_rx                     : STD_LOGIC;
   SIGNAL rd_in_refclk_pma                      : STD_LOGIC;
   SIGNAL rd_in_rx_control_rs                   : STD_LOGIC;
   SIGNAL rd_in_rx_data_rs                      : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL rd_in_rxpma_rst                       : STD_LOGIC;
   SIGNAL rd_in_rxpcs_rst                       : STD_LOGIC;
   SIGNAL rd_in_sigdetni                        : STD_LOGIC;
   SIGNAL rd_in_tx_ctrl_testbus                 : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL rd_in_txlp20b                         : STD_LOGIC_VECTOR(19 DOWNTO 0);
   SIGNAL rd_in_txpma_local_clk                 : STD_LOGIC;
   SIGNAL rd_in_wrdisable_rx                    : STD_LOGIC;
   SIGNAL rd_in_wrenable_rmf                    : STD_LOGIC;
   
   -- new input interfaces in STRATIXIV - ww26.5
   -- WYS (eidleinfersel)
   SIGNAL rd_in_eidleinfersel                   : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- Electrical Idle inference mechanism select
   -- WYS (rateswitchdone)
   SIGNAL rd_in_gen2ngen1                       : STD_LOGIC;		-- frequency switch done from PMA (rising edge of old clock to rising edge of new clock)
   -- WYS (rateswitchxndone)
   SIGNAL rd_in_gen2ngen1_bundle                : STD_LOGIC;		-- for bundle
   --to rx_ctrl and grouped with rxstatus_int,rxvalid_int as pipe_status_in
   --impact the out phystatus
   --from: rx_pipe
   SIGNAL rd_in_phystatus_int                   : STD_LOGIC;
   --from pma to auto_negotiation
   --from top feeding to both rx and tx_pcs.
   SIGNAL rd_in_powerdown                       : STD_LOGIC_VECTOR(1 DOWNTO 0);
   --from tx_ctrl - WYS (rateswitch)
   -- WYS (rxelecidlerateswitch)
   --from rx_pipe feeding to rx_ctrl
   SIGNAL rd_in_rxstatus_int                    : STD_LOGIC_VECTOR(2 DOWNTO 0);
   --from rx_pipe feeding to rx_ctrl
   SIGNAL rd_in_rxvalid_int                     : STD_LOGIC;
   
   -- ww47 RTL update - input interfaces ------------------------------------
   SIGNAL rd_in_rate                            : STD_LOGIC;		-- rate change output from upper layers. // from digi_chnl_support
   
   -- CDR control
   SIGNAL rd_in_pld_ltr                         : STD_LOGIC;		-- PLD control of the CDR when rcdr_ctrl_en = 1'b0
   SIGNAL rd_in_prbs_cid_en                     : STD_LOGIC;		-- PLD control of PRBS-CID enable
   
   -- new signal inputs for bundling
   SIGNAL rd_in_rx_div2_sync_in_centrl          : STD_LOGIC;
   SIGNAL rd_in_rx_div2_sync_in_quad_up         : STD_LOGIC;
   SIGNAL rd_in_rx_div2_sync_in_quad_down       : STD_LOGIC;
   SIGNAL rd_in_reset_pc_ptrs_in_centrl         : STD_LOGIC;
   SIGNAL rd_in_reset_pc_ptrs_in_quad_up        : STD_LOGIC;
   SIGNAL rd_in_reset_pc_ptrs_in_quad_down      : STD_LOGIC;
   SIGNAL rd_in_wr_enable_in_centrl             : STD_LOGIC;
   SIGNAL rd_in_wr_enable_in_quad_up            : STD_LOGIC;
   SIGNAL rd_in_wr_enable_in_quad_down          : STD_LOGIC;
   SIGNAL rd_in_rd_enable_in_centrl             : STD_LOGIC;
   SIGNAL rd_in_rd_enable_in_quad_up            : STD_LOGIC;
   SIGNAL rd_in_rd_enable_in_quad_down          : STD_LOGIC;
   SIGNAL rd_in_rx_we_in_centrl                 : STD_LOGIC;
   SIGNAL rd_in_rx_we_in_quad_up                : STD_LOGIC;
   SIGNAL rd_in_rx_we_in_quad_down              : STD_LOGIC;
   
   SIGNAL rd_in_speed_change_in_centrl          : STD_LOGIC;		-- up/down signals are in pipe_top_interface
   
   -- pipeline inputs for bundling
   SIGNAL rd_in_rx_div2_sync_in_pipe_quad_up    : STD_LOGIC;
   SIGNAL rd_in_rx_div2_sync_in_pipe_quad_down  : STD_LOGIC;
   SIGNAL rd_in_reset_pc_ptrs_in_pipe_quad_up   : STD_LOGIC;
   SIGNAL rd_in_reset_pc_ptrs_in_pipe_quad_down : STD_LOGIC;
   SIGNAL rd_in_wr_enable_in_pipe_quad_up       : STD_LOGIC;
   SIGNAL rd_in_wr_enable_in_pipe_quad_down     : STD_LOGIC;
   SIGNAL rd_in_rd_enable_in_pipe_quad_up       : STD_LOGIC;
   SIGNAL rd_in_rd_enable_in_pipe_quad_down     : STD_LOGIC;
   SIGNAL rd_in_rx_we_in_pipe_quad_up           : STD_LOGIC;
   SIGNAL rd_in_rx_we_in_pipe_quad_down         : STD_LOGIC;
   SIGNAL rd_in_speed_change_in_pipe_quad_up    : STD_LOGIC;
   SIGNAL rd_in_speed_change_in_pipe_quad_down  : STD_LOGIC;
   -- Bundle Mode Inputs for config_sel
   SIGNAL rd_in_config_sel_centrl               : STD_LOGIC;
   SIGNAL rd_in_config_sel_quad_up              : STD_LOGIC;
   SIGNAL rd_in_config_sel_quad_down            : STD_LOGIC;
   
   -- output interfaces -----------------------------------------------------
   SIGNAL rd_out_a1a2_k1k2_flag                 : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- begin output
   SIGNAL rd_out_align_det_sync                 : STD_LOGIC;
   SIGNAL rd_out_align_status_sync              : STD_LOGIC;
   SIGNAL rd_out_almost_fl_rmf                  : STD_LOGIC;
   SIGNAL rd_out_almost_mt_rmf                  : STD_LOGIC;
   SIGNAL rd_out_bistdone                       : STD_LOGIC;
   SIGNAL rd_out_bisterr                        : STD_LOGIC;
   SIGNAL rd_out_byteord_flag                   : STD_LOGIC;
   SIGNAL rd_out_cg_comma                       : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rd_out_chnl_test_bus_out              : STD_LOGIC_VECTOR(9 DOWNTO 0);
   SIGNAL rd_out_clk_2_b                        : STD_LOGIC;
   SIGNAL rd_out_dec_ctl                        : STD_LOGIC;
   SIGNAL rd_out_dec_data                       : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL rd_out_dec_data_valid                 : STD_LOGIC;
   SIGNAL rd_out_empty_rmf                      : STD_LOGIC;
   SIGNAL rd_out_empty_rx                       : STD_LOGIC;
   SIGNAL rd_out_err_ctl                        : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rd_out_err_data                       : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL rd_out_fifo_rd_out_comp               : STD_LOGIC;
   SIGNAL rd_out_freq_lock                      : STD_LOGIC;
   SIGNAL rd_out_full_rmf                       : STD_LOGIC;
   SIGNAL rd_out_full_rx                        : STD_LOGIC;
   SIGNAL rd_out_prbs_done                      : STD_LOGIC;
   SIGNAL rd_out_prbs_err_lt                    : STD_LOGIC;
   SIGNAL rd_out_rcvd_clk_pma_b                 : STD_LOGIC;
   SIGNAL rd_out_rd_align                       : STD_LOGIC;
   SIGNAL rd_out_rev_loop_data                  : STD_LOGIC_VECTOR(19 DOWNTO 0);
   SIGNAL rd_out_rlv                            : STD_LOGIC;
   SIGNAL rd_out_rlv_lt                         : STD_LOGIC;
   SIGNAL rd_out_running_disp                   : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rd_out_rx_clk                         : STD_LOGIC;
   SIGNAL rd_out_rx_pipe_clk                    : STD_LOGIC;
   SIGNAL rd_out_rx_pipe_soft_reset             : STD_LOGIC;
   SIGNAL rd_out_rxd                            : STD_LOGIC_VECTOR(63 DOWNTO 0);
   SIGNAL rd_out_selftest_done                  : STD_LOGIC;
   SIGNAL rd_out_selftest_err                   : STD_LOGIC;
   SIGNAL rd_out_signal_detect_out              : STD_LOGIC;
   SIGNAL rd_out_sync_status                    : STD_LOGIC;
   
   -- new output interfaces - ww26.5
   --from auto_speed_neg to nowhere
   --from auto_speed_neg to nowhere to tx_digi (tx_ctrl)
   -- to PLD
   
   SIGNAL rd_out_phystatus                      : STD_LOGIC;
   --to PIPE's rxd (UPDATE)
   SIGNAL rd_out_pipe_data                      : STD_LOGIC_VECTOR(63 DOWNTO 0);
   -- from rx_ctrl to:nowhere
   SIGNAL rd_out_soft_reset_rclk1               : STD_LOGIC;		-- Synchronized reset
   --from auto_speed_neg to nowhere to rx_pipe
   SIGNAL rd_out_speed_change                   : STD_LOGIC;		-- speed change done to PIPE interface (i.e. auto negotiation done)
   --from electrial_idle_inference_module to PCS_TOP
   
   --from electrial_idle_inference_module to rx_pipe
   SIGNAL rd_out_rxelecidle_int                 : STD_LOGIC;		-- Asserted when Electrical Idle is detected
   --to PLD
   SIGNAL rd_out_rxstatus                       : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rd_out_rxvalid                        : STD_LOGIC;
   -- values greater than 2 entails that syncstatus is used
   
   -- ww47 RTL output interfaces -------------------------------------------------
   
   -- to PLD and then back to tx_boundary_sel of tx_pcs
   SIGNAL rd_out_wa_boundary                    : STD_LOGIC_VECTOR(4 DOWNTO 0);		--describes word boundary 
   
   -- CDR control
   SIGNAL rd_out_early_eios                     : STD_LOGIC;		-- Asserted when K_I or K_X_I is detected on the incoming data  
   -- to PLD 
   
   SIGNAL rd_out_ltr                            : STD_LOGIC;		-- force CDR to LTR mode - to RX_PMA?
   
   -- new outputs for bundling and auto speed
   SIGNAL rd_out_rx_div2_sync_out_pipe          : STD_LOGIC;
   SIGNAL rd_out_rx_we_out_pipe                 : STD_LOGIC;
   SIGNAL rd_out_wr_enable_out_pipe             : STD_LOGIC;
   SIGNAL rd_out_rd_enable_out_pipe             : STD_LOGIC;
   SIGNAL rd_out_reset_pc_ptrs_out_pipe         : STD_LOGIC;
   SIGNAL rd_out_speed_change_out_pipe          : STD_LOGIC;
   SIGNAL rd_out_dis_pc_byte                    : STD_LOGIC;		-- from auto_speed_neg and feed to digi_tx 
   SIGNAL rd_out_reset_pc_ptrs                  : STD_LOGIC;		-- from auto_speed_neg and feed to digi_tx
   SIGNAL rd_out_pcie_switch                    : STD_LOGIC;
   
   -- ww12 interfaces --------------------------------------------------------
   --feeding to cdr_ctrl and eii_module
   --from rev_loopbk of tx_pipe_interface; 
   --tx_digi.rev_loopbk <= tx_pipe_interface.rev_loopback; (ww12 WYS todo: adding rev_loopback output port at tx_pcs)
   --rx_digi.pipe_loopbk <= tx_pipe_interface.rev_loopback; (ww12 WYS todo: adding pipe_loopback input port at rx_pcs)
   -- reverse parallel loopback requires 4 EIOS to be transmitted up to the upper layer.
   --Used in the CDR control block and electrical idle inference module 
   SIGNAL rd_in_pipe_loopbk                     : STD_LOGIC;
   
   -- XAUI related ports 
   -- from rate_match to rate_match to achieve all channel rd/wr at same time
   -- Full connection rx[i].cg_comp_rd_d_chj <= rx[j].cg_comp_rd_out
   -- for Quartus simulation: using its own ptrs since we do not model delays
   SIGNAL rd_out_cg_comp_rd_d_out               : STD_LOGIC;
   SIGNAL rd_out_cg_comp_wr_out                 : STD_LOGIC;
   
   SIGNAL rd_in_cg_comp_rd_d_ch0                : STD_LOGIC;
   SIGNAL rd_in_cg_comp_rd_d_ch1                : STD_LOGIC;
   SIGNAL rd_in_cg_comp_rd_d_ch2                : STD_LOGIC;
   SIGNAL rd_in_cg_comp_rd_d_ch3                : STD_LOGIC;
   SIGNAL rd_in_cg_comp_wr_ch0                  : STD_LOGIC;
   SIGNAL rd_in_cg_comp_wr_ch1                  : STD_LOGIC;
   SIGNAL rd_in_cg_comp_wr_ch2                  : STD_LOGIC;
   SIGNAL rd_in_cg_comp_wr_ch3                  : STD_LOGIC;
   
   -- XAUI related channel 0 to rest channels in ICD
   -- in Quartus sim: using its own ptrs
   SIGNAL rd_out_del_cond_met_out               : STD_LOGIC;
   SIGNAL rd_out_fifo_ovr_out                   : STD_LOGIC;
   SIGNAL rd_out_latency_comp_out               : STD_LOGIC;
   SIGNAL rd_out_insert_incomplete_out          : STD_LOGIC;
   
   SIGNAL rd_in_del_cond_met_0                  : STD_LOGIC;
   SIGNAL rd_in_fifo_ovr_0                      : STD_LOGIC;
   SIGNAL rd_in_latency_comp_0                  : STD_LOGIC;
   SIGNAL rd_in_insert_incomplete_0             : STD_LOGIC;
   
   -- ww12 - splitting IQP into pipe_up/_down
   SIGNAL rd_out_rx_div2_sync_out_pipe_up       : STD_LOGIC;
   SIGNAL rd_out_rx_we_out_pipe_up              : STD_LOGIC;
   SIGNAL rd_out_wr_enable_out_pipe_up          : STD_LOGIC;
   SIGNAL rd_out_rd_enable_out_pipe_up          : STD_LOGIC;
   SIGNAL rd_out_reset_pc_ptrs_out_pipe_up      : STD_LOGIC;
   SIGNAL rd_out_speed_change_out_pipe_up       : STD_LOGIC;
   
   SIGNAL rd_out_rx_div2_sync_out_pipe_down     : STD_LOGIC;
   SIGNAL rd_out_rx_we_out_pipe_down            : STD_LOGIC;
   SIGNAL rd_out_wr_enable_out_pipe_down        : STD_LOGIC;
   SIGNAL rd_out_rd_enable_out_pipe_down        : STD_LOGIC;
   SIGNAL rd_out_reset_pc_ptrs_out_pipe_down    : STD_LOGIC;
   SIGNAL rd_out_speed_change_out_pipe_down     : STD_LOGIC;
   
   -- ww12 - spliting inputs because tx_side's iqp output split
   SIGNAL rd_in_tx_div2_sync_out_pipe_up        : STD_LOGIC;		-- from corresponding tx channels output *_out_pipe
   SIGNAL rd_in_fifo_select_out_pipe_up         : STD_LOGIC;		-- from corresponding tx channels output *_out_pipe
   SIGNAL rd_in_tx_wr_enable_out_pipe_up        : STD_LOGIC;		-- from corresponding tx channels output *_out_pipe
   SIGNAL rd_in_tx_rd_enable_out_pipe_up        : STD_LOGIC;		-- from corresponding tx channels output *_out_pipe
   SIGNAL rd_in_tx_div2_sync_out_pipe_down      : STD_LOGIC;		-- from corresponding tx channels output *_out_pipe
   SIGNAL rd_in_fifo_select_out_pipe_down       : STD_LOGIC;		-- from corresponding tx channels output *_out_pipe
   SIGNAL rd_in_tx_wr_enable_out_pipe_down      : STD_LOGIC;		-- from corresponding tx channels output *_out_pipe
   SIGNAL rd_in_tx_rd_enable_out_pipe_down      : STD_LOGIC;		-- from corresponding tx channels output *_out_pipe
   
   -- ww25.2008 interfaces --------------------------------------------------------
   SIGNAL rd_in_pcs_wrapback_in                 : STD_LOGIC_VECTOR(69 DOWNTO 0);
     
   --///////////////////////////////////////////////////////////////////////////
   -- Internal Variables  ----------------------------------------------------//
   --///////////////////////////////////////////////////////////////////////////
   SIGNAL i                                     : INTEGER;
   SIGNAL j                                     : INTEGER;
   
   SIGNAL tmp_reg40                             : STD_LOGIC_VECTOR(39 DOWNTO 0);
   SIGNAL tmp_rcomp_size                        : STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   --///////////////////////////////////////////////////////////////////////////
   -- Internal Functions  ----------------------------------------------------//
   --///////////////////////////////////////////////////////////////////////////
   
   --///////////////////////////////////////////////////////////////////////////
   -- INPUT FILTERING  -------------------------------------------------------//
   --///////////////////////////////////////////////////////////////////////////
   
   SIGNAL a1a2size_in                           : STD_LOGIC;
   SIGNAL alignstatus_in                        : STD_LOGIC;
   SIGNAL alignstatussync_in                    : STD_LOGIC;
   SIGNAL bitslip_in                            : STD_LOGIC;
   SIGNAL coreclk_in                            : STD_LOGIC;
   SIGNAL datain_in                             : STD_LOGIC_VECTOR(19 DOWNTO 0);		--NEW: updated width
   SIGNAL digitalreset_in                       : STD_LOGIC;
   SIGNAL dpriodisable_in                       : STD_LOGIC;
   SIGNAL dprioin_in                            : STD_LOGIC_VECTOR(399 DOWNTO 0);		-- tmp width
   SIGNAL elecidleinfersel_in                   : STD_LOGIC_VECTOR(2 DOWNTO 0);		
   SIGNAL enabledeskew_in                       : STD_LOGIC;
   SIGNAL enabyteord_in                         : STD_LOGIC;
   SIGNAL enapatternalign_in                    : STD_LOGIC;
   SIGNAL fifordin_in                           : STD_LOGIC;
   SIGNAL fiforesetrd_in                        : STD_LOGIC;
   SIGNAL invpol_in                             : STD_LOGIC;
   SIGNAL localrefclk_in                        : STD_LOGIC;
   SIGNAL masterclk_in                          : STD_LOGIC;
   SIGNAL parallelfdbk_in                       : STD_LOGIC_VECTOR(19 DOWNTO 0);
   SIGNAL phfifordenable_in                     : STD_LOGIC;
   SIGNAL phfiforeset_in                        : STD_LOGIC;
   SIGNAL phfifowrdisable_in                    : STD_LOGIC;
   SIGNAL phfifox4bytesel_in                    : STD_LOGIC;
   SIGNAL phfifox4rdenable_in                   : STD_LOGIC;
   SIGNAL phfifox4wrclk_in                      : STD_LOGIC;
   SIGNAL phfifox4wrenable_in                   : STD_LOGIC;
   SIGNAL phfifox8bytesel_in                    : STD_LOGIC;
   SIGNAL phfifox8rdenable_in                   : STD_LOGIC;
   SIGNAL phfifox8wrclk_in                      : STD_LOGIC;
   SIGNAL phfifox8wrenable_in                   : STD_LOGIC;
   SIGNAL pipe8b10binvpolarity_in               : STD_LOGIC;
   SIGNAL pipepowerdown_in                      : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL pipepowerstate_in                     : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL ppmdetectdividedclk_in                : STD_LOGIC;		
   SIGNAL ppmdetectrefclk_in                    : STD_LOGIC;		
   SIGNAL quadreset_in                          : STD_LOGIC;
   SIGNAL rateswitch_in                         : STD_LOGIC;		
   SIGNAL rateswitchisdone_in                   : STD_LOGIC;		
   SIGNAL rateswitchxndone_in                   : STD_LOGIC;		
   SIGNAL recoveredclk_in                       : STD_LOGIC;		
   SIGNAL refclk_in                             : STD_LOGIC;
   SIGNAL revbitorderwa_in                      : STD_LOGIC;
   SIGNAL revbyteorderwa_in                     : STD_LOGIC;
   SIGNAL rmfifordena_in                        : STD_LOGIC;
   SIGNAL rmfiforeset_in                        : STD_LOGIC;
   SIGNAL rmfifowrena_in                        : STD_LOGIC;
   SIGNAL rxdetectvalid_in                      : STD_LOGIC;
   SIGNAL rxelecidlerateswitch_in               : STD_LOGIC;		
   SIGNAL rxfound_in                            : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL signaldetected_in                     : STD_LOGIC;		
   SIGNAL xgmctrlin_in                          : STD_LOGIC;
   SIGNAL xgmdatain_in                          : STD_LOGIC_VECTOR(7 DOWNTO 0);		--54 ins ---
   
   --ww47 inputs
   SIGNAL autospdxnconfigsel_in                 : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- config_sel_centrl, quad_up, quad_down
   SIGNAL autospdxnspdchg_in                    : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- From CMU.spped-change_centrl, rx3(up), rx0(down)
   SIGNAL cdrctrllocktorefcl_in                 : STD_LOGIC;		-- pld_ltr
   SIGNAL hip8b10binvpolarity_in                : STD_LOGIC;		-- hip_rxpolarity
   SIGNAL hipelecidleinfersel_in                : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- hip_eidleinfersel_ch
   SIGNAL hippowerdown_in                       : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- hip_powerdown_ch
   SIGNAL hiprateswitch_in                      : STD_LOGIC;		-- hip_rate
   SIGNAL iqpautospdxnspgchg_in                 : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- speed_change_in_pipe_quad_up, down
   SIGNAL iqpphfifoxnbytesel_in                 : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- wr_enable_ptrs_in_pipe_quad_up, down
   SIGNAL iqpphfifoxnptrsreset_in               : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- reset_pc_ptrs_in_pipe_quad_up, down
   SIGNAL iqpphfifoxnrdenable_in                : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- rd_enable_ptrs_in_pipe_quad_up, down
   SIGNAL iqpphfifoxnwrclk_in                   : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- rx_div2_sync_in_pipe_quad_up, down
   SIGNAL iqpphfifoxnwrenable_in                : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- wr_enable_ptrs_in_pipe_quad_up, down
   SIGNAL phfifoxnbytesel_in                    : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- rx_we_in_centrl, quad_up, quad_down
   SIGNAL phfifoxnptrsreset_in                  : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- ph fifo. From CMU to both RX & TX.
   SIGNAL phfifoxnrdenable_in                   : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- rd_enable_in_centrl, quad_up, quad_down
   SIGNAL phfifoxnwrclk_in                      : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- ph fifo. From CMU to RX.
   SIGNAL phfifoxnwrenable_in                   : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- wr_enable_in_centrl, quad_up, quad_down
   SIGNAL powerdn_in                            : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL prbscidenable_in                      : STD_LOGIC;		-- prbs_cid_en
   
   -- ww12.08 inputs
   SIGNAL grayelecidleinferselfromtx_in        : STD_LOGIC_VECTOR(2 DOWNTO 0);
  
   SIGNAL pipeenrevparallellpbkfromtx_in       : STD_LOGIC := '0';
      
   --NEW: updated width
   --assign disablefifordin_in = (disablefifordin == 1'b0) ? 1'b0 : 1'b1; // inverted
   --assign disablefifowrin_in = (disablefifowrin == 1'b0) ? 1'b0 : 1'b1; // inverted
   --///////////////////////////////////////////////////////////////////////////
   -- TIMING -- TCO/TSU/HOLD                                                  //
   --///////////////////////////////////////////////////////////////////////////
   
   --///////////////////////////////////////////////////////////////////////////
   -- dprio outputs                                                           //
   --///////////////////////////////////////////////////////////////////////////
   SIGNAL wire_dprioout                         : STD_LOGIC_VECTOR(299 DOWNTO 0);
     
   --///////////////////////////////////////////////////////////////////////////
   -- select CRAMs between DPIRO vs. parameters  -----------------------------//
   --///////////////////////////////////////////////////////////////////////////
   SIGNAL mpcs_dpriodisable                     : STD_LOGIC;
   -- X-HDL generated signals

   SIGNAL xhdl0 : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL xhdl1 : STD_LOGIC_VECTOR(1 DOWNTO 0);
BEGIN
          
      ------------------------
      --  Wire Delay Block --
      ------------------------
      WireDelay : BLOCK
      BEGIN
           VitalWireDelay (phfifox8bytesel_ipd,phfifox8bytesel, tipd_phfifox8bytesel);
           VitalWireDelay (xgmctrlin_ipd,xgmctrlin, tipd_xgmctrlin);
       bits_pipepowerdown : FOR i in pipepowerdown'RANGE GENERATE
           VitalWireDelay (pipepowerdown_ipd(i),pipepowerdown(i), tipd_pipepowerdown(i));
       END GENERATE;
       bits_parallelfdbk : FOR i in parallelfdbk'RANGE GENERATE
           VitalWireDelay (parallelfdbk_ipd(i),parallelfdbk(i), tipd_parallelfdbk(i));
       END GENERATE;
       bits_iqpphfifoxnwrclk : FOR i in iqpphfifoxnwrclk'RANGE GENERATE
           VitalWireDelay (iqpphfifoxnwrclk_ipd(i),iqpphfifoxnwrclk(i), tipd_iqpphfifoxnwrclk(i));
       END GENERATE;
           VitalWireDelay (masterclk_ipd,masterclk, tipd_masterclk);
           VitalWireDelay (rxelecidlerateswitch_ipd,rxelecidlerateswitch, tipd_rxelecidlerateswitch);
       bits_pipepowerstate : FOR i in pipepowerstate'RANGE GENERATE
           VitalWireDelay (pipepowerstate_ipd(i),pipepowerstate(i), tipd_pipepowerstate(i));
       END GENERATE;
           VitalWireDelay (alignstatussync_ipd,alignstatussync, tipd_alignstatussync);
       bits_powerdn : FOR i in powerdn'RANGE GENERATE
           VitalWireDelay (powerdn_ipd(i),powerdn(i), tipd_powerdn(i));
       END GENERATE;
           VitalWireDelay (refclk_ipd,refclk, tipd_refclk);
           VitalWireDelay (phfifox4bytesel_ipd,phfifox4bytesel, tipd_phfifox4bytesel);
           VitalWireDelay (bitslip_ipd,bitslip, tipd_bitslip);
           VitalWireDelay (phfiforeset_ipd,phfiforeset, tipd_phfiforeset);
       bits_dprioin : FOR i in dprioin'RANGE GENERATE
           VitalWireDelay (dprioin_ipd(i),dprioin(i), tipd_dprioin(i));
       END GENERATE;
           VitalWireDelay (disablefifowrin_ipd,disablefifowrin, tipd_disablefifowrin);
           VitalWireDelay (ppmdetectdividedclk_ipd,ppmdetectdividedclk, tipd_ppmdetectdividedclk);
       bits_datain : FOR i in datain'RANGE GENERATE
           VitalWireDelay (datain_ipd(i),datain(i), tipd_datain(i));
       END GENERATE;
           VitalWireDelay (enabledeskew_ipd,enabledeskew, tipd_enabledeskew);
       bits_hippowerdown : FOR i in hippowerdown'RANGE GENERATE
           VitalWireDelay (hippowerdown_ipd(i),hippowerdown(i), tipd_hippowerdown(i));
       END GENERATE;
           VitalWireDelay (revbyteorderwa_ipd,revbyteorderwa, tipd_revbyteorderwa);
           VitalWireDelay (phfifox4wrenable_ipd,phfifox4wrenable, tipd_phfifox4wrenable);
           VitalWireDelay (dpriodisable_ipd,dpriodisable, tipd_dpriodisable);
           VitalWireDelay (phfifox8wrclk_ipd,phfifox8wrclk, tipd_phfifox8wrclk);
           VitalWireDelay (enabyteord_ipd,enabyteord, tipd_enabyteord);
           VitalWireDelay (invpol_ipd,invpol, tipd_invpol);
           VitalWireDelay (phfifox8rdenable_ipd,phfifox8rdenable, tipd_phfifox8rdenable);
           VitalWireDelay (revbitorderwa_ipd,revbitorderwa, tipd_revbitorderwa);
           VitalWireDelay (localrefclk_ipd,localrefclk, tipd_localrefclk);
           VitalWireDelay (enapatternalign_ipd,enapatternalign, tipd_enapatternalign);
       bits_iqpphfifoxnrdenable : FOR i in iqpphfifoxnrdenable'RANGE GENERATE
           VitalWireDelay (iqpphfifoxnrdenable_ipd(i),iqpphfifoxnrdenable(i), tipd_iqpphfifoxnrdenable(i));
       END GENERATE;
       bits_iqpphfifoxnptrsreset : FOR i in iqpphfifoxnptrsreset'RANGE GENERATE
           VitalWireDelay (iqpphfifoxnptrsreset_ipd(i),iqpphfifoxnptrsreset(i), tipd_iqpphfifoxnptrsreset(i));
       END GENERATE;
           VitalWireDelay (phfifowrdisable_ipd,phfifowrdisable, tipd_phfifowrdisable);
           VitalWireDelay (signaldetected_ipd,signaldetected, tipd_signaldetected);
           VitalWireDelay (alignstatus_ipd,alignstatus, tipd_alignstatus);
       bits_autospdxnconfigsel : FOR i in autospdxnconfigsel'RANGE GENERATE
           VitalWireDelay (autospdxnconfigsel_ipd(i),autospdxnconfigsel(i), tipd_autospdxnconfigsel(i));
       END GENERATE;
           VitalWireDelay (quadreset_ipd,quadreset, tipd_quadreset);
           VitalWireDelay (rxdetectvalid_ipd,rxdetectvalid, tipd_rxdetectvalid);
           VitalWireDelay (recoveredclk_ipd,recoveredclk, tipd_recoveredclk);
           VitalWireDelay (hiprateswitch_ipd,hiprateswitch, tipd_hiprateswitch);
           VitalWireDelay (phfifordenable_ipd,phfifordenable, tipd_phfifordenable);
           VitalWireDelay (phfifox4wrclk_ipd,phfifox4wrclk, tipd_phfifox4wrclk);
       bits_phfifoxnbytesel : FOR i in phfifoxnbytesel'RANGE GENERATE
           VitalWireDelay (phfifoxnbytesel_ipd(i),phfifoxnbytesel(i), tipd_phfifoxnbytesel(i));
       END GENERATE;
           VitalWireDelay (rmfifowrena_ipd,rmfifowrena, tipd_rmfifowrena);
           VitalWireDelay (a1a2size_ipd,a1a2size, tipd_a1a2size);
           VitalWireDelay (phfifox8wrenable_ipd,phfifox8wrenable, tipd_phfifox8wrenable);
       bits_phfifoxnptrsreset : FOR i in phfifoxnptrsreset'RANGE GENERATE
           VitalWireDelay (phfifoxnptrsreset_ipd(i),phfifoxnptrsreset(i), tipd_phfifoxnptrsreset(i));
       END GENERATE;
       bits_iqpphfifoxnwrenable : FOR i in iqpphfifoxnwrenable'RANGE GENERATE
           VitalWireDelay (iqpphfifoxnwrenable_ipd(i),iqpphfifoxnwrenable(i), tipd_iqpphfifoxnwrenable(i));
       END GENERATE;
       bits_phfifoxnrdenable : FOR i in phfifoxnrdenable'RANGE GENERATE
           VitalWireDelay (phfifoxnrdenable_ipd(i),phfifoxnrdenable(i), tipd_phfifoxnrdenable(i));
       END GENERATE;
           VitalWireDelay (rateswitchisdone_ipd,rateswitchisdone, tipd_rateswitchisdone);
       bits_elecidleinfersel : FOR i in elecidleinfersel'RANGE GENERATE
           VitalWireDelay (elecidleinfersel_ipd(i),elecidleinfersel(i), tipd_elecidleinfersel(i));
       END GENERATE;
           VitalWireDelay (hip8b10binvpolarity_ipd,hip8b10binvpolarity, tipd_hip8b10binvpolarity);
           VitalWireDelay (rateswitchxndone_ipd,rateswitchxndone, tipd_rateswitchxndone);
       bits_iqpautospdxnspgchg : FOR i in iqpautospdxnspgchg'RANGE GENERATE
           VitalWireDelay (iqpautospdxnspgchg_ipd(i),iqpautospdxnspgchg(i), tipd_iqpautospdxnspgchg(i));
       END GENERATE;
           VitalWireDelay (rmfiforeset_ipd,rmfiforeset, tipd_rmfiforeset);
           VitalWireDelay (coreclk_ipd,coreclk, tipd_coreclk);
           VitalWireDelay (rmfifordena_ipd,rmfifordena, tipd_rmfifordena);
           VitalWireDelay (disablefifordin_ipd,disablefifordin, tipd_disablefifordin);
           VitalWireDelay (rateswitch_ipd,rateswitch, tipd_rateswitch);
       bits_hipelecidleinfersel : FOR i in hipelecidleinfersel'RANGE GENERATE
           VitalWireDelay (hipelecidleinfersel_ipd(i),hipelecidleinfersel(i), tipd_hipelecidleinfersel(i));
       END GENERATE;
           VitalWireDelay (phfifox4rdenable_ipd,phfifox4rdenable, tipd_phfifox4rdenable);
           VitalWireDelay (pipe8b10binvpolarity_ipd,pipe8b10binvpolarity, tipd_pipe8b10binvpolarity);
           VitalWireDelay (fifordin_ipd,fifordin, tipd_fifordin);
           VitalWireDelay (ppmdetectrefclk_ipd,ppmdetectrefclk, tipd_ppmdetectrefclk);
           VitalWireDelay (prbscidenable_ipd,prbscidenable, tipd_prbscidenable);
           VitalWireDelay (digitalreset_ipd,digitalreset, tipd_digitalreset);
       bits_rxfound : FOR i in rxfound'RANGE GENERATE
           VitalWireDelay (rxfound_ipd(i),rxfound(i), tipd_rxfound(i));
       END GENERATE;
           VitalWireDelay (cdrctrllocktorefcl_ipd,cdrctrllocktorefcl, tipd_cdrctrllocktorefcl);
       bits_phfifoxnwrclk : FOR i in phfifoxnwrclk'RANGE GENERATE
           VitalWireDelay (phfifoxnwrclk_ipd(i),phfifoxnwrclk(i), tipd_phfifoxnwrclk(i));
       END GENERATE;
       bits_autospdxnspdchg : FOR i in autospdxnspdchg'RANGE GENERATE
           VitalWireDelay (autospdxnspdchg_ipd(i),autospdxnspdchg(i), tipd_autospdxnspdchg(i));
       END GENERATE;
       bits_iqpphfifoxnbytesel : FOR i in iqpphfifoxnbytesel'RANGE GENERATE
           VitalWireDelay (iqpphfifoxnbytesel_ipd(i),iqpphfifoxnbytesel(i), tipd_iqpphfifoxnbytesel(i));
       END GENERATE;
       bits_phfifoxnwrenable : FOR i in phfifoxnwrenable'RANGE GENERATE
           VitalWireDelay (phfifoxnwrenable_ipd(i),phfifoxnwrenable(i), tipd_phfifoxnwrenable(i));
       END GENERATE;
           VitalWireDelay (fiforesetrd_ipd,fiforesetrd, tipd_fiforesetrd);
       bits_xgmdatain : FOR i in xgmdatain'RANGE GENERATE
           VitalWireDelay (xgmdatain_ipd(i),xgmdatain(i), tipd_xgmdatain(i));
       END GENERATE;
      END BLOCK;
          
      ------------------------
      --  Functionality Section --
      ------------------------

    VITAL: PROCESS (coreclk_ipd, phfifordenable_ipd, a1a2sizeout_reg, ctrldetect_reg, dataout_reg, disperr_reg, errdetect_reg, patterndetect_reg, rmfifodatadeleted_reg, rmfifodatainserted_reg, runningdisp_reg, syncstatus_reg, pi_out_rxd_ch, rd_out_byteord_flag, rd_out_full_rx, rd_out_empty_rx, hs_out_rxstatus_ch, hs_out_phystatus, hs_out_rxvalid, rd_out_rxd(13), rd_out_rxd(14), rd_out_rxd(45), rd_out_rxd(46))

    variable Tviol_phfifordenable_coreclk : std_ulogic := '0';
    variable TimingData_phfifordenable_coreclk : VitalTimingDataType := VitalTimingDataInit;

    variable pipebufferstat0_VitalGlitchData: VitalGlitchDataType;
    variable pipebufferstat1_VitalGlitchData: VitalGlitchDataType;
    variable pipebufferstat2_VitalGlitchData: VitalGlitchDataType;
    variable pipebufferstat3_VitalGlitchData: VitalGlitchDataType;
    variable byteorderalignstatus_VitalGlitchData: VitalGlitchDataType;
    variable phfifooverflow_VitalGlitchData: VitalGlitchDataType;
    variable phfifounderflow_VitalGlitchData: VitalGlitchDataType;
    variable pipephydonestatus_VitalGlitchData: VitalGlitchDataType;
    variable pipedatavalid_VitalGlitchData: VitalGlitchDataType;
    variable CQDelayA1a2sizeout: TIME := 0 ns;
    variable CQDelayCtrldetect: TIME := 0 ns;
    variable CQDelayDataout: TIME := 0 ns;
    variable CQDelayDataoutfull: TIME := 0 ns;
    variable CQDelayDisperr: TIME := 0 ns;
    variable CQDelayErrdetect: TIME := 0 ns;
    variable CQDelayPatterndetect: TIME := 0 ns;
    variable CQDelayRmfifodatadeleted: TIME := 0 ns;
    variable CQDelayRmfifodatainserted: TIME := 0 ns;
    variable CQDelayRunningdisp: TIME := 0 ns;
    variable CQDelaySyncstatus: TIME := 0 ns;
    variable CQDelayPipestatus: TIME := 0 ns;

    BEGIN

        ------------------------
        --  Timing Check Section
        ------------------------

        if (TimingChecksOn) then

            VitalSetupHoldCheck (
                Violation       => Tviol_phfifordenable_coreclk,
                TimingData      => TimingData_phfifordenable_coreclk,
                TestSignal      => phfifordenable_ipd,
                TestSignalName  => "PHFIFORDENABLE",
                RefSignal       => coreclk_ipd,
                RefSignalName   => "CORECLK",
                SetupHigh       => tsetup_phfifordenable_coreclk_noedge_posedge,
                SetupLow        => tsetup_phfifordenable_coreclk_noedge_posedge,
                HoldHigh        => thold_phfifordenable_coreclk_noedge_posedge,
                HoldLow         => thold_phfifordenable_coreclk_noedge_posedge,
                RefTransition   => '/',
                HeaderMsg       => InstancePath & "/STRATIXIV_HSSI_RX_PCS",
                XOn             => XOnChecks,
                MsgOn           => MsgOnChecks );
        end if;

        ----------------------
        --  Path Delay Section
        ----------------------

        CQDelayA1a2sizeout := hssiSelectDelay (
            Paths => (0 => (coreclk_ipd'last_event, tpd_coreclk_a1a2sizeout_posedge, TRUE)));
        a1a2sizeout <= TRANSPORT a1a2sizeout_reg AFTER CQDelayA1a2sizeout;

        CQDelayCtrldetect := hssiSelectDelay (
            Paths => (0 => (coreclk_ipd'last_event, tpd_coreclk_ctrldetect_posedge, TRUE)));
        ctrldetect <= TRANSPORT ctrldetect_reg AFTER CQDelayCtrldetect;

        CQDelayDataout := hssiSelectDelay (
            Paths => (0 => (coreclk_ipd'last_event, tpd_coreclk_dataout_posedge, TRUE)));
        dataout <= TRANSPORT dataout_reg AFTER CQDelayDataout;

        CQDelayDataoutfull := hssiSelectDelay (
            Paths => (0 => (coreclk_ipd'last_event, tpd_coreclk_dataoutfull_posedge, TRUE)));
        dataoutfull <= TRANSPORT rd_out_rxd AFTER CQDelayDataoutfull;

        CQDelayDisperr := hssiSelectDelay (
            Paths => (0 => (coreclk_ipd'last_event, tpd_coreclk_disperr_posedge, TRUE)));
        disperr <= TRANSPORT disperr_reg AFTER CQDelayDisperr;

        CQDelayErrdetect := hssiSelectDelay (
            Paths => (0 => (coreclk_ipd'last_event, tpd_coreclk_errdetect_posedge, TRUE)));
        errdetect <= TRANSPORT errdetect_reg AFTER CQDelayErrdetect;

        CQDelayPatterndetect := hssiSelectDelay (
            Paths => (0 => (coreclk_ipd'last_event, tpd_coreclk_patterndetect_posedge, TRUE)));
        patterndetect <= TRANSPORT patterndetect_reg AFTER CQDelayPatterndetect;

        CQDelayRmfifodatadeleted := hssiSelectDelay (
            Paths => (0 => (coreclk_ipd'last_event, tpd_coreclk_rmfifodatadeleted_posedge, TRUE)));
        rmfifodatadeleted <= TRANSPORT rmfifodatadeleted_reg AFTER CQDelayRmfifodatadeleted;

        CQDelayRmfifodatainserted := hssiSelectDelay (
            Paths => (0 => (coreclk_ipd'last_event, tpd_coreclk_rmfifodatainserted_posedge, TRUE)));
        rmfifodatainserted <= TRANSPORT rmfifodatainserted_reg AFTER CQDelayRmfifodatainserted;

        CQDelayRunningdisp := hssiSelectDelay (
            Paths => (0 => (coreclk_ipd'last_event, tpd_coreclk_runningdisp_posedge, TRUE)));
        runningdisp <= TRANSPORT runningdisp_reg AFTER CQDelayRunningdisp;

        CQDelaySyncstatus := hssiSelectDelay (
            Paths => (0 => (coreclk_ipd'last_event, tpd_coreclk_syncstatus_posedge, TRUE)));
        syncstatus <= TRANSPORT syncstatus_reg AFTER CQDelaySyncstatus;

        VitalPathDelay01 (
            OutSignal => pipebufferstat(0),
            OutSignalName => "PIPEBUFFERSTAT",
            OutTemp => rd_out_rxd(13),
            Paths => (1 => (coreclk_ipd'last_event, tpd_coreclk_pipebufferstat_posedge(0), TRUE)),
            GlitchData => pipebufferstat0_VitalGlitchData,
            Mode => DefGlitchMode,
            XOn  => XOn,
            MsgOn  => MsgOn );

        VitalPathDelay01 (
            OutSignal => pipebufferstat(1),
            OutSignalName => "PIPEBUFFERSTAT",
            OutTemp => rd_out_rxd(14),
            Paths => (1 => (coreclk_ipd'last_event, tpd_coreclk_pipebufferstat_posedge(1), TRUE)),
            GlitchData => pipebufferstat1_VitalGlitchData,
            Mode => DefGlitchMode,
            XOn  => XOn,
            MsgOn  => MsgOn );

        VitalPathDelay01 (
            OutSignal => pipebufferstat(2),
            OutSignalName => "PIPEBUFFERSTAT",
            OutTemp => rd_out_rxd(45),
            Paths => (1 => (coreclk_ipd'last_event, tpd_coreclk_pipebufferstat_posedge(2), TRUE)),
            GlitchData => pipebufferstat2_VitalGlitchData,
            Mode => DefGlitchMode,
            XOn  => XOn,
            MsgOn  => MsgOn );

        VitalPathDelay01 (
            OutSignal => pipebufferstat(3),
            OutSignalName => "PIPEBUFFERSTAT",
            OutTemp => rd_out_rxd(46),
            Paths => (1 => (coreclk_ipd'last_event, tpd_coreclk_pipebufferstat_posedge(3), TRUE)),
            GlitchData => pipebufferstat3_VitalGlitchData,
            Mode => DefGlitchMode,
            XOn  => XOn,
            MsgOn  => MsgOn );

        VitalPathDelay01 (
            OutSignal => byteorderalignstatus,
            OutSignalName => "BYTEORDERALIGNSTATUS",
            OutTemp => rd_out_byteord_flag,
            Paths => (1 => (coreclk_ipd'last_event, tpd_coreclk_byteorderalignstatus_posedge, TRUE)),
            GlitchData => byteorderalignstatus_VitalGlitchData,
            Mode => DefGlitchMode,
            XOn  => XOn,
            MsgOn  => MsgOn );

        VitalPathDelay01 (
            OutSignal => phfifooverflow,
            OutSignalName => "PHFIFOOVERFLOW",
            OutTemp => rd_out_full_rx,
            Paths => (1 => (coreclk_ipd'last_event, tpd_coreclk_phfifooverflow_posedge, TRUE)),
            GlitchData => phfifooverflow_VitalGlitchData,
            Mode => DefGlitchMode,
            XOn  => XOn,
            MsgOn  => MsgOn );

        VitalPathDelay01 (
            OutSignal => phfifounderflow,
            OutSignalName => "PHFIFOUNDERFLOW",
            OutTemp => rd_out_empty_rx,
            Paths => (1 => (coreclk_ipd'last_event, tpd_coreclk_phfifounderflow_posedge, TRUE)),
            GlitchData => phfifounderflow_VitalGlitchData,
            Mode => DefGlitchMode,
            XOn  => XOn,
            MsgOn  => MsgOn );

        CQDelayPipestatus := hssiSelectDelay (
            Paths => (0 => (coreclk_ipd'last_event, tpd_coreclk_pipestatus_posedge, TRUE)));
        pipestatus <= TRANSPORT hs_out_rxstatus_ch AFTER CQDelayPipestatus;

        VitalPathDelay01 (
            OutSignal => pipephydonestatus,
            OutSignalName => "PIPEPHYDONESTATUS",
            OutTemp => hs_out_phystatus,
            Paths => (1 => (coreclk_ipd'last_event, tpd_coreclk_pipephydonestatus_posedge, TRUE)),
            GlitchData => pipephydonestatus_VitalGlitchData,
            Mode => DefGlitchMode,
            XOn  => XOn,
            MsgOn  => MsgOn );

        VitalPathDelay01 (
            OutSignal => pipedatavalid,
            OutSignalName => "pipedatavalid",
            OutTemp => hs_out_rxvalid,
            Paths => (1 => (coreclk_ipd'last_event, tpd_coreclk_pipedatavalid_posedge, TRUE)),
            GlitchData => pipedatavalid_VitalGlitchData,
            Mode => DefGlitchMode,
            XOn  => XOn,
            MsgOn  => MsgOn );

    END PROCESS;


   a1a2size_in <= '1' WHEN (a1a2size = '1') ELSE
                  '0';
   alignstatus_in <= '1' WHEN (alignstatus = '1') ELSE
                     '0';
   alignstatussync_in <= '1' WHEN (alignstatussync = '1') ELSE
                         '0';
   bitslip_in <= '1' WHEN (bitslip = '1') ELSE
                 '0';
   coreclk_in <= '1' WHEN (coreclk = '1') ELSE
                 '0';
   datain_in <= datain;
   digitalreset_in <= '1' WHEN (digitalreset = '1') ELSE
                      '0';
   dpriodisable_in <= '0' WHEN (dpriodisable = '0') ELSE
                      '1';
   dprioin_in <= dprioin(399 DOWNTO 0);
   elecidleinfersel_in <= "001" WHEN (elecidleinfersel = "001") ELSE
                          "000";
   enabledeskew_in <= '1' WHEN (enabledeskew = '1') ELSE
                      '0';
   enabyteord_in <= '1' WHEN (enabyteord = '1') ELSE
                    '0';
   enapatternalign_in <= '1' WHEN (enapatternalign = '1') ELSE
                         '0';
   fifordin_in <= '1' WHEN (fifordin = '1') ELSE
                  '0';
   fiforesetrd_in <= '1' WHEN (fiforesetrd = '1') ELSE
                     '0';
   invpol_in <= '1' WHEN (invpol = '1') ELSE
                '0';
   localrefclk_in <= '1' WHEN (localrefclk = '1') ELSE
                     '0';
   masterclk_in <= '1' WHEN (masterclk = '1') ELSE
                   '0';
   parallelfdbk_in <= parallelfdbk;
   phfifordenable_in <= '0' WHEN (phfifordenable = '0') ELSE
                        '1';
   phfiforeset_in <= '1' WHEN (phfiforeset = '1') ELSE
                     '0';
   phfifowrdisable_in <= '1' WHEN (phfifowrdisable = '1') ELSE
                         '0';
   phfifox4bytesel_in <= '1' WHEN (phfifox4bytesel = '1') ELSE
                         '0';
   phfifox4rdenable_in <= '1' WHEN (phfifox4rdenable = '1') ELSE
                          '0';
   phfifox4wrclk_in <= '1' WHEN (phfifox4wrclk = '1') ELSE
                       '0';
   phfifox4wrenable_in <= '1' WHEN (phfifox4wrenable = '1') ELSE
                          '0';
   phfifox8bytesel_in <= '1' WHEN (phfifox8bytesel = '1') ELSE
                         '0';
   phfifox8rdenable_in <= '1' WHEN (phfifox8rdenable = '1') ELSE
                          '0';
   phfifox8wrclk_in <= '1' WHEN (phfifox8wrclk = '1') ELSE
                       '0';
   phfifox8wrenable_in <= '1' WHEN (phfifox8wrenable = '1') ELSE
                          '0';
   pipe8b10binvpolarity_in <= '1' WHEN (pipe8b10binvpolarity = '1') ELSE
                              '0';
   pipepowerdown_in <= pipepowerdown;
   pipepowerstate_in <= pipepowerstate;
   ppmdetectdividedclk_in <= '1' WHEN (ppmdetectdividedclk = '1') ELSE
                             '0';
   ppmdetectrefclk_in <= '1' WHEN (ppmdetectrefclk = '1') ELSE
                         '0';
   quadreset_in <= '1' WHEN (quadreset = '1') ELSE
                   '0';
   rateswitch_in <= '1' WHEN (rateswitch = '1') ELSE
                    '0';
   rateswitchisdone_in <= '1' WHEN (rateswitchisdone = '1') ELSE
                          '0';
   rateswitchxndone_in <= '1' WHEN (rateswitchxndone = '1') ELSE
                          '0';
   recoveredclk_in <= '1' WHEN (recoveredclk = '1') ELSE
                      '0';
   refclk_in <= '1' WHEN (refclk = '1') ELSE
                '0';
   revbitorderwa_in <= '1' WHEN (revbitorderwa = '1') ELSE
                       '0';
   revbyteorderwa_in <= '1' WHEN (revbyteorderwa = '1') ELSE
                        '0';
   rmfifordena_in <= '1' WHEN (rmfifordena = '1') ELSE
                     '0';
   rmfiforeset_in <= '1' WHEN (rmfiforeset = '1') ELSE
                     '0';
   rmfifowrena_in <= '1' WHEN (rmfifowrena = '1') ELSE
                     '0';
   rxdetectvalid_in <= '1' WHEN (rxdetectvalid = '1') ELSE
                       '0';
   rxelecidlerateswitch_in <= '1' WHEN (rxelecidlerateswitch = '1') ELSE
                              '0';
   rxfound_in <= rxfound;
   signaldetected_in <= '1' WHEN (signaldetected = '1') ELSE
                        '0';
   xgmctrlin_in <= '1' WHEN (xgmctrlin = '1') ELSE
                   '0';
   xgmdatain_in <= xgmdatain;
   autospdxnconfigsel_in <= autospdxnconfigsel;
   autospdxnspdchg_in <= autospdxnspdchg;
   cdrctrllocktorefcl_in <= cdrctrllocktorefcl;
   hip8b10binvpolarity_in <= hip8b10binvpolarity;
   hipelecidleinfersel_in <= hipelecidleinfersel;
   hippowerdown_in <= hippowerdown;
   hiprateswitch_in <= hiprateswitch;
   iqpautospdxnspgchg_in <= iqpautospdxnspgchg;
   iqpphfifoxnbytesel_in <= iqpphfifoxnbytesel;
   iqpphfifoxnptrsreset_in <= iqpphfifoxnptrsreset;
   iqpphfifoxnrdenable_in <= iqpphfifoxnrdenable;
   iqpphfifoxnwrclk_in <= iqpphfifoxnwrclk;
   iqpphfifoxnwrenable_in <= iqpphfifoxnwrenable;
   phfifoxnbytesel_in <= phfifoxnbytesel;
   phfifoxnptrsreset_in <= phfifoxnptrsreset;
   phfifoxnrdenable_in <= phfifoxnrdenable;
   phfifoxnwrclk_in <= phfifoxnwrclk;
   phfifoxnwrenable_in <= phfifoxnwrenable;
   powerdn_in <= powerdn;
   prbscidenable_in <= prbscidenable;
   -- ww12 inputs
   grayelecidleinferselfromtx_in(0) <= '1' WHEN (grayelecidleinferselfromtx(0) = '1') ELSE '0';
   grayelecidleinferselfromtx_in(1) <= '1' WHEN (grayelecidleinferselfromtx(1) = '1') ELSE '0';
   grayelecidleinferselfromtx_in(2) <= '1' WHEN (grayelecidleinferselfromtx(2) = '1') ELSE '0';
   
   pipeenrevparallellpbkfromtx_in   <= '1' WHEN (pipeenrevparallellpbkfromtx_in = '1') ELSE '0';
   
   PROCESS 
      
       FUNCTION compute_rrundisp (                                                           
       pma_doublewidth         : IN std_logic;                                                
       pma_width               : IN std_logic;                                                
       run_length              : IN integer) RETURN STD_LOGIC_VECTOR IS                       
                                                          
                                                                                              
       VARIABLE res                    :  std_logic_vector(5 DOWNTO 0);                       
       VARIABLE compute_rrundisp       :  std_logic_vector(5 DOWNTO 0);                       
       VARIABLE run_len_stepped        :  integer;                                            
       VARIABLE temp_xhdl56 : STD_LOGIC_VECTOR(1 DOWNTO 0);                                   
       VARIABLE txt : LINE;                                                                   
   BEGIN                                                                                      
       temp_xhdl56 := pma_doublewidth & pma_width;                                            
       CASE temp_xhdl56 IS                                                                    
           WHEN "00" =>                                                                       
                       run_len_stepped := run_length / 4;                                     
                       IF (run_len_stepped = 32) THEN                                         
                           res := "000000";                                                   
                       ELSE                                                                   
                           res := int2bin(run_len_stepped, 6);                                
                       END IF;                                                                
           WHEN "01" =>                                                                       
                       run_len_stepped := run_length / 5;                                     
                       IF (run_len_stepped = 32) THEN                                         
                           res := "000000";                                                   
                       ELSE                                                                   
                           res := int2bin(run_len_stepped, 6);                                
                       END IF;                                                                
           WHEN "10" =>                                                                       
                       run_len_stepped := run_length / 8;                                     
                       IF (run_len_stepped = 64) THEN                                         
                           res := "000000";                                                   
                       ELSE                                                                   
                           res := int2bin(run_len_stepped, 6);                                
                       END IF;                                                                
           WHEN "11" =>                                                                       
                       run_len_stepped := run_length / 10;                                    
                       IF (run_len_stepped = 64) THEN                                         
                           res := "000000";                                                   
                       ELSE                                                                   
                           res := int2bin(run_len_stepped, 6);                                
                       END IF;                                                                
           WHEN OTHERS  =>                                                                    
                       --WRITE(TXT,STRING'("Invalid pma_doublewidth and pma_width selection")); 
                      -- WRITELINE(OUTPUT,TXT);                                                 
       END CASE;                                                                              
       RETURN res;                                                                        
   END compute_rrundisp;                                                                      
      
   FUNCTION compute_rprbs_sel_rx (                                                                                  
           pma_doublewidth         : IN std_logic;                                                                   
           pma_width               : IN std_logic;                                                                   
           test_mode                          : IN STRING) RETURN STD_LOGIC_VECTOR IS                       
                                                                                   
                                                                                                                     
           VARIABLE res                    :  std_logic_vector(2 DOWNTO 0);                                          
           VARIABLE compute_rprbs_sel_rx        : std_logic_vector(2 DOWNTO 0);                                      
           VARIABLE temp_xhdl56 : STD_LOGIC_VECTOR(1 DOWNTO 0);                                                      
           VARIABLE txt : LINE;                                                                                      
       BEGIN                                                                                                         
           temp_xhdl56 := pma_doublewidth & pma_width;                                                               
           CASE temp_xhdl56 IS                                                                                       
               WHEN "00" =>                                                                                          
                           IF ((test_mode = "prbs_8") OR (test_mode = "prbs8")) THEN       
                               res := "000";                                                                         
                           ELSIF (test_mode = "prbs7") THEN
                               res := "010";                     
                           ELSIF (test_mode = "prbs23") THEN
                               res := "100";
                           ELSIF (test_mode = "high frequency") THEN
                               res := "001";
                           ELSE                        
                               res := "000";     -- default
                           END IF;                                                                                   
               WHEN "01" =>                                                                                          
                           IF ((test_mode = "prbs_10") OR (test_mode = "prbs10")) THEN    
                               res := "000";                                                                         
                           ELSIF (test_mode = "high frequency") THEN
                               res := "001";
                           ELSIF (test_mode = "low frequency") THEN
                               res := "010";
                           ELSIF (test_mode = "mixed frequency") THEN
                               res := "011";
                           ELSE
                               res := "000";     -- default
                           END IF;                                                                                   
               WHEN "10" =>                                                                                          
                           IF ((test_mode = "prbs_7") OR (test_mode = "prbs7")) THEN       
                               res := "000";                                                                         
                           ELSIF (test_mode = "prbs_23" OR test_mode = "prbs23")  THEN
                               res := "001";
                           ELSIF (test_mode = "high frequency")  THEN
                               res := "010";
                           ELSE
                               res := "000";     -- default
                           END IF;                                                                                   
               WHEN "11" =>                                                                                          
                           IF ((test_mode = "prbs_7") OR (test_mode = "prbs7")) THEN       
                               res := "000";                                                                         
                           ELSIF ((test_mode = "prbs_23") OR (test_mode = "prbs23")) THEN
                               res := "001";                     
                           ELSIF (test_mode = "high frequency") THEN
                               res := "010";
                           ELSIF (test_mode = "low frequency") THEN
                               res := "011";
                           ELSIF (test_mode = "mixed frequency") THEN
                               res := "100";
                           ELSE
                               res := "000";     -- default
                           END IF;                                                                                   
               WHEN OTHERS  =>                                                                                       
                          -- WRITE(TXT,STRING'("Invalid pma_doublewidth and pma_width selection"));                    
                          -- WRITELINE(OUTPUT,TXT);                                                                    
                                                                                                                     
           END CASE;                                                                                                 
           RETURN res;                                                                                           
       END compute_rprbs_sel_rx;                                                                                     
      
  variable init_rpma_doublewidth_rx_var : std_logic;
  variable init_rpmadwidth_rx_var : std_logic;
  VARIABLE tmp_rcomp_size           :  std_logic_vector(2 DOWNTO 0);
  VARIABLE tmp_reg40 : STD_LOGIC_VECTOR(39 DOWNTO 0);
  
   BEGIN
   
     if(use_deserializer_double_data_mode = ("true"))then
     	init_rpma_doublewidth_rx <= '1';
     	init_rpma_doublewidth_rx_var := '1';
     else
     	init_rpma_doublewidth_rx <= '0';
     	init_rpma_doublewidth_rx_var := '0';
     end if;
    
     init_rdeskewen  <= mux_select((use_deskew_fifo = ("true")), '1', '0');
     
    if((dec_8b_10b_mode = ("none")) AND ((channel_width = 8) OR (channel_width = 16) OR (channel_width = 32)))then
    	init_rpmadwidth_rx <= '0';
     	init_rpmadwidth_rx_var := '0';
     else
     	init_rpmadwidth_rx <= '1';
     	init_rpmadwidth_rx_var := '1';
     end if;
     
      init_dskwclksel(1) <= mux_select((use_deskew_fifo = ("true")), '1', '0');
      init_dskwclksel(0) <= '0';
      init_is_lane0 <= mux_select((channel_number = 0), '1', '0');
      init_r8b10b_dec_ibm_en(0) <= mux_select((dec_8b_10b_compatibility_mode = ("true")), '1', '0');
      init_r8b10b_dec_ibm_en(1) <= '0';
      --init_ralempty <= mux_select((rate_match_almost_empty_threshold = 11), "0000", ("0000" - int2bin(rate_match_almost_empty_threshold, 4)));
      --init_ralfull <= mux_select((rate_match_almost_full_threshold = 13), "0000", (int2bin(rate_match_almost_full_threshold, 4) - "0100"));
      init_rall_one_dect_only <= mux_select((prbs_all_one_detect = ("true")), '1', '0');
      init_rautobtalg_dis <= mux_select((bit_slip_enable = ("true")), '1', '0');
      init_rautoinsdis <= mux_select((disable_auto_idle_insertion = ("true")), '1', '0');
      init_rbist_clr_rx <= '0';
      init_rbist_sel <= mux_select((self_test_mode = ("cjpat")), "01", mux_select((self_test_mode = ("crpat")), "10", "00"));
      init_rbisten_rx <= mux_select(((enable_self_test_mode = ("true")) AND (self_test_mode = ("cjpat") OR self_test_mode = ("crpat") OR self_test_mode = ("incremental"))), '1', '0');
      init_rbitloc_rev_en <= mux_select((enable_bit_reversal = ("true")), '1', '0');
      --init_rbitslip_size <= mux_select((protocol_hint = ("pipe")), "11", mux_select((protocol_hint = ("xaui")), "10", "00")); - removed
      init_rbysync_polinv_en <= mux_select((allow_align_polarity_inversion = ("true")), '1', '0');
      init_rbyte_rev_en <= mux_select((enable_deep_align_byte_swap = ("true")), '1', '0');
      
      IF (byte_order_mode = "none" ) THEN
          init_rbyteorden <= "00";
      ELSIF (byte_order_mode = "8"  OR byte_order_mode = "16") THEN
          init_rbyteorden <= "01";
      ELSIF (byte_order_mode = "10" OR byte_order_mode = "20") THEN                   
          init_rbyteorden <= "11";
      ELSIF (byte_order_mode = "9"  OR byte_order_mode = "18") THEN
          init_rbyteorden <=  "10";
      ELSE 
          init_rbyteorden <=  "ZZ";
      END IF;
      
      IF (byte_order_mode = "16" OR byte_order_mode = "18" OR byte_order_mode = "20") THEN
	      init_rbytord_2sym_en <= '1';
	  ELSE 
	      init_rbytord_2sym_en <= '0';
	  END IF;
  
	  tmp_reg40 :=  str2bin(byte_order_pad_pattern) ; 
      init_rbytordpad <= tmp_reg40(9 DOWNTO 0);
      
      tmp_reg40 :=  str2bin(byte_order_pattern) ; 
      init_rbytordpat(9 DOWNTO 0) <= tmp_reg40(9 DOWNTO 0);
      IF (byte_order_mode = "16") THEN
          init_rbytordpat(19 DOWNTO 10) <= ("00" & tmp_reg40(15 DOWNTO 8));
      ELSIF (byte_order_mode = "18") THEN
	      init_rbytordpat(19 DOWNTO 10) <= ("0" & tmp_reg40(17 DOWNTO 9));
	  ELSE 
	      init_rbytordpat(19 DOWNTO 10) <= tmp_reg40(19 DOWNTO 10);
	  END IF;

	  IF (byte_order_pld_ctrl_enable = "true") THEN
          init_rbytordplden <= '1';
      ELSE
          init_rbytordplden <= '0';
      END IF;
            
      init_rcascaded_8b10b_en_rx <= mux_select((dec_8b_10b_mode = ("cascaded")), '1', '0');
      init_rclk_1_sel <= mux_select((clk1_mux_select = ("recvd_clk") OR clk1_mux_select = ("recovered clock")), "00", mux_select((clk1_mux_select = ("digital_refclk") OR clk1_mux_select = ("digital reference clock")), "01", mux_select((clk1_mux_select = ("local_refclk") OR clk1_mux_select = ("local reference clock")), "10", mux_select((clk1_mux_select = ("master_clk") OR clk1_mux_select = ("master clock")), "11", "ZZ"))));
      init_rclk_2_sel <= mux_select((clk2_mux_select = ("recvd_clk") OR clk2_mux_select = ("recovered clock")), "00", mux_select((clk2_mux_select = ("digital_refclk") OR clk2_mux_select = ("digital reference clock")), "10", mux_select((clk2_mux_select = ("local_refclk") OR clk2_mux_select = ("local reference clock")), "01", mux_select((clk2_mux_select = ("core_clk") OR clk2_mux_select = ("core clk") OR clk2_mux_select = ("core clock")), "11", "ZZ"))));
      init_rclkcmpinsertpad <= mux_select((insert_pad_on_underflow = ("true")), '1', '0');
      tmp_reg40 :=  str2bin(rate_match_pattern2) ; 
      init_rclkcmpsq1n <= tmp_reg40(19 DOWNTO 0);
      tmp_reg40 :=  str2bin(rate_match_pattern1) ; 
      init_rclkcmpsq1p <= tmp_reg40(19 DOWNTO 0);
      init_rclkcmpsqmd <= mux_select((rate_match_ordered_set_based = ("true")), '1', '0');
      init_rcmpfifourst <= mux_select((rate_match_reset_enable = ("true")), '1', '0');
      init_rcomp_pat <=  str2bin(align_pattern) ; 
      init_rcomp_pat_porn <= mux_select((enable_true_complement_match_in_word_align = ("true")), '1', '0');
      IF (align_pattern_length = 16) THEN
         IF (init_rpmadwidth_rx_var = '0' AND init_rpma_doublewidth_rx_var = '0') THEN
             tmp_rcomp_size := "001";
         ELSE
             tmp_rcomp_size := "011";
         END IF;
      ELSE
          tmp_rcomp_size := "ZZZ";
      END IF;
      init_rcomp_size <= mux_select((align_pattern_length = 7), "000", mux_select((align_pattern_length = 8), "001", mux_select((align_pattern_length = 10), "010", mux_select((align_pattern_length = 16), tmp_rcomp_size, mux_select((align_pattern_length = 20), "100", mux_select((align_pattern_length = 32), "101", mux_select((align_pattern_length = 40), "110", "ZZZ")))))));
      init_rcxpat_chnl_en <= mux_select((channel_number = 1), "01", mux_select((channel_number = 2), "10", mux_select((channel_number = 3), "11", "00")));
      init_rdis_rx_disp <= mux_select((disable_running_disp_in_word_align = ("true")), '1', '0');
      tmp_reg40 :=  str2bin(deskew_pattern) ; 
      init_rdskchrp <= tmp_reg40(9 DOWNTO 0);
      init_rdskposdisp <= mux_select((align_to_deskew_pattern_pos_disp_only = ("true")), '1', '0');
      init_rdwidth_rx <= mux_select((use_double_data_mode = ("true")), '1', '0');
      init_rencdt_rising <= mux_select((use_rising_edge_triggered_pattern_align = ("true")), '1', '0');
      init_rendec_data_sel_rx <= mux_select((protocol_hint = ("xaui")), '0', '1');
      init_rendec_rx <= mux_select((dec_8b_10b_mode /= ("none")), '1', '0');
      init_renpolinv_rx <= mux_select((allow_pipe_polarity_inversion = ("true")), '1', '0');
      init_renumber <= int2bin(num_align_loss_sync_error, 6) - "000001";
      init_resync_badcg_en <= "00";
      init_rforce_sig_det_pcs <= mux_select((force_signal_detect_dig = ("true")), '1', '0');
      init_rforce0_freqdet <= '0';
      init_rforce1_freqdet <= '0';
      init_rfreerun_rx <= mux_select((reset_clock_output_during_digital_reset = ("false")), '1', '0');
      init_rgenericfifo <= '0';
      init_rgnumber <= (int2bin(num_align_cons_good_data, 8) - "00000001");
      init_rib_inv_cd <= int2bin(infiniband_invalid_code, 2);
      init_rindv_rx <= mux_select((channel_bonding = ("x4") OR channel_bonding = ("x8") OR protocol_hint = ("xaui")), '0', '1');
      init_rkchar <= mux_select((disallow_kchar_after_pattern_ordered_set = ("true")), '1', '0');
      init_rknumber <= mux_select((num_align_code_groups_in_ordered_set = 0), (int2bin(num_align_cons_pat, 8) - "00000001"), int2bin(num_align_cons_pat, 8));
      init_rlp20ben <= mux_select((use_parallel_loopback = ("true")), '1', '0');
      init_rmatchen <= mux_select((rate_match_fifo_mode = ("none") OR rate_match_fifo_mode = ("false")), '0', mux_select((rate_match_fifo_mode = ("true") OR rate_match_fifo_mode = ("normal")), '1', 'Z'));
      init_rosbased <= mux_select((align_ordered_set_based = ("true")), '1', '0');
      init_rosnumber <= int2bin(num_align_code_groups_in_ordered_set, 2);
      init_rphfifopldenrx <= '1';
      init_rphfifourstrx <= '1';
      init_rppm_cnt_reset <= '0';
      init_rppmsel <= "000000";
      init_rprbs_clr_rslt_rx <= '0';
      init_rprbs_sel <= compute_rprbs_sel_rx(init_rpma_doublewidth_rx_var,init_rpmadwidth_rx_var,self_test_mode);
      init_rprbsen_rx <= mux_select(((enable_self_test_mode = ("true")) AND (self_test_mode /= ("incremental")) AND (self_test_mode /= ("cjpat")) AND (self_test_mode /= ("crpat"))), '1', '0');
      init_rrcvd_clk_sel <= mux_select((recovered_clk_mux_select = ("recvd_clk") OR recovered_clk_mux_select = ("recovered clock")), "00", mux_select((recovered_clk_mux_select = ("digital_refclk") OR recovered_clk_mux_select = ("digital reference clock")), "01", mux_select((recovered_clk_mux_select = ("local_refclk") OR recovered_clk_mux_select = ("local reference clock")), "10", "ZZ")));
      init_rrlv_en <= mux_select((run_length_enable = ("true")), '1', '0');
      init_rrundisp <= compute_rrundisp(init_rpma_doublewidth_rx_var,init_rpmadwidth_rx_var,run_length);
      init_rrx_rd_clk_sel <= mux_select((rd_clk_mux_select = ("core_clk") OR rd_clk_mux_select = ("core clk") OR rd_clk_mux_select = ("core clock")), '1', '0');
      init_rrxfifo_dis <= mux_select((enable_phfifo_bypass = ("true")), '1', '0');
      init_rrxfifo_lowlatency_en <= mux_select((ph_fifo_low_latency_enable = ("true")), '1', '0');
      init_rskpsetbased <= mux_select((rate_match_skip_set_based = ("true")), '1', '0');
      init_rsync_sm_dis <= mux_select((use_alignment_state_machine = ("false")), '1', '0');
      init_rtruebac2bac <= mux_select((rate_match_back_to_back = ("true")), '1', '0');
      init_rwa_6g_en <= mux_select((enable_deep_align = ("true")), '1', '0');
      init_scan_mode <= '0';
      init_sel_gp_md <= '0';
      init_rphystatus_rst_toggle <= mux_select((phystatus_reset_toggle = ("true")), '1', '0');
      init_rrdwidth_rx <= mux_select((use_double_data_mode = ("true")), '1', '0');
      init_rrx_detect_bypass <= mux_select((rx_detect_bypass = ("true")), '1', '0');
      init_rrx_pipe_enable <= mux_select((protocol_hint = ("pcie") OR protocol_hint = ("pcie2")), '1', '0');
      init_rtx_elec_idle_delay <= "00";
      init_rtx_pipe_enable <= '0';
      init_rauto_speed_ena <= mux_select((pipe_auto_speed_nego_enable = ("true")), '1', '0');
      init_rbytord_6g_mask_en <= mux_select((byte_order_double_data_mode_mask_enable = ("true")), '1', '0');
      init_rbytord_s2gx <= mux_select((byte_order_back_compat_enable = ("true")), '1', '0');
      init_rclkcmp_pipe_en <= mux_select((rate_match_pipe_enable = ("true")), '1', '0');
      init_rdel_threshold <= int2bin(rate_match_delete_threshold, 5);
      init_reidle_com_detect <= int2bin(elec_idle_num_com_detect, 2);
      init_reidleinferenable <= mux_select((elec_idle_infer_enable = ("true")), '1', '0');
      init_rempty_threshold <= int2bin(rate_match_empty_threshold, 3);
      init_renpolinv_en <= mux_select((dec_8b_10b_polarity_inv_enable = ("true")), '1', '0');
      init_rfreq_sel <= mux_select((alpha_tolower(pipe_freq_scale_mode) = ("data width")), '0', '1');
      init_rfull_threshold <= int2bin(rate_match_full_threshold, 5);
      init_rind_error_reporting <= mux_select((rxstatus_error_report_mode = 0), '0', '1');
      init_rins_threshold <= int2bin(rate_match_insert_threshold, 5);
      init_rinvalid_code_err_only <= mux_select((byte_order_invalid_code_or_run_disp_error = ("true")), '1', '0');
      init_rphfifourstenrx <= mux_select((ph_fifo_reset_enable = ("true")), '1', '0');
      init_rphystatus_delay <= int2bin(phystatus_delay, 3);
      init_rrx_fifo_dis <= mux_select((ph_fifo_disable = ("true")), '1', '0');
      init_rrxpcsbypass_en <= mux_select((datapath_low_latency_mode = ("true")), '1', '0');
      init_rstart_threshold <= int2bin(rate_match_start_threshold, 3);
      init_rauto_deassert_pc_rst_cnt <= int2bin(auto_spd_deassert_ph_fifo_rst_count, 4);
      init_rauto_pc_en_cnt <= int2bin(auto_spd_phystatus_notify_count, 5);
      init_rcdr_ctrl_en <= mux_select((cdrctrl_enable = ("true")), '1', '0');
      init_rcid_en <= mux_select((cdrctrl_cid_mode_enable = ("true")), '1', '0');
      init_rcid_len_rx <= int2bin(prbs_cid_pattern_length, 8);
      init_rcid_pattern_rx <= mux_select((prbs_cid_pattern = ("true")), '1', '0');
      init_rfts_count <= int2bin(cdrctrl_bypass_ppm_detector_cycle, 10);
      init_rhip_ena <= mux_select((hip_enable = ("true")), '1', '0');
      init_rmask_count <= int2bin(cdrctrl_mask_cycle, 10);
      IF ((channel_bonding /= "x8") OR (stratixiv_tx_pcs_mph_fifo_xn_mapping(ph_fifo_xn_select,ph_fifo_xn_mapping0,ph_fifo_xn_mapping1,ph_fifo_xn_mapping2) = "central")) THEN
          init_rmaster_rx <= '1';
      ELSE
          init_rmaster_rx <= '0';
      END IF;
      -- flip
      IF (stratixiv_tx_pcs_mph_fifo_xn_mapping(ph_fifo_xn_select,ph_fifo_xn_mapping0,ph_fifo_xn_mapping1,ph_fifo_xn_mapping2) = "down") THEN
          init_rmaster_up_rx <= '1';  
      ELSE
          init_rmaster_up_rx <= '0';
      END IF;
      init_rphfifo_regmode_rx <= mux_select((ph_fifo_reg_mode = ("true")), '1', '0');
      init_rpipeline_bypass_rx <= mux_select((iqp_bypass = ("true")), '1', '0');
      init_rpma_done_count <= "000000000000001111"; -- int2bin(pma_done_count, 18);
      init_rrxpcsclkpwdn <= mux_select((clk_pd_enable = ("true")), '1', '0');
      init_rrxvalid_mask <= mux_select((cdrctrl_rxvalid_mask = ("true")), '1', '0');
      init_rself_sw_en_rx <= mux_select((auto_spd_self_switch_enable = ("true")), '1', '0');
      init_rtest_bus_sel <= int2bin(test_bus_sel, 4);
      init_rwait_count <= int2bin(cdrctrl_min_lock_to_ref_cycle, 8);
      init_rwait_for_phfifo_cnt <= int2bin(rx_phfifo_wait_cnt, 6);
      init_rppm_post_eidle_del <= '0';
      init_rppm_gen1_2xcnt_en <= '0';
      
      IF (elec_idle_eios_detect_priority_over_eidle_disable = "true") THEN
          init_riei_eios_priority_dis <= '1';
      ELSE 
          init_riei_eios_priority_dis <= '0';
      END IF;
      
      IF (elec_idle_gen1_sigdet_enable = "true") THEN
          init_rgen1_sigdet_ena <= '1';
      ELSE 
          init_rgen1_sigdet_ena <= '0';
      END IF;
      
      -- STRATIXIV WW25.2008 -----------------------------------------------------
      IF (error_from_wa_or_8b_10b_select = "true") THEN
          init_rerr_flags_sel         <= '1';
      ELSE
          init_rerr_flags_sel         <= '0';      
      END IF;
      
      init_rpcs_wrapback_en       <= '0';

      WAIT;
   END PROCESS;
   
   	-- Mapping Assignment -------------------------------------------------- 
    -- init_rcomp_pat
    init_rcomp_pat_0 <= init_rcomp_pat(0);
    init_rcomp_pat_1 <= init_rcomp_pat(1);
    init_rcomp_pat_2 <= init_rcomp_pat(2);
    init_rcomp_pat_3 <= init_rcomp_pat(3);
    init_rcomp_pat_4 <= init_rcomp_pat(4);
    init_rcomp_pat_5 <= init_rcomp_pat(5);
    init_rcomp_pat_6 <= init_rcomp_pat(6);
    init_rcomp_pat_7 <= init_rcomp_pat(7);
    init_rcomp_pat_8 <= init_rcomp_pat(8);
    init_rcomp_pat_9 <= init_rcomp_pat(9);
    init_rcomp_pat_10 <= init_rcomp_pat(10);
    init_rcomp_pat_11 <= init_rcomp_pat(11);
    init_rcomp_pat_12 <= init_rcomp_pat(12);
    init_rcomp_pat_13 <= init_rcomp_pat(13);
    init_rcomp_pat_14 <= init_rcomp_pat(14);
    init_rcomp_pat_15 <= init_rcomp_pat(15);
    init_rcomp_pat_16 <= init_rcomp_pat(16);
    init_rcomp_pat_17 <= init_rcomp_pat(17);
    init_rcomp_pat_18 <= init_rcomp_pat(18);
    init_rcomp_pat_19 <= init_rcomp_pat(19);
    init_rcomp_pat_20 <= init_rcomp_pat(20);
    init_rcomp_pat_21 <= init_rcomp_pat(21);
    init_rcomp_pat_22 <= init_rcomp_pat(22);
    init_rcomp_pat_23 <= init_rcomp_pat(23);
    init_rcomp_pat_24 <= init_rcomp_pat(24);
    init_rcomp_pat_25 <= init_rcomp_pat(25);
    init_rcomp_pat_26 <= init_rcomp_pat(26);
    init_rcomp_pat_27 <= init_rcomp_pat(27);
    init_rcomp_pat_28 <= init_rcomp_pat(28);
    init_rcomp_pat_29 <= init_rcomp_pat(29);
    init_rcomp_pat_30 <= init_rcomp_pat(30);
    init_rcomp_pat_31 <= init_rcomp_pat(31);
    init_rcomp_pat_32 <= init_rcomp_pat(32);
    init_rcomp_pat_33 <= init_rcomp_pat(33);
    init_rcomp_pat_34 <= init_rcomp_pat(34);
    init_rcomp_pat_35 <= init_rcomp_pat(35);
    init_rcomp_pat_36 <= init_rcomp_pat(36);
    init_rcomp_pat_37 <= init_rcomp_pat(37);
    init_rcomp_pat_38 <= init_rcomp_pat(38);
    init_rcomp_pat_39 <= init_rcomp_pat(39);
    
    --init_rclkcmpsq1p
    init_rclkcmpsq1p_0 <= init_rclkcmpsq1p(0);
    init_rclkcmpsq1p_1 <= init_rclkcmpsq1p(1);
    init_rclkcmpsq1p_2 <= init_rclkcmpsq1p(2);
    init_rclkcmpsq1p_3 <= init_rclkcmpsq1p(3);
    init_rclkcmpsq1p_4 <= init_rclkcmpsq1p(4);
    init_rclkcmpsq1p_5 <= init_rclkcmpsq1p(5);
    init_rclkcmpsq1p_6 <= init_rclkcmpsq1p(6);
    init_rclkcmpsq1p_7 <= init_rclkcmpsq1p(7);
    init_rclkcmpsq1p_8 <= init_rclkcmpsq1p(8);
    init_rclkcmpsq1p_9 <= init_rclkcmpsq1p(9);
    init_rclkcmpsq1p_10 <= init_rclkcmpsq1p(10);
    init_rclkcmpsq1p_11 <= init_rclkcmpsq1p(11);
    init_rclkcmpsq1p_12 <= init_rclkcmpsq1p(12);
    init_rclkcmpsq1p_13 <= init_rclkcmpsq1p(13);
    init_rclkcmpsq1p_14 <= init_rclkcmpsq1p(14);
    init_rclkcmpsq1p_15 <= init_rclkcmpsq1p(15);
    init_rclkcmpsq1p_16 <= init_rclkcmpsq1p(16);
    init_rclkcmpsq1p_17 <= init_rclkcmpsq1p(17);
    init_rclkcmpsq1p_18 <= init_rclkcmpsq1p(18);
    init_rclkcmpsq1p_19 <= init_rclkcmpsq1p(19);
    
    --init_rclkcmpsq1n
    init_rclkcmpsq1n_0 <= init_rclkcmpsq1n(0);
    init_rclkcmpsq1n_1 <= init_rclkcmpsq1n(1);
    init_rclkcmpsq1n_2 <= init_rclkcmpsq1n(2);
    init_rclkcmpsq1n_3 <= init_rclkcmpsq1n(3);
    init_rclkcmpsq1n_4 <= init_rclkcmpsq1n(4);
    init_rclkcmpsq1n_5 <= init_rclkcmpsq1n(5);
    init_rclkcmpsq1n_6 <= init_rclkcmpsq1n(6);
    init_rclkcmpsq1n_7 <= init_rclkcmpsq1n(7);
    init_rclkcmpsq1n_8 <= init_rclkcmpsq1n(8);
    init_rclkcmpsq1n_9 <= init_rclkcmpsq1n(9);
    init_rclkcmpsq1n_10 <= init_rclkcmpsq1n(10);
    init_rclkcmpsq1n_11 <= init_rclkcmpsq1n(11);
    init_rclkcmpsq1n_12 <= init_rclkcmpsq1n(12);
    init_rclkcmpsq1n_13 <= init_rclkcmpsq1n(13);
    init_rclkcmpsq1n_14 <= init_rclkcmpsq1n(14);
    init_rclkcmpsq1n_15 <= init_rclkcmpsq1n(15);
    init_rclkcmpsq1n_16 <= init_rclkcmpsq1n(16);
    init_rclkcmpsq1n_17 <= init_rclkcmpsq1n(17);
    init_rclkcmpsq1n_18 <= init_rclkcmpsq1n(18);
    init_rclkcmpsq1n_19 <= init_rclkcmpsq1n(19);
    
    --init_rpma_done_count
    init_rpma_done_count_0 <= init_rpma_done_count(0);
    init_rpma_done_count_1 <= init_rpma_done_count(1);
    init_rpma_done_count_2 <= init_rpma_done_count(2);
    init_rpma_done_count_3 <= init_rpma_done_count(3);
    init_rpma_done_count_4 <= init_rpma_done_count(4);
    init_rpma_done_count_5 <= init_rpma_done_count(5);
    init_rpma_done_count_6 <= init_rpma_done_count(6);
    init_rpma_done_count_7 <= init_rpma_done_count(7);
    init_rpma_done_count_8 <= init_rpma_done_count(8);
    init_rpma_done_count_9 <= init_rpma_done_count(9);
    init_rpma_done_count_10 <= init_rpma_done_count(10);
    init_rpma_done_count_11 <= init_rpma_done_count(11);
    init_rpma_done_count_12 <= init_rpma_done_count(12);
    init_rpma_done_count_13 <= init_rpma_done_count(13);
    init_rpma_done_count_14 <= init_rpma_done_count(14);
    init_rpma_done_count_15 <= init_rpma_done_count(15);
    init_rpma_done_count_16 <= init_rpma_done_count(16);
    init_rpma_done_count_17 <= init_rpma_done_count(17);

    --init_rbytordpat
    init_rbytordpat_0 <= init_rbytordpat(0);
    init_rbytordpat_1 <= init_rbytordpat(1);
    init_rbytordpat_2 <= init_rbytordpat(2);
    init_rbytordpat_3 <= init_rbytordpat(3);
    init_rbytordpat_4 <= init_rbytordpat(4);
    init_rbytordpat_5 <= init_rbytordpat(5);
    init_rbytordpat_6 <= init_rbytordpat(6);
    init_rbytordpat_7 <= init_rbytordpat(7);
    init_rbytordpat_8 <= init_rbytordpat(8);
    init_rbytordpat_9 <= init_rbytordpat(9);
    init_rbytordpat_10 <= init_rbytordpat(10);
    init_rbytordpat_11 <= init_rbytordpat(11);
    init_rbytordpat_12 <= init_rbytordpat(12);
    init_rbytordpat_13 <= init_rbytordpat(13);
    init_rbytordpat_14 <= init_rbytordpat(14);
    init_rbytordpat_15 <= init_rbytordpat(15);
    init_rbytordpat_16 <= init_rbytordpat(16);
    init_rbytordpat_17 <= init_rbytordpat(17);
    init_rbytordpat_18 <= init_rbytordpat(18);
    init_rbytordpat_19 <= init_rbytordpat(19);   
  
    cram_rcomp_pat <= (cram_rcomp_pat_39 & cram_rcomp_pat_38 & cram_rcomp_pat_37 & cram_rcomp_pat_36 & cram_rcomp_pat_35 & cram_rcomp_pat_34 & cram_rcomp_pat_33 & cram_rcomp_pat_32 & cram_rcomp_pat_31 & cram_rcomp_pat_30 &
                            cram_rcomp_pat_29 & cram_rcomp_pat_28 & cram_rcomp_pat_27 & cram_rcomp_pat_26 & cram_rcomp_pat_25 & cram_rcomp_pat_24 & cram_rcomp_pat_23 & cram_rcomp_pat_22 & cram_rcomp_pat_21 & cram_rcomp_pat_20 &
                                cram_rcomp_pat_19 & cram_rcomp_pat_18 & cram_rcomp_pat_17 & cram_rcomp_pat_16 & cram_rcomp_pat_15 & cram_rcomp_pat_14 & cram_rcomp_pat_13 & cram_rcomp_pat_12 & cram_rcomp_pat_11 & cram_rcomp_pat_10 &
                                    cram_rcomp_pat_9 & cram_rcomp_pat_8 & cram_rcomp_pat_7 & cram_rcomp_pat_6 & cram_rcomp_pat_5 & cram_rcomp_pat_4 & cram_rcomp_pat_3 & cram_rcomp_pat_2 & cram_rcomp_pat_1 & cram_rcomp_pat_0);

    cram_rclkcmpsq1p <= (cram_rclkcmpsq1p_19 & cram_rclkcmpsq1p_18 & cram_rclkcmpsq1p_17 & cram_rclkcmpsq1p_16 & cram_rclkcmpsq1p_15 & cram_rclkcmpsq1p_14 & cram_rclkcmpsq1p_13 & cram_rclkcmpsq1p_12 & cram_rclkcmpsq1p_11 & cram_rclkcmpsq1p_10 &
                            cram_rclkcmpsq1p_9 & cram_rclkcmpsq1p_8 & cram_rclkcmpsq1p_7 & cram_rclkcmpsq1p_6 & cram_rclkcmpsq1p_5 & cram_rclkcmpsq1p_4 & cram_rclkcmpsq1p_3 & cram_rclkcmpsq1p_2 & cram_rclkcmpsq1p_1 & cram_rclkcmpsq1p_0);

    cram_rclkcmpsq1n <= (cram_rclkcmpsq1n_19 & cram_rclkcmpsq1n_18 & cram_rclkcmpsq1n_17 & cram_rclkcmpsq1n_16 & cram_rclkcmpsq1n_15 & cram_rclkcmpsq1n_14 & cram_rclkcmpsq1n_13 & cram_rclkcmpsq1n_12 & cram_rclkcmpsq1n_11 & cram_rclkcmpsq1n_10 &
                            cram_rclkcmpsq1n_9 & cram_rclkcmpsq1n_8 & cram_rclkcmpsq1n_7 & cram_rclkcmpsq1n_6 & cram_rclkcmpsq1n_5 & cram_rclkcmpsq1n_4 & cram_rclkcmpsq1n_3 & cram_rclkcmpsq1n_2 & cram_rclkcmpsq1n_1 & cram_rclkcmpsq1n_0); 

	cram_rpma_done_count <= (cram_rpma_done_count_17 & cram_rpma_done_count_16 & cram_rpma_done_count_15 & cram_rpma_done_count_14 & cram_rpma_done_count_13 & cram_rpma_done_count_12 & cram_rpma_done_count_11 & cram_rpma_done_count_10 & cram_rpma_done_count_9 & cram_rpma_done_count_8 &
        						cram_rpma_done_count_7 & cram_rpma_done_count_6 & cram_rpma_done_count_5 & cram_rpma_done_count_4 & cram_rpma_done_count_3 & cram_rpma_done_count_2 & cram_rpma_done_count_1 & cram_rpma_done_count_0);

	cram_rbytordpat <= (cram_rbytordpat_19 & cram_rbytordpat_18 & cram_rbytordpat_17 & cram_rbytordpat_16 & cram_rbytordpat_15 & cram_rbytordpat_14 & cram_rbytordpat_13 & cram_rbytordpat_12 & cram_rbytordpat_11 & cram_rbytordpat_10 &
                            cram_rbytordpat_9 & cram_rbytordpat_8 & cram_rbytordpat_7 & cram_rbytordpat_6 & cram_rbytordpat_5 & cram_rbytordpat_4 & cram_rbytordpat_3 & cram_rbytordpat_2 & cram_rbytordpat_1 & cram_rbytordpat_0);
        						
    -- ---------------------------------------------------------------------------
	-- Set DPRIO CRAM input from dprioin  
	-- ---------------------------------------------------------------------------
	-- Manual section
	dprioin_rpma_doublewidth_rx <= dprioin_in(rpma_doublewidth_rx_RX_IDX); 
	dprioin_rpmadwidth_rx       <= dprioin_in(rpmadwidth_rx_RX_IDX);
	dprioin_rendec_data_sel_rx  <= dprioin_in(rendec_data_sel_rx_RX_IDX);
	dprioin_rdeskewen           <= dprioin_in(rdeskewen_RX_IDX);
	dprioin_rindv_rx            <= dprioin_in(rindv_rx_RX_IDX);
	dprioin_rmaster_rx          <= dprioin_in(rmaster_rx_RX_IDX);
	dprioin_rmaster_up_rx       <= dprioin_in(rmaster_up_rx_RX_IDX);
	dprioin_rdskposdisp         <= dprioin_in(rdskposdisp_RX_IDX);
	dprioin_dskwclksel(1)       <= dprioin_rdeskewen;
	dprioin_dskwclksel(0)       <= '0';
	
	-- Existing
	dprioin_is_lane0            <= init_is_lane0;
	dprioin_rbist_sel           <= init_rbist_sel;
	dprioin_rclkcmppos          <= dprioin_in(rclkcmppos_RX_IDX);
	dprioin_rcxpat_chnl_en      <= init_rcxpat_chnl_en;
	dprioin_rdskchrp            <= init_rdskchrp;
	dprioin_rforce0_freqdet     <= dprioin_in(rforce0_freqdet_RX_IDX);
	dprioin_rforce1_freqdet     <= dprioin_in(rforce1_freqdet_RX_IDX);
	dprioin_rppmsel             <= dprioin_in(rppmsel_RX_IDX_5 DOWNTO rppmsel_RX_IDX_0);
	dprioin_rprbs_sel           <= init_rprbs_sel;
	dprioin_rrdwidth_rx         <= dprioin_in(rdwidth_rx_RX_IDX);
	dprioin_rrx_revlb_sw        <= dprioin_in(rrx_revlb_sw_RX_IDX);
	dprioin_rs_lpbk             <= dprioin_in(rs_lpbk_RX_IDX);
	dprioin_rtx_elec_idle_delay <= dprioin_in(rtx_idle_delay_RX_IDX_1 DOWNTO rtx_idle_delay_RX_IDX_0);
	dprioin_rtx_pipe_enable     <= init_rtx_pipe_enable;
	dprioin_scan_mode           <= init_scan_mode;
	dprioin_sel_gp_md           <= init_sel_gp_md;
	
	-- PCS Per Channel RX Control Register 1 for Channel 0
	dprioin_rrxpcsbypass_en	<= dprioin(rrxpcsbypass_en_RXPCS_IDX_0);
	dprioin_rall_one_dect_only	<= dprioin(rall_one_dect_only_RXPCS_IDX_0);
	dprioin_rbist_clr_rx	<= dprioin(rbist_clr_rx_RXPCS_IDX_0);
	dprioin_rbisten_rx	<= dprioin(rbisten_rx_RXPCS_IDX_0);
	dprioin_rprbs_clr_rslt_rx	<= dprioin(rprbs_clr_rslt_rx_RXPCS_IDX_0);
	dprioin_rprbsen_rx	<= dprioin(rprbsen_rx_RXPCS_IDX_0);
	dprioin_rrx_rd_clk_sel	<= dprioin(rrx_rd_clk_sel_RXPCS_IDX_0);
	dprioin_rclk_2_sel	<= dprioin(rclk_2_sel_RXPCS_IDX_1 DOWNTO rclk_2_sel_RXPCS_IDX_0);
	dprioin_rclk_1_sel	<= dprioin(rclk_1_sel_RXPCS_IDX_1 DOWNTO rclk_1_sel_RXPCS_IDX_0);
	dprioin_rrcvd_clk_sel	<= dprioin(rrcvd_clk_sel_RXPCS_IDX_1 DOWNTO rrcvd_clk_sel_RXPCS_IDX_0);
	dprioin_rfreerun_rx	<= dprioin(rfreerun_rx_RXPCS_IDX_0);
	dprioin_rrxurstpcs	<= dprioin(rrxurstpcs_RXPCS_IDX_0);
	dprioin_reserved_0_TB5	<= dprioin(reserved_0_TB5_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 2 for Channel 0
	dprioin_rcomp_pat_32	<= dprioin(rcomp_pat_32_RXPCS_IDX_0);
	dprioin_rcomp_pat_33	<= dprioin(rcomp_pat_33_RXPCS_IDX_0);
	dprioin_rcomp_pat_34	<= dprioin(rcomp_pat_34_RXPCS_IDX_0);
	dprioin_rcomp_pat_35	<= dprioin(rcomp_pat_35_RXPCS_IDX_0);
	dprioin_rcomp_pat_36	<= dprioin(rcomp_pat_36_RXPCS_IDX_0);
	dprioin_rcomp_pat_37	<= dprioin(rcomp_pat_37_RXPCS_IDX_0);
	dprioin_rcomp_pat_38	<= dprioin(rcomp_pat_38_RXPCS_IDX_0);
	dprioin_rcomp_pat_39	<= dprioin(rcomp_pat_39_RXPCS_IDX_0);
	dprioin_rcomp_size	<= dprioin(rcomp_size_RXPCS_IDX_2 DOWNTO rcomp_size_RXPCS_IDX_0);
	dprioin_rcomp_pat_porn	<= dprioin(rcomp_pat_porn_RXPCS_IDX_0);
	dprioin_rdis_rx_disp	<= dprioin(rdis_rx_disp_RXPCS_IDX_0);
	dprioin_rencdt_rising	<= dprioin(rencdt_rising_RXPCS_IDX_0);
	dprioin_resync_badcg_en	<= dprioin(resync_badcg_en_RXPCS_IDX_1 DOWNTO resync_badcg_en_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 3 for Channel 0
	dprioin_rcomp_pat_16	<= dprioin(rcomp_pat_16_RXPCS_IDX_0);
	dprioin_rcomp_pat_17	<= dprioin(rcomp_pat_17_RXPCS_IDX_0);
	dprioin_rcomp_pat_18	<= dprioin(rcomp_pat_18_RXPCS_IDX_0);
	dprioin_rcomp_pat_19	<= dprioin(rcomp_pat_19_RXPCS_IDX_0);
	dprioin_rcomp_pat_20	<= dprioin(rcomp_pat_20_RXPCS_IDX_0);
	dprioin_rcomp_pat_21	<= dprioin(rcomp_pat_21_RXPCS_IDX_0);
	dprioin_rcomp_pat_22	<= dprioin(rcomp_pat_22_RXPCS_IDX_0);
	dprioin_rcomp_pat_23	<= dprioin(rcomp_pat_23_RXPCS_IDX_0);
	dprioin_rcomp_pat_24	<= dprioin(rcomp_pat_24_RXPCS_IDX_0);
	dprioin_rcomp_pat_25	<= dprioin(rcomp_pat_25_RXPCS_IDX_0);
	dprioin_rcomp_pat_26	<= dprioin(rcomp_pat_26_RXPCS_IDX_0);
	dprioin_rcomp_pat_27	<= dprioin(rcomp_pat_27_RXPCS_IDX_0);
	dprioin_rcomp_pat_28	<= dprioin(rcomp_pat_28_RXPCS_IDX_0);
	dprioin_rcomp_pat_29	<= dprioin(rcomp_pat_29_RXPCS_IDX_0);
	dprioin_rcomp_pat_30	<= dprioin(rcomp_pat_30_RXPCS_IDX_0);
	dprioin_rcomp_pat_31	<= dprioin(rcomp_pat_31_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 4 for Channel 0
	dprioin_rcomp_pat_0	<= dprioin(rcomp_pat_0_RXPCS_IDX_0);
	dprioin_rcomp_pat_1	<= dprioin(rcomp_pat_1_RXPCS_IDX_0);
	dprioin_rcomp_pat_2	<= dprioin(rcomp_pat_2_RXPCS_IDX_0);
	dprioin_rcomp_pat_3	<= dprioin(rcomp_pat_3_RXPCS_IDX_0);
	dprioin_rcomp_pat_4	<= dprioin(rcomp_pat_4_RXPCS_IDX_0);
	dprioin_rcomp_pat_5	<= dprioin(rcomp_pat_5_RXPCS_IDX_0);
	dprioin_rcomp_pat_6	<= dprioin(rcomp_pat_6_RXPCS_IDX_0);
	dprioin_rcomp_pat_7	<= dprioin(rcomp_pat_7_RXPCS_IDX_0);
	dprioin_rcomp_pat_8	<= dprioin(rcomp_pat_8_RXPCS_IDX_0);
	dprioin_rcomp_pat_9	<= dprioin(rcomp_pat_9_RXPCS_IDX_0);
	dprioin_rcomp_pat_10	<= dprioin(rcomp_pat_10_RXPCS_IDX_0);
	dprioin_rcomp_pat_11	<= dprioin(rcomp_pat_11_RXPCS_IDX_0);
	dprioin_rcomp_pat_12	<= dprioin(rcomp_pat_12_RXPCS_IDX_0);
	dprioin_rcomp_pat_13	<= dprioin(rcomp_pat_13_RXPCS_IDX_0);
	dprioin_rcomp_pat_14	<= dprioin(rcomp_pat_14_RXPCS_IDX_0);
	dprioin_rcomp_pat_15	<= dprioin(rcomp_pat_15_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 5 for Channel 0
	dprioin_rbitloc_rev_en	<= dprioin(rbitloc_rev_en_RXPCS_IDX_0);
	dprioin_rbysync_polinv_en	<= dprioin(rbysync_polinv_en_RXPCS_IDX_0);
	dprioin_rwa_6g_en	<= dprioin(rwa_6g_en_RXPCS_IDX_0);
	dprioin_rosnumber	<= dprioin(rosnumber_RXPCS_IDX_1 DOWNTO rosnumber_RXPCS_IDX_0);
	dprioin_rosbased	<= dprioin(rosbased_RXPCS_IDX_0);
	dprioin_rkchar	<= dprioin(rkchar_RXPCS_IDX_0);
	dprioin_renumber	<= dprioin(renumber_RXPCS_IDX_5 DOWNTO renumber_RXPCS_IDX_0);
	dprioin_rib_inv_cd	<= dprioin(rib_inv_cd_RXPCS_IDX_1 DOWNTO rib_inv_cd_RXPCS_IDX_0);
	dprioin_rsync_sm_dis	<= dprioin(rsync_sm_dis_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 6 for Channel 0
	dprioin_rknumber	<= dprioin(rknumber_RXPCS_IDX_7 DOWNTO rknumber_RXPCS_IDX_0);
	dprioin_rgnumber	<= dprioin(rgnumber_RXPCS_IDX_7 DOWNTO rgnumber_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 7 for Channel 0
	dprioin_renpolinv_rx	<= dprioin(renpolinv_rx_RXPCS_IDX_0);
	dprioin_rcascaded_8b10b_en_rx	<= dprioin(rcascaded_8b10b_en_rx_RXPCS_IDX_0);
	dprioin_r8b10b_dec_ibm_en	<= dprioin(r8b10b_dec_ibm_en_RXPCS_IDX_1 DOWNTO r8b10b_dec_ibm_en_RXPCS_IDX_0);
	dprioin_rendec_rx	<= dprioin(rendec_rx_RXPCS_IDX_0);
	dprioin_rautobtalg_dis	<= dprioin(rautobtalg_dis_RXPCS_IDX_0);
	dprioin_rrlv_en	<= dprioin(rrlv_en_RXPCS_IDX_0);
	dprioin_rlp20ben	<= dprioin(rlp20ben_RXPCS_IDX_0);
	dprioin_rforce_sig_det_pcs	<= dprioin(rforce_sig_det_pcs_RXPCS_IDX_0);
	dprioin_rbyte_rev_en	<= dprioin(rbyte_rev_en_RXPCS_IDX_0);
	dprioin_rrundisp	<= dprioin(rrundisp_RXPCS_IDX_5 DOWNTO rrundisp_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 8 for Channel 0
	dprioin_rclkcmpsq1p_0	<= dprioin(rclkcmpsq1p_0_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_1	<= dprioin(rclkcmpsq1p_1_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_2	<= dprioin(rclkcmpsq1p_2_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_3	<= dprioin(rclkcmpsq1p_3_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_4	<= dprioin(rclkcmpsq1p_4_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_5	<= dprioin(rclkcmpsq1p_5_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_6	<= dprioin(rclkcmpsq1p_6_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_7	<= dprioin(rclkcmpsq1p_7_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_8	<= dprioin(rclkcmpsq1p_8_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_9	<= dprioin(rclkcmpsq1p_9_RXPCS_IDX_0);
	dprioin_rclkcmpsqmd	<= dprioin(rclkcmpsqmd_RXPCS_IDX_0);
	dprioin_rclkcmpinsertpad	<= dprioin(rclkcmpinsertpad_RXPCS_IDX_0);
	dprioin_rtruebac2bac	<= dprioin(rtruebac2bac_RXPCS_IDX_0);
	dprioin_rskpsetbased	<= dprioin(rskpsetbased_RXPCS_IDX_0);
	dprioin_rgenericfifo	<= dprioin(rgenericfifo_RXPCS_IDX_0);
	dprioin_rmatchen	<= dprioin(rmatchen_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 9 for Channel 0
	dprioin_rclkcmpsq1p_10	<= dprioin(rclkcmpsq1p_10_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_11	<= dprioin(rclkcmpsq1p_11_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_12	<= dprioin(rclkcmpsq1p_12_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_13	<= dprioin(rclkcmpsq1p_13_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_14	<= dprioin(rclkcmpsq1p_14_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_15	<= dprioin(rclkcmpsq1p_15_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_16	<= dprioin(rclkcmpsq1p_16_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_17	<= dprioin(rclkcmpsq1p_17_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_18	<= dprioin(rclkcmpsq1p_18_RXPCS_IDX_0);
	dprioin_rclkcmpsq1p_19	<= dprioin(rclkcmpsq1p_19_RXPCS_IDX_0);
	dprioin_reserved_0_TB13	<= dprioin(reserved_0_TB13_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_15	<= dprioin(rclkcmpsq1n_15_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_16	<= dprioin(rclkcmpsq1n_16_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_17	<= dprioin(rclkcmpsq1n_17_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_18	<= dprioin(rclkcmpsq1n_18_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_19	<= dprioin(rclkcmpsq1n_19_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 10 for Channel 0
	dprioin_rclkcmpsq1n_0	<= dprioin(rclkcmpsq1n_0_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_1	<= dprioin(rclkcmpsq1n_1_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_2	<= dprioin(rclkcmpsq1n_2_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_3	<= dprioin(rclkcmpsq1n_3_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_4	<= dprioin(rclkcmpsq1n_4_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_5	<= dprioin(rclkcmpsq1n_5_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_6	<= dprioin(rclkcmpsq1n_6_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_7	<= dprioin(rclkcmpsq1n_7_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_8	<= dprioin(rclkcmpsq1n_8_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_9	<= dprioin(rclkcmpsq1n_9_RXPCS_IDX_0);
	dprioin_reserved_0_TB14	<= dprioin(reserved_0_TB14_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_10	<= dprioin(rclkcmpsq1n_10_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_11	<= dprioin(rclkcmpsq1n_11_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_12	<= dprioin(rclkcmpsq1n_12_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_13	<= dprioin(rclkcmpsq1n_13_RXPCS_IDX_0);
	dprioin_rclkcmpsq1n_14	<= dprioin(rclkcmpsq1n_14_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 11 for Channel 0
	dprioin_rfull_threshold	<= dprioin(rfull_threshold_RXPCS_IDX_4 DOWNTO rfull_threshold_RXPCS_IDX_0);
	dprioin_rdel_threshold	<= dprioin(rdel_threshold_RXPCS_IDX_4 DOWNTO rdel_threshold_RXPCS_IDX_0);
	dprioin_rins_threshold	<= dprioin(rins_threshold_RXPCS_IDX_4 DOWNTO rins_threshold_RXPCS_IDX_0);
	dprioin_rclkcmp_pipe_en	<= dprioin(rclkcmp_pipe_en_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 12 for Channel 0
	dprioin_rfreq_sel	<= dprioin(rfreq_sel_RXPCS_IDX_0);
	dprioin_rauto_speed_ena	<= dprioin(rauto_speed_ena_RXPCS_IDX_0);
	dprioin_rhip_ena	<= dprioin(rhip_ena_RXPCS_IDX_0);
	dprioin_rpma_done_gen_ena	<= dprioin(rpma_done_gen_ena_RXPCS_IDX_0);
	dprioin_rpma_done_count_16	<= dprioin(rpma_done_count_16_RXPCS_IDX_0);
	dprioin_rpma_done_count_17	<= dprioin(rpma_done_count_17_RXPCS_IDX_0);
	dprioin_reserved_0_TB16	<= dprioin(reserved_0_TB16_RXPCS_IDX_3 DOWNTO reserved_0_TB16_RXPCS_IDX_0);
	dprioin_rstart_threshold	<= dprioin(rstart_threshold_RXPCS_IDX_2 DOWNTO rstart_threshold_RXPCS_IDX_0);
	dprioin_rempty_threshold	<= dprioin(rempty_threshold_RXPCS_IDX_2 DOWNTO rempty_threshold_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 13 for Channel 0
	dprioin_rtest_bus_sel	<= dprioin(rtest_bus_sel_RXPCS_IDX_3 DOWNTO rtest_bus_sel_RXPCS_IDX_0);
	dprioin_rautoinsdis	<= dprioin(rautoinsdis_RXPCS_IDX_0);
	dprioin_rphfifopldenrx	<= dprioin(rphfifopldenrx_RXPCS_IDX_0);
	dprioin_rbytordplden	<= dprioin(rbytordplden_RXPCS_IDX_0);
	dprioin_rbyteorden	<= dprioin(rbyteorden_RXPCS_IDX_1 DOWNTO rbyteorden_RXPCS_IDX_0);
	dprioin_rbytord_2sym_en	<= dprioin(rbytord_2sym_en_RXPCS_IDX_0);
	dprioin_rinvalid_code_err_only	<= dprioin(rinvalid_code_err_only_RXPCS_IDX_0);
	dprioin_rcmpfifourst	<= dprioin(rcmpfifourst_RXPCS_IDX_0);
	dprioin_rphfifourstrx	<= dprioin(rphfifourstrx_RXPCS_IDX_0);
	dprioin_rdwidth_rx	<= dprioin(rdwidth_rx_RXPCS_IDX_0);
	dprioin_rrxfifo_lowlatency_en	<= dprioin(rrxfifo_lowlatency_en_RXPCS_IDX_0);
	dprioin_rrxfifo_dis	<= dprioin(rrxfifo_dis_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 14 for Channel 0
	dprioin_rbytordpat_0	<= dprioin(rbytordpat_0_RXPCS_IDX_0);
	dprioin_rbytordpat_1	<= dprioin(rbytordpat_1_RXPCS_IDX_0);
	dprioin_rbytordpat_2	<= dprioin(rbytordpat_2_RXPCS_IDX_0);
	dprioin_rbytordpat_3	<= dprioin(rbytordpat_3_RXPCS_IDX_0);
	dprioin_rbytordpat_4	<= dprioin(rbytordpat_4_RXPCS_IDX_0);
	dprioin_rbytordpat_5	<= dprioin(rbytordpat_5_RXPCS_IDX_0);
	dprioin_rbytordpat_6	<= dprioin(rbytordpat_6_RXPCS_IDX_0);
	dprioin_rbytordpat_7	<= dprioin(rbytordpat_7_RXPCS_IDX_0);
	dprioin_rbytordpat_8	<= dprioin(rbytordpat_8_RXPCS_IDX_0);
	dprioin_rbytordpat_9	<= dprioin(rbytordpat_9_RXPCS_IDX_0);
	dprioin_reserved_0_TB18	<= dprioin(reserved_0_TB18_RXPCS_IDX_5 DOWNTO reserved_0_TB18_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 15 for Channel 0
	dprioin_rbytordpad	<= dprioin(rbytordpad_RXPCS_IDX_9 DOWNTO rbytordpad_RXPCS_IDX_0);
	dprioin_reserved_0_TB19	<= dprioin(reserved_0_TB19_RXPCS_IDX_5 DOWNTO reserved_0_TB19_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 16 for Channel 0
	dprioin_rload_shreg_del	<= dprioin(rload_shreg_del_RXPCS_IDX_4 DOWNTO rload_shreg_del_RXPCS_IDX_0);
	dprioin_rphystatus_rst_toggle	<= dprioin(rphystatus_rst_toggle_RXPCS_IDX_0);
	dprioin_reidle_com_detect	<= dprioin(reidle_com_detect_RXPCS_IDX_1 DOWNTO reidle_com_detect_RXPCS_IDX_0);
	dprioin_rk285detect	<= dprioin(rk285detect_RXPCS_IDX_0);
	dprioin_reidleinferenable	<= dprioin(reidleinferenable_RXPCS_IDX_0);
	dprioin_rphystatus_delay	<= dprioin(rphystatus_delay_RXPCS_IDX_2 DOWNTO rphystatus_delay_RXPCS_IDX_0);
	dprioin_rind_error_reporting	<= dprioin(rind_error_reporting_RXPCS_IDX_0);
	dprioin_rrx_detect_bypass	<= dprioin(rrx_detect_bypass_RXPCS_IDX_0);
	dprioin_rrx_pipe_enable	<= dprioin(rrx_pipe_enable_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 17 for Channel 0
	dprioin_rpma_done_count_0	<= dprioin(rpma_done_count_0_RXPCS_IDX_0);
	dprioin_rpma_done_count_1	<= dprioin(rpma_done_count_1_RXPCS_IDX_0);
	dprioin_rpma_done_count_2	<= dprioin(rpma_done_count_2_RXPCS_IDX_0);
	dprioin_rpma_done_count_3	<= dprioin(rpma_done_count_3_RXPCS_IDX_0);
	dprioin_rpma_done_count_4	<= dprioin(rpma_done_count_4_RXPCS_IDX_0);
	dprioin_rpma_done_count_5	<= dprioin(rpma_done_count_5_RXPCS_IDX_0);
	dprioin_rpma_done_count_6	<= dprioin(rpma_done_count_6_RXPCS_IDX_0);
	dprioin_rpma_done_count_7	<= dprioin(rpma_done_count_7_RXPCS_IDX_0);
	dprioin_rpma_done_count_8	<= dprioin(rpma_done_count_8_RXPCS_IDX_0);
	dprioin_rpma_done_count_9	<= dprioin(rpma_done_count_9_RXPCS_IDX_0);
	dprioin_rpma_done_count_10	<= dprioin(rpma_done_count_10_RXPCS_IDX_0);
	dprioin_rpma_done_count_11	<= dprioin(rpma_done_count_11_RXPCS_IDX_0);
	dprioin_rpma_done_count_12	<= dprioin(rpma_done_count_12_RXPCS_IDX_0);
	dprioin_rpma_done_count_13	<= dprioin(rpma_done_count_13_RXPCS_IDX_0);
	dprioin_rpma_done_count_14	<= dprioin(rpma_done_count_14_RXPCS_IDX_0);
	dprioin_rpma_done_count_15	<= dprioin(rpma_done_count_15_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 18 for Channel 0
	dprioin_rbytordpat_10	<= dprioin(rbytordpat_10_RXPCS_IDX_0);
	dprioin_rbytordpat_11	<= dprioin(rbytordpat_11_RXPCS_IDX_0);
	dprioin_rbytordpat_12	<= dprioin(rbytordpat_12_RXPCS_IDX_0);
	dprioin_rbytordpat_13	<= dprioin(rbytordpat_13_RXPCS_IDX_0);
	dprioin_rbytordpat_14	<= dprioin(rbytordpat_14_RXPCS_IDX_0);
	dprioin_rbytordpat_15	<= dprioin(rbytordpat_15_RXPCS_IDX_0);
	dprioin_rbytordpat_16	<= dprioin(rbytordpat_16_RXPCS_IDX_0);
	dprioin_rbytordpat_17	<= dprioin(rbytordpat_17_RXPCS_IDX_0);
	dprioin_rbytordpat_18	<= dprioin(rbytordpat_18_RXPCS_IDX_0);
	dprioin_rbytordpat_19	<= dprioin(rbytordpat_19_RXPCS_IDX_0);
	dprioin_rbytord_6g_mask_en	<= dprioin(rbytord_6g_mask_en_RXPCS_IDX_0);
	dprioin_rbytord_s2gx	<= dprioin(rbytord_s2gx_RXPCS_IDX_0);
	dprioin_reserved_0_TB22	<= dprioin(reserved_0_TB22_RXPCS_IDX_0);
	dprioin_rcdr_ctrl_en	<= dprioin(rcdr_ctrl_en_RXPCS_IDX_0);
	dprioin_rrxpcsclkpwdn	<= dprioin(rrxpcsclkpwdn_RXPCS_IDX_0);
	dprioin_rerr_flags_sel	<= dprioin(rerr_flags_sel_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 19 for Channel 0
	dprioin_rwait_count	<= dprioin(rwait_count_RXPCS_IDX_7 DOWNTO rwait_count_RXPCS_IDX_0);
	dprioin_reserved_0_TB23	<= dprioin(reserved_0_TB23_RXPCS_IDX_7 DOWNTO reserved_0_TB23_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 20 for Channel 0
	dprioin_rfts_count	<= dprioin(rfts_count_RXPCS_IDX_9 DOWNTO rfts_count_RXPCS_IDX_0);
	dprioin_rwait_for_phfifo_cnt	<= dprioin(rwait_for_phfifo_cnt_RXPCS_IDX_5 DOWNTO rwait_for_phfifo_cnt_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 21 for Channel 0
	dprioin_rppm_meas_delay	<= dprioin(rppm_meas_delay_RXPCS_IDX_0);
	dprioin_rcid_len_rx	<= dprioin(rcid_len_rx_RXPCS_IDX_7 DOWNTO rcid_len_rx_RXPCS_IDX_0);
	dprioin_rcid_pattern_rx	<= dprioin(rcid_pattern_rx_RXPCS_IDX_0);
	dprioin_rpcs_wrapback_en	<= dprioin(rpcs_wrapback_en_RXPCS_IDX_0);
	dprioin_reserved_0_TB25	<= dprioin(reserved_0_TB25_RXPCS_IDX_4 DOWNTO reserved_0_TB25_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 22 for Channel 0
	dprioin_rauto_pc_en_cnt	<= dprioin(rauto_pc_en_cnt_RXPCS_IDX_4 DOWNTO rauto_pc_en_cnt_RXPCS_IDX_0);
	dprioin_reserved_1_TB26	<= dprioin(reserved_1_TB26_RXPCS_IDX_0);
	dprioin_rauto_deassert_pc_rst_cnt	<= dprioin(rauto_deassert_pc_rst_cnt_RXPCS_IDX_3 DOWNTO rauto_deassert_pc_rst_cnt_RXPCS_IDX_0);
	dprioin_reserved_0_TB26	<= dprioin(reserved_0_TB26_RXPCS_IDX_0);
	dprioin_rpipeline_bypass_rx	<= dprioin(rpipeline_bypass_rx_RXPCS_IDX_0);
	dprioin_rself_sw_en_rx	<= dprioin(rself_sw_en_rx_RXPCS_IDX_0);
	dprioin_rrxvalid_mask	<= dprioin(rrxvalid_mask_RXPCS_IDX_0);
	dprioin_rcid_en	<= dprioin(rcid_en_RXPCS_IDX_0);
	dprioin_rphfifo_regmode_rx	<= dprioin(rphfifo_regmode_rx_RXPCS_IDX_0);
	
	-- PCS Per Channel RX Control Register 23 for Channel 0
	dprioin_rmask_count	<= dprioin(rmask_count_RXPCS_IDX_9 DOWNTO rmask_count_RXPCS_IDX_0);
	dprioin_rgen1_sigdet_ena	<= dprioin(rgen1_sigdet_ena_RXPCS_IDX_0);
	dprioin_riei_eios_priority_dis	<= dprioin(riei_eios_priority_dis_RXPCS_IDX_0);
	dprioin_reserved_0_TB27	<= dprioin(reserved_0_TB27_RXPCS_IDX_3 DOWNTO reserved_0_TB27_RXPCS_IDX_0);
	
	-- ---------------------------------------------------------------------------
	-- Set DPRIO output from initial CRAM
	-- ---------------------------------------------------------------------------
	-- Manual section
	dprioout(rpma_doublewidth_rx_RX_IDX)   <= init_rpma_doublewidth_rx;
	dprioout(rpmadwidth_rx_RX_IDX)         <= init_rpmadwidth_rx;
	dprioout(rendec_data_sel_rx_RX_IDX)    <= init_rendec_data_sel_rx;
	dprioout(rdeskewen_RX_IDX)             <= init_rdeskewen;
	dprioout(rindv_rx_RX_IDX)              <= init_rindv_rx;
	dprioout(rmaster_rx_RX_IDX)            <= init_rmaster_rx;
	dprioout(rmaster_up_rx_RX_IDX)         <= init_rmaster_up_rx;
	dprioout(rdskposdisp_RX_IDX)           <= init_rdskposdisp;
	
	-- Existing
	dprioout(rclkcmppos_RX_IDX)            <= init_rclkcmppos;
	dprioout(rforce0_freqdet_RX_IDX)       <= init_rforce0_freqdet;
	dprioout(rforce1_freqdet_RX_IDX)       <= init_rforce1_freqdet;
	dprioout(rppmsel_RX_IDX_5 DOWNTO rppmsel_RX_IDX_0)	<= init_rppmsel;
	dprioout(rdwidth_rx_RX_IDX)            <= init_rrdwidth_rx;
	dprioout(rtx_idle_delay_RX_IDX_1 DOWNTO rtx_idle_delay_RX_IDX_0) <= init_rtx_elec_idle_delay;
	
	-- PCS Per Channel RX Control Register 1 for Channel 0
	dprioout(rrxpcsbypass_en_RXPCS_IDX_0) <= init_rrxpcsbypass_en;
	dprioout(rall_one_dect_only_RXPCS_IDX_0) <= init_rall_one_dect_only;
	dprioout(rbist_clr_rx_RXPCS_IDX_0) <= init_rbist_clr_rx;
	dprioout(rbisten_rx_RXPCS_IDX_0) <= init_rbisten_rx;
	dprioout(rprbs_clr_rslt_rx_RXPCS_IDX_0) <= init_rprbs_clr_rslt_rx;
	dprioout(rprbsen_rx_RXPCS_IDX_0) <= init_rprbsen_rx;
	dprioout(rrx_rd_clk_sel_RXPCS_IDX_0) <= init_rrx_rd_clk_sel;
	dprioout(rclk_2_sel_RXPCS_IDX_1 DOWNTO rclk_2_sel_RXPCS_IDX_0) <= init_rclk_2_sel;
	dprioout(rclk_1_sel_RXPCS_IDX_1 DOWNTO rclk_1_sel_RXPCS_IDX_0) <= init_rclk_1_sel;
	dprioout(rrcvd_clk_sel_RXPCS_IDX_1 DOWNTO rrcvd_clk_sel_RXPCS_IDX_0) <= init_rrcvd_clk_sel;
	dprioout(rfreerun_rx_RXPCS_IDX_0) <= init_rfreerun_rx;
	dprioout(rrxurstpcs_RXPCS_IDX_0) <= init_rrxurstpcs;
	dprioout(reserved_0_TB5_RXPCS_IDX_0) <= init_reserved_0_TB5;
	
	-- PCS Per Channel RX Control Register 2 for Channel 0
	dprioout(rcomp_pat_32_RXPCS_IDX_0) <= init_rcomp_pat_32;
	dprioout(rcomp_pat_33_RXPCS_IDX_0) <= init_rcomp_pat_33;
	dprioout(rcomp_pat_34_RXPCS_IDX_0) <= init_rcomp_pat_34;
	dprioout(rcomp_pat_35_RXPCS_IDX_0) <= init_rcomp_pat_35;
	dprioout(rcomp_pat_36_RXPCS_IDX_0) <= init_rcomp_pat_36;
	dprioout(rcomp_pat_37_RXPCS_IDX_0) <= init_rcomp_pat_37;
	dprioout(rcomp_pat_38_RXPCS_IDX_0) <= init_rcomp_pat_38;
	dprioout(rcomp_pat_39_RXPCS_IDX_0) <= init_rcomp_pat_39;
	dprioout(rcomp_size_RXPCS_IDX_2 DOWNTO rcomp_size_RXPCS_IDX_0) <= init_rcomp_size;
	dprioout(rcomp_pat_porn_RXPCS_IDX_0) <= init_rcomp_pat_porn;
	dprioout(rdis_rx_disp_RXPCS_IDX_0) <= init_rdis_rx_disp;
	dprioout(rencdt_rising_RXPCS_IDX_0) <= init_rencdt_rising;
	dprioout(resync_badcg_en_RXPCS_IDX_1 DOWNTO resync_badcg_en_RXPCS_IDX_0) <= init_resync_badcg_en;
	
	-- PCS Per Channel RX Control Register 3 for Channel 0
	dprioout(rcomp_pat_16_RXPCS_IDX_0) <= init_rcomp_pat_16;
	dprioout(rcomp_pat_17_RXPCS_IDX_0) <= init_rcomp_pat_17;
	dprioout(rcomp_pat_18_RXPCS_IDX_0) <= init_rcomp_pat_18;
	dprioout(rcomp_pat_19_RXPCS_IDX_0) <= init_rcomp_pat_19;
	dprioout(rcomp_pat_20_RXPCS_IDX_0) <= init_rcomp_pat_20;
	dprioout(rcomp_pat_21_RXPCS_IDX_0) <= init_rcomp_pat_21;
	dprioout(rcomp_pat_22_RXPCS_IDX_0) <= init_rcomp_pat_22;
	dprioout(rcomp_pat_23_RXPCS_IDX_0) <= init_rcomp_pat_23;
	dprioout(rcomp_pat_24_RXPCS_IDX_0) <= init_rcomp_pat_24;
	dprioout(rcomp_pat_25_RXPCS_IDX_0) <= init_rcomp_pat_25;
	dprioout(rcomp_pat_26_RXPCS_IDX_0) <= init_rcomp_pat_26;
	dprioout(rcomp_pat_27_RXPCS_IDX_0) <= init_rcomp_pat_27;
	dprioout(rcomp_pat_28_RXPCS_IDX_0) <= init_rcomp_pat_28;
	dprioout(rcomp_pat_29_RXPCS_IDX_0) <= init_rcomp_pat_29;
	dprioout(rcomp_pat_30_RXPCS_IDX_0) <= init_rcomp_pat_30;
	dprioout(rcomp_pat_31_RXPCS_IDX_0) <= init_rcomp_pat_31;
	
	-- PCS Per Channel RX Control Register 4 for Channel 0
	dprioout(rcomp_pat_0_RXPCS_IDX_0) <= init_rcomp_pat_0;
	dprioout(rcomp_pat_1_RXPCS_IDX_0) <= init_rcomp_pat_1;
	dprioout(rcomp_pat_2_RXPCS_IDX_0) <= init_rcomp_pat_2;
	dprioout(rcomp_pat_3_RXPCS_IDX_0) <= init_rcomp_pat_3;
	dprioout(rcomp_pat_4_RXPCS_IDX_0) <= init_rcomp_pat_4;
	dprioout(rcomp_pat_5_RXPCS_IDX_0) <= init_rcomp_pat_5;
	dprioout(rcomp_pat_6_RXPCS_IDX_0) <= init_rcomp_pat_6;
	dprioout(rcomp_pat_7_RXPCS_IDX_0) <= init_rcomp_pat_7;
	dprioout(rcomp_pat_8_RXPCS_IDX_0) <= init_rcomp_pat_8;
	dprioout(rcomp_pat_9_RXPCS_IDX_0) <= init_rcomp_pat_9;
	dprioout(rcomp_pat_10_RXPCS_IDX_0) <= init_rcomp_pat_10;
	dprioout(rcomp_pat_11_RXPCS_IDX_0) <= init_rcomp_pat_11;
	dprioout(rcomp_pat_12_RXPCS_IDX_0) <= init_rcomp_pat_12;
	dprioout(rcomp_pat_13_RXPCS_IDX_0) <= init_rcomp_pat_13;
	dprioout(rcomp_pat_14_RXPCS_IDX_0) <= init_rcomp_pat_14;
	dprioout(rcomp_pat_15_RXPCS_IDX_0) <= init_rcomp_pat_15;
	
	-- PCS Per Channel RX Control Register 5 for Channel 0
	dprioout(rbitloc_rev_en_RXPCS_IDX_0) <= init_rbitloc_rev_en;
	dprioout(rbysync_polinv_en_RXPCS_IDX_0) <= init_rbysync_polinv_en;
	dprioout(rwa_6g_en_RXPCS_IDX_0) <= init_rwa_6g_en;
	dprioout(rosnumber_RXPCS_IDX_1 DOWNTO rosnumber_RXPCS_IDX_0) <= init_rosnumber;
	dprioout(rosbased_RXPCS_IDX_0) <= init_rosbased;
	dprioout(rkchar_RXPCS_IDX_0) <= init_rkchar;
	dprioout(renumber_RXPCS_IDX_5 DOWNTO renumber_RXPCS_IDX_0) <= init_renumber;
	dprioout(rib_inv_cd_RXPCS_IDX_1 DOWNTO rib_inv_cd_RXPCS_IDX_0) <= init_rib_inv_cd;
	dprioout(rsync_sm_dis_RXPCS_IDX_0) <= init_rsync_sm_dis;
	
	-- PCS Per Channel RX Control Register 6 for Channel 0
	dprioout(rknumber_RXPCS_IDX_7 DOWNTO rknumber_RXPCS_IDX_0) <= init_rknumber;
	dprioout(rgnumber_RXPCS_IDX_7 DOWNTO rgnumber_RXPCS_IDX_0) <= init_rgnumber;
	
	-- PCS Per Channel RX Control Register 7 for Channel 0
	dprioout(renpolinv_rx_RXPCS_IDX_0) <= init_renpolinv_rx;
	dprioout(rcascaded_8b10b_en_rx_RXPCS_IDX_0) <= init_rcascaded_8b10b_en_rx;
	dprioout(r8b10b_dec_ibm_en_RXPCS_IDX_1 DOWNTO r8b10b_dec_ibm_en_RXPCS_IDX_0) <= init_r8b10b_dec_ibm_en;
	dprioout(rendec_rx_RXPCS_IDX_0) <= init_rendec_rx;
	dprioout(rautobtalg_dis_RXPCS_IDX_0) <= init_rautobtalg_dis;
	dprioout(rrlv_en_RXPCS_IDX_0) <= init_rrlv_en;
	dprioout(rlp20ben_RXPCS_IDX_0) <= init_rlp20ben;
	dprioout(rforce_sig_det_pcs_RXPCS_IDX_0) <= init_rforce_sig_det_pcs;
	dprioout(rbyte_rev_en_RXPCS_IDX_0) <= init_rbyte_rev_en;
	dprioout(rrundisp_RXPCS_IDX_5 DOWNTO rrundisp_RXPCS_IDX_0) <= init_rrundisp;
	
	-- PCS Per Channel RX Control Register 8 for Channel 0
    dprioout(rclkcmpsq1p_0_RXPCS_IDX_0) <= init_rclkcmpsq1p_0;
	dprioout(rclkcmpsq1p_1_RXPCS_IDX_0) <= init_rclkcmpsq1p_1;
	dprioout(rclkcmpsq1p_2_RXPCS_IDX_0) <= init_rclkcmpsq1p_2;
	dprioout(rclkcmpsq1p_3_RXPCS_IDX_0) <= init_rclkcmpsq1p_3;
	dprioout(rclkcmpsq1p_4_RXPCS_IDX_0) <= init_rclkcmpsq1p_4;
	dprioout(rclkcmpsq1p_5_RXPCS_IDX_0) <= init_rclkcmpsq1p_5;
	dprioout(rclkcmpsq1p_6_RXPCS_IDX_0) <= init_rclkcmpsq1p_6;
	dprioout(rclkcmpsq1p_7_RXPCS_IDX_0) <= init_rclkcmpsq1p_7;
	dprioout(rclkcmpsq1p_8_RXPCS_IDX_0) <= init_rclkcmpsq1p_8;
	dprioout(rclkcmpsq1p_9_RXPCS_IDX_0) <= init_rclkcmpsq1p_9;
	dprioout(rclkcmpsqmd_RXPCS_IDX_0) <= init_rclkcmpsqmd;
	dprioout(rclkcmpinsertpad_RXPCS_IDX_0) <= init_rclkcmpinsertpad;
	dprioout(rtruebac2bac_RXPCS_IDX_0) <= init_rtruebac2bac;
	dprioout(rskpsetbased_RXPCS_IDX_0) <= init_rskpsetbased;
	dprioout(rgenericfifo_RXPCS_IDX_0) <= init_rgenericfifo;
	dprioout(rmatchen_RXPCS_IDX_0) <= init_rmatchen;
	
	-- PCS Per Channel RX Control Register 9 for Channel 0
	dprioout(rclkcmpsq1p_10_RXPCS_IDX_0) <= init_rclkcmpsq1p_10;
	dprioout(rclkcmpsq1p_11_RXPCS_IDX_0) <= init_rclkcmpsq1p_11;
	dprioout(rclkcmpsq1p_12_RXPCS_IDX_0) <= init_rclkcmpsq1p_12;
	dprioout(rclkcmpsq1p_13_RXPCS_IDX_0) <= init_rclkcmpsq1p_13;
	dprioout(rclkcmpsq1p_14_RXPCS_IDX_0) <= init_rclkcmpsq1p_14;
	dprioout(rclkcmpsq1p_15_RXPCS_IDX_0) <= init_rclkcmpsq1p_15;
	dprioout(rclkcmpsq1p_16_RXPCS_IDX_0) <= init_rclkcmpsq1p_16;
	dprioout(rclkcmpsq1p_17_RXPCS_IDX_0) <= init_rclkcmpsq1p_17;
	dprioout(rclkcmpsq1p_18_RXPCS_IDX_0) <= init_rclkcmpsq1p_18;
	dprioout(rclkcmpsq1p_19_RXPCS_IDX_0) <= init_rclkcmpsq1p_19;
	dprioout(reserved_0_TB13_RXPCS_IDX_0) <= init_reserved_0_TB13;
	dprioout(rclkcmpsq1n_15_RXPCS_IDX_0) <= init_rclkcmpsq1n_15;
	dprioout(rclkcmpsq1n_16_RXPCS_IDX_0) <= init_rclkcmpsq1n_16;
	dprioout(rclkcmpsq1n_17_RXPCS_IDX_0) <= init_rclkcmpsq1n_17;
	dprioout(rclkcmpsq1n_18_RXPCS_IDX_0) <= init_rclkcmpsq1n_18;
	dprioout(rclkcmpsq1n_19_RXPCS_IDX_0) <= init_rclkcmpsq1n_19;
	
	-- PCS Per Channel RX Control Register 10 for Channel 0
	dprioout(rclkcmpsq1n_0_RXPCS_IDX_0) <= init_rclkcmpsq1n_0;
	dprioout(rclkcmpsq1n_1_RXPCS_IDX_0) <= init_rclkcmpsq1n_1;
	dprioout(rclkcmpsq1n_2_RXPCS_IDX_0) <= init_rclkcmpsq1n_2;
	dprioout(rclkcmpsq1n_3_RXPCS_IDX_0) <= init_rclkcmpsq1n_3;
	dprioout(rclkcmpsq1n_4_RXPCS_IDX_0) <= init_rclkcmpsq1n_4;
	dprioout(rclkcmpsq1n_5_RXPCS_IDX_0) <= init_rclkcmpsq1n_5;
	dprioout(rclkcmpsq1n_6_RXPCS_IDX_0) <= init_rclkcmpsq1n_6;
	dprioout(rclkcmpsq1n_7_RXPCS_IDX_0) <= init_rclkcmpsq1n_7;
	dprioout(rclkcmpsq1n_8_RXPCS_IDX_0) <= init_rclkcmpsq1n_8;
	dprioout(rclkcmpsq1n_9_RXPCS_IDX_0) <= init_rclkcmpsq1n_9;
	dprioout(reserved_0_TB14_RXPCS_IDX_0) <= init_reserved_0_TB14;
	dprioout(rclkcmpsq1n_10_RXPCS_IDX_0) <= init_rclkcmpsq1n_10;
	dprioout(rclkcmpsq1n_11_RXPCS_IDX_0) <= init_rclkcmpsq1n_11;
	dprioout(rclkcmpsq1n_12_RXPCS_IDX_0) <= init_rclkcmpsq1n_12;
	dprioout(rclkcmpsq1n_13_RXPCS_IDX_0) <= init_rclkcmpsq1n_13;
	dprioout(rclkcmpsq1n_14_RXPCS_IDX_0) <= init_rclkcmpsq1n_14;
	
	-- PCS Per Channel RX Control Register 11 for Channel 0
	dprioout(rfull_threshold_RXPCS_IDX_4 DOWNTO rfull_threshold_RXPCS_IDX_0) <= init_rfull_threshold;
	dprioout(rdel_threshold_RXPCS_IDX_4 DOWNTO rdel_threshold_RXPCS_IDX_0) <= init_rdel_threshold;
	dprioout(rins_threshold_RXPCS_IDX_4 DOWNTO rins_threshold_RXPCS_IDX_0) <= init_rins_threshold;
	dprioout(rclkcmp_pipe_en_RXPCS_IDX_0) <= init_rclkcmp_pipe_en;
	
	-- PCS Per Channel RX Control Register 12 for Channel 0
	dprioout(rfreq_sel_RXPCS_IDX_0) <= init_rfreq_sel;
	dprioout(rauto_speed_ena_RXPCS_IDX_0) <= init_rauto_speed_ena;
	dprioout(rhip_ena_RXPCS_IDX_0) <= init_rhip_ena;
	dprioout(rpma_done_gen_ena_RXPCS_IDX_0) <= init_rpma_done_gen_ena;
	dprioout(rpma_done_count_16_RXPCS_IDX_0) <= init_rpma_done_count_16;
	dprioout(rpma_done_count_17_RXPCS_IDX_0) <= init_rpma_done_count_17;
	dprioout(reserved_0_TB16_RXPCS_IDX_3 DOWNTO reserved_0_TB16_RXPCS_IDX_0) <= init_reserved_0_TB16;
	dprioout(rstart_threshold_RXPCS_IDX_2 DOWNTO rstart_threshold_RXPCS_IDX_0) <= init_rstart_threshold;
	dprioout(rempty_threshold_RXPCS_IDX_2 DOWNTO rempty_threshold_RXPCS_IDX_0) <= init_rempty_threshold;
	
	-- PCS Per Channel RX Control Register 13 for Channel 0
	dprioout(rtest_bus_sel_RXPCS_IDX_3 DOWNTO rtest_bus_sel_RXPCS_IDX_0) <= init_rtest_bus_sel;
	dprioout(rautoinsdis_RXPCS_IDX_0) <= init_rautoinsdis;
	dprioout(rphfifopldenrx_RXPCS_IDX_0) <= init_rphfifopldenrx;
	dprioout(rbytordplden_RXPCS_IDX_0) <= init_rbytordplden;
	dprioout(rbyteorden_RXPCS_IDX_1 DOWNTO rbyteorden_RXPCS_IDX_0) <= init_rbyteorden;
	dprioout(rbytord_2sym_en_RXPCS_IDX_0) <= init_rbytord_2sym_en;
	dprioout(rinvalid_code_err_only_RXPCS_IDX_0) <= init_rinvalid_code_err_only;
	dprioout(rcmpfifourst_RXPCS_IDX_0) <= init_rcmpfifourst;
	dprioout(rphfifourstrx_RXPCS_IDX_0) <= init_rphfifourstrx;
	dprioout(rdwidth_rx_RXPCS_IDX_0) <= init_rdwidth_rx;
	dprioout(rrxfifo_lowlatency_en_RXPCS_IDX_0) <= init_rrxfifo_lowlatency_en;
	dprioout(rrxfifo_dis_RXPCS_IDX_0) <= init_rrxfifo_dis;
	
	-- PCS Per Channel RX Control Register 14 for Channel 0
	dprioout(rbytordpat_0_RXPCS_IDX_0) <= init_rbytordpat_0;
	dprioout(rbytordpat_1_RXPCS_IDX_0) <= init_rbytordpat_1;
	dprioout(rbytordpat_2_RXPCS_IDX_0) <= init_rbytordpat_2;
	dprioout(rbytordpat_3_RXPCS_IDX_0) <= init_rbytordpat_3;
	dprioout(rbytordpat_4_RXPCS_IDX_0) <= init_rbytordpat_4;
	dprioout(rbytordpat_5_RXPCS_IDX_0) <= init_rbytordpat_5;
	dprioout(rbytordpat_6_RXPCS_IDX_0) <= init_rbytordpat_6;
	dprioout(rbytordpat_7_RXPCS_IDX_0) <= init_rbytordpat_7;
	dprioout(rbytordpat_8_RXPCS_IDX_0) <= init_rbytordpat_8;
	dprioout(rbytordpat_9_RXPCS_IDX_0) <= init_rbytordpat_9;
	dprioout(reserved_0_TB18_RXPCS_IDX_5 DOWNTO reserved_0_TB18_RXPCS_IDX_0) <= init_reserved_0_TB18;
	
	-- PCS Per Channel RX Control Register 15 for Channel 0
	dprioout(rbytordpad_RXPCS_IDX_9 DOWNTO rbytordpad_RXPCS_IDX_0) <= init_rbytordpad;
	dprioout(reserved_0_TB19_RXPCS_IDX_5 DOWNTO reserved_0_TB19_RXPCS_IDX_0) <= init_reserved_0_TB19;
	
	-- PCS Per Channel RX Control Register 16 for Channel 0
	dprioout(rload_shreg_del_RXPCS_IDX_4 DOWNTO rload_shreg_del_RXPCS_IDX_0) <= init_rload_shreg_del;
	dprioout(rphystatus_rst_toggle_RXPCS_IDX_0) <= init_rphystatus_rst_toggle;
	dprioout(reidle_com_detect_RXPCS_IDX_1 DOWNTO reidle_com_detect_RXPCS_IDX_0) <= init_reidle_com_detect;
	dprioout(rk285detect_RXPCS_IDX_0) <= init_rk285detect;
	dprioout(reidleinferenable_RXPCS_IDX_0) <= init_reidleinferenable;
	dprioout(rphystatus_delay_RXPCS_IDX_2 DOWNTO rphystatus_delay_RXPCS_IDX_0) <= init_rphystatus_delay;
	dprioout(rind_error_reporting_RXPCS_IDX_0) <= init_rind_error_reporting;
	dprioout(rrx_detect_bypass_RXPCS_IDX_0) <= init_rrx_detect_bypass;
	dprioout(rrx_pipe_enable_RXPCS_IDX_0) <= init_rrx_pipe_enable;
	
	-- PCS Per Channel RX Control Register 17 for Channel 0
	dprioout(rpma_done_count_0_RXPCS_IDX_0) <= init_rpma_done_count_0;
	dprioout(rpma_done_count_1_RXPCS_IDX_0) <= init_rpma_done_count_1;
	dprioout(rpma_done_count_2_RXPCS_IDX_0) <= init_rpma_done_count_2;
	dprioout(rpma_done_count_3_RXPCS_IDX_0) <= init_rpma_done_count_3;
	dprioout(rpma_done_count_4_RXPCS_IDX_0) <= init_rpma_done_count_4;
	dprioout(rpma_done_count_5_RXPCS_IDX_0) <= init_rpma_done_count_5;
	dprioout(rpma_done_count_6_RXPCS_IDX_0) <= init_rpma_done_count_6;
	dprioout(rpma_done_count_7_RXPCS_IDX_0) <= init_rpma_done_count_7;
	dprioout(rpma_done_count_8_RXPCS_IDX_0) <= init_rpma_done_count_8;
	dprioout(rpma_done_count_9_RXPCS_IDX_0) <= init_rpma_done_count_9;
	dprioout(rpma_done_count_10_RXPCS_IDX_0) <= init_rpma_done_count_10;
	dprioout(rpma_done_count_11_RXPCS_IDX_0) <= init_rpma_done_count_11;
	dprioout(rpma_done_count_12_RXPCS_IDX_0) <= init_rpma_done_count_12;
	dprioout(rpma_done_count_13_RXPCS_IDX_0) <= init_rpma_done_count_13;
	dprioout(rpma_done_count_14_RXPCS_IDX_0) <= init_rpma_done_count_14;
	dprioout(rpma_done_count_15_RXPCS_IDX_0) <= init_rpma_done_count_15;
	
	-- PCS Per Channel RX Control Register 18 for Channel 0
	dprioout(rbytordpat_10_RXPCS_IDX_0) <= init_rbytordpat_10;
	dprioout(rbytordpat_11_RXPCS_IDX_0) <= init_rbytordpat_11;
	dprioout(rbytordpat_12_RXPCS_IDX_0) <= init_rbytordpat_12;
	dprioout(rbytordpat_13_RXPCS_IDX_0) <= init_rbytordpat_13;
	dprioout(rbytordpat_14_RXPCS_IDX_0) <= init_rbytordpat_14;
	dprioout(rbytordpat_15_RXPCS_IDX_0) <= init_rbytordpat_15;
	dprioout(rbytordpat_16_RXPCS_IDX_0) <= init_rbytordpat_16;
	dprioout(rbytordpat_17_RXPCS_IDX_0) <= init_rbytordpat_17;
	dprioout(rbytordpat_18_RXPCS_IDX_0) <= init_rbytordpat_18;
	dprioout(rbytordpat_19_RXPCS_IDX_0) <= init_rbytordpat_19;
	dprioout(rbytord_6g_mask_en_RXPCS_IDX_0) <= init_rbytord_6g_mask_en;
	dprioout(rbytord_s2gx_RXPCS_IDX_0) <= init_rbytord_s2gx;
	dprioout(reserved_0_TB22_RXPCS_IDX_0) <= init_reserved_0_TB22;
	dprioout(rcdr_ctrl_en_RXPCS_IDX_0) <= init_rcdr_ctrl_en;
	dprioout(rrxpcsclkpwdn_RXPCS_IDX_0) <= init_rrxpcsclkpwdn;
	dprioout(rerr_flags_sel_RXPCS_IDX_0) <= init_rerr_flags_sel;
	
	-- PCS Per Channel RX Control Register 19 for Channel 0
	dprioout(rwait_count_RXPCS_IDX_7 DOWNTO rwait_count_RXPCS_IDX_0) <= init_rwait_count;
	dprioout(reserved_0_TB23_RXPCS_IDX_7 DOWNTO reserved_0_TB23_RXPCS_IDX_0) <= init_reserved_0_TB23;
	
	-- PCS Per Channel RX Control Register 20 for Channel 0
	dprioout(rfts_count_RXPCS_IDX_9 DOWNTO rfts_count_RXPCS_IDX_0) <= init_rfts_count;
	dprioout(rwait_for_phfifo_cnt_RXPCS_IDX_5 DOWNTO rwait_for_phfifo_cnt_RXPCS_IDX_0) <= init_rwait_for_phfifo_cnt;
	
	-- PCS Per Channel RX Control Register 21 for Channel 0
	dprioout(rppm_meas_delay_RXPCS_IDX_0) <= init_rppm_meas_delay;
	dprioout(rcid_len_rx_RXPCS_IDX_7 DOWNTO rcid_len_rx_RXPCS_IDX_0) <= init_rcid_len_rx;
	dprioout(rcid_pattern_rx_RXPCS_IDX_0) <= init_rcid_pattern_rx;
	dprioout(rpcs_wrapback_en_RXPCS_IDX_0) <= init_rpcs_wrapback_en;
	dprioout(reserved_0_TB25_RXPCS_IDX_4 DOWNTO reserved_0_TB25_RXPCS_IDX_0) <= init_reserved_0_TB25;
	
	-- PCS Per Channel RX Control Register 22 for Channel 0
	dprioout(rauto_pc_en_cnt_RXPCS_IDX_4 DOWNTO rauto_pc_en_cnt_RXPCS_IDX_0) <= init_rauto_pc_en_cnt;
	dprioout(reserved_1_TB26_RXPCS_IDX_0) <= init_reserved_1_TB26;
	dprioout(rauto_deassert_pc_rst_cnt_RXPCS_IDX_3 DOWNTO rauto_deassert_pc_rst_cnt_RXPCS_IDX_0) <= init_rauto_deassert_pc_rst_cnt;
	dprioout(reserved_0_TB26_RXPCS_IDX_0) <= init_reserved_0_TB26;
	dprioout(rpipeline_bypass_rx_RXPCS_IDX_0) <= init_rpipeline_bypass_rx;
	dprioout(rself_sw_en_rx_RXPCS_IDX_0) <= init_rself_sw_en_rx;
	dprioout(rrxvalid_mask_RXPCS_IDX_0) <= init_rrxvalid_mask;
	dprioout(rcid_en_RXPCS_IDX_0) <= init_rcid_en;
	dprioout(rphfifo_regmode_rx_RXPCS_IDX_0) <= init_rphfifo_regmode_rx;
	
	-- PCS Per Channel RX Control Register 23 for Channel 0
	dprioout(rmask_count_RXPCS_IDX_9 DOWNTO rmask_count_RXPCS_IDX_0) <= init_rmask_count;
	dprioout(rgen1_sigdet_ena_RXPCS_IDX_0) <= init_rgen1_sigdet_ena;
	dprioout(riei_eios_priority_dis_RXPCS_IDX_0) <= init_riei_eios_priority_dis;
	dprioout(reserved_0_TB27_RXPCS_IDX_3 DOWNTO reserved_0_TB27_RXPCS_IDX_0) <= init_reserved_0_TB27;

	-- ---------------------------------------------------------------------------
	-- Set DPRIO CRAM
	-- ---------------------------------------------------------------------------
	dpriodisable_in <= '0' WHEN (dpriodisable = '0') ELSE '1';
	
	-- Manual Section
	cram_rpma_doublewidth_rx	<= init_rpma_doublewidth_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rpma_doublewidth_rx;  -- enabled
	cram_rpmadwidth_rx      	<= init_rpmadwidth_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rpmadwidth_rx;        -- enabled
	cram_rendec_data_sel_rx 	<= init_rendec_data_sel_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rendec_data_sel_rx;
	cram_rindv_rx           	<= init_rindv_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rindv_rx;
	cram_rdeskewen          	<= init_rdeskewen WHEN (dpriodisable_in /= '0') ELSE dprioin_rdeskewen;
	cram_rmaster_rx         	<= init_rmaster_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rmaster_rx;
	cram_rmaster_up_rx      	<= init_rmaster_up_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rmaster_up_rx;
	cram_rdskposdisp        	<= init_rdskposdisp WHEN (dpriodisable_in /= '0') ELSE dprioin_rdskposdisp;
		
	-- Existing
	cram_dskwclksel         	<= init_dskwclksel WHEN (dpriodisable_in /= '0') ELSE dprioin_dskwclksel;
	cram_is_lane0           	<= init_is_lane0 WHEN (dpriodisable_in /= '0') ELSE dprioin_is_lane0;
	cram_rbist_sel          	<= init_rbist_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rbist_sel;
	cram_rclkcmppos         	<= init_rclkcmppos WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmppos; 
	cram_rcxpat_chnl_en     	<= init_rcxpat_chnl_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rcxpat_chnl_en;
	cram_rdskchrp           	<= init_rdskchrp WHEN (dpriodisable_in /= '0') ELSE dprioin_rdskchrp;
	cram_renpolinv_en       	<= init_renpolinv_en WHEN (dpriodisable_in /= '0') ELSE dprioin_renpolinv_en;
	cram_rforce0_freqdet    	<= init_rforce0_freqdet WHEN (dpriodisable_in /= '0') ELSE dprioin_rforce0_freqdet;
	cram_rforce1_freqdet    	<= init_rforce1_freqdet WHEN (dpriodisable_in /= '0') ELSE dprioin_rforce1_freqdet;
	cram_rphfifourstenrx    	<= init_rphfifourstenrx WHEN (dpriodisable_in /= '0') ELSE dprioin_rphfifourstenrx;
	cram_rppm_gen1_2xcnt_en 	<= init_rppm_gen1_2xcnt_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rppm_gen1_2xcnt_en;
	cram_rppm_post_eidle_del 	<= init_rppm_post_eidle_del WHEN (dpriodisable_in /= '0') ELSE dprioin_rppm_post_eidle_del;
	cram_rppmsel            	<= init_rppmsel WHEN (dpriodisable_in /= '0') ELSE dprioin_rppmsel;
	cram_rprbs_sel          	<= init_rprbs_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rprbs_sel;
	cram_rrdwidth_rx        	<= init_rrdwidth_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rrdwidth_rx;
	cram_rrx_fifo_dis       	<= init_rrx_fifo_dis WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_fifo_dis;
	cram_rtx_elec_idle_delay 	<= init_rtx_elec_idle_delay WHEN (dpriodisable_in /= '0') ELSE dprioin_rtx_elec_idle_delay;
	cram_rtx_pipe_enable    	<= init_rtx_pipe_enable WHEN (dpriodisable_in /= '0') ELSE dprioin_rtx_pipe_enable;
	cram_scan_mode          	<= init_scan_mode WHEN (dpriodisable_in /= '0') ELSE dprioin_scan_mode;
	cram_sel_gp_md          	<= init_sel_gp_md WHEN (dpriodisable_in /= '0') ELSE dprioin_sel_gp_md;
	
	-- PCS Per Channel RX Control Register 1 for Channel 0
	cram_rrxpcsbypass_en <= init_rrxpcsbypass_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rrxpcsbypass_en;
	cram_rall_one_dect_only <= init_rall_one_dect_only WHEN (dpriodisable_in /= '0') ELSE dprioin_rall_one_dect_only;
	cram_rbist_clr_rx <= init_rbist_clr_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rbist_clr_rx;
	cram_rbisten_rx <= init_rbisten_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rbisten_rx;
	cram_rprbs_clr_rslt_rx <= init_rprbs_clr_rslt_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rprbs_clr_rslt_rx;
	cram_rprbsen_rx <= init_rprbsen_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rprbsen_rx;
	cram_rrx_rd_clk_sel <= init_rrx_rd_clk_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_rd_clk_sel;
	cram_rclk_2_sel <= init_rclk_2_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rclk_2_sel;
	cram_rclk_1_sel <= init_rclk_1_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rclk_1_sel;
	cram_rrcvd_clk_sel <= init_rrcvd_clk_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rrcvd_clk_sel;
	cram_rfreerun_rx <= init_rfreerun_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rfreerun_rx;
	cram_rrxurstpcs <= init_rrxurstpcs WHEN (dpriodisable_in /= '0') ELSE dprioin_rrxurstpcs;
	cram_reserved_0_TB5 <= init_reserved_0_TB5 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB5;
	
	-- PCS Per Channel RX Control Register 2 for Channel 0
	cram_rcomp_pat_32 <= init_rcomp_pat_32 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_32;
	cram_rcomp_pat_33 <= init_rcomp_pat_33 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_33;
	cram_rcomp_pat_34 <= init_rcomp_pat_34 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_34;
	cram_rcomp_pat_35 <= init_rcomp_pat_35 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_35;
	cram_rcomp_pat_36 <= init_rcomp_pat_36 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_36;
	cram_rcomp_pat_37 <= init_rcomp_pat_37 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_37;
	cram_rcomp_pat_38 <= init_rcomp_pat_38 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_38;
	cram_rcomp_pat_39 <= init_rcomp_pat_39 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_39;
	cram_rcomp_size <= init_rcomp_size WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_size;
	cram_rcomp_pat_porn <= init_rcomp_pat_porn WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_porn;
	cram_rdis_rx_disp <= init_rdis_rx_disp WHEN (dpriodisable_in /= '0') ELSE dprioin_rdis_rx_disp;
	cram_rencdt_rising <= init_rencdt_rising WHEN (dpriodisable_in /= '0') ELSE dprioin_rencdt_rising;
	cram_resync_badcg_en <= init_resync_badcg_en WHEN (dpriodisable_in /= '0') ELSE dprioin_resync_badcg_en;
	
	-- PCS Per Channel RX Control Register 3 for Channel 0
	cram_rcomp_pat_16 <= init_rcomp_pat_16 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_16;
	cram_rcomp_pat_17 <= init_rcomp_pat_17 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_17;
	cram_rcomp_pat_18 <= init_rcomp_pat_18 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_18;
	cram_rcomp_pat_19 <= init_rcomp_pat_19 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_19;
	cram_rcomp_pat_20 <= init_rcomp_pat_20 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_20;
	cram_rcomp_pat_21 <= init_rcomp_pat_21 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_21;
	cram_rcomp_pat_22 <= init_rcomp_pat_22 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_22;
	cram_rcomp_pat_23 <= init_rcomp_pat_23 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_23;
	cram_rcomp_pat_24 <= init_rcomp_pat_24 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_24;
	cram_rcomp_pat_25 <= init_rcomp_pat_25 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_25;
	cram_rcomp_pat_26 <= init_rcomp_pat_26 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_26;
	cram_rcomp_pat_27 <= init_rcomp_pat_27 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_27;
	cram_rcomp_pat_28 <= init_rcomp_pat_28 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_28;
	cram_rcomp_pat_29 <= init_rcomp_pat_29 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_29;
	cram_rcomp_pat_30 <= init_rcomp_pat_30 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_30;
	cram_rcomp_pat_31 <= init_rcomp_pat_31 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_31;
	
	-- PCS Per Channel RX Control Register 4 for Channel 0
	cram_rcomp_pat_0 <= init_rcomp_pat_0 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_0;
	cram_rcomp_pat_1 <= init_rcomp_pat_1 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_1;
	cram_rcomp_pat_2 <= init_rcomp_pat_2 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_2;
	cram_rcomp_pat_3 <= init_rcomp_pat_3 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_3;
	cram_rcomp_pat_4 <= init_rcomp_pat_4 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_4;
	cram_rcomp_pat_5 <= init_rcomp_pat_5 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_5;
	cram_rcomp_pat_6 <= init_rcomp_pat_6 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_6;
	cram_rcomp_pat_7 <= init_rcomp_pat_7 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_7;
	cram_rcomp_pat_8 <= init_rcomp_pat_8 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_8;
	cram_rcomp_pat_9 <= init_rcomp_pat_9 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_9;
	cram_rcomp_pat_10 <= init_rcomp_pat_10 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_10;
	cram_rcomp_pat_11 <= init_rcomp_pat_11 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_11;
	cram_rcomp_pat_12 <= init_rcomp_pat_12 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_12;
	cram_rcomp_pat_13 <= init_rcomp_pat_13 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_13;
	cram_rcomp_pat_14 <= init_rcomp_pat_14 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_14;
	cram_rcomp_pat_15 <= init_rcomp_pat_15 WHEN (dpriodisable_in /= '0') ELSE dprioin_rcomp_pat_15;
	
	-- PCS Per Channel RX Control Register 5 for Channel 0
	cram_rbitloc_rev_en <= init_rbitloc_rev_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rbitloc_rev_en;
	cram_rbysync_polinv_en <= init_rbysync_polinv_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rbysync_polinv_en;
	cram_rwa_6g_en <= init_rwa_6g_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rwa_6g_en;
	cram_rosnumber <= init_rosnumber WHEN (dpriodisable_in /= '0') ELSE dprioin_rosnumber;
	cram_rosbased <= init_rosbased WHEN (dpriodisable_in /= '0') ELSE dprioin_rosbased;
	cram_rkchar <= init_rkchar WHEN (dpriodisable_in /= '0') ELSE dprioin_rkchar;
	cram_renumber <= init_renumber WHEN (dpriodisable_in /= '0') ELSE dprioin_renumber;
	cram_rib_inv_cd <= init_rib_inv_cd WHEN (dpriodisable_in /= '0') ELSE dprioin_rib_inv_cd;
	cram_rsync_sm_dis <= init_rsync_sm_dis WHEN (dpriodisable_in /= '0') ELSE dprioin_rsync_sm_dis;
	
	-- PCS Per Channel RX Control Register 6 for Channel 0
	cram_rknumber <= init_rknumber WHEN (dpriodisable_in /= '0') ELSE dprioin_rknumber;
	cram_rgnumber <= init_rgnumber WHEN (dpriodisable_in /= '0') ELSE dprioin_rgnumber;
	
	-- PCS Per Channel RX Control Register 7 for Channel 0
	cram_renpolinv_rx <= init_renpolinv_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_renpolinv_rx;
	cram_rcascaded_8b10b_en_rx <= init_rcascaded_8b10b_en_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rcascaded_8b10b_en_rx;
	cram_r8b10b_dec_ibm_en <= init_r8b10b_dec_ibm_en WHEN (dpriodisable_in /= '0') ELSE dprioin_r8b10b_dec_ibm_en;
	cram_rendec_rx <= init_rendec_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rendec_rx;
	cram_rautobtalg_dis <= init_rautobtalg_dis WHEN (dpriodisable_in /= '0') ELSE dprioin_rautobtalg_dis;
	cram_rrlv_en <= init_rrlv_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rrlv_en;
	cram_rlp20ben <= init_rlp20ben WHEN (dpriodisable_in /= '0') ELSE dprioin_rlp20ben;
	cram_rforce_sig_det_pcs <= init_rforce_sig_det_pcs WHEN (dpriodisable_in /= '0') ELSE dprioin_rforce_sig_det_pcs;
	cram_rbyte_rev_en <= init_rbyte_rev_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rbyte_rev_en;
	cram_rrundisp <= init_rrundisp WHEN (dpriodisable_in /= '0') ELSE dprioin_rrundisp;
	
	-- PCS Per Channel RX Control Register 8 for Channel 0
	cram_rclkcmpsq1p_0 <= init_rclkcmpsq1p_0 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_0;
	cram_rclkcmpsq1p_1 <= init_rclkcmpsq1p_1 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_1;
	cram_rclkcmpsq1p_2 <= init_rclkcmpsq1p_2 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_2;
	cram_rclkcmpsq1p_3 <= init_rclkcmpsq1p_3 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_3;
	cram_rclkcmpsq1p_4 <= init_rclkcmpsq1p_4 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_4;
	cram_rclkcmpsq1p_5 <= init_rclkcmpsq1p_5 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_5;
	cram_rclkcmpsq1p_6 <= init_rclkcmpsq1p_6 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_6;
	cram_rclkcmpsq1p_7 <= init_rclkcmpsq1p_7 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_7;
	cram_rclkcmpsq1p_8 <= init_rclkcmpsq1p_8 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_8;
	cram_rclkcmpsq1p_9 <= init_rclkcmpsq1p_9 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_9;
	cram_rclkcmpsqmd <= init_rclkcmpsqmd WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsqmd;
	cram_rclkcmpinsertpad <= init_rclkcmpinsertpad WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpinsertpad;
	cram_rtruebac2bac <= init_rtruebac2bac WHEN (dpriodisable_in /= '0') ELSE dprioin_rtruebac2bac;
	cram_rskpsetbased <= init_rskpsetbased WHEN (dpriodisable_in /= '0') ELSE dprioin_rskpsetbased;
	cram_rgenericfifo <= init_rgenericfifo WHEN (dpriodisable_in /= '0') ELSE dprioin_rgenericfifo;
	cram_rmatchen <= init_rmatchen WHEN (dpriodisable_in /= '0') ELSE dprioin_rmatchen;
	
	-- PCS Per Channel RX Control Register 9 for Channel 0
	cram_rclkcmpsq1p_10 <= init_rclkcmpsq1p_10 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_10;
	cram_rclkcmpsq1p_11 <= init_rclkcmpsq1p_11 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_11;
	cram_rclkcmpsq1p_12 <= init_rclkcmpsq1p_12 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_12;
	cram_rclkcmpsq1p_13 <= init_rclkcmpsq1p_13 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_13;
	cram_rclkcmpsq1p_14 <= init_rclkcmpsq1p_14 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_14;
	cram_rclkcmpsq1p_15 <= init_rclkcmpsq1p_15 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_15;
	cram_rclkcmpsq1p_16 <= init_rclkcmpsq1p_16 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_16;
	cram_rclkcmpsq1p_17 <= init_rclkcmpsq1p_17 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_17;
	cram_rclkcmpsq1p_18 <= init_rclkcmpsq1p_18 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_18;
	cram_rclkcmpsq1p_19 <= init_rclkcmpsq1p_19 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1p_19;
	cram_reserved_0_TB13 <= init_reserved_0_TB13 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB13;
	cram_rclkcmpsq1n_15 <= init_rclkcmpsq1n_15 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_15;
	cram_rclkcmpsq1n_16 <= init_rclkcmpsq1n_16 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_16;
	cram_rclkcmpsq1n_17 <= init_rclkcmpsq1n_17 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_17;
	cram_rclkcmpsq1n_18 <= init_rclkcmpsq1n_18 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_18;
	cram_rclkcmpsq1n_19 <= init_rclkcmpsq1n_19 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_19;
	
	-- PCS Per Channel RX Control Register 10 for Channel 0
	cram_rclkcmpsq1n_0 <= init_rclkcmpsq1n_0 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_0;
	cram_rclkcmpsq1n_1 <= init_rclkcmpsq1n_1 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_1;
	cram_rclkcmpsq1n_2 <= init_rclkcmpsq1n_2 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_2;
	cram_rclkcmpsq1n_3 <= init_rclkcmpsq1n_3 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_3;
	cram_rclkcmpsq1n_4 <= init_rclkcmpsq1n_4 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_4;
	cram_rclkcmpsq1n_5 <= init_rclkcmpsq1n_5 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_5;
	cram_rclkcmpsq1n_6 <= init_rclkcmpsq1n_6 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_6;
	cram_rclkcmpsq1n_7 <= init_rclkcmpsq1n_7 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_7;
	cram_rclkcmpsq1n_8 <= init_rclkcmpsq1n_8 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_8;
	cram_rclkcmpsq1n_9 <= init_rclkcmpsq1n_9 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_9;
	cram_reserved_0_TB14 <= init_reserved_0_TB14 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB14;
	cram_rclkcmpsq1n_10 <= init_rclkcmpsq1n_10 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_10;
	cram_rclkcmpsq1n_11 <= init_rclkcmpsq1n_11 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_11;
	cram_rclkcmpsq1n_12 <= init_rclkcmpsq1n_12 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_12;
	cram_rclkcmpsq1n_13 <= init_rclkcmpsq1n_13 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_13;
	cram_rclkcmpsq1n_14 <= init_rclkcmpsq1n_14 WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmpsq1n_14;
	
	-- PCS Per Channel RX Control Register 11 for Channel 0
	cram_rfull_threshold <= init_rfull_threshold WHEN (dpriodisable_in /= '0') ELSE dprioin_rfull_threshold;
	cram_rdel_threshold <= init_rdel_threshold WHEN (dpriodisable_in /= '0') ELSE dprioin_rdel_threshold;
	cram_rins_threshold <= init_rins_threshold WHEN (dpriodisable_in /= '0') ELSE dprioin_rins_threshold;
	cram_rclkcmp_pipe_en <= init_rclkcmp_pipe_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rclkcmp_pipe_en;
	
	-- PCS Per Channel RX Control Register 12 for Channel 0
	cram_rfreq_sel <= init_rfreq_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rfreq_sel;
	cram_rauto_speed_ena <= init_rauto_speed_ena WHEN (dpriodisable_in /= '0') ELSE dprioin_rauto_speed_ena;
	cram_rhip_ena <= init_rhip_ena WHEN (dpriodisable_in /= '0') ELSE dprioin_rhip_ena;
	cram_rpma_done_gen_ena <= init_rpma_done_gen_ena WHEN (dpriodisable_in /= '0') ELSE dprioin_rpma_done_gen_ena;
	cram_rpma_done_count_16 <= init_rpma_done_count_16 ; -- hardening it
	cram_rpma_done_count_17 <= init_rpma_done_count_17 ; -- hardening it
	cram_reserved_0_TB16 <= init_reserved_0_TB16 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB16;
	cram_rstart_threshold <= init_rstart_threshold WHEN (dpriodisable_in /= '0') ELSE dprioin_rstart_threshold;
	cram_rempty_threshold <= init_rempty_threshold WHEN (dpriodisable_in /= '0') ELSE dprioin_rempty_threshold;
	
	-- PCS Per Channel RX Control Register 13 for Channel 0
	cram_rtest_bus_sel <= init_rtest_bus_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rtest_bus_sel;
	cram_rautoinsdis <= init_rautoinsdis WHEN (dpriodisable_in /= '0') ELSE dprioin_rautoinsdis;
	cram_rphfifopldenrx <= init_rphfifopldenrx WHEN (dpriodisable_in /= '0') ELSE dprioin_rphfifopldenrx;
	cram_rbytordplden <= init_rbytordplden WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordplden;
	cram_rbyteorden <= init_rbyteorden WHEN (dpriodisable_in /= '0') ELSE dprioin_rbyteorden;
	cram_rbytord_2sym_en <= init_rbytord_2sym_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytord_2sym_en;
	cram_rinvalid_code_err_only <= init_rinvalid_code_err_only WHEN (dpriodisable_in /= '0') ELSE dprioin_rinvalid_code_err_only;
	cram_rcmpfifourst <= init_rcmpfifourst WHEN (dpriodisable_in /= '0') ELSE dprioin_rcmpfifourst;
	cram_rphfifourstrx <= init_rphfifourstrx WHEN (dpriodisable_in /= '0') ELSE dprioin_rphfifourstrx;
	cram_rdwidth_rx <= init_rdwidth_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rdwidth_rx;
	cram_rrxfifo_lowlatency_en <= init_rrxfifo_lowlatency_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rrxfifo_lowlatency_en;
	cram_rrxfifo_dis <= init_rrxfifo_dis WHEN (dpriodisable_in /= '0') ELSE dprioin_rrxfifo_dis;
	
	-- PCS Per Channel RX Control Register 14 for Channel 0
	cram_rbytordpat_0 <= init_rbytordpat_0 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_0;
	cram_rbytordpat_1 <= init_rbytordpat_1 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_1;
	cram_rbytordpat_2 <= init_rbytordpat_2 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_2;
	cram_rbytordpat_3 <= init_rbytordpat_3 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_3;
	cram_rbytordpat_4 <= init_rbytordpat_4 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_4;
	cram_rbytordpat_5 <= init_rbytordpat_5 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_5;
	cram_rbytordpat_6 <= init_rbytordpat_6 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_6;
	cram_rbytordpat_7 <= init_rbytordpat_7 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_7;
	cram_rbytordpat_8 <= init_rbytordpat_8 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_8;
	cram_rbytordpat_9 <= init_rbytordpat_9 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_9;
	cram_reserved_0_TB18 <= init_reserved_0_TB18 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB18;
	
	-- PCS Per Channel RX Control Register 15 for Channel 0
	cram_rbytordpad <= init_rbytordpad WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpad;
	cram_reserved_0_TB19 <= init_reserved_0_TB19 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB19;
	
	-- PCS Per Channel RX Control Register 16 for Channel 0
	cram_rload_shreg_del <= init_rload_shreg_del WHEN (dpriodisable_in /= '0') ELSE dprioin_rload_shreg_del;
	cram_rphystatus_rst_toggle <= init_rphystatus_rst_toggle WHEN (dpriodisable_in /= '0') ELSE dprioin_rphystatus_rst_toggle;
	cram_reidle_com_detect <= init_reidle_com_detect WHEN (dpriodisable_in /= '0') ELSE dprioin_reidle_com_detect;
	cram_rk285detect <= init_rk285detect WHEN (dpriodisable_in /= '0') ELSE dprioin_rk285detect;
	cram_reidleinferenable <= init_reidleinferenable WHEN (dpriodisable_in /= '0') ELSE dprioin_reidleinferenable;
	cram_rphystatus_delay <= init_rphystatus_delay WHEN (dpriodisable_in /= '0') ELSE dprioin_rphystatus_delay;
	cram_rind_error_reporting <= init_rind_error_reporting WHEN (dpriodisable_in /= '0') ELSE dprioin_rind_error_reporting;
	cram_rrx_detect_bypass <= init_rrx_detect_bypass WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_detect_bypass;
	cram_rrx_pipe_enable <= init_rrx_pipe_enable WHEN (dpriodisable_in /= '0') ELSE dprioin_rrx_pipe_enable;
	
	-- PCS Per Channel RX Control Register 17 for Channel 0
	cram_rpma_done_count_0 <= init_rpma_done_count_0 ; -- hardening it
	cram_rpma_done_count_1 <= init_rpma_done_count_1 ;
	cram_rpma_done_count_2 <= init_rpma_done_count_2 ;
	cram_rpma_done_count_3 <= init_rpma_done_count_3 ;
	cram_rpma_done_count_4 <= init_rpma_done_count_4 ;
	cram_rpma_done_count_5 <= init_rpma_done_count_5 ;
	cram_rpma_done_count_6 <= init_rpma_done_count_6 ;
	cram_rpma_done_count_7 <= init_rpma_done_count_7 ;
	cram_rpma_done_count_8 <= init_rpma_done_count_8 ;
	cram_rpma_done_count_9 <= init_rpma_done_count_9 ;
	cram_rpma_done_count_10 <= init_rpma_done_count_10 ;
	cram_rpma_done_count_11 <= init_rpma_done_count_11 ;
	cram_rpma_done_count_12 <= init_rpma_done_count_12 ;
	cram_rpma_done_count_13 <= init_rpma_done_count_13 ;
	cram_rpma_done_count_14 <= init_rpma_done_count_14 ;
	cram_rpma_done_count_15 <= init_rpma_done_count_15 ;
	
	-- PCS Per Channel RX Control Register 18 for Channel 0
	cram_rbytordpat_10 <= init_rbytordpat_10 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_10;
	cram_rbytordpat_11 <= init_rbytordpat_11 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_11;
	cram_rbytordpat_12 <= init_rbytordpat_12 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_12;
	cram_rbytordpat_13 <= init_rbytordpat_13 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_13;
	cram_rbytordpat_14 <= init_rbytordpat_14 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_14;
	cram_rbytordpat_15 <= init_rbytordpat_15 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_15;
	cram_rbytordpat_16 <= init_rbytordpat_16 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_16;
	cram_rbytordpat_17 <= init_rbytordpat_17 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_17;
	cram_rbytordpat_18 <= init_rbytordpat_18 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_18;
	cram_rbytordpat_19 <= init_rbytordpat_19 WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytordpat_19;
	cram_rbytord_6g_mask_en <= init_rbytord_6g_mask_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytord_6g_mask_en;
	cram_rbytord_s2gx <= init_rbytord_s2gx WHEN (dpriodisable_in /= '0') ELSE dprioin_rbytord_s2gx;
	cram_reserved_0_TB22 <= init_reserved_0_TB22 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB22;
	cram_rcdr_ctrl_en <= init_rcdr_ctrl_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rcdr_ctrl_en;
	cram_rrxpcsclkpwdn <= init_rrxpcsclkpwdn WHEN (dpriodisable_in /= '0') ELSE dprioin_rrxpcsclkpwdn;
	cram_rerr_flags_sel <= init_rerr_flags_sel WHEN (dpriodisable_in /= '0') ELSE dprioin_rerr_flags_sel;
	
	-- PCS Per Channel RX Control Register 19 for Channel 0
	cram_rwait_count <= init_rwait_count WHEN (dpriodisable_in /= '0') ELSE dprioin_rwait_count;
	cram_reserved_0_TB23 <= init_reserved_0_TB23 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB23;
	
	-- PCS Per Channel RX Control Register 20 for Channel 0
	cram_rfts_count <= init_rfts_count WHEN (dpriodisable_in /= '0') ELSE dprioin_rfts_count;
	cram_rwait_for_phfifo_cnt <= init_rwait_for_phfifo_cnt WHEN (dpriodisable_in /= '0') ELSE dprioin_rwait_for_phfifo_cnt;
	
	-- PCS Per Channel RX Control Register 21 for Channel 0
	cram_rppm_meas_delay <= init_rppm_meas_delay WHEN (dpriodisable_in /= '0') ELSE dprioin_rppm_meas_delay;
	cram_rcid_len_rx <= init_rcid_len_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rcid_len_rx;
	cram_rcid_pattern_rx <= init_rcid_pattern_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rcid_pattern_rx;
	cram_rpcs_wrapback_en <= init_rpcs_wrapback_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rpcs_wrapback_en;
	cram_reserved_0_TB25 <= init_reserved_0_TB25 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB25;
	
	-- PCS Per Channel RX Control Register 22 for Channel 0
	cram_rauto_pc_en_cnt <= init_rauto_pc_en_cnt WHEN (dpriodisable_in /= '0') ELSE dprioin_rauto_pc_en_cnt;
	cram_reserved_1_TB26 <= init_reserved_1_TB26 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_1_TB26;
	cram_rauto_deassert_pc_rst_cnt <= init_rauto_deassert_pc_rst_cnt WHEN (dpriodisable_in /= '0') ELSE dprioin_rauto_deassert_pc_rst_cnt;
	cram_reserved_0_TB26 <= init_reserved_0_TB26 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB26;
	cram_rpipeline_bypass_rx <= init_rpipeline_bypass_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rpipeline_bypass_rx;
	cram_rself_sw_en_rx <= init_rself_sw_en_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rself_sw_en_rx;
	cram_rrxvalid_mask <= init_rrxvalid_mask WHEN (dpriodisable_in /= '0') ELSE dprioin_rrxvalid_mask;
	cram_rcid_en <= init_rcid_en WHEN (dpriodisable_in /= '0') ELSE dprioin_rcid_en;
	cram_rphfifo_regmode_rx <= init_rphfifo_regmode_rx WHEN (dpriodisable_in /= '0') ELSE dprioin_rphfifo_regmode_rx;
	
	-- PCS Per Channel RX Control Register 23 for Channel 0
	cram_rmask_count <= init_rmask_count WHEN (dpriodisable_in /= '0') ELSE dprioin_rmask_count;
	cram_rgen1_sigdet_ena <= init_rgen1_sigdet_ena WHEN (dpriodisable_in /= '0') ELSE dprioin_rgen1_sigdet_ena;
	cram_riei_eios_priority_dis <= init_riei_eios_priority_dis WHEN (dpriodisable_in /= '0') ELSE dprioin_riei_eios_priority_dis;
	cram_reserved_0_TB27 <= init_reserved_0_TB27 WHEN (dpriodisable_in /= '0') ELSE dprioin_reserved_0_TB27;
  
   --///////////////////////////////////////////////////////////////////////////
   -- Connect top level output  ----------------------------------------------//
   --///////////////////////////////////////////////////////////////////////////
   
--   a1a2sizeout <= a1a2sizeout_reg;
   a1detect <= a1detect_reg;
   a2detect <= a2detect_reg;
--   ctrldetect <= ctrldetect_reg;
--   dataout <= dataout_reg;
--   dataoutfull <= pi_out_rxd_ch;
--   disperr <= disperr_reg;
--   errdetect <= errdetect_reg;
   k1detect <= k1detect_reg;
   k2detect <= k2detect_reg;
--   patterndetect <= patterndetect_reg;
--   rmfifodatadeleted <= rmfifodatadeleted_reg;
--   rmfifodatainserted <= rmfifodatainserted_reg;
--   runningdisp <= runningdisp_reg;
--   syncstatus <= syncstatus_reg;
   
   -- a1a2sizeout; - used in SONET mode
   PROCESS (rd_out_rxd(8), rd_out_rxd(24), rd_out_rxd(40), rd_out_rxd(56))
VARIABLE  txt : LINE;
 variable i : integer;
   BEGIN
      IF (cram_rpma_doublewidth_rx = '0' AND cram_rdwidth_rx = '1') THEN
 i := 0;
         while ((i <  4) AND (i < 2) ) LOOP
            a1a2sizeout_reg(i) <= rd_out_rxd(8 + 32 * i);
 i := i + 1;
         END LOOP;
      ELSE
         FOR i IN 0 TO 3 LOOP
            a1a2sizeout_reg(i) <= rd_out_rxd(8 + 16 * i);
         END LOOP;
      END IF;
   END PROCESS;
   
   
   -- a1detect; [1:0] - Async from Word align, not going BYTE SERDES
   PROCESS (rd_out_a1a2_k1k2_flag(0), rd_out_a1a2_k1k2_flag(2))
VARIABLE  txt : LINE;
   BEGIN
      FOR i IN 0 TO 1 LOOP
         
         -- a2detect; [0] = detecting A2 on datain[7:0]; [1] = on datain[15:8]
         a1detect_reg(i) <= rd_out_a1a2_k1k2_flag(2 * i);
      END LOOP;
   END PROCESS;
   
   PROCESS (rd_out_a1a2_k1k2_flag(1), rd_out_a1a2_k1k2_flag(3))
VARIABLE  txt : LINE;
   BEGIN
      FOR i IN 0 TO 1 LOOP
         
         -- adetectdeskew;
         a2detect_reg(i) <= rd_out_a1a2_k1k2_flag(1 + 2 * i);
      END LOOP;
   END PROCESS;
   
   adetectdeskew <= rd_out_align_det_sync;
   
   -- alignstatussyncout
   alignstatussyncout <= rd_out_align_status_sync;
   
   -- bistdone;
   bistdone <= rd_out_bistdone;
   
   -- bisterr;
   bisterr <= rd_out_bisterr;
   
   -- byteorderalignstatus;
--   byteorderalignstatus <= rd_out_byteord_flag;
   
   -- clkout;
   clkout <= rd_out_rx_clk;
   
   -- ctrldetect; - 8b10b used 
   PROCESS (rd_out_rxd(8), rd_out_rxd(24), rd_out_rxd(40), rd_out_rxd(56))
VARIABLE  txt : LINE;
 variable i : integer;
   BEGIN
      IF (cram_rpma_doublewidth_rx = '0' AND cram_rdwidth_rx = '1') THEN
 i := 0;
         while ((i <  4) AND (i < 2) ) LOOP
            ctrldetect_reg(i) <= rd_out_rxd(8 + 32 * i);
 i := i + 1;
         END LOOP;
      ELSE
         FOR i IN 0 TO 3 LOOP
            ctrldetect_reg(i) <= rd_out_rxd(8 + 16 * i);
         END LOOP;
      END IF;
   END PROCESS;
   
   
   -- dataout; - 40 => [7:0]/[9:0], [23:16]/[25:16], [39:32]/[41:32], [55:48]/[57:48]
         PROCESS                                                             
 VARIABLE BASIC_WIDTH :  integer;                                            
 VARIABLE NUM_OF_BASIC : integer;                                            
 VARIABLE i : integer := 0;                                                  
 VARIABLE j : integer := 0;                                                  
 BEGIN                                                                       
     IF (channel_width mod 10 = 0) THEN                                      
         BASIC_WIDTH := 10;                                                  
     ELSE                                                                    
         BASIC_WIDTH := 8;                                                   
     END IF;                                                                 
                                                                             
     NUM_OF_BASIC := channel_width/BASIC_WIDTH;                              
                                                                             
     WAIT UNTIL rd_out_rxd'EVENT;                                            
     IF (cram_rpma_doublewidth_rx = '0' AND cram_rdwidth_rx = '1') THEN      
         i := 0;                                                             
         WHILE ((i < NUM_OF_BASIC) AND (i < 2)) LOOP                         
             j := 0;                                                         
             WHILE (j < BASIC_WIDTH) LOOP                                    
                 dataout_reg(i * BASIC_WIDTH + j) <= rd_out_rxd(i * 32 + j); 
                 j := j + 1;                                                 
             END LOOP;                                                       
             i := i + 1;                                                     
         END LOOP;                                                           
     ELSE                                                                    
         i := 0;                                                             
         WHILE (i < NUM_OF_BASIC) LOOP                                       
             j := 0;                                                         
             WHILE (j < BASIC_WIDTH) LOOP                                    
                 dataout_reg(i * BASIC_WIDTH + j) <= rd_out_rxd(i * 16 + j); 
                 j := j + 1;                                                 
             END LOOP;                                                       
             i := i + 1;                                                     
         END LOOP;                                                           
     END IF;                                                                 
 END PROCESS;                                                                
   
   -- disperr;
   PROCESS (rd_out_rxd(11), rd_out_rxd(27), rd_out_rxd(43), rd_out_rxd(59))
VARIABLE  txt : LINE;
 variable i : integer;
   BEGIN
      IF (cram_rpma_doublewidth_rx = '0' AND cram_rdwidth_rx = '1') THEN
 i := 0;
         while ((i <  4) AND (i < 2) ) LOOP
            disperr_reg(i) <= rd_out_rxd(11 + 32 * i);
 i := i + 1;
         END LOOP;
      ELSE
         FOR i IN 0 TO 3 LOOP
            disperr_reg(i) <= rd_out_rxd(11 + 16 * i);
         END LOOP;
      END IF;
   END PROCESS;
   
   
   -- dprioout
   --dprioout <= ("0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000" & wire_dprioout);
   
   -- errdetect;
   PROCESS (rd_out_rxd(9), rd_out_rxd(25), rd_out_rxd(41), rd_out_rxd(57))
VARIABLE  txt : LINE;
 variable i : integer;
   BEGIN
      IF (cram_rpma_doublewidth_rx = '0' AND cram_rdwidth_rx = '1') THEN
 i := 0;
         while ((i <  4) AND (i < 2) ) LOOP
            errdetect_reg(i) <= rd_out_rxd(9 + 32 * i);
 i := i + 1;
         END LOOP;
      ELSE
         FOR i IN 0 TO 3 LOOP
            errdetect_reg(i) <= rd_out_rxd(9 + 16 * i);
         END LOOP;
      END IF;
   END PROCESS;
   
   
   -- fifordout;
   fifordout <= rd_out_fifo_rd_out_comp;
   
   -- k1detect; [1:0] - Async from Word align, not going BYTE SERDES
   PROCESS (rd_out_a1a2_k1k2_flag(0), rd_out_a1a2_k1k2_flag(2))
VARIABLE  txt : LINE;
   BEGIN
      FOR i IN 0 TO 1 LOOP
         
         -- k2detect; [0] = detecting K2 on datain[9:0]; [1] = datain[19:20]
         k1detect_reg(i) <= rd_out_a1a2_k1k2_flag(2 * i);
      END LOOP;
   END PROCESS;
   
   PROCESS (rd_out_a1a2_k1k2_flag(1), rd_out_a1a2_k1k2_flag(3))
VARIABLE  txt : LINE;
   BEGIN
      FOR i IN 0 TO 1 LOOP
         
         -- patterndetect;
         k2detect_reg(i) <= rd_out_a1a2_k1k2_flag(1 + 2 * i);
      END LOOP;
   END PROCESS;
   
   PROCESS (rd_out_rxd(12), rd_out_rxd(28), rd_out_rxd(44), rd_out_rxd(60))
VARIABLE  txt : LINE;
 variable i : integer;
   BEGIN
      IF (cram_rpma_doublewidth_rx = '0' AND cram_rdwidth_rx = '1') THEN
 i := 0;
         while ((i <  4) AND (i < 2) ) LOOP
            patterndetect_reg(i) <= rd_out_rxd(12 + 32 * i);
 i := i + 1;
         END LOOP;
      ELSE
         FOR i IN 0 TO 3 LOOP
            patterndetect_reg(i) <= rd_out_rxd(12 + 16 * i);
         END LOOP;
      END IF;
   END PROCESS;
   
    -- phfifooverflow;
--    phfifooverflow <= rd_out_full_rx;  
    
    -- phfifounderflow; 
--    phfifounderflow <= rd_out_empty_rx;
   
   -- pipebufferstat; 4 - expect wys - may remove according ICD
--   pipebufferstat(1 DOWNTO 0) <= rd_out_rxd(14 DOWNTO 13);
--   pipebufferstat(3 DOWNTO 2) <= rd_out_rxd(46 DOWNTO 45);
   
   -- pipedatavalid; - UPDATE
--   pipedatavalid <= hs_out_rxvalid;		-- rd_out_rxvalid; pi_out_rxvalid;
   
   -- pipeelecidle;
   pipeelecidle <= hs_out_rxelecidle;		-- pi_out_rxelecidle;
   
   -- pipephydonestatus; - UPDATE
--   pipephydonestatus <= hs_out_phystatus;	-- rd_out_phystatus; pi_out_phystatus;
   
   -- pipestatus; 3  - UPDATE
--   pipestatus <= hs_out_rxstatus_ch;		-- rd_out_rxstatus; pi_out_rxstatus
   
   -- pipestatetransdoneout
   pipestatetransdoneout <= pi_out_sim_state_transition_done;
   
   -- rdalign;
   rdalign <= rd_out_rd_align;
   
   -- revparallelfdbkdata;        
   revparallelfdbkdata <= rd_out_rev_loop_data;
   
   -- rlv; 
   rlv <= rd_out_rlv_lt;
   
   -- rmfifoalmostempty;
   rmfifoalmostempty <= rd_out_almost_mt_rmf;
   
   -- rmfifoalmostfull;
   rmfifoalmostfull <= rd_out_almost_fl_rmf;
   
   -- rmfifodatadeleted - 4;  
   PROCESS (rd_out_rxd(13), rd_out_rxd(29), rd_out_rxd(45), rd_out_rxd(61))
VARIABLE  txt : LINE;
 variable i : integer;
   BEGIN
      IF (cram_rpma_doublewidth_rx = '0' AND cram_rdwidth_rx = '1') THEN
 i := 0;
         while ((i <  4) AND (i < 2) ) LOOP
            rmfifodatadeleted_reg(i) <= rd_out_rxd(13 + 32 * i);
 i := i + 1;
         END LOOP;
      ELSE
         FOR i IN 0 TO 3 LOOP
            rmfifodatadeleted_reg(i) <= rd_out_rxd(13 + 16 * i);
         END LOOP;
      END IF;
   END PROCESS;
   
   
   -- rmfifodatainserted - 4;  
   PROCESS (rd_out_rxd(14), rd_out_rxd(30), rd_out_rxd(46), rd_out_rxd(62))
VARIABLE  txt : LINE;
 variable i : integer;
   BEGIN
      IF (cram_rpma_doublewidth_rx = '0' AND cram_rdwidth_rx = '1') THEN
 i := 0;
         while ((i <  4) AND (i < 2) ) LOOP
            rmfifodatainserted_reg(i) <= rd_out_rxd(14 + 32 * i);
 i := i + 1;
         END LOOP;
      ELSE
         FOR i IN 0 TO 3 LOOP
            rmfifodatainserted_reg(i) <= rd_out_rxd(14 + 16 * i);
         END LOOP;
      END IF;
   END PROCESS;
   
   
   -- rmfifoempty;
   rmfifoempty <= rd_out_empty_rmf;
   
   -- rmfifofull;
   rmfifofull <= rd_out_full_rmf;
   
   -- runningdisp - 4;  
   PROCESS (rd_out_rxd(15), rd_out_rxd(31), rd_out_rxd(47), rd_out_rxd(63))
VARIABLE  txt : LINE;
 variable i : integer;
   BEGIN
      IF (cram_rpma_doublewidth_rx = '0' AND cram_rdwidth_rx = '1') THEN
 i := 0;
         while ((i <  4) AND (i < 2) ) LOOP
            runningdisp_reg(i) <= rd_out_rxd(15 + 32 * i);
 i := i + 1;
         END LOOP;
      ELSE
         FOR i IN 0 TO 3 LOOP
            runningdisp_reg(i) <= rd_out_rxd(15 + 16 * i);
         END LOOP;
      END IF;
   END PROCESS;
   
   
   -- signaldetect;
   signaldetect <= rd_out_signal_detect_out;
   
   -- syncstatus;
   PROCESS (rd_out_rxd(10), rd_out_rxd(26), rd_out_rxd(42), rd_out_rxd(58))
VARIABLE  txt : LINE;
 variable i : integer;
   BEGIN
      IF (cram_rpma_doublewidth_rx = '0' AND cram_rdwidth_rx = '1') THEN
 i := 0;
         while ((i <  4) AND (i < 2) ) LOOP
            syncstatus_reg(i) <= rd_out_rxd(10 + 32 * i);
 i := i + 1;
         END LOOP;
      ELSE
         FOR i IN 0 TO 3 LOOP
            syncstatus_reg(i) <= rd_out_rxd(10 + 16 * i);
         END LOOP;
      END IF;
   END PROCESS;
   
   
   -- syncstatusdeskew;
   syncstatusdeskew <= rd_out_sync_status;
   
   -- xgmctrldet;
   xgmctrldet <= rd_out_dec_ctl;
   
   -- xgmdataout; - 8
   xgmdataout <= rd_out_dec_data;
   
   -- xgmdatavalid;
   xgmdatavalid <= rd_out_dec_data_valid;
   
   -- xgmrunningdisp;
   xgmrunningdisp <= rd_out_running_disp(0);
   
   --///////////////////////////////////////////////////////////////////////////
   -- simulation only - pass through from ch0 to CMU -------------------------//
   --///////////////////////////////////////////////////////////////////////////
   coreclkout <= coreclk_in;
   phfiforesetout <= phfiforeset;
   phfifowrdisableout <= phfifowrdisable_in;
   
   autospdrateswitchout <= rd_out_pcie_switch;		-- feed to rx_cdr and tx_clk_divider?
   autospdspdchgout <= rd_out_speed_change_out_pipe;		-- speed_chang_out_pipe
   bitslipboundaryselectout <= rd_out_wa_boundary;		-- wa_boundary
   cdrctrlearlyeios <= rd_out_early_eios;		-- Asserted when K_I or K
   cdrctrllocktorefclkout <= rd_out_ltr;		-- Force CDR(RX PLL) to LTR.
   hipdataout <= hs_out_hip_rxd_ch;		-- hip_rxd_ch(8:0)
   
   -- corresponding soft signal: replacing prefix hip by pipe
   hipdatavalid <= hs_out_hip_rxvalid;		-- hip_rxvalid
   hipelecidle <= hs_out_hip_rxelecidle;		-- hip_rxelecidle
   hipphydonestatus <= hs_out_hip_phystatus;		-- hip_phystatus
   hipstatus <= hs_out_hip_rxstatus_ch;		-- hip_rxstatus_ch(2:0)
   
   iqpphfifobyteselout <= rd_out_rx_we_out_pipe;		-- rx_we_out_pipe
   iqpphfifoptrsresetout <= rd_out_reset_pc_ptrs_out_pipe;		-- reset_pc_pters_out_pipe
   iqpphfifordenableout <= rd_out_rd_enable_out_pipe;		-- rd_enable_pipe_out
   iqpphfifowrclkout <= rd_out_rx_div2_sync_out_pipe;		-- rx_div2_sync_out_pipe
   iqpphfifowrenableout <= rd_out_wr_enable_out_pipe;		-- wr_enable_out_pipe
   
   phfifobyteserdisableout <= rd_out_dis_pc_byte;		--From Auto Speed Neg to TX
   phfifoptrsresetout <= rd_out_reset_pc_ptrs;		--From Auto Speed Neg to TX
   
   rateswitchout <= hs_out_pcs_rate;		-- rx0 feeds to CMU
   
   --///////////////////////////////////////////////////////////////////////////
   -- rx sub-block instantiation: pcs_reset ----------------------------------//
   --///////////////////////////////////////////////////////////////////////////
   
   pr_in_hard_reset <= '1' WHEN (quadreset_in = '1') ELSE		-- from top
                       '0';
   pr_in_clk_2_b <= rd_out_clk_2_b;		--  
   pr_in_refclk_b_in <= '0';		-- tx only
   pr_in_scan_mode <= '0';
   pr_in_rxpcs_rst <= '1' WHEN (digitalreset_in = '1') ELSE		-- from top 
                      '0';
   pr_in_txpcs_rst <= '0';		-- for tx side
   
   
   
   mrx_pcs_reset_1 : stratixiv_hssi_pcs_reset
      PORT MAP (
         hard_reset   => pr_in_hard_reset,
         clk_2_b      => pr_in_clk_2_b,
         refclk_b_in  => pr_in_refclk_b_in,
         scan_mode    => pr_in_scan_mode,
         rxpcs_rst    => pr_in_rxpcs_rst,
         txpcs_rst    => pr_in_txpcs_rst,
         rxrst_int    => pr_out_rxrst_int,
         txrst_int    => pr_out_txrst_int
      );
   
   --///////////////////////////////////////////////////////////////////////////
   -- rx sub-block instantiation: chnl_hip_support ---------------------------//
   --///////////////////////////////////////////////////////////////////////////
   
   hs_in_eidleinfersel_ch <= "000"; -- elecidleinfersel_in;
   hs_in_hip_eidleinfersel_ch <= "000"; -- hipelecidleinfersel_in;
   hs_in_hip_powerdown_ch <= hippowerdown_in;
   hs_in_hip_rate <= hiprateswitch_in;
   hs_in_hip_rxpolarity <= hip8b10binvpolarity_in;
   hs_in_hip_txd_ch <= "ZZZZZZZZZZ";
   hs_in_hip_txdeemph <= 'Z';
   hs_in_hip_txdetectrxloopback <= 'Z';
   hs_in_hip_txelecidle <= 'Z';
   hs_in_hip_txmargin_ch <= "00Z";
   hs_in_pcs_phystatus <= rd_out_phystatus;
   hs_in_pcs_rxd_ch <= rd_out_rxd(8 DOWNTO 0);
   hs_in_pcs_rxelecidle <= pi_out_rxelecidle;
   hs_in_pcs_rxstatus_ch <= rd_out_rxstatus;
   hs_in_pcs_rxvalid <= rd_out_rxvalid;
   hs_in_powerdown_ch <= powerdn_in;		-- pipepowerdown_in;
   hs_in_rate <= rateswitch_in;
   hs_in_rhip_ena <= cram_rhip_ena;
   hs_in_rxpolarity <= pipe8b10binvpolarity_in;		-- fine !RTL
   hs_in_txd_ch <= "ZZZZZZZZZZZ";
   hs_in_txdeemph <= 'Z';
   hs_in_txdetectrxloopback <= 'Z';
   hs_in_txmargin_ch <= "ZZZ";
   hs_in_txpma_local_clk <= 'Z';
   
   mrx_hs : stratixiv_hssi_digi_chnl_hip_spt
      PORT MAP (
         
         eidleinfersel_ch        => hs_in_eidleinfersel_ch,
         hip_eidleinfersel_ch    => hs_in_hip_eidleinfersel_ch,
         hip_powerdown_ch        => hs_in_hip_powerdown_ch,
         hip_rate                => hs_in_hip_rate,
         hip_rxpolarity          => hs_in_hip_rxpolarity,
         hip_txd_ch              => hs_in_hip_txd_ch,
         hip_txdeemph            => hs_in_hip_txdeemph,
         hip_txdetectrxloopback  => hs_in_hip_txdetectrxloopback,
         hip_txelecidle          => hs_in_hip_txelecidle,
         hip_txmargin_ch         => hs_in_hip_txmargin_ch,
         pcs_phystatus           => hs_in_pcs_phystatus,
         pcs_rxd_ch              => hs_in_pcs_rxd_ch,
         pcs_rxelecidle          => hs_in_pcs_rxelecidle,
         pcs_rxstatus_ch         => hs_in_pcs_rxstatus_ch,
         pcs_rxvalid             => hs_in_pcs_rxvalid,
         powerdown_ch            => hs_in_powerdown_ch,
         rate                    => hs_in_rate,
         rhip_ena                => hs_in_rhip_ena,
         rxpolarity              => hs_in_rxpolarity,
         txd_ch                  => hs_in_txd_ch,
         txdeemph                => hs_in_txdeemph,
         txdetectrxloopback      => hs_in_txdetectrxloopback,
         txmargin_ch             => hs_in_txmargin_ch,
         txpma_local_clk         => hs_in_txpma_local_clk,
         
         hip_phystatus           => hs_out_hip_phystatus,
         hip_rxd_ch              => hs_out_hip_rxd_ch,
         hip_rxelecidle          => hs_out_hip_rxelecidle,
         hip_rxstatus_ch         => hs_out_hip_rxstatus_ch,
         hip_rxvalid             => hs_out_hip_rxvalid,
         hip_tx_clk              => hs_out_hip_tx_clk,
         pcs_eidleinfersel_ch    => hs_out_pcs_eidleinfersel_ch,
         pcs_powerdown_ch        => hs_out_pcs_powerdown_ch,
         pcs_rate                => hs_out_pcs_rate,
         pcs_rxpolarity          => hs_out_pcs_rxpolarity,
         pcs_txd_ch              => hs_out_pcs_txd_ch,
         pcs_txdeemph            => hs_out_pcs_txdeemph,
         pcs_txdetectrxloopback  => hs_out_pcs_txdetectrxloopback,
         pcs_txmargin_ch         => hs_out_pcs_txmargin_ch,
         phystatus               => hs_out_phystatus,
         rxd_ch                  => hs_out_rxd_ch,
         rxelecidle              => hs_out_rxelecidle,
         rxstatus_ch             => hs_out_rxstatus_ch,
         rxvalid                 => hs_out_rxvalid
      );
   
   --///////////////////////////////////////////////////////////////////////////
   -- tx sub-block instantiation: pipe_interface -----------------------------//
   --///////////////////////////////////////////////////////////////////////////
   
   --assign  pi_in_pipe_rx_clk = rd_out_rx_pipe_clk;
   pi_in_pipe_rx_clk <= '0' WHEN (cram_rrx_pipe_enable = '0') ELSE
                        rd_out_rx_pipe_clk;
   pi_in_pipe_tx_clk <= '0';
   pi_in_polinv_rx <= '1' WHEN (invpol_in = '1') ELSE		-- from top
                      '0';
   pi_in_power_state_transition_done <= '0';		-- grounded in rtl - quad_top
   pi_in_power_state_transition_done_ena <= '0';		-- grounded in rtl - digi_chnl
   pi_in_powerdown <= pipepowerdown_in;		-- from top - tx_digi
   pi_in_refclk_b <= '0';		-- tx pipe
   pi_in_refclk_b_reset <= '0';		-- tx pipe
   pi_in_revloopback <= '0';		-- tx pipe
   pi_in_rx_detect_valid <= rxdetectvalid_in;		-- from top - TX_PMA  
   pi_in_rx_found <= rxfound_in(0);		-- from top - TX_PMA
   pi_in_rx_pipe_reset <= rd_out_rx_pipe_soft_reset;
   pi_in_rxbeacon <= '0';		-- grounded in rtl - quad_top
   --UPDATE
   pi_in_rxd <= rd_out_pipe_data;		-- rd_out_rxd; -- 64 bits
   --UPDATE
   pi_in_rxelectricalidle <= rd_out_rxelecidle_int;		-- ~pma_out_sigdet;
   pi_in_rxpolarity <= '1' WHEN (pipe8b10binvpolarity_in = '1') ELSE		-- from top
                       '0';
   pi_in_tx_elec_idle_comp <= '0';		-- tx pipe
   pi_in_tx_pipe_reset <= '0';		-- tx pipe
   pi_in_txcompliance <= '0';		-- tx pipe
   pi_in_txd_ch <= "00000000000000000000000000000000000000000000";		-- tx pipe - 44 bits
   pi_in_txdetectrxloopback <= '0';		-- tx pipe
   pi_in_txelecidle <= '0';		-- tx pipe
   
   pi_in_powerstatein <= pipepowerstate_in;		-- from top - new by shawn
   pi_in_txdetectrxin <= rxfound_in(1);		-- from top of tx_pipe - new by shawn
   
   -- stratixiv new input interfaces - ww26.5
   pi_in_speed_change <= rd_out_speed_change;
   pi_in_txdeemph <= '0';		-- tx_only
   pi_in_txmargin <= "000";		-- tx only
   pi_in_txswing <= '0';		-- tx only
   
   -- ww47 new input interfaces
   pi_in_speed_change_centrl <= autospdxnspdchg_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));		-- like other fifo bundle
   pi_in_speed_change_quad_up <= autospdxnspdchg_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));		--
   pi_in_speed_change_quad_down <= autospdxnspdchg_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));		-- 
   
   -- ww25.2008
   pi_in_sigdetni <= signaldetected_in;

   -- stratixiv new cram - ww26.5
   tmp_cram_rtx_elec_idle_delay <= "000";		-- tx_only
   tmp_cram_rtxswing_sel_ena <= '0';		-- tx_only
   --	[2:0]	rtx_elec_idle_delay;           -- tx_only
   --          rtxswing_sel_ena;              -- tx_only
   --          rind_error_reporting;          -- y
   --          rphystatus_delay;              -- y
   
   rx_pipe_interface_top_1 : stratixiv_hssi_q_pipe_interface_top
      PORT MAP (
         phystatus                        => pi_out_phystatus,
         pipe_rx_clk                      => pi_in_pipe_rx_clk,
         pipe_tx_clk                      => pi_in_pipe_tx_clk,
         polinv_rx                        => pi_in_polinv_rx,
         polinv_rx_int                    => pi_out_polinv_rx_int,
         power_state_transition_done      => pi_in_power_state_transition_done,
         power_state_transition_done_ena  => pi_in_power_state_transition_done_ena,
         powerdown                        => pi_in_powerdown,
         powerstate                       => pi_out_powerstate,
         rclkcmpinsertpad                 => cram_rclkcmpinsertpad,
         refclk_b                         => pi_in_refclk_b,
         refclk_b_reset                   => pi_in_refclk_b_reset,
         rev_loopbk                       => pi_out_rev_loopbk,
         revloopback                      => pi_in_revloopback,
         rphystatus_rst_toggle            => cram_rphystatus_rst_toggle,
         rrdwidth_rx                      => cram_rdwidth_rx,
         rrx_detect_bypass                => cram_rrx_detect_bypass,
         rrx_pipe_enable                  => cram_rrx_pipe_enable,
         --	.rtx_elec_idle_delay             (cram_rtx_elec_idle_delay),
         rtx_pipe_enable                  => cram_rtx_pipe_enable,
         rx_detect_valid                  => pi_in_rx_detect_valid,
         rx_found                         => pi_in_rx_found,
         rx_pipe_reset                    => pi_in_rx_pipe_reset,
         rxd                              => pi_in_rxd,
         rxd_ch                           => pi_out_rxd_ch,
         rxelecidle                       => pi_out_rxelecidle,
         rxelectricalidle                 => pi_in_rxelectricalidle,
         rxpolarity                       => pi_in_rxpolarity,
         rxstatus                         => pi_out_rxstatus,
         rxvalid                          => pi_out_rxvalid,
         tx_elec_idle                     => pi_out_tx_elec_idle,
         tx_elec_idle_comp                => pi_in_tx_elec_idle_comp,
         tx_pipe_reset                    => pi_in_tx_pipe_reset,
         txd                              => pi_out_txd,
         txd_ch                           => pi_in_txd_ch,
         txdetectrx                       => pi_out_txdetectrx,
         txdetectrxloopback               => pi_in_txdetectrxloopback,
         txelecidle                       => pi_in_txelecidle,
         txdetectrxin                     => pi_in_txdetectrxin,		-- shawn
         powerstatein                     => pi_in_powerstatein,		-- shawn
         use_powerstatein                 => '1',
         -- shawn
         
         -- STRATIXIV new interfaces    
         speed_change                     => pi_in_speed_change,
         txdeemph                         => pi_in_txdeemph,
         txmargin                         => pi_in_txmargin,
         txswing                          => pi_in_txswing,
         
         rtx_elec_idle_delay              => tmp_cram_rtx_elec_idle_delay,
         rtxswing_sel_ena                 => tmp_cram_rtxswing_sel_ena,
         rind_error_reporting             => cram_rind_error_reporting,
         rphystatus_delay                 => cram_rphystatus_delay,
         
         txdeemph_int                     => pi_out_txdeemph_int,
         txmargin_int                     => pi_out_txmargin_int,
         txswing_int                      => pi_out_txswing_int,
         
         -- ww25_2008
         sigdetni                         => pi_in_sigdetni,
    
         -- WW47
         rindv_rx                         => cram_rindv_rx,
         rmaster_rx                       => cram_rmaster_rx,
         rmaster_up_rx                    => cram_rmaster_up_rx,
         speed_change_centrl              => pi_in_speed_change_centrl,
         speed_change_quad_up             => pi_in_speed_change_quad_up,
         speed_change_quad_down           => pi_in_speed_change_quad_down
      );
   
   --///////////////////////////////////////////////////////////////////////////
   -- rx sub-block instantiation: pipe_interface -----------------------------//
   --///////////////////////////////////////////////////////////////////////////
   rd_in_a1a2_size <= '1' WHEN (a1a2size_in = '1') ELSE		-- from top        
                      '0';
   rd_in_align_status <= alignstatus_in;		-- from top   
   rd_in_align_status_sync_0 <= alignstatussync_in;		-- from top     
   rd_in_align_status_sync_2 <= alignstatussync_in;		-- from top - ideally from alignstatusout of channel2
   rd_in_bitloc_rev_en <= '1' WHEN (revbitorderwa_in = '1') ELSE		-- from top
                          '0';
   rd_in_bitslip <= '1' WHEN (bitslip_in = '1') ELSE		-- from top          
                    '0';
   rd_in_byte_rev_en <= '1' WHEN (revbyteorderwa_in = '1') ELSE		-- from top
                        '0';
   rd_in_bytordpld <= '1' WHEN (enabyteord_in = '1') ELSE		-- from top
                      '0';
   --UPDATE: freqdet moved to RXPMA. 
   rd_in_clklow <= '0';		-- VCO divided clk from CDR to freqdet
   rd_in_cmpfifourst <= '1' WHEN (rmfiforeset_in = '1') ELSE		-- from top
                        '0';
   rd_in_en_dskw_gp <= enabledeskew_in;		-- from top - dskw_sm to dskw_fifo    
   rd_in_en_dskw_qd <= enabledeskew_in;
   rd_in_encdt <= '1' WHEN (enapatternalign_in = '1') ELSE		-- from top            
                  '0';
   rd_in_encoder_testbus <= "0000000000";		-- 10 bit
   rd_in_fifo_rd_in_comp_0 <= fifordin_in;		-- from top  
   rd_in_fifo_rd_in_comp_2 <= fifordin_in;		-- from top  - ideally from fifordout of channel2  
   rd_in_fifo_rst_rd_gp <= fiforesetrd_in;		-- from top - dskw_sm to dskw_fifo
   rd_in_fifo_rst_rd_qd <= fiforesetrd_in;
   --UPDATE: freqdet moved to RXPMA. 
   rd_in_fref <= '0';		-- ref clock from CDR to freqdet
   rd_in_hard_reset <= '1' WHEN (quadreset_in = '1') ELSE		-- from top
                       '0';
   rd_in_phfifourst_rx <= '1' WHEN (phfiforeset_in = '1') ELSE		-- from top
                          '0';
   rd_in_pld_rx_clk <= coreclk;		-- coreclk_in from top
   rd_in_pma_testbus <= "00000000";		-- 8 bit
   rd_in_polinv_rx <= pi_out_polinv_rx_int;
   rd_in_pudi <= datain_in;		-- 20 bit from RX PMA             
   rd_in_rcvd_clk_pma <= recoveredclk_in;		-- from RX PMA
   rd_in_rcvd_clk0_pma <= masterclk_in;		-- from top
   rd_in_rdenable_rmf <= '0' WHEN (rmfifordena_in = '0') ELSE		-- from top         
                         '1';
   rd_in_rdenable_rx <= phfifordenable_in;		-- from top
   rd_in_refclk_pma <= refclk_in;
   rd_in_rx_control_rs <= xgmctrlin_in;		-- from top    
   rd_in_rx_data_rs <= xgmdatain_in;		-- from top - 8 bit
   --UPDATE: freqdet moved to RXPMA from top - to freqdet (hardreset) assuming active low
   rd_in_rxpma_rst <= '0';		--(analogreset_in === 1'b1) ? 1'b0 : 1'b1;    
   rd_in_rxpcs_rst <= pr_out_rxrst_int;
   rd_in_sigdetni <= signaldetected_in;
   rd_in_tx_ctrl_testbus <= "0000000000";		-- 10 bit
   rd_in_txlp20b <= parallelfdbk_in;		-- from top - 20 bit         
   rd_in_txpma_local_clk <= localrefclk_in;		-- from top
   rd_in_wrdisable_rx <= phfifowrdisable_in;		-- from top
   rd_in_wrenable_rmf <= '0' WHEN (rmfifowrena_in = '0') ELSE		-- from top         
                         '1';
   
   -- new input interfaces in STRATIXIV - ww26.5
   rd_in_eidleinfersel <= grayelecidleinferselfromtx_in; -- elecidleinfersel_in;
   rd_in_gen2ngen1 <= rateswitchisdone_in;
   rd_in_gen2ngen1_bundle <= rateswitchxndone_in;
   rd_in_phystatus_int <= pi_out_phystatus;
   rd_in_powerdown <= hs_out_pcs_powerdown_ch;
   rd_in_rxstatus_int <= pi_out_rxstatus;
   rd_in_rxvalid_int <= pi_out_rxvalid;
     
   -- WW47 input interfaces -------------------------------------------------
   rd_in_rate <= hs_out_pcs_rate;		-- rate change output from upper layers.
   -- from digi_chnl_support
   -- CDR control
   rd_in_pld_ltr <= cdrctrllocktorefcl_in;		-- PLD control of the CDR when rcdr_ctrl_en = 1'b0
   rd_in_prbs_cid_en <= prbscidenable_in;		-- PLD control of PRBS-CID enable
   
   --todo: use "select" to access the bus
   
   -- new signal inputs for bundling
   rd_in_rx_div2_sync_in_centrl <= phfifoxnwrclk_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_rx_div2_sync_in_quad_up <= phfifoxnwrclk_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_rx_div2_sync_in_quad_down <= phfifoxnwrclk_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_reset_pc_ptrs_in_centrl <= phfifoxnptrsreset_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_reset_pc_ptrs_in_quad_up <= phfifoxnptrsreset_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_reset_pc_ptrs_in_quad_down <= phfifoxnptrsreset_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_wr_enable_in_centrl <= phfifoxnwrenable_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_wr_enable_in_quad_up <= phfifoxnwrenable_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_wr_enable_in_quad_down <= phfifoxnwrenable_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_rd_enable_in_centrl <= phfifoxnrdenable_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_rd_enable_in_quad_up <= phfifoxnrdenable_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_rd_enable_in_quad_down <= phfifoxnrdenable_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_rx_we_in_centrl <= phfifoxnbytesel_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_rx_we_in_quad_up <= phfifoxnbytesel_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_rx_we_in_quad_down <= phfifoxnbytesel_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   
   -- up/down signals are in pipe_top_interface as it is the user of the signal
   -- this is needed for RD because of IQP mux
   rd_in_speed_change_in_centrl <= autospdxnspdchg_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   
   -- Bundle Mode Inputs for config_sel
   rd_in_config_sel_centrl <= autospdxnconfigsel_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_config_sel_quad_up <= autospdxnconfigsel_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   rd_in_config_sel_quad_down <= autospdxnconfigsel_in(stratixiv_tx_pcs_mphfifo_index(ph_fifo_xn_select));
   
   -- pipeline inputs for IQ bundling
   rd_in_rx_div2_sync_in_pipe_quad_up <= iqpphfifoxnwrclk_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   rd_in_rx_div2_sync_in_pipe_quad_down <= iqpphfifoxnwrclk_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   rd_in_reset_pc_ptrs_in_pipe_quad_up <= iqpphfifoxnptrsreset_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   rd_in_reset_pc_ptrs_in_pipe_quad_down <= iqpphfifoxnptrsreset_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   rd_in_wr_enable_in_pipe_quad_up <= iqpphfifoxnwrenable_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   rd_in_wr_enable_in_pipe_quad_down <= iqpphfifoxnwrenable_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   rd_in_rd_enable_in_pipe_quad_up <= iqpphfifoxnrdenable_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   rd_in_rd_enable_in_pipe_quad_down <= iqpphfifoxnrdenable_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   rd_in_rx_we_in_pipe_quad_up <= iqpphfifoxnbytesel_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   rd_in_rx_we_in_pipe_quad_down <= iqpphfifoxnbytesel_in(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   rd_in_speed_change_in_pipe_quad_up <= iqpautospdxnspgchg(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   rd_in_speed_change_in_pipe_quad_down <= iqpautospdxnspgchg(stratixiv_tx_pcs_miqp_phfifo_index(ph_fifo_xn_select));
   
   -- WW12 input interfaces -------------------------------------------------
   rd_in_pipe_loopbk <= pipeenrevparallellpbkfromtx_in;		-- ww12 mega todo 
   
   -- XAUI related - to revisit if need to
   rd_in_cg_comp_rd_d_ch0 <= rd_out_cg_comp_rd_d_out;
   rd_in_cg_comp_rd_d_ch1 <= rd_out_cg_comp_rd_d_out;
   rd_in_cg_comp_rd_d_ch2 <= rd_out_cg_comp_rd_d_out;
   rd_in_cg_comp_rd_d_ch3 <= rd_out_cg_comp_rd_d_out;
   rd_in_cg_comp_wr_ch0 <= rd_out_cg_comp_wr_out;
   rd_in_cg_comp_wr_ch1 <= rd_out_cg_comp_wr_out;
   rd_in_cg_comp_wr_ch2 <= rd_out_cg_comp_wr_out;
   rd_in_cg_comp_wr_ch3 <= rd_out_cg_comp_wr_out;
   
   -- XAUI related channel 0 to rest channels in ICD
   -- in Quartus sim: using its own ptrs
   
   rd_in_del_cond_met_0 <= rd_out_del_cond_met_out;
   rd_in_fifo_ovr_0 <= rd_out_fifo_ovr_out;
   rd_in_latency_comp_0 <= rd_out_latency_comp_out;
   rd_in_insert_incomplete_0 <= rd_out_insert_incomplete_out;
   
   -- SW way
   rd_out_rx_div2_sync_out_pipe <= rd_out_rx_div2_sync_out_pipe_up WHEN (cram_rmaster_up_rx = '0') ELSE
                                   rd_out_rx_div2_sync_out_pipe_down;
   rd_out_rx_we_out_pipe <= rd_out_rx_we_out_pipe_up WHEN (cram_rmaster_up_rx = '0') ELSE
                            rd_out_rx_we_out_pipe_down;
   rd_out_wr_enable_out_pipe <= rd_out_wr_enable_out_pipe_up WHEN (cram_rmaster_up_rx = '0') ELSE
                                rd_out_wr_enable_out_pipe_down;
   rd_out_rd_enable_out_pipe <= rd_out_rd_enable_out_pipe_up WHEN (cram_rmaster_up_rx = '0') ELSE
                                rd_out_rd_enable_out_pipe_down;
   rd_out_reset_pc_ptrs_out_pipe <= rd_out_reset_pc_ptrs_out_pipe_up WHEN (cram_rmaster_up_rx = '0') ELSE
                                    rd_out_reset_pc_ptrs_out_pipe_down;
   rd_out_speed_change_out_pipe <= rd_out_speed_change_out_pipe_up WHEN (cram_rmaster_up_rx = '0') ELSE
                                   rd_out_speed_change_out_pipe_down;
   
   rd_in_tx_div2_sync_out_pipe_up <= 'Z';		--only impact test_bus from corresponding tx channels output *_out_pipe
   rd_in_fifo_select_out_pipe_up <= 'Z';		--only impact test_bus from corresponding tx channels output *_out_pipe
   rd_in_tx_wr_enable_out_pipe_up <= 'Z';		--only impact test_bus from corresponding tx channels output *_out_pipe
   rd_in_tx_rd_enable_out_pipe_up <= 'Z';		--only impact test_bus from corresponding tx channels output *_out_pipe
   rd_in_tx_div2_sync_out_pipe_down <= 'Z';		--only impact test_bus from corresponding tx channels output *_out_pipe
   rd_in_fifo_select_out_pipe_down <= 'Z';		--only impact test_bus from corresponding tx channels output *_out_pipe
   rd_in_tx_wr_enable_out_pipe_down <= 'Z';		--only impact test_bus from corresponding tx channels output *_out_pipe
   rd_in_tx_rd_enable_out_pipe_down <= 'Z';		--only impact test_bus from corresponding tx channels output *_out_pipe
   
   -- WW25.2008 input interfaces -----------------------------------------------
   rd_in_pcs_wrapback_in <= "0000000001000000000000000000000000000000000000000000000000000000000000";
   
   
   digi_rx_1 : stratixiv_hssi_rx_digi
      PORT MAP (
         rxpcs_rst                        => rd_in_rxpcs_rst,
         hard_reset                       => rd_in_hard_reset,
         rxpma_rst                        => rd_in_rxpma_rst,
         cmpfifourst                      => rd_in_cmpfifourst,
         phfifourst_rx                    => rd_in_phfifourst_rx,
         rphfifourstrx                    => cram_rphfifourstrx,
         scan_mode                        => cram_scan_mode,
         encdt                            => rd_in_encdt,
         a1a2_size                        => rd_in_a1a2_size,
         bitslip                          => rd_in_bitslip,
         rdenable_rmf                     => rd_in_rdenable_rmf,
         wrenable_rmf                     => rd_in_wrenable_rmf,
         pld_rx_clk                       => rd_in_pld_rx_clk,
         polinv_rx                        => rd_in_polinv_rx,
         bitloc_rev_en                    => rd_in_bitloc_rev_en,
         byte_rev_en                      => rd_in_byte_rev_en,
         rcvd_clk_pma                     => rd_in_rcvd_clk_pma,
         pudi                             => rd_in_pudi,
         sigdetni                         => rd_in_sigdetni,
         fifo_rst_rd_qd                   => rd_in_fifo_rst_rd_qd,
         fifo_rst_rd_gp                   => rd_in_fifo_rst_rd_gp,
         en_dskw_qd                       => rd_in_en_dskw_qd,
         en_dskw_gp                       => rd_in_en_dskw_gp,
         is_lane0                         => cram_is_lane0,
         align_status                     => rd_in_align_status,
         align_status_sync_0              => rd_in_align_status_sync_0,
         align_status_sync_2              => rd_in_align_status_sync_2,
         rx_data_rs                       => rd_in_rx_data_rs,
         rx_control_rs                    => rd_in_rx_control_rs,
         rcvd_clk0_pma                    => rd_in_rcvd_clk0_pma,
         fifo_rd_in_comp_0                => rd_in_fifo_rd_in_comp_0,
         fifo_rd_in_comp_2                => rd_in_fifo_rd_in_comp_2,
         txlp20b                          => rd_in_txlp20b,
         refclk_pma                       => rd_in_refclk_pma,
         tx_pma_clk                       => rd_in_txpma_local_clk,
         fref                             => rd_in_fref,
         clklow                           => rd_in_clklow,
         bytordpld                        => rd_in_bytordpld,
         wrdisable_rx                     => rd_in_wrdisable_rx,
         rdenable_rx                      => rd_in_rdenable_rx,
         pma_testbus                      => rd_in_pma_testbus,
         encoder_testbus                  => rd_in_encoder_testbus,
         tx_ctrl_testbus                  => rd_in_tx_ctrl_testbus,
         fifo_rd_out_comp                 => rd_out_fifo_rd_out_comp,
         rxd                              => rd_out_rxd,
         rev_loop_data                    => rd_out_rev_loop_data,
         rx_clk                           => rd_out_rx_clk,
         bisterr                          => rd_out_bisterr,
         cg_comma                         => rd_out_cg_comma,
         clk_2_b                          => rd_out_clk_2_b,
         rcvd_clk_pma_b                   => rd_out_rcvd_clk_pma_b,
         sync_status                      => rd_out_sync_status,
         align_status_sync                => rd_out_align_status_sync,
         dec_data_valid                   => rd_out_dec_data_valid,
         dec_data                         => rd_out_dec_data,
         dec_ctl                          => rd_out_dec_ctl,
         running_disp                     => rd_out_running_disp,
         selftest_done                    => rd_out_selftest_done,
         selftest_err                     => rd_out_selftest_err,
         err_data                         => rd_out_err_data,
         err_ctl                          => rd_out_err_ctl,
         prbs_done                        => rd_out_prbs_done,
         prbs_err_lt                      => rd_out_prbs_err_lt,
         signal_detect_out                => rd_out_signal_detect_out,
         align_det_sync                   => rd_out_align_det_sync,
         rd_align                         => rd_out_rd_align,
         bistdone                         => rd_out_bistdone,
         rlv                              => rd_out_rlv,
         rlv_lt                           => rd_out_rlv_lt,
         almost_fl_rmf                    => rd_out_almost_fl_rmf,
         full_rmf                         => rd_out_full_rmf,
         almost_mt_rmf                    => rd_out_almost_mt_rmf,
         empty_rmf                        => rd_out_empty_rmf,
         freq_lock                        => rd_out_freq_lock,
         full_rx                          => rd_out_full_rx,
         empty_rx                         => rd_out_empty_rx,
         a1a2_k1k2_flag                   => rd_out_a1a2_k1k2_flag,
         byteord_flag                     => rd_out_byteord_flag,
         rx_pipe_clk                      => rd_out_rx_pipe_clk,
         chnl_test_bus_out                => rd_out_chnl_test_bus_out,
         rx_pipe_soft_reset               => rd_out_rx_pipe_soft_reset,
         rskpsetbased                     => cram_rskpsetbased,
         rtruebac2bac                     => cram_rtruebac2bac,
         rcmpfifourst                     => cram_rcmpfifourst,
         rcomp_size                       => cram_rcomp_size,
         rcomp_pat                        => cram_rcomp_pat,
         rrundisp                         => cram_rrundisp,
         rib_inv_cd                       => cram_rib_inv_cd,
         rrlv_en                          => cram_rrlv_en,
         rsync_sm_dis                     => cram_rsync_sm_dis,
         rautobtalg_dis                   => cram_rautobtalg_dis,
         rdis_rx_disp                     => cram_rdis_rx_disp,
         rmatchen                         => cram_rmatchen,
         rgenericfifo                     => cram_rgenericfifo,
         rendec_rx                        => cram_rendec_rx,
         rdwidth_rx                       => cram_rdwidth_rx,
         rlp20ben                         => cram_rlp20ben,
         rrxfifo_dis                      => cram_rrxfifo_dis,
         rpmadwidth_rx                    => cram_rpmadwidth_rx,
         rpma_doublewidth_rx              => cram_rpma_doublewidth_rx,
         renumber                         => cram_renumber,
         rknumber                         => cram_rknumber,
         renpolinv_rx                     => cram_renpolinv_rx,
         rgnumber                         => cram_rgnumber,
         rclkcmpsqmd                      => cram_rclkcmpsqmd,
         rclkcmpsq1p                      => cram_rclkcmpsq1p,
         rclkcmpsq1n                      => cram_rclkcmpsq1n,
         rosnumber                        => cram_rosnumber,
         rosbased                         => cram_rosbased,
         rkchar                           => cram_rkchar,
         rcascaded_8b10b_en_rx            => cram_rcascaded_8b10b_en_rx,
         resync_badcg_en                  => cram_resync_badcg_en,
         rencdt_rising                    => cram_rencdt_rising,
         rcomp_pat_porn                   => cram_rcomp_pat_porn,
         rprbsen_rx                       => cram_rprbsen_rx,
         rprbs_clr_rslt_rx                => cram_rprbs_clr_rslt_rx,
         rbisten_rx                       => cram_rbisten_rx,
         rbist_clr_rx                     => cram_rbist_clr_rx,
         rwa_6g_en                        => cram_rwa_6g_en,
         rbytord_2sym_en                  => cram_rbytord_2sym_en,
         rbysync_polinv_en                => cram_rbysync_polinv_en,
         rbitloc_rev_en                   => cram_rbitloc_rev_en,
         rbyte_rev_en                     => cram_rbyte_rev_en,
         rbyteorden                       => cram_rbyteorden,
         rbytordplden                     => cram_rbytordplden,
         rphfifopldenrx                   => cram_rphfifopldenrx,
         rautoinsdis                      => cram_rautoinsdis,
         rppmsel                          => cram_rppmsel,
         rforce0_freqdet                  => cram_rforce0_freqdet,
         rforce1_freqdet                  => cram_rforce1_freqdet,
         rbytordpat                       => cram_rbytordpat,
         rbytordpad                       => cram_rbytordpad,
         rforce_sig_det_pcs               => cram_rforce_sig_det_pcs,
         rfreerun_rx                      => cram_rfreerun_rx,
         rrcvd_clk_sel                    => cram_rrcvd_clk_sel,
         rclk_1_sel                       => cram_rclk_1_sel,
         rclk_2_sel                       => cram_rclk_2_sel,
         rrx_rd_clk_sel                   => cram_rrx_rd_clk_sel,
         rall_one_dect_only               => cram_rall_one_dect_only,
         rtest_bus_sel                    => cram_rtest_bus_sel,
         r8b10b_dec_ibm_en                => cram_r8b10b_dec_ibm_en,
         rrxfifo_lowlatency_en            => cram_rrxfifo_lowlatency_en,
         rppm_cnt_reset                   => cram_rppm_cnt_reset,
         sel_gp_md                        => cram_sel_gp_md,
         rclkcmpinsertpad                 => cram_rclkcmpinsertpad,
         rindv_rx                         => cram_rindv_rx,
         dskwclksel                       => cram_dskwclksel,
         rdskposdisp                      => cram_rdskposdisp,
         rdskchrp                         => cram_rdskchrp,
         rendec_data_sel_rx               => cram_rendec_data_sel_rx,
         rprbs_sel                        => cram_rprbs_sel,
         rbist_sel                        => cram_rbist_sel,
         rcxpat_chnl_en                   => cram_rcxpat_chnl_en,
         
         -- new STRATIXIV interfaces ----------------------------------------
         eidleinfersel                    => rd_in_eidleinfersel,
         gen2ngen1                        => rd_in_gen2ngen1,
         gen2ngen1_bundle                 => rd_in_gen2ngen1_bundle,
         phystatus_int                    => rd_in_phystatus_int,
         powerdown                        => rd_in_powerdown,
         rxstatus_int                     => rd_in_rxstatus_int,
         rxvalid_int                      => rd_in_rxvalid_int,
         
         rclkcmp_pipe_en                  => cram_rclkcmp_pipe_en,
         rrxpcsclkpwdn                    => cram_rrxpcsclkpwdn,
         rstart_threshold                 => cram_rstart_threshold,
         rins_threshold                   => cram_rins_threshold,
         rdel_threshold                   => cram_rdel_threshold,
         rfull_threshold                  => cram_rfull_threshold,
         rempty_threshold                 => cram_rempty_threshold,
         rinvalid_code_err_only           => cram_rinvalid_code_err_only,
         rrxpcsbypass_en                  => cram_rrxpcsbypass_en,
         rauto_speed_ena                  => cram_rauto_speed_ena,
         rfreq_sel                        => cram_rfreq_sel,
         rpma_done_count                  => cram_rpma_done_count,
         reidleinferenable                => cram_reidleinferenable,
         reidle_com_detect                => cram_reidle_com_detect,
         
         phystatus                        => rd_out_phystatus,
         pipe_data                        => rd_out_pipe_data,
         soft_reset_rclk1                 => rd_out_soft_reset_rclk1,
         speed_change                     => rd_out_speed_change,
         rxelecidle_int                   => rd_out_rxelecidle_int,
         rxstatus                         => rd_out_rxstatus,
         rxvalid                          => rd_out_rxvalid,
         
         -- ww47 input port interfaces --------------------------------
         config_sel_centrl                => rd_in_config_sel_centrl,
         config_sel_quad_down             => rd_in_config_sel_quad_down,
         config_sel_quad_up               => rd_in_config_sel_quad_up,
         pld_ltr                          => rd_in_pld_ltr,
         prbs_cid_en                      => rd_in_prbs_cid_en,
         rate                             => rd_in_rate,
         rd_enable_in_centrl              => rd_in_rd_enable_in_centrl,
         rd_enable_in_pipe_quad_down      => rd_in_rd_enable_in_pipe_quad_down,
         rd_enable_in_pipe_quad_up        => rd_in_rd_enable_in_pipe_quad_up,
         rd_enable_in_quad_down           => rd_in_rd_enable_in_quad_down,
         rd_enable_in_quad_up             => rd_in_rd_enable_in_quad_up,
         reset_pc_ptrs_in_centrl          => rd_in_reset_pc_ptrs_in_centrl,
         reset_pc_ptrs_in_pipe_quad_down  => rd_in_reset_pc_ptrs_in_pipe_quad_down,
         reset_pc_ptrs_in_pipe_quad_up    => rd_in_reset_pc_ptrs_in_pipe_quad_up,
         reset_pc_ptrs_in_quad_down       => rd_in_reset_pc_ptrs_in_quad_down,
         reset_pc_ptrs_in_quad_up         => rd_in_reset_pc_ptrs_in_quad_up,
         rx_div2_sync_in_centrl           => rd_in_rx_div2_sync_in_centrl,
         rx_div2_sync_in_pipe_quad_down   => rd_in_rx_div2_sync_in_pipe_quad_down,
         rx_div2_sync_in_pipe_quad_up     => rd_in_rx_div2_sync_in_pipe_quad_up,
         rx_div2_sync_in_quad_down        => rd_in_rx_div2_sync_in_quad_down,
         rx_div2_sync_in_quad_up          => rd_in_rx_div2_sync_in_quad_up,
         rx_we_in_centrl                  => rd_in_rx_we_in_centrl,
         rx_we_in_pipe_quad_down          => rd_in_rx_we_in_pipe_quad_down,
         rx_we_in_pipe_quad_up            => rd_in_rx_we_in_pipe_quad_up,
         rx_we_in_quad_down               => rd_in_rx_we_in_quad_down,
         rx_we_in_quad_up                 => rd_in_rx_we_in_quad_up,
         speed_change_in_centrl           => rd_in_speed_change_in_centrl,
         speed_change_in_pipe_quad_down   => rd_in_speed_change_in_pipe_quad_down,
         speed_change_in_pipe_quad_up     => rd_in_speed_change_in_pipe_quad_up,
         wr_enable_in_centrl              => rd_in_wr_enable_in_centrl,
         wr_enable_in_pipe_quad_down      => rd_in_wr_enable_in_pipe_quad_down,
         wr_enable_in_pipe_quad_up        => rd_in_wr_enable_in_pipe_quad_up,
         wr_enable_in_quad_down           => rd_in_wr_enable_in_quad_down,
         wr_enable_in_quad_up             => rd_in_wr_enable_in_quad_up,
         
         -- ww47 output port interfaces --------------------------------
         dis_pc_byte                      => rd_out_dis_pc_byte,
         early_eios                       => rd_out_early_eios,
         ltr                              => rd_out_ltr,
         pcie_switch                      => rd_out_pcie_switch,
         reset_pc_ptrs                    => rd_out_reset_pc_ptrs,
         wa_boundary                      => rd_out_wa_boundary,
         
         -- ww47 CRAM interfaces --------------------------------
         rauto_deassert_pc_rst_cnt        => cram_rauto_deassert_pc_rst_cnt,
         rauto_pc_en_cnt                  => cram_rauto_pc_en_cnt,
         rbytord_6g_mask_en               => cram_rbytord_6g_mask_en,
         rbytord_s2gx                     => cram_rbytord_s2gx,
         --.rbytordpat                    (cram_rbytordpat),  width change from 10 to 20
         rcdr_ctrl_en                     => cram_rcdr_ctrl_en,
         rcid_en                          => cram_rcid_en,
         rcid_len_rx                      => cram_rcid_len_rx,
         rcid_pattern_rx                  => cram_rcid_pattern_rx,
         rfts_count                       => cram_rfts_count,
         rmask_count                      => cram_rmask_count,
         rmaster_rx                       => cram_rmaster_rx,
         rmaster_up_rx                    => cram_rmaster_up_rx,
         rphfifo_regmode_rx               => cram_rphfifo_regmode_rx,
         rpipeline_bypass_rx              => cram_rpipeline_bypass_rx,
         rrxvalid_mask                    => cram_rrxvalid_mask,
         rself_sw_en_rx                   => cram_rself_sw_en_rx,
         --.rtest_bus_sel                   (cram_rtest_bus_sel), width added 1
         rwait_count                      => cram_rwait_count,
         
         -- ww12 port interfaces --------------------------------
         pipe_loopbk                      => rd_in_pipe_loopbk,
         
         -- XAUI related ports
         cg_comp_rd_d_out                 => rd_out_cg_comp_rd_d_out,
         cg_comp_wr_out                   => rd_out_cg_comp_wr_out,
         cg_comp_rd_d_ch0                 => rd_in_cg_comp_rd_d_ch0,
         cg_comp_rd_d_ch1                 => rd_in_cg_comp_rd_d_ch1,
         cg_comp_rd_d_ch2                 => rd_in_cg_comp_rd_d_ch2,
         cg_comp_rd_d_ch3                 => rd_in_cg_comp_rd_d_ch3,
         cg_comp_wr_ch0                   => rd_in_cg_comp_wr_ch0,
         cg_comp_wr_ch1                   => rd_in_cg_comp_wr_ch1,
         cg_comp_wr_ch2                   => rd_in_cg_comp_wr_ch2,
         cg_comp_wr_ch3                   => rd_in_cg_comp_wr_ch3,
         
         del_cond_met_out                 => rd_out_del_cond_met_out,
         fifo_ovr_out                     => rd_out_fifo_ovr_out,
         latency_comp_out                 => rd_out_latency_comp_out,
         insert_incomplete_out            => rd_out_insert_incomplete_out,
         del_cond_met_0                   => rd_in_del_cond_met_0,
         fifo_ovr_0                       => rd_in_fifo_ovr_0,
         latency_comp_0                   => rd_in_latency_comp_0,
         insert_incomplete_0              => rd_in_insert_incomplete_0,
         
         -- bundle ptrs in ww12 - split up/down
         rd_enable_out_pipe_up            => rd_out_rd_enable_out_pipe_up,
         reset_pc_ptrs_out_pipe_up        => rd_out_reset_pc_ptrs_out_pipe_up,
         rx_div2_sync_out_pipe_up         => rd_out_rx_div2_sync_out_pipe_up,
         rx_we_out_pipe_up                => rd_out_rx_we_out_pipe_up,
         speed_change_out_pipe_up         => rd_out_speed_change_out_pipe_up,
         wr_enable_out_pipe_up            => rd_out_wr_enable_out_pipe_up,
         
         rd_enable_out_pipe_down          => rd_out_rd_enable_out_pipe_down,
         reset_pc_ptrs_out_pipe_down      => rd_out_reset_pc_ptrs_out_pipe_down,
         rx_div2_sync_out_pipe_down       => rd_out_rx_div2_sync_out_pipe_down,
         rx_we_out_pipe_down              => rd_out_rx_we_out_pipe_down,
         speed_change_out_pipe_down       => rd_out_speed_change_out_pipe_down,
         wr_enable_out_pipe_down          => rd_out_wr_enable_out_pipe_down,
         
         -- tx to rx pipe ptr for testbus
         fifo_select_out_pipe_up          => rd_in_fifo_select_out_pipe_up,
         tx_div2_sync_out_pipe_up         => rd_in_tx_div2_sync_out_pipe_up,
         tx_rd_enable_out_pipe_up         => rd_in_tx_rd_enable_out_pipe_up,
         tx_wr_enable_out_pipe_up         => rd_in_tx_wr_enable_out_pipe_up,
         
         fifo_select_out_pipe_down        => rd_in_fifo_select_out_pipe_down,
         tx_div2_sync_out_pipe_down       => rd_in_tx_div2_sync_out_pipe_down,
         tx_rd_enable_out_pipe_down       => rd_in_tx_rd_enable_out_pipe_down,
         tx_wr_enable_out_pipe_down       => rd_in_tx_wr_enable_out_pipe_down,
         
         -- ww12 CRAM interfaces --------------------------------
         rwait_for_phfifo_cnt             => cram_rwait_for_phfifo_cnt,
         rppm_post_eidle_del              => cram_rppm_post_eidle_del,
         rppm_gen1_2xcnt_en               => cram_rppm_gen1_2xcnt_en,
         riei_eios_priority_dis           => cram_riei_eios_priority_dis,
         rgen1_sigdet_ena                 => cram_rgen1_sigdet_ena,
         
         -- ww25.2008 port interface -----------------------------
         pcs_wrapback_in                  => rd_in_pcs_wrapback_in,
    
         -- ww25.2008 CRAM interface -----------------------------
         rpcs_wrapback_en                => cram_rpcs_wrapback_en,
         rrx_pipe_enable                 => cram_rrx_pipe_enable,
         rerr_flags_sel                  => cram_rerr_flags_sel  
         
      );
   
END trans;

--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 46 mux21 24 oper_mux 5 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_dskw_sm IS 
	 PORT 
	 ( 
		 align_det_sync	:	IN  STD_LOGIC_VECTOR (7 DOWNTO 0);
		 align_status	:	OUT  STD_LOGIC;
		 clk_1	:	IN  STD_LOGIC;
		 curr_state	:	OUT  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 enable_deskew	:	OUT  STD_LOGIC;
		 fifo_reset_rd	:	OUT  STD_LOGIC;
		 octal_mode	:	IN  STD_LOGIC;
		 rd_align	:	IN  STD_LOGIC_VECTOR (7 DOWNTO 0);
		 soft_reset	:	IN  STD_LOGIC;
		 sync_status	:	IN  STD_LOGIC_VECTOR (7 DOWNTO 0)
	 ); 
 END stratixiv_hssi_dskw_sm;

 ARCHITECTURE RTL OF stratixiv_hssi_dskw_sm IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 nl0ll35	:	STD_LOGIC := '0';
	 SIGNAL	 nl0ll36	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl0ll36_w_lg_w_lg_q268w269w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0ll36_w_lg_q268w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl0lO33	:	STD_LOGIC := '0';
	 SIGNAL	 nl0lO34	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl0lO34_w_lg_w_lg_q232w233w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0lO34_w_lg_q232w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl0Oi31	:	STD_LOGIC := '0';
	 SIGNAL	 nl0Oi32	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl0Oi32_w_lg_w_lg_q227w228w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Oi32_w_lg_q227w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl0Ol29	:	STD_LOGIC := '0';
	 SIGNAL	 nl0Ol30	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl0Ol30_w_lg_w_lg_q198w199w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0Ol30_w_lg_q198w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nl0OO27	:	STD_LOGIC := '0';
	 SIGNAL	 nl0OO28	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl0OO28_w_lg_w_lg_q195w196w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl0OO28_w_lg_q195w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nli0i19	:	STD_LOGIC := '0';
	 SIGNAL	 nli0i20	:	STD_LOGIC := '0';
	 SIGNAL  wire_nli0i20_w_lg_w_lg_q121w122w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli0i20_w_lg_q121w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nli0l17	:	STD_LOGIC := '0';
	 SIGNAL	 nli0l18	:	STD_LOGIC := '0';
	 SIGNAL  wire_nli0l18_w_lg_w_lg_q89w90w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli0l18_w_lg_q89w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nli1i25	:	STD_LOGIC := '0';
	 SIGNAL	 nli1i26	:	STD_LOGIC := '0';
	 SIGNAL  wire_nli1i26_w_lg_w_lg_q165w166w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1i26_w_lg_q165w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nli1l23	:	STD_LOGIC := '0';
	 SIGNAL	 nli1l24	:	STD_LOGIC := '0';
	 SIGNAL  wire_nli1l24_w_lg_w_lg_q132w133w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1l24_w_lg_q132w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nli1O21	:	STD_LOGIC := '0';
	 SIGNAL	 nli1O22	:	STD_LOGIC := '0';
	 SIGNAL  wire_nli1O22_w_lg_w_lg_q128w129w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nli1O22_w_lg_q128w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nliii15	:	STD_LOGIC := '0';
	 SIGNAL	 nliii16	:	STD_LOGIC := '0';
	 SIGNAL	 nliOi13	:	STD_LOGIC := '0';
	 SIGNAL	 nliOi14	:	STD_LOGIC := '0';
	 SIGNAL	 nll0i10	:	STD_LOGIC := '0';
	 SIGNAL	 nll0i9	:	STD_LOGIC := '0';
	 SIGNAL	 nll0O7	:	STD_LOGIC := '0';
	 SIGNAL	 nll0O8	:	STD_LOGIC := '0';
	 SIGNAL	 nll1i11	:	STD_LOGIC := '0';
	 SIGNAL	 nll1i12	:	STD_LOGIC := '0';
	 SIGNAL	 nlliO5	:	STD_LOGIC := '0';
	 SIGNAL	 nlliO6	:	STD_LOGIC := '0';
	 SIGNAL	 nllll3	:	STD_LOGIC := '0';
	 SIGNAL	 nllll4	:	STD_LOGIC := '0';
	 SIGNAL	 nlO1i1	:	STD_LOGIC := '0';
	 SIGNAL	 nlO1i2	:	STD_LOGIC := '0';
	 SIGNAL	n0il	:	STD_LOGIC := '0';
	 SIGNAL	nii	:	STD_LOGIC := '0';
	 SIGNAL	nil	:	STD_LOGIC := '0';
	 SIGNAL	nli	:	STD_LOGIC := '0';
	 SIGNAL	nllO	:	STD_LOGIC := '0';
	 SIGNAL	nlOi	:	STD_LOGIC := '0';
	 SIGNAL	nlOl	:	STD_LOGIC := '0';
	 SIGNAL	wire_niO_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_niO_w_lg_nil83w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niO_w_lg_w_lg_nil83w84w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n00O	:	STD_LOGIC := '0';
	 SIGNAL	n0ii	:	STD_LOGIC := '0';
	 SIGNAL	nO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nl_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nl_w_lg_n00O271w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nl_w_lg_nO80w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0i_w_lg_dataout58w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n1i_w_lg_dataout59w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_n0li_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0li_o	:	STD_LOGIC;
	 SIGNAL  wire_n0li_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0ll_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0ll_o	:	STD_LOGIC;
	 SIGNAL  wire_n0ll_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0lO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0lO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0lO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Oi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Ol_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Ol_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_w_lg_nli0O126w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nliiO158w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlili82w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nll1O57w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_soft_reset2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  nli0O :	STD_LOGIC;
	 SIGNAL  nliiO :	STD_LOGIC;
	 SIGNAL  nlili :	STD_LOGIC;
	 SIGNAL  nlill :	STD_LOGIC;
	 SIGNAL  nlilO :	STD_LOGIC;
	 SIGNAL  nliOO :	STD_LOGIC;
	 SIGNAL  nll1O :	STD_LOGIC;
	 SIGNAL  nllil :	STD_LOGIC;
	 SIGNAL  nllli :	STD_LOGIC;
	 SIGNAL  nllOl :	STD_LOGIC;
 BEGIN

	wire_w_lg_nli0O126w(0) <= NOT nli0O;
	wire_w_lg_nliiO158w(0) <= NOT nliiO;
	wire_w_lg_nlili82w(0) <= NOT nlili;
	wire_w_lg_nll1O57w(0) <= NOT nll1O;
	wire_w_lg_soft_reset2w(0) <= NOT soft_reset;
	align_status <= nlOl;
	curr_state <= ( "0" & nlOi & nllO & n0il);
	enable_deskew <= n0ii;
	fifo_reset_rd <= (n0ii AND wire_nl_w_lg_n00O271w(0));
	nli0O <= wire_niO_w_lg_w_lg_nil83w84w(0);
	nliiO <= (wire_niO_w_lg_w_lg_nil83w84w(0) OR (NOT (nliii16 XOR nliii15)));
	nlili <= (wire_nl_w_lg_nO80w(0) AND wire_n0i_dataout);
	nlill <= (nil AND wire_nliO_dataout);
	nlilO <= ((((((((align_det_sync(0) AND align_det_sync(1)) AND align_det_sync(2)) AND align_det_sync(3)) AND align_det_sync(4)) AND align_det_sync(5)) AND align_det_sync(6)) AND align_det_sync(7)) AND (nliOi14 XOR nliOi13));
	nliOO <= (wire_n0i_w_lg_dataout58w(0) AND wire_n1i_w_lg_dataout59w(0));
	nll1O <= ((((((((rd_align(0) OR rd_align(1)) OR rd_align(2)) OR rd_align(3)) OR rd_align(4)) OR rd_align(5)) OR rd_align(6)) OR rd_align(7)) OR (NOT (nll0i10 XOR nll0i9)));
	nllil <= (((((((rd_align(0) AND rd_align(1)) AND rd_align(2)) AND rd_align(3)) AND rd_align(4)) AND rd_align(5)) AND rd_align(6)) AND rd_align(7));
	nllli <= ((((((((sync_status(0) AND sync_status(1)) AND sync_status(2)) AND sync_status(3)) AND sync_status(4)) AND sync_status(5)) AND sync_status(6)) AND sync_status(7)) AND (nllll4 XOR nllll3));
	nllOl <= '1';
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nl0ll35 <= nl0ll36;
		END IF;
		if (now = 0 ns) then
			nl0ll35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nl0ll36 <= nl0ll35;
		END IF;
	END PROCESS;
	wire_nl0ll36_w_lg_w_lg_q268w269w(0) <= wire_nl0ll36_w_lg_q268w(0) AND wire_n0OO_dataout;
	wire_nl0ll36_w_lg_q268w(0) <= nl0ll36 XOR nl0ll35;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nl0lO33 <= nl0lO34;
		END IF;
		if (now = 0 ns) then
			nl0lO33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nl0lO34 <= nl0lO33;
		END IF;
	END PROCESS;
	wire_nl0lO34_w_lg_w_lg_q232w233w(0) <= wire_nl0lO34_w_lg_q232w(0) AND wire_ni0l_dataout;
	wire_nl0lO34_w_lg_q232w(0) <= nl0lO34 XOR nl0lO33;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nl0Oi31 <= nl0Oi32;
		END IF;
		if (now = 0 ns) then
			nl0Oi31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nl0Oi32 <= nl0Oi31;
		END IF;
	END PROCESS;
	wire_nl0Oi32_w_lg_w_lg_q227w228w(0) <= wire_nl0Oi32_w_lg_q227w(0) AND nii;
	wire_nl0Oi32_w_lg_q227w(0) <= nl0Oi32 XOR nl0Oi31;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nl0Ol29 <= nl0Ol30;
		END IF;
		if (now = 0 ns) then
			nl0Ol29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nl0Ol30 <= nl0Ol29;
		END IF;
	END PROCESS;
	wire_nl0Ol30_w_lg_w_lg_q198w199w(0) <= wire_nl0Ol30_w_lg_q198w(0) AND wire_nili_dataout;
	wire_nl0Ol30_w_lg_q198w(0) <= nl0Ol30 XOR nl0Ol29;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nl0OO27 <= nl0OO28;
		END IF;
		if (now = 0 ns) then
			nl0OO27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nl0OO28 <= nl0OO27;
		END IF;
	END PROCESS;
	wire_nl0OO28_w_lg_w_lg_q195w196w(0) <= wire_nl0OO28_w_lg_q195w(0) AND wire_nill_dataout;
	wire_nl0OO28_w_lg_q195w(0) <= nl0OO28 XOR nl0OO27;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nli0i19 <= nli0i20;
		END IF;
		if (now = 0 ns) then
			nli0i19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nli0i20 <= nli0i19;
		END IF;
	END PROCESS;
	wire_nli0i20_w_lg_w_lg_q121w122w(0) <= wire_nli0i20_w_lg_q121w(0) AND nil;
	wire_nli0i20_w_lg_q121w(0) <= nli0i20 XOR nli0i19;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nli0l17 <= nli0l18;
		END IF;
		if (now = 0 ns) then
			nli0l17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nli0l18 <= nli0l17;
		END IF;
	END PROCESS;
	wire_nli0l18_w_lg_w_lg_q89w90w(0) <= wire_nli0l18_w_lg_q89w(0) AND n0il;
	wire_nli0l18_w_lg_q89w(0) <= nli0l18 XOR nli0l17;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nli1i25 <= nli1i26;
		END IF;
		if (now = 0 ns) then
			nli1i25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nli1i26 <= nli1i25;
		END IF;
	END PROCESS;
	wire_nli1i26_w_lg_w_lg_q165w166w(0) <= wire_nli1i26_w_lg_q165w(0) AND wire_w_lg_nli0O126w(0);
	wire_nli1i26_w_lg_q165w(0) <= nli1i26 XOR nli1i25;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nli1l23 <= nli1l24;
		END IF;
		if (now = 0 ns) then
			nli1l23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nli1l24 <= nli1l23;
		END IF;
	END PROCESS;
	wire_nli1l24_w_lg_w_lg_q132w133w(0) <= wire_nli1l24_w_lg_q132w(0) AND nllO;
	wire_nli1l24_w_lg_q132w(0) <= nli1l24 XOR nli1l23;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nli1O21 <= nli1O22;
		END IF;
		if (now = 0 ns) then
			nli1O21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nli1O22 <= nli1O21;
		END IF;
	END PROCESS;
	wire_nli1O22_w_lg_w_lg_q128w129w(0) <= wire_nli1O22_w_lg_q128w(0) AND n0il;
	wire_nli1O22_w_lg_q128w(0) <= nli1O22 XOR nli1O21;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nliii15 <= nliii16;
		END IF;
		if (now = 0 ns) then
			nliii15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nliii16 <= nliii15;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nliOi13 <= nliOi14;
		END IF;
		if (now = 0 ns) then
			nliOi13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nliOi14 <= nliOi13;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nll0i10 <= nll0i9;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nll0i9 <= nll0i10;
		END IF;
		if (now = 0 ns) then
			nll0i9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nll0O7 <= nll0O8;
		END IF;
		if (now = 0 ns) then
			nll0O7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nll0O8 <= nll0O7;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nll1i11 <= nll1i12;
		END IF;
		if (now = 0 ns) then
			nll1i11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nll1i12 <= nll1i11;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlliO5 <= nlliO6;
		END IF;
		if (now = 0 ns) then
			nlliO5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlliO6 <= nlliO5;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nllll3 <= nllll4;
		END IF;
		if (now = 0 ns) then
			nllll3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nllll4 <= nllll3;
		END IF;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlO1i1 <= nlO1i2;
		END IF;
		if (now = 0 ns) then
			nlO1i1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_1)
	BEGIN
		IF (clk_1 = '1' AND clk_1'event) THEN nlO1i2 <= nlO1i1;
		END IF;
	END PROCESS;
	PROCESS (clk_1, wire_niO_CLRN)
	BEGIN
		IF (wire_niO_CLRN = '0') THEN
				n0il <= '0';
				nii <= '0';
				nil <= '0';
				nli <= '0';
				nllO <= '0';
				nlOi <= '0';
				nlOl <= '0';
		ELSIF (clk_1 = '1' AND clk_1'event) THEN
				n0il <= wire_n0lO_o;
				nii <= wire_n0ll_o;
				nil <= nli;
				nli <= wire_nll_dataout;
				nllO <= wire_n0Oi_o;
				nlOi <= wire_n0Ol_o;
				nlOl <= nii;
		END IF;
	END PROCESS;
	wire_niO_CLRN <= ((nlliO6 XOR nlliO5) AND wire_w_lg_soft_reset2w(0));
	wire_niO_w_lg_nil83w(0) <= NOT nil;
	wire_niO_w_lg_w_lg_nil83w84w(0) <= wire_niO_w_lg_nil83w(0) OR nliOO;
	PROCESS (clk_1, soft_reset, wire_nl_CLRN)
	BEGIN
		IF (soft_reset = '1') THEN
				n00O <= '1';
				n0ii <= '1';
				nO <= '1';
		ELSIF (wire_nl_CLRN = '0') THEN
				n00O <= '0';
				n0ii <= '0';
				nO <= '0';
		ELSIF (clk_1 = '1' AND clk_1'event) THEN
				n00O <= n0ii;
				n0ii <= wire_n0li_o;
				nO <= n00O;
		END IF;
		if (now = 0 ns) then
			n00O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0ii <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nO <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nl_CLRN <= (nlO1i2 XOR nlO1i1);
	wire_nl_w_lg_n00O271w(0) <= NOT n00O;
	wire_nl_w_lg_nO80w(0) <= NOT nO;
	wire_n0i_dataout <= nllil WHEN octal_mode = '1'  ELSE ((((rd_align(0) AND rd_align(1)) AND rd_align(2)) AND rd_align(3)) AND (nll0O8 XOR nll0O7));
	wire_n0i_w_lg_dataout58w(0) <= NOT wire_n0i_dataout;
	wire_n0OO_dataout <= n0ii OR nli0O;
	wire_n1i_dataout <= wire_w_lg_nll1O57w(0) WHEN octal_mode = '1'  ELSE (NOT ((((rd_align(0) OR rd_align(1)) OR rd_align(2)) OR rd_align(3)) OR (NOT (nll1i12 XOR nll1i11))));
	wire_n1i_w_lg_dataout59w(0) <= NOT wire_n1i_dataout;
	wire_ni0i_dataout <= n0ii OR wire_niO_w_lg_nil83w(0);
	wire_ni0l_dataout <= nii AND NOT(wire_niO_w_lg_nil83w(0));
	wire_ni0O_dataout <= wire_niil_dataout AND NOT(wire_niO_w_lg_nil83w(0));
	wire_ni1i_dataout <= nii AND NOT(nli0O);
	wire_ni1l_dataout <= wire_n0i_w_lg_dataout58w(0) AND NOT(nli0O);
	wire_niii_dataout <= wire_niiO_dataout AND NOT(wire_niO_w_lg_nil83w(0));
	wire_niil_dataout <= wire_n0i_dataout OR nliOO;
	wire_niiO_dataout <= wire_n0i_w_lg_dataout58w(0) OR nliOO;
	wire_nili_dataout <= wire_nilO_dataout AND NOT(wire_niO_w_lg_nil83w(0));
	wire_nill_dataout <= nliOO AND NOT(wire_niO_w_lg_nil83w(0));
	wire_nilO_dataout <= wire_n0i_w_lg_dataout58w(0) AND NOT(nliOO);
	wire_niOi_dataout <= nii WHEN nliiO = '1'  ELSE wire_nl1l_dataout;
	wire_niOl_dataout <= n0ii OR nliiO;
	wire_niOO_dataout <= wire_n0i_w_lg_dataout58w(0) AND NOT(nliiO);
	wire_nl0i_dataout <= wire_w_lg_nlili82w(0) AND NOT(nliiO);
	wire_nl0l_dataout <= nlili AND NOT(nliiO);
	wire_nl1i_dataout <= wire_n0i_dataout AND NOT(nliiO);
	wire_nl1l_dataout <= nii OR wire_n0i_dataout;
	wire_nlii_dataout <= n0ii AND NOT(nlill);
	wire_nliO_dataout <= nlilO WHEN octal_mode = '1'  ELSE (((align_det_sync(0) AND align_det_sync(1)) AND align_det_sync(2)) AND align_det_sync(3));
	wire_nll_dataout <= nllli WHEN octal_mode = '1'  ELSE (((sync_status(0) AND sync_status(1)) AND sync_status(2)) AND sync_status(3));
	wire_n0li_data <= ( wire_nl0ll36_w_lg_w_lg_q268w269w & wire_ni0i_dataout & wire_ni0i_dataout & wire_ni0i_dataout & wire_niOl_dataout & wire_niOl_dataout & wire_niOl_dataout & wire_nlii_dataout & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0");
	wire_n0li_sel <= ( "1" & nlOi & nllO & n0il);
	n0li :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0li_data,
		o => wire_n0li_o,
		sel => wire_n0li_sel
	  );
	wire_n0ll_data <= ( wire_ni1i_dataout & wire_ni0l_dataout & wire_ni0l_dataout & wire_nl0lO34_w_lg_w_lg_q232w233w & wire_niOi_dataout & nii & wire_nl0Oi32_w_lg_w_lg_q227w228w & nii & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0");
	wire_n0ll_sel <= ( "1" & nlOi & nllO & n0il);
	n0ll :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0ll_data,
		o => wire_n0ll_o,
		sel => wire_n0ll_sel
	  );
	wire_n0lO_data <= ( wire_ni1l_dataout & wire_ni0O_dataout & wire_nl0Ol30_w_lg_w_lg_q198w199w & wire_nl0OO28_w_lg_w_lg_q195w196w & wire_niOO_dataout & wire_nl1i_dataout & wire_nl0i_dataout & nlill & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0");
	wire_n0lO_sel <= ( "1" & nlOi & nllO & n0il);
	n0lO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0lO_data,
		o => wire_n0lO_o,
		sel => wire_n0lO_sel
	  );
	wire_n0Oi_data <= ( wire_nli1i26_w_lg_w_lg_q165w166w & wire_niii_dataout & wire_nill_dataout & "0" & wire_niOO_dataout & wire_w_lg_nliiO158w & wire_nl0l_dataout & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0");
	wire_n0Oi_sel <= ( "1" & nlOi & wire_nli1l24_w_lg_w_lg_q132w133w & wire_nli1O22_w_lg_w_lg_q128w129w);
	n0Oi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Oi_data,
		o => wire_n0Oi_o,
		sel => wire_n0Oi_sel
	  );
	wire_n0Ol_data <= ( wire_w_lg_nli0O126w & nil & nil & wire_nli0i20_w_lg_w_lg_q121w122w & wire_nl1i_dataout & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0");
	wire_n0Ol_sel <= ( "1" & nlOi & nllO & wire_nli0l18_w_lg_w_lg_q89w90w);
	n0Ol :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Ol_data,
		o => wire_n0Ol_o,
		sel => wire_n0Ol_sel
	  );

 END RTL; --stratixiv_hssi_dskw_sm
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 143 mux21 336 oper_add 1 oper_decoder 1 oper_less_than 1 oper_mux 39 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_tx_sm IS 
	 PORT 
	 ( 
		 curr_state	:	OUT  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 indv	:	IN  STD_LOGIC;
		 rd_enable_sync	:	IN  STD_LOGIC;
		 rxaui_s2gx_en	:	IN  STD_LOGIC;
		 sm_ctl	:	OUT  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 sm_data	:	OUT  STD_LOGIC_VECTOR (31 DOWNTO 0);
		 soft_reset	:	IN  STD_LOGIC;
		 tx_clk	:	IN  STD_LOGIC;
		 tx_ctl	:	IN  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 tx_data	:	IN  STD_LOGIC_VECTOR (31 DOWNTO 0);
		 tx_local_fault	:	OUT  STD_LOGIC;
		 tx_local_fault_clr	:	IN  STD_LOGIC;
		 tx_local_fault_det	:	OUT  STD_LOGIC
	 ); 
 END stratixiv_hssi_tx_sm;

 ARCHITECTURE RTL OF stratixiv_hssi_tx_sm IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 nil00i49	:	STD_LOGIC := '0';
	 SIGNAL	 nil00i50	:	STD_LOGIC := '0';
	 SIGNAL	 nil00l47	:	STD_LOGIC := '0';
	 SIGNAL	 nil00l48	:	STD_LOGIC := '0';
	 SIGNAL	 nili0i41	:	STD_LOGIC := '0';
	 SIGNAL	 nili0i42	:	STD_LOGIC := '0';
	 SIGNAL	 nili1i45	:	STD_LOGIC := '0';
	 SIGNAL	 nili1i46	:	STD_LOGIC := '0';
	 SIGNAL	 nili1O43	:	STD_LOGIC := '0';
	 SIGNAL	 nili1O44	:	STD_LOGIC := '0';
	 SIGNAL	 nilOll39	:	STD_LOGIC := '0';
	 SIGNAL	 nilOll40	:	STD_LOGIC := '0';
	 SIGNAL	 niO01l25	:	STD_LOGIC := '0';
	 SIGNAL	 niO01l26	:	STD_LOGIC := '0';
	 SIGNAL  wire_niO01l26_w_lg_q89w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niO0il23	:	STD_LOGIC := '0';
	 SIGNAL	 niO0il24	:	STD_LOGIC := '0';
	 SIGNAL	 niO0ll21	:	STD_LOGIC := '0';
	 SIGNAL	 niO0ll22	:	STD_LOGIC := '0';
	 SIGNAL	 niO10l35	:	STD_LOGIC := '0';
	 SIGNAL	 niO10l36	:	STD_LOGIC := '0';
	 SIGNAL	 niO11i37	:	STD_LOGIC := '0';
	 SIGNAL	 niO11i38	:	STD_LOGIC := '0';
	 SIGNAL	 niO1iO33	:	STD_LOGIC := '0';
	 SIGNAL	 niO1iO34	:	STD_LOGIC := '0';
	 SIGNAL	 niO1ll31	:	STD_LOGIC := '0';
	 SIGNAL	 niO1ll32	:	STD_LOGIC := '0';
	 SIGNAL	 niO1Oi29	:	STD_LOGIC := '0';
	 SIGNAL	 niO1Oi30	:	STD_LOGIC := '0';
	 SIGNAL	 niO1OO27	:	STD_LOGIC := '0';
	 SIGNAL	 niO1OO28	:	STD_LOGIC := '0';
	 SIGNAL	 niOi0i17	:	STD_LOGIC := '0';
	 SIGNAL	 niOi0i18	:	STD_LOGIC := '0';
	 SIGNAL	 niOi1i19	:	STD_LOGIC := '0';
	 SIGNAL	 niOi1i20	:	STD_LOGIC := '0';
	 SIGNAL	 niOili15	:	STD_LOGIC := '0';
	 SIGNAL	 niOili16	:	STD_LOGIC := '0';
	 SIGNAL	 niOl0l13	:	STD_LOGIC := '0';
	 SIGNAL	 niOl0l14	:	STD_LOGIC := '0';
	 SIGNAL	 niOlli11	:	STD_LOGIC := '0';
	 SIGNAL	 niOlli12	:	STD_LOGIC := '0';
	 SIGNAL	 niOlOi10	:	STD_LOGIC := '0';
	 SIGNAL	 niOlOi9	:	STD_LOGIC := '0';
	 SIGNAL	 niOO1l7	:	STD_LOGIC := '0';
	 SIGNAL	 niOO1l8	:	STD_LOGIC := '0';
	 SIGNAL	 niOOii5	:	STD_LOGIC := '0';
	 SIGNAL	 niOOii6	:	STD_LOGIC := '0';
	 SIGNAL	 niOOll3	:	STD_LOGIC := '0';
	 SIGNAL	 niOOll4	:	STD_LOGIC := '0';
	 SIGNAL	 niOOOO1	:	STD_LOGIC := '0';
	 SIGNAL	 niOOOO2	:	STD_LOGIC := '0';
	 SIGNAL	nlii0l	:	STD_LOGIC := '0';
	 SIGNAL	nlii0O	:	STD_LOGIC := '0';
	 SIGNAL	nliiii	:	STD_LOGIC := '0';
	 SIGNAL	nliili	:	STD_LOGIC := '0';
	 SIGNAL	nlilOl	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlilOi_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nlilOi_w_lg_nlilOl1869w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	nlii0i	:	STD_LOGIC := '0';
	 SIGNAL	nlii1l	:	STD_LOGIC := '0';
	 SIGNAL	nliiil	:	STD_LOGIC := '0';
	 SIGNAL	nliiiO	:	STD_LOGIC := '0';
	 SIGNAL	nliill	:	STD_LOGIC := '0';
	 SIGNAL	nliilO	:	STD_LOGIC := '0';
	 SIGNAL	nliiOi	:	STD_LOGIC := '0';
	 SIGNAL	nliiOl	:	STD_LOGIC := '0';
	 SIGNAL	nliiOO	:	STD_LOGIC := '0';
	 SIGNAL	nlil0i	:	STD_LOGIC := '0';
	 SIGNAL	nlil0l	:	STD_LOGIC := '0';
	 SIGNAL	nlil0O	:	STD_LOGIC := '0';
	 SIGNAL	nlil1i	:	STD_LOGIC := '0';
	 SIGNAL	nlil1l	:	STD_LOGIC := '0';
	 SIGNAL	nlil1O	:	STD_LOGIC := '0';
	 SIGNAL	nlilii	:	STD_LOGIC := '0';
	 SIGNAL	nlilil	:	STD_LOGIC := '0';
	 SIGNAL	nliliO	:	STD_LOGIC := '0';
	 SIGNAL	nlilli	:	STD_LOGIC := '0';
	 SIGNAL	nlilll	:	STD_LOGIC := '0';
	 SIGNAL	nlillO	:	STD_LOGIC := '0';
	 SIGNAL	nlilOO	:	STD_LOGIC := '0';
	 SIGNAL	nliO0i	:	STD_LOGIC := '0';
	 SIGNAL	nliO0O	:	STD_LOGIC := '0';
	 SIGNAL	nliO1i	:	STD_LOGIC := '0';
	 SIGNAL	nliO1l	:	STD_LOGIC := '0';
	 SIGNAL	nliO1O	:	STD_LOGIC := '0';
	 SIGNAL	wire_nliO0l_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nliO0l_w_lg_w_lg_w_lg_w1866w1868w1870w1871w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_w_lg_w1866w1868w1870w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_w1866w1868w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w1866w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_w_lg_w_lg_w_lg_nliO0O1858w1860w1862w1864w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_w_lg_w_lg_nliO0O1858w1860w1862w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_w_lg_nliO0O1858w1860w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nliill1902w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nliilO1900w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nliiOi1898w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nliiOl1896w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nliiOO1894w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nlil0i1886w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nlil0l1884w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nlil0O1882w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nlil1i1892w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nlil1l1890w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nlil1O1888w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nlilii1880w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nlilil1878w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nliliO1876w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nlilli1874w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nlilll1872w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nlilOO1867w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nliO0i1859w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nliO0O1858w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nliO1i1865w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nliO1l1863w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nliO0l_w_lg_nliO1O1861w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n0l0O	:	STD_LOGIC := '0';
	 SIGNAL	n0lii	:	STD_LOGIC := '0';
	 SIGNAL	n0llO	:	STD_LOGIC := '0';
	 SIGNAL	n0lOl	:	STD_LOGIC := '0';
	 SIGNAL	n1i0i	:	STD_LOGIC := '0';
	 SIGNAL	n1i0l	:	STD_LOGIC := '0';
	 SIGNAL	n1ili	:	STD_LOGIC := '0';
	 SIGNAL	nilOi	:	STD_LOGIC := '0';
	 SIGNAL	nilOl	:	STD_LOGIC := '0';
	 SIGNAL	niOil	:	STD_LOGIC := '0';
	 SIGNAL	niOiO	:	STD_LOGIC := '0';
	 SIGNAL	niOOi	:	STD_LOGIC := '0';
	 SIGNAL	nli00i	:	STD_LOGIC := '0';
	 SIGNAL	nli10i	:	STD_LOGIC := '0';
	 SIGNAL	nli10l	:	STD_LOGIC := '0';
	 SIGNAL	nli10O	:	STD_LOGIC := '0';
	 SIGNAL	nliOii	:	STD_LOGIC := '0';
	 SIGNAL	nliOll	:	STD_LOGIC := '0';
	 SIGNAL	nliOlO	:	STD_LOGIC := '0';
	 SIGNAL	nliOO	:	STD_LOGIC := '0';
	 SIGNAL	nll0i	:	STD_LOGIC := '0';
	 SIGNAL	nll0O	:	STD_LOGIC := '0';
	 SIGNAL	nll11l	:	STD_LOGIC := '0';
	 SIGNAL	nlO01l	:	STD_LOGIC := '0';
	 SIGNAL	nlO01O	:	STD_LOGIC := '0';
	 SIGNAL	nlO0il	:	STD_LOGIC := '0';
	 SIGNAL	wire_nll0l_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nll0l_PRN	:	STD_LOGIC;
	 SIGNAL  wire_nll0l_w_lg_w_lg_w_lg_w_lg_nll0O365w371w1503w1504w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0l_w_lg_w_lg_w_lg_w_lg_nll0O365w371w372w373w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0l_w_lg_w_lg_w_lg_nll0O365w367w368w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0l_w_lg_w_lg_w_lg_nll0O365w371w1503w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0l_w_lg_w_lg_w_lg_nll0O365w371w372w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0l_w_lg_w_lg_nll0O365w367w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0l_w_lg_w_lg_nll0O365w371w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0l_w_lg_n0lOl378w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0l_w_lg_nilOi377w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0l_w_lg_nliOii237w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0l_w_lg_nll0i366w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll0l_w_lg_nll0O365w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n0lil	:	STD_LOGIC := '0';
	 SIGNAL	n0liO	:	STD_LOGIC := '0';
	 SIGNAL	n0lli	:	STD_LOGIC := '0';
	 SIGNAL	n0lll	:	STD_LOGIC := '0';
	 SIGNAL	n0lOi	:	STD_LOGIC := '0';
	 SIGNAL	n1i0O	:	STD_LOGIC := '0';
	 SIGNAL	n1iii	:	STD_LOGIC := '0';
	 SIGNAL	n1iil	:	STD_LOGIC := '0';
	 SIGNAL	n1iiO	:	STD_LOGIC := '0';
	 SIGNAL	n1ill	:	STD_LOGIC := '0';
	 SIGNAL	n1ilO	:	STD_LOGIC := '0';
	 SIGNAL	niOli	:	STD_LOGIC := '0';
	 SIGNAL	nli0ll	:	STD_LOGIC := '0';
	 SIGNAL	nli0lO	:	STD_LOGIC := '0';
	 SIGNAL	nli0Oi	:	STD_LOGIC := '0';
	 SIGNAL	nli0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nli0OO	:	STD_LOGIC := '0';
	 SIGNAL	nli1ii	:	STD_LOGIC := '0';
	 SIGNAL	nli1il	:	STD_LOGIC := '0';
	 SIGNAL	nlii1i	:	STD_LOGIC := '0';
	 SIGNAL	nliOil	:	STD_LOGIC := '0';
	 SIGNAL	nliOOi	:	STD_LOGIC := '0';
	 SIGNAL	nliOOl	:	STD_LOGIC := '0';
	 SIGNAL	nliOOO	:	STD_LOGIC := '0';
	 SIGNAL	nll10i	:	STD_LOGIC := '0';
	 SIGNAL	nll11i	:	STD_LOGIC := '0';
	 SIGNAL	nll11O	:	STD_LOGIC := '0';
	 SIGNAL	nll1i	:	STD_LOGIC := '0';
	 SIGNAL	nll1O	:	STD_LOGIC := '0';
	 SIGNAL	nlO00i	:	STD_LOGIC := '0';
	 SIGNAL	nlO00l	:	STD_LOGIC := '0';
	 SIGNAL	nlO00O	:	STD_LOGIC := '0';
	 SIGNAL	nlO0ii	:	STD_LOGIC := '0';
	 SIGNAL	nlO0iO	:	STD_LOGIC := '0';
	 SIGNAL	nlO0li	:	STD_LOGIC := '0';
	 SIGNAL	wire_nll1l_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_nll1l_w_lg_w_lg_w_lg_niOli360w361w362w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll1l_w_lg_niOli360w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll1l_w_lg_nli1il239w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll1l_w_lg_nll1i369w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll1l_w_lg_nll1O1502w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nll1l_w_lg_w_lg_niOli360w361w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n000i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n000O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n001O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nli00l_a	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nli00l_b	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_gnd	:	STD_LOGIC;
	 SIGNAL  wire_nli00l_o	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nl01i_i	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl01i_o	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nl1li_a	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1li_b	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1li_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OiO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OiO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OiO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Oli_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Oli_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oli_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0Oll_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0Oll_o	:	STD_LOGIC;
	 SIGNAL  wire_n0Oll_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OlO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OlO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OlO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OOi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OOi_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OOi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OOl_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OOl_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OOl_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n0OOO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n0OOO_o	:	STD_LOGIC;
	 SIGNAL  wire_n0OOO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1lii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1lii_o	:	STD_LOGIC;
	 SIGNAL  wire_n1lii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1lil_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1lil_o	:	STD_LOGIC;
	 SIGNAL  wire_n1lil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1liO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1liO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1liO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1lli_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1lli_o	:	STD_LOGIC;
	 SIGNAL  wire_n1lli_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1lll_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1lll_o	:	STD_LOGIC;
	 SIGNAL  wire_n1lll_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1llO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1llO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1llO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1lOi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1lOi_o	:	STD_LOGIC;
	 SIGNAL  wire_n1lOi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1lOl_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1lOl_o	:	STD_LOGIC;
	 SIGNAL  wire_n1lOl_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_n1lOO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_n1lOO_o	:	STD_LOGIC;
	 SIGNAL  wire_n1lOO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni11i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni11i_o	:	STD_LOGIC;
	 SIGNAL  wire_ni11i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_ni11l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni11l_o	:	STD_LOGIC;
	 SIGNAL  wire_ni11l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1lO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nl1lO_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1lO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1Oi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nl1Oi_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1Oi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nl1Ol_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nl1Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_nl1Ol_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll00i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nll00i_o	:	STD_LOGIC;
	 SIGNAL  wire_nll00i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll00l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nll00l_o	:	STD_LOGIC;
	 SIGNAL  wire_nll00l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll00O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nll00O_o	:	STD_LOGIC;
	 SIGNAL  wire_nll00O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll01i_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nll01i_o	:	STD_LOGIC;
	 SIGNAL  wire_nll01i_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll01l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nll01l_o	:	STD_LOGIC;
	 SIGNAL  wire_nll01l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll01O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nll01O_o	:	STD_LOGIC;
	 SIGNAL  wire_nll01O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll0ii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nll0ii_o	:	STD_LOGIC;
	 SIGNAL  wire_nll0ii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll1Ol_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nll1Ol_o	:	STD_LOGIC;
	 SIGNAL  wire_nll1Ol_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nll1OO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nll1OO_o	:	STD_LOGIC;
	 SIGNAL  wire_nll1OO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlOi0l_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nlOi0l_o	:	STD_LOGIC;
	 SIGNAL  wire_nlOi0l_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlOi0O_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nlOi0O_o	:	STD_LOGIC;
	 SIGNAL  wire_nlOi0O_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlOiii_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nlOiii_o	:	STD_LOGIC;
	 SIGNAL  wire_nlOiii_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlOiil_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nlOiil_o	:	STD_LOGIC;
	 SIGNAL  wire_nlOiil_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlOiiO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nlOiiO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlOiiO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlOili_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nlOili_o	:	STD_LOGIC;
	 SIGNAL  wire_nlOili_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlOill_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nlOill_o	:	STD_LOGIC;
	 SIGNAL  wire_nlOill_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlOilO_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nlOilO_o	:	STD_LOGIC;
	 SIGNAL  wire_nlOilO_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nlOiOi_data	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_nlOiOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nlOiOi_sel	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_niO00O83w85w87w90w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_niliOO199w201w203w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_nilllO168w170w172w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_nilOiO139w141w143w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_niO00O83w85w87w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rd_enable_sync357w358w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_tx_ctl_range4w22w23w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_niliOO199w201w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nilllO168w170w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_nilOiO139w141w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_niO00O83w85w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_rd_enable_sync235w355w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_niOO1i223w224w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil0lO1500w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOiii208w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOiii226w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOiiO176w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOiOi147w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rd_enable_sync357w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_ctl_range1w54w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_ctl_range1w32w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_ctl_range1w97w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_ctl_range1w41w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_ctl_range2w113w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_ctl_range4w151w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_ctl_range4w48w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_ctl_range4w22w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_ctl_range6w182w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_ctl_range6w27w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_data_range389w1766w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_data_range945w1820w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_data_range1226w1835w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_data_range667w1797w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_niOiOO206w207w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil0Oi238w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil0Ol236w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nil0OO234w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niliOi202w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niliOl200w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niliOO199w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nill0i191w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nill0l189w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nill0O185w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nill1i197w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nill1l195w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nill1O193w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nillii183w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilliO175w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nillli171w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nillll169w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilllO168w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nillOi166w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nillOl164w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nillOO162w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilO0i152w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilO0O146w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilO1i160w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilO1l158w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilO1O154w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOii142w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOil140w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOiO139w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOli137w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOOi132w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOOl130w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_nilOOO128w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niO00i86w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niO00l84w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niO00O83w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niO0ii81w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niO0li76w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niO0Oi71w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niO0Ol69w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niO0OO67w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niO10i119w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niO11O123w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niO1ii114w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOi0O53w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOi1O60w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOiil181w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOilO150w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOiOl112w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOl1i156w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOl1O121w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOlii65w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOlil1217w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOliO55w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOlOO187w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOOOi96w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rd_enable_sync235w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_rxaui_s2gx_en105w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_soft_reset230w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_ctl_range2w31w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_data_range944w1659w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_data_range388w1592w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_data_range1225w1697w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_tx_data_range666w1621w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_w_lg_niO00O83w85w87w90w91w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_niliOO199w201w203w204w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_nilllO168w170w172w173w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_w_lg_nilOiO139w141w143w144w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_rd_enable_sync235w355w356w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOiOO225w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOiOO206w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_niOO1i223w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  nil00O :	STD_LOGIC;
	 SIGNAL  nil01O :	STD_LOGIC;
	 SIGNAL  nil0ii :	STD_LOGIC;
	 SIGNAL  nil0il :	STD_LOGIC;
	 SIGNAL  nil0iO :	STD_LOGIC;
	 SIGNAL  nil0li :	STD_LOGIC;
	 SIGNAL  nil0ll :	STD_LOGIC;
	 SIGNAL  nil0lO :	STD_LOGIC;
	 SIGNAL  nil0Oi :	STD_LOGIC;
	 SIGNAL  nil0Ol :	STD_LOGIC;
	 SIGNAL  nil0OO :	STD_LOGIC;
	 SIGNAL  nili0l :	STD_LOGIC;
	 SIGNAL  nili0O :	STD_LOGIC;
	 SIGNAL  nili1l :	STD_LOGIC;
	 SIGNAL  niliii :	STD_LOGIC;
	 SIGNAL  niliil :	STD_LOGIC;
	 SIGNAL  niliiO :	STD_LOGIC;
	 SIGNAL  nilili :	STD_LOGIC;
	 SIGNAL  nilill :	STD_LOGIC;
	 SIGNAL  nililO :	STD_LOGIC;
	 SIGNAL  niliOi :	STD_LOGIC;
	 SIGNAL  niliOl :	STD_LOGIC;
	 SIGNAL  niliOO :	STD_LOGIC;
	 SIGNAL  nill0i :	STD_LOGIC;
	 SIGNAL  nill0l :	STD_LOGIC;
	 SIGNAL  nill0O :	STD_LOGIC;
	 SIGNAL  nill1i :	STD_LOGIC;
	 SIGNAL  nill1l :	STD_LOGIC;
	 SIGNAL  nill1O :	STD_LOGIC;
	 SIGNAL  nillii :	STD_LOGIC;
	 SIGNAL  nillil :	STD_LOGIC;
	 SIGNAL  nilliO :	STD_LOGIC;
	 SIGNAL  nillli :	STD_LOGIC;
	 SIGNAL  nillll :	STD_LOGIC;
	 SIGNAL  nilllO :	STD_LOGIC;
	 SIGNAL  nillOi :	STD_LOGIC;
	 SIGNAL  nillOl :	STD_LOGIC;
	 SIGNAL  nillOO :	STD_LOGIC;
	 SIGNAL  nilO0i :	STD_LOGIC;
	 SIGNAL  nilO0l :	STD_LOGIC;
	 SIGNAL  nilO0O :	STD_LOGIC;
	 SIGNAL  nilO1i :	STD_LOGIC;
	 SIGNAL  nilO1l :	STD_LOGIC;
	 SIGNAL  nilO1O :	STD_LOGIC;
	 SIGNAL  nilOii :	STD_LOGIC;
	 SIGNAL  nilOil :	STD_LOGIC;
	 SIGNAL  nilOiO :	STD_LOGIC;
	 SIGNAL  nilOli :	STD_LOGIC;
	 SIGNAL  nilOOi :	STD_LOGIC;
	 SIGNAL  nilOOl :	STD_LOGIC;
	 SIGNAL  nilOOO :	STD_LOGIC;
	 SIGNAL  niO00i :	STD_LOGIC;
	 SIGNAL  niO00l :	STD_LOGIC;
	 SIGNAL  niO00O :	STD_LOGIC;
	 SIGNAL  niO0ii :	STD_LOGIC;
	 SIGNAL  niO0li :	STD_LOGIC;
	 SIGNAL  niO0Oi :	STD_LOGIC;
	 SIGNAL  niO0Ol :	STD_LOGIC;
	 SIGNAL  niO0OO :	STD_LOGIC;
	 SIGNAL  niO10i :	STD_LOGIC;
	 SIGNAL  niO11O :	STD_LOGIC;
	 SIGNAL  niO1ii :	STD_LOGIC;
	 SIGNAL  niO1il :	STD_LOGIC;
	 SIGNAL  niOi0O :	STD_LOGIC;
	 SIGNAL  niOi1O :	STD_LOGIC;
	 SIGNAL  niOiii :	STD_LOGIC;
	 SIGNAL  niOiil :	STD_LOGIC;
	 SIGNAL  niOiiO :	STD_LOGIC;
	 SIGNAL  niOilO :	STD_LOGIC;
	 SIGNAL  niOiOi :	STD_LOGIC;
	 SIGNAL  niOiOl :	STD_LOGIC;
	 SIGNAL  niOiOO :	STD_LOGIC;
	 SIGNAL  niOl0i :	STD_LOGIC;
	 SIGNAL  niOl1i :	STD_LOGIC;
	 SIGNAL  niOl1l :	STD_LOGIC;
	 SIGNAL  niOl1O :	STD_LOGIC;
	 SIGNAL  niOlii :	STD_LOGIC;
	 SIGNAL  niOlil :	STD_LOGIC;
	 SIGNAL  niOliO :	STD_LOGIC;
	 SIGNAL  niOllO :	STD_LOGIC;
	 SIGNAL  niOlOO :	STD_LOGIC;
	 SIGNAL  niOO0i :	STD_LOGIC;
	 SIGNAL  niOO0l :	STD_LOGIC;
	 SIGNAL  niOO0O :	STD_LOGIC;
	 SIGNAL  niOO1i :	STD_LOGIC;
	 SIGNAL  niOOiO :	STD_LOGIC;
	 SIGNAL  niOOli :	STD_LOGIC;
	 SIGNAL  niOOOi :	STD_LOGIC;
	 SIGNAL  niOOOl :	STD_LOGIC;
	 SIGNAL  wire_w_tx_ctl_range1w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tx_ctl_range2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tx_ctl_range4w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tx_ctl_range6w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tx_data_range389w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tx_data_range945w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tx_data_range944w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tx_data_range388w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tx_data_range1226w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tx_data_range1225w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tx_data_range667w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_tx_data_range666w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_gnd <= '0';
	wire_w_lg_w_lg_w_lg_w_lg_niO00O83w85w87w90w(0) <= wire_w_lg_w_lg_w_lg_niO00O83w85w87w(0) AND wire_niO01l26_w_lg_q89w(0);
	wire_w_lg_w_lg_w_lg_niliOO199w201w203w(0) <= wire_w_lg_w_lg_niliOO199w201w(0) AND wire_w_lg_niliOi202w(0);
	wire_w_lg_w_lg_w_lg_nilllO168w170w172w(0) <= wire_w_lg_w_lg_nilllO168w170w(0) AND wire_w_lg_nillli171w(0);
	wire_w_lg_w_lg_w_lg_nilOiO139w141w143w(0) <= wire_w_lg_w_lg_nilOiO139w141w(0) AND wire_w_lg_nilOii142w(0);
	wire_w_lg_w_lg_w_lg_niO00O83w85w87w(0) <= wire_w_lg_w_lg_niO00O83w85w(0) AND wire_w_lg_niO00i86w(0);
	wire_w_lg_w_lg_rd_enable_sync357w358w(0) <= wire_w_lg_rd_enable_sync357w(0) AND nil0lO;
	wire_w_lg_w_lg_w_tx_ctl_range4w22w23w(0) <= wire_w_lg_w_tx_ctl_range4w22w(0) AND niOO0i;
	wire_w_lg_w_lg_niliOO199w201w(0) <= wire_w_lg_niliOO199w(0) AND wire_w_lg_niliOl200w(0);
	wire_w_lg_w_lg_nilllO168w170w(0) <= wire_w_lg_nilllO168w(0) AND wire_w_lg_nillll169w(0);
	wire_w_lg_w_lg_nilOiO139w141w(0) <= wire_w_lg_nilOiO139w(0) AND wire_w_lg_nilOil140w(0);
	wire_w_lg_w_lg_niO00O83w85w(0) <= wire_w_lg_niO00O83w(0) AND wire_w_lg_niO00l84w(0);
	wire_w_lg_w_lg_rd_enable_sync235w355w(0) <= wire_w_lg_rd_enable_sync235w(0) AND nil0iO;
	wire_w_lg_w_lg_niOO1i223w224w(0) <= wire_w_lg_niOO1i223w(0) AND rxaui_s2gx_en;
	wire_w_lg_nil0lO1500w(0) <= nil0lO AND wire_w_lg_nil0Oi238w(0);
	wire_w_lg_niOiii208w(0) <= niOiii AND wire_w_lg_w_lg_niOiOO206w207w(0);
	wire_w_lg_niOiii226w(0) <= niOiii AND wire_w_lg_niOiOO225w(0);
	wire_w_lg_niOiiO176w(0) <= niOiiO AND wire_w_lg_nilliO175w(0);
	wire_w_lg_niOiOi147w(0) <= niOiOi AND wire_w_lg_nilO0O146w(0);
	wire_w_lg_rd_enable_sync357w(0) <= rd_enable_sync AND nil0iO;
	wire_w_lg_w_tx_ctl_range1w54w(0) <= wire_w_tx_ctl_range1w(0) AND wire_w_lg_niOi0O53w(0);
	wire_w_lg_w_tx_ctl_range1w32w(0) <= wire_w_tx_ctl_range1w(0) AND wire_w_lg_w_tx_ctl_range2w31w(0);
	wire_w_lg_w_tx_ctl_range1w97w(0) <= wire_w_tx_ctl_range1w(0) AND niOi0O;
	wire_w_lg_w_tx_ctl_range1w41w(0) <= wire_w_tx_ctl_range1w(0) AND niOlii;
	wire_w_lg_w_tx_ctl_range2w113w(0) <= wire_w_tx_ctl_range2w(0) AND wire_w_lg_niOiOl112w(0);
	wire_w_lg_w_tx_ctl_range4w151w(0) <= wire_w_tx_ctl_range4w(0) AND wire_w_lg_niOilO150w(0);
	wire_w_lg_w_tx_ctl_range4w48w(0) <= wire_w_tx_ctl_range4w(0) AND niOilO;
	wire_w_lg_w_tx_ctl_range4w22w(0) <= wire_w_tx_ctl_range4w(0) AND wire_w_tx_ctl_range6w(0);
	wire_w_lg_w_tx_ctl_range6w182w(0) <= wire_w_tx_ctl_range6w(0) AND wire_w_lg_niOiil181w(0);
	wire_w_lg_w_tx_ctl_range6w27w(0) <= wire_w_tx_ctl_range6w(0) AND niOlOO;
	wire_w_lg_w_tx_data_range389w1766w(0) <= wire_w_tx_data_range389w(0) AND wire_w_lg_w_tx_data_range388w1592w(0);
	wire_w_lg_w_tx_data_range945w1820w(0) <= wire_w_tx_data_range945w(0) AND wire_w_lg_w_tx_data_range944w1659w(0);
	wire_w_lg_w_tx_data_range1226w1835w(0) <= wire_w_tx_data_range1226w(0) AND wire_w_lg_w_tx_data_range1225w1697w(0);
	wire_w_lg_w_tx_data_range667w1797w(0) <= wire_w_tx_data_range667w(0) AND wire_w_lg_w_tx_data_range666w1621w(0);
	wire_w_lg_w_lg_niOiOO206w207w(0) <= NOT wire_w_lg_niOiOO206w(0);
	wire_w_lg_nil0Oi238w(0) <= NOT nil0Oi;
	wire_w_lg_nil0Ol236w(0) <= NOT nil0Ol;
	wire_w_lg_nil0OO234w(0) <= NOT nil0OO;
	wire_w_lg_niliOi202w(0) <= NOT niliOi;
	wire_w_lg_niliOl200w(0) <= NOT niliOl;
	wire_w_lg_niliOO199w(0) <= NOT niliOO;
	wire_w_lg_nill0i191w(0) <= NOT nill0i;
	wire_w_lg_nill0l189w(0) <= NOT nill0l;
	wire_w_lg_nill0O185w(0) <= NOT nill0O;
	wire_w_lg_nill1i197w(0) <= NOT nill1i;
	wire_w_lg_nill1l195w(0) <= NOT nill1l;
	wire_w_lg_nill1O193w(0) <= NOT nill1O;
	wire_w_lg_nillii183w(0) <= NOT nillii;
	wire_w_lg_nilliO175w(0) <= NOT nilliO;
	wire_w_lg_nillli171w(0) <= NOT nillli;
	wire_w_lg_nillll169w(0) <= NOT nillll;
	wire_w_lg_nilllO168w(0) <= NOT nilllO;
	wire_w_lg_nillOi166w(0) <= NOT nillOi;
	wire_w_lg_nillOl164w(0) <= NOT nillOl;
	wire_w_lg_nillOO162w(0) <= NOT nillOO;
	wire_w_lg_nilO0i152w(0) <= NOT nilO0i;
	wire_w_lg_nilO0O146w(0) <= NOT nilO0O;
	wire_w_lg_nilO1i160w(0) <= NOT nilO1i;
	wire_w_lg_nilO1l158w(0) <= NOT nilO1l;
	wire_w_lg_nilO1O154w(0) <= NOT nilO1O;
	wire_w_lg_nilOii142w(0) <= NOT nilOii;
	wire_w_lg_nilOil140w(0) <= NOT nilOil;
	wire_w_lg_nilOiO139w(0) <= NOT nilOiO;
	wire_w_lg_nilOli137w(0) <= NOT nilOli;
	wire_w_lg_nilOOi132w(0) <= NOT nilOOi;
	wire_w_lg_nilOOl130w(0) <= NOT nilOOl;
	wire_w_lg_nilOOO128w(0) <= NOT nilOOO;
	wire_w_lg_niO00i86w(0) <= NOT niO00i;
	wire_w_lg_niO00l84w(0) <= NOT niO00l;
	wire_w_lg_niO00O83w(0) <= NOT niO00O;
	wire_w_lg_niO0ii81w(0) <= NOT niO0ii;
	wire_w_lg_niO0li76w(0) <= NOT niO0li;
	wire_w_lg_niO0Oi71w(0) <= NOT niO0Oi;
	wire_w_lg_niO0Ol69w(0) <= NOT niO0Ol;
	wire_w_lg_niO0OO67w(0) <= NOT niO0OO;
	wire_w_lg_niO10i119w(0) <= NOT niO10i;
	wire_w_lg_niO11O123w(0) <= NOT niO11O;
	wire_w_lg_niO1ii114w(0) <= NOT niO1ii;
	wire_w_lg_niOi0O53w(0) <= NOT niOi0O;
	wire_w_lg_niOi1O60w(0) <= NOT niOi1O;
	wire_w_lg_niOiil181w(0) <= NOT niOiil;
	wire_w_lg_niOilO150w(0) <= NOT niOilO;
	wire_w_lg_niOiOl112w(0) <= NOT niOiOl;
	wire_w_lg_niOl1i156w(0) <= NOT niOl1i;
	wire_w_lg_niOl1O121w(0) <= NOT niOl1O;
	wire_w_lg_niOlii65w(0) <= NOT niOlii;
	wire_w_lg_niOlil1217w(0) <= NOT niOlil;
	wire_w_lg_niOliO55w(0) <= NOT niOliO;
	wire_w_lg_niOlOO187w(0) <= NOT niOlOO;
	wire_w_lg_niOOOi96w(0) <= NOT niOOOi;
	wire_w_lg_rd_enable_sync235w(0) <= NOT rd_enable_sync;
	wire_w_lg_rxaui_s2gx_en105w(0) <= NOT rxaui_s2gx_en;
	wire_w_lg_soft_reset230w(0) <= NOT soft_reset;
	wire_w_lg_w_tx_ctl_range2w31w(0) <= NOT wire_w_tx_ctl_range2w(0);
	wire_w_lg_w_tx_data_range944w1659w(0) <= NOT wire_w_tx_data_range944w(0);
	wire_w_lg_w_tx_data_range388w1592w(0) <= NOT wire_w_tx_data_range388w(0);
	wire_w_lg_w_tx_data_range1225w1697w(0) <= NOT wire_w_tx_data_range1225w(0);
	wire_w_lg_w_tx_data_range666w1621w(0) <= NOT wire_w_tx_data_range666w(0);
	wire_w_lg_w_lg_w_lg_w_lg_w_lg_niO00O83w85w87w90w91w(0) <= wire_w_lg_w_lg_w_lg_w_lg_niO00O83w85w87w90w(0) OR rxaui_s2gx_en;
	wire_w_lg_w_lg_w_lg_w_lg_niliOO199w201w203w204w(0) <= wire_w_lg_w_lg_w_lg_niliOO199w201w203w(0) OR rxaui_s2gx_en;
	wire_w_lg_w_lg_w_lg_w_lg_nilllO168w170w172w173w(0) <= wire_w_lg_w_lg_w_lg_nilllO168w170w172w(0) OR rxaui_s2gx_en;
	wire_w_lg_w_lg_w_lg_w_lg_nilOiO139w141w143w144w(0) <= wire_w_lg_w_lg_w_lg_nilOiO139w141w143w(0) OR rxaui_s2gx_en;
	wire_w_lg_w_lg_w_lg_rd_enable_sync235w355w356w(0) <= wire_w_lg_w_lg_rd_enable_sync235w355w(0) OR wire_nl1li_o;
	wire_w_lg_niOiOO225w(0) <= niOiOO OR niliii;
	wire_w_lg_niOiOO206w(0) <= niOiOO OR nilliO;
	wire_w_lg_niOO1i223w(0) <= niOO1i OR niliil;
	curr_state <= ( nll0O & nll0i & nll1O & nll1i);
	nil00O <= (nil0ii AND (wire_nll0l_w_lg_nilOi377w(0) AND wire_nll0l_w_lg_n0lOl378w(0)));
	nil01O <= (wire_w_lg_nil0lO1500w(0) AND (((wire_nll0l_w_lg_w_lg_w_lg_nll0O365w371w372w(0) AND wire_nll1l_w_lg_nll1i369w(0)) OR wire_nll0l_w_lg_w_lg_w_lg_w_lg_nll0O365w371w1503w1504w(0)) OR (niOli AND nil0ll)));
	nil0ii <= ((((((((((((((((wire_nliO0l_w_lg_w_lg_w_lg_w1866w1868w1870w1871w(0) AND wire_nliO0l_w_lg_nlilll1872w(0)) AND wire_nliO0l_w_lg_nlilli1874w(0)) AND wire_nliO0l_w_lg_nliliO1876w(0)) AND wire_nliO0l_w_lg_nlilil1878w(0)) AND wire_nliO0l_w_lg_nlilii1880w(0)) AND wire_nliO0l_w_lg_nlil0O1882w(0)) AND wire_nliO0l_w_lg_nlil0l1884w(0)) AND wire_nliO0l_w_lg_nlil0i1886w(0)) AND wire_nliO0l_w_lg_nlil1O1888w(0)) AND wire_nliO0l_w_lg_nlil1l1890w(0)) AND wire_nliO0l_w_lg_nlil1i1892w(0)) AND wire_nliO0l_w_lg_nliiOO1894w(0)) AND wire_nliO0l_w_lg_nliiOl1896w(0)) AND wire_nliO0l_w_lg_nliiOi1898w(0)) AND wire_nliO0l_w_lg_nliilO1900w(0)) AND wire_nliO0l_w_lg_nliill1902w(0));
	nil0il <= ((((wire_nll0l_w_lg_w_lg_w_lg_nll0O365w367w368w(0) AND wire_nll1l_w_lg_nll1i369w(0)) OR wire_nll0l_w_lg_w_lg_w_lg_w_lg_nll0O365w371w372w373w(0)) AND nil0lO) AND nliOii);
	nil0iO <= (wire_nll0l_w_lg_w_lg_w_lg_nll0O365w367w368w(0) AND nll1i);
	nil0li <= (nil0lO AND nil0ll);
	nil0ll <= ((wire_nll0l_w_lg_w_lg_nll0O365w367w(0) AND wire_nll1l_w_lg_nll1O1502w(0)) AND nll1i);
	nil0lO <= (niOOOi OR niOlil);
	nil0Oi <= ((((nli00i OR nli1ii) OR nli10O) OR nli10l) OR nli10i);
	nil0Ol <= (niOli AND wire_w_lg_nil0Oi238w(0));
	nil0OO <= (wire_w_lg_niOOOi96w(0) AND wire_w_lg_niOlil1217w(0));
	nili0l <= (wire_w_lg_w_lg_niOO1i223w224w(0) OR (wire_w_lg_niOiii226w(0) AND wire_w_lg_rxaui_s2gx_en105w(0)));
	nili0O <= ((niliil AND rxaui_s2gx_en) OR ((niOiiO AND niliii) AND wire_w_lg_rxaui_s2gx_en105w(0)));
	nili1l <= '1';
	niliii <= (niOl0i OR niOl1l);
	niliil <= (niOOiO OR niOO0l);
	niliiO <= (nilill OR ((niOl0i AND niOiOi) AND wire_w_lg_rxaui_s2gx_en105w(0)));
	nilili <= ((niOl0i AND wire_w_lg_rxaui_s2gx_en105w(0)) OR nilill);
	nilill <= (niOOiO AND rxaui_s2gx_en);
	nililO <= ((((((((((wire_w_lg_w_tx_ctl_range6w182w(0) AND wire_w_lg_nillii183w(0)) AND wire_w_lg_nill0O185w(0)) AND wire_w_lg_niOlOO187w(0)) AND wire_w_lg_nill0l189w(0)) AND wire_w_lg_nill0i191w(0)) AND wire_w_lg_nill1O193w(0)) AND wire_w_lg_nill1l195w(0)) AND wire_w_lg_nill1i197w(0)) AND wire_w_lg_w_lg_w_lg_w_lg_niliOO199w201w203w204w(0)) OR (wire_w_lg_niOiii208w(0) AND wire_w_lg_rxaui_s2gx_en105w(0)));
	niliOi <= ((((((((NOT tx_data(24)) AND wire_w_lg_w_tx_data_range1225w1697w(0)) AND tx_data(26)) AND tx_data(27)) AND tx_data(28)) AND tx_data(29)) AND (NOT tx_data(30))) AND tx_data(31));
	niliOl <= ((((((((NOT tx_data(24)) AND wire_w_lg_w_tx_data_range1225w1697w(0)) AND tx_data(26)) AND tx_data(27)) AND tx_data(28)) AND tx_data(29)) AND tx_data(30)) AND (NOT tx_data(31)));
	niliOO <= ((((((((NOT tx_data(24)) AND wire_w_lg_w_tx_data_range1225w1697w(0)) AND tx_data(26)) AND tx_data(27)) AND tx_data(28)) AND (NOT tx_data(29))) AND (NOT tx_data(30))) AND (NOT tx_data(31)));
	nill0i <= ((((((((NOT tx_data(24)) AND wire_w_lg_w_tx_data_range1225w1697w(0)) AND tx_data(26)) AND tx_data(27)) AND tx_data(28)) AND (NOT tx_data(29))) AND tx_data(30)) AND (NOT tx_data(31)));
	nill0l <= ((((((((NOT tx_data(24)) AND wire_w_lg_w_tx_data_range1225w1697w(0)) AND tx_data(26)) AND tx_data(27)) AND tx_data(28)) AND tx_data(29)) AND (NOT tx_data(30))) AND (NOT tx_data(31)));
	nill0O <= (((((((tx_data(24) AND tx_data(25)) AND (NOT tx_data(26))) AND tx_data(27)) AND tx_data(28)) AND tx_data(29)) AND tx_data(30)) AND tx_data(31));
	nill1i <= (((((((tx_data(24) AND tx_data(25)) AND tx_data(26)) AND (NOT tx_data(27))) AND tx_data(28)) AND tx_data(29)) AND tx_data(30)) AND tx_data(31));
	nill1l <= ((((((((NOT tx_data(24)) AND wire_w_lg_w_tx_data_range1225w1697w(0)) AND tx_data(26)) AND tx_data(27)) AND tx_data(28)) AND tx_data(29)) AND tx_data(30)) AND tx_data(31));
	nill1O <= ((((((((NOT tx_data(24)) AND wire_w_lg_w_tx_data_range1225w1697w(0)) AND tx_data(26)) AND tx_data(27)) AND tx_data(28)) AND (NOT tx_data(29))) AND tx_data(30)) AND tx_data(31));
	nillii <= ((((((((NOT tx_data(24)) AND wire_w_lg_w_tx_data_range1225w1697w(0)) AND tx_data(26)) AND tx_data(27)) AND tx_data(28)) AND (NOT tx_data(29))) AND (NOT tx_data(30))) AND tx_data(31));
	nillil <= ((((((((((wire_w_lg_w_tx_ctl_range4w151w(0) AND wire_w_lg_nilO0i152w(0)) AND wire_w_lg_nilO1O154w(0)) AND wire_w_lg_niOl1i156w(0)) AND wire_w_lg_nilO1l158w(0)) AND wire_w_lg_nilO1i160w(0)) AND wire_w_lg_nillOO162w(0)) AND wire_w_lg_nillOl164w(0)) AND wire_w_lg_nillOi166w(0)) AND wire_w_lg_w_lg_w_lg_w_lg_nilllO168w170w172w173w(0)) OR (wire_w_lg_niOiiO176w(0) AND wire_w_lg_rxaui_s2gx_en105w(0)));
	nilliO <= (niOl1l OR nilO0O);
	nillli <= ((((((((NOT tx_data(16)) AND wire_w_lg_w_tx_data_range944w1659w(0)) AND tx_data(18)) AND tx_data(19)) AND tx_data(20)) AND tx_data(21)) AND (NOT tx_data(22))) AND tx_data(23));
	nillll <= ((((((((NOT tx_data(16)) AND wire_w_lg_w_tx_data_range944w1659w(0)) AND tx_data(18)) AND tx_data(19)) AND tx_data(20)) AND tx_data(21)) AND tx_data(22)) AND (NOT tx_data(23)));
	nilllO <= ((((((((NOT tx_data(16)) AND wire_w_lg_w_tx_data_range944w1659w(0)) AND tx_data(18)) AND tx_data(19)) AND tx_data(20)) AND (NOT tx_data(21))) AND (NOT tx_data(22))) AND (NOT tx_data(23)));
	nillOi <= (((((((tx_data(16) AND tx_data(17)) AND tx_data(18)) AND (NOT tx_data(19))) AND tx_data(20)) AND tx_data(21)) AND tx_data(22)) AND tx_data(23));
	nillOl <= ((((((((NOT tx_data(16)) AND wire_w_lg_w_tx_data_range944w1659w(0)) AND tx_data(18)) AND tx_data(19)) AND tx_data(20)) AND tx_data(21)) AND tx_data(22)) AND tx_data(23));
	nillOO <= ((((((((NOT tx_data(16)) AND wire_w_lg_w_tx_data_range944w1659w(0)) AND tx_data(18)) AND tx_data(19)) AND tx_data(20)) AND (NOT tx_data(21))) AND tx_data(22)) AND tx_data(23));
	nilO0i <= ((((((((NOT tx_data(16)) AND wire_w_lg_w_tx_data_range944w1659w(0)) AND tx_data(18)) AND tx_data(19)) AND tx_data(20)) AND (NOT tx_data(21))) AND (NOT tx_data(22))) AND tx_data(23));
	nilO0l <= (((((((((((((wire_w_lg_w_tx_ctl_range2w113w(0) AND wire_w_lg_niO1ii114w(0)) AND (niO10l36 XOR niO10l35)) AND wire_w_lg_niO10i119w(0)) AND wire_w_lg_niOl1O121w(0)) AND wire_w_lg_niO11O123w(0)) AND (niO11i38 XOR niO11i37)) AND wire_w_lg_nilOOO128w(0)) AND wire_w_lg_nilOOl130w(0)) AND wire_w_lg_nilOOi132w(0)) AND (nilOll40 XOR nilOll39)) AND wire_w_lg_nilOli137w(0)) AND wire_w_lg_w_lg_w_lg_w_lg_nilOiO139w141w143w144w(0)) OR (wire_w_lg_niOiOi147w(0) AND wire_w_lg_rxaui_s2gx_en105w(0)));
	nilO0O <= (niOOOi OR niOl0i);
	nilO1i <= ((((((((NOT tx_data(16)) AND wire_w_lg_w_tx_data_range944w1659w(0)) AND tx_data(18)) AND tx_data(19)) AND tx_data(20)) AND (NOT tx_data(21))) AND tx_data(22)) AND (NOT tx_data(23)));
	nilO1l <= ((((((((NOT tx_data(16)) AND wire_w_lg_w_tx_data_range944w1659w(0)) AND tx_data(18)) AND tx_data(19)) AND tx_data(20)) AND tx_data(21)) AND (NOT tx_data(22))) AND (NOT tx_data(23)));
	nilO1O <= (((((((tx_data(16) AND tx_data(17)) AND (NOT tx_data(18))) AND tx_data(19)) AND tx_data(20)) AND tx_data(21)) AND tx_data(22)) AND tx_data(23));
	nilOii <= ((((((((NOT tx_data(8)) AND wire_w_lg_w_tx_data_range666w1621w(0)) AND tx_data(10)) AND tx_data(11)) AND tx_data(12)) AND tx_data(13)) AND (NOT tx_data(14))) AND tx_data(15));
	nilOil <= ((((((((NOT tx_data(8)) AND wire_w_lg_w_tx_data_range666w1621w(0)) AND tx_data(10)) AND tx_data(11)) AND tx_data(12)) AND tx_data(13)) AND tx_data(14)) AND (NOT tx_data(15)));
	nilOiO <= ((((((((NOT tx_data(8)) AND wire_w_lg_w_tx_data_range666w1621w(0)) AND tx_data(10)) AND tx_data(11)) AND tx_data(12)) AND (NOT tx_data(13))) AND (NOT tx_data(14))) AND (NOT tx_data(15)));
	nilOli <= (((((((tx_data(8) AND tx_data(9)) AND tx_data(10)) AND (NOT tx_data(11))) AND tx_data(12)) AND tx_data(13)) AND tx_data(14)) AND tx_data(15));
	nilOOi <= ((((((((NOT tx_data(8)) AND wire_w_lg_w_tx_data_range666w1621w(0)) AND tx_data(10)) AND tx_data(11)) AND tx_data(12)) AND tx_data(13)) AND tx_data(14)) AND tx_data(15));
	nilOOl <= ((((((((NOT tx_data(8)) AND wire_w_lg_w_tx_data_range666w1621w(0)) AND tx_data(10)) AND tx_data(11)) AND tx_data(12)) AND (NOT tx_data(13))) AND tx_data(14)) AND tx_data(15));
	nilOOO <= ((((((((NOT tx_data(8)) AND wire_w_lg_w_tx_data_range666w1621w(0)) AND tx_data(10)) AND tx_data(11)) AND tx_data(12)) AND (NOT tx_data(13))) AND tx_data(14)) AND (NOT tx_data(15)));
	niO00i <= ((((((((NOT tx_data(0)) AND wire_w_lg_w_tx_data_range388w1592w(0)) AND tx_data(2)) AND tx_data(3)) AND tx_data(4)) AND tx_data(5)) AND (NOT tx_data(6))) AND tx_data(7));
	niO00l <= ((((((((NOT tx_data(0)) AND wire_w_lg_w_tx_data_range388w1592w(0)) AND tx_data(2)) AND tx_data(3)) AND tx_data(4)) AND tx_data(5)) AND tx_data(6)) AND (NOT tx_data(7)));
	niO00O <= ((((((((NOT tx_data(0)) AND wire_w_lg_w_tx_data_range388w1592w(0)) AND tx_data(2)) AND tx_data(3)) AND tx_data(4)) AND (NOT tx_data(5))) AND (NOT tx_data(6))) AND (NOT tx_data(7)));
	niO0ii <= (((((((tx_data(0) AND tx_data(1)) AND tx_data(2)) AND (NOT tx_data(3))) AND tx_data(4)) AND tx_data(5)) AND tx_data(6)) AND tx_data(7));
	niO0li <= ((((((((NOT tx_data(0)) AND wire_w_lg_w_tx_data_range388w1592w(0)) AND tx_data(2)) AND tx_data(3)) AND tx_data(4)) AND tx_data(5)) AND tx_data(6)) AND tx_data(7));
	niO0Oi <= ((((((((NOT tx_data(0)) AND wire_w_lg_w_tx_data_range388w1592w(0)) AND tx_data(2)) AND tx_data(3)) AND tx_data(4)) AND (NOT tx_data(5))) AND tx_data(6)) AND tx_data(7));
	niO0Ol <= ((((((((NOT tx_data(0)) AND wire_w_lg_w_tx_data_range388w1592w(0)) AND tx_data(2)) AND tx_data(3)) AND tx_data(4)) AND (NOT tx_data(5))) AND tx_data(6)) AND (NOT tx_data(7)));
	niO0OO <= ((((((((NOT tx_data(0)) AND wire_w_lg_w_tx_data_range388w1592w(0)) AND tx_data(2)) AND tx_data(3)) AND tx_data(4)) AND tx_data(5)) AND (NOT tx_data(6))) AND (NOT tx_data(7)));
	niO10i <= (((((((tx_data(8) AND tx_data(9)) AND (NOT tx_data(10))) AND tx_data(11)) AND tx_data(12)) AND tx_data(13)) AND tx_data(14)) AND tx_data(15));
	niO11O <= ((((((((NOT tx_data(8)) AND wire_w_lg_w_tx_data_range666w1621w(0)) AND tx_data(10)) AND tx_data(11)) AND tx_data(12)) AND tx_data(13)) AND (NOT tx_data(14))) AND (NOT tx_data(15)));
	niO1ii <= ((((((((NOT tx_data(8)) AND wire_w_lg_w_tx_data_range666w1621w(0)) AND tx_data(10)) AND tx_data(11)) AND tx_data(12)) AND (NOT tx_data(13))) AND (NOT tx_data(14))) AND tx_data(15));
	niO1il <= ((((((((((((((((wire_w_lg_w_tx_ctl_range1w54w(0) AND wire_w_lg_niOliO55w(0)) AND (niOi0i18 XOR niOi0i17)) AND wire_w_lg_niOi1O60w(0)) AND (niOi1i20 XOR niOi1i19)) AND wire_w_lg_niOlii65w(0)) AND wire_w_lg_niO0OO67w(0)) AND wire_w_lg_niO0Ol69w(0)) AND wire_w_lg_niO0Oi71w(0)) AND (niO0ll22 XOR niO0ll21)) AND wire_w_lg_niO0li76w(0)) AND (niO0il24 XOR niO0il23)) AND wire_w_lg_niO0ii81w(0)) AND wire_w_lg_w_lg_w_lg_w_lg_w_lg_niO00O83w85w87w90w91w(0)) AND (niO1OO28 XOR niO1OO27)) OR (((wire_w_lg_niOOOi96w(0) AND (wire_w_lg_w_tx_ctl_range1w97w(0) AND (niO1Oi30 XOR niO1Oi29))) AND (niO1ll32 XOR niO1ll31)) AND wire_w_lg_rxaui_s2gx_en105w(0))) OR (NOT (niO1iO34 XOR niO1iO33)));
	niOi0O <= (((((((tx_data(0) AND tx_data(1)) AND tx_data(2)) AND (NOT tx_data(3))) AND (NOT tx_data(4))) AND (NOT tx_data(5))) AND (NOT tx_data(6))) AND (NOT tx_data(7)));
	niOi1O <= (((((((tx_data(0) AND tx_data(1)) AND (NOT tx_data(2))) AND tx_data(3)) AND tx_data(4)) AND tx_data(5)) AND tx_data(6)) AND tx_data(7));
	niOiii <= (tx_ctl(3) AND niOiil);
	niOiil <= (((((((tx_data(24) AND tx_data(25)) AND tx_data(26)) AND (NOT tx_data(27))) AND (NOT tx_data(28))) AND (NOT tx_data(29))) AND (NOT tx_data(30))) AND (NOT tx_data(31)));
	niOiiO <= (wire_w_lg_w_tx_ctl_range4w48w(0) AND (niOili16 XOR niOili15));
	niOilO <= (((((((tx_data(16) AND tx_data(17)) AND tx_data(18)) AND (NOT tx_data(19))) AND (NOT tx_data(20))) AND (NOT tx_data(21))) AND (NOT tx_data(22))) AND (NOT tx_data(23)));
	niOiOi <= (tx_ctl(1) AND niOiOl);
	niOiOl <= (((((((tx_data(8) AND tx_data(9)) AND tx_data(10)) AND (NOT tx_data(11))) AND (NOT tx_data(12))) AND (NOT tx_data(13))) AND (NOT tx_data(14))) AND (NOT tx_data(15)));
	niOiOO <= (tx_ctl(2) AND niOl1i);
	niOl0i <= (wire_w_lg_w_tx_ctl_range1w41w(0) AND (niOl0l14 XOR niOl0l13));
	niOl1i <= ((((((wire_w_lg_w_tx_data_range945w1820w(0) AND tx_data(18)) AND tx_data(19)) AND tx_data(20)) AND tx_data(21)) AND tx_data(22)) AND tx_data(23));
	niOl1l <= (tx_ctl(1) AND niOl1O);
	niOl1O <= ((((((wire_w_lg_w_tx_data_range667w1797w(0) AND tx_data(10)) AND tx_data(11)) AND tx_data(12)) AND tx_data(13)) AND tx_data(14)) AND tx_data(15));
	niOlii <= ((((((wire_w_lg_w_tx_data_range389w1766w(0) AND tx_data(2)) AND tx_data(3)) AND tx_data(4)) AND tx_data(5)) AND tx_data(6)) AND tx_data(7));
	niOlil <= ((((wire_w_lg_w_tx_ctl_range1w32w(0) AND (NOT tx_ctl(2))) AND (NOT tx_ctl(3))) AND (niOlli12 XOR niOlli11)) AND niOliO);
	niOliO <= ((((((((NOT tx_data(0)) AND wire_w_lg_w_tx_data_range388w1592w(0)) AND tx_data(2)) AND tx_data(3)) AND tx_data(4)) AND (NOT tx_data(5))) AND (NOT tx_data(6))) AND tx_data(7));
	niOllO <= (wire_w_lg_w_tx_ctl_range6w27w(0) AND (niOlOi10 XOR niOlOi9));
	niOlOO <= ((((((wire_w_lg_w_tx_data_range1226w1835w(0) AND tx_data(26)) AND tx_data(27)) AND tx_data(28)) AND tx_data(29)) AND tx_data(30)) AND tx_data(31));
	niOO0i <= ((((((((((((((wire_w_lg_w_tx_data_range945w1820w(0) AND tx_data(18)) AND tx_data(19)) AND tx_data(20)) AND tx_data(21)) AND tx_data(22)) AND tx_data(23)) AND tx_data(24)) AND tx_data(25)) AND tx_data(26)) AND (NOT tx_data(27))) AND (NOT tx_data(28))) AND (NOT tx_data(29))) AND (NOT tx_data(30))) AND (NOT tx_data(31)));
	niOO0l <= ((((tx_ctl(1) AND tx_ctl(2)) AND tx_ctl(3)) AND (niOOii6 XOR niOOii5)) AND niOO0O);
	niOO0O <= ((((((((((((((((((((((wire_w_lg_w_tx_data_range667w1797w(0) AND tx_data(10)) AND tx_data(11)) AND tx_data(12)) AND tx_data(13)) AND tx_data(14)) AND tx_data(15)) AND tx_data(16)) AND tx_data(17)) AND tx_data(18)) AND (NOT tx_data(19))) AND (NOT tx_data(20))) AND (NOT tx_data(21))) AND (NOT tx_data(22))) AND (NOT tx_data(23))) AND tx_data(24)) AND tx_data(25)) AND tx_data(26)) AND (NOT tx_data(27))) AND (NOT tx_data(28))) AND (NOT tx_data(29))) AND (NOT tx_data(30))) AND (NOT tx_data(31)));
	niOO1i <= (wire_w_lg_w_lg_w_tx_ctl_range4w22w23w(0) AND (niOO1l8 XOR niOO1l7));
	niOOiO <= (((((tx_ctl(0) AND tx_ctl(1)) AND tx_ctl(2)) AND tx_ctl(3)) AND (niOOll4 XOR niOOll3)) AND niOOli);
	niOOli <= ((((((((((((((((((((((((((((((wire_w_lg_w_tx_data_range389w1766w(0) AND tx_data(2)) AND tx_data(3)) AND tx_data(4)) AND tx_data(5)) AND tx_data(6)) AND tx_data(7)) AND tx_data(8)) AND tx_data(9)) AND tx_data(10)) AND (NOT tx_data(11))) AND (NOT tx_data(12))) AND (NOT tx_data(13))) AND (NOT tx_data(14))) AND (NOT tx_data(15))) AND tx_data(16)) AND tx_data(17)) AND tx_data(18)) AND (NOT tx_data(19))) AND (NOT tx_data(20))) AND (NOT tx_data(21))) AND (NOT tx_data(22))) AND (NOT tx_data(23))) AND tx_data(24)) AND tx_data(25)) AND tx_data(26)) AND (NOT tx_data(27))) AND (NOT tx_data(28))) AND (NOT tx_data(29))) AND (NOT tx_data(30))) AND (NOT tx_data(31)));
	niOOOi <= (((((tx_ctl(0) AND tx_ctl(1)) AND tx_ctl(2)) AND tx_ctl(3)) AND (niOOOO2 XOR niOOOO1)) AND niOOOl);
	niOOOl <= (((((((((((((((((((((((((((((((tx_data(0) AND tx_data(1)) AND tx_data(2)) AND (NOT tx_data(3))) AND (NOT tx_data(4))) AND (NOT tx_data(5))) AND (NOT tx_data(6))) AND (NOT tx_data(7))) AND tx_data(8)) AND tx_data(9)) AND tx_data(10)) AND (NOT tx_data(11))) AND (NOT tx_data(12))) AND (NOT tx_data(13))) AND (NOT tx_data(14))) AND (NOT tx_data(15))) AND tx_data(16)) AND tx_data(17)) AND tx_data(18)) AND (NOT tx_data(19))) AND (NOT tx_data(20))) AND (NOT tx_data(21))) AND (NOT tx_data(22))) AND (NOT tx_data(23))) AND tx_data(24)) AND tx_data(25)) AND tx_data(26)) AND (NOT tx_data(27))) AND (NOT tx_data(28))) AND (NOT tx_data(29))) AND (NOT tx_data(30))) AND (NOT tx_data(31)));
	sm_ctl <= ( nliOil & nll10i & nlO0li & n1ilO);
	sm_data <= ( nll11O & nll11l & nll11i & nliOOO & nliOOl & nliOOi & nliOlO & nliOll & nlO0iO & nlO0il & nlO0ii & nlO00O & nlO00l & nlO00i & nlO01O & nlO01l & n1ill & n1ili & n1iiO & n1iil & n1iii & n1i0O & n1i0l & n1i0i & n0lOi & n0llO & n0lll & n0lli & n0liO & n0lil & n0lii & n0l0O);
	tx_local_fault <= niOiO;
	tx_local_fault_det <= n0lOl;
	wire_w_tx_ctl_range1w(0) <= tx_ctl(0);
	wire_w_tx_ctl_range2w(0) <= tx_ctl(1);
	wire_w_tx_ctl_range4w(0) <= tx_ctl(2);
	wire_w_tx_ctl_range6w(0) <= tx_ctl(3);
	wire_w_tx_data_range389w(0) <= tx_data(0);
	wire_w_tx_data_range945w(0) <= tx_data(16);
	wire_w_tx_data_range944w(0) <= tx_data(17);
	wire_w_tx_data_range388w(0) <= tx_data(1);
	wire_w_tx_data_range1226w(0) <= tx_data(24);
	wire_w_tx_data_range1225w(0) <= tx_data(25);
	wire_w_tx_data_range667w(0) <= tx_data(8);
	wire_w_tx_data_range666w(0) <= tx_data(9);
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nil00i49 <= nil00i50;
		END IF;
		if (now = 0 ns) then
			nil00i49 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nil00i50 <= nil00i49;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nil00l47 <= nil00l48;
		END IF;
		if (now = 0 ns) then
			nil00l47 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nil00l48 <= nil00l47;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nili0i41 <= nili0i42;
		END IF;
		if (now = 0 ns) then
			nili0i41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nili0i42 <= nili0i41;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nili1i45 <= nili1i46;
		END IF;
		if (now = 0 ns) then
			nili1i45 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nili1i46 <= nili1i45;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nili1O43 <= nili1O44;
		END IF;
		if (now = 0 ns) then
			nili1O43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nili1O44 <= nili1O43;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nilOll39 <= nilOll40;
		END IF;
		if (now = 0 ns) then
			nilOll39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN nilOll40 <= nilOll39;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO01l25 <= niO01l26;
		END IF;
		if (now = 0 ns) then
			niO01l25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO01l26 <= niO01l25;
		END IF;
	END PROCESS;
	wire_niO01l26_w_lg_q89w(0) <= niO01l26 XOR niO01l25;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO0il23 <= niO0il24;
		END IF;
		if (now = 0 ns) then
			niO0il23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO0il24 <= niO0il23;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO0ll21 <= niO0ll22;
		END IF;
		if (now = 0 ns) then
			niO0ll21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO0ll22 <= niO0ll21;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO10l35 <= niO10l36;
		END IF;
		if (now = 0 ns) then
			niO10l35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO10l36 <= niO10l35;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO11i37 <= niO11i38;
		END IF;
		if (now = 0 ns) then
			niO11i37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO11i38 <= niO11i37;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO1iO33 <= niO1iO34;
		END IF;
		if (now = 0 ns) then
			niO1iO33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO1iO34 <= niO1iO33;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO1ll31 <= niO1ll32;
		END IF;
		if (now = 0 ns) then
			niO1ll31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO1ll32 <= niO1ll31;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO1Oi29 <= niO1Oi30;
		END IF;
		if (now = 0 ns) then
			niO1Oi29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO1Oi30 <= niO1Oi29;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO1OO27 <= niO1OO28;
		END IF;
		if (now = 0 ns) then
			niO1OO27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niO1OO28 <= niO1OO27;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOi0i17 <= niOi0i18;
		END IF;
		if (now = 0 ns) then
			niOi0i17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOi0i18 <= niOi0i17;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOi1i19 <= niOi1i20;
		END IF;
		if (now = 0 ns) then
			niOi1i19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOi1i20 <= niOi1i19;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOili15 <= niOili16;
		END IF;
		if (now = 0 ns) then
			niOili15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOili16 <= niOili15;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOl0l13 <= niOl0l14;
		END IF;
		if (now = 0 ns) then
			niOl0l13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOl0l14 <= niOl0l13;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOlli11 <= niOlli12;
		END IF;
		if (now = 0 ns) then
			niOlli11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOlli12 <= niOlli11;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOlOi10 <= niOlOi9;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOlOi9 <= niOlOi10;
		END IF;
		if (now = 0 ns) then
			niOlOi9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOO1l7 <= niOO1l8;
		END IF;
		if (now = 0 ns) then
			niOO1l7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOO1l8 <= niOO1l7;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOOii5 <= niOOii6;
		END IF;
		if (now = 0 ns) then
			niOOii5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOOii6 <= niOOii5;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOOll3 <= niOOll4;
		END IF;
		if (now = 0 ns) then
			niOOll3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOOll4 <= niOOll3;
		END IF;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOOOO1 <= niOOOO2;
		END IF;
		if (now = 0 ns) then
			niOOOO1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (tx_clk)
	BEGIN
		IF (tx_clk = '1' AND tx_clk'event) THEN niOOOO2 <= niOOOO1;
		END IF;
	END PROCESS;
	PROCESS (tx_clk, soft_reset, wire_nlilOi_CLRN)
	BEGIN
		IF (soft_reset = '1') THEN
				nlii0l <= '1';
				nlii0O <= '1';
				nliiii <= '1';
				nliili <= '1';
				nlilOl <= '1';
		ELSIF (wire_nlilOi_CLRN = '0') THEN
				nlii0l <= '0';
				nlii0O <= '0';
				nliiii <= '0';
				nliili <= '0';
				nlilOl <= '0';
		ELSIF (tx_clk = '1' AND tx_clk'event) THEN
			IF (niOlil = '1') THEN
				nlii0l <= tx_data(2);
				nlii0O <= tx_data(3);
				nliiii <= tx_data(4);
				nliili <= tx_data(7);
				nlilOl <= tx_data(25);
			END IF;
		END IF;
		if (now = 0 ns) then
			nlii0l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlii0O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nliiii <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nliili <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlilOl <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nlilOi_CLRN <= (nil00i50 XOR nil00i49);
	wire_nlilOi_w_lg_nlilOl1869w(0) <= NOT nlilOl;
	PROCESS (tx_clk, wire_nliO0l_CLRN)
	BEGIN
		IF (wire_nliO0l_CLRN = '0') THEN
				nlii0i <= '0';
				nlii1l <= '0';
				nliiil <= '0';
				nliiiO <= '0';
				nliill <= '0';
				nliilO <= '0';
				nliiOi <= '0';
				nliiOl <= '0';
				nliiOO <= '0';
				nlil0i <= '0';
				nlil0l <= '0';
				nlil0O <= '0';
				nlil1i <= '0';
				nlil1l <= '0';
				nlil1O <= '0';
				nlilii <= '0';
				nlilil <= '0';
				nliliO <= '0';
				nlilli <= '0';
				nlilll <= '0';
				nlillO <= '0';
				nlilOO <= '0';
				nliO0i <= '0';
				nliO0O <= '0';
				nliO1i <= '0';
				nliO1l <= '0';
				nliO1O <= '0';
		ELSIF (tx_clk = '1' AND tx_clk'event) THEN
			IF (niOlil = '1') THEN
				nlii0i <= tx_data(1);
				nlii1l <= tx_data(0);
				nliiil <= tx_data(5);
				nliiiO <= tx_data(6);
				nliill <= tx_data(8);
				nliilO <= tx_data(9);
				nliiOi <= tx_data(10);
				nliiOl <= tx_data(11);
				nliiOO <= tx_data(12);
				nlil0i <= tx_data(16);
				nlil0l <= tx_data(17);
				nlil0O <= tx_data(18);
				nlil1i <= tx_data(13);
				nlil1l <= tx_data(14);
				nlil1O <= tx_data(15);
				nlilii <= tx_data(19);
				nlilil <= tx_data(20);
				nliliO <= tx_data(21);
				nlilli <= tx_data(22);
				nlilll <= tx_data(23);
				nlillO <= tx_data(24);
				nlilOO <= tx_data(26);
				nliO0i <= tx_data(30);
				nliO0O <= tx_data(31);
				nliO1i <= tx_data(27);
				nliO1l <= tx_data(28);
				nliO1O <= tx_data(29);
			END IF;
		END IF;
	END PROCESS;
	wire_nliO0l_CLRN <= ((nil00l48 XOR nil00l47) AND wire_w_lg_soft_reset230w(0));
	wire_nliO0l_w_lg_w_lg_w_lg_w1866w1868w1870w1871w(0) <= wire_nliO0l_w_lg_w_lg_w1866w1868w1870w(0) AND nlillO;
	wire_nliO0l_w_lg_w_lg_w1866w1868w1870w(0) <= wire_nliO0l_w_lg_w1866w1868w(0) AND wire_nlilOi_w_lg_nlilOl1869w(0);
	wire_nliO0l_w_lg_w1866w1868w(0) <= wire_nliO0l_w1866w(0) AND wire_nliO0l_w_lg_nlilOO1867w(0);
	wire_nliO0l_w1866w(0) <= wire_nliO0l_w_lg_w_lg_w_lg_w_lg_nliO0O1858w1860w1862w1864w(0) AND wire_nliO0l_w_lg_nliO1i1865w(0);
	wire_nliO0l_w_lg_w_lg_w_lg_w_lg_nliO0O1858w1860w1862w1864w(0) <= wire_nliO0l_w_lg_w_lg_w_lg_nliO0O1858w1860w1862w(0) AND wire_nliO0l_w_lg_nliO1l1863w(0);
	wire_nliO0l_w_lg_w_lg_w_lg_nliO0O1858w1860w1862w(0) <= wire_nliO0l_w_lg_w_lg_nliO0O1858w1860w(0) AND wire_nliO0l_w_lg_nliO1O1861w(0);
	wire_nliO0l_w_lg_w_lg_nliO0O1858w1860w(0) <= wire_nliO0l_w_lg_nliO0O1858w(0) AND wire_nliO0l_w_lg_nliO0i1859w(0);
	wire_nliO0l_w_lg_nliill1902w(0) <= NOT nliill;
	wire_nliO0l_w_lg_nliilO1900w(0) <= NOT nliilO;
	wire_nliO0l_w_lg_nliiOi1898w(0) <= NOT nliiOi;
	wire_nliO0l_w_lg_nliiOl1896w(0) <= NOT nliiOl;
	wire_nliO0l_w_lg_nliiOO1894w(0) <= NOT nliiOO;
	wire_nliO0l_w_lg_nlil0i1886w(0) <= NOT nlil0i;
	wire_nliO0l_w_lg_nlil0l1884w(0) <= NOT nlil0l;
	wire_nliO0l_w_lg_nlil0O1882w(0) <= NOT nlil0O;
	wire_nliO0l_w_lg_nlil1i1892w(0) <= NOT nlil1i;
	wire_nliO0l_w_lg_nlil1l1890w(0) <= NOT nlil1l;
	wire_nliO0l_w_lg_nlil1O1888w(0) <= NOT nlil1O;
	wire_nliO0l_w_lg_nlilii1880w(0) <= NOT nlilii;
	wire_nliO0l_w_lg_nlilil1878w(0) <= NOT nlilil;
	wire_nliO0l_w_lg_nliliO1876w(0) <= NOT nliliO;
	wire_nliO0l_w_lg_nlilli1874w(0) <= NOT nlilli;
	wire_nliO0l_w_lg_nlilll1872w(0) <= NOT nlilll;
	wire_nliO0l_w_lg_nlilOO1867w(0) <= NOT nlilOO;
	wire_nliO0l_w_lg_nliO0i1859w(0) <= NOT nliO0i;
	wire_nliO0l_w_lg_nliO0O1858w(0) <= NOT nliO0O;
	wire_nliO0l_w_lg_nliO1i1865w(0) <= NOT nliO1i;
	wire_nliO0l_w_lg_nliO1l1863w(0) <= NOT nliO1l;
	wire_nliO0l_w_lg_nliO1O1861w(0) <= NOT nliO1O;
	PROCESS (tx_clk, wire_nll0l_PRN, wire_nll0l_CLRN)
	BEGIN
		IF (wire_nll0l_PRN = '0') THEN
				n0l0O <= '1';
				n0lii <= '1';
				n0llO <= '1';
				n0lOl <= '1';
				n1i0i <= '1';
				n1i0l <= '1';
				n1ili <= '1';
				nilOi <= '1';
				nilOl <= '1';
				niOil <= '1';
				niOiO <= '1';
				niOOi <= '1';
				nli00i <= '1';
				nli10i <= '1';
				nli10l <= '1';
				nli10O <= '1';
				nliOii <= '1';
				nliOll <= '1';
				nliOlO <= '1';
				nliOO <= '1';
				nll0i <= '1';
				nll0O <= '1';
				nll11l <= '1';
				nlO01l <= '1';
				nlO01O <= '1';
				nlO0il <= '1';
		ELSIF (wire_nll0l_CLRN = '0') THEN
				n0l0O <= '0';
				n0lii <= '0';
				n0llO <= '0';
				n0lOl <= '0';
				n1i0i <= '0';
				n1i0l <= '0';
				n1ili <= '0';
				nilOi <= '0';
				nilOl <= '0';
				niOil <= '0';
				niOiO <= '0';
				niOOi <= '0';
				nli00i <= '0';
				nli10i <= '0';
				nli10l <= '0';
				nli10O <= '0';
				nliOii <= '0';
				nliOll <= '0';
				nliOlO <= '0';
				nliOO <= '0';
				nll0i <= '0';
				nll0O <= '0';
				nll11l <= '0';
				nlO01l <= '0';
				nlO01O <= '0';
				nlO0il <= '0';
		ELSIF (tx_clk = '1' AND tx_clk'event) THEN
				n0l0O <= wire_n0O1i_dataout;
				n0lii <= wire_n0O1l_dataout;
				n0llO <= wire_n0Oii_dataout;
				n0lOl <= wire_nilOO_dataout;
				n1i0i <= wire_n1iOl_dataout;
				n1i0l <= wire_n1iOO_dataout;
				n1ili <= wire_n1l0l_dataout;
				nilOi <= wire_niO1i_dataout;
				nilOl <= niOil;
				niOil <= tx_local_fault_clr;
				niOiO <= wire_niOll_dataout;
				niOOi <= nliOO;
				nli00i <= wire_nli1iO_dataout;
				nli10i <= wire_nli1li_dataout;
				nli10l <= wire_nli1ll_dataout;
				nli10O <= wire_nli1lO_dataout;
				nliOii <= wire_nliOiO_dataout;
				nliOll <= wire_nll10O_dataout;
				nliOlO <= wire_nll1ii_dataout;
				nliOO <= indv;
				nll0i <= wire_nl1Ol_o;
				nll0O <= wire_nl1OO_dataout;
				nll11l <= wire_nll1lO_dataout;
				nlO01l <= wire_nlO0lO_dataout;
				nlO01O <= wire_nlO0Oi_dataout;
				nlO0il <= wire_nlOi1O_dataout;
		END IF;
	END PROCESS;
	wire_nll0l_CLRN <= ((nili0i42 XOR nili0i41) AND wire_w_lg_soft_reset230w(0));
	wire_nll0l_PRN <= (nili1O44 XOR nili1O43);
	wire_nll0l_w_lg_w_lg_w_lg_w_lg_nll0O365w371w1503w1504w(0) <= wire_nll0l_w_lg_w_lg_w_lg_nll0O365w371w1503w(0) AND nll1i;
	wire_nll0l_w_lg_w_lg_w_lg_w_lg_nll0O365w371w372w373w(0) <= wire_nll0l_w_lg_w_lg_w_lg_nll0O365w371w372w(0) AND nll1i;
	wire_nll0l_w_lg_w_lg_w_lg_nll0O365w367w368w(0) <= wire_nll0l_w_lg_w_lg_nll0O365w367w(0) AND nll1O;
	wire_nll0l_w_lg_w_lg_w_lg_nll0O365w371w1503w(0) <= wire_nll0l_w_lg_w_lg_nll0O365w371w(0) AND wire_nll1l_w_lg_nll1O1502w(0);
	wire_nll0l_w_lg_w_lg_w_lg_nll0O365w371w372w(0) <= wire_nll0l_w_lg_w_lg_nll0O365w371w(0) AND nll1O;
	wire_nll0l_w_lg_w_lg_nll0O365w367w(0) <= wire_nll0l_w_lg_nll0O365w(0) AND wire_nll0l_w_lg_nll0i366w(0);
	wire_nll0l_w_lg_w_lg_nll0O365w371w(0) <= wire_nll0l_w_lg_nll0O365w(0) AND nll0i;
	wire_nll0l_w_lg_n0lOl378w(0) <= NOT n0lOl;
	wire_nll0l_w_lg_nilOi377w(0) <= NOT nilOi;
	wire_nll0l_w_lg_nliOii237w(0) <= NOT nliOii;
	wire_nll0l_w_lg_nll0i366w(0) <= NOT nll0i;
	wire_nll0l_w_lg_nll0O365w(0) <= NOT nll0O;
	PROCESS (tx_clk, soft_reset, wire_nll1l_CLRN)
	BEGIN
		IF (soft_reset = '1') THEN
				n0lil <= '1';
				n0liO <= '1';
				n0lli <= '1';
				n0lll <= '1';
				n0lOi <= '1';
				n1i0O <= '1';
				n1iii <= '1';
				n1iil <= '1';
				n1iiO <= '1';
				n1ill <= '1';
				n1ilO <= '1';
				niOli <= '1';
				nli0ll <= '1';
				nli0lO <= '1';
				nli0Oi <= '1';
				nli0Ol <= '1';
				nli0OO <= '1';
				nli1ii <= '1';
				nli1il <= '1';
				nlii1i <= '1';
				nliOil <= '1';
				nliOOi <= '1';
				nliOOl <= '1';
				nliOOO <= '1';
				nll10i <= '1';
				nll11i <= '1';
				nll11O <= '1';
				nll1i <= '1';
				nll1O <= '1';
				nlO00i <= '1';
				nlO00l <= '1';
				nlO00O <= '1';
				nlO0ii <= '1';
				nlO0iO <= '1';
				nlO0li <= '1';
		ELSIF (wire_nll1l_CLRN = '0') THEN
				n0lil <= '0';
				n0liO <= '0';
				n0lli <= '0';
				n0lll <= '0';
				n0lOi <= '0';
				n1i0O <= '0';
				n1iii <= '0';
				n1iil <= '0';
				n1iiO <= '0';
				n1ill <= '0';
				n1ilO <= '0';
				niOli <= '0';
				nli0ll <= '0';
				nli0lO <= '0';
				nli0Oi <= '0';
				nli0Ol <= '0';
				nli0OO <= '0';
				nli1ii <= '0';
				nli1il <= '0';
				nlii1i <= '0';
				nliOil <= '0';
				nliOOi <= '0';
				nliOOl <= '0';
				nliOOO <= '0';
				nll10i <= '0';
				nll11i <= '0';
				nll11O <= '0';
				nll1i <= '0';
				nll1O <= '0';
				nlO00i <= '0';
				nlO00l <= '0';
				nlO00O <= '0';
				nlO0ii <= '0';
				nlO0iO <= '0';
				nlO0li <= '0';
		ELSIF (tx_clk = '1' AND tx_clk'event) THEN
				n0lil <= wire_n0O1O_dataout;
				n0liO <= wire_n0O0i_dataout;
				n0lli <= wire_n0O0l_dataout;
				n0lll <= wire_n0O0O_dataout;
				n0lOi <= wire_n0Oil_dataout;
				n1i0O <= wire_n1l1i_dataout;
				n1iii <= wire_n1l1l_dataout;
				n1iil <= wire_n1l1O_dataout;
				n1iiO <= wire_n1l0i_dataout;
				n1ill <= wire_n1l0O_dataout;
				n1ilO <= wire_n0lOO_dataout;
				niOli <= wire_niOOl_dataout;
				nli0ll <= nli1il;
				nli0lO <= nli0ll;
				nli0Oi <= nli0lO;
				nli0Ol <= nli0Oi;
				nli0OO <= nli0Ol;
				nli1ii <= wire_nli1Oi_dataout;
				nli1il <= (nlii1i XOR nli0OO);
				nlii1i <= nli0OO;
				nliOil <= wire_nll10l_dataout;
				nliOOi <= wire_nll1il_dataout;
				nliOOl <= wire_nll1iO_dataout;
				nliOOO <= wire_nll1li_dataout;
				nll10i <= wire_nlO0ll_dataout;
				nll11i <= wire_nll1ll_dataout;
				nll11O <= wire_nll1Oi_dataout;
				nll1i <= wire_nl1lO_o;
				nll1O <= wire_nl1Oi_o;
				nlO00i <= wire_nlO0Ol_dataout;
				nlO00l <= wire_nlO0OO_dataout;
				nlO00O <= wire_nlOi1i_dataout;
				nlO0ii <= wire_nlOi1l_dataout;
				nlO0iO <= wire_nlOi0i_dataout;
				nlO0li <= wire_n1iOi_dataout;
		END IF;
		if (now = 0 ns) then
			n0lil <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0liO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0lli <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0lll <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n0lOi <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n1i0O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n1iii <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n1iil <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n1iiO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n1ill <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n1ilO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			niOli <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nli0ll <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nli0lO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nli0Oi <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nli0Ol <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nli0OO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nli1ii <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nli1il <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlii1i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nliOil <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nliOOi <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nliOOl <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nliOOO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll10i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll11i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll11O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll1i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll1O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlO00i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlO00l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlO00O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlO0ii <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlO0iO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nlO0li <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_nll1l_CLRN <= (nili1i46 XOR nili1i45);
	wire_nll1l_w_lg_w_lg_w_lg_niOli360w361w362w(0) <= wire_nll1l_w_lg_w_lg_niOli360w361w(0) AND nil0li;
	wire_nll1l_w_lg_niOli360w(0) <= NOT niOli;
	wire_nll1l_w_lg_nli1il239w(0) <= NOT nli1il;
	wire_nll1l_w_lg_nll1i369w(0) <= NOT nll1i;
	wire_nll1l_w_lg_nll1O1502w(0) <= NOT nll1O;
	wire_nll1l_w_lg_w_lg_niOli360w361w(0) <= wire_nll1l_w_lg_niOli360w(0) OR nil0Oi;
	wire_n000i_dataout <= wire_n011i_dataout WHEN nil0OO = '1'  ELSE wire_n00lO_dataout;
	wire_n000l_dataout <= wire_n011l_dataout WHEN nil0OO = '1'  ELSE wire_n00Oi_dataout;
	wire_n000O_dataout <= wire_n011O_dataout WHEN nil0OO = '1'  ELSE wire_n00Ol_dataout;
	wire_n001i_dataout <= wire_n1OOi_dataout WHEN nil0OO = '1'  ELSE wire_n00iO_dataout;
	wire_n001l_dataout <= wire_n1OOl_dataout WHEN nil0OO = '1'  ELSE wire_n00li_dataout;
	wire_n001O_dataout <= wire_n1OOO_dataout WHEN nil0OO = '1'  ELSE wire_n00ll_dataout;
	wire_n00ii_dataout <= nliill AND nliOii;
	wire_n00il_dataout <= nliilO AND nliOii;
	wire_n00iO_dataout <= nliiOi OR NOT(nliOii);
	wire_n00li_dataout <= nliiOl OR NOT(nliOii);
	wire_n00ll_dataout <= nliiOO OR NOT(nliOii);
	wire_n00lO_dataout <= nlil1i WHEN nliOii = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_n00Oi_dataout <= nlil1l AND nliOii;
	wire_n00Ol_dataout <= nlil1O WHEN nliOii = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_n00OO_dataout <= wire_n011i_dataout WHEN nil0OO = '1'  ELSE wire_nllOll_dataout;
	wire_n010i_dataout <= tx_ctl(1) OR niOO0l;
	wire_n010l_dataout <= tx_data(8) OR niOO0l;
	wire_n010O_dataout <= tx_data(9) AND NOT(niOO0l);
	wire_n011i_dataout <= wire_n01li_dataout OR niliiO;
	wire_n011l_dataout <= wire_n01ll_dataout AND NOT(niliiO);
	wire_n011O_dataout <= wire_n01lO_dataout OR niliiO;
	wire_n01ii_dataout <= tx_data(10) OR niOO0l;
	wire_n01il_dataout <= tx_data(11) OR niOO0l;
	wire_n01iO_dataout <= tx_data(12) OR niOO0l;
	wire_n01li_dataout <= tx_data(13) OR niOO0l;
	wire_n01ll_dataout <= tx_data(14) OR niOO0l;
	wire_n01lO_dataout <= tx_data(15) OR niOO0l;
	wire_n01Oi_dataout <= wire_n1Oli_dataout WHEN nil0OO = '1'  ELSE wire_nll0l_w_lg_nliOii237w(0);
	wire_n01Ol_dataout <= wire_n1Oll_dataout WHEN nil0OO = '1'  ELSE wire_n00ii_dataout;
	wire_n01OO_dataout <= wire_n1OlO_dataout WHEN nil0OO = '1'  ELSE wire_n00il_dataout;
	wire_n0i0i_dataout <= wire_n011O_dataout AND nil0OO;
	wire_n0i0l_dataout <= wire_n011i_dataout WHEN nil0OO = '1'  ELSE wire_n0iii_dataout;
	wire_n0i0O_dataout <= wire_n011O_dataout WHEN nil0OO = '1'  ELSE wire_n0iil_dataout;
	wire_n0i1i_dataout <= wire_n011l_dataout WHEN nil0OO = '1'  ELSE wire_w_lg_nil0Oi238w(0);
	wire_n0i1l_dataout <= wire_n011O_dataout WHEN nil0OO = '1'  ELSE wire_nllOlO_dataout;
	wire_n0i1O_dataout <= wire_n011i_dataout AND nil0OO;
	wire_n0iii_dataout <= nlil1i AND nliOii;
	wire_n0iil_dataout <= nlil1O AND nliOii;
	wire_n0iiO_dataout <= wire_n011i_dataout OR NOT(nil0OO);
	wire_n0ili_dataout <= wire_n011l_dataout WHEN nil0OO = '1'  ELSE nil0Ol;
	wire_n0ill_dataout <= wire_n011O_dataout WHEN nil0OO = '1'  ELSE wire_w_lg_nil0Ol236w(0);
	wire_n0ilO_dataout <= wire_n1O1i_dataout OR NOT(rd_enable_sync);
	wire_n0iOi_dataout <= wire_n1O1l_dataout AND rd_enable_sync;
	wire_n0iOl_dataout <= wire_n1O1O_dataout AND rd_enable_sync;
	wire_n0iOO_dataout <= wire_n1O0i_dataout OR NOT(rd_enable_sync);
	wire_n0l0i_dataout <= wire_n1Oil_dataout AND rd_enable_sync;
	wire_n0l0l_dataout <= wire_n0i0i_dataout OR NOT(rd_enable_sync);
	wire_n0l1i_dataout <= wire_n1O0l_dataout OR NOT(rd_enable_sync);
	wire_n0l1l_dataout <= wire_n1O0O_dataout OR NOT(rd_enable_sync);
	wire_n0l1O_dataout <= wire_n0i1O_dataout OR NOT(rd_enable_sync);
	wire_n0lOO_dataout <= wire_n0OiO_o OR niO1il;
	wire_n0O0i_dataout <= wire_n0OOi_o OR niO1il;
	wire_n0O0l_dataout <= wire_n0OOl_o OR niO1il;
	wire_n0O0O_dataout <= wire_n0OOO_o OR niO1il;
	wire_n0O1i_dataout <= wire_n0Oli_o AND NOT(niO1il);
	wire_n0O1l_dataout <= wire_n0Oll_o OR niO1il;
	wire_n0O1O_dataout <= wire_n0OlO_o OR niO1il;
	wire_n0Oii_dataout <= wire_ni11i_o OR niO1il;
	wire_n0Oil_dataout <= wire_ni11l_o OR niO1il;
	wire_n100i_dataout <= wire_nlOO1i_dataout WHEN nil0OO = '1'  ELSE wire_n100O_dataout;
	wire_n100l_dataout <= nliliO AND nliOii;
	wire_n100O_dataout <= nlilll AND nliOii;
	wire_n101i_dataout <= wire_nlOlOl_dataout AND nil0OO;
	wire_n101l_dataout <= wire_nlOO1i_dataout AND nil0OO;
	wire_n101O_dataout <= wire_nlOlOl_dataout WHEN nil0OO = '1'  ELSE wire_n100l_dataout;
	wire_n10ii_dataout <= wire_nlOlOl_dataout OR NOT(nil0OO);
	wire_n10il_dataout <= wire_nlOlOO_dataout WHEN nil0OO = '1'  ELSE nil0Ol;
	wire_n10iO_dataout <= wire_nlOO1i_dataout WHEN nil0OO = '1'  ELSE wire_w_lg_nil0Ol236w(0);
	wire_n10li_dataout <= wire_nlOiOl_dataout OR NOT(rd_enable_sync);
	wire_n10ll_dataout <= wire_nlOiOO_dataout AND rd_enable_sync;
	wire_n10lO_dataout <= wire_nlOl1i_dataout AND rd_enable_sync;
	wire_n10Oi_dataout <= wire_nlOl1l_dataout OR NOT(rd_enable_sync);
	wire_n10Ol_dataout <= wire_nlOl1O_dataout OR NOT(rd_enable_sync);
	wire_n10OO_dataout <= wire_nlOl0i_dataout OR NOT(rd_enable_sync);
	wire_n110i_dataout <= wire_nlOO1i_dataout WHEN nil0OO = '1'  ELSE wire_n11lO_dataout;
	wire_n110l_dataout <= nlil0i AND nliOii;
	wire_n110O_dataout <= nlil0l AND nliOii;
	wire_n111i_dataout <= wire_nlOlOi_dataout WHEN nil0OO = '1'  ELSE wire_n11iO_dataout;
	wire_n111l_dataout <= wire_nlOlOl_dataout WHEN nil0OO = '1'  ELSE wire_n11li_dataout;
	wire_n111O_dataout <= wire_nlOlOO_dataout WHEN nil0OO = '1'  ELSE wire_n11ll_dataout;
	wire_n11ii_dataout <= nlil0O OR NOT(nliOii);
	wire_n11il_dataout <= nlilii OR NOT(nliOii);
	wire_n11iO_dataout <= nlilil OR NOT(nliOii);
	wire_n11li_dataout <= nliliO WHEN nliOii = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_n11ll_dataout <= nlilli AND nliOii;
	wire_n11lO_dataout <= nlilll WHEN nliOii = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_n11Oi_dataout <= wire_nlOlOl_dataout WHEN nil0OO = '1'  ELSE wire_nllOll_dataout;
	wire_n11Ol_dataout <= wire_nlOlOO_dataout WHEN nil0OO = '1'  ELSE wire_w_lg_nil0Oi238w(0);
	wire_n11OO_dataout <= wire_nlOO1i_dataout WHEN nil0OO = '1'  ELSE wire_nllOlO_dataout;
	wire_n1i1i_dataout <= wire_n101i_dataout OR NOT(rd_enable_sync);
	wire_n1i1l_dataout <= wire_nlOl0O_dataout AND rd_enable_sync;
	wire_n1i1O_dataout <= wire_n101l_dataout OR NOT(rd_enable_sync);
	wire_n1iOi_dataout <= wire_n1lii_o OR nilO0l;
	wire_n1iOl_dataout <= wire_n1lil_o AND NOT(nilO0l);
	wire_n1iOO_dataout <= wire_n1liO_o OR nilO0l;
	wire_n1l0i_dataout <= wire_n1lOi_o OR nilO0l;
	wire_n1l0l_dataout <= wire_n1lOl_o OR nilO0l;
	wire_n1l0O_dataout <= wire_n1lOO_o OR nilO0l;
	wire_n1l1i_dataout <= wire_n1lli_o OR nilO0l;
	wire_n1l1l_dataout <= wire_n1lll_o OR nilO0l;
	wire_n1l1O_dataout <= wire_n1llO_o OR nilO0l;
	wire_n1O0i_dataout <= wire_n1OOi_dataout OR NOT(nil0OO);
	wire_n1O0l_dataout <= wire_n1OOl_dataout OR NOT(nil0OO);
	wire_n1O0O_dataout <= wire_n1OOO_dataout OR NOT(nil0OO);
	wire_n1O1i_dataout <= wire_n1Oli_dataout OR NOT(nil0OO);
	wire_n1O1l_dataout <= wire_n1Oll_dataout AND nil0OO;
	wire_n1O1O_dataout <= wire_n1OlO_dataout AND nil0OO;
	wire_n1Oii_dataout <= wire_n011i_dataout WHEN nil0OO = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_n1Oil_dataout <= wire_n011l_dataout AND nil0OO;
	wire_n1OiO_dataout <= wire_n011O_dataout WHEN nil0OO = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_n1Oli_dataout <= wire_n010i_dataout OR niliiO;
	wire_n1Oll_dataout <= wire_n010l_dataout AND NOT(niliiO);
	wire_n1OlO_dataout <= wire_n010O_dataout AND NOT(niliiO);
	wire_n1OOi_dataout <= wire_n01ii_dataout OR niliiO;
	wire_n1OOl_dataout <= wire_n01il_dataout OR niliiO;
	wire_n1OOO_dataout <= wire_n01iO_dataout OR niliiO;
	wire_ni00i_dataout <= tx_data(6) OR nilili;
	wire_ni00l_dataout <= tx_data(7) OR nilili;
	wire_ni00O_dataout <= wire_ni1Oi_dataout WHEN nil0OO = '1'  ELSE wire_ni0Ol_dataout;
	wire_ni01i_dataout <= tx_data(3) OR nilili;
	wire_ni01l_dataout <= tx_data(4) OR nilili;
	wire_ni01O_dataout <= tx_data(5) OR nilili;
	wire_ni0ii_dataout <= wire_ni1Ol_dataout WHEN nil0OO = '1'  ELSE wire_ni0OO_dataout;
	wire_ni0il_dataout <= wire_ni1OO_dataout WHEN nil0OO = '1'  ELSE wire_nii1i_dataout;
	wire_ni0iO_dataout <= wire_ni01i_dataout WHEN nil0OO = '1'  ELSE wire_nii1l_dataout;
	wire_ni0li_dataout <= wire_ni01l_dataout WHEN nil0OO = '1'  ELSE wire_nii1O_dataout;
	wire_ni0ll_dataout <= wire_ni01O_dataout WHEN nil0OO = '1'  ELSE wire_nii0i_dataout;
	wire_ni0lO_dataout <= wire_ni00i_dataout WHEN nil0OO = '1'  ELSE wire_nii0l_dataout;
	wire_ni0Oi_dataout <= wire_ni00l_dataout WHEN nil0OO = '1'  ELSE wire_nii0O_dataout;
	wire_ni0Ol_dataout <= nlii1l AND nliOii;
	wire_ni0OO_dataout <= nlii0i AND nliOii;
	wire_ni10i_dataout <= wire_ni1Oi_dataout AND nil0OO;
	wire_ni10l_dataout <= wire_ni1Ol_dataout AND nil0OO;
	wire_ni10O_dataout <= wire_ni1OO_dataout OR NOT(nil0OO);
	wire_ni11O_dataout <= wire_ni1lO_dataout OR NOT(nil0OO);
	wire_ni1ii_dataout <= wire_ni01i_dataout OR NOT(nil0OO);
	wire_ni1il_dataout <= wire_ni01l_dataout OR NOT(nil0OO);
	wire_ni1iO_dataout <= wire_ni01O_dataout WHEN nil0OO = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_ni1li_dataout <= wire_ni00i_dataout AND nil0OO;
	wire_ni1ll_dataout <= wire_ni00l_dataout WHEN nil0OO = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_ni1lO_dataout <= tx_ctl(0) OR nilili;
	wire_ni1Oi_dataout <= tx_data(0) OR nilili;
	wire_ni1Ol_dataout <= tx_data(1) AND NOT(nilili);
	wire_ni1OO_dataout <= tx_data(2) OR nilili;
	wire_nii0i_dataout <= nliiil WHEN nliOii = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_nii0l_dataout <= nliiiO AND nliOii;
	wire_nii0O_dataout <= nliili WHEN nliOii = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_nii1i_dataout <= nlii0l OR NOT(nliOii);
	wire_nii1l_dataout <= nlii0O OR NOT(nliOii);
	wire_nii1O_dataout <= nliiii OR NOT(nliOii);
	wire_niiii_dataout <= wire_ni01O_dataout WHEN nil0OO = '1'  ELSE wire_nllOll_dataout;
	wire_niiil_dataout <= wire_ni00i_dataout WHEN nil0OO = '1'  ELSE wire_w_lg_nil0Oi238w(0);
	wire_niiiO_dataout <= wire_ni00l_dataout WHEN nil0OO = '1'  ELSE wire_nllOlO_dataout;
	wire_niili_dataout <= wire_ni01O_dataout AND nil0OO;
	wire_niill_dataout <= wire_ni00l_dataout AND nil0OO;
	wire_niilO_dataout <= wire_ni01O_dataout WHEN nil0OO = '1'  ELSE wire_niiOl_dataout;
	wire_niiOi_dataout <= wire_ni00l_dataout WHEN nil0OO = '1'  ELSE wire_niiOO_dataout;
	wire_niiOl_dataout <= nliiil AND nliOii;
	wire_niiOO_dataout <= nliili AND nliOii;
	wire_nil0i_dataout <= wire_ni11O_dataout OR NOT(rd_enable_sync);
	wire_nil0l_dataout <= wire_ni10i_dataout AND rd_enable_sync;
	wire_nil0O_dataout <= wire_ni10l_dataout AND rd_enable_sync;
	wire_nil1i_dataout <= wire_ni01O_dataout OR NOT(nil0OO);
	wire_nil1l_dataout <= wire_ni00i_dataout WHEN nil0OO = '1'  ELSE nil0Ol;
	wire_nil1O_dataout <= wire_ni00l_dataout WHEN nil0OO = '1'  ELSE wire_w_lg_nil0Ol236w(0);
	wire_nilii_dataout <= wire_ni10O_dataout OR NOT(rd_enable_sync);
	wire_nilil_dataout <= wire_ni1ii_dataout OR NOT(rd_enable_sync);
	wire_niliO_dataout <= wire_ni1il_dataout OR NOT(rd_enable_sync);
	wire_nilli_dataout <= wire_niili_dataout OR NOT(rd_enable_sync);
	wire_nilll_dataout <= wire_ni1li_dataout AND rd_enable_sync;
	wire_nillO_dataout <= wire_niill_dataout OR NOT(rd_enable_sync);
	wire_nilOO_dataout <= wire_niO1l_dataout AND nil0il;
	wire_niO1i_dataout <= nil00O AND nil0il;
	wire_niO1l_dataout <= (nilOi AND n0lOl) OR nil00O;
	wire_niOll_dataout <= wire_niOlO_dataout AND NOT(nilOl);
	wire_niOlO_dataout <= niOiO OR nilOi;
	wire_niOOl_dataout <= wire_niOOO_dataout OR ((wire_w_lg_w_lg_w_lg_rd_enable_sync235w355w356w(0) OR wire_w_lg_w_lg_rd_enable_sync357w358w(0)) OR wire_nll1l_w_lg_w_lg_w_lg_niOli360w361w362w(0));
	wire_niOOO_dataout <= niOli AND NOT((nil0li AND nil0Ol));
	wire_nl00i_dataout <= wire_w_lg_nil0OO234w(0) AND NOT(niOOi);
	wire_nl00l_dataout <= nli1il OR nil0OO;
	wire_nl00O_dataout <= wire_nll1l_w_lg_nli1il239w(0) AND NOT(nil0OO);
	wire_nl01l_dataout <= wire_nl00l_dataout OR niOOi;
	wire_nl01O_dataout <= wire_nl00O_dataout OR niOOi;
	wire_nl0ii_dataout <= wire_nl0ll_dataout OR niOOi;
	wire_nl0il_dataout <= wire_nl0lO_dataout OR niOOi;
	wire_nl0iO_dataout <= wire_nl0Oi_dataout AND NOT(niOOi);
	wire_nl0li_dataout <= wire_nl0Ol_dataout AND NOT(niOOi);
	wire_nl0ll_dataout <= wire_nl0OO_dataout OR nil0OO;
	wire_nl0lO_dataout <= wire_nli1i_dataout AND NOT(nil0OO);
	wire_nl0Oi_dataout <= wire_nll0l_w_lg_nliOii237w(0) AND NOT(nil0OO);
	wire_nl0Ol_dataout <= nliOii AND NOT(nil0OO);
	wire_nl0OO_dataout <= nli1il AND NOT(nliOii);
	wire_nl1OO_dataout <= wire_nl0li_dataout AND wire_nl01i_o(7);
	wire_nli01i_dataout <= wire_nli00l_o(3) WHEN nil0Oi = '1'  ELSE nli10l;
	wire_nli01l_dataout <= wire_nli00l_o(4) WHEN nil0Oi = '1'  ELSE nli10O;
	wire_nli01O_dataout <= wire_nli00l_o(5) WHEN nil0Oi = '1'  ELSE nli1ii;
	wire_nli0i_dataout <= wire_nli0O_dataout OR nil0OO;
	wire_nli0l_dataout <= wire_nllOll_dataout AND NOT(nil0OO);
	wire_nli0O_dataout <= nli1il OR wire_w_lg_nil0Oi238w(0);
	wire_nli1i_dataout <= wire_nll1l_w_lg_nli1il239w(0) AND NOT(nliOii);
	wire_nli1iO_dataout <= nli1il WHEN nil01O = '1'  ELSE wire_nli1Ol_dataout;
	wire_nli1l_dataout <= wire_nli0i_dataout OR niOOi;
	wire_nli1li_dataout <= nli0ll WHEN nil01O = '1'  ELSE wire_nli1OO_dataout;
	wire_nli1ll_dataout <= nli0lO WHEN nil01O = '1'  ELSE wire_nli01i_dataout;
	wire_nli1lO_dataout <= nli0Oi WHEN nil01O = '1'  ELSE wire_nli01l_dataout;
	wire_nli1O_dataout <= wire_nli0l_dataout OR niOOi;
	wire_nli1Oi_dataout <= wire_nli01O_dataout OR nil01O;
	wire_nli1Ol_dataout <= wire_nli00l_o(1) WHEN nil0Oi = '1'  ELSE nli00i;
	wire_nli1OO_dataout <= wire_nli00l_o(2) WHEN nil0Oi = '1'  ELSE nli10i;
	wire_nliii_dataout <= wire_nliil_dataout OR niOOi;
	wire_nliil_dataout <= wire_nll0l_w_lg_nliOii237w(0) OR nil0OO;
	wire_nliiO_dataout <= wire_nlill_dataout OR niOOi;
	wire_nlili_dataout <= wire_w_lg_nil0OO234w(0) OR niOOi;
	wire_nlill_dataout <= wire_w_lg_nil0Ol236w(0) OR nil0OO;
	wire_nlilO_dataout <= wire_w_lg_rd_enable_sync235w(0) OR niOOi;
	wire_nliOi_dataout <= wire_nliOl_dataout AND NOT(niOOi);
	wire_nliOiO_dataout <= wire_nliOli_dataout OR niOlil;
	wire_nliOl_dataout <= wire_w_lg_nil0OO234w(0) AND rd_enable_sync;
	wire_nliOli_dataout <= nliOii AND NOT(nil0il);
	wire_nll0il_dataout <= wire_nlli1l_dataout OR NOT(nil0OO);
	wire_nll0iO_dataout <= wire_nlli1O_dataout AND nil0OO;
	wire_nll0li_dataout <= wire_nlli0i_dataout AND nil0OO;
	wire_nll0ll_dataout <= wire_nlli0l_dataout OR NOT(nil0OO);
	wire_nll0lO_dataout <= wire_nlli0O_dataout OR NOT(nil0OO);
	wire_nll0Oi_dataout <= wire_nlliii_dataout OR NOT(nil0OO);
	wire_nll0Ol_dataout <= wire_nlliil_dataout WHEN nil0OO = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_nll0OO_dataout <= wire_nlliiO_dataout AND nil0OO;
	wire_nll10l_dataout <= wire_nll1Ol_o OR nililO;
	wire_nll10O_dataout <= wire_nll1OO_o AND NOT(nililO);
	wire_nll1ii_dataout <= wire_nll01i_o OR nililO;
	wire_nll1il_dataout <= wire_nll01l_o OR nililO;
	wire_nll1iO_dataout <= wire_nll01O_o OR nililO;
	wire_nll1li_dataout <= wire_nll00i_o OR nililO;
	wire_nll1ll_dataout <= wire_nll00l_o OR nililO;
	wire_nll1lO_dataout <= wire_nll00O_o OR nililO;
	wire_nll1Oi_dataout <= wire_nll0ii_o OR nililO;
	wire_nlli0i_dataout <= wire_nlliOi_dataout AND NOT(nili0l);
	wire_nlli0l_dataout <= wire_nlliOl_dataout OR nili0l;
	wire_nlli0O_dataout <= wire_nlliOO_dataout OR nili0l;
	wire_nlli1i_dataout <= wire_nllili_dataout WHEN nil0OO = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_nlli1l_dataout <= wire_nllill_dataout OR nili0l;
	wire_nlli1O_dataout <= wire_nllilO_dataout AND NOT(nili0l);
	wire_nlliii_dataout <= wire_nlll1i_dataout OR nili0l;
	wire_nlliil_dataout <= wire_nlll1l_dataout OR nili0l;
	wire_nlliiO_dataout <= wire_nlll1O_dataout AND NOT(nili0l);
	wire_nllili_dataout <= wire_nlll0i_dataout OR nili0l;
	wire_nllill_dataout <= tx_ctl(3) OR niOllO;
	wire_nllilO_dataout <= tx_data(24) OR niOllO;
	wire_nlliOi_dataout <= tx_data(25) AND NOT(niOllO);
	wire_nlliOl_dataout <= tx_data(26) OR niOllO;
	wire_nlliOO_dataout <= tx_data(27) OR niOllO;
	wire_nlll0i_dataout <= tx_data(31) OR niOllO;
	wire_nlll0O_dataout <= wire_nlli1l_dataout WHEN nil0OO = '1'  ELSE wire_nll0l_w_lg_nliOii237w(0);
	wire_nlll1i_dataout <= tx_data(28) OR niOllO;
	wire_nlll1l_dataout <= tx_data(29) OR niOllO;
	wire_nlll1O_dataout <= tx_data(30) OR niOllO;
	wire_nlllii_dataout <= wire_nlli1O_dataout WHEN nil0OO = '1'  ELSE wire_nlllOO_dataout;
	wire_nlllil_dataout <= wire_nlli0i_dataout WHEN nil0OO = '1'  ELSE wire_nllO1i_dataout;
	wire_nllliO_dataout <= wire_nlli0l_dataout WHEN nil0OO = '1'  ELSE wire_nllO1l_dataout;
	wire_nlllli_dataout <= wire_nlli0O_dataout WHEN nil0OO = '1'  ELSE wire_nllO1O_dataout;
	wire_nlllll_dataout <= wire_nlliii_dataout WHEN nil0OO = '1'  ELSE wire_nllO0i_dataout;
	wire_nllllO_dataout <= wire_nlliil_dataout WHEN nil0OO = '1'  ELSE wire_nllO0l_dataout;
	wire_nlllOi_dataout <= wire_nlliiO_dataout WHEN nil0OO = '1'  ELSE wire_nllO0O_dataout;
	wire_nlllOl_dataout <= wire_nllili_dataout WHEN nil0OO = '1'  ELSE wire_nllOii_dataout;
	wire_nlllOO_dataout <= nlillO AND nliOii;
	wire_nllO0i_dataout <= nliO1l OR NOT(nliOii);
	wire_nllO0l_dataout <= nliO1O WHEN nliOii = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_nllO0O_dataout <= nliO0i AND nliOii;
	wire_nllO1i_dataout <= nlilOl AND nliOii;
	wire_nllO1l_dataout <= nlilOO OR NOT(nliOii);
	wire_nllO1O_dataout <= nliO1i OR NOT(nliOii);
	wire_nllOii_dataout <= nliO0O WHEN nliOii = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_nllOil_dataout <= wire_nlliil_dataout WHEN nil0OO = '1'  ELSE wire_nllOll_dataout;
	wire_nllOiO_dataout <= wire_nlliiO_dataout WHEN nil0OO = '1'  ELSE wire_w_lg_nil0Oi238w(0);
	wire_nllOli_dataout <= wire_nllili_dataout WHEN nil0OO = '1'  ELSE wire_nllOlO_dataout;
	wire_nllOll_dataout <= wire_nll1l_w_lg_nli1il239w(0) OR wire_w_lg_nil0Oi238w(0);
	wire_nllOlO_dataout <= wire_nll1l_w_lg_nli1il239w(0) AND NOT(wire_w_lg_nil0Oi238w(0));
	wire_nllOOi_dataout <= wire_nlliil_dataout AND nil0OO;
	wire_nllOOl_dataout <= wire_nllili_dataout AND nil0OO;
	wire_nllOOO_dataout <= wire_nlliil_dataout WHEN nil0OO = '1'  ELSE wire_nlO11l_dataout;
	wire_nlO01i_dataout <= wire_nllOOl_dataout OR NOT(rd_enable_sync);
	wire_nlO0ll_dataout <= wire_nlOi0l_o OR nillil;
	wire_nlO0lO_dataout <= wire_nlOi0O_o AND NOT(nillil);
	wire_nlO0Oi_dataout <= wire_nlOiii_o OR nillil;
	wire_nlO0Ol_dataout <= wire_nlOiil_o OR nillil;
	wire_nlO0OO_dataout <= wire_nlOiiO_o OR nillil;
	wire_nlO10i_dataout <= wire_nlliil_dataout OR NOT(nil0OO);
	wire_nlO10l_dataout <= wire_nlliiO_dataout WHEN nil0OO = '1'  ELSE nil0Ol;
	wire_nlO10O_dataout <= wire_nllili_dataout WHEN nil0OO = '1'  ELSE wire_w_lg_nil0Ol236w(0);
	wire_nlO11i_dataout <= wire_nllili_dataout WHEN nil0OO = '1'  ELSE wire_nlO11O_dataout;
	wire_nlO11l_dataout <= nliO1O AND nliOii;
	wire_nlO11O_dataout <= nliO0O AND nliOii;
	wire_nlO1il_dataout <= wire_nll0il_dataout OR NOT(rd_enable_sync);
	wire_nlO1iO_dataout <= wire_nll0iO_dataout AND rd_enable_sync;
	wire_nlO1li_dataout <= wire_nll0li_dataout AND rd_enable_sync;
	wire_nlO1ll_dataout <= wire_nll0ll_dataout OR NOT(rd_enable_sync);
	wire_nlO1lO_dataout <= wire_nll0lO_dataout OR NOT(rd_enable_sync);
	wire_nlO1Oi_dataout <= wire_nll0Oi_dataout OR NOT(rd_enable_sync);
	wire_nlO1Ol_dataout <= wire_nllOOi_dataout OR NOT(rd_enable_sync);
	wire_nlO1OO_dataout <= wire_nll0OO_dataout AND rd_enable_sync;
	wire_nlOi0i_dataout <= wire_nlOiOi_o OR nillil;
	wire_nlOi1i_dataout <= wire_nlOili_o OR nillil;
	wire_nlOi1l_dataout <= wire_nlOill_o OR nillil;
	wire_nlOi1O_dataout <= wire_nlOilO_o OR nillil;
	wire_nlOiOl_dataout <= wire_nlOlil_dataout OR NOT(nil0OO);
	wire_nlOiOO_dataout <= wire_nlOliO_dataout AND nil0OO;
	wire_nlOl0i_dataout <= wire_nlOlOi_dataout OR NOT(nil0OO);
	wire_nlOl0l_dataout <= wire_nlOlOl_dataout WHEN nil0OO = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_nlOl0O_dataout <= wire_nlOlOO_dataout AND nil0OO;
	wire_nlOl1i_dataout <= wire_nlOlli_dataout AND nil0OO;
	wire_nlOl1l_dataout <= wire_nlOlll_dataout OR NOT(nil0OO);
	wire_nlOl1O_dataout <= wire_nlOllO_dataout OR NOT(nil0OO);
	wire_nlOlii_dataout <= wire_nlOO1i_dataout WHEN nil0OO = '1'  ELSE wire_nll1l_w_lg_nli1il239w(0);
	wire_nlOlil_dataout <= wire_nlOO1l_dataout OR nili0O;
	wire_nlOliO_dataout <= wire_nlOO1O_dataout AND NOT(nili0O);
	wire_nlOlli_dataout <= wire_nlOO0i_dataout AND NOT(nili0O);
	wire_nlOlll_dataout <= wire_nlOO0l_dataout OR nili0O;
	wire_nlOllO_dataout <= wire_nlOO0O_dataout OR nili0O;
	wire_nlOlOi_dataout <= wire_nlOOii_dataout OR nili0O;
	wire_nlOlOl_dataout <= wire_nlOOil_dataout OR nili0O;
	wire_nlOlOO_dataout <= wire_nlOOiO_dataout AND NOT(nili0O);
	wire_nlOO0i_dataout <= tx_data(17) AND NOT(niOO1i);
	wire_nlOO0l_dataout <= tx_data(18) OR niOO1i;
	wire_nlOO0O_dataout <= tx_data(19) OR niOO1i;
	wire_nlOO1i_dataout <= wire_nlOOli_dataout OR nili0O;
	wire_nlOO1l_dataout <= tx_ctl(2) OR niOO1i;
	wire_nlOO1O_dataout <= tx_data(16) OR niOO1i;
	wire_nlOOii_dataout <= tx_data(20) OR niOO1i;
	wire_nlOOil_dataout <= tx_data(21) OR niOO1i;
	wire_nlOOiO_dataout <= tx_data(22) OR niOO1i;
	wire_nlOOli_dataout <= tx_data(23) OR niOO1i;
	wire_nlOOll_dataout <= wire_nlOlil_dataout WHEN nil0OO = '1'  ELSE wire_nll0l_w_lg_nliOii237w(0);
	wire_nlOOlO_dataout <= wire_nlOliO_dataout WHEN nil0OO = '1'  ELSE wire_n110l_dataout;
	wire_nlOOOi_dataout <= wire_nlOlli_dataout WHEN nil0OO = '1'  ELSE wire_n110O_dataout;
	wire_nlOOOl_dataout <= wire_nlOlll_dataout WHEN nil0OO = '1'  ELSE wire_n11ii_dataout;
	wire_nlOOOO_dataout <= wire_nlOllO_dataout WHEN nil0OO = '1'  ELSE wire_n11il_dataout;
	wire_nli00l_a <= ( nli1ii & nli10O & nli10l & nli10i & nli00i & "1");
	wire_nli00l_b <= ( "1" & "1" & "1" & "1" & "0" & "1");
	nli00l :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 6,
		width_b => 6,
		width_o => 6
	  )
	  PORT MAP ( 
		a => wire_nli00l_a,
		b => wire_nli00l_b,
		cin => wire_gnd,
		o => wire_nli00l_o
	  );
	wire_nl01i_i <= ( nll0O & nll0i & nll1O & nll1i);
	nl01i :  oper_decoder
	  GENERIC MAP (
		width_i => 4,
		width_o => 16
	  )
	  PORT MAP ( 
		i => wire_nl01i_i,
		o => wire_nl01i_o
	  );
	wire_nl1li_a <= ( "1" & "0" & "0" & "0");
	wire_nl1li_b <= ( nll0O & nll0i & nll1O & nll1i);
	nl1li :  oper_less_than
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 4,
		width_b => 4
	  )
	  PORT MAP ( 
		a => wire_nl1li_a,
		b => wire_nl1li_b,
		cin => wire_gnd,
		o => wire_nl1li_o
	  );
	wire_n0OiO_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_ni11O_dataout & wire_ni11O_dataout & wire_ni11O_dataout & wire_ni11O_dataout & wire_ni11O_dataout & wire_nil0i_dataout & wire_ni11O_dataout & wire_ni11O_dataout & "1");
	wire_n0OiO_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n0OiO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OiO_data,
		o => wire_n0OiO_o,
		sel => wire_n0OiO_sel
	  );
	wire_n0Oli_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_ni10i_dataout & wire_ni00O_dataout & wire_ni10i_dataout & wire_ni10i_dataout & wire_ni10i_dataout & wire_nil0l_dataout & wire_ni00O_dataout & wire_ni10i_dataout & "0");
	wire_n0Oli_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n0Oli :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Oli_data,
		o => wire_n0Oli_o,
		sel => wire_n0Oli_sel
	  );
	wire_n0Oll_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_ni10l_dataout & wire_ni0ii_dataout & wire_ni10l_dataout & wire_ni10l_dataout & wire_ni10l_dataout & wire_nil0O_dataout & wire_ni0ii_dataout & wire_ni10l_dataout & "0");
	wire_n0Oll_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n0Oll :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0Oll_data,
		o => wire_n0Oll_o,
		sel => wire_n0Oll_sel
	  );
	wire_n0OlO_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_ni10O_dataout & wire_ni0il_dataout & wire_ni10O_dataout & wire_ni10O_dataout & wire_ni10O_dataout & wire_nilii_dataout & wire_ni0il_dataout & wire_ni10O_dataout & "1");
	wire_n0OlO_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n0OlO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OlO_data,
		o => wire_n0OlO_o,
		sel => wire_n0OlO_sel
	  );
	wire_n0OOi_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_ni1ii_dataout & wire_ni0iO_dataout & wire_ni1ii_dataout & wire_ni1ii_dataout & wire_ni1ii_dataout & wire_nilil_dataout & wire_ni0iO_dataout & wire_ni1ii_dataout & "1");
	wire_n0OOi_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n0OOi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OOi_data,
		o => wire_n0OOi_o,
		sel => wire_n0OOi_sel
	  );
	wire_n0OOl_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_ni1il_dataout & wire_ni0li_dataout & wire_ni1il_dataout & wire_ni1il_dataout & wire_ni1il_dataout & wire_niliO_dataout & wire_ni0li_dataout & wire_ni1il_dataout & "1");
	wire_n0OOl_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n0OOl :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OOl_data,
		o => wire_n0OOl_o,
		sel => wire_n0OOl_sel
	  );
	wire_n0OOO_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_ni1iO_dataout & wire_ni0ll_dataout & wire_niiii_dataout & wire_niiii_dataout & wire_niili_dataout & wire_nilli_dataout & wire_niilO_dataout & wire_nil1i_dataout & "1");
	wire_n0OOO_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n0OOO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n0OOO_data,
		o => wire_n0OOO_o,
		sel => wire_n0OOO_sel
	  );
	wire_n1lii_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_n1O1i_dataout & wire_n01Oi_dataout & wire_n1O1i_dataout & wire_n1O1i_dataout & wire_n1O1i_dataout & wire_n0ilO_dataout & wire_n01Oi_dataout & wire_n1O1i_dataout & "1");
	wire_n1lii_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n1lii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1lii_data,
		o => wire_n1lii_o,
		sel => wire_n1lii_sel
	  );
	wire_n1lil_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_n1O1l_dataout & wire_n01Ol_dataout & wire_n1O1l_dataout & wire_n1O1l_dataout & wire_n1O1l_dataout & wire_n0iOi_dataout & wire_n01Ol_dataout & wire_n1O1l_dataout & "0");
	wire_n1lil_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n1lil :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1lil_data,
		o => wire_n1lil_o,
		sel => wire_n1lil_sel
	  );
	wire_n1liO_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_n1O1O_dataout & wire_n01OO_dataout & wire_n1O1O_dataout & wire_n1O1O_dataout & wire_n1O1O_dataout & wire_n0iOl_dataout & wire_n01OO_dataout & wire_n1O1O_dataout & "0");
	wire_n1liO_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n1liO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1liO_data,
		o => wire_n1liO_o,
		sel => wire_n1liO_sel
	  );
	wire_n1lli_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_n1O0i_dataout & wire_n001i_dataout & wire_n1O0i_dataout & wire_n1O0i_dataout & wire_n1O0i_dataout & wire_n0iOO_dataout & wire_n001i_dataout & wire_n1O0i_dataout & "1");
	wire_n1lli_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n1lli :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1lli_data,
		o => wire_n1lli_o,
		sel => wire_n1lli_sel
	  );
	wire_n1lll_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_n1O0l_dataout & wire_n001l_dataout & wire_n1O0l_dataout & wire_n1O0l_dataout & wire_n1O0l_dataout & wire_n0l1i_dataout & wire_n001l_dataout & wire_n1O0l_dataout & "1");
	wire_n1lll_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n1lll :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1lll_data,
		o => wire_n1lll_o,
		sel => wire_n1lll_sel
	  );
	wire_n1llO_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_n1O0O_dataout & wire_n001O_dataout & wire_n1O0O_dataout & wire_n1O0O_dataout & wire_n1O0O_dataout & wire_n0l1l_dataout & wire_n001O_dataout & wire_n1O0O_dataout & "1");
	wire_n1llO_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n1llO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1llO_data,
		o => wire_n1llO_o,
		sel => wire_n1llO_sel
	  );
	wire_n1lOi_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_n1Oii_dataout & wire_n000i_dataout & wire_n00OO_dataout & wire_n00OO_dataout & wire_n0i1O_dataout & wire_n0l1O_dataout & wire_n0i0l_dataout & wire_n0iiO_dataout & "1");
	wire_n1lOi_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n1lOi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1lOi_data,
		o => wire_n1lOi_o,
		sel => wire_n1lOi_sel
	  );
	wire_n1lOl_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_n1Oil_dataout & wire_n000l_dataout & wire_n0i1i_dataout & wire_n0i1i_dataout & wire_n1Oil_dataout & wire_n0l0i_dataout & wire_n000l_dataout & wire_n0ili_dataout & "0");
	wire_n1lOl_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n1lOl :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1lOl_data,
		o => wire_n1lOl_o,
		sel => wire_n1lOl_sel
	  );
	wire_n1lOO_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_n1OiO_dataout & wire_n000O_dataout & wire_n0i1l_dataout & wire_n0i1l_dataout & wire_n0i0i_dataout & wire_n0l0l_dataout & wire_n0i0O_dataout & wire_n0ill_dataout & "1");
	wire_n1lOO_sel <= ( nll0O & nll0i & nll1O & nll1i);
	n1lOO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_n1lOO_data,
		o => wire_n1lOO_o,
		sel => wire_n1lOO_sel
	  );
	wire_ni11i_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_ni1li_dataout & wire_ni0lO_dataout & wire_niiil_dataout & wire_niiil_dataout & wire_ni1li_dataout & wire_nilll_dataout & wire_ni0lO_dataout & wire_nil1l_dataout & "0");
	wire_ni11i_sel <= ( nll0O & nll0i & nll1O & nll1i);
	ni11i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni11i_data,
		o => wire_ni11i_o,
		sel => wire_ni11i_sel
	  );
	wire_ni11l_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_ni1ll_dataout & wire_ni0Oi_dataout & wire_niiiO_dataout & wire_niiiO_dataout & wire_niill_dataout & wire_nillO_dataout & wire_niiOi_dataout & wire_nil1O_dataout & "1");
	wire_ni11l_sel <= ( nll0O & nll0i & nll1O & nll1i);
	ni11l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_ni11l_data,
		o => wire_ni11l_o,
		sel => wire_ni11l_sel
	  );
	wire_nl1lO_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_nl01l_dataout & wire_nl0ii_dataout & wire_nli1l_dataout & wire_nli1l_dataout & "1" & "1" & wire_nliii_dataout & wire_nliiO_dataout & "1");
	wire_nl1lO_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nl1lO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nl1lO_data,
		o => wire_nl1lO_o,
		sel => wire_nl1lO_sel
	  );
	wire_nl1Oi_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_nl01O_dataout & wire_nl0il_dataout & wire_nli1O_dataout & wire_nli1O_dataout & niOOi & wire_nlilO_dataout & niOOi & wire_nlili_dataout & "1");
	wire_nl1Oi_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nl1Oi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nl1Oi_data,
		o => wire_nl1Oi_o,
		sel => wire_nl1Oi_sel
	  );
	wire_nl1Ol_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nl00i_dataout & wire_nl0iO_dataout & wire_nl00i_dataout & wire_nl00i_dataout & wire_nl00i_dataout & wire_nliOi_dataout & wire_nl00i_dataout & "0" & "0");
	wire_nl1Ol_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nl1Ol :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nl1Ol_data,
		o => wire_nl1Ol_o,
		sel => wire_nl1Ol_sel
	  );
	wire_nll00i_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_nll0Oi_dataout & wire_nlllll_dataout & wire_nll0Oi_dataout & wire_nll0Oi_dataout & wire_nll0Oi_dataout & wire_nlO1Oi_dataout & wire_nlllll_dataout & wire_nll0Oi_dataout & "1");
	wire_nll00i_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nll00i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nll00i_data,
		o => wire_nll00i_o,
		sel => wire_nll00i_sel
	  );
	wire_nll00l_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_nll0Ol_dataout & wire_nllllO_dataout & wire_nllOil_dataout & wire_nllOil_dataout & wire_nllOOi_dataout & wire_nlO1Ol_dataout & wire_nllOOO_dataout & wire_nlO10i_dataout & "1");
	wire_nll00l_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nll00l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nll00l_data,
		o => wire_nll00l_o,
		sel => wire_nll00l_sel
	  );
	wire_nll00O_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nll0OO_dataout & wire_nlllOi_dataout & wire_nllOiO_dataout & wire_nllOiO_dataout & wire_nll0OO_dataout & wire_nlO1OO_dataout & wire_nlllOi_dataout & wire_nlO10l_dataout & "0");
	wire_nll00O_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nll00O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nll00O_data,
		o => wire_nll00O_o,
		sel => wire_nll00O_sel
	  );
	wire_nll01i_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nll0li_dataout & wire_nlllil_dataout & wire_nll0li_dataout & wire_nll0li_dataout & wire_nll0li_dataout & wire_nlO1li_dataout & wire_nlllil_dataout & wire_nll0li_dataout & "0");
	wire_nll01i_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nll01i :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nll01i_data,
		o => wire_nll01i_o,
		sel => wire_nll01i_sel
	  );
	wire_nll01l_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_nll0ll_dataout & wire_nllliO_dataout & wire_nll0ll_dataout & wire_nll0ll_dataout & wire_nll0ll_dataout & wire_nlO1ll_dataout & wire_nllliO_dataout & wire_nll0ll_dataout & "1");
	wire_nll01l_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nll01l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nll01l_data,
		o => wire_nll01l_o,
		sel => wire_nll01l_sel
	  );
	wire_nll01O_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_nll0lO_dataout & wire_nlllli_dataout & wire_nll0lO_dataout & wire_nll0lO_dataout & wire_nll0lO_dataout & wire_nlO1lO_dataout & wire_nlllli_dataout & wire_nll0lO_dataout & "1");
	wire_nll01O_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nll01O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nll01O_data,
		o => wire_nll01O_o,
		sel => wire_nll01O_sel
	  );
	wire_nll0ii_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_nlli1i_dataout & wire_nlllOl_dataout & wire_nllOli_dataout & wire_nllOli_dataout & wire_nllOOl_dataout & wire_nlO01i_dataout & wire_nlO11i_dataout & wire_nlO10O_dataout & "1");
	wire_nll0ii_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nll0ii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nll0ii_data,
		o => wire_nll0ii_o,
		sel => wire_nll0ii_sel
	  );
	wire_nll1Ol_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_nll0il_dataout & wire_nlll0O_dataout & wire_nll0il_dataout & wire_nll0il_dataout & wire_nll0il_dataout & wire_nlO1il_dataout & wire_nlll0O_dataout & wire_nll0il_dataout & "1");
	wire_nll1Ol_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nll1Ol :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nll1Ol_data,
		o => wire_nll1Ol_o,
		sel => wire_nll1Ol_sel
	  );
	wire_nll1OO_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nll0iO_dataout & wire_nlllii_dataout & wire_nll0iO_dataout & wire_nll0iO_dataout & wire_nll0iO_dataout & wire_nlO1iO_dataout & wire_nlllii_dataout & wire_nll0iO_dataout & "0");
	wire_nll1OO_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nll1OO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nll1OO_data,
		o => wire_nll1OO_o,
		sel => wire_nll1OO_sel
	  );
	wire_nlOi0l_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_nlOiOl_dataout & wire_nlOOll_dataout & wire_nlOiOl_dataout & wire_nlOiOl_dataout & wire_nlOiOl_dataout & wire_n10li_dataout & wire_nlOOll_dataout & wire_nlOiOl_dataout & "1");
	wire_nlOi0l_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nlOi0l :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlOi0l_data,
		o => wire_nlOi0l_o,
		sel => wire_nlOi0l_sel
	  );
	wire_nlOi0O_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nlOiOO_dataout & wire_nlOOlO_dataout & wire_nlOiOO_dataout & wire_nlOiOO_dataout & wire_nlOiOO_dataout & wire_n10ll_dataout & wire_nlOOlO_dataout & wire_nlOiOO_dataout & "0");
	wire_nlOi0O_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nlOi0O :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlOi0O_data,
		o => wire_nlOi0O_o,
		sel => wire_nlOi0O_sel
	  );
	wire_nlOiii_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nlOl1i_dataout & wire_nlOOOi_dataout & wire_nlOl1i_dataout & wire_nlOl1i_dataout & wire_nlOl1i_dataout & wire_n10lO_dataout & wire_nlOOOi_dataout & wire_nlOl1i_dataout & "0");
	wire_nlOiii_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nlOiii :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlOiii_data,
		o => wire_nlOiii_o,
		sel => wire_nlOiii_sel
	  );
	wire_nlOiil_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_nlOl1l_dataout & wire_nlOOOl_dataout & wire_nlOl1l_dataout & wire_nlOl1l_dataout & wire_nlOl1l_dataout & wire_n10Oi_dataout & wire_nlOOOl_dataout & wire_nlOl1l_dataout & "1");
	wire_nlOiil_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nlOiil :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlOiil_data,
		o => wire_nlOiil_o,
		sel => wire_nlOiil_sel
	  );
	wire_nlOiiO_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_nlOl1O_dataout & wire_nlOOOO_dataout & wire_nlOl1O_dataout & wire_nlOl1O_dataout & wire_nlOl1O_dataout & wire_n10Ol_dataout & wire_nlOOOO_dataout & wire_nlOl1O_dataout & "1");
	wire_nlOiiO_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nlOiiO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlOiiO_data,
		o => wire_nlOiiO_o,
		sel => wire_nlOiiO_sel
	  );
	wire_nlOili_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_nlOl0i_dataout & wire_n111i_dataout & wire_nlOl0i_dataout & wire_nlOl0i_dataout & wire_nlOl0i_dataout & wire_n10OO_dataout & wire_n111i_dataout & wire_nlOl0i_dataout & "1");
	wire_nlOili_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nlOili :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlOili_data,
		o => wire_nlOili_o,
		sel => wire_nlOili_sel
	  );
	wire_nlOill_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_nlOl0l_dataout & wire_n111l_dataout & wire_n11Oi_dataout & wire_n11Oi_dataout & wire_n101i_dataout & wire_n1i1i_dataout & wire_n101O_dataout & wire_n10ii_dataout & "1");
	wire_nlOill_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nlOill :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlOill_data,
		o => wire_nlOill_o,
		sel => wire_nlOill_sel
	  );
	wire_nlOilO_data <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & wire_nlOl0O_dataout & wire_n111O_dataout & wire_n11Ol_dataout & wire_n11Ol_dataout & wire_nlOl0O_dataout & wire_n1i1l_dataout & wire_n111O_dataout & wire_n10il_dataout & "0");
	wire_nlOilO_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nlOilO :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlOilO_data,
		o => wire_nlOilO_o,
		sel => wire_nlOilO_sel
	  );
	wire_nlOiOi_data <= ( "1" & "1" & "1" & "1" & "1" & "1" & "1" & wire_nlOlii_dataout & wire_n110i_dataout & wire_n11OO_dataout & wire_n11OO_dataout & wire_n101l_dataout & wire_n1i1O_dataout & wire_n100i_dataout & wire_n10iO_dataout & "1");
	wire_nlOiOi_sel <= ( nll0O & nll0i & nll1O & nll1i);
	nlOiOi :  oper_mux
	  GENERIC MAP (
		width_data => 16,
		width_sel => 4
	  )
	  PORT MAP ( 
		data => wire_nlOiOi_data,
		o => wire_nlOiOi_o,
		sel => wire_nlOiOi_sel
	  );

 END RTL; --stratixiv_hssi_tx_sm
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 170 mux21 775 oper_mux 3 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_rcv_sm IS 
	 PORT 
	 ( 
		 clk_2	:	IN  STD_LOGIC;
		 curr_state	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 dec_ctl	:	IN  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 dec_data	:	IN  STD_LOGIC_VECTOR (31 DOWNTO 0);
		 dec_data_valid	:	IN  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 indv	:	IN  STD_LOGIC;
		 running_disp	:	IN  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 rx_ctl_rs	:	OUT  STD_LOGIC_VECTOR (3 DOWNTO 0);
		 rx_data_rs	:	OUT  STD_LOGIC_VECTOR (31 DOWNTO 0);
		 rx_local_fault	:	OUT  STD_LOGIC;
		 rx_local_fault_clr	:	IN  STD_LOGIC;
		 rxaui_s2gx_en	:	IN  STD_LOGIC;
		 soft_reset	:	IN  STD_LOGIC;
		 tx_local_fault_det	:	IN  STD_LOGIC;
		 xs_link_status	:	OUT  STD_LOGIC;
		 xs_link_status_set	:	IN  STD_LOGIC
	 ); 
 END stratixiv_hssi_rcv_sm;

 ARCHITECTURE RTL OF stratixiv_hssi_rcv_sm IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 n0Olli45	:	STD_LOGIC := '0';
	 SIGNAL	 n0Olli46	:	STD_LOGIC := '0';
	 SIGNAL	 n0OlOl43	:	STD_LOGIC := '0';
	 SIGNAL	 n0OlOl44	:	STD_LOGIC := '0';
	 SIGNAL	 n0OO0l39	:	STD_LOGIC := '0';
	 SIGNAL	 n0OO0l40	:	STD_LOGIC := '0';
	 SIGNAL	 n0OO1l41	:	STD_LOGIC := '0';
	 SIGNAL	 n0OO1l42	:	STD_LOGIC := '0';
	 SIGNAL	 n0OOil37	:	STD_LOGIC := '0';
	 SIGNAL	 n0OOil38	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0OOil38_w_lg_w_lg_q150w151w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0OOil38_w_lg_q150w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0OOiO35	:	STD_LOGIC := '0';
	 SIGNAL	 n0OOiO36	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0OOiO36_w_lg_w_lg_q145w146w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0OOiO36_w_lg_q145w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0OOli33	:	STD_LOGIC := '0';
	 SIGNAL	 n0OOli34	:	STD_LOGIC := '0';
	 SIGNAL  wire_n0OOli34_w_lg_w_lg_q129w130w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n0OOli34_w_lg_q129w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 n0OOlO31	:	STD_LOGIC := '0';
	 SIGNAL	 n0OOlO32	:	STD_LOGIC := '0';
	 SIGNAL	 n0OOOl29	:	STD_LOGIC := '0';
	 SIGNAL	 n0OOOl30	:	STD_LOGIC := '0';
	 SIGNAL	 n0OOOO27	:	STD_LOGIC := '0';
	 SIGNAL	 n0OOOO28	:	STD_LOGIC := '0';
	 SIGNAL	 ni100l15	:	STD_LOGIC := '0';
	 SIGNAL	 ni100l16	:	STD_LOGIC := '0';
	 SIGNAL	 ni10OO13	:	STD_LOGIC := '0';
	 SIGNAL	 ni10OO14	:	STD_LOGIC := '0';
	 SIGNAL	 ni110l23	:	STD_LOGIC := '0';
	 SIGNAL	 ni110l24	:	STD_LOGIC := '0';
	 SIGNAL	 ni111l25	:	STD_LOGIC := '0';
	 SIGNAL	 ni111l26	:	STD_LOGIC := '0';
	 SIGNAL	 ni11ii21	:	STD_LOGIC := '0';
	 SIGNAL	 ni11ii22	:	STD_LOGIC := '0';
	 SIGNAL	 ni11Oi19	:	STD_LOGIC := '0';
	 SIGNAL	 ni11Oi20	:	STD_LOGIC := '0';
	 SIGNAL	 ni11OO17	:	STD_LOGIC := '0';
	 SIGNAL	 ni11OO18	:	STD_LOGIC := '0';
	 SIGNAL	 ni1i0O11	:	STD_LOGIC := '0';
	 SIGNAL	 ni1i0O12	:	STD_LOGIC := '0';
	 SIGNAL	 ni1ili10	:	STD_LOGIC := '0';
	 SIGNAL	 ni1ili9	:	STD_LOGIC := '0';
	 SIGNAL	 ni1ilO7	:	STD_LOGIC := '0';
	 SIGNAL	 ni1ilO8	:	STD_LOGIC := '0';
	 SIGNAL	 ni1l1O5	:	STD_LOGIC := '0';
	 SIGNAL	 ni1l1O6	:	STD_LOGIC := '0';
	 SIGNAL	 ni1lil3	:	STD_LOGIC := '0';
	 SIGNAL	 ni1lil4	:	STD_LOGIC := '0';
	 SIGNAL	 ni1lli1	:	STD_LOGIC := '0';
	 SIGNAL	 ni1lli2	:	STD_LOGIC := '0';
	 SIGNAL  wire_ni1lli2_w_lg_w_lg_q3w4w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1lli2_w_lg_q3w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n000i	:	STD_LOGIC := '0';
	 SIGNAL	n001O	:	STD_LOGIC := '0';
	 SIGNAL	n00ii	:	STD_LOGIC := '0';
	 SIGNAL	n01Ol	:	STD_LOGIC := '0';
	 SIGNAL	n0liO	:	STD_LOGIC := '0';
	 SIGNAL	n0lli	:	STD_LOGIC := '0';
	 SIGNAL	n0lll	:	STD_LOGIC := '0';
	 SIGNAL	n0llO	:	STD_LOGIC := '0';
	 SIGNAL	n0lOi	:	STD_LOGIC := '0';
	 SIGNAL	n0lOl	:	STD_LOGIC := '0';
	 SIGNAL	n0lOO	:	STD_LOGIC := '0';
	 SIGNAL	n0O1i	:	STD_LOGIC := '0';
	 SIGNAL	n0O1l	:	STD_LOGIC := '0';
	 SIGNAL	n10il	:	STD_LOGIC := '0';
	 SIGNAL	n10iO	:	STD_LOGIC := '0';
	 SIGNAL	n10li	:	STD_LOGIC := '0';
	 SIGNAL	n10ll	:	STD_LOGIC := '0';
	 SIGNAL	n10lO	:	STD_LOGIC := '0';
	 SIGNAL	n10Oi	:	STD_LOGIC := '0';
	 SIGNAL	n10Ol	:	STD_LOGIC := '0';
	 SIGNAL	n10OO	:	STD_LOGIC := '0';
	 SIGNAL	n11l	:	STD_LOGIC := '0';
	 SIGNAL	n1i1i	:	STD_LOGIC := '0';
	 SIGNAL	nii00i	:	STD_LOGIC := '0';
	 SIGNAL	nii00l	:	STD_LOGIC := '0';
	 SIGNAL	nii00O	:	STD_LOGIC := '0';
	 SIGNAL	nii0ii	:	STD_LOGIC := '0';
	 SIGNAL	nii0il	:	STD_LOGIC := '0';
	 SIGNAL	nii0lO	:	STD_LOGIC := '0';
	 SIGNAL	nii0Oi	:	STD_LOGIC := '0';
	 SIGNAL	niiii	:	STD_LOGIC := '0';
	 SIGNAL	niiil	:	STD_LOGIC := '0';
	 SIGNAL	niiiO	:	STD_LOGIC := '0';
	 SIGNAL	niili	:	STD_LOGIC := '0';
	 SIGNAL	niill	:	STD_LOGIC := '0';
	 SIGNAL	niilO	:	STD_LOGIC := '0';
	 SIGNAL	niiOi	:	STD_LOGIC := '0';
	 SIGNAL	niiOl	:	STD_LOGIC := '0';
	 SIGNAL	nill0i	:	STD_LOGIC := '0';
	 SIGNAL	nill1l	:	STD_LOGIC := '0';
	 SIGNAL	nill1O	:	STD_LOGIC := '0';
	 SIGNAL	nillil	:	STD_LOGIC := '0';
	 SIGNAL	nilliO	:	STD_LOGIC := '0';
	 SIGNAL	nillll	:	STD_LOGIC := '0';
	 SIGNAL	niO00i	:	STD_LOGIC := '0';
	 SIGNAL	niO00l	:	STD_LOGIC := '0';
	 SIGNAL	niO00O	:	STD_LOGIC := '0';
	 SIGNAL	niO01O	:	STD_LOGIC := '0';
	 SIGNAL	niO0ii	:	STD_LOGIC := '0';
	 SIGNAL	niO0il	:	STD_LOGIC := '0';
	 SIGNAL	niO0iO	:	STD_LOGIC := '0';
	 SIGNAL	niO0li	:	STD_LOGIC := '0';
	 SIGNAL	niO0ll	:	STD_LOGIC := '0';
	 SIGNAL	nl00i	:	STD_LOGIC := '0';
	 SIGNAL	nl00l	:	STD_LOGIC := '0';
	 SIGNAL	nl00O	:	STD_LOGIC := '0';
	 SIGNAL	nl0ii	:	STD_LOGIC := '0';
	 SIGNAL	nl0iiO	:	STD_LOGIC := '0';
	 SIGNAL	nl0il	:	STD_LOGIC := '0';
	 SIGNAL	nl0ili	:	STD_LOGIC := '0';
	 SIGNAL	nl0ill	:	STD_LOGIC := '0';
	 SIGNAL	nl0ilO	:	STD_LOGIC := '0';
	 SIGNAL	nl0iO	:	STD_LOGIC := '0';
	 SIGNAL	nl0iOi	:	STD_LOGIC := '0';
	 SIGNAL	nl0iOl	:	STD_LOGIC := '0';
	 SIGNAL	nl0iOO	:	STD_LOGIC := '0';
	 SIGNAL	nl0l1i	:	STD_LOGIC := '0';
	 SIGNAL	nl0l1l	:	STD_LOGIC := '0';
	 SIGNAL	nl0li	:	STD_LOGIC := '0';
	 SIGNAL	nl0ll	:	STD_LOGIC := '0';
	 SIGNAL	nl0lO	:	STD_LOGIC := '0';
	 SIGNAL	nl1l0O	:	STD_LOGIC := '0';
	 SIGNAL	nl1lii	:	STD_LOGIC := '0';
	 SIGNAL	nl1lil	:	STD_LOGIC := '0';
	 SIGNAL	nl1liO	:	STD_LOGIC := '0';
	 SIGNAL	nl1lli	:	STD_LOGIC := '0';
	 SIGNAL	nl1lll	:	STD_LOGIC := '0';
	 SIGNAL	nl1llO	:	STD_LOGIC := '0';
	 SIGNAL	nl1lOi	:	STD_LOGIC := '0';
	 SIGNAL	nl1lOl	:	STD_LOGIC := '0';
	 SIGNAL	nliOlO	:	STD_LOGIC := '0';
	 SIGNAL	nliOOi	:	STD_LOGIC := '0';
	 SIGNAL	nliOOl	:	STD_LOGIC := '0';
	 SIGNAL	nliOOO	:	STD_LOGIC := '0';
	 SIGNAL	nll10i	:	STD_LOGIC := '0';
	 SIGNAL	nll11i	:	STD_LOGIC := '0';
	 SIGNAL	nll11l	:	STD_LOGIC := '0';
	 SIGNAL	nll11O	:	STD_LOGIC := '0';
	 SIGNAL	nlllOO	:	STD_LOGIC := '0';
	 SIGNAL	nllO0i	:	STD_LOGIC := '0';
	 SIGNAL	nllO0l	:	STD_LOGIC := '0';
	 SIGNAL	nllO0O	:	STD_LOGIC := '0';
	 SIGNAL	nllO1i	:	STD_LOGIC := '0';
	 SIGNAL	nllO1l	:	STD_LOGIC := '0';
	 SIGNAL	nllO1O	:	STD_LOGIC := '0';
	 SIGNAL	nllOii	:	STD_LOGIC := '0';
	 SIGNAL	nlO0i	:	STD_LOGIC := '0';
	 SIGNAL	nlO0l	:	STD_LOGIC := '0';
	 SIGNAL	nlO0O	:	STD_LOGIC := '0';
	 SIGNAL	nlOii	:	STD_LOGIC := '0';
	 SIGNAL	nlOil	:	STD_LOGIC := '0';
	 SIGNAL	nlOiO	:	STD_LOGIC := '0';
	 SIGNAL	nlOli	:	STD_LOGIC := '0';
	 SIGNAL	nlOll	:	STD_LOGIC := '0';
	 SIGNAL	nlOlO	:	STD_LOGIC := '0';
	 SIGNAL	wire_n11i_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_n11i_PRN	:	STD_LOGIC;
	 SIGNAL  wire_n11i_w_lg_nlO0l282w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n11i_w_lg_nlO0O281w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n11i_w_lg_w_lg_w_lg_w_lg_nill1l1w5w6w7w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n11i_w_lg_w_lg_w_lg_nill1l1w5w6w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n11i_w_lg_w_lg_nill1l1w5w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_n11i_w_lg_nill1l1w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n000l	:	STD_LOGIC := '0';
	 SIGNAL	n000O	:	STD_LOGIC := '0';
	 SIGNAL	n001i	:	STD_LOGIC := '0';
	 SIGNAL	n001l	:	STD_LOGIC := '0';
	 SIGNAL	n01OO	:	STD_LOGIC := '0';
	 SIGNAL	n10i	:	STD_LOGIC := '0';
	 SIGNAL	nii0iO	:	STD_LOGIC := '0';
	 SIGNAL	nii0li	:	STD_LOGIC := '0';
	 SIGNAL	nii0ll	:	STD_LOGIC := '0';
	 SIGNAL	nii0Ol	:	STD_LOGIC := '0';
	 SIGNAL	nii0OO	:	STD_LOGIC := '0';
	 SIGNAL	niii1i	:	STD_LOGIC := '0';
	 SIGNAL	niiOO	:	STD_LOGIC := '0';
	 SIGNAL	nill0l	:	STD_LOGIC := '0';
	 SIGNAL	nill0O	:	STD_LOGIC := '0';
	 SIGNAL	nillii	:	STD_LOGIC := '0';
	 SIGNAL	nillli	:	STD_LOGIC := '0';
	 SIGNAL	nll10l	:	STD_LOGIC := '0';
	 SIGNAL	nllOil	:	STD_LOGIC := '0';
	 SIGNAL	wire_n11O_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_n00il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n01li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n100l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n101O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n111O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n11OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0i_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0i_w_lg_dataout23w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0l_w_lg_dataout27w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni0O_w_lg_dataout237w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1O_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni1O_w_lg_dataout16w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_ni1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nililO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nillOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl000O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl001O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl00OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl010i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl010l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl010O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl011i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl011l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl011O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl01OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0liO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0llO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl100i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl100l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl100O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl101i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl101l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl101O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl10OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl110i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl110l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl110O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl111i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl111l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl111O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl11OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1iOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1lOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1Oll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1OOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlillO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlilOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlliOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlllOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO00i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO00l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO00O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO01O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO0OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO10O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO11O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1il_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1iO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1li_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1ll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1lO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1Oi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOiOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOOOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nllOi_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllOi_o	:	STD_LOGIC;
	 SIGNAL  wire_nllOi_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllOl_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllOl_o	:	STD_LOGIC;
	 SIGNAL  wire_nllOl_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_nllOO_w_lg_o126w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nllOO_data	:	STD_LOGIC_VECTOR (3 DOWNTO 0);
	 SIGNAL  wire_nllOO_o	:	STD_LOGIC;
	 SIGNAL  wire_nllOO_sel	:	STD_LOGIC_VECTOR (1 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_dec_ctl_range17w18w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_dec_ctl_range24w25w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_dec_ctl_range28w29w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_dec_ctl_range54w238w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_dec_data_range236w285w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_dec_data_range218w301w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_dec_data_range202w309w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_dec_data_range227w293w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0OliO228w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0OlOi219w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_n0OO1i205w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni101O68w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni10ii62w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni10iO60w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni10ll58w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni10Oi56w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni110i128w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni111O120w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni11iO95w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni11li92w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni11ll89w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni11lO87w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni1i0i45w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni1i1l48w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni1iil38w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_soft_reset116w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_dec_data_range217w300w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_dec_data_range235w284w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_dec_data_range201w308w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_dec_data_range226w292w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_ni111O120w121w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_w_lg_ni1i0l74w75w76w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_ni1i0l74w75w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni1i0l74w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  n0Oill :	STD_LOGIC;
	 SIGNAL  n0OilO :	STD_LOGIC;
	 SIGNAL  n0OiOi :	STD_LOGIC;
	 SIGNAL  n0OiOl :	STD_LOGIC;
	 SIGNAL  n0OiOO :	STD_LOGIC;
	 SIGNAL  n0Ol0i :	STD_LOGIC;
	 SIGNAL  n0Ol0l :	STD_LOGIC;
	 SIGNAL  n0Ol0O :	STD_LOGIC;
	 SIGNAL  n0Ol1i :	STD_LOGIC;
	 SIGNAL  n0Ol1l :	STD_LOGIC;
	 SIGNAL  n0Ol1O :	STD_LOGIC;
	 SIGNAL  n0Olii :	STD_LOGIC;
	 SIGNAL  n0Olil :	STD_LOGIC;
	 SIGNAL  n0OliO :	STD_LOGIC;
	 SIGNAL  n0OllO :	STD_LOGIC;
	 SIGNAL  n0OlOi :	STD_LOGIC;
	 SIGNAL  n0OO0i :	STD_LOGIC;
	 SIGNAL  n0OO1i :	STD_LOGIC;
	 SIGNAL  n0OOii :	STD_LOGIC;
	 SIGNAL  n0OOll :	STD_LOGIC;
	 SIGNAL  ni100i :	STD_LOGIC;
	 SIGNAL  ni101l :	STD_LOGIC;
	 SIGNAL  ni101O :	STD_LOGIC;
	 SIGNAL  ni10ii :	STD_LOGIC;
	 SIGNAL  ni10il :	STD_LOGIC;
	 SIGNAL  ni10iO :	STD_LOGIC;
	 SIGNAL  ni10li :	STD_LOGIC;
	 SIGNAL  ni10ll :	STD_LOGIC;
	 SIGNAL  ni10lO :	STD_LOGIC;
	 SIGNAL  ni10Oi :	STD_LOGIC;
	 SIGNAL  ni10Ol :	STD_LOGIC;
	 SIGNAL  ni110i :	STD_LOGIC;
	 SIGNAL  ni111i :	STD_LOGIC;
	 SIGNAL  ni111O :	STD_LOGIC;
	 SIGNAL  ni11iO :	STD_LOGIC;
	 SIGNAL  ni11li :	STD_LOGIC;
	 SIGNAL  ni11ll :	STD_LOGIC;
	 SIGNAL  ni11lO :	STD_LOGIC;
	 SIGNAL  ni1i0i :	STD_LOGIC;
	 SIGNAL  ni1i0l :	STD_LOGIC;
	 SIGNAL  ni1i1l :	STD_LOGIC;
	 SIGNAL  ni1i1O :	STD_LOGIC;
	 SIGNAL  ni1iil :	STD_LOGIC;
	 SIGNAL  ni1iiO :	STD_LOGIC;
	 SIGNAL  ni1iOl :	STD_LOGIC;
	 SIGNAL  ni1iOO :	STD_LOGIC;
	 SIGNAL  ni1l0l :	STD_LOGIC;
	 SIGNAL  ni1l0O :	STD_LOGIC;
	 SIGNAL  ni1l1i :	STD_LOGIC;
	 SIGNAL  ni1l1l :	STD_LOGIC;
	 SIGNAL  ni1lii :	STD_LOGIC;
	 SIGNAL  wire_w_dec_ctl_range17w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_dec_ctl_range24w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_dec_ctl_range28w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_dec_ctl_range54w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_dec_data_range236w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_dec_data_range218w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_dec_data_range217w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_dec_data_range235w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_dec_data_range202w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_dec_data_range201w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_dec_data_range227w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_dec_data_range226w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_w_lg_w_dec_ctl_range17w18w(0) <= wire_w_dec_ctl_range17w(0) AND ni1l0l;
	wire_w_lg_w_dec_ctl_range24w25w(0) <= wire_w_dec_ctl_range24w(0) AND ni1l1i;
	wire_w_lg_w_dec_ctl_range28w29w(0) <= wire_w_dec_ctl_range28w(0) AND ni1iOl;
	wire_w_lg_w_dec_ctl_range54w238w(0) <= wire_w_dec_ctl_range54w(0) AND n0Oill;
	wire_w_lg_w_dec_data_range236w285w(0) <= wire_w_dec_data_range236w(0) AND wire_w_lg_w_dec_data_range235w284w(0);
	wire_w_lg_w_dec_data_range218w301w(0) <= wire_w_dec_data_range218w(0) AND wire_w_lg_w_dec_data_range217w300w(0);
	wire_w_lg_w_dec_data_range202w309w(0) <= wire_w_dec_data_range202w(0) AND wire_w_lg_w_dec_data_range201w308w(0);
	wire_w_lg_w_dec_data_range227w293w(0) <= wire_w_dec_data_range227w(0) AND wire_w_lg_w_dec_data_range226w292w(0);
	wire_w_lg_n0OliO228w(0) <= NOT n0OliO;
	wire_w_lg_n0OlOi219w(0) <= NOT n0OlOi;
	wire_w_lg_n0OO1i205w(0) <= NOT n0OO1i;
	wire_w_lg_ni101O68w(0) <= NOT ni101O;
	wire_w_lg_ni10ii62w(0) <= NOT ni10ii;
	wire_w_lg_ni10iO60w(0) <= NOT ni10iO;
	wire_w_lg_ni10ll58w(0) <= NOT ni10ll;
	wire_w_lg_ni10Oi56w(0) <= NOT ni10Oi;
	wire_w_lg_ni110i128w(0) <= NOT ni110i;
	wire_w_lg_ni111O120w(0) <= NOT ni111O;
	wire_w_lg_ni11iO95w(0) <= NOT ni11iO;
	wire_w_lg_ni11li92w(0) <= NOT ni11li;
	wire_w_lg_ni11ll89w(0) <= NOT ni11ll;
	wire_w_lg_ni11lO87w(0) <= NOT ni11lO;
	wire_w_lg_ni1i0i45w(0) <= NOT ni1i0i;
	wire_w_lg_ni1i1l48w(0) <= NOT ni1i1l;
	wire_w_lg_ni1iil38w(0) <= NOT ni1iil;
	wire_w_lg_soft_reset116w(0) <= NOT soft_reset;
	wire_w_lg_w_dec_data_range217w300w(0) <= NOT wire_w_dec_data_range217w(0);
	wire_w_lg_w_dec_data_range235w284w(0) <= NOT wire_w_dec_data_range235w(0);
	wire_w_lg_w_dec_data_range201w308w(0) <= NOT wire_w_dec_data_range201w(0);
	wire_w_lg_w_dec_data_range226w292w(0) <= NOT wire_w_dec_data_range226w(0);
	wire_w_lg_w_lg_ni111O120w121w(0) <= wire_w_lg_ni111O120w(0) OR nlOii;
	wire_w_lg_w_lg_w_lg_ni1i0l74w75w76w(0) <= wire_w_lg_w_lg_ni1i0l74w75w(0) OR ni10lO;
	wire_w_lg_w_lg_ni1i0l74w75w(0) <= wire_w_lg_ni1i0l74w(0) OR ni10Ol;
	wire_w_lg_ni1i0l74w(0) <= ni1i0l OR ni1i1O;
	curr_state <= ( nlO0O & nlO0l);
	n0Oill <= ((((((wire_w_lg_w_dec_data_range202w309w(0) AND dec_data(26)) AND dec_data(27)) AND dec_data(28)) AND dec_data(29)) AND dec_data(30)) AND dec_data(31));
	n0OilO <= (wire_n11i_w_lg_nlO0O281w(0) AND nlO0l);
	n0OiOi <= (ni110i AND (NOT (((wire_ni0O_dataout OR wire_ni0l_dataout) OR wire_ni0i_dataout) OR wire_ni1O_dataout)));
	n0OiOl <= (ni1iiO OR n0OOii);
	n0OiOO <= (wire_ni0O_dataout OR (ni10lO AND ni101l));
	n0Ol0i <= (ni1l1l OR ni110i);
	n0Ol0l <= (wire_ni1O_dataout OR (ni1i0l AND ni10li));
	n0Ol0O <= ((nii00l OR nii00i) OR nii00O);
	n0Ol1i <= (nlO0O AND nlO0l);
	n0Ol1l <= (ni1iiO OR n0Ol1O);
	n0Ol1O <= (ni1iOO OR n0Ol0i);
	n0Olii <= (wire_ni0i_dataout OR (ni1i1O AND ni10il));
	n0Olil <= (nii00O OR nii00i);
	n0OliO <= ((wire_ni0i_dataout OR ni1i1O) OR (NOT (n0Olli46 XOR n0Olli45)));
	n0OllO <= (wire_ni0l_dataout OR (ni10Ol AND ni100i));
	n0OlOi <= ((wire_ni0l_dataout OR ni10Ol) OR (NOT (n0OlOl44 XOR n0OlOl43)));
	n0OO0i <= ((ni1iiO OR n0OOii) OR (NOT (n0OO0l40 XOR n0OO0l39)));
	n0OO1i <= ((wire_ni0O_dataout OR ni10lO) OR (NOT (n0OO1l42 XOR n0OO1l41)));
	n0OOii <= (ni1l1l OR ni1iOO);
	n0OOll <= (wire_w_lg_ni111O120w(0) OR nl0lO);
	ni100i <= (((NOT dec_ctl(2)) OR wire_w_lg_ni10ii62w(0)) OR (NOT (ni100l16 XOR ni100l15)));
	ni101l <= ((NOT dec_ctl(3)) OR wire_w_lg_ni101O68w(0));
	ni101O <= ((((((((NOT dec_data(24)) AND wire_w_lg_w_dec_data_range201w308w(0)) AND dec_data(26)) AND dec_data(27)) AND dec_data(28)) AND dec_data(29)) AND dec_data(30)) AND (NOT dec_data(31)));
	ni10ii <= ((((((((NOT dec_data(16)) AND wire_w_lg_w_dec_data_range217w300w(0)) AND dec_data(18)) AND dec_data(19)) AND dec_data(20)) AND dec_data(21)) AND dec_data(22)) AND (NOT dec_data(23)));
	ni10il <= ((NOT dec_ctl(1)) OR wire_w_lg_ni10iO60w(0));
	ni10iO <= ((((((((NOT dec_data(8)) AND wire_w_lg_w_dec_data_range226w292w(0)) AND dec_data(10)) AND dec_data(11)) AND dec_data(12)) AND dec_data(13)) AND dec_data(14)) AND (NOT dec_data(15)));
	ni10li <= ((NOT dec_ctl(0)) OR wire_w_lg_ni10ll58w(0));
	ni10ll <= ((((((((NOT dec_data(0)) AND wire_w_lg_w_dec_data_range235w284w(0)) AND dec_data(2)) AND dec_data(3)) AND dec_data(4)) AND dec_data(5)) AND dec_data(6)) AND (NOT dec_data(7)));
	ni10lO <= ((NOT dec_ctl(3)) OR wire_w_lg_ni10Oi56w(0));
	ni10Oi <= ((((((((NOT dec_data(24)) AND wire_w_lg_w_dec_data_range201w308w(0)) AND dec_data(26)) AND dec_data(27)) AND dec_data(28)) AND dec_data(29)) AND (NOT dec_data(30))) AND dec_data(31));
	ni10Ol <= (((NOT dec_ctl(2)) OR wire_w_lg_ni1i1l48w(0)) OR (NOT (ni10OO14 XOR ni10OO13)));
	ni110i <= ((((NOT (((ni10li OR ni10il) OR ni100i) OR ni101l)) OR (NOT (wire_w_lg_w_lg_w_lg_ni1i0l74w75w76w(0) OR (NOT (ni11OO18 XOR ni11OO17))))) OR (NOT (ni11Oi20 XOR ni11Oi19))) OR (NOT ((((((NOT dec_ctl(0)) OR wire_w_lg_ni11lO87w(0)) OR ((NOT dec_ctl(1)) OR wire_w_lg_ni11ll89w(0))) OR ((NOT dec_ctl(2)) OR wire_w_lg_ni11li92w(0))) OR (((NOT dec_ctl(3)) OR wire_w_lg_ni11iO95w(0)) OR (NOT (ni11ii22 XOR ni11ii21)))) OR (NOT (ni110l24 XOR ni110l23)))));
	ni111i <= '1';
	ni111O <= (((dec_data_valid(0) AND dec_data_valid(1)) AND dec_data_valid(2)) AND dec_data_valid(3));
	ni11iO <= ((((((((NOT dec_data(24)) AND wire_w_lg_w_dec_data_range201w308w(0)) AND dec_data(26)) AND dec_data(27)) AND dec_data(28)) AND (NOT dec_data(29))) AND (NOT dec_data(30))) AND (NOT dec_data(31)));
	ni11li <= ((((((((NOT dec_data(16)) AND wire_w_lg_w_dec_data_range217w300w(0)) AND dec_data(18)) AND dec_data(19)) AND dec_data(20)) AND (NOT dec_data(21))) AND (NOT dec_data(22))) AND (NOT dec_data(23)));
	ni11ll <= ((((((((NOT dec_data(8)) AND wire_w_lg_w_dec_data_range226w292w(0)) AND dec_data(10)) AND dec_data(11)) AND dec_data(12)) AND (NOT dec_data(13))) AND (NOT dec_data(14))) AND (NOT dec_data(15)));
	ni11lO <= ((((((((NOT dec_data(0)) AND wire_w_lg_w_dec_data_range235w284w(0)) AND dec_data(2)) AND dec_data(3)) AND dec_data(4)) AND (NOT dec_data(5))) AND (NOT dec_data(6))) AND (NOT dec_data(7)));
	ni1i0i <= ((((((((NOT dec_data(8)) AND wire_w_lg_w_dec_data_range226w292w(0)) AND dec_data(10)) AND dec_data(11)) AND dec_data(12)) AND dec_data(13)) AND (NOT dec_data(14))) AND dec_data(15));
	ni1i0l <= (((NOT dec_ctl(0)) OR wire_w_lg_ni1iil38w(0)) OR (NOT (ni1i0O12 XOR ni1i0O11)));
	ni1i1l <= ((((((((NOT dec_data(16)) AND wire_w_lg_w_dec_data_range217w300w(0)) AND dec_data(18)) AND dec_data(19)) AND dec_data(20)) AND dec_data(21)) AND (NOT dec_data(22))) AND dec_data(23));
	ni1i1O <= ((NOT dec_ctl(1)) OR wire_w_lg_ni1i0i45w(0));
	ni1iil <= ((((((((NOT dec_data(0)) AND wire_w_lg_w_dec_data_range235w284w(0)) AND dec_data(2)) AND dec_data(3)) AND dec_data(4)) AND dec_data(5)) AND (NOT dec_data(6))) AND dec_data(7));
	ni1iiO <= ((wire_ni0l_w_lg_dataout27w(0) AND (wire_w_lg_w_dec_ctl_range28w29w(0) AND (ni1ilO8 XOR ni1ilO7))) AND (ni1ili10 XOR ni1ili9));
	ni1iOl <= ((((((wire_w_lg_w_dec_data_range218w301w(0) AND dec_data(18)) AND dec_data(19)) AND dec_data(20)) AND dec_data(21)) AND dec_data(22)) AND dec_data(23));
	ni1iOO <= (wire_ni0i_w_lg_dataout23w(0) AND wire_w_lg_w_dec_ctl_range24w25w(0));
	ni1l0l <= ((((((wire_w_lg_w_dec_data_range236w285w(0) AND dec_data(2)) AND dec_data(3)) AND dec_data(4)) AND dec_data(5)) AND dec_data(6)) AND dec_data(7));
	ni1l0O <= (wire_n11i_w_lg_nlO0O281w(0) AND wire_n11i_w_lg_nlO0l282w(0));
	ni1l1i <= ((((((wire_w_lg_w_dec_data_range227w293w(0) AND dec_data(10)) AND dec_data(11)) AND dec_data(12)) AND dec_data(13)) AND dec_data(14)) AND dec_data(15));
	ni1l1l <= ((wire_ni1O_w_lg_dataout16w(0) AND wire_w_lg_w_dec_ctl_range17w18w(0)) AND (ni1l1O6 XOR ni1l1O5));
	ni1lii <= (wire_n11i_w_lg_w_lg_w_lg_w_lg_nill1l1w5w6w7w(0) OR (NOT (ni1lil4 XOR ni1lil3)));
	rx_ctl_rs <= ( nl0ll & niiOl & n0O1i & n000O);
	rx_data_rs <= ( nl0li & nl0iO & nl0il & nl0ii & nl00O & nl00l & nl00i & niiOO & niiOi & niilO & niill & niili & niiiO & niiil & niiii & n0O1l & n0lOO & n0lOl & n0lOi & n0llO & n0lll & n0lli & n0liO & n00ii & n000l & n000i & n001O & n001l & n001i & n01OO & n01Ol & n1i1i);
	rx_local_fault <= n10i;
	xs_link_status <= nlOll;
	wire_w_dec_ctl_range17w(0) <= dec_ctl(0);
	wire_w_dec_ctl_range24w(0) <= dec_ctl(1);
	wire_w_dec_ctl_range28w(0) <= dec_ctl(2);
	wire_w_dec_ctl_range54w(0) <= dec_ctl(3);
	wire_w_dec_data_range236w(0) <= dec_data(0);
	wire_w_dec_data_range218w(0) <= dec_data(16);
	wire_w_dec_data_range217w(0) <= dec_data(17);
	wire_w_dec_data_range235w(0) <= dec_data(1);
	wire_w_dec_data_range202w(0) <= dec_data(24);
	wire_w_dec_data_range201w(0) <= dec_data(25);
	wire_w_dec_data_range227w(0) <= dec_data(8);
	wire_w_dec_data_range226w(0) <= dec_data(9);
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Olli45 <= n0Olli46;
		END IF;
		if (now = 0 ns) then
			n0Olli45 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0Olli46 <= n0Olli45;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OlOl43 <= n0OlOl44;
		END IF;
		if (now = 0 ns) then
			n0OlOl43 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OlOl44 <= n0OlOl43;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OO0l39 <= n0OO0l40;
		END IF;
		if (now = 0 ns) then
			n0OO0l39 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OO0l40 <= n0OO0l39;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OO1l41 <= n0OO1l42;
		END IF;
		if (now = 0 ns) then
			n0OO1l41 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OO1l42 <= n0OO1l41;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OOil37 <= n0OOil38;
		END IF;
		if (now = 0 ns) then
			n0OOil37 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OOil38 <= n0OOil37;
		END IF;
	END PROCESS;
	wire_n0OOil38_w_lg_w_lg_q150w151w(0) <= wire_n0OOil38_w_lg_q150w(0) AND wire_nlO1l_dataout;
	wire_n0OOil38_w_lg_q150w(0) <= n0OOil38 XOR n0OOil37;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OOiO35 <= n0OOiO36;
		END IF;
		if (now = 0 ns) then
			n0OOiO35 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OOiO36 <= n0OOiO35;
		END IF;
	END PROCESS;
	wire_n0OOiO36_w_lg_w_lg_q145w146w(0) <= wire_n0OOiO36_w_lg_q145w(0) AND wire_nlO1l_dataout;
	wire_n0OOiO36_w_lg_q145w(0) <= n0OOiO36 XOR n0OOiO35;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OOli33 <= n0OOli34;
		END IF;
		if (now = 0 ns) then
			n0OOli33 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OOli34 <= n0OOli33;
		END IF;
	END PROCESS;
	wire_n0OOli34_w_lg_w_lg_q129w130w(0) <= wire_n0OOli34_w_lg_q129w(0) AND nlO0l;
	wire_n0OOli34_w_lg_q129w(0) <= n0OOli34 XOR n0OOli33;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OOlO31 <= n0OOlO32;
		END IF;
		if (now = 0 ns) then
			n0OOlO31 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OOlO32 <= n0OOlO31;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OOOl29 <= n0OOOl30;
		END IF;
		if (now = 0 ns) then
			n0OOOl29 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OOOl30 <= n0OOOl29;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OOOO27 <= n0OOOO28;
		END IF;
		if (now = 0 ns) then
			n0OOOO27 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN n0OOOO28 <= n0OOOO27;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni100l15 <= ni100l16;
		END IF;
		if (now = 0 ns) then
			ni100l15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni100l16 <= ni100l15;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni10OO13 <= ni10OO14;
		END IF;
		if (now = 0 ns) then
			ni10OO13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni10OO14 <= ni10OO13;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni110l23 <= ni110l24;
		END IF;
		if (now = 0 ns) then
			ni110l23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni110l24 <= ni110l23;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni111l25 <= ni111l26;
		END IF;
		if (now = 0 ns) then
			ni111l25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni111l26 <= ni111l25;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni11ii21 <= ni11ii22;
		END IF;
		if (now = 0 ns) then
			ni11ii21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni11ii22 <= ni11ii21;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni11Oi19 <= ni11Oi20;
		END IF;
		if (now = 0 ns) then
			ni11Oi19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni11Oi20 <= ni11Oi19;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni11OO17 <= ni11OO18;
		END IF;
		if (now = 0 ns) then
			ni11OO17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni11OO18 <= ni11OO17;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni1i0O11 <= ni1i0O12;
		END IF;
		if (now = 0 ns) then
			ni1i0O11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni1i0O12 <= ni1i0O11;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni1ili10 <= ni1ili9;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni1ili9 <= ni1ili10;
		END IF;
		if (now = 0 ns) then
			ni1ili9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni1ilO7 <= ni1ilO8;
		END IF;
		if (now = 0 ns) then
			ni1ilO7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni1ilO8 <= ni1ilO7;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni1l1O5 <= ni1l1O6;
		END IF;
		if (now = 0 ns) then
			ni1l1O5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni1l1O6 <= ni1l1O5;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni1lil3 <= ni1lil4;
		END IF;
		if (now = 0 ns) then
			ni1lil3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni1lil4 <= ni1lil3;
		END IF;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni1lli1 <= ni1lli2;
		END IF;
		if (now = 0 ns) then
			ni1lli1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (clk_2)
	BEGIN
		IF (clk_2 = '1' AND clk_2'event) THEN ni1lli2 <= ni1lli1;
		END IF;
	END PROCESS;
	wire_ni1lli2_w_lg_w_lg_q3w4w(0) <= NOT wire_ni1lli2_w_lg_q3w(0);
	wire_ni1lli2_w_lg_q3w(0) <= ni1lli2 XOR ni1lli1;
	PROCESS (clk_2, wire_n11i_PRN, wire_n11i_CLRN)
	BEGIN
		IF (wire_n11i_PRN = '0') THEN
				n000i <= '1';
				n001O <= '1';
				n00ii <= '1';
				n01Ol <= '1';
				n0liO <= '1';
				n0lli <= '1';
				n0lll <= '1';
				n0llO <= '1';
				n0lOi <= '1';
				n0lOl <= '1';
				n0lOO <= '1';
				n0O1i <= '1';
				n0O1l <= '1';
				n10il <= '1';
				n10iO <= '1';
				n10li <= '1';
				n10ll <= '1';
				n10lO <= '1';
				n10Oi <= '1';
				n10Ol <= '1';
				n10OO <= '1';
				n11l <= '1';
				n1i1i <= '1';
				nii00i <= '1';
				nii00l <= '1';
				nii00O <= '1';
				nii0ii <= '1';
				nii0il <= '1';
				nii0lO <= '1';
				nii0Oi <= '1';
				niiii <= '1';
				niiil <= '1';
				niiiO <= '1';
				niili <= '1';
				niill <= '1';
				niilO <= '1';
				niiOi <= '1';
				niiOl <= '1';
				nill0i <= '1';
				nill1l <= '1';
				nill1O <= '1';
				nillil <= '1';
				nilliO <= '1';
				nillll <= '1';
				niO00i <= '1';
				niO00l <= '1';
				niO00O <= '1';
				niO01O <= '1';
				niO0ii <= '1';
				niO0il <= '1';
				niO0iO <= '1';
				niO0li <= '1';
				niO0ll <= '1';
				nl00i <= '1';
				nl00l <= '1';
				nl00O <= '1';
				nl0ii <= '1';
				nl0iiO <= '1';
				nl0il <= '1';
				nl0ili <= '1';
				nl0ill <= '1';
				nl0ilO <= '1';
				nl0iO <= '1';
				nl0iOi <= '1';
				nl0iOl <= '1';
				nl0iOO <= '1';
				nl0l1i <= '1';
				nl0l1l <= '1';
				nl0li <= '1';
				nl0ll <= '1';
				nl0lO <= '1';
				nl1l0O <= '1';
				nl1lii <= '1';
				nl1lil <= '1';
				nl1liO <= '1';
				nl1lli <= '1';
				nl1lll <= '1';
				nl1llO <= '1';
				nl1lOi <= '1';
				nl1lOl <= '1';
				nliOlO <= '1';
				nliOOi <= '1';
				nliOOl <= '1';
				nliOOO <= '1';
				nll10i <= '1';
				nll11i <= '1';
				nll11l <= '1';
				nll11O <= '1';
				nlllOO <= '1';
				nllO0i <= '1';
				nllO0l <= '1';
				nllO0O <= '1';
				nllO1i <= '1';
				nllO1l <= '1';
				nllO1O <= '1';
				nllOii <= '1';
				nlO0i <= '1';
				nlO0l <= '1';
				nlO0O <= '1';
				nlOii <= '1';
				nlOil <= '1';
				nlOiO <= '1';
				nlOli <= '1';
				nlOll <= '1';
				nlOlO <= '1';
		ELSIF (wire_n11i_CLRN = '0') THEN
				n000i <= '0';
				n001O <= '0';
				n00ii <= '0';
				n01Ol <= '0';
				n0liO <= '0';
				n0lli <= '0';
				n0lll <= '0';
				n0llO <= '0';
				n0lOi <= '0';
				n0lOl <= '0';
				n0lOO <= '0';
				n0O1i <= '0';
				n0O1l <= '0';
				n10il <= '0';
				n10iO <= '0';
				n10li <= '0';
				n10ll <= '0';
				n10lO <= '0';
				n10Oi <= '0';
				n10Ol <= '0';
				n10OO <= '0';
				n11l <= '0';
				n1i1i <= '0';
				nii00i <= '0';
				nii00l <= '0';
				nii00O <= '0';
				nii0ii <= '0';
				nii0il <= '0';
				nii0lO <= '0';
				nii0Oi <= '0';
				niiii <= '0';
				niiil <= '0';
				niiiO <= '0';
				niili <= '0';
				niill <= '0';
				niilO <= '0';
				niiOi <= '0';
				niiOl <= '0';
				nill0i <= '0';
				nill1l <= '0';
				nill1O <= '0';
				nillil <= '0';
				nilliO <= '0';
				nillll <= '0';
				niO00i <= '0';
				niO00l <= '0';
				niO00O <= '0';
				niO01O <= '0';
				niO0ii <= '0';
				niO0il <= '0';
				niO0iO <= '0';
				niO0li <= '0';
				niO0ll <= '0';
				nl00i <= '0';
				nl00l <= '0';
				nl00O <= '0';
				nl0ii <= '0';
				nl0iiO <= '0';
				nl0il <= '0';
				nl0ili <= '0';
				nl0ill <= '0';
				nl0ilO <= '0';
				nl0iO <= '0';
				nl0iOi <= '0';
				nl0iOl <= '0';
				nl0iOO <= '0';
				nl0l1i <= '0';
				nl0l1l <= '0';
				nl0li <= '0';
				nl0ll <= '0';
				nl0lO <= '0';
				nl1l0O <= '0';
				nl1lii <= '0';
				nl1lil <= '0';
				nl1liO <= '0';
				nl1lli <= '0';
				nl1lll <= '0';
				nl1llO <= '0';
				nl1lOi <= '0';
				nl1lOl <= '0';
				nliOlO <= '0';
				nliOOi <= '0';
				nliOOl <= '0';
				nliOOO <= '0';
				nll10i <= '0';
				nll11i <= '0';
				nll11l <= '0';
				nll11O <= '0';
				nlllOO <= '0';
				nllO0i <= '0';
				nllO0l <= '0';
				nllO0O <= '0';
				nllO1i <= '0';
				nllO1l <= '0';
				nllO1O <= '0';
				nllOii <= '0';
				nlO0i <= '0';
				nlO0l <= '0';
				nlO0O <= '0';
				nlOii <= '0';
				nlOil <= '0';
				nlOiO <= '0';
				nlOli <= '0';
				nlOll <= '0';
				nlOlO <= '0';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
				n000i <= wire_n00Ol_dataout;
				n001O <= wire_n00Oi_dataout;
				n00ii <= wire_n0O1O_dataout;
				n01Ol <= wire_n00iO_dataout;
				n0liO <= wire_n0O0i_dataout;
				n0lli <= wire_n0O0l_dataout;
				n0lll <= wire_n0O0O_dataout;
				n0llO <= wire_n0Oii_dataout;
				n0lOi <= wire_n0Oil_dataout;
				n0lOl <= wire_n0OiO_dataout;
				n0lOO <= wire_n0Oli_dataout;
				n0O1i <= wire_n0Oll_dataout;
				n0O1l <= wire_nil1i_dataout;
				n10il <= wire_n1i1O_dataout;
				n10iO <= wire_n1i0i_dataout;
				n10li <= wire_n1i0l_dataout;
				n10ll <= wire_n1i0O_dataout;
				n10lO <= wire_n1iii_dataout;
				n10Oi <= wire_n1iil_dataout;
				n10Ol <= wire_n1iiO_dataout;
				n10OO <= wire_n1ili_dataout;
				n11l <= rx_local_fault_clr;
				n1i1i <= wire_n00il_dataout;
				nii00i <= ni1iiO;
				nii00l <= ni1iOO;
				nii00O <= (wire_ni0O_w_lg_dataout237w(0) AND wire_w_lg_w_dec_ctl_range54w238w(0));
				nii0ii <= wire_niii1l_dataout;
				nii0il <= wire_niii1O_dataout;
				nii0lO <= wire_niiiii_dataout;
				nii0Oi <= wire_niiiil_dataout;
				niiii <= wire_nil1l_dataout;
				niiil <= wire_nil1O_dataout;
				niiiO <= wire_nil0i_dataout;
				niili <= wire_nil0l_dataout;
				niill <= wire_nil0O_dataout;
				niilO <= wire_nilii_dataout;
				niiOi <= wire_nilil_dataout;
				niiOl <= wire_niliO_dataout;
				nill0i <= wire_nillOl_dataout;
				nill1l <= ni1l1l;
				nill1O <= wire_nillOi_dataout;
				nillil <= wire_nilO1O_dataout;
				nilliO <= wire_nilO0i_dataout;
				nillll <= wire_niO0lO_dataout;
				niO00i <= wire_niO0Ol_dataout;
				niO00l <= wire_niO0OO_dataout;
				niO00O <= wire_niOi1i_dataout;
				niO01O <= wire_niO0Oi_dataout;
				niO0ii <= wire_niOi1l_dataout;
				niO0il <= wire_niOi1O_dataout;
				niO0iO <= wire_niOi0i_dataout;
				niO0li <= wire_niOi0l_dataout;
				niO0ll <= wire_nl1lOO_dataout;
				nl00i <= wire_nl0Ol_dataout;
				nl00l <= wire_nl0OO_dataout;
				nl00O <= wire_nli1i_dataout;
				nl0ii <= wire_nli1l_dataout;
				nl0iiO <= wire_nl0l0i_dataout;
				nl0il <= wire_nli1O_dataout;
				nl0ili <= wire_nl0l0l_dataout;
				nl0ill <= wire_nl0l0O_dataout;
				nl0ilO <= wire_nl0lii_dataout;
				nl0iO <= wire_nli0i_dataout;
				nl0iOi <= wire_nl0lil_dataout;
				nl0iOl <= wire_nl0liO_dataout;
				nl0iOO <= wire_nl0lli_dataout;
				nl0l1i <= wire_nl0lll_dataout;
				nl0l1l <= wire_nll10O_dataout;
				nl0li <= wire_nli0l_dataout;
				nl0ll <= wire_nli0O_dataout;
				nl0lO <= nlO0i;
				nl1l0O <= wire_nl1O1i_dataout;
				nl1lii <= wire_nl1O1l_dataout;
				nl1lil <= wire_nl1O1O_dataout;
				nl1liO <= wire_nl1O0i_dataout;
				nl1lli <= wire_nl1O0l_dataout;
				nl1lll <= wire_nl1O0O_dataout;
				nl1llO <= wire_nl1Oii_dataout;
				nl1lOi <= wire_nl1Oil_dataout;
				nl1lOl <= wire_nl0l1O_dataout;
				nliOlO <= wire_nll1ii_dataout;
				nliOOi <= wire_nll1il_dataout;
				nliOOl <= wire_nll1iO_dataout;
				nliOOO <= wire_nll1li_dataout;
				nll10i <= wire_nll1Ol_dataout;
				nll11i <= wire_nll1ll_dataout;
				nll11l <= wire_nll1lO_dataout;
				nll11O <= wire_nll1Oi_dataout;
				nlllOO <= wire_nllOli_dataout;
				nllO0i <= wire_nllOOl_dataout;
				nllO0l <= wire_nllOOO_dataout;
				nllO0O <= wire_nlO11i_dataout;
				nllO1i <= wire_nllOll_dataout;
				nllO1l <= wire_nllOlO_dataout;
				nllO1O <= wire_nllOOi_dataout;
				nllOii <= wire_nlO11l_dataout;
				nlO0i <= indv;
				nlO0l <= wire_nllOO_w_lg_o126w(0);
				nlO0O <= wire_nllOi_o;
				nlOii <= nlOil;
				nlOil <= tx_local_fault_det;
				nlOiO <= nlOli;
				nlOli <= xs_link_status_set;
				nlOll <= wire_nlOOi_dataout;
				nlOlO <= n11l;
		END IF;
	END PROCESS;
	wire_n11i_CLRN <= ((n0OOOO28 XOR n0OOOO27) AND wire_w_lg_soft_reset116w(0));
	wire_n11i_PRN <= (n0OOOl30 XOR n0OOOl29);
	wire_n11i_w_lg_nlO0l282w(0) <= NOT nlO0l;
	wire_n11i_w_lg_nlO0O281w(0) <= NOT nlO0O;
	wire_n11i_w_lg_w_lg_w_lg_w_lg_nill1l1w5w6w7w(0) <= wire_n11i_w_lg_w_lg_w_lg_nill1l1w5w6w(0) OR nii00O;
	wire_n11i_w_lg_w_lg_w_lg_nill1l1w5w6w(0) <= wire_n11i_w_lg_w_lg_nill1l1w5w(0) OR nii00i;
	wire_n11i_w_lg_w_lg_nill1l1w5w(0) <= wire_n11i_w_lg_nill1l1w(0) OR wire_ni1lli2_w_lg_w_lg_q3w4w(0);
	wire_n11i_w_lg_nill1l1w(0) <= nill1l OR nii00l;
	PROCESS (clk_2, soft_reset, wire_n11O_CLRN)
	BEGIN
		IF (soft_reset = '1') THEN
				n000l <= '1';
				n000O <= '1';
				n001i <= '1';
				n001l <= '1';
				n01OO <= '1';
				n10i <= '1';
				nii0iO <= '1';
				nii0li <= '1';
				nii0ll <= '1';
				nii0Ol <= '1';
				nii0OO <= '1';
				niii1i <= '1';
				niiOO <= '1';
				nill0l <= '1';
				nill0O <= '1';
				nillii <= '1';
				nillli <= '1';
				nll10l <= '1';
				nllOil <= '1';
		ELSIF (wire_n11O_CLRN = '0') THEN
				n000l <= '0';
				n000O <= '0';
				n001i <= '0';
				n001l <= '0';
				n01OO <= '0';
				n10i <= '0';
				nii0iO <= '0';
				nii0li <= '0';
				nii0ll <= '0';
				nii0Ol <= '0';
				nii0OO <= '0';
				niii1i <= '0';
				niiOO <= '0';
				nill0l <= '0';
				nill0O <= '0';
				nillii <= '0';
				nillli <= '0';
				nll10l <= '0';
				nllOil <= '0';
		ELSIF (clk_2 = '1' AND clk_2'event) THEN
				n000l <= wire_n00OO_dataout;
				n000O <= wire_n0i1i_dataout;
				n001i <= wire_n00ll_dataout;
				n001l <= wire_n00lO_dataout;
				n01OO <= wire_n00li_dataout;
				n10i <= wire_n10l_dataout;
				nii0iO <= wire_niii0i_dataout;
				nii0li <= wire_niii0l_dataout;
				nii0ll <= wire_niii0O_dataout;
				nii0Ol <= wire_niiiiO_dataout;
				nii0OO <= wire_niiili_dataout;
				niii1i <= wire_nilllO_dataout;
				niiOO <= wire_nl0Oi_dataout;
				nill0l <= wire_nillOO_dataout;
				nill0O <= wire_nilO1i_dataout;
				nillii <= wire_nilO1l_dataout;
				nillli <= wire_nilO0l_dataout;
				nll10l <= wire_nllOiO_dataout;
				nllOil <= wire_n1i1l_dataout;
		END IF;
		if (now = 0 ns) then
			n000l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n000O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n001i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n001l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n01OO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			n10i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nii0iO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nii0li <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nii0ll <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nii0Ol <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nii0OO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			niii1i <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			niiOO <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nill0l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nill0O <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nillii <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nillli <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nll10l <= '1' after 1 ps;
		end if;
		if (now = 0 ns) then
			nllOil <= '1' after 1 ps;
		end if;
	END PROCESS;
	wire_n11O_CLRN <= (ni111l26 XOR ni111l25);
	wire_n00il_dataout <= wire_n0i1l_dataout AND NOT(ni1l0O);
	wire_n00iO_dataout <= wire_n0i1O_dataout AND NOT(ni1l0O);
	wire_n00li_dataout <= wire_n0i0i_dataout OR ni1l0O;
	wire_n00ll_dataout <= wire_n0i0l_dataout OR ni1l0O;
	wire_n00lO_dataout <= wire_n0i0O_dataout OR ni1l0O;
	wire_n00Oi_dataout <= wire_n0iii_dataout AND NOT(ni1l0O);
	wire_n00Ol_dataout <= wire_n0iil_dataout AND NOT(ni1l0O);
	wire_n00OO_dataout <= wire_n0iiO_dataout OR ni1l0O;
	wire_n010i_dataout <= wire_n1O1i_dataout OR n0Ol1l;
	wire_n010l_dataout <= wire_n1O1l_dataout AND NOT(n0Ol1l);
	wire_n010O_dataout <= wire_n1O1O_dataout AND NOT(n0Ol1l);
	wire_n011i_dataout <= wire_n01li_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_n011l_dataout <= wire_n1lOl_dataout OR n0Ol1l;
	wire_n011O_dataout <= wire_n1lOO_dataout OR n0Ol1l;
	wire_n01ii_dataout <= wire_n1O0i_dataout AND NOT(n0Ol1l);
	wire_n01il_dataout <= wire_n1O0l_dataout AND NOT(n0Ol1l);
	wire_n01iO_dataout <= wire_n1O0O_dataout AND NOT(n0Ol1l);
	wire_n01li_dataout <= wire_n1Oii_dataout OR n0Ol1l;
	wire_n0i_dataout <= nliOOO WHEN rxaui_s2gx_en = '1'  ELSE nl0ilO;
	wire_n0i0i_dataout <= wire_n0iOi_dataout WHEN n0Ol0O = '1'  ELSE wire_nl1i_dataout;
	wire_n0i0l_dataout <= wire_n0iOl_dataout WHEN n0Ol0O = '1'  ELSE wire_nl1l_dataout;
	wire_n0i0O_dataout <= wire_n0iOO_dataout WHEN n0Ol0O = '1'  ELSE wire_nl1O_dataout;
	wire_n0i1i_dataout <= wire_n0ili_dataout OR ni1l0O;
	wire_n0i1l_dataout <= wire_n0ill_dataout WHEN n0Ol0O = '1'  ELSE wire_niOl_dataout;
	wire_n0i1O_dataout <= wire_n0ilO_dataout WHEN n0Ol0O = '1'  ELSE wire_niOO_dataout;
	wire_n0iii_dataout <= wire_n0l1i_dataout WHEN n0Ol0O = '1'  ELSE wire_nl0i_dataout;
	wire_n0iil_dataout <= wire_n0l1l_dataout WHEN n0Ol0O = '1'  ELSE wire_nl0l_dataout;
	wire_n0iiO_dataout <= wire_n0l1O_dataout WHEN n0Ol0O = '1'  ELSE wire_nl0O_dataout;
	wire_n0ili_dataout <= wire_n0l0i_dataout WHEN n0Ol0O = '1'  ELSE wire_nili_dataout;
	wire_n0ill_dataout <= wire_niOl_dataout AND NOT(n0Ol0l);
	wire_n0ilO_dataout <= wire_niOO_dataout OR n0Ol0l;
	wire_n0iOi_dataout <= wire_nl1i_dataout OR n0Ol0l;
	wire_n0iOl_dataout <= wire_nl1l_dataout OR n0Ol0l;
	wire_n0iOO_dataout <= wire_nl1O_dataout OR n0Ol0l;
	wire_n0l_dataout <= nll11i WHEN rxaui_s2gx_en = '1'  ELSE nl0iOi;
	wire_n0l0i_dataout <= wire_nili_dataout OR n0Ol0l;
	wire_n0l1i_dataout <= wire_nl0i_dataout OR n0Ol0l;
	wire_n0l1l_dataout <= wire_nl0l_dataout OR n0Ol0l;
	wire_n0l1O_dataout <= wire_nl0O_dataout OR n0Ol0l;
	wire_n0O_dataout <= nll11l WHEN rxaui_s2gx_en = '1'  ELSE nl0iOl;
	wire_n0O0i_dataout <= wire_n0OOi_dataout AND NOT(ni1l0O);
	wire_n0O0l_dataout <= wire_n0OOl_dataout AND NOT(ni1l0O);
	wire_n0O0O_dataout <= wire_n0OOO_dataout AND NOT(ni1l0O);
	wire_n0O1O_dataout <= wire_n0OlO_dataout AND NOT(ni1l0O);
	wire_n0Oii_dataout <= wire_ni11i_dataout AND NOT(ni1l0O);
	wire_n0Oil_dataout <= wire_ni11l_dataout AND NOT(ni1l0O);
	wire_n0OiO_dataout <= wire_ni11O_dataout AND NOT(ni1l0O);
	wire_n0Oli_dataout <= wire_ni10i_dataout AND NOT(ni1l0O);
	wire_n0Oll_dataout <= wire_ni10l_dataout AND NOT(ni1l0O);
	wire_n0OlO_dataout <= wire_ni0lO_dataout WHEN ni1l1l = '1'  ELSE wire_ni10O_dataout;
	wire_n0OOi_dataout <= wire_ni0Oi_dataout WHEN ni1l1l = '1'  ELSE wire_ni1ii_dataout;
	wire_n0OOl_dataout <= wire_ni0Ol_dataout WHEN ni1l1l = '1'  ELSE wire_ni1il_dataout;
	wire_n0OOO_dataout <= wire_ni0OO_dataout WHEN ni1l1l = '1'  ELSE wire_ni1iO_dataout;
	wire_n100i_dataout <= wire_nlOlli_dataout OR n0OiOO;
	wire_n100l_dataout <= wire_nlOlll_dataout OR n0OiOO;
	wire_n101i_dataout <= wire_nlOlii_dataout OR n0OiOO;
	wire_n101l_dataout <= wire_nlOlil_dataout OR n0OiOO;
	wire_n101O_dataout <= wire_nlOliO_dataout OR n0OiOO;
	wire_n10l_dataout <= wire_n10O_dataout AND NOT(nlOlO);
	wire_n10O_dataout <= n10i OR NOT(ni111O);
	wire_n110i_dataout <= wire_nlOill_dataout OR n0OiOl;
	wire_n110l_dataout <= n0OO1i WHEN n0OiOl = '1'  ELSE wire_nlOilO_dataout;
	wire_n110O_dataout <= n0OO1i WHEN n0OiOl = '1'  ELSE wire_nlOiOi_dataout;
	wire_n111i_dataout <= wire_n100l_dataout WHEN ni1lii = '1'  ELSE wire_n11li_dataout;
	wire_n111l_dataout <= wire_w_lg_n0OO1i205w(0) WHEN n0OiOl = '1'  ELSE wire_nlOiiO_dataout;
	wire_n111O_dataout <= wire_nlOili_dataout OR n0OiOl;
	wire_n11ii_dataout <= n0OO1i WHEN n0OiOl = '1'  ELSE wire_nlOiOl_dataout;
	wire_n11il_dataout <= n0OO1i WHEN n0OiOl = '1'  ELSE wire_nlOiOO_dataout;
	wire_n11iO_dataout <= n0OO1i WHEN n0OiOl = '1'  ELSE wire_nlOl1i_dataout;
	wire_n11li_dataout <= wire_nlOl1l_dataout OR n0OiOl;
	wire_n11lO_dataout <= wire_nlOl1O_dataout AND NOT(n0OiOO);
	wire_n11Oi_dataout <= wire_nlOl0i_dataout OR n0OiOO;
	wire_n11Ol_dataout <= wire_nlOl0l_dataout OR n0OiOO;
	wire_n11OO_dataout <= wire_nlOl0O_dataout OR n0OiOO;
	wire_n1i_dataout <= nliOlO WHEN rxaui_s2gx_en = '1'  ELSE nl0iiO;
	wire_n1i0i_dataout <= wire_n1Oli_dataout WHEN n0Ol1i = '1'  ELSE wire_n1iOi_dataout;
	wire_n1i0l_dataout <= wire_n1Oll_dataout WHEN n0Ol1i = '1'  ELSE wire_n1iOl_dataout;
	wire_n1i0O_dataout <= wire_n1OlO_dataout WHEN n0Ol1i = '1'  ELSE wire_n1iOO_dataout;
	wire_n1i1l_dataout <= wire_n1Oil_dataout WHEN n0Ol1i = '1'  ELSE wire_n1ill_dataout;
	wire_n1i1O_dataout <= wire_n1OiO_dataout WHEN n0Ol1i = '1'  ELSE wire_n1ilO_dataout;
	wire_n1iii_dataout <= wire_n1OOi_dataout WHEN n0Ol1i = '1'  ELSE wire_n1l1i_dataout;
	wire_n1iil_dataout <= wire_n1OOl_dataout WHEN n0Ol1i = '1'  ELSE wire_n1l1l_dataout;
	wire_n1iiO_dataout <= wire_n1OOO_dataout WHEN n0Ol1i = '1'  ELSE wire_n1l1O_dataout;
	wire_n1ili_dataout <= wire_n011i_dataout WHEN n0Ol1i = '1'  ELSE wire_n1l0i_dataout;
	wire_n1ill_dataout <= wire_n1l0l_dataout OR wire_w_lg_ni111O120w(0);
	wire_n1ilO_dataout <= wire_n1l0O_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_n1iOi_dataout <= wire_n1lii_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_n1iOl_dataout <= wire_n1lil_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_n1iOO_dataout <= wire_n1liO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_n1l_dataout <= nliOOi WHEN rxaui_s2gx_en = '1'  ELSE nl0ili;
	wire_n1l0i_dataout <= wire_n1lOi_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_n1l0l_dataout <= wire_n1lOl_dataout OR ni110i;
	wire_n1l0O_dataout <= wire_n1lOO_dataout OR ni110i;
	wire_n1l1i_dataout <= wire_n1lli_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_n1l1l_dataout <= wire_n1lll_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_n1l1O_dataout <= wire_n1llO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_n1lii_dataout <= wire_n1O1i_dataout OR ni110i;
	wire_n1lil_dataout <= wire_n1O1l_dataout AND NOT(ni110i);
	wire_n1liO_dataout <= wire_n1O1O_dataout AND NOT(ni110i);
	wire_n1lli_dataout <= wire_n1O0i_dataout AND NOT(ni110i);
	wire_n1lll_dataout <= wire_n1O0l_dataout AND NOT(ni110i);
	wire_n1llO_dataout <= wire_n1O0O_dataout AND NOT(ni110i);
	wire_n1lOi_dataout <= wire_n1Oii_dataout OR ni110i;
	wire_n1lOl_dataout <= dec_data(24) AND NOT(wire_ni0O_dataout);
	wire_n1lOO_dataout <= dec_data(25) OR wire_ni0O_dataout;
	wire_n1O_dataout <= nliOOl WHEN rxaui_s2gx_en = '1'  ELSE nl0ill;
	wire_n1O0i_dataout <= dec_data(29) OR wire_ni0O_dataout;
	wire_n1O0l_dataout <= dec_data(30) OR wire_ni0O_dataout;
	wire_n1O0O_dataout <= dec_data(31) OR wire_ni0O_dataout;
	wire_n1O1i_dataout <= dec_data(26) OR wire_ni0O_dataout;
	wire_n1O1l_dataout <= dec_data(27) OR wire_ni0O_dataout;
	wire_n1O1O_dataout <= dec_data(28) OR wire_ni0O_dataout;
	wire_n1Oii_dataout <= dec_ctl(3) OR wire_ni0O_dataout;
	wire_n1Oil_dataout <= wire_n011l_dataout OR wire_w_lg_ni111O120w(0);
	wire_n1OiO_dataout <= wire_n011O_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_n1Oli_dataout <= wire_n010i_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_n1Oll_dataout <= wire_n010l_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_n1OlO_dataout <= wire_n010O_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_n1OOi_dataout <= wire_n01ii_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_n1OOl_dataout <= wire_n01il_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_n1OOO_dataout <= wire_n01iO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_ni_dataout <= n10lO WHEN rxaui_s2gx_en = '1'  ELSE nllO0i;
	wire_ni00i_dataout <= wire_nlll_dataout OR n0Olii;
	wire_ni00l_dataout <= wire_nllO_dataout OR n0Olii;
	wire_ni00O_dataout <= wire_nlOi_dataout OR n0Olii;
	wire_ni01i_dataout <= wire_nlil_dataout OR n0Olii;
	wire_ni01l_dataout <= wire_nliO_dataout OR n0Olii;
	wire_ni01O_dataout <= wire_nlli_dataout OR n0Olii;
	wire_ni0i_dataout <= running_disp(1) AND NOT(ni1l0O);
	wire_ni0i_w_lg_dataout23w(0) <= NOT wire_ni0i_dataout;
	wire_ni0ii_dataout <= wire_nlOl_dataout OR n0Olii;
	wire_ni0il_dataout <= wire_nill_dataout OR n0Olii;
	wire_ni0l_dataout <= running_disp(2) AND NOT(ni1l0O);
	wire_ni0l_w_lg_dataout27w(0) <= NOT wire_ni0l_dataout;
	wire_ni0lO_dataout <= wire_nlii_dataout AND NOT(n0OliO);
	wire_ni0O_dataout <= running_disp(3) AND NOT(ni1l0O);
	wire_ni0O_w_lg_dataout237w(0) <= NOT wire_ni0O_dataout;
	wire_ni0Oi_dataout <= wire_nlil_dataout OR n0OliO;
	wire_ni0Ol_dataout <= wire_nliO_dataout OR n0OliO;
	wire_ni0OO_dataout <= wire_nlli_dataout OR n0OliO;
	wire_ni10i_dataout <= wire_nii0i_dataout WHEN ni1l1l = '1'  ELSE wire_ni1Oi_dataout;
	wire_ni10l_dataout <= wire_nii0l_dataout WHEN ni1l1l = '1'  ELSE wire_ni1Ol_dataout;
	wire_ni10O_dataout <= wire_ni1OO_dataout WHEN n0Olil = '1'  ELSE wire_nlii_dataout;
	wire_ni11i_dataout <= wire_nii1i_dataout WHEN ni1l1l = '1'  ELSE wire_ni1li_dataout;
	wire_ni11l_dataout <= wire_nii1l_dataout WHEN ni1l1l = '1'  ELSE wire_ni1ll_dataout;
	wire_ni11O_dataout <= wire_nii1O_dataout WHEN ni1l1l = '1'  ELSE wire_ni1lO_dataout;
	wire_ni1ii_dataout <= wire_ni01i_dataout WHEN n0Olil = '1'  ELSE wire_nlil_dataout;
	wire_ni1il_dataout <= wire_ni01l_dataout WHEN n0Olil = '1'  ELSE wire_nliO_dataout;
	wire_ni1iO_dataout <= wire_ni01O_dataout WHEN n0Olil = '1'  ELSE wire_nlli_dataout;
	wire_ni1li_dataout <= wire_ni00i_dataout WHEN n0Olil = '1'  ELSE wire_nlll_dataout;
	wire_ni1ll_dataout <= wire_ni00l_dataout WHEN n0Olil = '1'  ELSE wire_nllO_dataout;
	wire_ni1lO_dataout <= wire_ni00O_dataout WHEN n0Olil = '1'  ELSE wire_nlOi_dataout;
	wire_ni1O_dataout <= running_disp(0) AND NOT(ni1l0O);
	wire_ni1O_w_lg_dataout16w(0) <= NOT wire_ni1O_dataout;
	wire_ni1Oi_dataout <= wire_ni0ii_dataout WHEN n0Olil = '1'  ELSE wire_nlOl_dataout;
	wire_ni1Ol_dataout <= wire_ni0il_dataout WHEN n0Olil = '1'  ELSE wire_nill_dataout;
	wire_ni1OO_dataout <= wire_nlii_dataout AND NOT(n0Olii);
	wire_nii_dataout <= nll11O WHEN rxaui_s2gx_en = '1'  ELSE nl0iOO;
	wire_nii0i_dataout <= wire_nlOl_dataout OR n0OliO;
	wire_nii0l_dataout <= wire_nill_dataout OR n0OliO;
	wire_nii1i_dataout <= wire_nlll_dataout OR n0OliO;
	wire_nii1l_dataout <= wire_nllO_dataout OR n0OliO;
	wire_nii1O_dataout <= wire_nlOi_dataout OR n0OliO;
	wire_niii0i_dataout <= wire_nil0ii_dataout WHEN n0Ol1i = '1'  ELSE wire_niiiOi_dataout;
	wire_niii0l_dataout <= wire_nil0il_dataout WHEN n0Ol1i = '1'  ELSE wire_niiiOl_dataout;
	wire_niii0O_dataout <= wire_nil0iO_dataout WHEN n0Ol1i = '1'  ELSE wire_niiiOO_dataout;
	wire_niii1l_dataout <= wire_nil00l_dataout WHEN n0Ol1i = '1'  ELSE wire_niiill_dataout;
	wire_niii1O_dataout <= wire_nil00O_dataout WHEN n0Ol1i = '1'  ELSE wire_niiilO_dataout;
	wire_niiiii_dataout <= wire_nil0li_dataout WHEN n0Ol1i = '1'  ELSE wire_niil1i_dataout;
	wire_niiiil_dataout <= wire_nil0ll_dataout WHEN n0Ol1i = '1'  ELSE wire_niil1l_dataout;
	wire_niiiiO_dataout <= wire_nil0lO_dataout WHEN n0Ol1i = '1'  ELSE wire_niil1O_dataout;
	wire_niiili_dataout <= wire_nil0Oi_dataout WHEN n0Ol1i = '1'  ELSE wire_niil0i_dataout;
	wire_niiill_dataout <= wire_niiOil_dataout WHEN n0OilO = '1'  ELSE wire_niil0l_dataout;
	wire_niiilO_dataout <= wire_niiOiO_dataout WHEN n0OilO = '1'  ELSE wire_niil0O_dataout;
	wire_niiiOi_dataout <= wire_niiOli_dataout WHEN n0OilO = '1'  ELSE wire_niilii_dataout;
	wire_niiiOl_dataout <= wire_niiOll_dataout WHEN n0OilO = '1'  ELSE wire_niilil_dataout;
	wire_niiiOO_dataout <= wire_niiOlO_dataout WHEN n0OilO = '1'  ELSE wire_niiliO_dataout;
	wire_niil0i_dataout <= wire_nil11i_dataout WHEN n0OilO = '1'  ELSE wire_niilOi_dataout;
	wire_niil0l_dataout <= wire_niilOl_dataout AND ni111O;
	wire_niil0O_dataout <= wire_niilOO_dataout AND ni111O;
	wire_niil1i_dataout <= wire_niiOOi_dataout WHEN n0OilO = '1'  ELSE wire_niilli_dataout;
	wire_niil1l_dataout <= wire_niiOOl_dataout WHEN n0OilO = '1'  ELSE wire_niilll_dataout;
	wire_niil1O_dataout <= wire_niiOOO_dataout WHEN n0OilO = '1'  ELSE wire_niillO_dataout;
	wire_niilii_dataout <= wire_niiO1i_dataout OR NOT(ni111O);
	wire_niilil_dataout <= wire_niiO1l_dataout OR NOT(ni111O);
	wire_niiliO_dataout <= wire_niiO1O_dataout OR NOT(ni111O);
	wire_niilli_dataout <= wire_niiO0i_dataout AND ni111O;
	wire_niilll_dataout <= wire_niiO0l_dataout AND ni111O;
	wire_niillO_dataout <= wire_niiO0O_dataout OR NOT(ni111O);
	wire_niilOi_dataout <= wire_niiOii_dataout OR NOT(ni111O);
	wire_niilOl_dataout <= dec_data(0) OR ni110i;
	wire_niilOO_dataout <= dec_data(1) OR ni110i;
	wire_niiO0i_dataout <= dec_data(5) AND NOT(ni110i);
	wire_niiO0l_dataout <= dec_data(6) AND NOT(ni110i);
	wire_niiO0O_dataout <= dec_data(7) AND NOT(ni110i);
	wire_niiO1i_dataout <= dec_data(2) OR ni110i;
	wire_niiO1l_dataout <= dec_data(3) AND NOT(ni110i);
	wire_niiO1O_dataout <= dec_data(4) AND NOT(ni110i);
	wire_niiOii_dataout <= dec_ctl(0) OR ni110i;
	wire_niiOil_dataout <= wire_nil11l_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_niiOiO_dataout <= wire_nil11O_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_niiOli_dataout <= wire_nil10i_dataout OR wire_w_lg_ni111O120w(0);
	wire_niiOll_dataout <= wire_nil10l_dataout OR wire_w_lg_ni111O120w(0);
	wire_niiOlO_dataout <= wire_nil10O_dataout OR wire_w_lg_ni111O120w(0);
	wire_niiOOi_dataout <= wire_nil1ii_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_niiOOl_dataout <= wire_nil1il_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_niiOOO_dataout <= wire_nil1iO_dataout OR wire_w_lg_ni111O120w(0);
	wire_nil_dataout <= nllOil WHEN rxaui_s2gx_en = '1'  ELSE nll10l;
	wire_nil00i_dataout <= dec_ctl(0) OR n0OiOi;
	wire_nil00l_dataout <= wire_nil0Ol_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nil00O_dataout <= wire_nil0OO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nil01i_dataout <= dec_data(5) AND NOT(n0OiOi);
	wire_nil01l_dataout <= dec_data(6) AND NOT(n0OiOi);
	wire_nil01O_dataout <= dec_data(7) AND NOT(n0OiOi);
	wire_nil0i_dataout <= wire_nilOi_dataout AND NOT(ni1l0O);
	wire_nil0ii_dataout <= wire_nili1i_dataout OR wire_w_lg_ni111O120w(0);
	wire_nil0il_dataout <= wire_nili1l_dataout OR wire_w_lg_ni111O120w(0);
	wire_nil0iO_dataout <= wire_nili1O_dataout OR wire_w_lg_ni111O120w(0);
	wire_nil0l_dataout <= wire_nilOl_dataout AND NOT(ni1l0O);
	wire_nil0li_dataout <= wire_nili0i_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nil0ll_dataout <= wire_nili0l_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nil0lO_dataout <= wire_nili0O_dataout OR wire_w_lg_ni111O120w(0);
	wire_nil0O_dataout <= wire_nilOO_dataout AND NOT(ni1l0O);
	wire_nil0Oi_dataout <= wire_niliii_dataout OR wire_w_lg_ni111O120w(0);
	wire_nil0Ol_dataout <= wire_niliil_dataout WHEN ni1lii = '1'  ELSE wire_nil11l_dataout;
	wire_nil0OO_dataout <= wire_niliiO_dataout WHEN ni1lii = '1'  ELSE wire_nil11O_dataout;
	wire_nil10i_dataout <= wire_nil1Oi_dataout OR wire_ni1O_dataout;
	wire_nil10l_dataout <= wire_nil1Ol_dataout OR wire_ni1O_dataout;
	wire_nil10O_dataout <= wire_nil1OO_dataout OR wire_ni1O_dataout;
	wire_nil11i_dataout <= wire_nil1li_dataout OR wire_w_lg_ni111O120w(0);
	wire_nil11l_dataout <= wire_nil1ll_dataout AND NOT(wire_ni1O_dataout);
	wire_nil11O_dataout <= wire_nil1lO_dataout OR wire_ni1O_dataout;
	wire_nil1i_dataout <= wire_nilli_dataout AND NOT(ni1l0O);
	wire_nil1ii_dataout <= wire_nil01i_dataout OR wire_ni1O_dataout;
	wire_nil1il_dataout <= wire_nil01l_dataout OR wire_ni1O_dataout;
	wire_nil1iO_dataout <= wire_nil01O_dataout OR wire_ni1O_dataout;
	wire_nil1l_dataout <= wire_nilll_dataout AND NOT(ni1l0O);
	wire_nil1li_dataout <= wire_nil00i_dataout OR wire_ni1O_dataout;
	wire_nil1ll_dataout <= dec_data(0) OR n0OiOi;
	wire_nil1lO_dataout <= dec_data(1) OR n0OiOi;
	wire_nil1O_dataout <= wire_nillO_dataout AND NOT(ni1l0O);
	wire_nil1Oi_dataout <= dec_data(2) OR n0OiOi;
	wire_nil1Ol_dataout <= dec_data(3) AND NOT(n0OiOi);
	wire_nil1OO_dataout <= dec_data(4) AND NOT(n0OiOi);
	wire_nili_dataout <= niii1i WHEN rxaui_s2gx_en = '1'  ELSE nii0OO;
	wire_nili0i_dataout <= wire_niliOi_dataout WHEN ni1lii = '1'  ELSE wire_nil1ii_dataout;
	wire_nili0l_dataout <= wire_niliOl_dataout WHEN ni1lii = '1'  ELSE wire_nil1il_dataout;
	wire_nili0O_dataout <= wire_niliOO_dataout WHEN ni1lii = '1'  ELSE wire_nil1iO_dataout;
	wire_nili1i_dataout <= wire_nilili_dataout WHEN ni1lii = '1'  ELSE wire_nil10i_dataout;
	wire_nili1l_dataout <= wire_nilill_dataout WHEN ni1lii = '1'  ELSE wire_nil10l_dataout;
	wire_nili1O_dataout <= wire_nililO_dataout WHEN ni1lii = '1'  ELSE wire_nil10O_dataout;
	wire_nilii_dataout <= wire_niO1i_dataout AND NOT(ni1l0O);
	wire_niliii_dataout <= wire_nill1i_dataout WHEN ni1lii = '1'  ELSE wire_nil1li_dataout;
	wire_niliil_dataout <= wire_nil1ll_dataout AND NOT(n0Ol0l);
	wire_niliiO_dataout <= wire_nil1lO_dataout OR n0Ol0l;
	wire_nilil_dataout <= wire_niO1l_dataout AND NOT(ni1l0O);
	wire_nilili_dataout <= wire_nil1Oi_dataout OR n0Ol0l;
	wire_nilill_dataout <= wire_nil1Ol_dataout OR n0Ol0l;
	wire_nililO_dataout <= wire_nil1OO_dataout OR n0Ol0l;
	wire_niliO_dataout <= wire_niO1O_dataout AND NOT(ni1l0O);
	wire_niliOi_dataout <= wire_nil01i_dataout OR n0Ol0l;
	wire_niliOl_dataout <= wire_nil01l_dataout OR n0Ol0l;
	wire_niliOO_dataout <= wire_nil01O_dataout OR n0Ol0l;
	wire_nill_dataout <= nl1lOi WHEN rxaui_s2gx_en = '1'  ELSE niO0li;
	wire_nill1i_dataout <= wire_nil00i_dataout OR n0Ol0l;
	wire_nilli_dataout <= wire_nl1iO_dataout WHEN n0OOii = '1'  ELSE wire_niO0i_dataout;
	wire_nilll_dataout <= wire_nl1li_dataout WHEN n0OOii = '1'  ELSE wire_niO0l_dataout;
	wire_nilllO_dataout <= wire_nilO0O_dataout OR wire_nllOO_o;
	wire_nillO_dataout <= wire_nl1ll_dataout WHEN n0OOii = '1'  ELSE wire_niO0O_dataout;
	wire_nillOi_dataout <= wire_nilOii_dataout AND NOT(wire_nllOO_o);
	wire_nillOl_dataout <= wire_nilOil_dataout AND NOT(wire_nllOO_o);
	wire_nillOO_dataout <= wire_nilOiO_dataout OR wire_nllOO_o;
	wire_nilO_dataout <= nll10i WHEN rxaui_s2gx_en = '1'  ELSE nl0l1i;
	wire_nilO0i_dataout <= wire_nilOOi_dataout AND NOT(wire_nllOO_o);
	wire_nilO0l_dataout <= wire_nilOOl_dataout OR wire_nllOO_o;
	wire_nilO0O_dataout <= wire_nilOOO_dataout OR wire_nllOl_o;
	wire_nilO1i_dataout <= wire_nilOli_dataout OR wire_nllOO_o;
	wire_nilO1l_dataout <= wire_nilOll_dataout OR wire_nllOO_o;
	wire_nilO1O_dataout <= wire_nilOlO_dataout AND NOT(wire_nllOO_o);
	wire_nilOi_dataout <= wire_nl1lO_dataout WHEN n0OOii = '1'  ELSE wire_niOii_dataout;
	wire_nilOii_dataout <= wire_niO11i_dataout OR wire_nllOl_o;
	wire_nilOil_dataout <= wire_niO11l_dataout OR wire_nllOl_o;
	wire_nilOiO_dataout <= wire_niO11O_dataout OR wire_nllOl_o;
	wire_nilOl_dataout <= wire_nl1Oi_dataout WHEN n0OOii = '1'  ELSE wire_niOil_dataout;
	wire_nilOli_dataout <= wire_niO10i_dataout AND NOT(wire_nllOl_o);
	wire_nilOll_dataout <= wire_niO10l_dataout AND NOT(wire_nllOl_o);
	wire_nilOlO_dataout <= wire_niO10O_dataout AND NOT(wire_nllOl_o);
	wire_nilOO_dataout <= wire_nl1Ol_dataout WHEN n0OOii = '1'  ELSE wire_niOiO_dataout;
	wire_nilOOi_dataout <= wire_niO1ii_dataout AND NOT(wire_nllOl_o);
	wire_nilOOl_dataout <= wire_niO1il_dataout AND NOT(wire_nllOl_o);
	wire_nilOOO_dataout <= dec_ctl(0) WHEN ni1l1l = '1'  ELSE wire_niO01l_dataout;
	wire_niO_dataout <= n10il WHEN rxaui_s2gx_en = '1'  ELSE nlllOO;
	wire_niO01i_dataout <= dec_data(7) OR wire_ni1O_dataout;
	wire_niO01l_dataout <= dec_ctl(0) OR wire_ni1O_dataout;
	wire_niO0i_dataout <= wire_niOOi_dataout WHEN nii00O = '1'  ELSE wire_nlOO_dataout;
	wire_niO0l_dataout <= wire_niOOl_dataout WHEN nii00O = '1'  ELSE wire_n1i_dataout;
	wire_niO0lO_dataout <= wire_nl11OO_dataout WHEN n0Ol1i = '1'  ELSE wire_niOi0O_dataout;
	wire_niO0O_dataout <= wire_niOOO_dataout WHEN nii00O = '1'  ELSE wire_n1l_dataout;
	wire_niO0Oi_dataout <= wire_nl101i_dataout WHEN n0Ol1i = '1'  ELSE wire_niOiii_dataout;
	wire_niO0Ol_dataout <= wire_nl101l_dataout WHEN n0Ol1i = '1'  ELSE wire_niOiil_dataout;
	wire_niO0OO_dataout <= wire_nl101O_dataout WHEN n0Ol1i = '1'  ELSE wire_niOiiO_dataout;
	wire_niO10i_dataout <= dec_data(3) WHEN ni1l1l = '1'  ELSE wire_niO1lO_dataout;
	wire_niO10l_dataout <= dec_data(4) WHEN ni1l1l = '1'  ELSE wire_niO1Oi_dataout;
	wire_niO10O_dataout <= dec_data(5) WHEN ni1l1l = '1'  ELSE wire_niO1Ol_dataout;
	wire_niO11i_dataout <= dec_data(0) WHEN ni1l1l = '1'  ELSE wire_niO1iO_dataout;
	wire_niO11l_dataout <= dec_data(1) WHEN ni1l1l = '1'  ELSE wire_niO1li_dataout;
	wire_niO11O_dataout <= dec_data(2) WHEN ni1l1l = '1'  ELSE wire_niO1ll_dataout;
	wire_niO1i_dataout <= wire_nl1OO_dataout WHEN n0OOii = '1'  ELSE wire_niOli_dataout;
	wire_niO1ii_dataout <= dec_data(6) WHEN ni1l1l = '1'  ELSE wire_niO1OO_dataout;
	wire_niO1il_dataout <= dec_data(7) WHEN ni1l1l = '1'  ELSE wire_niO01i_dataout;
	wire_niO1iO_dataout <= dec_data(0) AND NOT(wire_ni1O_dataout);
	wire_niO1l_dataout <= wire_nl01i_dataout WHEN n0OOii = '1'  ELSE wire_niOll_dataout;
	wire_niO1li_dataout <= dec_data(1) OR wire_ni1O_dataout;
	wire_niO1ll_dataout <= dec_data(2) OR wire_ni1O_dataout;
	wire_niO1lO_dataout <= dec_data(3) OR wire_ni1O_dataout;
	wire_niO1O_dataout <= wire_nl01l_dataout WHEN n0OOii = '1'  ELSE wire_niOlO_dataout;
	wire_niO1Oi_dataout <= dec_data(4) OR wire_ni1O_dataout;
	wire_niO1Ol_dataout <= dec_data(5) OR wire_ni1O_dataout;
	wire_niO1OO_dataout <= dec_data(6) OR wire_ni1O_dataout;
	wire_niOi_dataout <= n10OO WHEN rxaui_s2gx_en = '1'  ELSE nllOii;
	wire_niOi0i_dataout <= wire_nl10ii_dataout WHEN n0Ol1i = '1'  ELSE wire_niOiOi_dataout;
	wire_niOi0l_dataout <= wire_nl10il_dataout WHEN n0Ol1i = '1'  ELSE wire_niOiOl_dataout;
	wire_niOi0O_dataout <= wire_niOO1O_dataout WHEN n0OilO = '1'  ELSE wire_niOiOO_dataout;
	wire_niOi1i_dataout <= wire_nl100i_dataout WHEN n0Ol1i = '1'  ELSE wire_niOili_dataout;
	wire_niOi1l_dataout <= wire_nl100l_dataout WHEN n0Ol1i = '1'  ELSE wire_niOill_dataout;
	wire_niOi1O_dataout <= wire_nl100O_dataout WHEN n0Ol1i = '1'  ELSE wire_niOilO_dataout;
	wire_niOii_dataout <= wire_nl11i_dataout WHEN nii00O = '1'  ELSE wire_n1O_dataout;
	wire_niOiii_dataout <= wire_niOO0i_dataout WHEN n0OilO = '1'  ELSE wire_niOl1i_dataout;
	wire_niOiil_dataout <= wire_niOO0l_dataout WHEN n0OilO = '1'  ELSE wire_niOl1l_dataout;
	wire_niOiiO_dataout <= wire_niOO0O_dataout WHEN n0OilO = '1'  ELSE wire_niOl1O_dataout;
	wire_niOil_dataout <= wire_nl11l_dataout WHEN nii00O = '1'  ELSE wire_n0i_dataout;
	wire_niOili_dataout <= wire_niOOii_dataout WHEN n0OilO = '1'  ELSE wire_niOl0i_dataout;
	wire_niOill_dataout <= wire_niOOil_dataout WHEN n0OilO = '1'  ELSE wire_niOl0l_dataout;
	wire_niOilO_dataout <= wire_niOOiO_dataout WHEN n0OilO = '1'  ELSE wire_niOl0O_dataout;
	wire_niOiO_dataout <= wire_nl11O_dataout WHEN nii00O = '1'  ELSE wire_n0l_dataout;
	wire_niOiOi_dataout <= wire_niOOli_dataout WHEN n0OilO = '1'  ELSE wire_niOlii_dataout;
	wire_niOiOl_dataout <= wire_niOOll_dataout WHEN n0OilO = '1'  ELSE wire_niOlil_dataout;
	wire_niOiOO_dataout <= wire_niOliO_dataout AND ni111O;
	wire_niOl_dataout <= nill1O WHEN rxaui_s2gx_en = '1'  ELSE nii0ii;
	wire_niOl0i_dataout <= wire_niOlOi_dataout AND ni111O;
	wire_niOl0l_dataout <= wire_niOlOl_dataout AND ni111O;
	wire_niOl0O_dataout <= wire_niOlOO_dataout AND ni111O;
	wire_niOl1i_dataout <= wire_niOlli_dataout AND ni111O;
	wire_niOl1l_dataout <= wire_niOlll_dataout AND ni111O;
	wire_niOl1O_dataout <= wire_niOllO_dataout AND ni111O;
	wire_niOli_dataout <= wire_nl10i_dataout WHEN nii00O = '1'  ELSE wire_n0O_dataout;
	wire_niOlii_dataout <= wire_niOO1i_dataout AND ni111O;
	wire_niOlil_dataout <= wire_niOO1l_dataout AND ni111O;
	wire_niOliO_dataout <= dec_data(8) OR ni110i;
	wire_niOll_dataout <= wire_nl10l_dataout WHEN nii00O = '1'  ELSE wire_nii_dataout;
	wire_niOlli_dataout <= dec_data(9) OR ni110i;
	wire_niOlll_dataout <= dec_data(10) OR ni110i;
	wire_niOllO_dataout <= dec_data(11) AND NOT(ni110i);
	wire_niOlO_dataout <= wire_nl10O_dataout WHEN nii00O = '1'  ELSE wire_nilO_dataout;
	wire_niOlOi_dataout <= dec_data(12) AND NOT(ni110i);
	wire_niOlOl_dataout <= dec_data(13) AND NOT(ni110i);
	wire_niOlOO_dataout <= dec_data(14) AND NOT(ni110i);
	wire_niOO_dataout <= nill0i WHEN rxaui_s2gx_en = '1'  ELSE nii0il;
	wire_niOO0i_dataout <= wire_niOOOi_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_niOO0l_dataout <= wire_niOOOl_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_niOO0O_dataout <= wire_niOOOO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_niOO1i_dataout <= dec_data(15) AND NOT(ni110i);
	wire_niOO1l_dataout <= dec_ctl(1) OR ni110i;
	wire_niOO1O_dataout <= wire_niOOlO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_niOOi_dataout <= wire_nlOO_dataout AND NOT(n0OllO);
	wire_niOOii_dataout <= wire_nl111i_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_niOOil_dataout <= wire_nl111l_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_niOOiO_dataout <= wire_nl111O_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_niOOl_dataout <= wire_n1i_dataout OR n0OllO;
	wire_niOOli_dataout <= wire_nl110i_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_niOOll_dataout <= wire_nl110l_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_niOOlO_dataout <= wire_nl110O_dataout AND NOT(wire_ni0i_dataout);
	wire_niOOO_dataout <= wire_n1l_dataout OR n0OllO;
	wire_niOOOi_dataout <= wire_nl11ii_dataout OR wire_ni0i_dataout;
	wire_niOOOl_dataout <= wire_nl11il_dataout OR wire_ni0i_dataout;
	wire_niOOOO_dataout <= wire_nl11iO_dataout OR wire_ni0i_dataout;
	wire_nl_dataout <= n10Oi WHEN rxaui_s2gx_en = '1'  ELSE nllO0l;
	wire_nl000i_dataout <= dec_data(15) OR wire_ni0i_dataout;
	wire_nl000l_dataout <= dec_ctl(1) OR wire_ni0i_dataout;
	wire_nl000O_dataout <= wire_nl00OO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl001i_dataout <= dec_data(12) OR wire_ni0i_dataout;
	wire_nl001l_dataout <= dec_data(13) OR wire_ni0i_dataout;
	wire_nl001O_dataout <= dec_data(14) OR wire_ni0i_dataout;
	wire_nl00ii_dataout <= wire_nl0i1i_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl00il_dataout <= wire_nl0i1l_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl00iO_dataout <= wire_nl0i1O_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl00li_dataout <= wire_nl0i0i_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl00ll_dataout <= wire_nl0i0l_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl00lO_dataout <= wire_nl0i0O_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl00Oi_dataout <= wire_nl0iii_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl00Ol_dataout <= wire_nl0iil_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl00OO_dataout <= wire_nl01lO_dataout OR n0Ol0i;
	wire_nl010i_dataout <= wire_nl01Oi_dataout OR ni110i;
	wire_nl010l_dataout <= wire_nl01Ol_dataout OR ni110i;
	wire_nl010O_dataout <= wire_nl01OO_dataout AND NOT(ni110i);
	wire_nl011i_dataout <= wire_nl01li_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl011l_dataout <= wire_nl01ll_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl011O_dataout <= wire_nl01lO_dataout OR ni110i;
	wire_nl01i_dataout <= wire_nii_dataout OR n0OlOi;
	wire_nl01ii_dataout <= wire_nl001i_dataout AND NOT(ni110i);
	wire_nl01il_dataout <= wire_nl001l_dataout AND NOT(ni110i);
	wire_nl01iO_dataout <= wire_nl001O_dataout AND NOT(ni110i);
	wire_nl01l_dataout <= wire_nilO_dataout OR n0OlOi;
	wire_nl01li_dataout <= wire_nl000i_dataout AND NOT(ni110i);
	wire_nl01ll_dataout <= wire_nl000l_dataout OR ni110i;
	wire_nl01lO_dataout <= dec_data(8) AND NOT(wire_ni0i_dataout);
	wire_nl01Oi_dataout <= dec_data(9) OR wire_ni0i_dataout;
	wire_nl01Ol_dataout <= dec_data(10) OR wire_ni0i_dataout;
	wire_nl01OO_dataout <= dec_data(11) OR wire_ni0i_dataout;
	wire_nl0i_dataout <= nillil WHEN rxaui_s2gx_en = '1'  ELSE nii0lO;
	wire_nl0i0i_dataout <= wire_nl001i_dataout AND NOT(n0Ol0i);
	wire_nl0i0l_dataout <= wire_nl001l_dataout AND NOT(n0Ol0i);
	wire_nl0i0O_dataout <= wire_nl001O_dataout AND NOT(n0Ol0i);
	wire_nl0i1i_dataout <= wire_nl01Oi_dataout OR n0Ol0i;
	wire_nl0i1l_dataout <= wire_nl01Ol_dataout OR n0Ol0i;
	wire_nl0i1O_dataout <= wire_nl01OO_dataout AND NOT(n0Ol0i);
	wire_nl0iii_dataout <= wire_nl000i_dataout AND NOT(n0Ol0i);
	wire_nl0iil_dataout <= wire_nl000l_dataout OR n0Ol0i;
	wire_nl0l_dataout <= nilliO WHEN rxaui_s2gx_en = '1'  ELSE nii0Oi;
	wire_nl0l0i_dataout <= wire_nliiii_dataout WHEN n0Ol1i = '1'  ELSE wire_nl0lOi_dataout;
	wire_nl0l0l_dataout <= wire_nliiil_dataout WHEN n0Ol1i = '1'  ELSE wire_nl0lOl_dataout;
	wire_nl0l0O_dataout <= wire_nliiiO_dataout WHEN n0Ol1i = '1'  ELSE wire_nl0lOO_dataout;
	wire_nl0l1O_dataout <= wire_nlii0O_dataout WHEN n0Ol1i = '1'  ELSE wire_nl0llO_dataout;
	wire_nl0lii_dataout <= wire_nliili_dataout WHEN n0Ol1i = '1'  ELSE wire_nl0O1i_dataout;
	wire_nl0lil_dataout <= wire_nliill_dataout WHEN n0Ol1i = '1'  ELSE wire_nl0O1l_dataout;
	wire_nl0liO_dataout <= wire_nliilO_dataout WHEN n0Ol1i = '1'  ELSE wire_nl0O1O_dataout;
	wire_nl0lli_dataout <= wire_nliiOi_dataout WHEN n0Ol1i = '1'  ELSE wire_nl0O0i_dataout;
	wire_nl0lll_dataout <= wire_nliiOl_dataout WHEN n0Ol1i = '1'  ELSE wire_nl0O0l_dataout;
	wire_nl0llO_dataout <= wire_nli1iO_dataout WHEN n0OilO = '1'  ELSE wire_nl0O0O_dataout;
	wire_nl0lOi_dataout <= wire_nli1li_dataout WHEN n0OilO = '1'  ELSE wire_nl0Oii_dataout;
	wire_nl0lOl_dataout <= wire_nli1ll_dataout WHEN n0OilO = '1'  ELSE wire_nl0Oil_dataout;
	wire_nl0lOO_dataout <= wire_nli1lO_dataout WHEN n0OilO = '1'  ELSE wire_nl0OiO_dataout;
	wire_nl0O_dataout <= nillli WHEN rxaui_s2gx_en = '1'  ELSE nii0Ol;
	wire_nl0O0i_dataout <= wire_nli01i_dataout WHEN n0OilO = '1'  ELSE wire_nl0OOi_dataout;
	wire_nl0O0l_dataout <= wire_nli01l_dataout WHEN n0OilO = '1'  ELSE wire_nl0OOl_dataout;
	wire_nl0O0O_dataout <= wire_nl0OOO_dataout AND ni111O;
	wire_nl0O1i_dataout <= wire_nli1Oi_dataout WHEN n0OilO = '1'  ELSE wire_nl0Oli_dataout;
	wire_nl0O1l_dataout <= wire_nli1Ol_dataout WHEN n0OilO = '1'  ELSE wire_nl0Oll_dataout;
	wire_nl0O1O_dataout <= wire_nli1OO_dataout WHEN n0OilO = '1'  ELSE wire_nl0OlO_dataout;
	wire_nl0Oi_dataout <= wire_nliii_dataout OR ni1l0O;
	wire_nl0Oii_dataout <= wire_nli11i_dataout AND ni111O;
	wire_nl0Oil_dataout <= wire_nli11l_dataout AND ni111O;
	wire_nl0OiO_dataout <= wire_nli11O_dataout AND ni111O;
	wire_nl0Ol_dataout <= wire_nliil_dataout AND NOT(ni1l0O);
	wire_nl0Oli_dataout <= wire_nli10i_dataout AND ni111O;
	wire_nl0Oll_dataout <= wire_nli10l_dataout AND ni111O;
	wire_nl0OlO_dataout <= wire_nli10O_dataout AND ni111O;
	wire_nl0OO_dataout <= wire_nliiO_dataout AND NOT(ni1l0O);
	wire_nl0OOi_dataout <= wire_nli1ii_dataout AND ni111O;
	wire_nl0OOl_dataout <= wire_nli1il_dataout AND ni111O;
	wire_nl0OOO_dataout <= dec_data(16) OR ni110i;
	wire_nl100i_dataout <= wire_nl10Oi_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl100l_dataout <= wire_nl10Ol_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl100O_dataout <= wire_nl10OO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl101i_dataout <= wire_nl10li_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl101l_dataout <= wire_nl10ll_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl101O_dataout <= wire_nl10lO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl10i_dataout <= wire_n0O_dataout OR n0OllO;
	wire_nl10ii_dataout <= wire_nl1i1i_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl10il_dataout <= wire_nl1i1l_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl10iO_dataout <= wire_nl1ilO_dataout WHEN ni1lii = '1'  ELSE wire_nl1i1O_dataout;
	wire_nl10l_dataout <= wire_nii_dataout OR n0OllO;
	wire_nl10li_dataout <= wire_nl1iOi_dataout WHEN ni1lii = '1'  ELSE wire_nl1i0i_dataout;
	wire_nl10ll_dataout <= wire_nl1iOl_dataout WHEN ni1lii = '1'  ELSE wire_nl1i0l_dataout;
	wire_nl10lO_dataout <= wire_nl1iOO_dataout WHEN ni1lii = '1'  ELSE wire_nl1i0O_dataout;
	wire_nl10O_dataout <= wire_nilO_dataout OR n0OllO;
	wire_nl10Oi_dataout <= wire_nl1l1i_dataout WHEN ni1lii = '1'  ELSE wire_nl1iii_dataout;
	wire_nl10Ol_dataout <= wire_nl1l1l_dataout WHEN ni1lii = '1'  ELSE wire_nl1iil_dataout;
	wire_nl10OO_dataout <= wire_nl1l1O_dataout WHEN ni1lii = '1'  ELSE wire_nl1iiO_dataout;
	wire_nl110i_dataout <= wire_nl11Oi_dataout OR wire_ni0i_dataout;
	wire_nl110l_dataout <= wire_nl11Ol_dataout OR wire_ni0i_dataout;
	wire_nl110O_dataout <= dec_data(8) OR n0OiOi;
	wire_nl111i_dataout <= wire_nl11li_dataout OR wire_ni0i_dataout;
	wire_nl111l_dataout <= wire_nl11ll_dataout OR wire_ni0i_dataout;
	wire_nl111O_dataout <= wire_nl11lO_dataout OR wire_ni0i_dataout;
	wire_nl11i_dataout <= wire_n1O_dataout OR n0OllO;
	wire_nl11ii_dataout <= dec_data(9) OR n0OiOi;
	wire_nl11il_dataout <= dec_data(10) OR n0OiOi;
	wire_nl11iO_dataout <= dec_data(11) AND NOT(n0OiOi);
	wire_nl11l_dataout <= wire_n0i_dataout OR n0OllO;
	wire_nl11li_dataout <= dec_data(12) AND NOT(n0OiOi);
	wire_nl11ll_dataout <= dec_data(13) AND NOT(n0OiOi);
	wire_nl11lO_dataout <= dec_data(14) AND NOT(n0OiOi);
	wire_nl11O_dataout <= wire_n0l_dataout OR n0OllO;
	wire_nl11Oi_dataout <= dec_data(15) AND NOT(n0OiOi);
	wire_nl11Ol_dataout <= dec_ctl(1) OR n0OiOi;
	wire_nl11OO_dataout <= wire_nl10iO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl1i_dataout <= nill0l WHEN rxaui_s2gx_en = '1'  ELSE nii0iO;
	wire_nl1i0i_dataout <= wire_niOOOi_dataout OR ni1l1l;
	wire_nl1i0l_dataout <= wire_niOOOl_dataout OR ni1l1l;
	wire_nl1i0O_dataout <= n0OliO WHEN ni1l1l = '1'  ELSE wire_niOOOO_dataout;
	wire_nl1i1i_dataout <= wire_nl1l0i_dataout WHEN ni1lii = '1'  ELSE wire_nl1ili_dataout;
	wire_nl1i1l_dataout <= wire_nl1l0l_dataout WHEN ni1lii = '1'  ELSE wire_nl1ill_dataout;
	wire_nl1i1O_dataout <= wire_w_lg_n0OliO228w(0) WHEN ni1l1l = '1'  ELSE wire_niOOlO_dataout;
	wire_nl1iii_dataout <= n0OliO WHEN ni1l1l = '1'  ELSE wire_nl111i_dataout;
	wire_nl1iil_dataout <= n0OliO WHEN ni1l1l = '1'  ELSE wire_nl111l_dataout;
	wire_nl1iiO_dataout <= n0OliO WHEN ni1l1l = '1'  ELSE wire_nl111O_dataout;
	wire_nl1ili_dataout <= n0OliO WHEN ni1l1l = '1'  ELSE wire_nl110i_dataout;
	wire_nl1ill_dataout <= wire_nl110l_dataout OR ni1l1l;
	wire_nl1ilO_dataout <= wire_nl110O_dataout AND NOT(n0Olii);
	wire_nl1iO_dataout <= wire_nlOO_dataout AND NOT(n0OlOi);
	wire_nl1iOi_dataout <= wire_nl11ii_dataout OR n0Olii;
	wire_nl1iOl_dataout <= wire_nl11il_dataout OR n0Olii;
	wire_nl1iOO_dataout <= wire_nl11iO_dataout OR n0Olii;
	wire_nl1l_dataout <= nill0O WHEN rxaui_s2gx_en = '1'  ELSE nii0li;
	wire_nl1l0i_dataout <= wire_nl11Oi_dataout OR n0Olii;
	wire_nl1l0l_dataout <= wire_nl11Ol_dataout OR n0Olii;
	wire_nl1l1i_dataout <= wire_nl11li_dataout OR n0Olii;
	wire_nl1l1l_dataout <= wire_nl11ll_dataout OR n0Olii;
	wire_nl1l1O_dataout <= wire_nl11lO_dataout OR n0Olii;
	wire_nl1li_dataout <= wire_n1i_dataout OR n0OlOi;
	wire_nl1ll_dataout <= wire_n1l_dataout OR n0OlOi;
	wire_nl1lO_dataout <= wire_n1O_dataout OR n0OlOi;
	wire_nl1lOO_dataout <= wire_nl000O_dataout WHEN n0Ol1i = '1'  ELSE wire_nl1OiO_dataout;
	wire_nl1O_dataout <= nillii WHEN rxaui_s2gx_en = '1'  ELSE nii0ll;
	wire_nl1O0i_dataout <= wire_nl00li_dataout WHEN n0Ol1i = '1'  ELSE wire_nl1OOi_dataout;
	wire_nl1O0l_dataout <= wire_nl00ll_dataout WHEN n0Ol1i = '1'  ELSE wire_nl1OOl_dataout;
	wire_nl1O0O_dataout <= wire_nl00lO_dataout WHEN n0Ol1i = '1'  ELSE wire_nl1OOO_dataout;
	wire_nl1O1i_dataout <= wire_nl00ii_dataout WHEN n0Ol1i = '1'  ELSE wire_nl1Oli_dataout;
	wire_nl1O1l_dataout <= wire_nl00il_dataout WHEN n0Ol1i = '1'  ELSE wire_nl1Oll_dataout;
	wire_nl1O1O_dataout <= wire_nl00iO_dataout WHEN n0Ol1i = '1'  ELSE wire_nl1OlO_dataout;
	wire_nl1Oi_dataout <= wire_n0i_dataout OR n0OlOi;
	wire_nl1Oii_dataout <= wire_nl00Oi_dataout WHEN n0Ol1i = '1'  ELSE wire_nl011i_dataout;
	wire_nl1Oil_dataout <= wire_nl00Ol_dataout WHEN n0Ol1i = '1'  ELSE wire_nl011l_dataout;
	wire_nl1OiO_dataout <= wire_nl011O_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl1Ol_dataout <= wire_n0l_dataout OR n0OlOi;
	wire_nl1Oli_dataout <= wire_nl010i_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl1Oll_dataout <= wire_nl010l_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl1OlO_dataout <= wire_nl010O_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl1OO_dataout <= wire_n0O_dataout OR n0OlOi;
	wire_nl1OOi_dataout <= wire_nl01ii_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl1OOl_dataout <= wire_nl01il_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nl1OOO_dataout <= wire_nl01iO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nli_dataout <= n10iO WHEN rxaui_s2gx_en = '1'  ELSE nllO1i;
	wire_nli00i_dataout <= wire_nli0Oi_dataout OR wire_ni0l_dataout;
	wire_nli00l_dataout <= wire_nli0Ol_dataout OR wire_ni0l_dataout;
	wire_nli00O_dataout <= wire_nli0OO_dataout OR wire_ni0l_dataout;
	wire_nli01i_dataout <= wire_nli0li_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nli01l_dataout <= wire_nli0ll_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nli01O_dataout <= wire_nli0lO_dataout AND NOT(wire_ni0l_dataout);
	wire_nli0i_dataout <= wire_nliOi_dataout AND NOT(ni1l0O);
	wire_nli0ii_dataout <= wire_nlii1i_dataout OR wire_ni0l_dataout;
	wire_nli0il_dataout <= wire_nlii1l_dataout OR wire_ni0l_dataout;
	wire_nli0iO_dataout <= wire_nlii1O_dataout OR wire_ni0l_dataout;
	wire_nli0l_dataout <= wire_nliOl_dataout AND NOT(ni1l0O);
	wire_nli0li_dataout <= wire_nlii0i_dataout OR wire_ni0l_dataout;
	wire_nli0ll_dataout <= wire_nlii0l_dataout OR wire_ni0l_dataout;
	wire_nli0lO_dataout <= dec_data(16) OR n0OiOi;
	wire_nli0O_dataout <= wire_nliOO_dataout AND NOT(ni1l0O);
	wire_nli0Oi_dataout <= dec_data(17) OR n0OiOi;
	wire_nli0Ol_dataout <= dec_data(18) OR n0OiOi;
	wire_nli0OO_dataout <= dec_data(19) AND NOT(n0OiOi);
	wire_nli10i_dataout <= dec_data(20) AND NOT(ni110i);
	wire_nli10l_dataout <= dec_data(21) AND NOT(ni110i);
	wire_nli10O_dataout <= dec_data(22) AND NOT(ni110i);
	wire_nli11i_dataout <= dec_data(17) OR ni110i;
	wire_nli11l_dataout <= dec_data(18) OR ni110i;
	wire_nli11O_dataout <= dec_data(19) AND NOT(ni110i);
	wire_nli1i_dataout <= wire_nlili_dataout AND NOT(ni1l0O);
	wire_nli1ii_dataout <= dec_data(23) AND NOT(ni110i);
	wire_nli1il_dataout <= dec_ctl(2) OR ni110i;
	wire_nli1iO_dataout <= wire_nli01O_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nli1l_dataout <= wire_nlill_dataout AND NOT(ni1l0O);
	wire_nli1li_dataout <= wire_nli00i_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nli1ll_dataout <= wire_nli00l_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nli1lO_dataout <= wire_nli00O_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nli1O_dataout <= wire_nlilO_dataout AND NOT(ni1l0O);
	wire_nli1Oi_dataout <= wire_nli0ii_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nli1Ol_dataout <= wire_nli0il_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nli1OO_dataout <= wire_nli0iO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlii_dataout <= niO0ll WHEN rxaui_s2gx_en = '1'  ELSE nillll;
	wire_nlii0i_dataout <= dec_data(23) AND NOT(n0OiOi);
	wire_nlii0l_dataout <= dec_ctl(2) OR n0OiOi;
	wire_nlii0O_dataout <= wire_nliiOO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlii1i_dataout <= dec_data(20) AND NOT(n0OiOi);
	wire_nlii1l_dataout <= dec_data(21) AND NOT(n0OiOi);
	wire_nlii1O_dataout <= dec_data(22) AND NOT(n0OiOi);
	wire_nliii_dataout <= wire_nll1i_dataout WHEN n0OO0i = '1'  ELSE wire_nil_dataout;
	wire_nliiii_dataout <= wire_nlil1i_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nliiil_dataout <= wire_nlil1l_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nliiiO_dataout <= wire_nlil1O_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nliil_dataout <= wire_nll1l_dataout WHEN n0OO0i = '1'  ELSE wire_niO_dataout;
	wire_nliili_dataout <= wire_nlil0i_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nliill_dataout <= wire_nlil0l_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nliilO_dataout <= wire_nlil0O_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nliiO_dataout <= wire_nll1O_dataout WHEN n0OO0i = '1'  ELSE wire_nli_dataout;
	wire_nliiOi_dataout <= wire_nlilii_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nliiOl_dataout <= wire_nlilil_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nliiOO_dataout <= wire_nliO1O_dataout WHEN ni1lii = '1'  ELSE wire_nliliO_dataout;
	wire_nlil_dataout <= nl1l0O WHEN rxaui_s2gx_en = '1'  ELSE niO01O;
	wire_nlil0i_dataout <= wire_nliOii_dataout WHEN ni1lii = '1'  ELSE wire_nlilOi_dataout;
	wire_nlil0l_dataout <= wire_nliOil_dataout WHEN ni1lii = '1'  ELSE wire_nlilOl_dataout;
	wire_nlil0O_dataout <= wire_nliOiO_dataout WHEN ni1lii = '1'  ELSE wire_nlilOO_dataout;
	wire_nlil1i_dataout <= wire_nliO0i_dataout WHEN ni1lii = '1'  ELSE wire_nlilli_dataout;
	wire_nlil1l_dataout <= wire_nliO0l_dataout WHEN ni1lii = '1'  ELSE wire_nlilll_dataout;
	wire_nlil1O_dataout <= wire_nliO0O_dataout WHEN ni1lii = '1'  ELSE wire_nlillO_dataout;
	wire_nlili_dataout <= wire_nll0i_dataout WHEN n0OO0i = '1'  ELSE wire_nll_dataout;
	wire_nlilii_dataout <= wire_nliOli_dataout WHEN ni1lii = '1'  ELSE wire_nliO1i_dataout;
	wire_nlilil_dataout <= wire_nliOll_dataout WHEN ni1lii = '1'  ELSE wire_nliO1l_dataout;
	wire_nliliO_dataout <= wire_w_lg_n0OlOi219w(0) WHEN n0OOii = '1'  ELSE wire_nli01O_dataout;
	wire_nlill_dataout <= wire_nll0l_dataout WHEN n0OO0i = '1'  ELSE wire_nlO_dataout;
	wire_nlilli_dataout <= wire_nli00i_dataout OR n0OOii;
	wire_nlilll_dataout <= wire_nli00l_dataout OR n0OOii;
	wire_nlillO_dataout <= n0OlOi WHEN n0OOii = '1'  ELSE wire_nli00O_dataout;
	wire_nlilO_dataout <= wire_nll0O_dataout WHEN n0OO0i = '1'  ELSE wire_ni_dataout;
	wire_nlilOi_dataout <= n0OlOi WHEN n0OOii = '1'  ELSE wire_nli0ii_dataout;
	wire_nlilOl_dataout <= n0OlOi WHEN n0OOii = '1'  ELSE wire_nli0il_dataout;
	wire_nlilOO_dataout <= n0OlOi WHEN n0OOii = '1'  ELSE wire_nli0iO_dataout;
	wire_nliO_dataout <= nl1lii WHEN rxaui_s2gx_en = '1'  ELSE niO00i;
	wire_nliO0i_dataout <= wire_nli0Oi_dataout OR n0OllO;
	wire_nliO0l_dataout <= wire_nli0Ol_dataout OR n0OllO;
	wire_nliO0O_dataout <= wire_nli0OO_dataout OR n0OllO;
	wire_nliO1i_dataout <= n0OlOi WHEN n0OOii = '1'  ELSE wire_nli0li_dataout;
	wire_nliO1l_dataout <= wire_nli0ll_dataout OR n0OOii;
	wire_nliO1O_dataout <= wire_nli0lO_dataout AND NOT(n0OllO);
	wire_nliOi_dataout <= wire_nllii_dataout WHEN n0OO0i = '1'  ELSE wire_nl_dataout;
	wire_nliOii_dataout <= wire_nlii1i_dataout OR n0OllO;
	wire_nliOil_dataout <= wire_nlii1l_dataout OR n0OllO;
	wire_nliOiO_dataout <= wire_nlii1O_dataout OR n0OllO;
	wire_nliOl_dataout <= wire_nllil_dataout WHEN n0OO0i = '1'  ELSE wire_nO_dataout;
	wire_nliOli_dataout <= wire_nlii0i_dataout OR n0OllO;
	wire_nliOll_dataout <= wire_nlii0l_dataout OR n0OllO;
	wire_nliOO_dataout <= wire_nlliO_dataout WHEN n0OO0i = '1'  ELSE wire_niOi_dataout;
	wire_nll_dataout <= n10li WHEN rxaui_s2gx_en = '1'  ELSE nllO1l;
	wire_nll00i_dataout <= wire_nll0Oi_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nll00l_dataout <= wire_nll0Ol_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nll00O_dataout <= wire_nll0OO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nll01i_dataout <= wire_nll0li_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nll01l_dataout <= wire_nll0ll_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nll01O_dataout <= wire_nll0lO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nll0i_dataout <= wire_nll_dataout OR n0OO1i;
	wire_nll0ii_dataout <= wire_nlli1i_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nll0il_dataout <= wire_nlli1l_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nll0iO_dataout <= wire_nlli1O_dataout OR ni110i;
	wire_nll0l_dataout <= wire_nlO_dataout OR n0OO1i;
	wire_nll0li_dataout <= wire_nlli0i_dataout OR ni110i;
	wire_nll0ll_dataout <= wire_nlli0l_dataout OR ni110i;
	wire_nll0lO_dataout <= wire_nlli0O_dataout AND NOT(ni110i);
	wire_nll0O_dataout <= wire_ni_dataout OR n0OO1i;
	wire_nll0Oi_dataout <= wire_nlliii_dataout AND NOT(ni110i);
	wire_nll0Ol_dataout <= wire_nlliil_dataout AND NOT(ni110i);
	wire_nll0OO_dataout <= wire_nlliiO_dataout AND NOT(ni110i);
	wire_nll10O_dataout <= wire_nllilO_dataout WHEN n0Ol1i = '1'  ELSE wire_nll1OO_dataout;
	wire_nll1i_dataout <= wire_nil_dataout AND NOT(n0OO1i);
	wire_nll1ii_dataout <= wire_nlliOi_dataout WHEN n0Ol1i = '1'  ELSE wire_nll01i_dataout;
	wire_nll1il_dataout <= wire_nlliOl_dataout WHEN n0Ol1i = '1'  ELSE wire_nll01l_dataout;
	wire_nll1iO_dataout <= wire_nlliOO_dataout WHEN n0Ol1i = '1'  ELSE wire_nll01O_dataout;
	wire_nll1l_dataout <= wire_niO_dataout OR n0OO1i;
	wire_nll1li_dataout <= wire_nlll1i_dataout WHEN n0Ol1i = '1'  ELSE wire_nll00i_dataout;
	wire_nll1ll_dataout <= wire_nlll1l_dataout WHEN n0Ol1i = '1'  ELSE wire_nll00l_dataout;
	wire_nll1lO_dataout <= wire_nlll1O_dataout WHEN n0Ol1i = '1'  ELSE wire_nll00O_dataout;
	wire_nll1O_dataout <= wire_nli_dataout OR n0OO1i;
	wire_nll1Oi_dataout <= wire_nlll0i_dataout WHEN n0Ol1i = '1'  ELSE wire_nll0ii_dataout;
	wire_nll1Ol_dataout <= wire_nlll0l_dataout WHEN n0Ol1i = '1'  ELSE wire_nll0il_dataout;
	wire_nll1OO_dataout <= wire_nll0iO_dataout OR wire_w_lg_ni111O120w(0);
	wire_nlli_dataout <= nl1lil WHEN rxaui_s2gx_en = '1'  ELSE niO00l;
	wire_nlli0i_dataout <= dec_data(17) OR wire_ni0l_dataout;
	wire_nlli0l_dataout <= dec_data(18) OR wire_ni0l_dataout;
	wire_nlli0O_dataout <= dec_data(19) OR wire_ni0l_dataout;
	wire_nlli1i_dataout <= wire_nllili_dataout AND NOT(ni110i);
	wire_nlli1l_dataout <= wire_nllill_dataout OR ni110i;
	wire_nlli1O_dataout <= dec_data(16) AND NOT(wire_ni0l_dataout);
	wire_nllii_dataout <= wire_nl_dataout OR n0OO1i;
	wire_nlliii_dataout <= dec_data(20) OR wire_ni0l_dataout;
	wire_nlliil_dataout <= dec_data(21) OR wire_ni0l_dataout;
	wire_nlliiO_dataout <= dec_data(22) OR wire_ni0l_dataout;
	wire_nllil_dataout <= wire_nO_dataout OR n0OO1i;
	wire_nllili_dataout <= dec_data(23) OR wire_ni0l_dataout;
	wire_nllill_dataout <= dec_ctl(2) OR wire_ni0l_dataout;
	wire_nllilO_dataout <= wire_nlll0O_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlliO_dataout <= wire_niOi_dataout OR n0OO1i;
	wire_nlliOi_dataout <= wire_nlllii_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlliOl_dataout <= wire_nlllil_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlliOO_dataout <= wire_nllliO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlll_dataout <= nl1liO WHEN rxaui_s2gx_en = '1'  ELSE niO00O;
	wire_nlll0i_dataout <= wire_nlllOi_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlll0l_dataout <= wire_nlllOl_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlll0O_dataout <= wire_nlli1O_dataout OR n0Ol1O;
	wire_nlll1i_dataout <= wire_nlllli_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlll1l_dataout <= wire_nlllll_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlll1O_dataout <= wire_nllllO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlllii_dataout <= wire_nlli0i_dataout OR n0Ol1O;
	wire_nlllil_dataout <= wire_nlli0l_dataout OR n0Ol1O;
	wire_nllliO_dataout <= wire_nlli0O_dataout AND NOT(n0Ol1O);
	wire_nlllli_dataout <= wire_nlliii_dataout AND NOT(n0Ol1O);
	wire_nlllll_dataout <= wire_nlliil_dataout AND NOT(n0Ol1O);
	wire_nllllO_dataout <= wire_nlliiO_dataout AND NOT(n0Ol1O);
	wire_nlllOi_dataout <= wire_nllili_dataout AND NOT(n0Ol1O);
	wire_nlllOl_dataout <= wire_nllill_dataout OR n0Ol1O;
	wire_nllO_dataout <= nl1lli WHEN rxaui_s2gx_en = '1'  ELSE niO0ii;
	wire_nllOiO_dataout <= wire_nlOlOl_dataout WHEN n0Ol1i = '1'  ELSE wire_nlO11O_dataout;
	wire_nllOli_dataout <= wire_nlOlOO_dataout WHEN n0Ol1i = '1'  ELSE wire_nlO10i_dataout;
	wire_nllOll_dataout <= wire_nlOO1i_dataout WHEN n0Ol1i = '1'  ELSE wire_nlO10l_dataout;
	wire_nllOlO_dataout <= wire_nlOO1l_dataout WHEN n0Ol1i = '1'  ELSE wire_nlO10O_dataout;
	wire_nllOOi_dataout <= wire_nlOO1O_dataout WHEN n0Ol1i = '1'  ELSE wire_nlO1ii_dataout;
	wire_nllOOl_dataout <= wire_nlOO0i_dataout WHEN n0Ol1i = '1'  ELSE wire_nlO1il_dataout;
	wire_nllOOO_dataout <= wire_nlOO0l_dataout WHEN n0Ol1i = '1'  ELSE wire_nlO1iO_dataout;
	wire_nlO_dataout <= n10ll WHEN rxaui_s2gx_en = '1'  ELSE nllO1O;
	wire_nlO00i_dataout <= wire_nlO0Oi_dataout AND ni111O;
	wire_nlO00l_dataout <= wire_nlO0Ol_dataout AND ni111O;
	wire_nlO00O_dataout <= dec_data(24) OR ni110i;
	wire_nlO01i_dataout <= wire_nlO0li_dataout AND ni111O;
	wire_nlO01l_dataout <= wire_nlO0ll_dataout AND ni111O;
	wire_nlO01O_dataout <= wire_nlO0lO_dataout AND ni111O;
	wire_nlO0ii_dataout <= dec_data(25) OR ni110i;
	wire_nlO0il_dataout <= dec_data(26) OR ni110i;
	wire_nlO0iO_dataout <= dec_data(27) AND NOT(ni110i);
	wire_nlO0li_dataout <= dec_data(28) AND NOT(ni110i);
	wire_nlO0ll_dataout <= dec_data(29) AND NOT(ni110i);
	wire_nlO0lO_dataout <= dec_data(30) AND NOT(ni110i);
	wire_nlO0Oi_dataout <= dec_data(31) AND NOT(ni110i);
	wire_nlO0Ol_dataout <= dec_ctl(3) OR ni110i;
	wire_nlO0OO_dataout <= wire_nlOiiO_dataout OR wire_w_lg_ni111O120w(0);
	wire_nlO10i_dataout <= wire_nlOi1i_dataout WHEN n0OilO = '1'  ELSE wire_nlO1Oi_dataout;
	wire_nlO10l_dataout <= wire_nlOi1l_dataout WHEN n0OilO = '1'  ELSE wire_nlO1Ol_dataout;
	wire_nlO10O_dataout <= wire_nlOi1O_dataout WHEN n0OilO = '1'  ELSE wire_nlO1OO_dataout;
	wire_nlO11i_dataout <= wire_nlOO0O_dataout WHEN n0Ol1i = '1'  ELSE wire_nlO1li_dataout;
	wire_nlO11l_dataout <= wire_nlOOii_dataout WHEN n0Ol1i = '1'  ELSE wire_nlO1ll_dataout;
	wire_nlO11O_dataout <= wire_nlO0OO_dataout WHEN n0OilO = '1'  ELSE wire_nlO1lO_dataout;
	wire_nlO1i_dataout <= wire_w_lg_ni110i128w(0) AND NOT(n0OOll);
	wire_nlO1ii_dataout <= wire_nlOi0i_dataout WHEN n0OilO = '1'  ELSE wire_nlO01i_dataout;
	wire_nlO1il_dataout <= wire_nlOi0l_dataout WHEN n0OilO = '1'  ELSE wire_nlO01l_dataout;
	wire_nlO1iO_dataout <= wire_nlOi0O_dataout WHEN n0OilO = '1'  ELSE wire_nlO01O_dataout;
	wire_nlO1l_dataout <= ni110i AND NOT(n0OOll);
	wire_nlO1li_dataout <= wire_nlOiii_dataout WHEN n0OilO = '1'  ELSE wire_nlO00i_dataout;
	wire_nlO1ll_dataout <= wire_nlOiil_dataout WHEN n0OilO = '1'  ELSE wire_nlO00l_dataout;
	wire_nlO1lO_dataout <= wire_nlO00O_dataout OR NOT(ni111O);
	wire_nlO1Oi_dataout <= wire_nlO0ii_dataout AND ni111O;
	wire_nlO1Ol_dataout <= wire_nlO0il_dataout AND ni111O;
	wire_nlO1OO_dataout <= wire_nlO0iO_dataout AND ni111O;
	wire_nlOi_dataout <= nl1lll WHEN rxaui_s2gx_en = '1'  ELSE niO0il;
	wire_nlOi0i_dataout <= wire_nlOiOi_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOi0l_dataout <= wire_nlOiOl_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOi0O_dataout <= wire_nlOiOO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOi1i_dataout <= wire_nlOili_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOi1l_dataout <= wire_nlOill_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOi1O_dataout <= wire_nlOilO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOiii_dataout <= wire_nlOl1i_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOiil_dataout <= wire_nlOl1l_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOiiO_dataout <= wire_nlOl1O_dataout AND NOT(wire_ni0O_dataout);
	wire_nlOili_dataout <= wire_nlOl0i_dataout OR wire_ni0O_dataout;
	wire_nlOill_dataout <= wire_nlOl0l_dataout OR wire_ni0O_dataout;
	wire_nlOilO_dataout <= wire_nlOl0O_dataout OR wire_ni0O_dataout;
	wire_nlOiOi_dataout <= wire_nlOlii_dataout OR wire_ni0O_dataout;
	wire_nlOiOl_dataout <= wire_nlOlil_dataout OR wire_ni0O_dataout;
	wire_nlOiOO_dataout <= wire_nlOliO_dataout OR wire_ni0O_dataout;
	wire_nlOl_dataout <= nl1llO WHEN rxaui_s2gx_en = '1'  ELSE niO0iO;
	wire_nlOl0i_dataout <= dec_data(25) OR n0OiOi;
	wire_nlOl0l_dataout <= dec_data(26) OR n0OiOi;
	wire_nlOl0O_dataout <= dec_data(27) AND NOT(n0OiOi);
	wire_nlOl1i_dataout <= wire_nlOlli_dataout OR wire_ni0O_dataout;
	wire_nlOl1l_dataout <= wire_nlOlll_dataout OR wire_ni0O_dataout;
	wire_nlOl1O_dataout <= dec_data(24) OR n0OiOi;
	wire_nlOlii_dataout <= dec_data(28) AND NOT(n0OiOi);
	wire_nlOlil_dataout <= dec_data(29) AND NOT(n0OiOi);
	wire_nlOliO_dataout <= dec_data(30) AND NOT(n0OiOi);
	wire_nlOlli_dataout <= dec_data(31) AND NOT(n0OiOi);
	wire_nlOlll_dataout <= dec_ctl(3) OR n0OiOi;
	wire_nlOlOl_dataout <= wire_nlOOil_dataout OR wire_w_lg_ni111O120w(0);
	wire_nlOlOO_dataout <= wire_nlOOiO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOO_dataout <= nl0l1l WHEN rxaui_s2gx_en = '1'  ELSE nl1lOl;
	wire_nlOO0i_dataout <= wire_nlOOOi_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOO0l_dataout <= wire_nlOOOl_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOO0O_dataout <= wire_nlOOOO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOO1i_dataout <= wire_nlOOli_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOO1l_dataout <= wire_nlOOll_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOO1O_dataout <= wire_nlOOlO_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOOi_dataout <= wire_nlOOl_dataout OR nlOiO;
	wire_nlOOii_dataout <= wire_n111i_dataout AND NOT(wire_w_lg_ni111O120w(0));
	wire_nlOOil_dataout <= wire_n11lO_dataout WHEN ni1lii = '1'  ELSE wire_n111l_dataout;
	wire_nlOOiO_dataout <= wire_n11Oi_dataout WHEN ni1lii = '1'  ELSE wire_n111O_dataout;
	wire_nlOOl_dataout <= nlOll AND NOT((wire_w_lg_w_lg_ni111O120w121w(0) OR (NOT (n0OOlO32 XOR n0OOlO31))));
	wire_nlOOli_dataout <= wire_n11Ol_dataout WHEN ni1lii = '1'  ELSE wire_n110i_dataout;
	wire_nlOOll_dataout <= wire_n11OO_dataout WHEN ni1lii = '1'  ELSE wire_n110l_dataout;
	wire_nlOOlO_dataout <= wire_n101i_dataout WHEN ni1lii = '1'  ELSE wire_n110O_dataout;
	wire_nlOOOi_dataout <= wire_n101l_dataout WHEN ni1lii = '1'  ELSE wire_n11ii_dataout;
	wire_nlOOOl_dataout <= wire_n101O_dataout WHEN ni1lii = '1'  ELSE wire_n11il_dataout;
	wire_nlOOOO_dataout <= wire_n100i_dataout WHEN ni1lii = '1'  ELSE wire_n11iO_dataout;
	wire_nO_dataout <= n10Ol WHEN rxaui_s2gx_en = '1'  ELSE nllO0O;
	wire_nllOi_data <= ( wire_nlO1i_dataout & "0" & wire_nlO1i_dataout & wire_nlO1i_dataout);
	wire_nllOi_sel <= ( nlO0O & nlO0l);
	nllOi :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nllOi_data,
		o => wire_nllOi_o,
		sel => wire_nllOi_sel
	  );
	wire_nllOl_data <= ( wire_n0OOil38_w_lg_w_lg_q150w151w & "0" & wire_n0OOiO36_w_lg_w_lg_q145w146w & wire_nlO1l_dataout);
	wire_nllOl_sel <= ( nlO0O & nlO0l);
	nllOl :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nllOl_data,
		o => wire_nllOl_o,
		sel => wire_nllOl_sel
	  );
	wire_nllOO_w_lg_o126w(0) <= NOT wire_nllOO_o;
	wire_nllOO_data <= ( n0OOll & "1" & n0OOll & n0OOll);
	wire_nllOO_sel <= ( nlO0O & wire_n0OOli34_w_lg_w_lg_q129w130w);
	nllOO :  oper_mux
	  GENERIC MAP (
		width_data => 4,
		width_sel => 2
	  )
	  PORT MAP ( 
		data => wire_nllOO_data,
		o => wire_nllOO_o,
		sel => wire_nllOO_sel
	  );

 END RTL; --stratixiv_hssi_rcv_sm
--synopsys translate_on
--VALID FILE


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_quad_reset IS
   PORT (
      -- Common reset inputs
      -- Common reset CRAMs
      -- CMU reset inputs
      -- CMU reset CRAMs
      -- CMU powerdown inputs
      -- CMU powerdown CRAMs
      -- CMU reset outputs
      -- CMU powerdown outputs
      -- Other outputs
      
      -- Common reset inputs
      entest               : IN STD_LOGIC;		-- Test mode control from Control block
      plniotri             : IN STD_LOGIC;		-- PLL output enable
      npor                 : IN STD_LOGIC;		-- Power on reset
      frzreg               : IN STD_LOGIC;		-- Freeze register during power-up
      pllurst              : IN STD_LOGIC;		-- PLL user reset
      
      -- Common reset CRAMs
      rpllurst             : IN STD_LOGIC;		-- Gating CRAM for PLLURST
      rpowerdown           : IN STD_LOGIC;		-- Quad power down CRAM
      rreset               : IN STD_LOGIC;		-- Quad reset CRAM
      
      -- CMU reset inputs
      rxurstcmu            : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Dynamic signal for CMU[1:0]_RXPMA_RSTB
      
      -- CMU reset CRAMs
      rrxurstcmu           : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Gating CRAM for dynamic signal rxurstcmu
      rrx_cmu_rst          : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- TXPLL / RXPLL reset
      
      -- CMU powerdown inputs
      ucmurx_pdb           : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Dynamic signal for CMU[1:0]_RX_PDB
      
      -- CMU powerdown CRAMs
      rclk_pdb             : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rcmu_powdnr          : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rcmu_cru_pdb         : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rcmu_urx_pdb         : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rcmu_rx_ib_pdb       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rcmu_powdnt          : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rcmu_tx_ob_pdb       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rcmu_tx_cgb_pdb      : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rcmu_rx_det_pdb      : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      
      -- CMU reset outputs
      cmu0_rxpma_rstb      : OUT STD_LOGIC;
      cmu0_txpma_rstb      : OUT STD_LOGIC;
      cmu0_cru_rstb        : OUT STD_LOGIC;
      
      cmu1_rxpma_rstb      : OUT STD_LOGIC;
      cmu1_txpma_rstb      : OUT STD_LOGIC;
      cmu1_cru_rstb        : OUT STD_LOGIC;
      
      -- CMU powerdown outputs
      cmu0_rx_pdb          : OUT STD_LOGIC;
      cmu0_cru_pdb         : OUT STD_LOGIC;
      cmu0_clk_pdb         : OUT STD_LOGIC;
      cmu0_tx_pdb          : OUT STD_LOGIC;
      cmu0_cgb_pdb         : OUT STD_LOGIC;
      cmu0_rx_det_pdb      : OUT STD_LOGIC;
      
      cmu1_rx_pdb          : OUT STD_LOGIC;
      cmu1_cru_pdb         : OUT STD_LOGIC;
      cmu1_clk_pdb         : OUT STD_LOGIC;
      cmu1_tx_pdb          : OUT STD_LOGIC;
      cmu1_cgb_pdb         : OUT STD_LOGIC;
      cmu1_rx_det_pdb      : OUT STD_LOGIC;
      
      -- Other outputs
      mdio_rst             : OUT STD_LOGIC;		-- MDIO reset
      hard_reset           : OUT STD_LOGIC;		-- Output HARD_RESET signal for other MDIO modules
      soft_reset_all_hssi  : OUT STD_LOGIC		-- Quad soft reset output
   );
END stratixiv_hssi_cmu_quad_reset;

ARCHITECTURE trans OF stratixiv_hssi_cmu_quad_reset IS
   
   ------------------------------------
   -- Wiring section for Resets
   ------------------------------------
   SIGNAL cmu0_rxpma_rst_hssi : STD_LOGIC;
   SIGNAL cmu1_rxpma_rst_hssi : STD_LOGIC;
   
   ------------------------------------
   -- Wiring section for Powerdowns
   ------------------------------------
   SIGNAL cmu0_cru_pd_hssi    : STD_LOGIC;
   SIGNAL cmu0_rx_pd_hssi     : STD_LOGIC;
   SIGNAL cmu0_tx_pd_hssi     : STD_LOGIC;
   SIGNAL cmu0_cgb_pd_hssi    : STD_LOGIC;
   SIGNAL cmu0_rx_det_pd_hssi : STD_LOGIC;
   
   SIGNAL cmu1_cru_pd_hssi    : STD_LOGIC;
   SIGNAL cmu1_rx_pd_hssi     : STD_LOGIC;
   SIGNAL cmu1_tx_pd_hssi     : STD_LOGIC;
   SIGNAL cmu1_cgb_pd_hssi    : STD_LOGIC;
   SIGNAL cmu1_rx_det_pd_hssi : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL hard_reset_xhdl0    : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   hard_reset <= hard_reset_xhdl0;
   
   ------------------------------------
   -- Other reset outputs
   ------------------------------------
   -- SP update 10/17/07 - enpll term removed from hard_reset
   -- assign hard_reset = ~(plniotri & ~entest & npor & (enpll | rnenbpin) & (~pllurst | ~rpllurst));
   hard_reset_xhdl0 <= NOT((plniotri AND NOT(entest) AND npor AND (NOT(pllurst) OR NOT(rpllurst))));
   soft_reset_all_hssi <= frzreg OR rpowerdown OR rreset;
   mdio_rst <= NOT((plniotri AND NOT(entest) AND npor));
   
   ------------------------------------
   -- CMU reset internal signals
   ------------------------------------
   cmu0_rxpma_rst_hssi <= (rxurstcmu(0) AND rrxurstcmu(0)) OR rreset;
   cmu1_rxpma_rst_hssi <= (rxurstcmu(1) AND rrxurstcmu(1)) OR rreset;
   
   ------------------------------------
   -- CMU reset outputs
   ------------------------------------
   cmu0_rxpma_rstb <= NOT((cmu0_rxpma_rst_hssi OR hard_reset_xhdl0));
   cmu0_txpma_rstb <= NOT((hard_reset_xhdl0 OR rreset));
   cmu0_cru_rstb <= NOT((hard_reset_xhdl0 OR rreset OR rrx_cmu_rst(0)));
   
   cmu1_rxpma_rstb <= NOT((cmu1_rxpma_rst_hssi OR hard_reset_xhdl0));
   cmu1_txpma_rstb <= NOT((hard_reset_xhdl0 OR rreset));
   cmu1_cru_rstb <= NOT((hard_reset_xhdl0 OR rreset OR rrx_cmu_rst(1)));
   
   ------------------------------------
   -- powerdown internal signals
   ------------------------------------
   cmu0_cru_pd_hssi <= rpowerdown OR rcmu_powdnr(0) OR NOT((rcmu_cru_pdb(0)));
   cmu0_rx_pd_hssi <= rpowerdown OR rcmu_powdnr(0) OR NOT((ucmurx_pdb(0) OR NOT((rcmu_urx_pdb(0))))) OR NOT((rcmu_rx_ib_pdb(0)));
   cmu0_tx_pd_hssi <= rpowerdown OR rcmu_powdnt(0) OR NOT((rcmu_tx_ob_pdb(0)));
   cmu0_cgb_pd_hssi <= rpowerdown OR rcmu_powdnt(0) OR NOT((rcmu_tx_cgb_pdb(0)));
   cmu0_rx_det_pd_hssi <= rpowerdown OR rcmu_powdnt(0) OR NOT((rcmu_rx_det_pdb(0)));
   
   cmu1_cru_pd_hssi <= rpowerdown OR rcmu_powdnr(1) OR NOT((rcmu_cru_pdb(1)));
   cmu1_rx_pd_hssi <= rpowerdown OR rcmu_powdnr(1) OR NOT((ucmurx_pdb(1) OR NOT((rcmu_urx_pdb(1))))) OR NOT((rcmu_rx_ib_pdb(1)));
   cmu1_tx_pd_hssi <= rpowerdown OR rcmu_powdnt(1) OR NOT((rcmu_tx_ob_pdb(1)));
   cmu1_cgb_pd_hssi <= rpowerdown OR rcmu_powdnt(1) OR NOT((rcmu_tx_cgb_pdb(1)));
   cmu1_rx_det_pd_hssi <= rpowerdown OR rcmu_powdnt(1) OR NOT((rcmu_rx_det_pdb(1)));
   
   ------------------------------------
   -- powerdown outputs
   ------------------------------------
   cmu0_clk_pdb <= rclk_pdb(0);
   cmu0_cru_pdb <= NOT((hard_reset_xhdl0 OR cmu0_cru_pd_hssi));
   cmu0_rx_pdb <= NOT((hard_reset_xhdl0 OR cmu0_rx_pd_hssi));
   cmu0_tx_pdb <= NOT((hard_reset_xhdl0 OR cmu0_tx_pd_hssi));
   cmu0_cgb_pdb <= NOT((hard_reset_xhdl0 OR cmu0_cgb_pd_hssi));
   cmu0_rx_det_pdb <= NOT((hard_reset_xhdl0 OR cmu0_rx_det_pd_hssi));
   
   cmu1_clk_pdb <= rclk_pdb(1);
   cmu1_cru_pdb <= NOT((hard_reset_xhdl0 OR cmu1_cru_pd_hssi));
   cmu1_rx_pdb <= NOT((hard_reset_xhdl0 OR cmu1_rx_pd_hssi));
   cmu1_tx_pdb <= NOT((hard_reset_xhdl0 OR cmu1_tx_pd_hssi));
   cmu1_cgb_pdb <= NOT((hard_reset_xhdl0 OR cmu1_cgb_pd_hssi));
   cmu1_rx_det_pdb <= NOT((hard_reset_xhdl0 OR cmu1_rx_det_pd_hssi));
   
END trans;



LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_chnl_reset IS
   PORT (
      
      -- Inputs from QUAD reset module		  
      hard_reset           : IN STD_LOGIC;		-- hardreset signal
      soft_reset_all_hssi  : IN STD_LOGIC;		-- soft reset for all channel
      rreset               : IN STD_LOGIC;		-- Quad reset CRAM
      rpowerdown           : IN STD_LOGIC;		-- Quad power down CRAM
      
      -- Channel Reset inputs
      rxurstpma            : IN STD_LOGIC;		-- RX PMA user reset
      rxurstpcs            : IN STD_LOGIC;		-- RX PCS user reset
      txurstpcs            : IN STD_LOGIC;		-- TX PCS user reset
      
      -- Channel Reset CRAMs
      rpowdnr              : IN STD_LOGIC;		-- RX channel power down CRAM
      rpowdnt              : IN STD_LOGIC;		-- TX channel power down CRAM
      rrxurstpcs           : IN STD_LOGIC;		-- Gating CRAM for RXURSTPCS
      rtxurstpcs           : IN STD_LOGIC;		-- Gating CRAM for TXURSTPCS
      rrxurstpma           : IN STD_LOGIC;		-- Gating CRAM for RXURSTPMA
      rrx_cru_rst          : IN STD_LOGIC;		-- Channel RX PLL reset CRAMs
      radce_rst            : IN STD_LOGIC;		-- Channel Adaptive block reset CRAMs
      
      -- Powerdown inputs
      urx_pdb              : IN STD_LOGIC;		-- RX user powerdown signal
      
      -- Powerdown CRAMs
      rurx_pdb             : IN STD_LOGIC;		-- Gating CRAM for urx_pdb signals
      radce_pdb            : IN STD_LOGIC;		-- Adaptive block powerdown CRAMs
      rrx_ib_pdb           : IN STD_LOGIC;		-- RX Input buffer and PLL powerdown CRAMs
      rtx_ob_pdb           : IN STD_LOGIC;		-- TX Output buffer powerdown CRAMs
      rtx_cgb_pdb          : IN STD_LOGIC;		-- TX clock generator powerdown CRAMs
      rrx_cru_pdb          : IN STD_LOGIC;		-- RX PLL powerdown CRAMs
      
      -- PIPE Inputs
      rtx_pipe_en          : IN STD_LOGIC;		-- PIPE enable CRAMs
      p0_state             : IN STD_LOGIC;		-- PIPE P0 state indicators
      p0s_state            : IN STD_LOGIC;		-- PIPE P0S state indicators
      p2_state             : IN STD_LOGIC;		-- PIPE P2 state indicators
      
      -- Channel Reset outputs
      rxpma_rstb           : OUT STD_LOGIC;		-- RX PMA resets (powerdown)
      txpma_rstb           : OUT STD_LOGIC;		-- TX PMA resets (powerdown)
      rxpcs_rst            : OUT STD_LOGIC;		-- RX PCS resets 
      txpcs_rst            : OUT STD_LOGIC;		-- TX PCS resets
      cru_rstb             : OUT STD_LOGIC;		-- RX PLL resets
      adce_rstb            : OUT STD_LOGIC;		-- Adaptive block resets
      
      -- Channel Powerdown outputs
      adce_pdb             : OUT STD_LOGIC;		-- Adaptive block powerdown
      cru_pdb              : OUT STD_LOGIC;		-- RX PLL powerdown
      rx_pdb               : OUT STD_LOGIC;		-- RX powerdown
      tx_pdb               : OUT STD_LOGIC;		-- TX driver powerdown
      cgb_pdb              : OUT STD_LOGIC;		-- Clock generator powerdown
      rx_det_pdb           : OUT STD_LOGIC		-- Receiver detector powerdown
   );
END stratixiv_hssi_cmu_chnl_reset;

ARCHITECTURE trans OF stratixiv_hssi_cmu_chnl_reset IS
   
   -- Wiring section for Resets
   SIGNAL rxpcsrst_hssi    : STD_LOGIC;
   SIGNAL txpcsrst_hssi    : STD_LOGIC;
   SIGNAL rxpmarst_hssi    : STD_LOGIC;
   
   -- Wiring section for Powerdowns
   SIGNAL adce_pd_hssi     : STD_LOGIC;
   SIGNAL cru_pd_hssi      : STD_LOGIC;
   SIGNAL rx_pd_hssi       : STD_LOGIC;
   SIGNAL tx_pd_hssi       : STD_LOGIC;
   SIGNAL cgb_pd_hssi      : STD_LOGIC;
   SIGNAL rx_det_pd_hssi   : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL rxpma_rstb_xhdl0 : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   rxpma_rstb <= rxpma_rstb_xhdl0;
   
   -- reset internal signals
   rxpcsrst_hssi <= (rxurstpcs AND rrxurstpcs) OR rpowdnr;
   txpcsrst_hssi <= (txurstpcs AND rtxurstpcs) OR rpowdnt;
   rxpmarst_hssi <= (rxurstpma AND rrxurstpma) OR rreset;
   
   -- reset outputs
   rxpma_rstb_xhdl0 <= NOT((rxpmarst_hssi OR hard_reset));
   txpma_rstb <= NOT((rreset OR hard_reset));
   cru_rstb <= NOT((hard_reset OR rreset OR rrx_cru_rst));
   adce_rstb <= rxpma_rstb_xhdl0 AND NOT((radce_rst));
   
   rxpcs_rst <= rxpcsrst_hssi OR hard_reset OR soft_reset_all_hssi;
   txpcs_rst <= txpcsrst_hssi OR hard_reset OR soft_reset_all_hssi;
   
   -- powerdown internal signals
   adce_pd_hssi <= NOT((radce_pdb)) OR rpowdnr OR rpowerdown;
   cru_pd_hssi <= NOT((rrx_cru_pdb)) OR rpowdnr OR rpowerdown;
   rx_pd_hssi <= NOT((urx_pdb OR NOT((rurx_pdb)))) OR NOT((rrx_ib_pdb)) OR rpowdnr OR rpowerdown;
   tx_pd_hssi <= NOT((rtx_ob_pdb)) OR rpowdnt OR rpowerdown;
   cgb_pd_hssi <= NOT((rtx_cgb_pdb)) OR rpowdnt OR rpowerdown;
   rx_det_pd_hssi <= (rtx_pipe_en AND (p0_state OR p0s_state OR p2_state)) OR rpowdnt OR rpowerdown;
   
   -- powerdown outputs
   adce_pdb <= NOT((adce_pd_hssi OR hard_reset));
   cru_pdb <= NOT((cru_pd_hssi OR hard_reset));
   rx_pdb <= NOT((rx_pd_hssi OR hard_reset));
   tx_pdb <= NOT((tx_pd_hssi OR hard_reset));
   cgb_pdb <= NOT((cgb_pd_hssi OR hard_reset));
   rx_det_pdb <= NOT((rx_det_pd_hssi OR hard_reset));
   
END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_auto_speed_neg IS
   GENERIC (
      
      -- Clocks and Resets
      WAIT_RATE_CHANGE           : INTEGER := 0;
      WAIT_FOR_PHFIFO            : INTEGER := 1;
      DISABLE_PC_BYTE            : INTEGER := 2;
      SET_CONFIG_SEL             : INTEGER := 3;
      WAIT_GEN2NGEN1_CHANGE      : INTEGER := 4;
      WAIT_PMA_DONE_CNTR         : INTEGER := 5;
      DEASSERT_PC_PTR_RESET      : INTEGER := 6;
      WAIT_DEASSERT_RST_CNTR     : INTEGER := 7;
      ENABLE_PC_BYTE             : INTEGER := 8;
      WAIT_ENABLE_CNTR           : INTEGER := 9;
      SPEED_CHANGE_DONE          : INTEGER := 10
   );
   PORT (
      refclk                     : IN STD_LOGIC;
      rxpcs_rst_int              : IN STD_LOGIC;
      
      -- Input from LTSSM (sideband).  high is gen2, low is gen1.
      rate                       : IN STD_LOGIC;
      -- Input from PMA
      -- PMA indication for change in frequency.  transistions one cycle before actually frequency change.  high is gen2, low is gen1.
      gen2ngen1                  : IN STD_LOGIC;
      
      -- Bundle Mode Inputs for config_sel
      config_sel_centrl          : IN STD_LOGIC;
      config_sel_quad_up         : IN STD_LOGIC;
      config_sel_quad_down       : IN STD_LOGIC;
      
      -- MDIO
      rindv_rx                   : IN STD_LOGIC;
      rmaster_rx                 : IN STD_LOGIC;
      rmaster_up_rx              : IN STD_LOGIC;
      rauto_speed_ena            : IN STD_LOGIC;
      singleorbundle             : IN STD_LOGIC;
      rphfifo_regmode_rx         : IN STD_LOGIC;
      rpma_done_count            : IN STD_LOGIC_VECTOR(17 DOWNTO 0);
      rauto_deassert_pc_rst_cnt  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      rauto_pc_en_cnt            : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
      rwait_for_phfifo_cnt       : IN STD_LOGIC_VECTOR(5 DOWNTO 0);
      
      -- control signal output for bundle mode  high is gen2, low is gen1.
      config_sel                 : OUT STD_LOGIC;
      
      -- PMA rate change control
      pcie_switch                : OUT STD_LOGIC;
      
      -- RX Phase Comp
      -- Handshake signal to PIPE interface to assert PhyStatus
      speed_change               : OUT STD_LOGIC;
      
      -- Phase Comp and byte ser/deser control signals
      dis_pc_byte                : OUT STD_LOGIC;
      reset_pc_ptrs              : OUT STD_LOGIC;
      cs                         : OUT STD_LOGIC_VECTOR(3 DOWNTO 0)
   );
END stratixiv_hssi_cmu_auto_speed_neg;

ARCHITECTURE trans OF stratixiv_hssi_cmu_auto_speed_neg IS
   
   SIGNAL set_config_sel_reg : STD_LOGIC;
   SIGNAL next_state         : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rate_int_reg       : STD_LOGIC;
   SIGNAL gen2ngen1_del      : STD_LOGIC;
   SIGNAL freq_switch        : STD_LOGIC;
   SIGNAL reset_count        : STD_LOGIC;
   SIGNAL count_pma_done     : STD_LOGIC;
   SIGNAL count_deassert_rst : STD_LOGIC;
   SIGNAL count_enable_pc    : STD_LOGIC;
   SIGNAL rate_sync1_reg     : STD_LOGIC;
   SIGNAL rate_sync2_reg     : STD_LOGIC;
   SIGNAL counter            : STD_LOGIC_VECTOR(18 DOWNTO 0);
   SIGNAL counter_done       : STD_LOGIC;
   SIGNAL count_phfifo       : STD_LOGIC;
   
   SIGNAL rate_edge          : STD_LOGIC;
   -- X-HDL generated signals

   SIGNAL xhdl2 : STD_LOGIC;
   SIGNAL xhdl3 : STD_LOGIC;
   SIGNAL xhdl4 : STD_LOGIC;
   SIGNAL xhdl5 : STD_LOGIC;
   SIGNAL xhdl6 : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL config_sel_xhdl0   : STD_LOGIC;
   SIGNAL cs_xhdl1           : STD_LOGIC_VECTOR(3 DOWNTO 0);
BEGIN
   -- Drive referenced outputs
   config_sel <= config_sel_xhdl0;
   cs <= cs_xhdl1;
   
   --============================================================================
   --  FSM states
   --
   --============================================================================
   
   --============================================================================
   --  Multi-use Counter with *2 done flag capablility 
   --
   --============================================================================
   
   
   xhdl2 <= '1' WHEN (((counter(18 DOWNTO 1) = rpma_done_count(17 DOWNTO 0)) AND (gen2ngen1 = '1') AND (counter(0) = '1')) OR ((counter(17 DOWNTO 0) = rpma_done_count(17 DOWNTO 0)) AND (NOT(gen2ngen1) = '1'))) ELSE
   '0';
   xhdl3 <= '1' WHEN (((counter(4 DOWNTO 1) = rauto_deassert_pc_rst_cnt(3 DOWNTO 0)) AND (gen2ngen1 = '1') AND (counter(0) = '1')) OR ((counter(3 DOWNTO 0) = rauto_deassert_pc_rst_cnt(3 DOWNTO 0)) AND (NOT(gen2ngen1) = '1'))) ELSE
   '0';
   xhdl4 <= '1' WHEN (((counter(5 DOWNTO 1) = rauto_pc_en_cnt(4 DOWNTO 0)) AND (gen2ngen1 = '1') AND (counter(0) = '1')) OR ((counter(4 DOWNTO 0) = rauto_pc_en_cnt(4 DOWNTO 0)) AND (NOT(gen2ngen1) = '1'))) ELSE
   '0';
   xhdl5 <= '1' WHEN (((counter(6 DOWNTO 1) = rwait_for_phfifo_cnt(5 DOWNTO 0)) AND (gen2ngen1 = '1') AND (counter(0) = '1')) OR ((counter(5 DOWNTO 0) = rwait_for_phfifo_cnt(5 DOWNTO 0)) AND (NOT(gen2ngen1) = '1'))) ELSE
   '0';
   PROCESS (refclk, rxpcs_rst_int)
VARIABLE  txt : LINE;
   BEGIN
      IF (rxpcs_rst_int = '1') THEN
         counter <=  TRANSPORT "0000000000000000000" AFTER 1* 1 ps;
         counter_done <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (refclk'EVENT AND refclk = '1') THEN
         IF (reset_count = '1') THEN
            counter <=  TRANSPORT "0000000000000000000" AFTER 1* 1 ps;
            counter_done <=  TRANSPORT '0' AFTER 1* 1 ps;
         ELSE
            counter <=  TRANSPORT counter + "0000000000000000001" AFTER 1* 1 ps;
            IF ((NOT(counter_done)) = '1') THEN
               IF (count_pma_done = '1') THEN
                  counter_done <=  TRANSPORT xhdl2 AFTER 1* 1 ps;
               ELSIF (count_deassert_rst = '1') THEN
                  counter_done <=  TRANSPORT xhdl3 AFTER 1* 1 ps;
               ELSIF (count_enable_pc = '1') THEN
                  counter_done <=  TRANSPORT xhdl4 AFTER 1* 1 ps;
               ELSIF (count_phfifo = '1') THEN
                  counter_done <=  TRANSPORT xhdl5 AFTER 1* 1 ps;
               END IF;
            END IF;
         END IF;
      END IF;
   END PROCESS;
   
   -- if (~count_pma_done)
   -- always @ (posedge clk or posedge reset)
   
   --============================================================================
   --  Control signal output logic
   --
   --============================================================================
   
   pcie_switch <= config_sel_xhdl0 WHEN (rindv_rx = '1') ELSE
                  config_sel_centrl WHEN (rmaster_rx = '1') ELSE
                  config_sel_quad_up WHEN (rmaster_up_rx = '1') ELSE
                  config_sel_quad_down;
   
   --============================================================================
   --  Synchronization, Input & Output Logic
   --
   --============================================================================
   
   PROCESS (refclk, rxpcs_rst_int)
VARIABLE  txt : LINE;
   BEGIN
      IF (rxpcs_rst_int = '1') THEN
         rate_sync1_reg <=  TRANSPORT '0' AFTER 1* 1 ps;
         rate_sync2_reg <=  TRANSPORT '0' AFTER 1* 1 ps;
         rate_int_reg <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (refclk'EVENT AND refclk = '1') THEN
         rate_sync1_reg <=  TRANSPORT rate AFTER 1* 1 ps;
         rate_sync2_reg <=  TRANSPORT rate_sync1_reg AFTER 1* 1 ps;
         rate_int_reg <=  TRANSPORT rate_sync2_reg AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   -- always @ (posedge refclk or posedge reset)
   
   rate_edge <= '1' WHEN (rate_sync2_reg /= rate_int_reg) ELSE
                '0';
   
   -- convert gen2ngen1 to freq_switch
   xhdl6 <= '1' WHEN (gen2ngen1_del /= gen2ngen1) ELSE
                '0';
   PROCESS (refclk, rxpcs_rst_int)
VARIABLE  txt : LINE;
   BEGIN
      IF (rxpcs_rst_int = '1') THEN
         gen2ngen1_del <=  TRANSPORT '0' AFTER 1* 1 ps;
         freq_switch <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (refclk'EVENT AND refclk = '1') THEN
         gen2ngen1_del <=  TRANSPORT gen2ngen1 AFTER 1* 1 ps;
         freq_switch <=  TRANSPORT xhdl6 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   -- always @ (posedge refclk or posedge reset)
   
   -- config_sel
   PROCESS (refclk, rxpcs_rst_int)
VARIABLE  txt : LINE;
   BEGIN
      IF (rxpcs_rst_int = '1') THEN
         config_sel_xhdl0 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (refclk'EVENT AND refclk = '1') THEN
         IF (set_config_sel_reg = '1') THEN
            config_sel_xhdl0 <=  TRANSPORT rate_sync2_reg AFTER 1* 1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   -- always @ (posedge refclk or posedge reset)
   
   --============================================================================
   --  Auto Speed Negotiation State Machine
   --
   --============================================================================
   --   
   
   PROCESS (refclk, rxpcs_rst_int)
VARIABLE  txt : LINE;
   BEGIN
      IF (rxpcs_rst_int = '1') THEN
         cs_xhdl1 <=  TRANSPORT int2bin(WAIT_RATE_CHANGE, 4) AFTER 1* 1 ps;
      ELSIF (refclk'EVENT AND refclk = '1') THEN
         cs_xhdl1 <=  TRANSPORT next_state AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   -- always @ (posedge refclk or posedge reset)
   
   PROCESS (cs_xhdl1, rate_edge, rauto_speed_ena, rphfifo_regmode_rx, freq_switch, counter_done, singleorbundle)
VARIABLE  txt : LINE;
   BEGIN
--      IF (cs_xhdl1'EVENT) THEN
         
         next_state <= cs_xhdl1;
         dis_pc_byte <= '0';
         reset_pc_ptrs <= '0';
         set_config_sel_reg <= '0';
         speed_change <= '0';
         reset_count <= '1';
         count_pma_done <= '0';
         count_deassert_rst <= '0';
         count_enable_pc <= '0';
         
         count_phfifo <= '0';
         
         CASE cs_xhdl1 IS
            
            -- case: WAIT_RATE_CHANGE
            
            WHEN "0000" =>
               IF ((rate_edge AND rauto_speed_ena AND singleorbundle) = '1') THEN
                  IF ((NOT(rphfifo_regmode_rx)) = '1') THEN
                     next_state <= int2bin(WAIT_FOR_PHFIFO, 4);
                  ELSE
                     next_state <= int2bin(SET_CONFIG_SEL, 4);
                  END IF;
               END IF;
            
            -- case: WAIT_FOR_PHFIFO

            WHEN "0001" =>
               reset_count <= '0';
               count_phfifo <= '1';
               IF (counter_done = '1') THEN
                  next_state <= int2bin(DISABLE_PC_BYTE, 4);
               END IF;
            
            -- case: DISABLE_PC_BYTE
            
            WHEN "0010" =>
               dis_pc_byte <= '1';
               reset_pc_ptrs <= '1';
               speed_change <= '1';
               next_state <= int2bin(SET_CONFIG_SEL, 4);
            
            -- case: SET_CONFIG_SEL
            
            WHEN "0011" =>
               dis_pc_byte <= '1';
               reset_pc_ptrs <= '1';
               set_config_sel_reg <= '1';
               speed_change <= '1';
               next_state <= int2bin(WAIT_GEN2NGEN1_CHANGE, 4);
            
            -- case: WAIT_GEN2NGEN1_CHANGE
            
            WHEN "0100" =>
               dis_pc_byte <= '1';
               reset_pc_ptrs <= '1';
               speed_change <= '1';
               IF (freq_switch = '1') THEN
                  next_state <= int2bin(WAIT_PMA_DONE_CNTR, 4);
               END IF;
            
            -- case: WAIT_PMA_DONE_CNTR
            
            WHEN "0101" =>
               dis_pc_byte <= '1';
               reset_pc_ptrs <= '1';
               speed_change <= '1';
               reset_count <= '0';
               count_pma_done <= '1';
               IF (counter_done = '1') THEN
                  IF ((NOT(rphfifo_regmode_rx)) = '1') THEN
                     next_state <= int2bin(DEASSERT_PC_PTR_RESET, 4);
                  ELSE
                     next_state <= int2bin(SPEED_CHANGE_DONE, 4);
                  END IF;
               END IF;
            
 	  -- case DEASSERT_PC_PTR_RESET

           WHEN "0110" =>
               dis_pc_byte <= '1';
               speed_change <= '1';
               next_state <= int2bin(WAIT_DEASSERT_RST_CNTR, 4);
            
            -- case: WAIT_DEASSERT_RST_CNTR
            
            WHEN "0111" =>
               dis_pc_byte <= '1';
               speed_change <= '1';
               reset_count <= '0';
               count_deassert_rst <= '1';
               IF (counter_done = '1') THEN
                  next_state <= int2bin(ENABLE_PC_BYTE, 4);
               END IF;
            
            -- case: ENABLE_PC_BYTE:

            WHEN "1000" =>
               speed_change <= '1';
               next_state <= int2bin(WAIT_ENABLE_CNTR, 4);
            
            -- case: WAIT_ENABLE_CNTR:  
    
            WHEN "1001" =>
               speed_change <= '1';
               reset_count <= '0';
               count_enable_pc <= '1';
               IF (counter_done = '1') THEN
                  next_state <= int2bin(SPEED_CHANGE_DONE, 4);
               END IF;
            
            -- case: SPEED_CHANGE_DONE:

            WHEN "1010" =>
               next_state <= int2bin(WAIT_RATE_CHANGE, 4);
            
            -- case: default
            
            WHEN OTHERS =>		-- case(cs)
               dis_pc_byte <= '0';
               reset_pc_ptrs <= '0';
               set_config_sel_reg <= '0';
               speed_change <= '0';
               reset_count <= '1';
               count_pma_done <= '0';
               count_deassert_rst <= '0';
               count_enable_pc <= '0';
               next_state <= int2bin(WAIT_RATE_CHANGE, 4);
         END CASE;
--      END IF;
   END PROCESS;
   
   
END trans;



-- always @ (cs or rate_edge or rauto_speed_ena or rphfifo_regmode_rx or freq_switch or counter_done)


-- auto_speed_neg_centrl
LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_clk_gating IS
    PORT (
        
        select_n   : IN STD_LOGIC;
        clk1       : IN STD_LOGIC;
        clk2       : IN STD_LOGIC;
        clk1out_n  : OUT STD_LOGIC;
        clk2out_n  : OUT STD_LOGIC
    );
END ENTITY stratixiv_hssi_cmu_clk_gating;

ARCHITECTURE trans OF stratixiv_hssi_cmu_clk_gating IS
BEGIN
    
    clk1out_n <= NOT((select_n OR clk1));
    clk2out_n <= NOT((NOT(select_n) OR clk2));
    
END ARCHITECTURE trans;

-- centrl_clk_gating


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_clk_ctl IS
   PORT (
      
      pclk_pma           : IN STD_LOGIC;		-- x4 PCLK from PMA CMU
      refclk_dig         : IN STD_LOGIC;		-- External digital clock
      mdc                : IN STD_LOGIC;		-- MDIO input clock
      ser_clk            : IN STD_LOGIC;		-- Serial clock
      ser_mode           : IN STD_LOGIC;		-- Serial shift configuration mode
      scan_mode          : IN STD_LOGIC;		-- Scan mode
      scan_clk           : IN STD_LOGIC;		-- Scan mode
      rfreerun_centrl    : IN STD_LOGIC;		-- REFCLK_OUT free running enable CRAM
      rcentrl_clk_sel    : IN STD_LOGIC;		-- REFCLK_PMA global clock selection CRAM
      rrefclk_out_div2   : IN STD_LOGIC;		-- REFCLK_OUT divide by 2 enable CRAM
      hard_reset         : IN STD_LOGIC;		-- Hard reset input
      txrst              : IN STD_LOGIC;
      
      refclk_pma_out     : OUT STD_LOGIC;		-- Global TX PCS clock
      mdc_b              : OUT STD_LOGIC;		-- Configuration output clock
      refclk_out         : OUT STD_LOGIC;		-- REFCLK_OUT output clk
      rauto_speed_ena    : IN STD_LOGIC;
      rfreq_sel          : IN STD_LOGIC;
      gen2ngen1_bundle   : IN STD_LOGIC
   );
END stratixiv_hssi_cmu_clk_ctl;

ARCHITECTURE trans OF stratixiv_hssi_cmu_clk_ctl IS
   
   COMPONENT stratixiv_hssi_cmu_clk_gating    
   PORT (
        
        select_n   : IN STD_LOGIC;
        clk1       : IN STD_LOGIC;
        clk2       : IN STD_LOGIC;
        clk1out_n  : OUT STD_LOGIC;
        clk2out_n  : OUT STD_LOGIC
    );
   END COMPONENT;

   SIGNAL refclk_pma_int       : STD_LOGIC;
   SIGNAL refclk_out_div2_inv  : STD_LOGIC;
   SIGNAL hard_reset_n         : STD_LOGIC;
   SIGNAL refclk_out_div2      : STD_LOGIC := '1';
   
   SIGNAL gen2ngen1_local_sync : STD_LOGIC;
   SIGNAL dynamic_div2ndiv1    : STD_LOGIC;
  
   SIGNAL clk1out_n    : STD_LOGIC;
   SIGNAL clk2out_n    : STD_LOGIC;
       
   -- Declare intermediate signals for referenced outputs
   SIGNAL refclk_pma_out_xhdl1 : STD_LOGIC;
   SIGNAL refclk_out_xhdl0     : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   refclk_pma_out <= refclk_pma_out_xhdl1;
   refclk_out <= refclk_out_xhdl0;
   
     
   -- The following assignments need to be replaced with clock buffers
   -- instantiation when the technology is identified later
   
   -- refclk_pma clock selection
   refclk_pma_int <= refclk_dig WHEN (rcentrl_clk_sel = '1') ELSE
                     pclk_pma;
   refclk_pma_out_xhdl1 <= scan_clk WHEN (scan_mode = '1') ELSE
                           refclk_pma_int;
   
   -- refclk_out logic
   -- This register is used to generate divided by two clock. Div by 2 clock starts off high after reset
   refclk_out_div2_inv <= (NOT(refclk_out_div2) OR NOT(gen2ngen1_local_sync)) WHEN ((rauto_speed_ena AND NOT(rfreq_sel)) = '1') ELSE
                          NOT(refclk_out_div2);
   
   hard_reset_n <= '1' WHEN (rfreerun_centrl = '1') ELSE
                   NOT(hard_reset);
   
   PROCESS (hard_reset_n, refclk_pma_out_xhdl1)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(hard_reset_n)) = '1') THEN
         refclk_out_div2 <= '1';
      ELSIF (refclk_pma_out_xhdl1'EVENT AND refclk_pma_out_xhdl1 = '1') THEN
         refclk_out_div2 <= refclk_out_div2_inv;
      END IF;
   END PROCESS;
   
   PROCESS (txrst, refclk_pma_out_xhdl1)
VARIABLE  txt : LINE;
   BEGIN
      IF (txrst = '1') THEN
         gen2ngen1_local_sync <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (refclk_pma_out_xhdl1'EVENT AND refclk_pma_out_xhdl1 = '1') THEN
         gen2ngen1_local_sync <=  TRANSPORT gen2ngen1_bundle AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   dynamic_div2ndiv1 <= rrefclk_out_div2 OR (gen2ngen1_local_sync AND rauto_speed_ena AND NOT(rfreq_sel));
   
   
   
   centrl_clk_gating : stratixiv_hssi_cmu_clk_gating
      PORT MAP (
        select_n   => dynamic_div2ndiv1,
        clk1       => refclk_pma_out_xhdl1,
        clk2       => refclk_out_div2,
        clk1out_n  => clk1out_n,
        clk2out_n  => clk2out_n
      );
      
   refclk_out_xhdl0 <= NOT (clk1out_n OR clk2out_n);
   
   -- mdc_b clock logic
   mdc_b <= refclk_pma_out_xhdl1 WHEN ((scan_mode = '1') AND (ser_mode = '1')) ELSE
            refclk_pma_out_xhdl1 WHEN ((scan_mode = '1') AND (ser_mode = '0')) ELSE
            ser_clk WHEN ((scan_mode = '0') AND (ser_mode = '1')) ELSE
            mdc WHEN ((scan_mode = '0') AND (ser_mode = '0')) ELSE
            mdc;
   
END trans;



-- centrl_clk_ctl


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_rx_ctrl IS
   PORT (
      
      -- =======
      -- inputs
      -- =======
      soft_reset          : IN STD_LOGIC;
      clk_2               : IN STD_LOGIC;
      rx_rd_clk           : IN STD_LOGIC;		-- This replaces PLD_RX_CLK
      rx_wr_clk           : IN STD_LOGIC;		-- divided by 1 or 2 write clock.
      scan_mode           : IN STD_LOGIC;		-- scan enable
      rrxfifo_urst_en     : IN STD_LOGIC;		-- Enable rxfifo_urst
      rxfifo_urst         : IN STD_LOGIC;		-- User reset exclusive to rx_ctrl & below
      rrxphfifopldctl_en  : IN STD_LOGIC;		-- CRAM to enable PLD controlled write/read enable
      pld_wr_dis          : IN STD_LOGIC;		-- PLD write disable
      pld_re              : IN STD_LOGIC;		-- PLD read eanble
      dis_pc_byte         : IN STD_LOGIC;
      -- New MDIO for new bundling scheme and new PCIE features like autospeed
      rauto_speed_ena     : IN STD_LOGIC;
      
      -- =======
      -- outputs
      -- =======
      rx_we_out           : OUT STD_LOGIC;
      wr_enable_out       : OUT STD_LOGIC;
      rd_enable_out       : OUT STD_LOGIC
   );
END stratixiv_hssi_cmu_rx_ctrl;

ARCHITECTURE trans OF stratixiv_hssi_cmu_rx_ctrl IS
   
   -- reset signals
   SIGNAL local_soft_reset        : STD_LOGIC;		-- OR of local & global resets. 
   SIGNAL soft_reset_wclk0        : STD_LOGIC;
   SIGNAL soft_reset_wclk1_b4scan : STD_LOGIC;
   SIGNAL soft_reset_wclk1        : STD_LOGIC;		-- reset for fifo_wr_clk
   SIGNAL soft_reset_rclk0        : STD_LOGIC;
   SIGNAL soft_reset_rclk1_b4scan : STD_LOGIC;
   SIGNAL soft_reset_rclk1        : STD_LOGIC;		-- reset for pld_rx_clk
   
   -- Channel zero output should all channel rx_we_in of rx_ctrl
   
   SIGNAL rd_enable0              : STD_LOGIC;
   SIGNAL rd_enable0p5            : STD_LOGIC;
   SIGNAL rd_enable1              : STD_LOGIC;
   SIGNAL pld_wr_dis0             : STD_LOGIC;
   SIGNAL pld_wr_dis1             : STD_LOGIC;
   SIGNAL pld_wr_dis2             : STD_LOGIC;
   SIGNAL pld_wr_dis_edge         : STD_LOGIC;
   SIGNAL wr_enable0              : STD_LOGIC;
   SIGNAL wr_enable0p5            : STD_LOGIC;
   SIGNAL wr_enable1              : STD_LOGIC;
   SIGNAL wr_enable2              : STD_LOGIC;
   SIGNAL rxfifo_en_clk2_0        : STD_LOGIC;
   SIGNAL rxfifo_en_clk2_1        : STD_LOGIC;
   SIGNAL wr_enable_clk2          : STD_LOGIC;
   -- X-HDL generated signals

   SIGNAL xhdl1 : STD_LOGIC;
   SIGNAL xhdl2 : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL rx_we_out_xhdl0         : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   rx_we_out <= rx_we_out_xhdl0;
   
   local_soft_reset <= soft_reset OR (rrxfifo_urst_en AND rxfifo_urst);
   
   wr_enable_out <= wr_enable1;
   rd_enable_out <= rd_enable1;
   
   -- generate rx_wr_clk reset
   PROCESS (local_soft_reset, rx_wr_clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (local_soft_reset = '1') THEN
         soft_reset_wclk0 <=  TRANSPORT '1' AFTER 1* 1 ps;
         soft_reset_wclk1_b4scan <=  TRANSPORT '1' AFTER 1* 1 ps;
      ELSIF (rx_wr_clk'EVENT AND rx_wr_clk = '1') THEN
         soft_reset_wclk0 <=  TRANSPORT '0' AFTER 1* 1 ps;
         soft_reset_wclk1_b4scan <=  TRANSPORT soft_reset_wclk0 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   soft_reset_wclk1 <= '0' WHEN (scan_mode = '1') ELSE
                       soft_reset_wclk1_b4scan;
   
   -- generate pld_rx_clk reset
   PROCESS (local_soft_reset, rx_rd_clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (local_soft_reset = '1') THEN
         soft_reset_rclk0 <=  TRANSPORT '1' AFTER 1* 1 ps;
         soft_reset_rclk1_b4scan <=  TRANSPORT '1' AFTER 1* 1 ps;
      ELSIF (rx_rd_clk'EVENT AND rx_rd_clk = '1') THEN
         soft_reset_rclk0 <=  TRANSPORT '0' AFTER 1* 1 ps;
         soft_reset_rclk1_b4scan <=  TRANSPORT soft_reset_rclk0 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   soft_reset_rclk1 <= '0' WHEN (scan_mode = '1') ELSE
                       soft_reset_rclk1_b4scan;
   
   -- write enable, fifo data in
   xhdl1 <= (wr_enable0p5 AND NOT(pld_wr_dis_edge)) WHEN (rrxphfifopldctl_en = '1') ELSE
                       wr_enable0p5;
   PROCESS (rx_wr_clk, soft_reset_wclk1)
VARIABLE  txt : LINE;
   BEGIN
      IF (soft_reset_wclk1 = '1') THEN
         pld_wr_dis0 <=  TRANSPORT '0' AFTER 1* 1 ps;
         pld_wr_dis1 <=  TRANSPORT '0' AFTER 1* 1 ps;
         pld_wr_dis2 <=  TRANSPORT '0' AFTER 1* 1 ps;
         pld_wr_dis_edge <=  TRANSPORT '0' AFTER 1* 1 ps;
         wr_enable0 <=  TRANSPORT '0' AFTER 1* 1 ps;
         wr_enable0p5 <=  TRANSPORT '0' AFTER 1* 1 ps;
         wr_enable1 <=  TRANSPORT '0' AFTER 1* 1 ps;
         wr_enable2 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (rx_wr_clk'EVENT AND rx_wr_clk = '1') THEN
         pld_wr_dis0 <=  TRANSPORT pld_wr_dis AFTER 1* 1 ps;
         pld_wr_dis1 <=  TRANSPORT pld_wr_dis0 AFTER 1* 1 ps;
         pld_wr_dis2 <=  TRANSPORT pld_wr_dis1 AFTER 1* 1 ps;
         pld_wr_dis_edge <=  TRANSPORT int2bit((pld_wr_dis2 /= pld_wr_dis1)) AFTER 1* 1 ps;
         wr_enable0 <=  TRANSPORT NOT((rauto_speed_ena AND dis_pc_byte)) AFTER 1* 1 ps;
         wr_enable0p5 <=  TRANSPORT wr_enable0 AFTER 1* 1 ps;
         wr_enable1 <=  TRANSPORT xhdl1 AFTER 1* 1 ps;
         wr_enable2 <=  TRANSPORT wr_enable1 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   -- read enable
   xhdl2 <= (rd_enable0p5 AND pld_re) WHEN (rrxphfifopldctl_en = '1') ELSE
                 rd_enable0p5;
   PROCESS (rx_rd_clk, soft_reset_rclk1)
VARIABLE  txt : LINE;
   BEGIN
      IF (soft_reset_rclk1 = '1') THEN
         rd_enable0 <=  TRANSPORT '0' AFTER 1* 1 ps;
         rd_enable0p5 <=  TRANSPORT '0' AFTER 1* 1 ps;
         rd_enable1 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (rx_rd_clk'EVENT AND rx_rd_clk = '1') THEN
         rd_enable0 <=  TRANSPORT NOT((rauto_speed_ena AND dis_pc_byte)) AFTER 1* 1 ps;
         rd_enable0p5 <=  TRANSPORT rd_enable0 AFTER 1* 1 ps;
         rd_enable1 <=  TRANSPORT xhdl2 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   -- byte de-serializer high/low select
   PROCESS (clk_2, soft_reset)
VARIABLE  txt : LINE;
   BEGIN
      IF (soft_reset = '1') THEN
         rx_we_out_xhdl0 <=  TRANSPORT '1' AFTER 1* 1 ps;
         rxfifo_en_clk2_0 <=  TRANSPORT '0' AFTER 1* 1 ps;
         rxfifo_en_clk2_1 <=  TRANSPORT '0' AFTER 1* 1 ps;
         wr_enable_clk2 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (clk_2'EVENT AND clk_2 = '1') THEN
         --rxfifo_en_clk2_0 <=  rxfifo_en;
         -- rxfifo_en_clk2_0 <=  1'b1;
         rxfifo_en_clk2_0 <=  TRANSPORT NOT((rauto_speed_ena AND dis_pc_byte)) AFTER 1* 1 ps;
         
         rxfifo_en_clk2_1 <=  TRANSPORT rxfifo_en_clk2_0 AFTER 1* 1 ps;
         IF (rxfifo_en_clk2_1 = '0') THEN
            wr_enable_clk2 <=  TRANSPORT '0' AFTER 1* 1 ps;
         ELSIF (wr_enable_clk2 = '0') THEN
            
            wr_enable_clk2 <=  TRANSPORT wr_enable2 AFTER 1* 1 ps;
         END IF;
         IF (wr_enable_clk2 = '1') THEN
            rx_we_out_xhdl0 <=  TRANSPORT NOT(rx_we_out_xhdl0) AFTER 1* 1 ps;
         ELSE
            rx_we_out_xhdl0 <=  TRANSPORT '0' AFTER 1* 1 ps;
         END IF;
      END IF;
   END PROCESS;
   
END trans;




-- rx_ctrl_centrl

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_rxclk_gating IS
    PORT (
        
        select_n           : IN STD_LOGIC;
        clk1               : IN STD_LOGIC;
        clk2               : IN STD_LOGIC;
        clk1out_n          : OUT STD_LOGIC;
        clk2out_n          : OUT STD_LOGIC
    );
END ENTITY stratixiv_hssi_cmu_rxclk_gating;

ARCHITECTURE trans OF stratixiv_hssi_cmu_rxclk_gating IS
BEGIN
    
    clk1out_n <= NOT((select_n OR clk1));
    clk2out_n <= NOT((NOT(select_n) OR clk2));
    
END ARCHITECTURE trans;


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_rxclk_ctl IS
   PORT (
      
      -- Clock Inputs
      pld_rx_clk              : IN STD_LOGIC;		-- PLD clock from PLD clock trees
      rcvd_clk_pma            : IN STD_LOGIC;		-- local recovered clock
      rcvd_clk0_pma           : IN STD_LOGIC;		-- channel zero recovered clock
      tx_pma_clk              : IN STD_LOGIC;		-- local TX PMA clock
      refclk_pma              : IN STD_LOGIC;		-- Quad based clk from TXPLL
      fref                    : IN STD_LOGIC;
      clklow                  : IN STD_LOGIC;
      
      -- Control Inputs
      scan_mode               : IN STD_LOGIC;		-- Scan mode enable signal
      -- This is the soft_reset for the RX_PCS
      
      -- New Control Inputs
      gen2ngen1               : IN STD_LOGIC;		-- from PMA for PCIexp Gen1/Gen2 datawidth scaling
      gen2ngen1_bundle        : IN STD_LOGIC;		-- from PMA for PCIexp Gen1/Gen2 datawidth scaling in x4 and x8 
      rx_div2_sync_centrl     : IN STD_LOGIC;		-- divided clock from the central channel (x2, x4 mode)
      rx_div2_sync_quad_up    : IN STD_LOGIC;		-- divided clock from quad above (> x4 mode)
      rx_div2_sync_quad_down  : IN STD_LOGIC;		-- divided clock from quad below (> x4 mode)
      
      -- MDIO Inputs
      rrcvd_clk_sel           : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rclk_1_sel              : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rclk_2_sel              : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rrx_rd_clk_sel          : IN STD_LOGIC;		-- Select clock for rx ph comp fifo read side
      rxrst                   : IN STD_LOGIC;
      rindv_rx                : IN STD_LOGIC;		-- Select between XAUI mode or indiv  channel mode
      rdwidth_rx              : IN STD_LOGIC;		-- divide by 1 or 2 before feeding to FIFO write clock
      rfreerun_rx             : IN STD_LOGIC;		-- Select whether divider is permamently enabled (free -running) or divider should be enabled / reset by RX PCS reset
      
      -- New MDIO Inputs
      rauto_speed_ena         : IN STD_LOGIC;		-- auto speed negotiation enable
      rfreq_sel               : IN STD_LOGIC;		-- freq scaling or data width scaling
      rrxpcsclkpwdn           : IN STD_LOGIC;		-- RX clocking power down enable
      rmaster_rx              : IN STD_LOGIC;		-- New bundle mode MDIO, selects master quad
      rmaster_up_rx           : IN STD_LOGIC;		-- New bundle mode MDIO, selects master quad
      rself_sw_en_rx          : IN STD_LOGIC;		-- enables self-switch to have correct /2 clock in all quads in bundle mode
      
      -- Removed Inputs
      --    input          rphfifo_master_sel_rx;  // RX Phase comp. FIFO rx_div2_sync selection CRAM
      --    input          rx_div2_sync_in_ch0;    // Connect from channel zero rx_div2_sync_out
      --    input          rx_div2_sync_in_q0_ch0; // Connect from channel zero rx_div2_sync_out of Master Quad
      
      -- Clock Outputs with CTS
      fref_muxed              : OUT STD_LOGIC;
      clklow_muxed            : OUT STD_LOGIC;
      rcvd_clk                : OUT STD_LOGIC;
      clk_1_b                 : OUT STD_LOGIC;
      clk_2_b                 : OUT STD_LOGIC;
      rx_wr_clk               : OUT STD_LOGIC;		-- drives the rx ph comp fifo write clock tree
      rx_rd_clk               : OUT STD_LOGIC;		-- drives the rx ph comp fifo read clock tree
      
      -- Clock Outputs to PLD, no CTS
      rx_clk                  : OUT STD_LOGIC;		-- drives the PLD clock tree in x1 mode, logically same as rx_wr_clk
      rcvd_clk_pma_b          : OUT STD_LOGIC;		-- debug output clock to PLD
      
      -- New Clock Outputs with CTS
      clk_2_b_raw             : OUT STD_LOGIC;		-- same as clk_2_b, but with no clock gating
      rx_wr_clk_raw           : OUT STD_LOGIC;		-- same as rx_wr_clk, but with no clock gating
      rx_rd_clk_raw           : OUT STD_LOGIC;		-- same as rx_rd_clk, but with no clock gating
      
      -- Control Outputs
      rx_div2_sync_out        : OUT STD_LOGIC		-- inverted /2 clock.  not used w/new bundling scheme. (left for safety)
   );
END stratixiv_hssi_cmu_rxclk_ctl;

ARCHITECTURE trans OF stratixiv_hssi_cmu_rxclk_ctl IS
   COMPONENT stratixiv_hssi_cmu_rxclk_gating
        PORT (
            select_n                : IN STD_LOGIC;
            clk1                    : IN STD_LOGIC;
            clk2                    : IN STD_LOGIC;
            clk1out_n               : OUT STD_LOGIC;
            clk2out_n               : OUT STD_LOGIC
        );
    END COMPONENT;
      
   SIGNAL rx_clk_2_by2           : STD_LOGIC := '1';
   SIGNAL gen2ngen1_local_sync   : STD_LOGIC;
   SIGNAL counter                : STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   SIGNAL rx_div2_sync           : STD_LOGIC;
   SIGNAL rx_rst_n               : STD_LOGIC;
   SIGNAL rrcvd_clk_sel_int      : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rclk_1_sel_int         : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rclk_2_sel_int         : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL dynamic_div2ndiv1      : STD_LOGIC;
   SIGNAL gen2ngen1_local        : STD_LOGIC;
   SIGNAL rrxpcsclkpwdn_nscan    : STD_LOGIC;
   SIGNAL rx_div2_this_quad      : STD_LOGIC;
   SIGNAL rx_div2_this_channel   : STD_LOGIC;
   SIGNAL rx_div2_other_quad     : STD_LOGIC;
   SIGNAL force_master           : STD_LOGIC;
   
    SIGNAL select_div1_n          : STD_LOGIC;
    SIGNAL clk1out_n              : STD_LOGIC;
    SIGNAL clk2out_n              : STD_LOGIC;
    
   -- Declare intermediate signals for referenced outputs
   SIGNAL rx_wr_clk_xhdl3        : STD_LOGIC;
   SIGNAL clk_2_b_raw_xhdl0      : STD_LOGIC;
   SIGNAL rx_wr_clk_raw_xhdl4    : STD_LOGIC;
   SIGNAL rx_rd_clk_raw_xhdl2    : STD_LOGIC;
   SIGNAL rx_div2_sync_out_xhdl1 : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   rx_wr_clk <= rx_wr_clk_xhdl3;
   clk_2_b_raw <= clk_2_b_raw_xhdl0;
   rx_wr_clk_raw <= rx_wr_clk_raw_xhdl4;
   rx_rd_clk_raw <= rx_rd_clk_raw_xhdl2;
   rx_div2_sync_out <= rx_div2_sync_out_xhdl1;
   
   -- Old bundle logic:
   -- Select between the local synchronization signal or the global synchronization signal
   --assign rx_div2_sync = rindv_rx ? rx_div2_sync_out : rx_div2_sync_in;
   -- assign 	  rx_div2_sync = (rphfifo_master_sel_rx == 1'b0) ? rx_div2_sync_in_q0_ch0 :
   -- 				 (rindv_rx == 1'b0) ? rx_div2_sync_in_ch0 : 
   -- 				 (rauto_speed_ena & ~rfreq_sel) ? (rx_div2_sync_out | ~gen2ngen1_local_sync) : rx_div2_sync_out;
   
   PROCESS (rxrst, clk_2_b_raw_xhdl0)
VARIABLE  txt : LINE;
   BEGIN
      IF (rxrst = '1') THEN
         counter <=  TRANSPORT "00" AFTER 1* 1 ps;
      ELSIF (clk_2_b_raw_xhdl0'EVENT AND clk_2_b_raw_xhdl0 = '1') THEN
         IF (((rauto_speed_ena AND NOT(rfreq_sel) AND rself_sw_en_rx) AND NOT(force_master)) = '1') THEN
            counter <=  TRANSPORT counter + "01" AFTER 1* 1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   force_master <= '1' WHEN ((counter = "11") AND ((rauto_speed_ena AND NOT(rfreq_sel) AND rself_sw_en_rx) = '1')) ELSE
                   '0';
   
   rx_div2_sync <= rx_div2_this_quad WHEN ((rmaster_rx OR force_master) = '1') ELSE
                   rx_div2_other_quad;
   rx_div2_this_quad <= rx_div2_this_channel WHEN ((rindv_rx OR force_master) = '1') ELSE
                        rx_div2_sync_centrl;
   rx_div2_this_channel <= (rx_div2_sync_out_xhdl1 OR NOT(gen2ngen1_local_sync)) WHEN ((rauto_speed_ena AND NOT(rfreq_sel)) = '1') ELSE
                           rx_div2_sync_out_xhdl1;
   rx_div2_other_quad <= rx_div2_sync_quad_up WHEN (rmaster_up_rx = '1') ELSE
                         rx_div2_sync_quad_down;
   
   gen2ngen1_local <= gen2ngen1_bundle WHEN (rindv_rx = '0') ELSE
                      gen2ngen1;
   
   PROCESS (rxrst, clk_2_b_raw_xhdl0)
VARIABLE  txt : LINE;
   BEGIN
      IF (rxrst = '1') THEN
         gen2ngen1_local_sync <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (clk_2_b_raw_xhdl0'EVENT AND clk_2_b_raw_xhdl0 = '1') THEN
         gen2ngen1_local_sync <=  TRANSPORT gen2ngen1_local AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   dynamic_div2ndiv1 <= rdwidth_rx OR (gen2ngen1_local_sync AND rauto_speed_ena AND NOT(rfreq_sel));
   
   -- Reset for Divide-by-2 FF and synchronization FF's for clock gating
   rx_rst_n <= '1' WHEN (rfreerun_rx = '1') ELSE
               NOT(rxrst);
   
   rrxpcsclkpwdn_nscan <= rrxpcsclkpwdn AND NOT(scan_mode);
   
   -- clocks are assigned below in the order in which they appear in the out flowing data path
   -- RCVD_CLK selection
   rrcvd_clk_sel_int <= "01" WHEN (scan_mode = '1') ELSE
                        rrcvd_clk_sel;
   rcvd_clk <= '1' WHEN (rrxpcsclkpwdn_nscan = '1') ELSE
               rcvd_clk_pma WHEN (rrcvd_clk_sel_int = "00") ELSE
               refclk_pma WHEN (rrcvd_clk_sel_int = "01") ELSE
               tx_pma_clk WHEN (rrcvd_clk_sel_int = "10") ELSE
               rcvd_clk_pma WHEN (rrcvd_clk_sel_int = "11") ELSE
               rcvd_clk_pma;
   
   -- CLK_1 seleciton
   rclk_1_sel_int <= "01" WHEN (scan_mode = '1') ELSE
                     rclk_1_sel;
   clk_1_b <= '1' WHEN (rrxpcsclkpwdn_nscan = '1') ELSE
              rcvd_clk_pma WHEN (rclk_1_sel_int = "00") ELSE
              refclk_pma WHEN (rclk_1_sel_int = "01") ELSE
              tx_pma_clk WHEN (rclk_1_sel_int = "10") ELSE
              rcvd_clk0_pma WHEN (rclk_1_sel_int = "11") ELSE
              rcvd_clk_pma;
   
   -- CLK_2 selection
   rclk_2_sel_int <= "10" WHEN (scan_mode = '1') ELSE
                     rclk_2_sel;
   clk_2_b_raw_xhdl0 <= rcvd_clk_pma WHEN (rclk_2_sel_int = "00") ELSE
                        tx_pma_clk WHEN (rclk_2_sel_int = "01") ELSE
                        refclk_pma WHEN (rclk_2_sel_int = "10") ELSE
                        rcvd_clk_pma;
   --change made for S3GX to remove pld_rx_clk from mux input 
   --(rclk_2_sel_int == 2'b10) ? refclk_pma : 
   --(rclk_2_sel_int == 2'b11) ? pld_rx_clk : rcvd_clk_pma;
   
   clk_2_b <= '1' WHEN (rrxpcsclkpwdn_nscan = '1') ELSE
              clk_2_b_raw_xhdl0;
   
   -- This register is used to generate divided by two clock. Div by 2 clock starts off high after reset
   -- No #1 on this FF as it generates a clock
   PROCESS (rx_rst_n, clk_2_b_raw_xhdl0)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(rx_rst_n)) = '1') THEN
         rx_clk_2_by2 <= '1';
      ELSIF (clk_2_b_raw_xhdl0'EVENT AND clk_2_b_raw_xhdl0 = '1') THEN
         rx_clk_2_by2 <= rx_div2_sync;
      END IF;
   END PROCESS;
   
   rx_div2_sync_out_xhdl1 <= NOT(rx_clk_2_by2);
   
   -- RX FIFO write clock: could be fast or divided by 2
   -- old code:
   -- assign rx_wr_clk = ((rdwidth_rx == 1'b0) || scan_mode) ? clk_2_b_raw : rx_clk_2_by2;
   
   select_div1_n <= NOT((scan_mode OR NOT(dynamic_div2ndiv1)));
   
   rxclk_gating : stratixiv_hssi_cmu_rxclk_gating
      PORT MAP (
            select_n   => select_div1_n,
            clk1       => clk_2_b_raw_xhdl0,
            clk2       => rx_clk_2_by2,
            clk1out_n  => clk1out_n,
            clk2out_n  => clk2out_n
        );
    
   rx_wr_clk_raw_xhdl4 <= NOT((clk1out_n OR clk2out_n));
   
   rx_wr_clk_xhdl3 <= '1' WHEN (rrxpcsclkpwdn_nscan = '1') ELSE
                      rx_wr_clk_raw_xhdl4;
   
   -- RX FIFO read clock
   rx_rd_clk_raw_xhdl2 <= rx_wr_clk_raw_xhdl4 WHEN ((scan_mode OR int2bit((rrx_rd_clk_sel = '0'))) = '1') ELSE
                          pld_rx_clk;
   rx_rd_clk <= '1' WHEN (rrxpcsclkpwdn_nscan = '1') ELSE
                rx_rd_clk_raw_xhdl2;
   
   -- RX clock out
   rx_clk <= rx_wr_clk_xhdl3;		-- drives PLD clock tree
   
   -- Recovered clock for debugging
   rcvd_clk_pma_b <= rcvd_clk_pma;		-- Goes out to PLD as debug clock. This clock may or may not be routed out to PLD fabric. TBD
   
   fref_muxed <= refclk_pma WHEN (scan_mode = '1') ELSE
                 '1' WHEN (rrxpcsclkpwdn = '1') ELSE
                 fref;
   clklow_muxed <= refclk_pma WHEN (scan_mode = '1') ELSE
                   '1' WHEN (rrxpcsclkpwdn = '1') ELSE
                   clklow;
   
END trans;




-- rxclk_ctl_centrl


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_tx_ctrl IS
    PORT (
      
      -- ======
      -- inputs
      -- ======
      soft_reset          : IN STD_LOGIC;		-- Reset
      fifo_wr_clk         : IN STD_LOGIC;		-- Used to be wr_clk_pos
      fifo_rd_clk         : IN STD_LOGIC;		-- Coming from txclk_xg_ctl 
      refclk_b_in         : IN STD_LOGIC;		-- The local reference clock used by the internal
      scan_mode           : IN STD_LOGIC;		-- scan enable
      rtxfifo_urst_en     : IN STD_LOGIC;		-- user reset CRAM enable
      txfifo_urst         : IN STD_LOGIC;		-- user reset 
      rtxphfifopldctl_en  : IN STD_LOGIC;		-- CRAM to enable PLD controlled write/read enable
      pld_we              : IN STD_LOGIC;		-- PLD phase comp. fifo we, level active
      pld_rd_dis          : IN STD_LOGIC;		-- PLD phase comp. fifo rd dis, edge active
      dis_pc_byte         : IN STD_LOGIC;
      -- New MDIO for new bundling scheme and new PCIE features like autospeed
      rauto_speed_ena     : IN STD_LOGIC;
      
      -- =======
      -- outputs
      -- =======
      wr_enable_out       : OUT STD_LOGIC;		-- ch0 wr_enable1 output for X4/X8 mode
      rd_enable_out       : OUT STD_LOGIC;		-- ch0 rd_enable1 output for X4/X8 mode
      fifo_select_out     : OUT STD_LOGIC		-- New output for Rev.B 
   );
END stratixiv_hssi_cmu_tx_ctrl;

ARCHITECTURE trans OF stratixiv_hssi_cmu_tx_ctrl IS
   
   SIGNAL wr_enable0                 : STD_LOGIC;
   SIGNAL wr_enable0p5               : STD_LOGIC;
   SIGNAL wr_enable1                 : STD_LOGIC;
   SIGNAL rd_enable0                 : STD_LOGIC;
   SIGNAL rd_enable0p5               : STD_LOGIC;
   SIGNAL rd_enable1                 : STD_LOGIC;
   SIGNAL rd_enable2                 : STD_LOGIC;
   
   SIGNAL soft_reset_local           : STD_LOGIC;
   SIGNAL soft_reset_wclk0           : STD_LOGIC;
   SIGNAL soft_reset_wclk1_b4scan    : STD_LOGIC;
   SIGNAL soft_reset_wclk1           : STD_LOGIC;
   SIGNAL soft_reset_rclk0           : STD_LOGIC;
   SIGNAL soft_reset_rclk1_b4scan    : STD_LOGIC;
   SIGNAL soft_reset_rclk1           : STD_LOGIC;
   
   SIGNAL pld_rd_dis0                : STD_LOGIC;
   SIGNAL pld_rd_dis1                : STD_LOGIC;
   SIGNAL pld_rd_dis2                : STD_LOGIC;
   SIGNAL pld_rd_dis_edge            : STD_LOGIC;
   
   SIGNAL txfifo_en_refclk0          : STD_LOGIC;
   SIGNAL txfifo_en_refclk1          : STD_LOGIC;
   SIGNAL rd_enable_sync_refclk_b_in : STD_LOGIC;
   -- X-HDL generated signals

   SIGNAL xhdl1 : STD_LOGIC;
   SIGNAL xhdl2 : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL fifo_select_out_xhdl0      : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   fifo_select_out <= fifo_select_out_xhdl0;
   
   wr_enable_out <= wr_enable1;
   rd_enable_out <= rd_enable1;
   
   soft_reset_local <= soft_reset OR (rtxfifo_urst_en AND txfifo_urst);
   
   -- synchronize reset input (in refclk_b domain)
   PROCESS (soft_reset_local, fifo_wr_clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (soft_reset_local = '1') THEN
         soft_reset_wclk0 <=  TRANSPORT '1' AFTER 1* 1 ps;
         soft_reset_wclk1_b4scan <=  TRANSPORT '1' AFTER 1* 1 ps;
      ELSIF (fifo_wr_clk'EVENT AND fifo_wr_clk = '1') THEN
         soft_reset_wclk0 <=  TRANSPORT '0' AFTER 1* 1 ps;
         soft_reset_wclk1_b4scan <=  TRANSPORT soft_reset_wclk0 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   -- always @ (posedge soft_reset_local or posedge fifo_wr_clk)
   
   soft_reset_wclk1 <= '0' WHEN (scan_mode = '1') ELSE
                       soft_reset_wclk1_b4scan;
   
   -- synchronize reset input (in refclk_b domain) and balance it with fifo_wr_clk reset
   PROCESS (soft_reset_local, fifo_rd_clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (soft_reset_local = '1') THEN
         soft_reset_rclk0 <=  TRANSPORT '1' AFTER 1* 1 ps;
         soft_reset_rclk1_b4scan <=  TRANSPORT '1' AFTER 1* 1 ps;
      ELSIF (fifo_rd_clk'EVENT AND fifo_rd_clk = '1') THEN
         soft_reset_rclk0 <=  TRANSPORT '0' AFTER 1* 1 ps;
         soft_reset_rclk1_b4scan <=  TRANSPORT soft_reset_rclk0 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   -- always @ (posedge soft_reset_local or posedge fifo_rd_clk)
   
   soft_reset_rclk1 <= '0' WHEN (scan_mode = '1') ELSE
                       soft_reset_rclk1_b4scan;
   
   -- write enable
   xhdl1 <= (wr_enable0p5 AND pld_we) WHEN (rtxphfifopldctl_en = '1') ELSE
                       wr_enable0p5;
   PROCESS (soft_reset_wclk1, fifo_wr_clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (soft_reset_wclk1 = '1') THEN
         wr_enable0 <=  TRANSPORT '0' AFTER 1* 1 ps;
         wr_enable0p5 <=  TRANSPORT '0' AFTER 1* 1 ps;
         wr_enable1 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (fifo_wr_clk'EVENT AND fifo_wr_clk = '1') THEN
         wr_enable0 <=  TRANSPORT NOT((rauto_speed_ena AND dis_pc_byte)) AFTER 1* 1 ps;
         wr_enable0p5 <=  TRANSPORT wr_enable0 AFTER 1* 1 ps;
         wr_enable1 <=  TRANSPORT xhdl1 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   -- always @ (posedge soft_reset_wclk1 or posedge fifo_wr_clk)
   
   -- read enable & 
   -- read enable sync (for byte serializer output enable)
   
   xhdl2 <= (rd_enable0p5 AND NOT(pld_rd_dis_edge)) WHEN (rtxphfifopldctl_en = '1') ELSE
                 rd_enable0p5;
   PROCESS (soft_reset_rclk1, fifo_rd_clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (soft_reset_rclk1 = '1') THEN
         pld_rd_dis0 <=  TRANSPORT '0' AFTER 1* 1 ps;
         pld_rd_dis1 <=  TRANSPORT '0' AFTER 1* 1 ps;
         pld_rd_dis2 <=  TRANSPORT '0' AFTER 1* 1 ps;
         pld_rd_dis_edge <=  TRANSPORT '0' AFTER 1* 1 ps;
         rd_enable0 <=  TRANSPORT '0' AFTER 1* 1 ps;
         rd_enable0p5 <=  TRANSPORT '0' AFTER 1* 1 ps;
         rd_enable1 <=  TRANSPORT '0' AFTER 1* 1 ps;
         rd_enable2 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (fifo_rd_clk'EVENT AND fifo_rd_clk = '1') THEN
         pld_rd_dis0 <=  TRANSPORT pld_rd_dis AFTER 1* 1 ps;
         pld_rd_dis1 <=  TRANSPORT pld_rd_dis0 AFTER 1* 1 ps;
         pld_rd_dis2 <=  TRANSPORT pld_rd_dis1 AFTER 1* 1 ps;
         pld_rd_dis_edge <=  TRANSPORT int2bit((pld_rd_dis2 /= pld_rd_dis1)) AFTER 1* 1 ps;
         rd_enable0 <=  TRANSPORT NOT((rauto_speed_ena AND dis_pc_byte)) AFTER 1* 1 ps;
         rd_enable0p5 <=  TRANSPORT rd_enable0 AFTER 1* 1 ps;
         rd_enable1 <=  TRANSPORT xhdl2 AFTER 1* 1 ps;
         
         rd_enable2 <=  TRANSPORT rd_enable1 AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   -- always @ (posedge soft_reset_rclk1 or posedge fifo_rd_clk)
   
   -- byte serializer high/low select
   PROCESS (soft_reset, refclk_b_in)
VARIABLE  txt : LINE;
   BEGIN
      IF (soft_reset = '1') THEN
         rd_enable_sync_refclk_b_in <=  TRANSPORT '0' AFTER 1* 1 ps;
         txfifo_en_refclk0 <=  TRANSPORT '0' AFTER 1* 1 ps;
         txfifo_en_refclk1 <=  TRANSPORT '0' AFTER 1* 1 ps;
         fifo_select_out_xhdl0 <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (refclk_b_in'EVENT AND refclk_b_in = '1') THEN
         txfifo_en_refclk0 <=  TRANSPORT NOT((rauto_speed_ena AND dis_pc_byte)) AFTER 1* 1 ps;
         
         txfifo_en_refclk1 <=  TRANSPORT txfifo_en_refclk0 AFTER 1* 1 ps;
         IF (txfifo_en_refclk1 = '0') THEN
            rd_enable_sync_refclk_b_in <=  TRANSPORT '0' AFTER 1* 1 ps;
         ELSIF (rd_enable_sync_refclk_b_in = '0') THEN
            
            rd_enable_sync_refclk_b_in <=  TRANSPORT rd_enable2 AFTER 1* 1 ps;
         END IF;
         IF (rd_enable_sync_refclk_b_in = '1') THEN
            fifo_select_out_xhdl0 <=  TRANSPORT NOT(fifo_select_out_xhdl0) AFTER 1* 1 ps;
         ELSE
            fifo_select_out_xhdl0 <=  TRANSPORT '0' AFTER 1* 1 ps;
         END IF;
      END IF;
   END PROCESS;
   
END trans;


-- always @ (posedge soft_reset or posedge refclk_b_in)


-- tx_ctrl_centrl

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_txclk_gating IS
    PORT (
        
        select_n                : IN STD_LOGIC;
        clk1                    : IN STD_LOGIC;
        clk2                    : IN STD_LOGIC;
        clk1out_n               : OUT STD_LOGIC;
        clk2out_n               : OUT STD_LOGIC
    );
END ENTITY stratixiv_hssi_cmu_txclk_gating;

ARCHITECTURE trans OF stratixiv_hssi_cmu_txclk_gating IS
BEGIN
    
    clk1out_n <= NOT((select_n OR clk1));
    clk2out_n <= NOT((NOT(select_n) OR clk2));
    
END ARCHITECTURE trans;

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_txclk_ctl IS
   PORT (
      
      -- Clock Inputs
      pld_tx_clk              : IN STD_LOGIC;		-- PLD clock from PLD clock trees, the transmit clock from XGMII.
      refclk_pma              : IN STD_LOGIC;		-- Quad based clk from TXPLL
      txpma_local_clk         : IN STD_LOGIC;		-- Local channel TX PMA clock.
      
      -- Control Inputs
      txrst                   : IN STD_LOGIC;		-- reset for the tx_pcs
      scan_mode               : IN STD_LOGIC;		-- Scan mode enable signal for selecting scan_clk from refclk_pma
      
      -- New Control Inputs
      gen2ngen1               : IN STD_LOGIC;		-- from PMA for PCIexp Gen1/Gen2 datawidth scaling
      gen2ngen1_bundle        : IN STD_LOGIC;		-- from PMA for PCIexp Gen1/Gen2 datawidth scaling in x4 and x8
      tx_div2_sync_centrl     : IN STD_LOGIC;		-- divided clock from the central channel (x2, x4 mode)
      tx_div2_sync_quad_up    : IN STD_LOGIC;		-- divided clock from quad above (> x4 mode)
      tx_div2_sync_quad_down  : IN STD_LOGIC;		-- divided clock from quad below (> x4 mode)
      
      -- MDIO Inputs
      rindv_tx                : IN STD_LOGIC;		-- Selects between indiv chan. mode and bundled mode
      rtxwrclksel             : IN STD_LOGIC;		-- Selects which clock writes into FIFO
      rtxrdclksel             : IN STD_LOGIC;		-- Selects which clock reads from FIFO and also clocks reest of TX logic
      rdwidth_tx              : IN STD_LOGIC;		-- divide by 1 or 2 before feeding to FIFO read clock
      rfreerun_tx             : IN STD_LOGIC;		-- Select whether divider is permamently enabled (free -running) or  divider should be enabled / reset by TX PCS reset  
      
      -- New MDIO Inputs
      rauto_speed_ena         : IN STD_LOGIC;		-- auto speed negotiation enable
      rfreq_sel               : IN STD_LOGIC;		-- freq scaling or data width scaling
      rtxpcsclkpwdn           : IN STD_LOGIC;		-- TX clocking power down enable
      rmaster_tx              : IN STD_LOGIC;		-- New bundle mode MDIO, selects master quad
      rmaster_up_tx           : IN STD_LOGIC;		-- New bundle mode MDIO, selects master quad
      rself_sw_en_tx          : IN STD_LOGIC;		-- enables self-switch to have correct /2 clock in all quads in bundle mode
      
      -- Removed Inputs
      -- input        tx_div2_sync_in_ch0;    // from the channel zero tx_div2_sync_out
      -- input        tx_div2_sync_in_q0_ch0; // From channel0 of Master Quad
      -- input        rphfifo_master_sel_tx;  // TX Phase comp. FIFO tx_div2_sync selection CRAM
      
      -- Clock Outputs wtih CTS
      refclk_b                : OUT STD_LOGIC;		-- Drives the tx channel clock
      wr_clk_pos              : OUT STD_LOGIC;		-- Drives tx phase comp fifo write side
      fifo_rd_clk             : OUT STD_LOGIC;		-- Drives tx phase comp fifo read side
      
      -- Clock Outputs to PLD, w/o CTS
      tx_clk_out              : OUT STD_LOGIC;		-- Drives to the PLD clock tree -- unconnected
      
      -- New Clock Outputs with CTS
      refclk_b_raw            : OUT STD_LOGIC;		-- same as refclk_b, but with no clock gating
      wr_clk_pos_raw          : OUT STD_LOGIC;		-- same as wr_clk_pos, but with no clock gating
      fifo_rd_clk_raw         : OUT STD_LOGIC;		-- same as fifo_rd_clk, but with no clock gating
      
      -- Control Outputs
      tx_div2_sync_out        : OUT STD_LOGIC		-- Synchronizes the divided by two clock
   );
END stratixiv_hssi_cmu_txclk_ctl;

ARCHITECTURE trans OF stratixiv_hssi_cmu_txclk_ctl IS
    COMPONENT stratixiv_hssi_cmu_txclk_gating IS
        PORT (
            select_n                : IN STD_LOGIC;
            clk1                    : IN STD_LOGIC;
            clk2                    : IN STD_LOGIC;
            clk1out_n               : OUT STD_LOGIC;
            clk2out_n               : OUT STD_LOGIC
        );
    END COMPONENT;
      
   SIGNAL fifo_rd_clk_by2        : STD_LOGIC := '1';
   SIGNAL gen2ngen1_local_sync   : STD_LOGIC;
   SIGNAL counter                : STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   SIGNAL tx_rst_n               : STD_LOGIC;
   SIGNAL tx_div2_sync           : STD_LOGIC;
   SIGNAL dynamic_div2ndiv1      : STD_LOGIC;
   SIGNAL gen2ngen1_local        : STD_LOGIC;
   SIGNAL tx_div2_this_quad      : STD_LOGIC;
   SIGNAL tx_div2_this_channel   : STD_LOGIC;
   SIGNAL tx_div2_other_quad     : STD_LOGIC;
   SIGNAL force_master           : STD_LOGIC;
   SIGNAL rtxpcsclkpwdn_nscan    : STD_LOGIC;
    
    SIGNAL select_div1_n          : STD_LOGIC;
    SIGNAL clk1out_n              : STD_LOGIC;
    SIGNAL clk2out_n              : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL fifo_rd_clk_xhdl0      : STD_LOGIC;
   SIGNAL refclk_b_raw_xhdl2     : STD_LOGIC;
   SIGNAL wr_clk_pos_raw_xhdl4   : STD_LOGIC;
   SIGNAL fifo_rd_clk_raw_xhdl1  : STD_LOGIC;
   SIGNAL tx_div2_sync_out_xhdl3 : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   fifo_rd_clk <= fifo_rd_clk_xhdl0;
   refclk_b_raw <= refclk_b_raw_xhdl2;
   wr_clk_pos_raw <= wr_clk_pos_raw_xhdl4;
   fifo_rd_clk_raw <= fifo_rd_clk_raw_xhdl1;
   tx_div2_sync_out <= tx_div2_sync_out_xhdl3;
   
   
   -- Old bundle logic:   
   -- Select between the local synchronization signal or the global synchronization signal (either from Channel0 or 
   -- Channel0 of Master Quad
   --assign tx_div2_sync = rindv_tx ? tx_div2_sync_out : tx_div2_sync_in;
   -- assign 	tx_div2_sync = (rphfifo_master_sel_tx == 1'b0) ? tx_div2_sync_in_q0_ch0 :
   --                            (rindv_tx == 1'b0) ? tx_div2_sync_in_ch0 : 
   --                            (rauto_speed_ena & ~rfreq_sel) ? (tx_div2_sync_out | ~gen2ngen1_local_sync) : tx_div2_sync_out;
   --
   
   PROCESS (txrst, refclk_b_raw_xhdl2)
VARIABLE  txt : LINE;
   BEGIN
      IF (txrst = '1') THEN
         counter <=  TRANSPORT "00" AFTER 1* 1 ps;
      ELSIF (refclk_b_raw_xhdl2'EVENT AND refclk_b_raw_xhdl2 = '1') THEN
         IF (((rauto_speed_ena AND NOT(rfreq_sel) AND rself_sw_en_tx) AND NOT(force_master)) = '1') THEN
            counter <=  TRANSPORT counter + "01" AFTER 1* 1 ps;
         END IF;
      END IF;
   END PROCESS;
   
   force_master <= '1' WHEN ((counter = "11") AND ((rauto_speed_ena AND NOT(rfreq_sel) AND rself_sw_en_tx) = '1')) ELSE
                   '0';
   
   tx_div2_sync <= tx_div2_this_quad WHEN ((rmaster_tx OR force_master) = '1') ELSE
                   tx_div2_other_quad;
   tx_div2_this_quad <= tx_div2_this_channel WHEN ((rindv_tx OR force_master) = '1') ELSE
                        tx_div2_sync_centrl;
   tx_div2_this_channel <= (tx_div2_sync_out_xhdl3 OR NOT(gen2ngen1_local_sync)) WHEN ((rauto_speed_ena AND NOT(rfreq_sel)) = '1') ELSE
                           tx_div2_sync_out_xhdl3;
   tx_div2_other_quad <= tx_div2_sync_quad_up WHEN (rmaster_up_tx = '1') ELSE
                         tx_div2_sync_quad_down;
   
   gen2ngen1_local <= gen2ngen1_bundle WHEN (rindv_tx = '0') ELSE
                      gen2ngen1;
   
   PROCESS (txrst, refclk_b_raw_xhdl2)
VARIABLE  txt : LINE;
   BEGIN
      IF (txrst = '1') THEN
         gen2ngen1_local_sync <=  TRANSPORT '0' AFTER 1* 1 ps;
      ELSIF (refclk_b_raw_xhdl2'EVENT AND refclk_b_raw_xhdl2 = '1') THEN
         gen2ngen1_local_sync <=  TRANSPORT gen2ngen1_local AFTER 1* 1 ps;
      END IF;
   END PROCESS;
   
   dynamic_div2ndiv1 <= rdwidth_tx OR (gen2ngen1_local_sync AND rauto_speed_ena AND NOT(rfreq_sel));
   
   -- Reset for Divide-by-2 FF
   tx_rst_n <= '1' WHEN (rfreerun_tx = '1') ELSE
               NOT(txrst);
   
   rtxpcsclkpwdn_nscan <= rtxpcsclkpwdn AND NOT(scan_mode);
   
   -- Full speed clock for TX PCS
   refclk_b_raw_xhdl2 <= refclk_pma WHEN ((scan_mode OR rtxrdclksel) = '1') ELSE
                         txpma_local_clk;
   
   refclk_b <= '1' WHEN (rtxpcsclkpwdn_nscan = '1') ELSE
               refclk_b_raw_xhdl2;
   
   -- Divide-by-2 FF
   PROCESS (tx_rst_n, refclk_b_raw_xhdl2)
VARIABLE  txt : LINE;
   BEGIN
      IF ((NOT(tx_rst_n)) = '1') THEN
         fifo_rd_clk_by2 <= '1';
      ELSIF (refclk_b_raw_xhdl2'EVENT AND refclk_b_raw_xhdl2 = '1') THEN
         fifo_rd_clk_by2 <= tx_div2_sync;		-- local divided clock
      END IF;
   END PROCESS;
   
   tx_div2_sync_out_xhdl3 <= NOT(fifo_rd_clk_by2);
   
   -- TX FIFO read clock: could be fast or divided by 2
   -- old code:
   -- assign fifo_rd_clk = ((rdwidth_tx == 1'b0) || scan_mode) ? refclk_b_raw : fifo_rd_clk_by2;
   
    select_div1_n <= NOT((scan_mode OR NOT(dynamic_div2ndiv1)));
    
    txclk_gating : stratixiv_hssi_cmu_txclk_gating
        PORT MAP (
            select_n   => select_div1_n,
            clk1       => refclk_b_raw_xhdl2,
            clk2       => fifo_rd_clk_by2,
            clk1out_n  => clk1out_n,
            clk2out_n  => clk2out_n
        );
    
   fifo_rd_clk_raw_xhdl1 <= NOT((clk1out_n OR clk2out_n));
      
   fifo_rd_clk_xhdl0 <= '1' WHEN (rtxpcsclkpwdn_nscan = '1') ELSE
                        fifo_rd_clk_raw_xhdl1;
   
   -- TX FIFO write clock: used internal clock when in BIST or scan or HIP
   wr_clk_pos_raw_xhdl4 <= fifo_rd_clk_raw_xhdl1 WHEN ((scan_mode OR rtxwrclksel) = '1') ELSE
                           pld_tx_clk;
   wr_clk_pos <= '1' WHEN (rtxpcsclkpwdn_nscan = '1') ELSE
                 wr_clk_pos_raw_xhdl4;
   
   -- TX Clock Out
   tx_clk_out <= fifo_rd_clk_xhdl0;		-- drives PLD clock tree
   
END trans;




-- txclk_ctl_cenrtl


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_dprio_bit IS
   PORT (
      
      reset        : IN STD_LOGIC;		-- reset
      clk          : IN STD_LOGIC;		-- clock
      sig_in       : IN STD_LOGIC;		-- signal input
      ext_in       : IN STD_LOGIC;		-- external input port
      serial_mode  : IN STD_LOGIC;		-- serial shift mode enable  
      si           : IN STD_LOGIC;		-- scan input
      shift        : IN STD_LOGIC;		-- 1'b1=shift in data from si into scan flop
      -- 1'b0=load data from sig_in into scan flop
      mdio_dis     : IN STD_LOGIC;		-- 1'b1=choose ext_in to the sig_out mux
      -- 1'b0=choose so to the sign_out mux
      sig_out      : OUT STD_LOGIC;		-- signal output
      so           : OUT STD_LOGIC		-- scan output
   );
END stratixiv_hssi_cmu_dprio_bit;

ARCHITECTURE trans OF stratixiv_hssi_cmu_dprio_bit IS
   
   SIGNAL cram_int : STD_LOGIC;
   SIGNAL set_int  : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL so_xhdl0 : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   so <= so_xhdl0;
   
   -- select signal output
   sig_out <= (so_xhdl0 AND NOT(shift)) WHEN (serial_mode = '1') ELSE
              (cram_int);
   cram_int <= (ext_in) WHEN (mdio_dis = '1') ELSE
               (so_xhdl0);
   
   -- Set signal for the flop
   set_int <= '0' WHEN (shift = '1' OR reset = '1') ELSE
              ext_in;
   
   -- scan flop
   PROCESS (reset, set_int, clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         so_xhdl0 <= '0';
      ELSIF (set_int = '1') THEN
         so_xhdl0 <= '1';
      ELSIF (clk'EVENT AND clk = '1') THEN
         IF ((shift AND serial_mode) = '1') THEN
            so_xhdl0 <= si;
         ELSE
            
            so_xhdl0 <= sig_in;
         END IF;
      END IF;
   END PROCESS;
   
END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_dprio_bit_pma IS
   PORT (
      
      reset          : IN STD_LOGIC;		-- reset
      clk            : IN STD_LOGIC;		-- clock
      sig_in         : IN STD_LOGIC;		-- signal input
      ext_in         : IN STD_LOGIC;		-- external input port
      serial_mode    : IN STD_LOGIC;		-- serial shift mode enable  
      si             : IN STD_LOGIC;		-- scan input
      shift          : IN STD_LOGIC;		-- 1'b1=shift in data from si into scan flop
      -- 1'b0=load data from sig_in into scan flop
      mdio_dis       : IN STD_LOGIC;		-- 1'b1=choose ext_in to the sig_out mux
      -- 1'b0=choose so to the sign_out mux
      pma_cram_test  : IN STD_LOGIC;		--1'b1: choose the previous output of this register
      --1'b0: choose either si or input from DPRIO SM (sig_in)
      sig_out        : OUT STD_LOGIC;		-- signal output
      so             : OUT STD_LOGIC		-- scan output
   );
END stratixiv_hssi_cmu_dprio_bit_pma;

ARCHITECTURE trans OF stratixiv_hssi_cmu_dprio_bit_pma IS
   
   SIGNAL cram_int      : STD_LOGIC;
   SIGNAL set_int       : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL sig_out_xhdl0 : STD_LOGIC;
   SIGNAL so_xhdl1      : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   sig_out <= sig_out_xhdl0;
   so <= so_xhdl1;
   
   -- select signal output
   sig_out_xhdl0 <= (so_xhdl1 AND NOT(shift)) WHEN (serial_mode = '1') ELSE
                    (cram_int);
   cram_int <= (ext_in) WHEN (mdio_dis = '1') ELSE
               (so_xhdl1);
   
   -- Set signal for the flop
   set_int <= '0' WHEN (shift = '1'OR reset = '1') ELSE
              ext_in;
   
   -- scan flop
   PROCESS (reset, set_int, clk)
VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         so_xhdl1 <= '0';
      ELSIF (set_int = '1') THEN
         so_xhdl1 <= '1';
      ELSIF (clk'EVENT AND clk = '1') THEN
         IF (pma_cram_test = '1') THEN
            so_xhdl1 <= sig_out_xhdl0;
         ELSIF ((shift AND serial_mode) = '1') THEN
            so_xhdl1 <= si;
         ELSE
            
            so_xhdl1 <= sig_in;
         END IF;
      END IF;
   END PROCESS;
   
END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_dprio_16bit IS
   PORT (
      
      reset        : IN STD_LOGIC;		-- reset
      mdio_wr      : IN STD_LOGIC;
      reg_addr     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      target_addr  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      clk          : IN STD_LOGIC;		-- clock
      sig_in       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);		-- signal input
      ext_in       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);		-- external port input
      serial_mode  : IN STD_LOGIC;		-- serial shift mode enable  
      si           : IN STD_LOGIC;		-- scan input
      shift        : IN STD_LOGIC;		-- 1'b1=shift in data from si into scan flop
      -- 1'b0=load data from sig_in into scan flop
      mdio_dis     : IN STD_LOGIC;		--
      -- 1'b1=output CRAM
      -- 1'b0=output MDIO control register
      sig_out      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);		-- signal output
      so           : OUT STD_LOGIC		-- scan output
   );
END stratixiv_hssi_cmu_dprio_16bit;

ARCHITECTURE trans OF stratixiv_hssi_cmu_dprio_16bit IS
   COMPONENT stratixiv_hssi_cmu_dprio_bit
      PORT (
         reset        : IN STD_LOGIC;
         clk          : IN STD_LOGIC;
         sig_in       : IN STD_LOGIC;
         ext_in       : IN STD_LOGIC;
         serial_mode  : IN STD_LOGIC;
         si           : IN STD_LOGIC;
         shift        : IN STD_LOGIC;
         mdio_dis     : IN STD_LOGIC;
         sig_out      : OUT STD_LOGIC;
         so           : OUT STD_LOGIC
      );
   END COMPONENT;
   
   
   SIGNAL signal_in_int : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL chain         : STD_LOGIC_VECTOR(14 DOWNTO 0);
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL sig_out_xhdl0 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL so_xhdl1      : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   sig_out <= sig_out_xhdl0;
   so <= so_xhdl1;
   
   signal_in_int <= sig_in WHEN ((("000000000000000" & mdio_wr) AND int2bin((reg_addr = target_addr), 16)) /= "0000000000000000") ELSE
                    (so_xhdl1 & chain);
   
   
   
   ctrl_reg_bit_0 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(0),
         ext_in       => ext_in(0),
         serial_mode  => serial_mode,
         si           => si,
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(0),
         so           => chain(0)
      );
   
   
   
   ctrl_reg_bit_1 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(1),
         ext_in       => ext_in(1),
         serial_mode  => serial_mode,
         si           => chain(0),
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(1),
         so           => chain(1)
      );
   
   
   
   ctrl_reg_bit_2 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(2),
         ext_in       => ext_in(2),
         serial_mode  => serial_mode,
         si           => chain(1),
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(2),
         so           => chain(2)
      );
   
   
   
   ctrl_reg_bit_3 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(3),
         ext_in       => ext_in(3),
         serial_mode  => serial_mode,
         si           => chain(2),
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(3),
         so           => chain(3)
      );
   
   
   
   ctrl_reg_bit_4 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(4),
         ext_in       => ext_in(4),
         serial_mode  => serial_mode,
         si           => chain(3),
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(4),
         so           => chain(4)
      );
   
   
   
   ctrl_reg_bit_5 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(5),
         ext_in       => ext_in(5),
         serial_mode  => serial_mode,
         si           => chain(4),
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(5),
         so           => chain(5)
      );
   
   
   
   ctrl_reg_bit_6 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(6),
         ext_in       => ext_in(6),
         serial_mode  => serial_mode,
         si           => chain(5),
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(6),
         so           => chain(6)
      );
   
   
   
   ctrl_reg_bit_7 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(7),
         ext_in       => ext_in(7),
         serial_mode  => serial_mode,
         si           => chain(6),
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(7),
         so           => chain(7)
      );
   
   
   
   ctrl_reg_bit_8 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(8),
         ext_in       => ext_in(8),
         serial_mode  => serial_mode,
         si           => chain(7),
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(8),
         so           => chain(8)
      );
   
   
   
   ctrl_reg_bit_9 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(9),
         ext_in       => ext_in(9),
         serial_mode  => serial_mode,
         si           => chain(8),
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(9),
         so           => chain(9)
      );
   
   
   
   ctrl_reg_bit_10 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(10),
         ext_in       => ext_in(10),
         serial_mode  => serial_mode,
         si           => chain(9),
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(10),
         so           => chain(10)
      );
   
   
   
   ctrl_reg_bit_11 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(11),
         ext_in       => ext_in(11),
         serial_mode  => serial_mode,
         si           => chain(10),
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(11),
         so           => chain(11)
      );
   
   
   
   ctrl_reg_bit_12 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(12),
         ext_in       => ext_in(12),
         serial_mode  => serial_mode,
         si           => chain(11),
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(12),
         so           => chain(12)
      );
   
   
   
   ctrl_reg_bit_13 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(13),
         ext_in       => ext_in(13),
         serial_mode  => serial_mode,
         si           => chain(12),
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(13),
         so           => chain(13)
      );
   
   
   
   ctrl_reg_bit_14 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(14),
         ext_in       => ext_in(14),
         serial_mode  => serial_mode,
         si           => chain(13),
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(14),
         so           => chain(14)
      );
   
   
   
   ctrl_reg_bit_15 : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => reset,
         clk          => clk,
         sig_in       => signal_in_int(15),
         ext_in       => ext_in(15),
         serial_mode  => serial_mode,
         si           => chain(14),
         shift        => shift,
         mdio_dis     => mdio_dis,
         sig_out      => sig_out_xhdl0(15),
         so           => so_xhdl1
      );
   
END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_dprio_16bit_pma IS
   PORT (
      
      reset          : IN STD_LOGIC;		-- reset
      mdio_wr        : IN STD_LOGIC;
      reg_addr       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      target_addr    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      clk            : IN STD_LOGIC;		-- clock
      sig_in         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);		-- signal input
      ext_in         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);		-- external port input
      serial_mode    : IN STD_LOGIC;		-- serial shift mode enable  
      si             : IN STD_LOGIC;		-- scan input
      shift          : IN STD_LOGIC;		-- 1'b1=shift in data from si into scan flop
      -- 1'b0=load data from sig_in into scan flop
      mdio_dis       : IN STD_LOGIC;		--
      -- 1'b1=output CRAM
      -- 1'b0=output MDIO control register
      pma_cram_test  : IN STD_LOGIC;		--1'b1: choose the previous output of this register
      --1'b0: choose either si or input from DPRIO SM (sig_in)
      sig_out        : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);		-- signal output
      so             : OUT STD_LOGIC		-- scan output
   );
END stratixiv_hssi_cmu_dprio_16bit_pma;

ARCHITECTURE trans OF stratixiv_hssi_cmu_dprio_16bit_pma IS
   COMPONENT stratixiv_hssi_cmu_dprio_bit_pma
      PORT (
         reset          : IN STD_LOGIC;
         clk            : IN STD_LOGIC;
         sig_in         : IN STD_LOGIC;
         ext_in         : IN STD_LOGIC;
         serial_mode    : IN STD_LOGIC;
         si             : IN STD_LOGIC;
         shift          : IN STD_LOGIC;
         mdio_dis       : IN STD_LOGIC;
         pma_cram_test  : IN STD_LOGIC;
         sig_out        : OUT STD_LOGIC;
         so             : OUT STD_LOGIC
      );
   END COMPONENT;
   
   
   SIGNAL signal_in_int : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL chain         : STD_LOGIC_VECTOR(14 DOWNTO 0);
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL sig_out_xhdl0 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL so_xhdl1      : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   sig_out <= sig_out_xhdl0;
   so <= so_xhdl1;
   
   signal_in_int <= sig_in WHEN ((("000000000000000" & mdio_wr) AND int2bin((reg_addr = target_addr), 16)) /= "0000000000000000") ELSE
                    (so_xhdl1 & chain);
   
   
   
   ctrl_reg_bit_pma_0 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(0),
         ext_in         => ext_in(0),
         serial_mode    => serial_mode,
         si             => si,
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(0),
         so             => chain(0)
      );
   
   
   
   ctrl_reg_bit_pma_1 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(1),
         ext_in         => ext_in(1),
         serial_mode    => serial_mode,
         si             => chain(0),
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(1),
         so             => chain(1)
      );
   
   
   
   ctrl_reg_bit_pma_2 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(2),
         ext_in         => ext_in(2),
         serial_mode    => serial_mode,
         si             => chain(1),
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(2),
         so             => chain(2)
      );
   
   
   
   ctrl_reg_bit_pma_3 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(3),
         ext_in         => ext_in(3),
         serial_mode    => serial_mode,
         si             => chain(2),
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(3),
         so             => chain(3)
      );
   
   
   
   ctrl_reg_bit_pma_4 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(4),
         ext_in         => ext_in(4),
         serial_mode    => serial_mode,
         si             => chain(3),
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(4),
         so             => chain(4)
      );
   
   
   
   ctrl_reg_bit_pma_5 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(5),
         ext_in         => ext_in(5),
         serial_mode    => serial_mode,
         si             => chain(4),
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(5),
         so             => chain(5)
      );
   
   
   
   ctrl_reg_bit_pma_6 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(6),
         ext_in         => ext_in(6),
         serial_mode    => serial_mode,
         si             => chain(5),
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(6),
         so             => chain(6)
      );
   
   
   
   ctrl_reg_bit_pma_7 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(7),
         ext_in         => ext_in(7),
         serial_mode    => serial_mode,
         si             => chain(6),
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(7),
         so             => chain(7)
      );
   
   
   
   ctrl_reg_bit_pma_8 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(8),
         ext_in         => ext_in(8),
         serial_mode    => serial_mode,
         si             => chain(7),
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(8),
         so             => chain(8)
      );
   
   
   
   ctrl_reg_bit_pma_9 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(9),
         ext_in         => ext_in(9),
         serial_mode    => serial_mode,
         si             => chain(8),
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(9),
         so             => chain(9)
      );
   
   
   
   ctrl_reg_bit_pma_10 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(10),
         ext_in         => ext_in(10),
         serial_mode    => serial_mode,
         si             => chain(9),
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(10),
         so             => chain(10)
      );
   
   
   
   ctrl_reg_bit_pma_11 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(11),
         ext_in         => ext_in(11),
         serial_mode    => serial_mode,
         si             => chain(10),
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(11),
         so             => chain(11)
      );
   
   
   
   ctrl_reg_bit_pma_12 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(12),
         ext_in         => ext_in(12),
         serial_mode    => serial_mode,
         si             => chain(11),
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(12),
         so             => chain(12)
      );
   
   
   
   ctrl_reg_bit_pma_13 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(13),
         ext_in         => ext_in(13),
         serial_mode    => serial_mode,
         si             => chain(12),
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(13),
         so             => chain(13)
      );
   
   
   
   ctrl_reg_bit_pma_14 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(14),
         ext_in         => ext_in(14),
         serial_mode    => serial_mode,
         si             => chain(13),
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(14),
         so             => chain(14)
      );
   
   
   
   ctrl_reg_bit_pma_15 : stratixiv_hssi_cmu_dprio_bit_pma
      PORT MAP (
         reset          => reset,
         clk            => clk,
         sig_in         => signal_in_int(15),
         ext_in         => ext_in(15),
         serial_mode    => serial_mode,
         si             => chain(14),
         shift          => shift,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => sig_out_xhdl0(15),
         so             => so_xhdl1
      );
   
END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_dprio_reg_chnl IS
   PORT (
      -- CSR input
      -- DPRIO register output
      
      mdio_rst           : IN STD_LOGIC;
      mdio_wr            : IN STD_LOGIC;
      reg_addr           : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      mdc                : IN STD_LOGIC;
      mbus_in            : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      serial_mode        : IN STD_LOGIC;
      mdio_dis           : IN STD_LOGIC;
      pma_cram_test      : IN STD_LOGIC;
      ser_shift_load     : IN STD_LOGIC;
      si                 : IN STD_LOGIC;
      ext_chnl_ctrl_1    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_2    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_3    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_4    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_5    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_6    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_7    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_8    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_9    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_10   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_11   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_12   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_13   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_14   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_15   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_16   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_17   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_18   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_19   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_20   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_21   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_22   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_23   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_24   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_25   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_26   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_27   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_28   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_29   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_30   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_31   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_32   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_33   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_34   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_35   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_36   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_37   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_38   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_39   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_40   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_41   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_42   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_43   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_44   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_45   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_46   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_47   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_48   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_49   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_50   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_51   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_52   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_chnl_ctrl_53   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      
      targ_addr_ctrl_1   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_2   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_3   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_4   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_5   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_6   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_7   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_8   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_9   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_10  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_11  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_12  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_13  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_14  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_15  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_16  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_17  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_18  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_19  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_20  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_21  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_22  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_23  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_24  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_25  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_26  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_27  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_28  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_29  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_30  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_31  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_32  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_33  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_34  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_35  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_36  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_37  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_38  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_39  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_40  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_41  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_42  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_43  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_44  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_45  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_46  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_47  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_48  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_49  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_50  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_51  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_52  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_53  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      
      out_chnl_ctrl_1    : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_2    : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_3    : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_4    : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_5    : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_6    : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_7    : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_8    : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_9    : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_10   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_11   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_12   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_13   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_14   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_15   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_16   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_17   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_18   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_19   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_20   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_21   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_22   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_23   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_24   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_25   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_26   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_27   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_28   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_29   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_30   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_31   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_32   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_33   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_34   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_35   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_36   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_37   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_38   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_39   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_40   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_41   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_42   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_43   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_44   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_45   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_46   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_47   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_48   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_49   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_50   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_51   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_52   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_chnl_ctrl_53   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      
      so                 : OUT STD_LOGIC
   );
END stratixiv_hssi_cmu_dprio_reg_chnl;

ARCHITECTURE trans OF stratixiv_hssi_cmu_dprio_reg_chnl IS
   COMPONENT stratixiv_hssi_cmu_dprio_16bit
      PORT (
         reset              : IN STD_LOGIC;
         mdio_wr            : IN STD_LOGIC;
         reg_addr           : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         target_addr        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         clk                : IN STD_LOGIC;
         sig_in             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_in             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         serial_mode        : IN STD_LOGIC;
         si                 : IN STD_LOGIC;
         shift              : IN STD_LOGIC;
         mdio_dis           : IN STD_LOGIC;
         sig_out            : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         so                 : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_dprio_16bit_pma
      PORT (
         reset              : IN STD_LOGIC;
         mdio_wr            : IN STD_LOGIC;
         reg_addr           : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         target_addr        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         clk                : IN STD_LOGIC;
         sig_in             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_in             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         serial_mode        : IN STD_LOGIC;
         si                 : IN STD_LOGIC;
         shift              : IN STD_LOGIC;
         mdio_dis           : IN STD_LOGIC;
         pma_cram_test      : IN STD_LOGIC;
         sig_out            : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         so                 : OUT STD_LOGIC
      );
   END COMPONENT;
   
   
   SIGNAL chain                   : STD_LOGIC_VECTOR(51 DOWNTO 0);
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL out_chnl_ctrl_1_xhdl0   : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_2_xhdl11  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_3_xhdl22  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_4_xhdl33  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_5_xhdl44  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_6_xhdl48  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_7_xhdl49  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_8_xhdl50  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_9_xhdl51  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_10_xhdl1  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_11_xhdl2  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_12_xhdl3  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_13_xhdl4  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_14_xhdl5  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_15_xhdl6  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_16_xhdl7  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_17_xhdl8  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_18_xhdl9  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_19_xhdl10 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_20_xhdl12 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_21_xhdl13 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_22_xhdl14 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_23_xhdl15 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_24_xhdl16 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_25_xhdl17 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_26_xhdl18 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_27_xhdl19 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_28_xhdl20 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_29_xhdl21 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_30_xhdl23 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_31_xhdl24 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_32_xhdl25 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_33_xhdl26 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_34_xhdl27 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_35_xhdl28 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_36_xhdl29 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_37_xhdl30 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_38_xhdl31 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_39_xhdl32 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_40_xhdl34 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_41_xhdl35 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_42_xhdl36 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_43_xhdl37 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_44_xhdl38 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_45_xhdl39 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_46_xhdl40 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_47_xhdl41 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_48_xhdl42 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_49_xhdl43 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_50_xhdl45 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_51_xhdl46 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_52_xhdl47 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_53_xhdl48 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL so_xhdl52               : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   out_chnl_ctrl_1 <= out_chnl_ctrl_1_xhdl0;
   out_chnl_ctrl_2 <= out_chnl_ctrl_2_xhdl11;
   out_chnl_ctrl_3 <= out_chnl_ctrl_3_xhdl22;
   out_chnl_ctrl_4 <= out_chnl_ctrl_4_xhdl33;
   out_chnl_ctrl_5 <= out_chnl_ctrl_5_xhdl44;
   out_chnl_ctrl_6 <= out_chnl_ctrl_6_xhdl48;
   out_chnl_ctrl_7 <= out_chnl_ctrl_7_xhdl49;
   out_chnl_ctrl_8 <= out_chnl_ctrl_8_xhdl50;
   out_chnl_ctrl_9 <= out_chnl_ctrl_9_xhdl51;
   out_chnl_ctrl_10 <= out_chnl_ctrl_10_xhdl1;
   out_chnl_ctrl_11 <= out_chnl_ctrl_11_xhdl2;
   out_chnl_ctrl_12 <= out_chnl_ctrl_12_xhdl3;
   out_chnl_ctrl_13 <= out_chnl_ctrl_13_xhdl4;
   out_chnl_ctrl_14 <= out_chnl_ctrl_14_xhdl5;
   out_chnl_ctrl_15 <= out_chnl_ctrl_15_xhdl6;
   out_chnl_ctrl_16 <= out_chnl_ctrl_16_xhdl7;
   out_chnl_ctrl_17 <= out_chnl_ctrl_17_xhdl8;
   out_chnl_ctrl_18 <= out_chnl_ctrl_18_xhdl9;
   out_chnl_ctrl_19 <= out_chnl_ctrl_19_xhdl10;
   out_chnl_ctrl_20 <= out_chnl_ctrl_20_xhdl12;
   out_chnl_ctrl_21 <= out_chnl_ctrl_21_xhdl13;
   out_chnl_ctrl_22 <= out_chnl_ctrl_22_xhdl14;
   out_chnl_ctrl_23 <= out_chnl_ctrl_23_xhdl15;
   out_chnl_ctrl_24 <= out_chnl_ctrl_24_xhdl16;
   out_chnl_ctrl_25 <= out_chnl_ctrl_25_xhdl17;
   out_chnl_ctrl_26 <= out_chnl_ctrl_26_xhdl18;
   out_chnl_ctrl_27 <= out_chnl_ctrl_27_xhdl19;
   out_chnl_ctrl_28 <= out_chnl_ctrl_28_xhdl20;
   out_chnl_ctrl_29 <= out_chnl_ctrl_29_xhdl21;
   out_chnl_ctrl_30 <= out_chnl_ctrl_30_xhdl23;
   out_chnl_ctrl_31 <= out_chnl_ctrl_31_xhdl24;
   out_chnl_ctrl_32 <= out_chnl_ctrl_32_xhdl25;
   out_chnl_ctrl_33 <= out_chnl_ctrl_33_xhdl26;
   out_chnl_ctrl_34 <= out_chnl_ctrl_34_xhdl27;
   out_chnl_ctrl_35 <= out_chnl_ctrl_35_xhdl28;
   out_chnl_ctrl_36 <= out_chnl_ctrl_36_xhdl29;
   out_chnl_ctrl_37 <= out_chnl_ctrl_37_xhdl30;
   out_chnl_ctrl_38 <= out_chnl_ctrl_38_xhdl31;
   out_chnl_ctrl_39 <= out_chnl_ctrl_39_xhdl32;
   out_chnl_ctrl_40 <= out_chnl_ctrl_40_xhdl34;
   out_chnl_ctrl_41 <= out_chnl_ctrl_41_xhdl35;
   out_chnl_ctrl_42 <= out_chnl_ctrl_42_xhdl36;
   out_chnl_ctrl_43 <= out_chnl_ctrl_43_xhdl37;
   out_chnl_ctrl_44 <= out_chnl_ctrl_44_xhdl38;
   out_chnl_ctrl_45 <= out_chnl_ctrl_45_xhdl39;
   out_chnl_ctrl_46 <= out_chnl_ctrl_46_xhdl40;
   out_chnl_ctrl_47 <= out_chnl_ctrl_47_xhdl41;
   out_chnl_ctrl_48 <= out_chnl_ctrl_48_xhdl42;
   out_chnl_ctrl_49 <= out_chnl_ctrl_49_xhdl43;
   out_chnl_ctrl_50 <= out_chnl_ctrl_50_xhdl45;
   out_chnl_ctrl_51 <= out_chnl_ctrl_51_xhdl46;
   out_chnl_ctrl_52 <= out_chnl_ctrl_52_xhdl47;
   out_chnl_ctrl_53 <= out_chnl_ctrl_53_xhdl48;
   so <= so_xhdl52;
   
   
   
   chnl_ctrl_1 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_1,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_1,
         serial_mode  => serial_mode,
         si           => si,
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_1_xhdl0,
         so           => chain(0)
      );
   
   
   
   chnl_ctrl_2 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_2,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_2,
         serial_mode  => serial_mode,
         si           => chain(0),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_2_xhdl11,
         so           => chain(1)
      );
   
   
   
   chnl_ctrl_3 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_3,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_3,
         serial_mode  => serial_mode,
         si           => chain(1),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_3_xhdl22,
         so           => chain(2)
      );
   
   
   
   chnl_ctrl_4 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_4,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_4,
         serial_mode  => serial_mode,
         si           => chain(2),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_4_xhdl33,
         so           => chain(3)
      );
   
   
   
   chnl_ctrl_5 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_5,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_5,
         serial_mode  => serial_mode,
         si           => chain(3),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_5_xhdl44,
         so           => chain(4)
      );
   
   
   
   chnl_ctrl_6 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_6,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_6,
         serial_mode  => serial_mode,
         si           => chain(4),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_6_xhdl48,
         so           => chain(5)
      );
   
   
   
   chnl_ctrl_7 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_7,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_7,
         serial_mode  => serial_mode,
         si           => chain(5),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_7_xhdl49,
         so           => chain(6)
      );
   
   
   
   chnl_ctrl_8 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_8,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_8,
         serial_mode  => serial_mode,
         si           => chain(6),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_8_xhdl50,
         so           => chain(7)
      );
   
   
   
   chnl_ctrl_9 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_9,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_9,
         serial_mode  => serial_mode,
         si           => chain(7),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_9_xhdl51,
         so           => chain(8)
      );
   
   
   
   chnl_ctrl_10 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_10,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_10,
         serial_mode  => serial_mode,
         si           => chain(8),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_10_xhdl1,
         so           => chain(9)
      );
   
   
   
   chnl_ctrl_11 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_11,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_11,
         serial_mode  => serial_mode,
         si           => chain(9),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_11_xhdl2,
         so           => chain(10)
      );
   
   
   
   chnl_ctrl_12 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_12,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_12,
         serial_mode  => serial_mode,
         si           => chain(10),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_12_xhdl3,
         so           => chain(11)
      );
   
   
   
   chnl_ctrl_13 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_13,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_13,
         serial_mode  => serial_mode,
         si           => chain(11),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_13_xhdl4,
         so           => chain(12)
      );
   
   
   
   chnl_ctrl_14 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_14,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_14,
         serial_mode  => serial_mode,
         si           => chain(12),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_14_xhdl5,
         so           => chain(13)
      );
   
   
   
   chnl_ctrl_15 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_15,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_15,
         serial_mode  => serial_mode,
         si           => chain(13),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_15_xhdl6,
         so           => chain(14)
      );
   
   
   
   chnl_ctrl_16 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_16,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_16,
         serial_mode  => serial_mode,
         si           => chain(14),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_16_xhdl7,
         so           => chain(15)
      );
   
   
   
   chnl_ctrl_17 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_17,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_17,
         serial_mode  => serial_mode,
         si           => chain(15),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_17_xhdl8,
         so           => chain(16)
      );
   
   
   
   chnl_ctrl_18 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_18,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_18,
         serial_mode  => serial_mode,
         si           => chain(16),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_18_xhdl9,
         so           => chain(17)
      );
   
   
   
   chnl_ctrl_19 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_19,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_19,
         serial_mode  => serial_mode,
         si           => chain(17),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_19_xhdl10,
         so           => chain(18)
      );
   
   
   
   chnl_ctrl_20 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_20,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_20,
         serial_mode  => serial_mode,
         si           => chain(18),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_20_xhdl12,
         so           => chain(19)
      );
   
   
   
   chnl_ctrl_21 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_21,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_21,
         serial_mode  => serial_mode,
         si           => chain(19),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_21_xhdl13,
         so           => chain(20)
      );
   
   
   
   chnl_ctrl_22 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_22,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_22,
         serial_mode  => serial_mode,
         si           => chain(20),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_22_xhdl14,
         so           => chain(21)
      );
   
   
   
   chnl_ctrl_23 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_23,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_23,
         serial_mode  => serial_mode,
         si           => chain(21),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_23_xhdl15,
         so           => chain(22)
      );
   
   
   
   chnl_ctrl_24 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_24,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_24,
         serial_mode  => serial_mode,
         si           => chain(22),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_24_xhdl16,
         so           => chain(23)
      );
   
   
   
   chnl_ctrl_25 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_25,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_25,
         serial_mode  => serial_mode,
         si           => chain(23),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_25_xhdl17,
         so           => chain(24)
      );
   
   
   
   chnl_ctrl_26 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_26,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_26,
         serial_mode  => serial_mode,
         si           => chain(24),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_26_xhdl18,
         so           => chain(25)
      );
   
   
   
   chnl_ctrl_27 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_27,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_chnl_ctrl_27,
         serial_mode  => serial_mode,
         si           => chain(25),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_chnl_ctrl_27_xhdl19,
         so           => chain(26)
      );
   
   
   
   chnl_ctrl_28 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_28,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_28,
         serial_mode    => serial_mode,
         si             => chain(26),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_28_xhdl20,
         so             => chain(27)
      );
   
   
   
   chnl_ctrl_29 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_29,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_29,
         serial_mode    => serial_mode,
         si             => chain(27),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_29_xhdl21,
         so             => chain(28)
      );
   
   
   
   chnl_ctrl_30 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_30,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_30,
         serial_mode    => serial_mode,
         si             => chain(28),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_30_xhdl23,
         so             => chain(29)
      );
   
   
   
   chnl_ctrl_31 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_31,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_31,
         serial_mode    => serial_mode,
         si             => chain(29),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_31_xhdl24,
         so             => chain(30)
      );
   
   
   
   chnl_ctrl_32 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_32,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_32,
         serial_mode    => serial_mode,
         si             => chain(30),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_32_xhdl25,
         so             => chain(31)
      );
   
   
   
   chnl_ctrl_33 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_33,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_33,
         serial_mode    => serial_mode,
         si             => chain(31),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_33_xhdl26,
         so             => chain(32)
      );
   
   
   
   chnl_ctrl_34 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_34,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_34,
         serial_mode    => serial_mode,
         si             => chain(32),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_34_xhdl27,
         so             => chain(33)
      );
   
   
   
   chnl_ctrl_35 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_35,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_35,
         serial_mode    => serial_mode,
         si             => chain(33),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_35_xhdl28,
         so             => chain(34)
      );
   
   
   
   chnl_ctrl_36 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_36,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_36,
         serial_mode    => serial_mode,
         si             => chain(34),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_36_xhdl29,
         so             => chain(35)
      );
   
   
   
   chnl_ctrl_37 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_37,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_37,
         serial_mode    => serial_mode,
         si             => chain(35),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_37_xhdl30,
         so             => chain(36)
      );
   
   
   
   chnl_ctrl_38 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_38,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_38,
         serial_mode    => serial_mode,
         si             => chain(36),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_38_xhdl31,
         so             => chain(37)
      );
   
   
   
   chnl_ctrl_39 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_39,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_39,
         serial_mode    => serial_mode,
         si             => chain(37),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_39_xhdl32,
         so             => chain(38)
      );
   
   
   
   chnl_ctrl_40 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_40,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_40,
         serial_mode    => serial_mode,
         si             => chain(38),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_40_xhdl34,
         so             => chain(39)
      );
   
   
   
   chnl_ctrl_41 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_41,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_41,
         serial_mode    => serial_mode,
         si             => chain(39),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_41_xhdl35,
         so             => chain(40)
      );
   
   
   
   chnl_ctrl_42 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_42,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_42,
         serial_mode    => serial_mode,
         si             => chain(40),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_42_xhdl36,
         so             => chain(41)
      );
   
   
   
   chnl_ctrl_43 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_43,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_43,
         serial_mode    => serial_mode,
         si             => chain(41),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_43_xhdl37,
         so             => chain(42)
      );
   
   
   
   chnl_ctrl_44 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_44,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_44,
         serial_mode    => serial_mode,
         si             => chain(42),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_44_xhdl38,
         so             => chain(43)
      );
   
   
   
   chnl_ctrl_45 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_45,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_45,
         serial_mode    => serial_mode,
         si             => chain(43),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_45_xhdl39,
         so             => chain(44)
      );
   
   
   
   chnl_ctrl_46 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_46,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_46,
         serial_mode    => serial_mode,
         si             => chain(44),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_46_xhdl40,
         so             => chain(45)
      );
   
   
   
   chnl_ctrl_47 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_47,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_47,
         serial_mode    => serial_mode,
         si             => chain(45),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_47_xhdl41,
         so             => chain(46)
      );
   
   
   
   chnl_ctrl_48 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_48,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_48,
         serial_mode    => serial_mode,
         si             => chain(46),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_48_xhdl42,
         so             => chain(47)
      );
   
   
   
   chnl_ctrl_49 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_49,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_49,
         serial_mode    => serial_mode,
         si             => chain(47),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_49_xhdl43,
         so             => chain(48)
      );
   
   
   
   chnl_ctrl_50 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_50,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_50,
         serial_mode    => serial_mode,
         si             => chain(48),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_50_xhdl45,
         so             => chain(49)
      );
   
   
   
   chnl_ctrl_51 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_51,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_51,
         serial_mode    => serial_mode,
         si             => chain(49),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_51_xhdl46,
         so             => chain(50)
      );
   
   
   
   chnl_ctrl_52 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_52,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_52,
         serial_mode    => serial_mode,
         si             => chain(50),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_52_xhdl47,
         so             => chain(51)
      );
   
   chnl_ctrl_53 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_53,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_chnl_ctrl_53,
         serial_mode    => serial_mode,
         si             => chain(51),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_chnl_ctrl_53_xhdl48,
         so             => so_xhdl52
      );
      
      
END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_dprio_chnl_bus_out_mux IS
   PORT (
      
      chnl_ctrl_in1         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in2         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in3         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in4         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in5         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in6         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in7         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in8         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in9         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in10        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in11        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in12        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in13        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in14        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in15        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in16        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in17        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in18        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in19        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in20        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in21        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in22        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in23        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in24        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in25        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in26        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in27        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in28        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in29        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in30        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in31        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in32        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in33        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in34        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in35        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in36        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in37        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in38        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in39        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in40        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in41        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in42        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in43        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in44        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in45        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in46        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in47        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in48        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in49        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in50        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in51        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in52        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      chnl_ctrl_in53        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in1   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in2   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in3   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in4   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in5   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in6   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in7   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in8   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in9   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in10  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in11  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in12  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in13  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in14  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in15  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in16  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in17  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in18  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in19  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in20  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in21  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in22  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in23  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in24  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in25  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in26  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in27  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in28  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in29  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in30  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in31  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in32  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in33  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in34  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in35  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in36  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in37  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in38  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in39  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in40  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in41  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in42  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in43  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in44  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in45  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in46  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in47  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in48  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in49  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in50  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in51  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in52  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in53  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      
      reg_addr              : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      
      chnl_ctrl_out         : OUT STD_LOGIC_VECTOR(15 DOWNTO 0)
   );
END stratixiv_hssi_cmu_dprio_chnl_bus_out_mux;

ARCHITECTURE trans OF stratixiv_hssi_cmu_dprio_chnl_bus_out_mux IS
BEGIN
   
   chnl_ctrl_out <= chnl_ctrl_in1 WHEN (reg_addr = hw_address_ctrl_in1) ELSE
                    chnl_ctrl_in2 WHEN (reg_addr = hw_address_ctrl_in2) ELSE
                    chnl_ctrl_in3 WHEN (reg_addr = hw_address_ctrl_in3) ELSE
                    chnl_ctrl_in4 WHEN (reg_addr = hw_address_ctrl_in4) ELSE
                    chnl_ctrl_in5 WHEN (reg_addr = hw_address_ctrl_in5) ELSE
                    chnl_ctrl_in6 WHEN (reg_addr = hw_address_ctrl_in6) ELSE
                    chnl_ctrl_in7 WHEN (reg_addr = hw_address_ctrl_in7) ELSE
                    chnl_ctrl_in8 WHEN (reg_addr = hw_address_ctrl_in8) ELSE
                    chnl_ctrl_in9 WHEN (reg_addr = hw_address_ctrl_in9) ELSE
                    chnl_ctrl_in10 WHEN (reg_addr = hw_address_ctrl_in10) ELSE
                    chnl_ctrl_in11 WHEN (reg_addr = hw_address_ctrl_in11) ELSE
                    chnl_ctrl_in12 WHEN (reg_addr = hw_address_ctrl_in12) ELSE
                    chnl_ctrl_in13 WHEN (reg_addr = hw_address_ctrl_in13) ELSE
                    chnl_ctrl_in14 WHEN (reg_addr = hw_address_ctrl_in14) ELSE
                    chnl_ctrl_in15 WHEN (reg_addr = hw_address_ctrl_in15) ELSE
                    chnl_ctrl_in16 WHEN (reg_addr = hw_address_ctrl_in16) ELSE
                    chnl_ctrl_in17 WHEN (reg_addr = hw_address_ctrl_in17) ELSE
                    chnl_ctrl_in18 WHEN (reg_addr = hw_address_ctrl_in18) ELSE
                    chnl_ctrl_in19 WHEN (reg_addr = hw_address_ctrl_in19) ELSE
                    chnl_ctrl_in20 WHEN (reg_addr = hw_address_ctrl_in20) ELSE
                    chnl_ctrl_in21 WHEN (reg_addr = hw_address_ctrl_in21) ELSE
                    chnl_ctrl_in22 WHEN (reg_addr = hw_address_ctrl_in22) ELSE
                    chnl_ctrl_in23 WHEN (reg_addr = hw_address_ctrl_in23) ELSE
                    chnl_ctrl_in24 WHEN (reg_addr = hw_address_ctrl_in24) ELSE
                    chnl_ctrl_in25 WHEN (reg_addr = hw_address_ctrl_in25) ELSE
                    chnl_ctrl_in26 WHEN (reg_addr = hw_address_ctrl_in26) ELSE
                    chnl_ctrl_in27 WHEN (reg_addr = hw_address_ctrl_in27) ELSE
                    chnl_ctrl_in28 WHEN (reg_addr = hw_address_ctrl_in28) ELSE
                    chnl_ctrl_in29 WHEN (reg_addr = hw_address_ctrl_in29) ELSE
                    chnl_ctrl_in30 WHEN (reg_addr = hw_address_ctrl_in30) ELSE
                    chnl_ctrl_in31 WHEN (reg_addr = hw_address_ctrl_in31) ELSE
                    chnl_ctrl_in32 WHEN (reg_addr = hw_address_ctrl_in32) ELSE
                    chnl_ctrl_in33 WHEN (reg_addr = hw_address_ctrl_in33) ELSE
                    chnl_ctrl_in34 WHEN (reg_addr = hw_address_ctrl_in34) ELSE
                    chnl_ctrl_in35 WHEN (reg_addr = hw_address_ctrl_in35) ELSE
                    chnl_ctrl_in36 WHEN (reg_addr = hw_address_ctrl_in36) ELSE
                    chnl_ctrl_in37 WHEN (reg_addr = hw_address_ctrl_in37) ELSE
                    chnl_ctrl_in38 WHEN (reg_addr = hw_address_ctrl_in38) ELSE
                    chnl_ctrl_in39 WHEN (reg_addr = hw_address_ctrl_in39) ELSE
                    chnl_ctrl_in40 WHEN (reg_addr = hw_address_ctrl_in40) ELSE
                    chnl_ctrl_in41 WHEN (reg_addr = hw_address_ctrl_in41) ELSE
                    chnl_ctrl_in42 WHEN (reg_addr = hw_address_ctrl_in42) ELSE
                    chnl_ctrl_in43 WHEN (reg_addr = hw_address_ctrl_in43) ELSE
                    chnl_ctrl_in44 WHEN (reg_addr = hw_address_ctrl_in44) ELSE
                    chnl_ctrl_in45 WHEN (reg_addr = hw_address_ctrl_in45) ELSE
                    chnl_ctrl_in46 WHEN (reg_addr = hw_address_ctrl_in46) ELSE
                    chnl_ctrl_in47 WHEN (reg_addr = hw_address_ctrl_in47) ELSE
                    chnl_ctrl_in48 WHEN (reg_addr = hw_address_ctrl_in48) ELSE
                    chnl_ctrl_in49 WHEN (reg_addr = hw_address_ctrl_in49) ELSE
                    chnl_ctrl_in50 WHEN (reg_addr = hw_address_ctrl_in50) ELSE
                    chnl_ctrl_in51 WHEN (reg_addr = hw_address_ctrl_in51) ELSE
                    chnl_ctrl_in52 WHEN (reg_addr = hw_address_ctrl_in52) ELSE
                    chnl_ctrl_in53 WHEN (reg_addr = hw_address_ctrl_in53) ELSE
                    "0000000000000000";
   
END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_dprio_chnl_top IS
   PORT (
      
      mdio_rst              : IN STD_LOGIC;		-- DPRIO reset input
      mdio_wr               : IN STD_LOGIC;		-- DPRIO register write enable
      reg_addr              : IN STD_LOGIC_VECTOR(15 DOWNTO 0);		-- DPRIO register address from SM
      mdc                   : IN STD_LOGIC;		-- DPRIO clock
      mbus_in               : IN STD_LOGIC_VECTOR(15 DOWNTO 0);		-- DPRIO data in from SM
      serial_mode           : IN STD_LOGIC;		-- DPRIO serial mode enable
      mdio_dis              : IN STD_LOGIC;		-- DPRIO disable signal (using CSR input)
      pma_cram_test         : IN STD_LOGIC;		-- For TE/PE increased coverage for PMA DPRIO cell
      ser_shift_load        : IN STD_LOGIC;		-- DPRIO serial shift or load control signal
      si                    : IN STD_LOGIC;		-- DPRIO serial input
      -- DPRIO channel base address ID, tells which channel/central DPRIO
      -- register is located
      csr_chnl_in           : IN STD_LOGIC_VECTOR(831 DOWNTO 0);		-- CSR inputs
      csr_chnl_in_reserved  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);		    -- CSR inputs
      dprio_chnl_id         : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      
      dp_chnl_out           : OUT STD_LOGIC_VECTOR(831 DOWNTO 0);		-- DP
      dp_chnl_out_reserved  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);		-- outputs
      
      so                    : OUT STD_LOGIC;		-- DPRIO serial out
      mbus_out              : OUT STD_LOGIC_VECTOR(15 DOWNTO 0)		-- DPRIO dataout
   );
END stratixiv_hssi_cmu_dprio_chnl_top;

ARCHITECTURE trans OF stratixiv_hssi_cmu_dprio_chnl_top IS
   COMPONENT stratixiv_hssi_cmu_dprio_reg_chnl
      PORT (
         mdio_rst              : IN STD_LOGIC;
         mdio_wr               : IN STD_LOGIC;
         reg_addr              : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         mdc                   : IN STD_LOGIC;
         mbus_in               : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         serial_mode           : IN STD_LOGIC;
         mdio_dis              : IN STD_LOGIC;
         pma_cram_test         : IN STD_LOGIC;
         ser_shift_load        : IN STD_LOGIC;
         si                    : IN STD_LOGIC;
         ext_chnl_ctrl_1       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_2       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_3       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_4       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_5       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_6       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_7       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_8       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_9       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_10      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_11      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_12      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_13      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_14      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_15      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_16      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_17      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_18      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_19      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_20      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_21      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_22      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_23      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_24      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_25      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_26      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_27      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_28      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_29      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_30      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_31      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_32      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_33      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_34      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_35      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_36      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_37      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_38      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_39      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_40      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_41      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_42      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_43      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_44      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_45      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_46      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_47      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_48      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_49      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_50      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_51      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_52      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_chnl_ctrl_53      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_1      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_2      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_3      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_4      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_5      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_6      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_7      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_8      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_9      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_10     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_11     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_12     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_13     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_14     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_15     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_16     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_17     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_18     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_19     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_20     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_21     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_22     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_23     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_24     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_25     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_26     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_27     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_28     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_29     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_30     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_31     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_32     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_33     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_34     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_35     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_36     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_37     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_38     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_39     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_40     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_41     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_42     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_43     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_44     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_45     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_46     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_47     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_48     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_49     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_50     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_51     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_52     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         targ_addr_ctrl_53     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         
         out_chnl_ctrl_1       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_2       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_3       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_4       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_5       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_6       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_7       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_8       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_9       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_10      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_11      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_12      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_13      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_14      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_15      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_16      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_17      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_18      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_19      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_20      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_21      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_22      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_23      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_24      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_25      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_26      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_27      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_28      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_29      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_30      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_31      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_32      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_33      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_34      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_35      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_36      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_37      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_38      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_39      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_40      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_41      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_42      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_43      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_44      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_45      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_46      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_47      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_48      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_49      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_50      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_51      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_52      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         out_chnl_ctrl_53      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         
         so                    : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_dprio_chnl_bus_out_mux
      PORT (
         chnl_ctrl_in1         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in2         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in3         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in4         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in5         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in6         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in7         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in8         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in9         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in10        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in11        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in12        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in13        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in14        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in15        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in16        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in17        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in18        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in19        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in20        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in21        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in22        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in23        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in24        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in25        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in26        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in27        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in28        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in29        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in30        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in31        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in32        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in33        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in34        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in35        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in36        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in37        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in38        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in39        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in40        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in41        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in42        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in43        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in44        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in45        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in46        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in47        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in48        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in49        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in50        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in51        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in52        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_in53        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in1   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in2   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in3   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in4   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in5   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in6   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in7   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in8   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in9   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in10  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in11  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in12  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in13  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in14  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in15  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in16  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in17  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in18  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in19  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in20  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in21  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in22  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in23  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in24  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in25  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in26  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in27  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in28  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in29  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in30  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in31  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in32  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in33  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in34  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in35  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in36  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in37  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in38  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in39  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in40  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in41  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in42  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in43  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in44  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in45  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in46  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in47  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in48  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in49  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in50  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in51  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in52  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         hw_address_ctrl_in53  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         reg_addr              : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         chnl_ctrl_out         : OUT STD_LOGIC_VECTOR(15 DOWNTO 0)
      );
   END COMPONENT;
   
   --////////////////////////////////////////////////////////////////////////
   -- begin of CRAM output -------------------------------------------------
   --////////////////////////////////////////////////////////////////////////
   
   -- CRAM output
   -- TX PCS CRAMs
   SIGNAL rforce_kchar              : STD_LOGIC;		-- Force /K/ char CRAM
   SIGNAL rforce_echar              : STD_LOGIC;		-- Force /E/ char CRAM
   SIGNAL rtxfifo_dis               : STD_LOGIC;		-- TX FIFO disable CRAM
   SIGNAL rib_force_disp            : STD_LOGIC;		-- Disparity force CRAM in IB mode
   SIGNAL rtxfifo_lowlatency_en     : STD_LOGIC;		-- TX FIFO low latency enable CRAM
   SIGNAL rdwidth_tx                : STD_LOGIC;		-- TX parallel interface data width CRAM
   SIGNAL rge_xaui_tx               : STD_LOGIC;		-- GIGE Idle test enable CRAM
   SIGNAL rphfifopldentx            : STD_LOGIC;		-- TX phase comp. FIFO PLD read/write enable CRAM
   SIGNAL rphfifoursttx             : STD_LOGIC;		-- TX phase comp. FIFO user reset enable CRAM
   SIGNAL rtxurstpcs                : STD_LOGIC;		-- TX PCS user reset enable CRAm
   SIGNAL rfreerun_tx               : STD_LOGIC;		-- TX_CLK out free running during TX PCS reset enable CRAM
   SIGNAL rtxwrclksel               : STD_LOGIC;		-- TX FIFO write clock selection CRAM
   SIGNAL rtxrdclksel               : STD_LOGIC;		-- TX FIFO read clock selection CRAM
   SIGNAL rrev_loopbk               : STD_LOGIC;		-- CRAM - Enable dynamic Reverse, PIPE mode
   SIGNAL rforce_disp               : STD_LOGIC;		-- Acting with TXD[9, 19] forces current disparity to 1 or 0
   SIGNAL rendec_tx                 : STD_LOGIC;		-- Enable 8B/10B encoder CRAM
   SIGNAL r8b10b_enc_ibm_en         : STD_LOGIC;		-- 8B10B Encoder fix enable CRAM
   SIGNAL rcascaded_8b10b_en_tx     : STD_LOGIC;		-- Caascaded 8b/10b encoder enable CRAM
   SIGNAL rensymswap_tx             : STD_LOGIC;		-- TX symbol swap enable CRAM
   SIGNAL renpolinv_tx              : STD_LOGIC;		-- TX Polarity inversion enable CRAM
   SIGNAL renbitrev_tx              : STD_LOGIC;		-- TX bit reversal enable CRAM
   SIGNAL rprbsen_tx                : STD_LOGIC;		-- PRBS generator enable CRAM
   SIGNAL rprbs_sel                 : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- PRBS selection CRAM
   SIGNAL rbisten_tx                : STD_LOGIC;		-- BIST generator enable CRAM
   SIGNAL rbist_sel                 : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- BIST selection CRAM
   SIGNAL rcxpat_chnl_en            : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- CRPAT or CJPAT selection CRAM
   SIGNAL rtxpcsbypass_en           : STD_LOGIC;		-- Bypass TX PCS CRAM
   SIGNAL rtx_pipe_enable           : STD_LOGIC;		-- TX PIPE interface enable CRAM
   SIGNAL rtx_idle_delay            : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- PIPE TxElecIdle delay value CRAM
   SIGNAL rtxswing_sel_ena          : STD_LOGIC;		-- Txswing select enable CRAM
   SIGNAL rtxpcsclkpwdn             : STD_LOGIC;		-- Enables/Disables all clocks to TX PCS
   SIGNAL rcid_pattern_tx           : STD_LOGIC;		-- Select CID pattern to be 0 or 1
   SIGNAL rcid_len_tx               : STD_LOGIC_VECTOR(7 DOWNTO 0);		-- Length of CID pattern in cycles
   SIGNAL rself_sw_en_tx            : STD_LOGIC;		-- En/Disable self switch circuit for clk divider in TX clk circuit
   SIGNAL rpipeline_bypass_tx       : STD_LOGIC;		-- Use/Don't use pipeline registers for TX inter-quad signals
   SIGNAL rphfifo_regmode_tx        : STD_LOGIC;		-- Enable TX phase comp register mode
   SIGNAL rtxbitslip_en             : STD_LOGIC;		-- 1: Enable TX bitslip for CPRI, 0: Normal operation (default)
   
   -- RX PCS CRAMs
   SIGNAL rrxurstpcs                : STD_LOGIC;		-- RX PCS user reset enable CRAm
   SIGNAL rfreerun_rx               : STD_LOGIC;		-- RX_CLK out free running during RX PCS reset enable CRAM
   SIGNAL rrcvd_clk_sel             : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- RCVD_CLK domain selection CRAM
   SIGNAL rclk_1_sel                : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- CLK_1 domain selection CRAM
   SIGNAL rclk_2_sel                : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- CLK_2 domain selection CRAM
   SIGNAL rrx_rd_clk_sel            : STD_LOGIC;		-- RX FIFO read clock selection CRAM
   SIGNAL rprbsen_rx                : STD_LOGIC;		-- PRBS Verifier enable CRAM
   SIGNAL rprbs_clr_rslt_rx         : STD_LOGIC;		-- PRBS pass/fail flag clear CRAM
   SIGNAL rbisten_rx                : STD_LOGIC;		-- BIST Verifier enable CRAM
   SIGNAL rbist_clr_rx              : STD_LOGIC;		-- BIST pass/fail flag clear CRAM
   SIGNAL rall_one_dect_only        : STD_LOGIC;		-- PRBS Verifier detect all one only enable CRAM
   SIGNAL rrxpcsbypass_en           : STD_LOGIC;		-- RX PCS bypass CRAM
   SIGNAL resync_badcg_en           : STD_LOGIC_VECTOR(1 DOWNTO 0);		--
   SIGNAL rencdt_rising             : STD_LOGIC;		-- encdt on rising edge enable CRAM
   SIGNAL rdis_rx_disp              : STD_LOGIC;		-- Receive running disparity calculation disable CRAM
   SIGNAL rcomp_pat_porn            : STD_LOGIC;		-- Positive and negative match enable CRAM
   SIGNAL rcomp_size                : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- Pattern comparision length CRAMs
   SIGNAL rcomp_pat                 : STD_LOGIC_VECTOR(39 DOWNTO 0);		-- Sync pattern CRAMs
   SIGNAL rsync_sm_dis              : STD_LOGIC;		-- GIGE/XAUI Sync SM disable CRAM
   SIGNAL rib_inv_cd                : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Invalid code setting CRAMs for IB
   SIGNAL renumber                  : STD_LOGIC_VECTOR(5 DOWNTO 0);		-- Number of consecutive errors without valid data to goto LOSS_OF_SYNC
   SIGNAL rkchar                    : STD_LOGIC;		-- use kchar at cg_bad logic calculation
   SIGNAL rosbased                  : STD_LOGIC;		-- Enable ordered-set based algorithm
   SIGNAL rosnumber                 : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Length of the ordered set
   SIGNAL rwa_6g_en                 : STD_LOGIC;		-- 6G word alignment enable CRAM
   SIGNAL rbysync_polinv_en         : STD_LOGIC;		-- Word alignment polarity inversion enable CRAM
   SIGNAL rbitloc_rev_en            : STD_LOGIC;		-- Bit reversal enable CRAM
   SIGNAL rgnumber                  : STD_LOGIC_VECTOR(7 DOWNTO 0);		-- Number of consecutive good data to approach SYNC_ACQ
   SIGNAL rknumber                  : STD_LOGIC_VECTOR(7 DOWNTO 0);		-- Number of consecutive commas to reach SYNC_ACQ from LOSS_OF_SYNC
   SIGNAL rrundisp                  : STD_LOGIC_VECTOR(5 DOWNTO 0);		-- Run lengh violation setting CRAMs
   SIGNAL rbyte_rev_en              : STD_LOGIC;		-- Byte swap enable CRAM
   SIGNAL rforce_sig_det_pcs        : STD_LOGIC;		-- Forcing sigdet to high in PCS CRAM
   SIGNAL rlp20ben                  : STD_LOGIC;		-- 20-b loopback enable CRAM
   SIGNAL rrlv_en                   : STD_LOGIC;		-- RLV enable CRAM
   SIGNAL rautobtalg_dis            : STD_LOGIC;		-- BITSLIP mode enable CRAM
   SIGNAL rendec_rx                 : STD_LOGIC;		-- 10B/8B decoder enable CRAM
   SIGNAL r8b10b_dec_ibm_en         : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- 8B10B Decoder fix enable CRAM
   SIGNAL rcascaded_8b10b_en_rx     : STD_LOGIC;		-- Cascaded 8B/10B decoder enable CRAM
   SIGNAL renpolinv_rx              : STD_LOGIC;		-- Allow polarity inversion
   SIGNAL rmatchen                  : STD_LOGIC;		-- Clock compensation enable CRAM
   SIGNAL rgenericfifo              : STD_LOGIC;		-- GenericFIFO mode enable CRAM
   SIGNAL rskpsetbased              : STD_LOGIC;		-- Enable rate matching for PCI-E/PIPE, other standards based on COMMA DEL DEL..
   SIGNAL rtruebac2bac              : STD_LOGIC;		-- Enabled (high) for all standards except PIPE. Back to back rate match enable.
   SIGNAL rclkcmpinsertpad          : STD_LOGIC;		-- Rate matching pad insertion enable CRAM
   SIGNAL rclkcmpsqmd               : STD_LOGIC;		-- How many characters to match
   SIGNAL rclkcmpsq1p               : STD_LOGIC_VECTOR(19 DOWNTO 0);		-- Programmable 20-bit encoded comp sequence pos. disp.
   SIGNAL rclkcmpsq1n               : STD_LOGIC_VECTOR(19 DOWNTO 0);		-- Programmable 20-bit encoded comp sequence neg. disp.
   SIGNAL rclkcmp_pipe_en           : STD_LOGIC;		-- RM FIFO Pipe-compatible mode enable CRAM
   SIGNAL rins_threshold            : STD_LOGIC_VECTOR(4 DOWNTO 0);		-- Rate Match FIFO programmable insertion threshold CRAMs
   SIGNAL rdel_threshold            : STD_LOGIC_VECTOR(4 DOWNTO 0);		-- Rate Match FIFO programmable delettion threshold CRAMs
   SIGNAL rfull_threshold           : STD_LOGIC_VECTOR(4 DOWNTO 0);		-- Rate Match FIFO programmable full condition threshold CRAMs
   SIGNAL rempty_threshold          : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- Rate Match FIFO programmable empty condition threshold CRAMs
   SIGNAL rstart_threshold          : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- Rate Match FIFO programmable start point CRAMs
   SIGNAL rpma_done_count           : STD_LOGIC_VECTOR(17 DOWNTO 0);		-- Programmable counter threshold for pma_done_int (1ms)
   SIGNAL rpma_done_gen_ena         : STD_LOGIC;		-- Enable/Disable internal generation of PMA_DONE
   SIGNAL rhip_ena                  : STD_LOGIC;		-- Enable/Disable Hard IP
   SIGNAL rauto_speed_ena           : STD_LOGIC;		-- Enable/Disable Auto Speed Negotiation
   SIGNAL rfreq_sel                 : STD_LOGIC;		-- 1: Frequency Scaling, 0: Data width scaling
   SIGNAL rrxfifo_dis               : STD_LOGIC;		-- RX FIFO bypassing CRAM
   SIGNAL rrxfifo_lowlatency_en     : STD_LOGIC;		-- RX FIFO low latency enable CRAM
   SIGNAL rdwidth_rx                : STD_LOGIC;		-- RX parallel interface data width selection CRAM
   SIGNAL rphfifourstrx             : STD_LOGIC;		-- Enable phfifourst_rx
   SIGNAL rcmpfifourst              : STD_LOGIC;		-- Enable cmpfifourst
   SIGNAL rinvalid_code_err_only    : STD_LOGIC;		-- enable error (EDB) replacement only on invalid code-group in RX FIFO
   SIGNAL rbytord_2sym_en           : STD_LOGIC;		-- Enable 2 symbols byte orderring CRAM
   SIGNAL rbyteorden                : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Byte ordering enable CRAM
   SIGNAL rbytordplden              : STD_LOGIC;		-- PLD control signal BYTEORDPLD enable CRAM
   SIGNAL rphfifopldenrx            : STD_LOGIC;		-- RX phase comp. FIFO read/write enable CRAM
   SIGNAL rautoinsdis               : STD_LOGIC;		-- Disable CRAM for auto insertion of 8'h9C
   SIGNAL rtest_bus_sel             : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- Per channel test bus selection CRAMs
   SIGNAL rbytordpat                : STD_LOGIC_VECTOR(19 DOWNTO 0);		-- Byte ordering pattern CRAM
   SIGNAL rbytordpad                : STD_LOGIC_VECTOR(9 DOWNTO 0);		-- Byte ordering pad pattern CRAM
   SIGNAL rrx_pipe_enable           : STD_LOGIC;		-- RX PIPE interface enable CRAM
   SIGNAL rrx_detect_bypass         : STD_LOGIC;		-- PMA RX detection bypass enable CRAM
   SIGNAL rind_error_reporting      : STD_LOGIC;		-- Enable individual reporting for rxstatus in 8b/10b error and disparity error
   SIGNAL rphystatus_delay          : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- Programmable dleay for the PHYSTATUS flag when power transtition
   SIGNAL reidleinferenable         : STD_LOGIC;		-- Enable Electrical Idle inference module
   SIGNAL rk285detect               : STD_LOGIC;		-- Enable detection of K28.7 in PMA for EIdle exit
   SIGNAL reidle_com_detect         : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Thet number of COMs required to enter/exit EIdle
   SIGNAL rphystatus_rst_toggle     : STD_LOGIC;		-- Enable option for PIPE PHY_STATUS wire toggle upon exitting reset
   SIGNAL rload_shreg_del           : STD_LOGIC_VECTOR(4 DOWNTO 0);		-- Programmable delay to allow for loading of the shadow registers before re-enabling the clock driving the PCS logic
   SIGNAL rrxpcsclkpwdn             : STD_LOGIC;		-- Enables/Disables all clocks to RX PCS
   SIGNAL rcdr_ctrl_en              : STD_LOGIC;		-- Enable/Disable CDR control block
   SIGNAL rbytord_s2gx              : STD_LOGIC;		-- 0: S4GX Byte ordering (trigger on every WA lock), 1: S2GX BO behavior
   SIGNAL rbytord_6g_mask_en        : STD_LOGIC;		-- 0: 6G BO normal operation, 1: mask out upper byte
   SIGNAL rwait_count               : STD_LOGIC_VECTOR(7 DOWNTO 0);		-- Minimum programmable period of time that LTR is asserted when CDR is enabled
   SIGNAL rwait_for_phfifo_cnt      : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- Counter timeout value to delay disabling of phase comp FIFO after rate change
   SIGNAL rfts_count                : STD_LOGIC_VECTOR(9 DOWNTO 0);		-- Programmable timer during which CDR control block controls PPM detector
   SIGNAL rcid_pattern_rx           : STD_LOGIC;		-- Select CID pattern to be 0 or 1 
   SIGNAL rcid_len_rx               : STD_LOGIC_VECTOR(7 DOWNTO 0);		-- Length of CID pattern in cycles 
   SIGNAL rppm_meas_delay           : STD_LOGIC;		-- 0: Wait 200, 1: Wait 400 cycles before starting post-eidle-exit PPM measurement
   SIGNAL rphfifo_regmode_rx        : STD_LOGIC;		-- Enable RX phase comp register mode
   SIGNAL rcid_en                   : STD_LOGIC;		-- PIPE only, enable generation of early_eios by CDR to place in protected CID mode
   SIGNAL rrxvalid_mask             : STD_LOGIC;		-- PIPE only, enables masking of rxvalid by CDR control block
   SIGNAL rself_sw_en_rx            : STD_LOGIC;		-- En/Disable self switch circuit for clk divider in TX clk circuit
   SIGNAL rpipeline_bypass_rx       : STD_LOGIC;		-- Use/Don't use pipeline registers for TX inter-quad signals
   SIGNAL rauto_deassert_pc_rst_cnt : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- Programmable counter threshold for timing to release sync reset to PC ptrs
   SIGNAL rauto_pc_en_cnt           : STD_LOGIC_VECTOR(4 DOWNTO 0);		-- Programmable counter threshold for timing to delay phystatus notification to upper layer
   SIGNAL riei_eios_priority_dis    : STD_LOGIC;		--  Disable EIOS detection priority over EIdle Inference when EIdle Inference is enabled
   SIGNAL rgen1_sigdet_ena          : STD_LOGIC;		--  Usage of signal detect under Gen 1 conditions when EIdle Inference is enabled
   SIGNAL rmask_count               : STD_LOGIC_VECTOR(9 DOWNTO 0);		-- Programmable counter to mask out the high bit error period upon exiting electrical
   -- idle in terms of number of gen1 cycles
   
   --//////////////
   -- TX PMA CRAMs
   --//////////////
   SIGNAL rvod_sel_non_pcie         : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- TX wire buffer Vod switching control CRAMs
   SIGNAL rvod_sela                 : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rvod_selb                 : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rvod_selc                 : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rvod_seld                 : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rpowdnt                   : STD_LOGIC;		-- TX channel power down CRAM
   SIGNAL rpre_em_1t_no_pcie        : STD_LOGIC_VECTOR(4 DOWNTO 0);		-- TX wire buffer pre-emphasis switching control for 1st post tap
   SIGNAL rpre_em_1t_a              : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL rpre_em_1t_b              : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL rpre_em_1t_c              : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL rpre_em_2t                : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- TX wire buffer pre-emphasis switching control for 2nd post tap
   SIGNAL rpre_em_pt                : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- TX wire buffer pre-emphasis switching control for pre-tap
   SIGNAL rtx_term_sel              : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- TX's Differential Termination selction CRAMs
   SIGNAL rtx_vtt                   : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- TX's Common-mode driver selection control CRAMs
   SIGNAL rtx_lst                   : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- Low Speed Test Selection CRAMs.
   SIGNAL rslew                     : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Slew rate control for TX
   SIGNAL rsig_inv_ptap             : STD_LOGIC;		-- Signal invert for Pre-tap
   SIGNAL rsig_inv_2t               : STD_LOGIC;		-- Signal invert for 2nd Post tap
   SIGNAL rrx_det                   : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- RAM bit for RX signal detect
   SIGNAL rlowv                     : STD_LOGIC;		-- 0: cascaded current source/sink, 1: bypass cascaded current source/sink
   SIGNAL r_dft_sel                 : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- Design for testing selection to check decoder outputs of main tap, 1st post tap, 2nd
   -- post tap, and pre-tap
   SIGNAL rtx_ob_pdb                : STD_LOGIC;		-- TX Power down CRAM (1: normal operation, 0: power down)
   
   --Serializer - Clock Generation Block (SER-CGB) CRAMs
   SIGNAL rcgb_x_en                 : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Single channel mode (X1 mode) enable CRAM (individual clock drives individual Serializer)
   SIGNAL rcgb_cmu_sel              : STD_LOGIC;		-- CMU selection CRAM in CLKGENBUF_6G block
   SIGNAL rcgb_m_sel                : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Division ratio selection CRAM for input clock in CLKGENBU /net/grouse/nobackup F_6G block
   SIGNAL rpma_doublewidth_tx       : STD_LOGIC;		-- TX PCS to TX PMA double data width (16/20) enable CRAM (S2GX RPMA_DOUBLEWIDTH_TX)
   SIGNAL rpmadwidth_tx             : STD_LOGIC;		-- TX PCS to TX PMA data width (8/10)selection CRAM (S2GX RPMADWIDTH_TX)
   SIGNAL rcgb_delay_sel            : STD_LOGIC;		-- Insert 6 gates delay CRAM for CLKMUX in TX channel
   SIGNAL rs_lpbk                   : STD_LOGIC;		-- reverse loop back control CRAM
   SIGNAL rdynamic_sw               : STD_LOGIC;		-- 0: disable dynamic switch, 1: enable dynamic switch
   SIGNAL rpclksel                  : STD_LOGIC;		-- 0: select local pclk, 1: select global pclk
   SIGNAL rtx_cgb_pdb               : STD_LOGIC;		-- Power down CRAM for CLKGENBUF, CLKMUX, and Serializer in TX channel (1: normal operation)
   
   --C_TX_RX CRAMs
   SIGNAL riqclk_sel                : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- RX path CLKMUX selection CRAM to select either iqclk or pldclk
   SIGNAL rrefclk_sel               : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- RX path REFCLKMUX selection CRAM
   SIGNAL rvcobypass                : STD_LOGIC;		-- RX clock selection sent to PCS
   SIGNAL rrevlb_sw                 : STD_LOGIC;		-- Switch select signal for TX_RLPBK
   SIGNAL rimpctrl                  : STD_LOGIC;		-- Control calibration bi-direction buffer
   SIGNAL rrx_refclk                : STD_LOGIC;		-- RAM bit to choose RX clock to train CDR
   SIGNAL rpcs_sd_sel               : STD_LOGIC;		-- 0: select analog signal detect output, 1: select digital signal detect output
   
   --Reserved CRAMs for TX PMA and RX PMA
   SIGNAL rpma_reserved             : STD_LOGIC_VECTOR(31 DOWNTO 0);		--Reserved bits for RX/TX PMA channel divided into 2 sixteen bit busses 
   --End TX CRAMs
   
   --//////////////
   -- RX PMA CRAMs
   --//////////////
   SIGNAL rrx_lst                   : STD_LOGIC_VECTOR(4 DOWNTO 0);		-- ATB Control Bits (refer to ATB table for details)
   SIGNAL rrx_bit_dc                : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- Select pin for DC gain 0db, 3db, 6db, 9db and 12 db
   SIGNAL rrx_s_rdlpbk              : STD_LOGIC;		-- Loopback control pin
   SIGNAL rrx_vtt                   : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- Control bits for common mode driver
   SIGNAL rrx_term_sel              : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- RX's Differential Termination selection CRAMs
   SIGNAL rrx_sdlv                  : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- Control bits for Signal Detect hysteresis (TBD)
   SIGNAL rrx_oc_en                 : STD_LOGIC;		-- Offset Cancellation control (TBD)
   SIGNAL rrx_oc                    : STD_LOGIC_VECTOR(7 DOWNTO 0);		-- Offset Cancellation control (TBD)
   SIGNAL rrx_sd_force              : STD_LOGIC;		-- Signal detect override
   SIGNAL rrx_test                  : STD_LOGIC;		-- Loopback to test ADCE and EQ stages
   SIGNAL rrxurstpma                : STD_LOGIC;		-- Enable CRAM for RXURSTPMA dynamic signal
   SIGNAL rrx_sd_on                 : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- Control bits for Signal Detect
   SIGNAL rrx_sd_off                : STD_LOGIC_VECTOR(4 DOWNTO 0);		-- Control bits for Signal Detect
   SIGNAL rrx_oc_calpd              : STD_LOGIC;		-- Offset cancellation calibration mode
   SIGNAL rurx_pdb                  : STD_LOGIC;		-- RX/DFE power down
   SIGNAL rrx_ib_pdb                : STD_LOGIC;		-- RX Power down CRAM (1: normal operation, 0: power down)
   SIGNAL rpowdnr                   : STD_LOGIC;		-- RX channel power down CRAM
   
   -- CDR CRAMs
   SIGNAL rcru_div2                 : STD_LOGIC;		-- Reference clock divided by two enable CRAMS
   SIGNAL rcru_m_sel                : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Division ratio selection of input clock
   SIGNAL rcru_m                    : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- Programmable Control. Select among 1,4,5,8,10,16,20 and 25.
   SIGNAL rcru_l                    : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Programmable Control. Select among 1,2, and 4.
   SIGNAL rcru_ctl0                 : STD_LOGIC;		-- CTL0 is Programmable Control CRAMs for Ring VCO frequency range control
   SIGNAL rcru_crplctrl             : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Ripple capacitor control CRAM:
   SIGNAL rcru_pfdbwctrl            : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- RXPLL PFD mode BW control CRAMS (resistor control in loop filter for PFD mode)
   SIGNAL rcru_pdbwctrl             : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- RXPLL PD mode BW control CRAMS (resistor control in loop filter for PD mode)
   SIGNAL rcru_rlbk                 : STD_LOGIC;		-- Enable reverse serial loopback from RX CDR to TX wire buffer with main tab
   SIGNAL rcru_lst                  : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- Low speed test selection CRAM
   SIGNAL rcru_testen               : STD_LOGIC;		-- Charge Pump Current test mode control CRAM in RXPLL
   SIGNAL rcru_testupen             : STD_LOGIC;		-- Charge Pump UP current test control CRAM in RXPLL
   SIGNAL rcru_testdnen             : STD_LOGIC;		-- Charge Pump DOWN current test control CRAM in RXPLL
   SIGNAL rcru_isel                 : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- RXPLL charge pump current control CRAM
   SIGNAL rcru_iselpd               : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- Charge pump current control CRAM at PD mode
   
   SIGNAL rcp_mode                  : STD_LOGIC;		-- Charge pump mode select CRAM
   SIGNAL rltd                      : STD_LOGIC;		-- Lock to Data enable signal (0: normal operation)
   SIGNAL rltr                      : STD_LOGIC;		-- Lock to Reference enable signal (0: normal operation)
   SIGNAL rrx_cru_pdb               : STD_LOGIC;		-- Power down CRAM for CRU in RX channel (1: normal operation)
   SIGNAL rrx_cru_rst               : STD_LOGIC;		-- CRU reset CRAM (1: normal operation)
   SIGNAL rcru_cmu_mode             : STD_LOGIC;		-- Used to disable the buffers in the L-counter when the CDR is configured just as a
   -- TXPLL
   SIGNAL rcru_ignore_phslck        : STD_LOGIC;		-- Used in LCK2REFCTRL block that will override Lock Detect outcome
   SIGNAL rcru_sd_sel               : STD_LOGIC;		-- Select signal detect wire either from analog signal detect or digital signal detect blocks for CDR
   SIGNAL rcru_pdfl                 : STD_LOGIC;		-- Fast Lock control. Use when the data is suddently switched to a different phase (esp 90 degree out of phase)
   SIGNAL rcru_pdof_test            : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- These RAM bits are used to characterize the offset of SALATCHs inside the BBPD
   SIGNAL rcru_rgla_isel            : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- Increase 1.8V regulator wire voltage.
   
   SIGNAL rcru_pdof_0i              : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- BBPD SALATCH offset control. Latch connects to CLK0. Choose either Left or Right, not both.
   SIGNAL rcru_pdof_90i             : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- BBPD SALATCH offset control. Latch connects to CLK90. Choose either Left or Right, not both.
   SIGNAL rcru_pdof_180i            : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- BBPD SALATCH offset control. Latch connects to CLK180. Choose either Left or Right, not both.
   SIGNAL rcru_pdof_270i            : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- BBPD SALATCH offset control. Latch connects to CLK270. Choose either Left or Right, not both.
   
   --Reserved CRAMs for RX PMA (declared above)
   --wire [15:0] rpma_reserved[15:0];   //Reserved bits for RX PMA channel
   
   --DeSerializer CRAMs
   SIGNAL rpma_doublewidth_rx       : STD_LOGIC;		-- RX PMA to RX PCS double data width (16/20) enable CRAM (S2GX RPMA_DOUBLEWIDTH_RX)
   SIGNAL rpmadwidth_rx             : STD_LOGIC;		-- RX PMA to RX PCS data width (8/10) selection CRAM (S2GX RPMADWIDTH_RX)
   SIGNAL rtest_fastsd              : STD_LOGIC;		-- Mux select between Fast SD circuit and Test signal
   SIGNAL rfastsd                   : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- Controls Fast Signal Detect Logic
   SIGNAL rppmsel                   : STD_LOGIC_VECTOR(5 DOWNTO 0);		-- Programmable PPM ajustment CRAM
   SIGNAL rforce0_freqdet           : STD_LOGIC;		-- Forcing FREQDET signal to low CRAM  
   SIGNAL rforce1_freqdet           : STD_LOGIC;		-- Forcing FREQDET signal to high CRAM
   SIGNAL rppm_cnt_reset            : STD_LOGIC;		-- PPM counter reset CRAM (latched version on Test bus)
         
   --DFE CRAMs
   SIGNAL r_dfe_1t                  : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- DFE 1st tap setting
   SIGNAL r_dfe_2t                  : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- DFE 2nd tap setting
   SIGNAL rppm_post_eidle_del       : STD_LOGIC;
   SIGNAL rppm_gen1_2xcnt_en        : STD_LOGIC; 
     
   --ADCE CRAMs
   SIGNAL reqa_set                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL reqb_set                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL reqc_set                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL reqd_set                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL reqv_set                  : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL rlock_lf_ovd              : STD_LOGIC;		-- Overdrive the dependency of ADAPT_DONE on low-frequency path
   SIGNAL rseq_sel                  : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Used to select the sequence of adaptation  (these bits for characterization only)
   SIGNAL radce_adapt               : STD_LOGIC;		-- This signal is used in conjunction with ADCE_PDB
   SIGNAL rrgen_set                 : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- These are the 3 MSB bits controlling the D2A
   SIGNAL rclkdiv                   : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- Effective division ratio for LFCLK and HFCLK
   SIGNAL rhyst_lf                  : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- Sets low-frequency path programmable digital filtering. When set to 000 the digital filter is bypassed.
   SIGNAL rdc_freq                  : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Sets corner frequency for the DC block.
   SIGNAL rhyst_hf                  : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- Sets high-frequency path programmable digital filtering. When set to 000 the digital filter is bypassed.
   SIGNAL rf_lpf                    : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Sets corner frequency for the LPF.
   SIGNAL rf_hpf                    : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Sets corner frequency for the HPF.
   SIGNAL rrgen_vod                 : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- Sets RGEN amplitude
   SIGNAL rrgen_bw                  : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Sets corner frequency of RGEN.
   SIGNAL rrect_adj                 : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Sets rectifier leaker and amplifier current.
   SIGNAL rd2a_res                  : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- Sets the D2A resolution. Default is 8 bit resolution. Adaptation time may be faster for lower resolution, but jitter may be increased.
   SIGNAL rlf_os                    : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- These bits are for characterization purposes only. These bits will allow cancellation of systematic offset in the low frequency loop
   SIGNAL rhf_os                    : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- These bits are for characterization purposes only. These bits will allow cancellation of systematic offset in the high frequency loop. 
   SIGNAL radce_rst                 : STD_LOGIC;		-- Presets counters in adaptive engine
   SIGNAL radce_pdb                 : STD_LOGIC;		-- Used in conjunction with RADCE_ADAPT
   SIGNAL radce_hflck               : STD_LOGIC_VECTOR(14 DOWNTO 0);		-- These bits are used in the HF portion of the adapt macro
   SIGNAL radce_lflck               : STD_LOGIC_VECTOR(14 DOWNTO 0);		-- These bits are used in the adapt_done macro
   SIGNAL radce_digital             : STD_LOGIC_VECTOR(9 DOWNTO 0);		-- Reserved bits
   
   --End RX CRAMs
   
   --////////////////////////////////////////////////////////////////////////
   -- end of CRAM output ---------------------------------------------------
   --////////////////////////////////////////////////////////////////////////
   
   SIGNAL targ_addr_ctrl_1          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_2          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_3          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_4          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_5          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_6          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_7          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_8          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_9          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_10         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_11         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_12         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_13         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_14         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_15         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_16         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_17         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_18         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_19         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_20         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_21         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_22         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_23         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_24         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_25         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_26         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_27         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_28         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_29         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_30         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_31         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_32         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_33         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_34         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_35         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_36         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_37         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_38         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_39         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_40         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_41         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_42         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_43         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_44         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_45         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_46         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_47         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_48         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_49         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_50         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_51         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_52         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL targ_addr_ctrl_53         : STD_LOGIC_VECTOR(15 DOWNTO 0);
   
   SIGNAL out_chnl_ctrl_1           : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_2           : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_3           : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_4           : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_5           : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_6           : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_7           : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_8           : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_9           : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_10          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_11          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_12          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_13          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_14          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_15          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_16          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_17          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_18          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_19          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_20          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_21          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_22          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_23          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_24          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_25          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_26          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_27          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_28          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_29          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_30          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_31          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_32          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_33          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_34          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_35          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_36          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_37          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_38          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_39          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_40          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_41          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_42          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_43          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_44          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_45          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_46          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_47          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_48          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_49          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_50          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_51          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_52          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_chnl_ctrl_53          : STD_LOGIC_VECTOR(15 DOWNTO 0);
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL so_xhdl54                 : STD_LOGIC;
   SIGNAL mbus_out_xhdl53           : STD_LOGIC_VECTOR(15 DOWNTO 0);
BEGIN
   -- Drive referenced outputs
   so <= so_xhdl54;
   mbus_out <= mbus_out_xhdl53;
   
   --////////////////////////////////////////////////////////////////////////
   -- begin of CRAM output -------------------------------------------------
   --////////////////////////////////////////////////////////////////////////
   
   dp_chnl_out(15 DOWNTO 0) <= out_chnl_ctrl_1;
   dp_chnl_out(31 DOWNTO 16) <= out_chnl_ctrl_2;
   dp_chnl_out(47 DOWNTO 32) <= out_chnl_ctrl_3;
   dp_chnl_out(63 DOWNTO 48) <= out_chnl_ctrl_4;
   dp_chnl_out(79 DOWNTO 64) <= out_chnl_ctrl_5;
   dp_chnl_out(95 DOWNTO 80) <= out_chnl_ctrl_6;
   dp_chnl_out(111 DOWNTO 96) <= out_chnl_ctrl_7;
   dp_chnl_out(127 DOWNTO 112) <= out_chnl_ctrl_8;
   dp_chnl_out(143 DOWNTO 128) <= out_chnl_ctrl_9;
   dp_chnl_out(159 DOWNTO 144) <= out_chnl_ctrl_10;
   dp_chnl_out(175 DOWNTO 160) <= out_chnl_ctrl_11;
   dp_chnl_out(191 DOWNTO 176) <= out_chnl_ctrl_12;
   dp_chnl_out(207 DOWNTO 192) <= out_chnl_ctrl_13;
   dp_chnl_out(223 DOWNTO 208) <= out_chnl_ctrl_14;
   dp_chnl_out(239 DOWNTO 224) <= out_chnl_ctrl_15;
   dp_chnl_out(255 DOWNTO 240) <= out_chnl_ctrl_16;
   dp_chnl_out(271 DOWNTO 256) <= out_chnl_ctrl_17;
   dp_chnl_out(287 DOWNTO 272) <= out_chnl_ctrl_18;
   dp_chnl_out(303 DOWNTO 288) <= out_chnl_ctrl_19;
   dp_chnl_out(319 DOWNTO 304) <= out_chnl_ctrl_20;
   dp_chnl_out(335 DOWNTO 320) <= out_chnl_ctrl_21;
   dp_chnl_out(351 DOWNTO 336) <= out_chnl_ctrl_22;
   dp_chnl_out(367 DOWNTO 352) <= out_chnl_ctrl_23;
   dp_chnl_out(383 DOWNTO 368) <= out_chnl_ctrl_24;
   dp_chnl_out(399 DOWNTO 384) <= out_chnl_ctrl_25;
   dp_chnl_out(415 DOWNTO 400) <= out_chnl_ctrl_26;
   dp_chnl_out(431 DOWNTO 416) <= out_chnl_ctrl_27;
   dp_chnl_out(447 DOWNTO 432) <= out_chnl_ctrl_28;
   dp_chnl_out(463 DOWNTO 448) <= out_chnl_ctrl_29;
   dp_chnl_out(479 DOWNTO 464) <= out_chnl_ctrl_30;
   dp_chnl_out(495 DOWNTO 480) <= out_chnl_ctrl_31;
   dp_chnl_out(511 DOWNTO 496) <= out_chnl_ctrl_32;
   dp_chnl_out(527 DOWNTO 512) <= out_chnl_ctrl_33;
   dp_chnl_out(543 DOWNTO 528) <= out_chnl_ctrl_34;
   dp_chnl_out(559 DOWNTO 544) <= out_chnl_ctrl_35;
   dp_chnl_out(575 DOWNTO 560) <= out_chnl_ctrl_36;
   dp_chnl_out(591 DOWNTO 576) <= out_chnl_ctrl_37;
   dp_chnl_out(607 DOWNTO 592) <= out_chnl_ctrl_38;
   dp_chnl_out(623 DOWNTO 608) <= out_chnl_ctrl_39;
   dp_chnl_out(639 DOWNTO 624) <= out_chnl_ctrl_40;
   dp_chnl_out(655 DOWNTO 640) <= out_chnl_ctrl_41;
   dp_chnl_out(671 DOWNTO 656) <= out_chnl_ctrl_42;
   dp_chnl_out_reserved(15 DOWNTO 0) <= out_chnl_ctrl_43; -- Table43 not part of regular csr
   dp_chnl_out(687 DOWNTO 672) <= out_chnl_ctrl_44;
   dp_chnl_out(703 DOWNTO 688) <= out_chnl_ctrl_45;
   dp_chnl_out(719 DOWNTO 704) <= out_chnl_ctrl_46;
   dp_chnl_out(735 DOWNTO 720) <= out_chnl_ctrl_47;
   dp_chnl_out(751 DOWNTO 736) <= out_chnl_ctrl_48;
   dp_chnl_out(767 DOWNTO 752) <= out_chnl_ctrl_49;
   dp_chnl_out(783 DOWNTO 768) <= out_chnl_ctrl_50;
   dp_chnl_out(799 DOWNTO 784) <= out_chnl_ctrl_51;
   dp_chnl_out(815 DOWNTO 800) <= out_chnl_ctrl_52;
   dp_chnl_out(831 DOWNTO 816) <= out_chnl_ctrl_53;
   
   --////////////////////////////////////////////////////////////////////////
   -- end of CRAM output ---------------------------------------------------
   --////////////////////////////////////////////////////////////////////////
   
   -- Control register address assignment
   -- PCS channel address space
   targ_addr_ctrl_1 <= (dprio_chnl_id & "000000000000") + "0000000000000000";
   targ_addr_ctrl_2 <= (dprio_chnl_id & "000000000000") + "0000000000000001";
   targ_addr_ctrl_3 <= (dprio_chnl_id & "000000000000") + "0000000000000010";
   targ_addr_ctrl_4 <= (dprio_chnl_id & "000000000000") + "0000000000000011";
   targ_addr_ctrl_5 <= (dprio_chnl_id & "010000000000") + "0000000000000000";
   targ_addr_ctrl_6 <= (dprio_chnl_id & "010000000000") + "0000000000000001";
   targ_addr_ctrl_7 <= (dprio_chnl_id & "010000000000") + "0000000000000010";
   targ_addr_ctrl_8 <= (dprio_chnl_id & "010000000000") + "0000000000000011";
   targ_addr_ctrl_9 <= (dprio_chnl_id & "010000000000") + "0000000000000100";
   targ_addr_ctrl_10 <= (dprio_chnl_id & "010000000000") + "0000000000000101";
   targ_addr_ctrl_11 <= (dprio_chnl_id & "010000000000") + "0000000000000110";
   targ_addr_ctrl_12 <= (dprio_chnl_id & "010000000000") + "0000000000000111";
   targ_addr_ctrl_13 <= (dprio_chnl_id & "010000000000") + "0000000000001000";
   targ_addr_ctrl_14 <= (dprio_chnl_id & "010000000000") + "0000000000001001";
   targ_addr_ctrl_15 <= (dprio_chnl_id & "010000000000") + "0000000000001010";
   targ_addr_ctrl_16 <= (dprio_chnl_id & "010000000000") + "0000000000001011";
   targ_addr_ctrl_17 <= (dprio_chnl_id & "010000000000") + "0000000000001100";
   targ_addr_ctrl_18 <= (dprio_chnl_id & "010000000000") + "0000000000001101";
   targ_addr_ctrl_19 <= (dprio_chnl_id & "010000000000") + "0000000000001110";
   targ_addr_ctrl_20 <= (dprio_chnl_id & "010000000000") + "0000000000001111";
   targ_addr_ctrl_21 <= (dprio_chnl_id & "010000000000") + "0000000000010000";
   targ_addr_ctrl_22 <= (dprio_chnl_id & "010000000000") + "0000000000010001";
   targ_addr_ctrl_23 <= (dprio_chnl_id & "010000000000") + "0000000000010010";
   targ_addr_ctrl_24 <= (dprio_chnl_id & "010000000000") + "0000000000010011";
   targ_addr_ctrl_25 <= (dprio_chnl_id & "010000000000") + "0000000000010100";
   targ_addr_ctrl_26 <= (dprio_chnl_id & "010000000000") + "0000000000010101";
   targ_addr_ctrl_27 <= (dprio_chnl_id & "010000000000") + "0000000000010110";
   
   -- PMA channel address space
   targ_addr_ctrl_28 <= (dprio_chnl_id & "100000000000") + "0000000000000000";
   targ_addr_ctrl_29 <= (dprio_chnl_id & "100000000000") + "0000000000000001";
   targ_addr_ctrl_30 <= (dprio_chnl_id & "100000000000") + "0000000000000010";
   targ_addr_ctrl_31 <= (dprio_chnl_id & "100000000000") + "0000000000000011";
   targ_addr_ctrl_32 <= (dprio_chnl_id & "100000000000") + "0000000000000100";
   targ_addr_ctrl_33 <= (dprio_chnl_id & "100000000000") + "0000000000000101";
   targ_addr_ctrl_34 <= (dprio_chnl_id & "100000000000") + "0000000000000110";
   targ_addr_ctrl_35 <= (dprio_chnl_id & "100000000000") + "0000000000000111";
   targ_addr_ctrl_36 <= (dprio_chnl_id & "110000000000") + "0000000000000000";
   targ_addr_ctrl_37 <= (dprio_chnl_id & "110000000000") + "0000000000000001";
   targ_addr_ctrl_38 <= (dprio_chnl_id & "110000000000") + "0000000000000010";
   targ_addr_ctrl_39 <= (dprio_chnl_id & "110000000000") + "0000000000000011";
   targ_addr_ctrl_40 <= (dprio_chnl_id & "110000000000") + "0000000000000100";
   targ_addr_ctrl_41 <= (dprio_chnl_id & "110000000000") + "0000000000000101";
   targ_addr_ctrl_42 <= (dprio_chnl_id & "110000000000") + "0000000000000110";
   targ_addr_ctrl_43 <= (dprio_chnl_id & "110000000000") + "0000000000000111";
   targ_addr_ctrl_44 <= (dprio_chnl_id & "110000000000") + "0000000000001000";
   targ_addr_ctrl_45 <= (dprio_chnl_id & "110000000000") + "0000000000001001";
   targ_addr_ctrl_46 <= (dprio_chnl_id & "110000000000") + "0000000000001010";
   targ_addr_ctrl_47 <= (dprio_chnl_id & "110000000000") + "0000000000001011";
   targ_addr_ctrl_48 <= (dprio_chnl_id & "110000000000") + "0000000000001100";
   targ_addr_ctrl_49 <= (dprio_chnl_id & "110000000000") + "0000000000001101";
   targ_addr_ctrl_50 <= (dprio_chnl_id & "110000000000") + "0000000000001110";
   targ_addr_ctrl_51 <= (dprio_chnl_id & "110000000000") + "0000000000001111";
   targ_addr_ctrl_52 <= (dprio_chnl_id & "110000000000") + "0000000000010000";
   targ_addr_ctrl_53 <= (dprio_chnl_id & "110000000000") + "0000000000010001";
 
   -- CRAM output assignment
   -- TX PCS CRAMs
   -- TX PCS Per channel control register 1
   rforce_kchar <= out_chnl_ctrl_1(15);
   rforce_echar <= out_chnl_ctrl_1(14);
   rtxfifo_dis <= out_chnl_ctrl_1(13);
   rib_force_disp <= out_chnl_ctrl_1(12);
   rtxfifo_lowlatency_en <= out_chnl_ctrl_1(11);
   rdwidth_tx <= out_chnl_ctrl_1(10);
   rge_xaui_tx <= out_chnl_ctrl_1(9);
   rphfifopldentx <= out_chnl_ctrl_1(8);
   rphfifoursttx <= out_chnl_ctrl_1(7);
   rtxurstpcs <= out_chnl_ctrl_1(5);
   rfreerun_tx <= out_chnl_ctrl_1(4);
   rtxwrclksel <= out_chnl_ctrl_1(3);
   rtxrdclksel <= out_chnl_ctrl_1(2);
   rrev_loopbk <= out_chnl_ctrl_1(1);
   rforce_disp <= out_chnl_ctrl_1(0);
   -- TX PCS Per channel control register 2
   rendec_tx <= out_chnl_ctrl_2(15);
   r8b10b_enc_ibm_en <= out_chnl_ctrl_2(14);
   rcascaded_8b10b_en_tx <= out_chnl_ctrl_2(13);
   rensymswap_tx <= out_chnl_ctrl_2(12);
   renpolinv_tx <= out_chnl_ctrl_2(11);
   renbitrev_tx <= out_chnl_ctrl_2(10);
   rprbsen_tx <= out_chnl_ctrl_2(9);
   rprbs_sel <= out_chnl_ctrl_2(8 DOWNTO 6);
   rbisten_tx <= out_chnl_ctrl_2(5);
   rbist_sel <= out_chnl_ctrl_2(4 DOWNTO 3);
   rcxpat_chnl_en <= out_chnl_ctrl_2(2 DOWNTO 1);
   rtxpcsbypass_en <= out_chnl_ctrl_2(0);
   -- TX PCS Per channel control register 3
   rtx_pipe_enable <= out_chnl_ctrl_3(15);
   rtx_idle_delay <= out_chnl_ctrl_3(14 DOWNTO 12);
   rtxswing_sel_ena <= out_chnl_ctrl_3(11);
   rtxpcsclkpwdn <= out_chnl_ctrl_3(10);
   rcid_pattern_tx <= out_chnl_ctrl_3(9);
   rcid_len_tx <= out_chnl_ctrl_3(8 DOWNTO 1);
   
   -- TX PCS Per channel control register 4
   rself_sw_en_tx <= out_chnl_ctrl_4(15);
   rpipeline_bypass_tx <= out_chnl_ctrl_4(14);
   rphfifo_regmode_tx <= out_chnl_ctrl_4(13);
   rtxbitslip_en <= out_chnl_ctrl_4(12);
   
   -- RX PCS CRAMs
   -- RX PCS Per channel control register 1
   rrxurstpcs <= out_chnl_ctrl_5(14);
   rfreerun_rx <= out_chnl_ctrl_5(13);
   rrcvd_clk_sel <= out_chnl_ctrl_5(12 DOWNTO 11);
   rclk_1_sel <= out_chnl_ctrl_5(10 DOWNTO 9);
   rclk_2_sel <= out_chnl_ctrl_5(8 DOWNTO 7);
   rrx_rd_clk_sel <= out_chnl_ctrl_5(6);
   rprbsen_rx <= out_chnl_ctrl_5(5);
   rprbs_clr_rslt_rx <= out_chnl_ctrl_5(4);
   rbisten_rx <= out_chnl_ctrl_5(3);
   rbist_clr_rx <= out_chnl_ctrl_5(2);
   rall_one_dect_only <= out_chnl_ctrl_5(1);
   rrxpcsbypass_en <= out_chnl_ctrl_5(0);
   -- RX PCS Per channel control register 2
   resync_badcg_en <= out_chnl_ctrl_6(15 DOWNTO 14);
   rencdt_rising <= out_chnl_ctrl_6(13);
   rdis_rx_disp <= out_chnl_ctrl_6(12);
   rcomp_pat_porn <= out_chnl_ctrl_6(11);
   rcomp_size <= out_chnl_ctrl_6(10 DOWNTO 8);
   rcomp_pat(39 DOWNTO 32) <= out_chnl_ctrl_6(7 DOWNTO 0);
   -- RX PCS Per channel control register 3
   rcomp_pat(31 DOWNTO 16) <= out_chnl_ctrl_7(15 DOWNTO 0);
   -- RX PCS Per channel control register 4
   rcomp_pat(15 DOWNTO 0) <= out_chnl_ctrl_8(15 DOWNTO 0);
   -- RX PCS Per channel control register 5
   rsync_sm_dis <= out_chnl_ctrl_9(15);
   rib_inv_cd <= out_chnl_ctrl_9(14 DOWNTO 13);
   renumber <= out_chnl_ctrl_9(12 DOWNTO 7);
   rkchar <= out_chnl_ctrl_9(6);
   rosbased <= out_chnl_ctrl_9(5);
   rosnumber <= out_chnl_ctrl_9(4 DOWNTO 3);
   rwa_6g_en <= out_chnl_ctrl_9(2);
   rbysync_polinv_en <= out_chnl_ctrl_9(1);
   rbitloc_rev_en <= out_chnl_ctrl_9(0);
   -- RX PCS Per channel control register 6
   rgnumber <= out_chnl_ctrl_10(15 DOWNTO 8);
   rknumber <= out_chnl_ctrl_10(7 DOWNTO 0);
   -- RX PCS Per channel control register 7
   rrundisp <= out_chnl_ctrl_11(15 DOWNTO 10);
   rbyte_rev_en <= out_chnl_ctrl_11(9);
   rforce_sig_det_pcs <= out_chnl_ctrl_11(8);
   rlp20ben <= out_chnl_ctrl_11(7);
   rrlv_en <= out_chnl_ctrl_11(6);
   rautobtalg_dis <= out_chnl_ctrl_11(5);
   rendec_rx <= out_chnl_ctrl_11(4);
   r8b10b_dec_ibm_en <= out_chnl_ctrl_11(3 DOWNTO 2);
   rcascaded_8b10b_en_rx <= out_chnl_ctrl_11(1);
   renpolinv_rx <= out_chnl_ctrl_11(0);
   -- RX PCS Per channel control register 8
   rmatchen <= out_chnl_ctrl_12(15);
   rgenericfifo <= out_chnl_ctrl_12(14);
   rskpsetbased <= out_chnl_ctrl_12(13);
   rtruebac2bac <= out_chnl_ctrl_12(12);
   rclkcmpinsertpad <= out_chnl_ctrl_12(11);
   rclkcmpsqmd <= out_chnl_ctrl_12(10);
   rclkcmpsq1p(9 DOWNTO 0) <= out_chnl_ctrl_12(9 DOWNTO 0);
   -- RX PCS Per channel control register 9
   rclkcmpsq1p(19 DOWNTO 10) <= out_chnl_ctrl_13(9 DOWNTO 0);
   rclkcmpsq1n(19 DOWNTO 15) <= out_chnl_ctrl_13(15 DOWNTO 11);
   -- RX PCS Per channel control register 10
   rclkcmpsq1n(14 DOWNTO 10) <= out_chnl_ctrl_14(15 DOWNTO 11);
   rclkcmpsq1n(9 DOWNTO 0) <= out_chnl_ctrl_14(9 DOWNTO 0);
   -- RX PCS Per channel control register 11
   rclkcmp_pipe_en <= out_chnl_ctrl_15(15);
   rins_threshold <= out_chnl_ctrl_15(14 DOWNTO 10);
   rdel_threshold <= out_chnl_ctrl_15(9 DOWNTO 5);
   rfull_threshold <= out_chnl_ctrl_15(4 DOWNTO 0);
   -- RX PCS Per channel control register 12
   rempty_threshold <= out_chnl_ctrl_16(15 DOWNTO 13);
   rstart_threshold <= out_chnl_ctrl_16(12 DOWNTO 10);
   rpma_done_count(17 DOWNTO 16) <= out_chnl_ctrl_16(5 DOWNTO 4);
   rpma_done_gen_ena <= out_chnl_ctrl_16(3);
   rhip_ena <= out_chnl_ctrl_16(2);
   rauto_speed_ena <= out_chnl_ctrl_16(1);
   rfreq_sel <= out_chnl_ctrl_16(0);
   -- RX PCS Per channel control register 13
   rrxfifo_dis <= out_chnl_ctrl_17(15);
   rrxfifo_lowlatency_en <= out_chnl_ctrl_17(14);
   rdwidth_rx <= out_chnl_ctrl_17(13);
   rphfifourstrx <= out_chnl_ctrl_17(12);
   rcmpfifourst <= out_chnl_ctrl_17(11);
   rinvalid_code_err_only <= out_chnl_ctrl_17(10);
   rbytord_2sym_en <= out_chnl_ctrl_17(9);
   rbyteorden <= out_chnl_ctrl_17(8 DOWNTO 7);
   rbytordplden <= out_chnl_ctrl_17(6);
   rphfifopldenrx <= out_chnl_ctrl_17(5);
   rautoinsdis <= out_chnl_ctrl_17(4);
   rtest_bus_sel(3 DOWNTO 0) <= out_chnl_ctrl_17(3 DOWNTO 0);
   -- RX PCS Per channel control register 14
   rbytordpat(9 DOWNTO 0) <= out_chnl_ctrl_18(9 DOWNTO 0);
   -- RX PCS Per channel control register 15
   rbytordpad <= out_chnl_ctrl_19(9 DOWNTO 0);
   -- RX PCS Per channel control register 16
   rrx_pipe_enable <= out_chnl_ctrl_20(15);
   rrx_detect_bypass <= out_chnl_ctrl_20(14);
   rind_error_reporting <= out_chnl_ctrl_20(13);
   rphystatus_delay <= out_chnl_ctrl_20(12 DOWNTO 10);
   reidleinferenable <= out_chnl_ctrl_20(9);
   rk285detect <= out_chnl_ctrl_20(8);
   reidle_com_detect <= out_chnl_ctrl_20(7 DOWNTO 6);
   rphystatus_rst_toggle <= out_chnl_ctrl_20(5);
   rload_shreg_del <= out_chnl_ctrl_20(4 DOWNTO 0);
   -- RX PCS Per channel control register 17
   rpma_done_count(15 DOWNTO 0) <= out_chnl_ctrl_21(15 DOWNTO 0);
   -- RX PCS Per channel control register 18
   rrxpcsclkpwdn <= out_chnl_ctrl_22(14);
   rcdr_ctrl_en <= out_chnl_ctrl_22(13);
   rbytord_s2gx <= out_chnl_ctrl_22(11);
   rbytord_6g_mask_en <= out_chnl_ctrl_22(10);
   rbytordpat(19 DOWNTO 10) <= out_chnl_ctrl_22(9 DOWNTO 0);
   -- RX PCS Per channel control register 19
   rwait_count(7 DOWNTO 0) <= out_chnl_ctrl_23(7 DOWNTO 0);
   -- RX PCS Per channel control register 20
   rwait_for_phfifo_cnt(3 DOWNTO 0) <= out_chnl_ctrl_24(13 DOWNTO 10);
   rfts_count(9 DOWNTO 0) <= out_chnl_ctrl_24(9 DOWNTO 0);
   -- RX PCS Per channel control register 21
   rcid_pattern_rx <= out_chnl_ctrl_25(9);
   rcid_len_rx(7 DOWNTO 0) <= out_chnl_ctrl_25(8 DOWNTO 1);
   rppm_meas_delay <= out_chnl_ctrl_25(0);
   -- RX PCS Per channel control register 22
   rphfifo_regmode_rx <= out_chnl_ctrl_26(15);
   rcid_en <= out_chnl_ctrl_26(14);
   rrxvalid_mask <= out_chnl_ctrl_26(13);
   rself_sw_en_rx <= out_chnl_ctrl_26(12);
   rpipeline_bypass_rx <= out_chnl_ctrl_26(11);
   rauto_deassert_pc_rst_cnt(3 DOWNTO 0) <= out_chnl_ctrl_26(9 DOWNTO 6);
   rauto_pc_en_cnt(4 DOWNTO 0) <= out_chnl_ctrl_26(4 DOWNTO 0);
   -- RX PCS Per channel control register 23
   riei_eios_priority_dis <= out_chnl_ctrl_27(11);
   rgen1_sigdet_ena <= out_chnl_ctrl_27(10);
   rmask_count(9 DOWNTO 0) <= out_chnl_ctrl_27(9 DOWNTO 0);
   
   --End PCS CRAMs
   
   -- TX PMA CRAMs
   -- TX PMA Per channel control register 1
   rvod_sel_non_pcie(2 DOWNTO 0) <= out_chnl_ctrl_28(15 DOWNTO 13);
   rvod_sela(2 DOWNTO 0) <= out_chnl_ctrl_28(12 DOWNTO 10);
   rvod_selb(2 DOWNTO 0) <= out_chnl_ctrl_28(9 DOWNTO 7);
   rvod_selc(2 DOWNTO 0) <= out_chnl_ctrl_28(6 DOWNTO 4);
   rvod_seld(2 DOWNTO 0) <= out_chnl_ctrl_28(3 DOWNTO 1);
   rpowdnt <= out_chnl_ctrl_28(0);
   -- TX PMA Per channel control register 2
   rpre_em_1t_no_pcie(4 DOWNTO 0) <= out_chnl_ctrl_29(15 DOWNTO 11);
   rpre_em_1t_a(4 DOWNTO 0) <= out_chnl_ctrl_29(10 DOWNTO 6);
   rpre_em_1t_b(4 DOWNTO 0) <= out_chnl_ctrl_29(5 DOWNTO 1);
   -- TX PMA Per channel control register 3
   rpre_em_1t_c(4 DOWNTO 0) <= out_chnl_ctrl_30(12 DOWNTO 8);
   rpre_em_2t(3 DOWNTO 0) <= out_chnl_ctrl_30(7 DOWNTO 4);
   rpre_em_pt(3 DOWNTO 0) <= out_chnl_ctrl_30(3 DOWNTO 0);
   -- TX PMA Per channel control register 4
   rtx_term_sel(2 DOWNTO 0) <= out_chnl_ctrl_31(15 DOWNTO 13);
   rtx_vtt(1 DOWNTO 0) <= out_chnl_ctrl_31(12 DOWNTO 11);
   rtx_lst(3 DOWNTO 0) <= out_chnl_ctrl_31(10 DOWNTO 7);
   rslew(1 DOWNTO 0) <= out_chnl_ctrl_31(6 DOWNTO 5);
   rsig_inv_ptap <= out_chnl_ctrl_31(4);
   rsig_inv_2t <= out_chnl_ctrl_31(3);
   rrx_det(1 DOWNTO 0) <= out_chnl_ctrl_31(2 DOWNTO 1);
   rlowv <= out_chnl_ctrl_31(0);
   -- TX PMA Per channel control register 5
   r_dft_sel(2 DOWNTO 0) <= out_chnl_ctrl_32(15 DOWNTO 13);
   rtx_ob_pdb <= out_chnl_ctrl_32(11);
   -- TX PMA Per channel control register 6
   rcgb_x_en(1 DOWNTO 0) <= out_chnl_ctrl_33(15 DOWNTO 14);
   rcgb_cmu_sel <= out_chnl_ctrl_33(13);
   rcgb_m_sel(1 DOWNTO 0) <= out_chnl_ctrl_33(12 DOWNTO 11);
   rpma_doublewidth_tx <= out_chnl_ctrl_33(10);
   rpmadwidth_tx <= out_chnl_ctrl_33(9);
   rcgb_delay_sel <= out_chnl_ctrl_33(8);
   rs_lpbk <= out_chnl_ctrl_33(7);
   rdynamic_sw <= out_chnl_ctrl_33(6);
   rpclksel <= out_chnl_ctrl_33(5);
   rtx_cgb_pdb <= out_chnl_ctrl_33(4);
   -- TX PMA Per channel control register 7
   riqclk_sel(1 DOWNTO 0) <= out_chnl_ctrl_34(15 DOWNTO 14);
   rrefclk_sel(1 DOWNTO 0) <= out_chnl_ctrl_34(13 DOWNTO 12);
   rvcobypass <= out_chnl_ctrl_34(11);
   rrevlb_sw <= out_chnl_ctrl_34(10);
   rimpctrl <= out_chnl_ctrl_34(5);
   rrx_refclk <= out_chnl_ctrl_34(4);
   rpcs_sd_sel <= out_chnl_ctrl_34(3);
   -- TX PMA Per channel control register 8
   rpma_reserved(31 DOWNTO 16) <= out_chnl_ctrl_35(15 DOWNTO 0);
   
   --RX PMA CRAMs
   -- RX PMA Per channel control register 1
   rrx_lst(4 DOWNTO 0) <= out_chnl_ctrl_36(15 DOWNTO 11);
   rrx_bit_dc(3 DOWNTO 0) <= out_chnl_ctrl_36(10 DOWNTO 7);
   rrx_s_rdlpbk <= out_chnl_ctrl_36(6);
   rrx_vtt(2 DOWNTO 0) <= out_chnl_ctrl_36(5 DOWNTO 3);
   rrx_term_sel(2 DOWNTO 0) <= out_chnl_ctrl_36(2 DOWNTO 0);
   -- RX PMA Per channel control register 2
   rrx_sdlv(3 DOWNTO 0) <= out_chnl_ctrl_37(15 DOWNTO 12);
   rrx_oc_en <= out_chnl_ctrl_37(11);
   rrx_oc(7 DOWNTO 0) <= out_chnl_ctrl_37(10 DOWNTO 3);
   rrx_sd_force <= out_chnl_ctrl_37(2);
   rrx_test <= out_chnl_ctrl_37(1);
   rrxurstpma <= out_chnl_ctrl_37(0);
   -- RX PMA Per channel control register 3
   rrx_sd_on(3 DOWNTO 0) <= out_chnl_ctrl_38(15 DOWNTO 12);
   rrx_sd_off(4 DOWNTO 0) <= out_chnl_ctrl_38(11 DOWNTO 7);
   rrx_oc_calpd <= out_chnl_ctrl_38(6);
   rurx_pdb <= out_chnl_ctrl_38(5);
   rrx_ib_pdb <= out_chnl_ctrl_38(4);
   rpowdnr <= out_chnl_ctrl_38(3);
   -- RX PMA Per channel control register 4
   rcru_div2 <= out_chnl_ctrl_39(15);
   rcru_m_sel(1 DOWNTO 0) <= out_chnl_ctrl_39(14 DOWNTO 13);
   rcru_m(3 DOWNTO 0) <= out_chnl_ctrl_39(12 DOWNTO 9);
   rcru_l(1 DOWNTO 0) <= out_chnl_ctrl_39(8 DOWNTO 7);
   rcru_ctl0 <= out_chnl_ctrl_39(6);
   rcru_crplctrl(1 DOWNTO 0) <= out_chnl_ctrl_39(5 DOWNTO 4);
   rcru_pfdbwctrl(1 DOWNTO 0) <= out_chnl_ctrl_39(3 DOWNTO 2);
   rcru_pdbwctrl(1 DOWNTO 0) <= out_chnl_ctrl_39(1 DOWNTO 0);
   -- RX PMA Per channel control register 5
   rcru_rlbk <= out_chnl_ctrl_40(15);
   rcru_lst(3 DOWNTO 0) <= out_chnl_ctrl_40(14 DOWNTO 11);
   rcru_testen <= out_chnl_ctrl_40(10);
   rcru_testupen <= out_chnl_ctrl_40(9);
   rcru_testdnen <= out_chnl_ctrl_40(8);
   rcru_isel(2 DOWNTO 0) <= out_chnl_ctrl_40(7 DOWNTO 5);
   rcru_iselpd(2 DOWNTO 0) <= out_chnl_ctrl_40(4 DOWNTO 2);
   -- RX PMA Per channel control register 6
   rcp_mode <= out_chnl_ctrl_41(15);
   rltd <= out_chnl_ctrl_41(14);
   rltr <= out_chnl_ctrl_41(13);
   rrx_cru_pdb <= out_chnl_ctrl_41(12);
   rrx_cru_rst <= out_chnl_ctrl_41(11);
   rcru_cmu_mode <= out_chnl_ctrl_41(10);
   rcru_ignore_phslck <= out_chnl_ctrl_41(9);
   rcru_sd_sel <= out_chnl_ctrl_41(7);
   rcru_pdfl <= out_chnl_ctrl_41(6);
   rcru_pdof_test(2 DOWNTO 0) <= out_chnl_ctrl_41(5 DOWNTO 3);
   rcru_rgla_isel(2 DOWNTO 0) <= out_chnl_ctrl_41(2 DOWNTO 0);
   -- RX PMA Per channel control register 7
   rcru_pdof_0i(3 DOWNTO 0) <= out_chnl_ctrl_42(15 DOWNTO 12);
   rcru_pdof_90i(3 DOWNTO 0) <= out_chnl_ctrl_42(11 DOWNTO 8);
   rcru_pdof_180i(3 DOWNTO 0) <= out_chnl_ctrl_42(7 DOWNTO 4);
   rcru_pdof_270i(3 DOWNTO 0) <= out_chnl_ctrl_42(3 DOWNTO 0);
   -- RX PMA Per channel control register 8
   --reye_monitor(7 DOWNTO 0)  =out_chnl_ctrl_43[7:0];
   -- RX PMA Per channel control register 9
   rpma_reserved(15 DOWNTO 0) <= out_chnl_ctrl_44(15 DOWNTO 0);
   -- RX PMA Per channel control register 10
   rpma_doublewidth_rx <= out_chnl_ctrl_45(15);
   rpmadwidth_rx <= out_chnl_ctrl_45(14);
   rtest_fastsd <= out_chnl_ctrl_45(13);
   rfastsd(3 DOWNTO 0) <= out_chnl_ctrl_45(12 DOWNTO 9);
   rppmsel(5 DOWNTO 0) <= out_chnl_ctrl_45(8 DOWNTO 3);
   rforce0_freqdet <= out_chnl_ctrl_45(2);
   rforce1_freqdet <= out_chnl_ctrl_45(1);
   rppm_cnt_reset <= out_chnl_ctrl_45(0);
   -- RX PMA Per channel control register 11
   r_dfe_1t(2 DOWNTO 0) <= out_chnl_ctrl_46(15 DOWNTO 13);
   r_dfe_2t(2 DOWNTO 0) <= out_chnl_ctrl_46(12 DOWNTO 10);
   rppm_post_eidle_del <= out_chnl_ctrl_46(9);
   rppm_gen1_2xcnt_en <= out_chnl_ctrl_46(8);
   -- RX PMA Per channel control register 12
   reqa_set <= out_chnl_ctrl_47(14 DOWNTO 12);
   reqb_set <= out_chnl_ctrl_47(11 DOWNTO 9);
   reqc_set <= out_chnl_ctrl_47(8 DOWNTO 6);
   reqd_set <= out_chnl_ctrl_47(5 DOWNTO 3);
   reqv_set <= out_chnl_ctrl_47(2 DOWNTO 0);
   -- RX PMA Per channel control register 13
   rlock_lf_ovd <= out_chnl_ctrl_48(15);
   rseq_sel(1 DOWNTO 0) <= out_chnl_ctrl_48(14 DOWNTO 13);
   radce_adapt <= out_chnl_ctrl_48(12);
   rrgen_set(2 DOWNTO 0) <= out_chnl_ctrl_48(11 DOWNTO 9);
   rclkdiv(3 DOWNTO 0) <= out_chnl_ctrl_48(8 DOWNTO 5);
   rhyst_lf(2 DOWNTO 0) <= out_chnl_ctrl_48(4 DOWNTO 2);
   rdc_freq(1 DOWNTO 0) <= out_chnl_ctrl_48(1 DOWNTO 0);
   -- RX PMA Per channel control register 14
   rhyst_hf(2 DOWNTO 0) <= out_chnl_ctrl_49(15 DOWNTO 13);
   rf_lpf(1 DOWNTO 0) <= out_chnl_ctrl_49(6 DOWNTO 5);
   rf_hpf(1 DOWNTO 0) <= out_chnl_ctrl_49(4 DOWNTO 3);
   rrgen_vod(2 DOWNTO 0) <= out_chnl_ctrl_49(2 DOWNTO 0);
   -- RX PMA Per channel control register 15
   rrgen_bw(1 DOWNTO 0) <= out_chnl_ctrl_50(15 DOWNTO 14);
   rrect_adj(1 DOWNTO 0) <= out_chnl_ctrl_50(13 DOWNTO 12);
   rd2a_res(1 DOWNTO 0) <= out_chnl_ctrl_50(11 DOWNTO 10);
   rlf_os(3 DOWNTO 0) <= out_chnl_ctrl_50(9 DOWNTO 6);
   rhf_os(3 DOWNTO 0) <= out_chnl_ctrl_50(5 DOWNTO 2);
   radce_rst <= out_chnl_ctrl_50(1);
   radce_pdb <= out_chnl_ctrl_50(0);
   -- RX PMA Per channel control register 16
   radce_hflck(14 DOWNTO 0) <= out_chnl_ctrl_51(14 DOWNTO 0);
   -- RX PMA Per channel control register 16
   radce_lflck(14 DOWNTO 0) <= out_chnl_ctrl_52(14 DOWNTO 0);
   -- RX PMA Per channel control register 18
   radce_digital <= out_chnl_ctrl_53(9 DOWNTO 0);
   
   
   
   reg_chnl_inst : stratixiv_hssi_cmu_dprio_reg_chnl
      PORT MAP (
         mdio_rst           => mdio_rst,
         mdio_wr            => mdio_wr,
         reg_addr           => reg_addr,
         mdc                => mdc,
         mbus_in            => mbus_in,
         serial_mode        => serial_mode,
         mdio_dis           => mdio_dis,
         pma_cram_test      => pma_cram_test,
         ser_shift_load     => ser_shift_load,
         si                 => si,
         -- CSR input
         ext_chnl_ctrl_1    => csr_chnl_in(15 DOWNTO 0),
         ext_chnl_ctrl_2    => csr_chnl_in(31 DOWNTO 16),
         ext_chnl_ctrl_3    => csr_chnl_in(47 DOWNTO 32),
         ext_chnl_ctrl_4    => csr_chnl_in(63 DOWNTO 48),
         ext_chnl_ctrl_5    => csr_chnl_in(79 DOWNTO 64),
         ext_chnl_ctrl_6    => csr_chnl_in(95 DOWNTO 80),
         ext_chnl_ctrl_7    => csr_chnl_in(111 DOWNTO 96),
         ext_chnl_ctrl_8    => csr_chnl_in(127 DOWNTO 112),
         ext_chnl_ctrl_9    => csr_chnl_in(143 DOWNTO 128),
         ext_chnl_ctrl_10   => csr_chnl_in(159 DOWNTO 144),
         ext_chnl_ctrl_11   => csr_chnl_in(175 DOWNTO 160),
         ext_chnl_ctrl_12   => csr_chnl_in(191 DOWNTO 176),
         ext_chnl_ctrl_13   => csr_chnl_in(207 DOWNTO 192),
         ext_chnl_ctrl_14   => csr_chnl_in(223 DOWNTO 208),
         ext_chnl_ctrl_15   => csr_chnl_in(239 DOWNTO 224),
         ext_chnl_ctrl_16   => csr_chnl_in(255 DOWNTO 240),
         ext_chnl_ctrl_17   => csr_chnl_in(271 DOWNTO 256),
         ext_chnl_ctrl_18   => csr_chnl_in(287 DOWNTO 272),
         ext_chnl_ctrl_19   => csr_chnl_in(303 DOWNTO 288),
         ext_chnl_ctrl_20   => csr_chnl_in(319 DOWNTO 304),
         ext_chnl_ctrl_21   => csr_chnl_in(335 DOWNTO 320),
         ext_chnl_ctrl_22   => csr_chnl_in(351 DOWNTO 336),
         ext_chnl_ctrl_23   => csr_chnl_in(367 DOWNTO 352),
         ext_chnl_ctrl_24   => csr_chnl_in(383 DOWNTO 368),
         ext_chnl_ctrl_25   => csr_chnl_in(399 DOWNTO 384),
         ext_chnl_ctrl_26   => csr_chnl_in(415 DOWNTO 400),
         ext_chnl_ctrl_27   => csr_chnl_in(431 DOWNTO 416),
         ext_chnl_ctrl_28   => csr_chnl_in(447 DOWNTO 432),
         ext_chnl_ctrl_29   => csr_chnl_in(463 DOWNTO 448),
         ext_chnl_ctrl_30   => csr_chnl_in(479 DOWNTO 464),
         ext_chnl_ctrl_31   => csr_chnl_in(495 DOWNTO 480),
         ext_chnl_ctrl_32   => csr_chnl_in(511 DOWNTO 496),
         ext_chnl_ctrl_33   => csr_chnl_in(527 DOWNTO 512),
         ext_chnl_ctrl_34   => csr_chnl_in(543 DOWNTO 528),
         ext_chnl_ctrl_35   => csr_chnl_in(559 DOWNTO 544),
         ext_chnl_ctrl_36   => csr_chnl_in(575 DOWNTO 560),
         ext_chnl_ctrl_37   => csr_chnl_in(591 DOWNTO 576),
         ext_chnl_ctrl_38   => csr_chnl_in(607 DOWNTO 592),
         ext_chnl_ctrl_39   => csr_chnl_in(623 DOWNTO 608),
         ext_chnl_ctrl_40   => csr_chnl_in(639 DOWNTO 624),
         ext_chnl_ctrl_41   => csr_chnl_in(655 DOWNTO 640),
         ext_chnl_ctrl_42   => csr_chnl_in(671 DOWNTO 656),
         ext_chnl_ctrl_43   => csr_chnl_in_reserved(15 DOWNTO 0),
         ext_chnl_ctrl_44   => csr_chnl_in(687 DOWNTO 672),
         ext_chnl_ctrl_45   => csr_chnl_in(703 DOWNTO 688),
         ext_chnl_ctrl_46   => csr_chnl_in(719 DOWNTO 704),
         ext_chnl_ctrl_47   => csr_chnl_in(735 DOWNTO 720),
         ext_chnl_ctrl_48   => csr_chnl_in(751 DOWNTO 736),
         ext_chnl_ctrl_49   => csr_chnl_in(767 DOWNTO 752),
         ext_chnl_ctrl_50   => csr_chnl_in(783 DOWNTO 768),
         ext_chnl_ctrl_51   => csr_chnl_in(799 DOWNTO 784),
         ext_chnl_ctrl_52   => csr_chnl_in(815 DOWNTO 800),
 		 ext_chnl_ctrl_53   => csr_chnl_in(831 DOWNTO 816),
         targ_addr_ctrl_1   => targ_addr_ctrl_1,
         targ_addr_ctrl_2   => targ_addr_ctrl_2,
         targ_addr_ctrl_3   => targ_addr_ctrl_3,
         targ_addr_ctrl_4   => targ_addr_ctrl_4,
         targ_addr_ctrl_5   => targ_addr_ctrl_5,
         targ_addr_ctrl_6   => targ_addr_ctrl_6,
         targ_addr_ctrl_7   => targ_addr_ctrl_7,
         targ_addr_ctrl_8   => targ_addr_ctrl_8,
         targ_addr_ctrl_9   => targ_addr_ctrl_9,
         targ_addr_ctrl_10  => targ_addr_ctrl_10,
         targ_addr_ctrl_11  => targ_addr_ctrl_11,
         targ_addr_ctrl_12  => targ_addr_ctrl_12,
         targ_addr_ctrl_13  => targ_addr_ctrl_13,
         targ_addr_ctrl_14  => targ_addr_ctrl_14,
         targ_addr_ctrl_15  => targ_addr_ctrl_15,
         targ_addr_ctrl_16  => targ_addr_ctrl_16,
         targ_addr_ctrl_17  => targ_addr_ctrl_17,
         targ_addr_ctrl_18  => targ_addr_ctrl_18,
         targ_addr_ctrl_19  => targ_addr_ctrl_19,
         targ_addr_ctrl_20  => targ_addr_ctrl_20,
         targ_addr_ctrl_21  => targ_addr_ctrl_21,
         targ_addr_ctrl_22  => targ_addr_ctrl_22,
         targ_addr_ctrl_23  => targ_addr_ctrl_23,
         targ_addr_ctrl_24  => targ_addr_ctrl_24,
         targ_addr_ctrl_25  => targ_addr_ctrl_25,
         targ_addr_ctrl_26  => targ_addr_ctrl_26,
         targ_addr_ctrl_27  => targ_addr_ctrl_27,
         targ_addr_ctrl_28  => targ_addr_ctrl_28,
         targ_addr_ctrl_29  => targ_addr_ctrl_29,
         targ_addr_ctrl_30  => targ_addr_ctrl_30,
         targ_addr_ctrl_31  => targ_addr_ctrl_31,
         targ_addr_ctrl_32  => targ_addr_ctrl_32,
         targ_addr_ctrl_33  => targ_addr_ctrl_33,
         targ_addr_ctrl_34  => targ_addr_ctrl_34,
         targ_addr_ctrl_35  => targ_addr_ctrl_35,
         targ_addr_ctrl_36  => targ_addr_ctrl_36,
         targ_addr_ctrl_37  => targ_addr_ctrl_37,
         targ_addr_ctrl_38  => targ_addr_ctrl_38,
         targ_addr_ctrl_39  => targ_addr_ctrl_39,
         targ_addr_ctrl_40  => targ_addr_ctrl_40,
         targ_addr_ctrl_41  => targ_addr_ctrl_41,
         targ_addr_ctrl_42  => targ_addr_ctrl_42,
         targ_addr_ctrl_43  => targ_addr_ctrl_43,
         targ_addr_ctrl_44  => targ_addr_ctrl_44,
         targ_addr_ctrl_45  => targ_addr_ctrl_45,
         targ_addr_ctrl_46  => targ_addr_ctrl_46,
         targ_addr_ctrl_47  => targ_addr_ctrl_47,
         targ_addr_ctrl_48  => targ_addr_ctrl_48,
         targ_addr_ctrl_49  => targ_addr_ctrl_49,
         targ_addr_ctrl_50  => targ_addr_ctrl_50,
         targ_addr_ctrl_51  => targ_addr_ctrl_51,
         targ_addr_ctrl_52  => targ_addr_ctrl_52,
		 targ_addr_ctrl_53  => targ_addr_ctrl_53,
         -- DPRIO register output
         out_chnl_ctrl_1    => out_chnl_ctrl_1,
         out_chnl_ctrl_2    => out_chnl_ctrl_2,
         out_chnl_ctrl_3    => out_chnl_ctrl_3,
         out_chnl_ctrl_4    => out_chnl_ctrl_4,
         out_chnl_ctrl_5    => out_chnl_ctrl_5,
         out_chnl_ctrl_6    => out_chnl_ctrl_6,
         out_chnl_ctrl_7    => out_chnl_ctrl_7,
         out_chnl_ctrl_8    => out_chnl_ctrl_8,
         out_chnl_ctrl_9    => out_chnl_ctrl_9,
         out_chnl_ctrl_10   => out_chnl_ctrl_10,
         out_chnl_ctrl_11   => out_chnl_ctrl_11,
         out_chnl_ctrl_12   => out_chnl_ctrl_12,
         out_chnl_ctrl_13   => out_chnl_ctrl_13,
         out_chnl_ctrl_14   => out_chnl_ctrl_14,
         out_chnl_ctrl_15   => out_chnl_ctrl_15,
         out_chnl_ctrl_16   => out_chnl_ctrl_16,
         out_chnl_ctrl_17   => out_chnl_ctrl_17,
         out_chnl_ctrl_18   => out_chnl_ctrl_18,
         out_chnl_ctrl_19   => out_chnl_ctrl_19,
         out_chnl_ctrl_20   => out_chnl_ctrl_20,
         out_chnl_ctrl_21   => out_chnl_ctrl_21,
         out_chnl_ctrl_22   => out_chnl_ctrl_22,
         out_chnl_ctrl_23   => out_chnl_ctrl_23,
         out_chnl_ctrl_24   => out_chnl_ctrl_24,
         out_chnl_ctrl_25   => out_chnl_ctrl_25,
         out_chnl_ctrl_26   => out_chnl_ctrl_26,
         out_chnl_ctrl_27   => out_chnl_ctrl_27,
         out_chnl_ctrl_28   => out_chnl_ctrl_28,
         out_chnl_ctrl_29   => out_chnl_ctrl_29,
         out_chnl_ctrl_30   => out_chnl_ctrl_30,
         out_chnl_ctrl_31   => out_chnl_ctrl_31,
         out_chnl_ctrl_32   => out_chnl_ctrl_32,
         out_chnl_ctrl_33   => out_chnl_ctrl_33,
         out_chnl_ctrl_34   => out_chnl_ctrl_34,
         out_chnl_ctrl_35   => out_chnl_ctrl_35,
         out_chnl_ctrl_36   => out_chnl_ctrl_36,
         out_chnl_ctrl_37   => out_chnl_ctrl_37,
         out_chnl_ctrl_38   => out_chnl_ctrl_38,
         out_chnl_ctrl_39   => out_chnl_ctrl_39,
         out_chnl_ctrl_40   => out_chnl_ctrl_40,
         out_chnl_ctrl_41   => out_chnl_ctrl_41,
         out_chnl_ctrl_42   => out_chnl_ctrl_42,
         out_chnl_ctrl_43   => out_chnl_ctrl_43,
         out_chnl_ctrl_44   => out_chnl_ctrl_44,
         out_chnl_ctrl_45   => out_chnl_ctrl_45,
         out_chnl_ctrl_46   => out_chnl_ctrl_46,
         out_chnl_ctrl_47   => out_chnl_ctrl_47,
         out_chnl_ctrl_48   => out_chnl_ctrl_48,
         out_chnl_ctrl_49   => out_chnl_ctrl_49,
         out_chnl_ctrl_50   => out_chnl_ctrl_50,
         out_chnl_ctrl_51   => out_chnl_ctrl_51,
         out_chnl_ctrl_52   => out_chnl_ctrl_52,
		 out_chnl_ctrl_53   => out_chnl_ctrl_53,

         so                 => so_xhdl54
      );
   
   -- MBUS_OUT muxing
   
   
   mbus_mux : stratixiv_hssi_cmu_dprio_chnl_bus_out_mux
      PORT MAP (
         chnl_ctrl_in1         => out_chnl_ctrl_1,
         chnl_ctrl_in2         => out_chnl_ctrl_2,
         chnl_ctrl_in3         => out_chnl_ctrl_3,
         chnl_ctrl_in4         => out_chnl_ctrl_4,
         chnl_ctrl_in5         => out_chnl_ctrl_5,
         chnl_ctrl_in6         => out_chnl_ctrl_6,
         chnl_ctrl_in7         => out_chnl_ctrl_7,
         chnl_ctrl_in8         => out_chnl_ctrl_8,
         chnl_ctrl_in9         => out_chnl_ctrl_9,
         chnl_ctrl_in10        => out_chnl_ctrl_10,
         chnl_ctrl_in11        => out_chnl_ctrl_11,
         chnl_ctrl_in12        => out_chnl_ctrl_12,
         chnl_ctrl_in13        => out_chnl_ctrl_13,
         chnl_ctrl_in14        => out_chnl_ctrl_14,
         chnl_ctrl_in15        => out_chnl_ctrl_15,
         chnl_ctrl_in16        => out_chnl_ctrl_16,
         chnl_ctrl_in17        => out_chnl_ctrl_17,
         chnl_ctrl_in18        => out_chnl_ctrl_18,
         chnl_ctrl_in19        => out_chnl_ctrl_19,
         chnl_ctrl_in20        => out_chnl_ctrl_20,
         chnl_ctrl_in21        => out_chnl_ctrl_21,
         chnl_ctrl_in22        => out_chnl_ctrl_22,
         chnl_ctrl_in23        => out_chnl_ctrl_23,
         chnl_ctrl_in24        => out_chnl_ctrl_24,
         chnl_ctrl_in25        => out_chnl_ctrl_25,
         chnl_ctrl_in26        => out_chnl_ctrl_26,
         chnl_ctrl_in27        => out_chnl_ctrl_27,
         chnl_ctrl_in28        => out_chnl_ctrl_28,
         chnl_ctrl_in29        => out_chnl_ctrl_29,
         chnl_ctrl_in30        => out_chnl_ctrl_30,
         chnl_ctrl_in31        => out_chnl_ctrl_31,
         chnl_ctrl_in32        => out_chnl_ctrl_32,
         chnl_ctrl_in33        => out_chnl_ctrl_33,
         chnl_ctrl_in34        => out_chnl_ctrl_34,
         chnl_ctrl_in35        => out_chnl_ctrl_35,
         chnl_ctrl_in36        => out_chnl_ctrl_36,
         chnl_ctrl_in37        => out_chnl_ctrl_37,
         chnl_ctrl_in38        => out_chnl_ctrl_38,
         chnl_ctrl_in39        => out_chnl_ctrl_39,
         chnl_ctrl_in40        => out_chnl_ctrl_40,
         chnl_ctrl_in41        => out_chnl_ctrl_41,
         chnl_ctrl_in42        => out_chnl_ctrl_42,
         chnl_ctrl_in43        => out_chnl_ctrl_43,
         chnl_ctrl_in44        => out_chnl_ctrl_44,
         chnl_ctrl_in45        => out_chnl_ctrl_45,
         chnl_ctrl_in46        => out_chnl_ctrl_46,
         chnl_ctrl_in47        => out_chnl_ctrl_47,
         chnl_ctrl_in48        => out_chnl_ctrl_48,
         chnl_ctrl_in49        => out_chnl_ctrl_49,
         chnl_ctrl_in50        => out_chnl_ctrl_50,
         chnl_ctrl_in51        => out_chnl_ctrl_51,
         chnl_ctrl_in52        => out_chnl_ctrl_52,
         chnl_ctrl_in53        => out_chnl_ctrl_53,
         hw_address_ctrl_in1   => targ_addr_ctrl_1,
         hw_address_ctrl_in2   => targ_addr_ctrl_2,
         hw_address_ctrl_in3   => targ_addr_ctrl_3,
         hw_address_ctrl_in4   => targ_addr_ctrl_4,
         hw_address_ctrl_in5   => targ_addr_ctrl_5,
         hw_address_ctrl_in6   => targ_addr_ctrl_6,
         hw_address_ctrl_in7   => targ_addr_ctrl_7,
         hw_address_ctrl_in8   => targ_addr_ctrl_8,
         hw_address_ctrl_in9   => targ_addr_ctrl_9,
         hw_address_ctrl_in10  => targ_addr_ctrl_10,
         hw_address_ctrl_in11  => targ_addr_ctrl_11,
         hw_address_ctrl_in12  => targ_addr_ctrl_12,
         hw_address_ctrl_in13  => targ_addr_ctrl_13,
         hw_address_ctrl_in14  => targ_addr_ctrl_14,
         hw_address_ctrl_in15  => targ_addr_ctrl_15,
         hw_address_ctrl_in16  => targ_addr_ctrl_16,
         hw_address_ctrl_in17  => targ_addr_ctrl_17,
         hw_address_ctrl_in18  => targ_addr_ctrl_18,
         hw_address_ctrl_in19  => targ_addr_ctrl_19,
         hw_address_ctrl_in20  => targ_addr_ctrl_20,
         hw_address_ctrl_in21  => targ_addr_ctrl_21,
         hw_address_ctrl_in22  => targ_addr_ctrl_22,
         hw_address_ctrl_in23  => targ_addr_ctrl_23,
         hw_address_ctrl_in24  => targ_addr_ctrl_24,
         hw_address_ctrl_in25  => targ_addr_ctrl_25,
         hw_address_ctrl_in26  => targ_addr_ctrl_26,
         hw_address_ctrl_in27  => targ_addr_ctrl_27,
         hw_address_ctrl_in28  => targ_addr_ctrl_28,
         hw_address_ctrl_in29  => targ_addr_ctrl_29,
         hw_address_ctrl_in30  => targ_addr_ctrl_30,
         hw_address_ctrl_in31  => targ_addr_ctrl_31,
         hw_address_ctrl_in32  => targ_addr_ctrl_32,
         hw_address_ctrl_in33  => targ_addr_ctrl_33,
         hw_address_ctrl_in34  => targ_addr_ctrl_34,
         hw_address_ctrl_in35  => targ_addr_ctrl_35,
         hw_address_ctrl_in36  => targ_addr_ctrl_36,
         hw_address_ctrl_in37  => targ_addr_ctrl_37,
         hw_address_ctrl_in38  => targ_addr_ctrl_38,
         hw_address_ctrl_in39  => targ_addr_ctrl_39,
         hw_address_ctrl_in40  => targ_addr_ctrl_40,
         hw_address_ctrl_in41  => targ_addr_ctrl_41,
         hw_address_ctrl_in42  => targ_addr_ctrl_42,
         hw_address_ctrl_in43  => targ_addr_ctrl_43,
         hw_address_ctrl_in44  => targ_addr_ctrl_44,
         hw_address_ctrl_in45  => targ_addr_ctrl_45,
         hw_address_ctrl_in46  => targ_addr_ctrl_46,
         hw_address_ctrl_in47  => targ_addr_ctrl_47,
         hw_address_ctrl_in48  => targ_addr_ctrl_48,
         hw_address_ctrl_in49  => targ_addr_ctrl_49,
         hw_address_ctrl_in50  => targ_addr_ctrl_50,
         hw_address_ctrl_in51  => targ_addr_ctrl_51,
         hw_address_ctrl_in52  => targ_addr_ctrl_52,
         hw_address_ctrl_in53  => targ_addr_ctrl_53,
         reg_addr              => reg_addr,
         chnl_ctrl_out         => mbus_out_xhdl53
      );
   
END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
--USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_dprio_status IS
   GENERIC (
      
      XGXS_STATUS1            : INTEGER := 24580;
      XGXS_STATUS2            : INTEGER := 24581;
      XGXS_LANE_STATUS        : INTEGER := 24582
   );
   PORT (
      mdio_rst                : IN STD_LOGIC;
      mdio_rd                 : IN STD_LOGIC;
      reg_addr                : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      dev_addr_0              : IN STD_LOGIC;
      mdc                     : IN STD_LOGIC;
      serial_mode             : IN STD_LOGIC;
      ser_shift_load          : IN STD_LOGIC;
      si                      : IN STD_LOGIC;
      mbus_out_ch0            : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      mbus_out_ch1            : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      mbus_out_ch2            : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      mbus_out_ch3            : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      mbus_out_centrl         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      
      -- Status inputs
      align_status            : IN STD_LOGIC;
      sync_status             : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      xs_link_status          : IN STD_LOGIC;
      rx_local_fault          : IN STD_LOGIC;
      tx_local_fault          : IN STD_LOGIC;
      -- Outputs
      rxs_link_status_set     : OUT STD_LOGIC;
      rtx_rx_local_fault_clr  : OUT STD_LOGIC;
      mbus_out                : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      so                      : OUT STD_LOGIC
   );
END stratixiv_hssi_cmu_dprio_status;

ARCHITECTURE trans OF stratixiv_hssi_cmu_dprio_status IS
   COMPONENT stratixiv_hssi_cmu_dprio_bit
      PORT (
         reset                   : IN STD_LOGIC;
         clk                     : IN STD_LOGIC;
         sig_in                  : IN STD_LOGIC;
         ext_in                  : IN STD_LOGIC;
         serial_mode             : IN STD_LOGIC;
         si                      : IN STD_LOGIC;
         shift                   : IN STD_LOGIC;
         mdio_dis                : IN STD_LOGIC;
         sig_out                 : OUT STD_LOGIC;
         so                      : OUT STD_LOGIC
      );
   END COMPONENT;
   
   
   SIGNAL chain                        : STD_LOGIC;
   SIGNAL xs_link_status_rd            : STD_LOGIC;
   SIGNAL tx_rx_local_fault_status_rd  : STD_LOGIC;
   SIGNAL local_fault                  : STD_LOGIC;
   SIGNAL xs_tx_local_fault            : STD_LOGIC;
   SIGNAL xs_rx_local_fault            : STD_LOGIC;
   SIGNAL xgxs_stat1_reg               : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL xgxs_stat2_reg               : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL xgxs_lane_stat_reg           : STD_LOGIC_VECTOR(15 DOWNTO 0);
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL rxs_link_status_set_xhdl1    : STD_LOGIC;
   SIGNAL rtx_rx_local_fault_clr_xhdl0 : STD_LOGIC;
   SIGNAL so_xhdl2                     : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   rxs_link_status_set <= rxs_link_status_set_xhdl1;
   rtx_rx_local_fault_clr <= rtx_rx_local_fault_clr_xhdl0;
   so <= so_xhdl2;
   
   -- Status register address parameters
   
   -- XGXS_STATUS1 and XGXS_STATUS2 status registers
   xs_link_status_rd <= mdio_rd AND int2bit(reg_addr = ieee.std_logic_arith.CONV_STD_LOGIC_VECTOR(XGXS_STATUS1, 16));
   tx_rx_local_fault_status_rd <= mdio_rd AND int2bit(reg_addr = ieee.std_logic_arith.CONV_STD_LOGIC_VECTOR(XGXS_STATUS2, 16));
   
   -- Status registers
   local_fault <= tx_local_fault OR rx_local_fault;
   xs_tx_local_fault <= tx_local_fault WHEN (dev_addr_0 = '1') ELSE
                        rx_local_fault;
   xs_rx_local_fault <= rx_local_fault WHEN (dev_addr_0 = '1') ELSE
                        tx_local_fault;
   
   xgxs_stat1_reg <= ("00000000" & local_fault & "0000" & xs_link_status & "10");
   xgxs_stat2_reg <= ("1000" & xs_rx_local_fault & xs_tx_local_fault & "0000000000");
   xgxs_lane_stat_reg <= ("000" & align_status & "11000000" & sync_status);
   
   -- Single control bits
   
   
   xs_link_status_set : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => mdio_rst,
         clk          => mdc,
         sig_in       => xs_link_status_rd,
         ext_in       => '0',
         serial_mode  => serial_mode,
         si           => si,
         shift        => ser_shift_load,
         mdio_dis     => '0',
         sig_out      => rxs_link_status_set_xhdl1,
         so           => chain
      );
   
   
   
   tx_rx_local_fault_clr : stratixiv_hssi_cmu_dprio_bit
      PORT MAP (
         reset        => mdio_rst,
         clk          => mdc,
         sig_in       => tx_rx_local_fault_status_rd,
         ext_in       => '0',
         serial_mode  => serial_mode,
         si           => chain,
         shift        => ser_shift_load,
         mdio_dis     => '0',
         sig_out      => rtx_rx_local_fault_clr_xhdl0,
         so           => so_xhdl2
      );
   
      mbus_out <= 
                  xgxs_stat1_reg WHEN      (reg_addr = XGXS_STATUS1)         else 
                  xgxs_stat2_reg WHEN      (reg_addr = XGXS_STATUS2)         else  
                  xgxs_lane_stat_reg WHEN  (reg_addr = XGXS_LANE_STATUS)     else 
                                       -- Muxing for Central PCS registers
                   mbus_out_centrl WHEN    (reg_addr = (X"6000" + X"0000")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"6000" + X"0001")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"6000" + X"0002")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"6000" + X"0003")) else
                                       -- Muxing for CMU PMA registers
                   mbus_out_centrl WHEN    (reg_addr = (X"4800" + X"0000")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"4800" + X"0001")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"4800" + X"0002")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"4800" + X"0003")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"4800" + X"0004")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"4800" + X"0005")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"4800" + X"0006")) else
                   mbus_out_centrl WHEN	   (reg_addr = (X"4800" + X"0007")) else	  
                   mbus_out_centrl WHEN    (reg_addr = (X"4C00" + X"0000")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"4C00" + X"0001")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"4C00" + X"0002")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"4C00" + X"0003")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"4C00" + X"0004")) else                           
                   mbus_out_centrl WHEN    (reg_addr = (X"4C00" + X"0005")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"4C00" + X"0006")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"4C00" + X"0007")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"4C00" + X"0008")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"4C00" + X"0009")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"4C00" + X"000A")) else
                   mbus_out_centrl WHEN	   (reg_addr = (X"4C00" + X"000B")) else	  	  		 
                   mbus_out_centrl WHEN	   (reg_addr = (X"4C00" + X"000C")) else	  	  		 
                   mbus_out_centrl WHEN    (reg_addr = (X"5800" + X"0000")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5800" + X"0001")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5800" + X"0002")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5800" + X"0003")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5800" + X"0004")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5800" + X"0005")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5800" + X"0006")) else
                   mbus_out_centrl WHEN	   (reg_addr = (X"5800" + X"0007")) else	  
                   mbus_out_centrl WHEN    (reg_addr = (X"5C00" + X"0000")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5C00" + X"0001")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5C00" + X"0002")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5C00" + X"0003")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5C00" + X"0004")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5C00" + X"0005")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5C00" + X"0006")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5C00" + X"0007")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5C00" + X"0008")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5C00" + X"0009")) else
                   mbus_out_centrl WHEN    (reg_addr = (X"5C00" + X"000A")) else
                   mbus_out_centrl WHEN	   (reg_addr = (X"5C00" + X"000B")) else	                                      
                   mbus_out_centrl WHEN	   (reg_addr = (X"5C00" + X"000C")) else	                                      
                                       -- Muxing for PCS channel0 registers
                   mbus_out_ch0 WHEN       (reg_addr = (X"0000" + X"0000")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0000" + X"0001")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0000" + X"0002")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0000" + X"0003")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"0000")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"0001")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"0002")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"0003")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"0004")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"0005")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"0006")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"0007")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"0008")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"0009")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"000A")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"000B")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"000C")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"000D")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"000E")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"000F")) else
                   mbus_out_ch0 WHEN	   (reg_addr = (X"0400" + X"0010")) else 
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"0011")) else
                   mbus_out_ch0 WHEN	   (reg_addr = (X"0400" + X"0012")) else 
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"0013")) else
                   mbus_out_ch0 WHEN	   (reg_addr = (X"0400" + X"0014")) else 		  	  		  
                   mbus_out_ch0 WHEN       (reg_addr = (X"0400" + X"0015")) else
                   mbus_out_ch0 WHEN	   (reg_addr = (X"0400" + X"0016")) else 		  		  	  		  
                                       -- Muxing for PMA channel0 registers
                   mbus_out_ch0 WHEN       (reg_addr = (X"0800" + X"0000")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0800" + X"0001")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0800" + X"0002")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0800" + X"0003")) else
		  		   mbus_out_ch0 WHEN       (reg_addr = (X"0800" + X"0004")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0800" + X"0005")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0800" + X"0006")) else
		  		   mbus_out_ch0 WHEN	   (reg_addr = (X"0800" + X"0007")) else 
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"0000")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"0001")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"0002")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"0003")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"0004")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"0005")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"0006")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"0007")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"0008")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"0009")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"000A")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"000B")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"000C")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"000D")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"000E")) else
                   mbus_out_ch0 WHEN       (reg_addr = (X"0C00" + X"000F")) else
                   mbus_out_ch0 WHEN	   (reg_addr = (X"0C00" + X"0010")) else
                   mbus_out_ch0 WHEN	   (reg_addr = (X"0C00" + X"0011")) else 		  
                                       -- Muxing for PCS channel1 registers
                   mbus_out_ch1 WHEN       (reg_addr = (X"1000" + X"0000")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1000" + X"0001")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1000" + X"0002")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1000" + X"0003")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"0000")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"0001")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"0002")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"0003")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"0004")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"0005")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"0006")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"0007")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"0008")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"0009")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"000A")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"000B")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"000C")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"000D")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"000E")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"000F")) else
                   mbus_out_ch1 WHEN	   (reg_addr = (X"1400" + X"0010")) else 
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"0011")) else
                   mbus_out_ch1 WHEN	   (reg_addr = (X"1400" + X"0012")) else 
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"0013")) else
                   mbus_out_ch1 WHEN	   (reg_addr = (X"1400" + X"0014")) else 		  	  		  
                   mbus_out_ch1 WHEN       (reg_addr = (X"1400" + X"0015")) else
                   mbus_out_ch1 WHEN	   (reg_addr = (X"1400" + X"0016")) else 		  		  	  		  
                                       -- Muxing for PMA channel1 registers
                   mbus_out_ch1 WHEN       (reg_addr = (X"1800" + X"0000")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1800" + X"0001")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1800" + X"0002")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1800" + X"0003")) else
		  		   mbus_out_ch1 WHEN       (reg_addr = (X"1800" + X"0004")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1800" + X"0005")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1800" + X"0006")) else
		  		   mbus_out_ch1 WHEN	   (reg_addr = (X"1800" + X"0007")) else 
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"0000")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"0001")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"0002")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"0003")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"0004")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"0005")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"0006")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"0007")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"0008")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"0009")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"000A")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"000B")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"000C")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"000D")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"000E")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"000F")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"0010")) else
                   mbus_out_ch1 WHEN       (reg_addr = (X"1C00" + X"0011")) else
		 -- Muxing for PCS channel2 registers
                   mbus_out_ch2 WHEN       (reg_addr = (X"2000" + X"0000")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2000" + X"0001")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2000" + X"0002")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2000" + X"0003")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"0000")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"0001")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"0002")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"0003")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"0004")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"0005")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"0006")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"0007")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"0008")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"0009")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"000A")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"000B")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"000C")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"000D")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"000E")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"000F")) else
                   mbus_out_ch2 WHEN	   (reg_addr = (X"2400" + X"0010")) else 
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"0011")) else
                   mbus_out_ch2 WHEN	   (reg_addr = (X"2400" + X"0012")) else 
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"0013")) else
                   mbus_out_ch2 WHEN	   (reg_addr = (X"2400" + X"0014")) else 		  	  		  
                   mbus_out_ch2 WHEN       (reg_addr = (X"2400" + X"0015")) else
                   mbus_out_ch2 WHEN	   (reg_addr = (X"2400" + X"0016")) else 		  		  	  		  
                                       -- Muxing for PMA channel2 registers
                   mbus_out_ch2 WHEN       (reg_addr = (X"2800" + X"0000")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2800" + X"0001")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2800" + X"0002")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2800" + X"0003")) else
		  		   mbus_out_ch2 WHEN       (reg_addr = (X"2800" + X"0004")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2800" + X"0005")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2800" + X"0006")) else
		  		   mbus_out_ch2 WHEN	   (reg_addr = (X"2800" + X"0007")) else 
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"0000")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"0001")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"0002")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"0003")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"0004")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"0005")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"0006")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"0007")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"0008")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"0009")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"000A")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"000B")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"000C")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"000D")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"000E")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"000F")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"0010")) else
                   mbus_out_ch2 WHEN       (reg_addr = (X"2C00" + X"0011")) else
		 -- Muxing for PCS channel3 registers
                   mbus_out_ch3 WHEN       (reg_addr = (X"3000" + X"0000")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3000" + X"0001")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3000" + X"0002")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3000" + X"0003")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"0000")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"0001")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"0002")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"0003")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"0004")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"0005")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"0006")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"0007")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"0008")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"0009")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"000A")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"000B")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"000C")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"000D")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"000E")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"000F")) else
                   mbus_out_ch3 WHEN	   (reg_addr = (X"3400" + X"0010")) else 
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"0011")) else
                   mbus_out_ch3 WHEN	   (reg_addr = (X"3400" + X"0012")) else 
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"0013")) else
                   mbus_out_ch3 WHEN	   (reg_addr = (X"3400" + X"0014")) else 		  	  		  
                   mbus_out_ch3 WHEN       (reg_addr = (X"3400" + X"0015")) else
                   mbus_out_ch3 WHEN	   (reg_addr = (X"3400" + X"0016")) else 		  		  	  		  
                 -- Muxing for PMA channel3 registers
                   mbus_out_ch3 WHEN       (reg_addr = (X"3800" + X"0000")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3800" + X"0001")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3800" + X"0002")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3800" + X"0003")) else
		  		   mbus_out_ch3 WHEN       (reg_addr = (X"3800" + X"0004")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3800" + X"0005")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3800" + X"0006")) else
		  		   mbus_out_ch3 WHEN	   (reg_addr = (X"3800" + X"0007")) else 
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"0000")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"0001")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"0002")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"0003")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"0004")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"0005")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"0006")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"0007")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"0008")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"0009")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"000A")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"000B")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"000C")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"000D")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"000E")) else
                   mbus_out_ch3 WHEN       (reg_addr = (X"3C00" + X"000F")) else
                   mbus_out_ch3 WHEN	   (reg_addr = (X"3C00" + X"0010")) else 
                   mbus_out_ch3 WHEN	   (reg_addr = (X"3C00" + X"0011")) else 
                  X"0000";
   
END trans;



-- MDIO readout data
-- Muxing for status registers

--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 33 mux21 32 oper_add 1 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_cmu_dprio_addr IS 
	 PORT 
	 ( 
		 incr_addr	:	IN  STD_LOGIC;
		 mdc	:	IN  STD_LOGIC;
		 mdio_in	:	IN  STD_LOGIC;
		 reg_addr	:	OUT  STD_LOGIC_VECTOR (15 DOWNTO 0);
		 reset	:	IN  STD_LOGIC;
		 shift_addr	:	IN  STD_LOGIC
	 ); 
 END stratixiv_hssi_cmu_dprio_addr;

 ARCHITECTURE RTL OF stratixiv_hssi_cmu_dprio_addr IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 nlO0i15	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0i16	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0l13	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0l14	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0O11	:	STD_LOGIC := '0';
	 SIGNAL	 nlO0O12	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlO0O12_w_lg_w_lg_q45w46w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO0O12_w_lg_q45w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlOii10	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlOii10_w_lg_w_lg_q37w38w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOii10_w_lg_q37w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlOii9	:	STD_LOGIC := '0';
	 SIGNAL	 nlOil7	:	STD_LOGIC := '0';
	 SIGNAL	 nlOil8	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlOil8_w_lg_w_lg_q33w34w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOil8_w_lg_q33w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlOiO5	:	STD_LOGIC := '0';
	 SIGNAL	 nlOiO6	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlOiO6_w_lg_w_lg_q30w31w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOiO6_w_lg_q30w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlOli3	:	STD_LOGIC := '0';
	 SIGNAL	 nlOli4	:	STD_LOGIC := '0';
	 SIGNAL  wire_nlOli4_w_lg_w_lg_q25w26w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlOli4_w_lg_q25w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 nlOOi1	:	STD_LOGIC := '0';
	 SIGNAL	 nlOOi2	:	STD_LOGIC := '0';
	 SIGNAL	n0il	:	STD_LOGIC := '0';
	 SIGNAL	n0iO	:	STD_LOGIC := '0';
	 SIGNAL	n0li	:	STD_LOGIC := '0';
	 SIGNAL	n0ll	:	STD_LOGIC := '0';
	 SIGNAL	n0lO	:	STD_LOGIC := '0';
	 SIGNAL	n0Oi	:	STD_LOGIC := '0';
	 SIGNAL	n0Ol	:	STD_LOGIC := '0';
	 SIGNAL	n0OO	:	STD_LOGIC := '0';
	 SIGNAL	ni0i	:	STD_LOGIC := '0';
	 SIGNAL	ni0l	:	STD_LOGIC := '0';
	 SIGNAL	ni0O	:	STD_LOGIC := '0';
	 SIGNAL	ni1i	:	STD_LOGIC := '0';
	 SIGNAL	ni1l	:	STD_LOGIC := '0';
	 SIGNAL	ni1O	:	STD_LOGIC := '0';
	 SIGNAL	niii	:	STD_LOGIC := '0';
	 SIGNAL	niil	:	STD_LOGIC := '0';
	 SIGNAL	nili	:	STD_LOGIC := '0';
	 SIGNAL	wire_niiO_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_niiO_PRN	:	STD_LOGIC;
	 SIGNAL  wire_niiO_w_lg_w14w15w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiO_w14w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiO_w_lg_w_lg_w_lg_w_lg_w_lg_w_lg_w7w8w9w10w11w12w13w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiO_w_lg_w_lg_w_lg_w_lg_w_lg_w7w8w9w10w11w12w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiO_w_lg_w_lg_w_lg_w_lg_w7w8w9w10w11w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiO_w_lg_w_lg_w_lg_w7w8w9w10w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiO_w_lg_w_lg_w7w8w9w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiO_w_lg_w7w8w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiO_w7w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiO_w_lg_w_lg_w_lg_w_lg_w_lg_w_lg_niil1w2w3w4w5w6w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiO_w_lg_w_lg_w_lg_w_lg_w_lg_niil1w2w3w4w5w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiO_w_lg_w_lg_w_lg_w_lg_niil1w2w3w4w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiO_w_lg_w_lg_w_lg_niil1w2w3w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiO_w_lg_w_lg_niil1w2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_niiO_w_lg_niil1w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_ni_a	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_ni_b	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_gnd	:	STD_LOGIC;
	 SIGNAL  wire_ni_o	:	STD_LOGIC_VECTOR (15 DOWNTO 0);
	 SIGNAL  wire_w_lg_nlOlO19w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_reset98w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  nlO1O :	STD_LOGIC;
	 SIGNAL  nlOll :	STD_LOGIC;
	 SIGNAL  nlOlO :	STD_LOGIC;
 BEGIN

	wire_gnd <= '0';
	wire_w_lg_nlOlO19w(0) <= NOT nlOlO;
	wire_w_lg_reset98w(0) <= NOT reset;
	nlO1O <= '1';
	nlOll <= (wire_w_lg_nlOlO19w(0) AND incr_addr);
	nlOlO <= (wire_niiO_w_lg_w14w15w(0) AND (nlOOi2 XOR nlOOi1));
	reg_addr <= ( niil & niii & ni0O & ni0l & ni0i & ni1O & ni1l & ni1i & n0OO & n0Ol & n0Oi & n0lO & n0ll & n0li & n0iO & n0il);
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlO0i15 <= nlO0i16;
		END IF;
		if (now = 0 ns) then
			nlO0i15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlO0i16 <= nlO0i15;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlO0l13 <= nlO0l14;
		END IF;
		if (now = 0 ns) then
			nlO0l13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlO0l14 <= nlO0l13;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlO0O11 <= nlO0O12;
		END IF;
		if (now = 0 ns) then
			nlO0O11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlO0O12 <= nlO0O11;
		END IF;
	END PROCESS;
	wire_nlO0O12_w_lg_w_lg_q45w46w(0) <= wire_nlO0O12_w_lg_q45w(0) AND niil;
	wire_nlO0O12_w_lg_q45w(0) <= nlO0O12 XOR nlO0O11;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlOii10 <= nlOii9;
		END IF;
	END PROCESS;
	wire_nlOii10_w_lg_w_lg_q37w38w(0) <= wire_nlOii10_w_lg_q37w(0) AND ni1l;
	wire_nlOii10_w_lg_q37w(0) <= nlOii10 XOR nlOii9;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlOii9 <= nlOii10;
		END IF;
		if (now = 0 ns) then
			nlOii9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlOil7 <= nlOil8;
		END IF;
		if (now = 0 ns) then
			nlOil7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlOil8 <= nlOil7;
		END IF;
	END PROCESS;
	wire_nlOil8_w_lg_w_lg_q33w34w(0) <= wire_nlOil8_w_lg_q33w(0) AND n0OO;
	wire_nlOil8_w_lg_q33w(0) <= nlOil8 XOR nlOil7;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlOiO5 <= nlOiO6;
		END IF;
		if (now = 0 ns) then
			nlOiO5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlOiO6 <= nlOiO5;
		END IF;
	END PROCESS;
	wire_nlOiO6_w_lg_w_lg_q30w31w(0) <= wire_nlOiO6_w_lg_q30w(0) AND n0Ol;
	wire_nlOiO6_w_lg_q30w(0) <= nlOiO6 XOR nlOiO5;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlOli3 <= nlOli4;
		END IF;
		if (now = 0 ns) then
			nlOli3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlOli4 <= nlOli3;
		END IF;
	END PROCESS;
	wire_nlOli4_w_lg_w_lg_q25w26w(0) <= wire_nlOli4_w_lg_q25w(0) AND n0ll;
	wire_nlOli4_w_lg_q25w(0) <= nlOli4 XOR nlOli3;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlOOi1 <= nlOOi2;
		END IF;
		if (now = 0 ns) then
			nlOOi1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nlOOi2 <= nlOOi1;
		END IF;
	END PROCESS;
	PROCESS (mdc, wire_niiO_PRN, wire_niiO_CLRN)
	BEGIN
		IF (wire_niiO_PRN = '0') THEN
				n0il <= '1';
				n0iO <= '1';
				n0li <= '1';
				n0ll <= '1';
				n0lO <= '1';
				n0Oi <= '1';
				n0Ol <= '1';
				n0OO <= '1';
				ni0i <= '1';
				ni0l <= '1';
				ni0O <= '1';
				ni1i <= '1';
				ni1l <= '1';
				ni1O <= '1';
				niii <= '1';
				niil <= '1';
				nili <= '1';
		ELSIF (wire_niiO_CLRN = '0') THEN
				n0il <= '0';
				n0iO <= '0';
				n0li <= '0';
				n0ll <= '0';
				n0lO <= '0';
				n0Oi <= '0';
				n0Ol <= '0';
				n0OO <= '0';
				ni0i <= '0';
				ni0l <= '0';
				ni0O <= '0';
				ni1i <= '0';
				ni1l <= '0';
				ni1O <= '0';
				niii <= '0';
				niil <= '0';
				nili <= '0';
		ELSIF (mdc = '1' AND mdc'event) THEN
				n0il <= wire_nill_dataout;
				n0iO <= wire_nilO_dataout;
				n0li <= wire_niOi_dataout;
				n0ll <= wire_niOl_dataout;
				n0lO <= wire_niOO_dataout;
				n0Oi <= wire_nl1i_dataout;
				n0Ol <= wire_nl1l_dataout;
				n0OO <= wire_nl1O_dataout;
				ni0i <= wire_nlii_dataout;
				ni0l <= wire_nlil_dataout;
				ni0O <= wire_nliO_dataout;
				ni1i <= wire_nl0i_dataout;
				ni1l <= wire_nl0l_dataout;
				ni1O <= wire_nl0O_dataout;
				niii <= wire_nlli_dataout;
				niil <= wire_nlll_dataout;
				nili <= mdio_in;
		END IF;
	END PROCESS;
	wire_niiO_CLRN <= ((nlO0l14 XOR nlO0l13) AND wire_w_lg_reset98w(0));
	wire_niiO_PRN <= (nlO0i16 XOR nlO0i15);
	wire_niiO_w_lg_w14w15w(0) <= wire_niiO_w14w(0) AND n0il;
	wire_niiO_w14w(0) <= wire_niiO_w_lg_w_lg_w_lg_w_lg_w_lg_w_lg_w7w8w9w10w11w12w13w(0) AND n0iO;
	wire_niiO_w_lg_w_lg_w_lg_w_lg_w_lg_w_lg_w7w8w9w10w11w12w13w(0) <= wire_niiO_w_lg_w_lg_w_lg_w_lg_w_lg_w7w8w9w10w11w12w(0) AND n0li;
	wire_niiO_w_lg_w_lg_w_lg_w_lg_w_lg_w7w8w9w10w11w12w(0) <= wire_niiO_w_lg_w_lg_w_lg_w_lg_w7w8w9w10w11w(0) AND n0ll;
	wire_niiO_w_lg_w_lg_w_lg_w_lg_w7w8w9w10w11w(0) <= wire_niiO_w_lg_w_lg_w_lg_w7w8w9w10w(0) AND n0lO;
	wire_niiO_w_lg_w_lg_w_lg_w7w8w9w10w(0) <= wire_niiO_w_lg_w_lg_w7w8w9w(0) AND n0Oi;
	wire_niiO_w_lg_w_lg_w7w8w9w(0) <= wire_niiO_w_lg_w7w8w(0) AND n0Ol;
	wire_niiO_w_lg_w7w8w(0) <= wire_niiO_w7w(0) AND n0OO;
	wire_niiO_w7w(0) <= wire_niiO_w_lg_w_lg_w_lg_w_lg_w_lg_w_lg_niil1w2w3w4w5w6w(0) AND ni1i;
	wire_niiO_w_lg_w_lg_w_lg_w_lg_w_lg_w_lg_niil1w2w3w4w5w6w(0) <= wire_niiO_w_lg_w_lg_w_lg_w_lg_w_lg_niil1w2w3w4w5w(0) AND ni1l;
	wire_niiO_w_lg_w_lg_w_lg_w_lg_w_lg_niil1w2w3w4w5w(0) <= wire_niiO_w_lg_w_lg_w_lg_w_lg_niil1w2w3w4w(0) AND ni1O;
	wire_niiO_w_lg_w_lg_w_lg_w_lg_niil1w2w3w4w(0) <= wire_niiO_w_lg_w_lg_w_lg_niil1w2w3w(0) AND ni0i;
	wire_niiO_w_lg_w_lg_w_lg_niil1w2w3w(0) <= wire_niiO_w_lg_w_lg_niil1w2w(0) AND ni0l;
	wire_niiO_w_lg_w_lg_niil1w2w(0) <= wire_niiO_w_lg_niil1w(0) AND ni0O;
	wire_niiO_w_lg_niil1w(0) <= niil AND niii;
	wire_n0i_dataout <= wire_ni_o(7) WHEN nlOll = '1'  ELSE n0OO;
	wire_n0l_dataout <= wire_ni_o(8) WHEN nlOll = '1'  ELSE ni1i;
	wire_n0O_dataout <= wire_ni_o(9) WHEN nlOll = '1'  ELSE ni1l;
	wire_n1i_dataout <= wire_ni_o(4) WHEN nlOll = '1'  ELSE n0lO;
	wire_n1l_dataout <= wire_ni_o(5) WHEN nlOll = '1'  ELSE n0Oi;
	wire_n1O_dataout <= wire_ni_o(6) WHEN nlOll = '1'  ELSE n0Ol;
	wire_nii_dataout <= wire_ni_o(10) WHEN nlOll = '1'  ELSE ni1O;
	wire_nil_dataout <= wire_ni_o(11) WHEN nlOll = '1'  ELSE ni0i;
	wire_nill_dataout <= nili WHEN shift_addr = '1'  ELSE wire_nllO_dataout;
	wire_nilO_dataout <= n0il WHEN shift_addr = '1'  ELSE wire_nlOi_dataout;
	wire_niO_dataout <= wire_ni_o(12) WHEN nlOll = '1'  ELSE ni0l;
	wire_niOi_dataout <= n0iO WHEN shift_addr = '1'  ELSE wire_nlOl_dataout;
	wire_niOl_dataout <= n0li WHEN shift_addr = '1'  ELSE wire_nlOO_dataout;
	wire_niOO_dataout <= n0ll WHEN shift_addr = '1'  ELSE wire_n1i_dataout;
	wire_nl0i_dataout <= n0OO WHEN shift_addr = '1'  ELSE wire_n0l_dataout;
	wire_nl0l_dataout <= ni1i WHEN shift_addr = '1'  ELSE wire_n0O_dataout;
	wire_nl0O_dataout <= ni1l WHEN shift_addr = '1'  ELSE wire_nii_dataout;
	wire_nl1i_dataout <= n0lO WHEN shift_addr = '1'  ELSE wire_n1l_dataout;
	wire_nl1l_dataout <= n0Oi WHEN shift_addr = '1'  ELSE wire_n1O_dataout;
	wire_nl1O_dataout <= n0Ol WHEN shift_addr = '1'  ELSE wire_n0i_dataout;
	wire_nli_dataout <= wire_ni_o(13) WHEN nlOll = '1'  ELSE ni0O;
	wire_nlii_dataout <= ni1O WHEN shift_addr = '1'  ELSE wire_nil_dataout;
	wire_nlil_dataout <= ni0i WHEN shift_addr = '1'  ELSE wire_niO_dataout;
	wire_nliO_dataout <= ni0l WHEN shift_addr = '1'  ELSE wire_nli_dataout;
	wire_nll_dataout <= wire_ni_o(14) WHEN nlOll = '1'  ELSE niii;
	wire_nlli_dataout <= ni0O WHEN shift_addr = '1'  ELSE wire_nll_dataout;
	wire_nlll_dataout <= niii WHEN shift_addr = '1'  ELSE wire_nlO_dataout;
	wire_nllO_dataout <= wire_ni_o(0) WHEN nlOll = '1'  ELSE n0il;
	wire_nlO_dataout <= wire_ni_o(15) WHEN nlOll = '1'  ELSE niil;
	wire_nlOi_dataout <= wire_ni_o(1) WHEN nlOll = '1'  ELSE n0iO;
	wire_nlOl_dataout <= wire_ni_o(2) WHEN nlOll = '1'  ELSE n0li;
	wire_nlOO_dataout <= wire_ni_o(3) WHEN nlOll = '1'  ELSE n0ll;
	wire_ni_a <= ( wire_nlO0O12_w_lg_w_lg_q45w46w & niii & ni0O & ni0l & ni0i & ni1O & wire_nlOii10_w_lg_w_lg_q37w38w & ni1i & wire_nlOil8_w_lg_w_lg_q33w34w & wire_nlOiO6_w_lg_w_lg_q30w31w & n0Oi & n0lO & wire_nlOli4_w_lg_w_lg_q25w26w & n0li & n0iO & n0il);
	wire_ni_b <= ( "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "0" & "1");
	ni :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 16,
		width_b => 16,
		width_o => 16
	  )
	  PORT MAP ( 
		a => wire_ni_a,
		b => wire_ni_b,
		cin => wire_gnd,
		o => wire_ni_o
	  );

 END RTL; --stratixiv_hssi_cmu_dprio_addr
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

 LIBRARY sgate;
 USE sgate.sgate_pack.all;

--synthesis_resources = lut 17 mux21 10 oper_add 1 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_cmu_dprio_cnt IS 
	 PORT 
	 ( 
		 cnt_eq_0	:	OUT  STD_LOGIC;
		 cnt_val	:	IN  STD_LOGIC_VECTOR (4 DOWNTO 0);
		 ld_cnt	:	IN  STD_LOGIC;
		 mdc	:	IN  STD_LOGIC;
		 reset	:	IN  STD_LOGIC
	 ); 
 END stratixiv_hssi_cmu_dprio_cnt;

 ARCHITECTURE RTL OF stratixiv_hssi_cmu_dprio_cnt IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 ni0O10	:	STD_LOGIC := '0';
	 SIGNAL	 ni0O9	:	STD_LOGIC := '0';
	 SIGNAL	 ni1O11	:	STD_LOGIC := '0';
	 SIGNAL	 ni1O12	:	STD_LOGIC := '0';
	 SIGNAL	 niiO7	:	STD_LOGIC := '0';
	 SIGNAL	 niiO8	:	STD_LOGIC := '0';
	 SIGNAL	 nili5	:	STD_LOGIC := '0';
	 SIGNAL	 nili6	:	STD_LOGIC := '0';
	 SIGNAL	 nill3	:	STD_LOGIC := '0';
	 SIGNAL	 nill4	:	STD_LOGIC := '0';
	 SIGNAL  wire_nill4_w_lg_w_lg_q16w17w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nill4_w_lg_q16w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	 niOi1	:	STD_LOGIC := '0';
	 SIGNAL	 niOi2	:	STD_LOGIC := '0';
	 SIGNAL	n1i	:	STD_LOGIC := '0';
	 SIGNAL	ni	:	STD_LOGIC := '0';
	 SIGNAL	nlOi	:	STD_LOGIC := '0';
	 SIGNAL	nlOl	:	STD_LOGIC := '0';
	 SIGNAL	nlOO	:	STD_LOGIC := '0';
	 SIGNAL	wire_nlO_CLRN	:	STD_LOGIC;
	 SIGNAL	wire_nlO_PRN	:	STD_LOGIC;
	 SIGNAL  wire_nlO_w_lg_w_lg_w_lg_w_lg_ni1w2w3w4w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO_w_lg_w_lg_w_lg_ni1w2w3w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO_w_lg_w_lg_ni1w2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_nlO_w_lg_ni1w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nll_dataout	:	STD_LOGIC;
	 SIGNAL  wire_nl_a	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_nl_b	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_gnd	:	STD_LOGIC;
	 SIGNAL  wire_nl_o	:	STD_LOGIC_VECTOR (5 DOWNTO 0);
	 SIGNAL  wire_w_lg_ld_cnt51w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_ni0l50w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_reset33w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  ni0l :	STD_LOGIC;
	 SIGNAL  niil :	STD_LOGIC;
	 SIGNAL  nilO :	STD_LOGIC;
 BEGIN

	wire_gnd <= '0';
	wire_w_lg_ld_cnt51w(0) <= NOT ld_cnt;
	wire_w_lg_ni0l50w(0) <= NOT ni0l;
	wire_w_lg_reset33w(0) <= NOT reset;
	cnt_eq_0 <= ((wire_w_lg_ni0l50w(0) AND wire_w_lg_ld_cnt51w(0)) AND (ni1O12 XOR ni1O11));
	ni0l <= (wire_nlO_w_lg_w_lg_w_lg_w_lg_ni1w2w3w4w(0) OR (NOT (ni0O10 XOR ni0O9)));
	niil <= '1';
	nilO <= (wire_nlO_w_lg_w_lg_w_lg_w_lg_ni1w2w3w4w(0) OR (NOT (niOi2 XOR niOi1)));
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN ni0O10 <= ni0O9;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN ni0O9 <= ni0O10;
		END IF;
		if (now = 0 ns) then
			ni0O9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN ni1O11 <= ni1O12;
		END IF;
		if (now = 0 ns) then
			ni1O11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN ni1O12 <= ni1O11;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niiO7 <= niiO8;
		END IF;
		if (now = 0 ns) then
			niiO7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niiO8 <= niiO7;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nili5 <= nili6;
		END IF;
		if (now = 0 ns) then
			nili5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nili6 <= nili5;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nill3 <= nill4;
		END IF;
		if (now = 0 ns) then
			nill3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nill4 <= nill3;
		END IF;
	END PROCESS;
	wire_nill4_w_lg_w_lg_q16w17w(0) <= wire_nill4_w_lg_q16w(0) AND n1i;
	wire_nill4_w_lg_q16w(0) <= nill4 XOR nill3;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niOi1 <= niOi2;
		END IF;
		if (now = 0 ns) then
			niOi1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niOi2 <= niOi1;
		END IF;
	END PROCESS;
	PROCESS (mdc, wire_nlO_PRN, wire_nlO_CLRN)
	BEGIN
		IF (wire_nlO_PRN = '0') THEN
				n1i <= '1';
				ni <= '1';
				nlOi <= '1';
				nlOl <= '1';
				nlOO <= '1';
		ELSIF (wire_nlO_CLRN = '0') THEN
				n1i <= '0';
				ni <= '0';
				nlOi <= '0';
				nlOl <= '0';
				nlOO <= '0';
		ELSIF (mdc = '1' AND mdc'event) THEN
				n1i <= wire_n0O_dataout;
				ni <= wire_n1l_dataout;
				nlOi <= wire_n1O_dataout;
				nlOl <= wire_n0i_dataout;
				nlOO <= wire_n0l_dataout;
		END IF;
	END PROCESS;
	wire_nlO_CLRN <= ((nili6 XOR nili5) AND wire_w_lg_reset33w(0));
	wire_nlO_PRN <= (niiO8 XOR niiO7);
	wire_nlO_w_lg_w_lg_w_lg_w_lg_ni1w2w3w4w(0) <= wire_nlO_w_lg_w_lg_w_lg_ni1w2w3w(0) OR nlOi;
	wire_nlO_w_lg_w_lg_w_lg_ni1w2w3w(0) <= wire_nlO_w_lg_w_lg_ni1w2w(0) OR nlOl;
	wire_nlO_w_lg_w_lg_ni1w2w(0) <= wire_nlO_w_lg_ni1w(0) OR nlOO;
	wire_nlO_w_lg_ni1w(0) <= ni OR n1i;
	wire_n0i_dataout <= cnt_val(2) WHEN ld_cnt = '1'  ELSE wire_niO_dataout;
	wire_n0l_dataout <= cnt_val(3) WHEN ld_cnt = '1'  ELSE wire_nli_dataout;
	wire_n0O_dataout <= cnt_val(4) WHEN ld_cnt = '1'  ELSE wire_nll_dataout;
	wire_n1l_dataout <= cnt_val(0) WHEN ld_cnt = '1'  ELSE wire_nii_dataout;
	wire_n1O_dataout <= cnt_val(1) WHEN ld_cnt = '1'  ELSE wire_nil_dataout;
	wire_nii_dataout <= wire_nl_o(1) WHEN nilO = '1'  ELSE ni;
	wire_nil_dataout <= wire_nl_o(2) WHEN nilO = '1'  ELSE nlOi;
	wire_niO_dataout <= wire_nl_o(3) WHEN nilO = '1'  ELSE nlOl;
	wire_nli_dataout <= wire_nl_o(4) WHEN nilO = '1'  ELSE nlOO;
	wire_nll_dataout <= wire_nl_o(5) WHEN nilO = '1'  ELSE n1i;
	wire_nl_a <= ( wire_nill4_w_lg_w_lg_q16w17w & nlOO & nlOl & nlOi & ni & "1");
	wire_nl_b <= ( "1" & "1" & "1" & "1" & "0" & "1");
	nl :  oper_add
	  GENERIC MAP (
		sgate_representation => 0,
		width_a => 6,
		width_b => 6,
		width_o => 6
	  )
	  PORT MAP ( 
		a => wire_nl_a,
		b => wire_nl_b,
		cin => wire_gnd,
		o => wire_nl_o
	  );

 END RTL; --stratixiv_hssi_cmu_dprio_cnt
--synopsys translate_on
--VALID FILE
--IP Functional Simulation Model
--VERSION_BEGIN 10.1 cbx_mgl 2010:11:29:21:24:23:SJ cbx_simgen 2010:11:29:21:22:45:SJ  VERSION_END


-- Copyright (C) 1991-2010 Altera Corporation
-- Your use of Altera Corporation's design tools, logic functions 
-- and other software and tools, and its AMPP partner logic 
-- functions, and any output files from any of the foregoing 
-- (including device programming or simulation files), and any 
-- associated documentation or information are expressly subject 
-- to the terms and conditions of the Altera Program License 
-- Subscription Agreement, Altera MegaCore Function License 
-- Agreement, or other applicable license agreement, including, 
-- without limitation, that your use is for the sole purpose of 
-- programming logic devices manufactured by Altera and sold by 
-- Altera or its authorized distributors.  Please refer to the 
-- applicable agreement for further details.

-- You may only use these simulation model output files for simulation
-- purposes and expressly not for synthesis or any other purposes (in which
-- event Altera disclaims all warranties of any kind).


--synopsys translate_off

--synthesis_resources = lut 47 mux21 36 
 LIBRARY ieee;
 USE ieee.std_logic_1164.all;

 ENTITY  stratixiv_hssi_cmu_dprio_ctl_data IS 
	 PORT 
	 ( 
		 data_enable_n	:	OUT  STD_LOGIC;
		 dev_addr	:	IN  STD_LOGIC_VECTOR (4 DOWNTO 0);
		 latch_ctl	:	IN  STD_LOGIC;
		 ld_data	:	IN  STD_LOGIC;
		 mbus_in	:	OUT  STD_LOGIC_VECTOR (15 DOWNTO 0);
		 mbus_out	:	IN  STD_LOGIC_VECTOR (15 DOWNTO 0);
		 mdc	:	IN  STD_LOGIC;
		 mdio_in	:	IN  STD_LOGIC;
		 mdio_out	:	OUT  STD_LOGIC;
		 opcode	:	OUT  STD_LOGIC_VECTOR (1 DOWNTO 0);
		 port_addr	:	IN  STD_LOGIC_VECTOR (4 DOWNTO 0);
		 reset	:	IN  STD_LOGIC;
		 shift_in	:	IN  STD_LOGIC;
		 shift_out	:	IN  STD_LOGIC;
		 valid_addr	:	OUT  STD_LOGIC;
		 valid_addr_lt	:	IN  STD_LOGIC
	 ); 
 END stratixiv_hssi_cmu_dprio_ctl_data;

 ARCHITECTURE RTL OF stratixiv_hssi_cmu_dprio_ctl_data IS

	 ATTRIBUTE synthesis_clearbox : natural;
	 ATTRIBUTE synthesis_clearbox OF RTL : ARCHITECTURE IS 1;
	 SIGNAL	 nilll25	:	STD_LOGIC := '0';
	 SIGNAL	 nilll26	:	STD_LOGIC := '0';
	 SIGNAL	 nilOi23	:	STD_LOGIC := '0';
	 SIGNAL	 nilOi24	:	STD_LOGIC := '0';
	 SIGNAL	 nilOO21	:	STD_LOGIC := '0';
	 SIGNAL	 nilOO22	:	STD_LOGIC := '0';
	 SIGNAL	 niO0i17	:	STD_LOGIC := '0';
	 SIGNAL	 niO0i18	:	STD_LOGIC := '0';
	 SIGNAL	 niO0O15	:	STD_LOGIC := '0';
	 SIGNAL	 niO0O16	:	STD_LOGIC := '0';
	 SIGNAL	 niO1l19	:	STD_LOGIC := '0';
	 SIGNAL	 niO1l20	:	STD_LOGIC := '0';
	 SIGNAL	 niOil13	:	STD_LOGIC := '0';
	 SIGNAL	 niOil14	:	STD_LOGIC := '0';
	 SIGNAL	 niOiO11	:	STD_LOGIC := '0';
	 SIGNAL	 niOiO12	:	STD_LOGIC := '0';
	 SIGNAL	 niOlO10	:	STD_LOGIC := '0';
	 SIGNAL	 niOlO9	:	STD_LOGIC := '0';
	 SIGNAL	 niOOl7	:	STD_LOGIC := '0';
	 SIGNAL	 niOOl8	:	STD_LOGIC := '0';
	 SIGNAL	 nl10l3	:	STD_LOGIC := '0';
	 SIGNAL	 nl10l4	:	STD_LOGIC := '0';
	 SIGNAL	 nl11l5	:	STD_LOGIC := '0';
	 SIGNAL	 nl11l6	:	STD_LOGIC := '0';
	 SIGNAL	 nl1iO1	:	STD_LOGIC := '0';
	 SIGNAL	 nl1iO2	:	STD_LOGIC := '0';
	 SIGNAL  wire_nl1iO2_w_lg_q6w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	n1li	:	STD_LOGIC := '0';
	 SIGNAL	n1lO	:	STD_LOGIC := '0';
	 SIGNAL	wire_n1ll_PRN	:	STD_LOGIC;
	 SIGNAL	n00i	:	STD_LOGIC := '0';
	 SIGNAL	n00l	:	STD_LOGIC := '0';
	 SIGNAL	n00O	:	STD_LOGIC := '0';
	 SIGNAL	n01l	:	STD_LOGIC := '0';
	 SIGNAL	n01O	:	STD_LOGIC := '0';
	 SIGNAL	n0ii	:	STD_LOGIC := '0';
	 SIGNAL	n0il	:	STD_LOGIC := '0';
	 SIGNAL	n0iO	:	STD_LOGIC := '0';
	 SIGNAL	n0li	:	STD_LOGIC := '0';
	 SIGNAL	n0ll	:	STD_LOGIC := '0';
	 SIGNAL	n0lO	:	STD_LOGIC := '0';
	 SIGNAL	n0Oi	:	STD_LOGIC := '0';
	 SIGNAL	n0Ol	:	STD_LOGIC := '0';
	 SIGNAL	n0OO	:	STD_LOGIC := '0';
	 SIGNAL	n1iO	:	STD_LOGIC := '0';
	 SIGNAL	n1Oi	:	STD_LOGIC := '0';
	 SIGNAL	ni0i	:	STD_LOGIC := '0';
	 SIGNAL	ni1i	:	STD_LOGIC := '0';
	 SIGNAL	ni1l	:	STD_LOGIC := '0';
	 SIGNAL	wire_ni1O_CLRN	:	STD_LOGIC;
	 SIGNAL  wire_ni1O_w_lg_w_lg_w_lg_w_lg_w_lg_ni1i2w4w7w8w9w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1O_w_lg_w_lg_w_lg_w_lg_ni1i2w4w7w8w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1O_w_lg_w_lg_w_lg_ni1i2w4w7w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1O_w_lg_w_lg_ni1i2w4w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1O_w_lg_n0Oi34w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1O_w_lg_n0lO33w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1O_w_lg_n0OO3w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1O_w_lg_ni1i2w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1O_w_lg_n00i107w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1O_w_lg_n00l115w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1O_w_lg_n0li84w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_ni1O_w_lg_n0ll92w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL	wire_n0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1Ol_dataout	:	STD_LOGIC;
	 SIGNAL	wire_n1OO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_ni0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niiO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nili_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nill_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nilO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_niOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl0O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1i_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1l_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nl1O_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlii_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlil_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nliO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlli_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlll_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nllO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOi_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOl_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nlOO_dataout	:	STD_LOGIC;
	 SIGNAL	wire_nO_dataout	:	STD_LOGIC;
	 SIGNAL  wire_w_lg_reset30w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_w_lg_shift_out48w49w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_lg_shift_out48w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  niOll :	STD_LOGIC;
	 SIGNAL  nl10i :	STD_LOGIC;
	 SIGNAL  nl11i :	STD_LOGIC;
	 SIGNAL  nl11O :	STD_LOGIC;
	 SIGNAL  nl1ii :	STD_LOGIC;
	 SIGNAL  nl1il :	STD_LOGIC;
	 SIGNAL  wire_w_dev_addr_range106w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_dev_addr_range114w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_port_addr_range83w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
	 SIGNAL  wire_w_port_addr_range91w	:	STD_LOGIC_VECTOR (0 DOWNTO 0);
 BEGIN

	wire_w_lg_reset30w(0) <= NOT reset;
	wire_w_lg_w_lg_shift_out48w49w(0) <= wire_w_lg_shift_out48w(0) OR n01l;
	wire_w_lg_shift_out48w(0) <= shift_out OR ld_data;
	data_enable_n <= (NOT ((wire_w_lg_w_lg_shift_out48w49w(0) AND (nl10i OR valid_addr_lt)) AND (niO0O16 XOR niO0O15)));
	mbus_in <= ( ni0i & ni1l & ni1i & n0OO & n0Ol & n0Oi & n0lO & n0ll & n0li & n0iO & n0il & n0ii & n00O & n00l & n00i & n01O);
	mdio_out <= wire_nl_dataout;
	niOll <= (((n0Oi AND n0lO) OR (wire_ni1O_w_lg_n0Oi34w(0) AND (niOOl8 XOR niOOl7))) OR (NOT (niOlO10 XOR niOlO9)));
	nl10i <= (wire_ni1O_w_lg_w_lg_w_lg_w_lg_w_lg_ni1i2w4w7w8w9w(0) AND (nl10l4 XOR nl10l3));
	nl11i <= '1';
	nl11O <= (shift_in OR shift_out);
	nl1ii <= ((((((NOT (n01O XOR dev_addr(0))) AND (NOT (wire_ni1O_w_lg_n00i107w(0) XOR (NOT (nilOO22 XOR nilOO21))))) AND (NOT (wire_ni1O_w_lg_n00l115w(0) XOR (NOT (nilOi24 XOR nilOi23))))) AND (NOT (n00O XOR dev_addr(3)))) AND (NOT (n0ii XOR dev_addr(4)))) AND (nilll26 XOR nilll25));
	nl1il <= (((((NOT (n0il XOR port_addr(0))) AND (NOT (n0iO XOR port_addr(1)))) AND (NOT (wire_ni1O_w_lg_n0li84w(0) XOR (NOT (niO0i18 XOR niO0i17))))) AND (NOT (wire_ni1O_w_lg_n0ll92w(0) XOR (NOT (niO1l20 XOR niO1l19))))) AND (NOT (n0lO XOR port_addr(4))));
	opcode <= ( n1lO & n1li);
	valid_addr <= nl10i;
	wire_w_dev_addr_range106w(0) <= dev_addr(1);
	wire_w_dev_addr_range114w(0) <= dev_addr(2);
	wire_w_port_addr_range83w(0) <= port_addr(2);
	wire_w_port_addr_range91w(0) <= port_addr(3);
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nilll25 <= nilll26;
		END IF;
		if (now = 0 ns) then
			nilll25 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nilll26 <= nilll25;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nilOi23 <= nilOi24;
		END IF;
		if (now = 0 ns) then
			nilOi23 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nilOi24 <= nilOi23;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nilOO21 <= nilOO22;
		END IF;
		if (now = 0 ns) then
			nilOO21 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nilOO22 <= nilOO21;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niO0i17 <= niO0i18;
		END IF;
		if (now = 0 ns) then
			niO0i17 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niO0i18 <= niO0i17;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niO0O15 <= niO0O16;
		END IF;
		if (now = 0 ns) then
			niO0O15 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niO0O16 <= niO0O15;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niO1l19 <= niO1l20;
		END IF;
		if (now = 0 ns) then
			niO1l19 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niO1l20 <= niO1l19;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niOil13 <= niOil14;
		END IF;
		if (now = 0 ns) then
			niOil13 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niOil14 <= niOil13;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niOiO11 <= niOiO12;
		END IF;
		if (now = 0 ns) then
			niOiO11 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niOiO12 <= niOiO11;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niOlO10 <= niOlO9;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niOlO9 <= niOlO10;
		END IF;
		if (now = 0 ns) then
			niOlO9 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niOOl7 <= niOOl8;
		END IF;
		if (now = 0 ns) then
			niOOl7 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN niOOl8 <= niOOl7;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nl10l3 <= nl10l4;
		END IF;
		if (now = 0 ns) then
			nl10l3 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nl10l4 <= nl10l3;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nl11l5 <= nl11l6;
		END IF;
		if (now = 0 ns) then
			nl11l5 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nl11l6 <= nl11l5;
		END IF;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nl1iO1 <= nl1iO2;
		END IF;
		if (now = 0 ns) then
			nl1iO1 <= '1' after 1 ps;
		end if;
	END PROCESS;
	PROCESS (mdc)
	BEGIN
		IF (mdc = '1' AND mdc'event) THEN nl1iO2 <= nl1iO1;
		END IF;
	END PROCESS;
	wire_nl1iO2_w_lg_q6w(0) <= nl1iO2 XOR nl1iO1;
	PROCESS (mdc, wire_n1ll_PRN, reset)
	BEGIN
		IF (wire_n1ll_PRN = '0') THEN
				n1li <= '1';
				n1lO <= '1';
		ELSIF (reset = '1') THEN
				n1li <= '0';
				n1lO <= '0';
		ELSIF (mdc = '1' AND mdc'event) THEN
			IF (latch_ctl = '1') THEN
				n1li <= n0lO;
				n1lO <= n0Oi;
			END IF;
		END IF;
	END PROCESS;
	wire_n1ll_PRN <= (niOil14 XOR niOil13);
	PROCESS (mdc, wire_ni1O_CLRN)
	BEGIN
		IF (wire_ni1O_CLRN = '0') THEN
				n00i <= '0';
				n00l <= '0';
				n00O <= '0';
				n01l <= '0';
				n01O <= '0';
				n0ii <= '0';
				n0il <= '0';
				n0iO <= '0';
				n0li <= '0';
				n0ll <= '0';
				n0lO <= '0';
				n0Oi <= '0';
				n0Ol <= '0';
				n0OO <= '0';
				n1iO <= '0';
				n1Oi <= '0';
				ni0i <= '0';
				ni1i <= '0';
				ni1l <= '0';
		ELSIF (mdc = '1' AND mdc'event) THEN
				n00i <= wire_ni0O_dataout;
				n00l <= wire_niii_dataout;
				n00O <= wire_niil_dataout;
				n01l <= wire_n1Ol_dataout;
				n01O <= wire_ni0l_dataout;
				n0ii <= wire_niiO_dataout;
				n0il <= wire_nili_dataout;
				n0iO <= wire_nill_dataout;
				n0li <= wire_nilO_dataout;
				n0ll <= wire_niOi_dataout;
				n0lO <= wire_niOl_dataout;
				n0Oi <= wire_niOO_dataout;
				n0Ol <= wire_nl1i_dataout;
				n0OO <= wire_nl1l_dataout;
				n1iO <= wire_n1OO_dataout;
				n1Oi <= mdio_in;
				ni0i <= wire_nl0l_dataout;
				ni1i <= wire_nl1O_dataout;
				ni1l <= wire_nl0i_dataout;
		END IF;
	END PROCESS;
	wire_ni1O_CLRN <= ((nl11l6 XOR nl11l5) AND wire_w_lg_reset30w(0));
	wire_ni1O_w_lg_w_lg_w_lg_w_lg_w_lg_ni1i2w4w7w8w9w(0) <= wire_ni1O_w_lg_w_lg_w_lg_w_lg_ni1i2w4w7w8w(0) AND nl1ii;
	wire_ni1O_w_lg_w_lg_w_lg_w_lg_ni1i2w4w7w8w(0) <= wire_ni1O_w_lg_w_lg_w_lg_ni1i2w4w7w(0) AND nl1il;
	wire_ni1O_w_lg_w_lg_w_lg_ni1i2w4w7w(0) <= wire_ni1O_w_lg_w_lg_ni1i2w4w(0) AND wire_nl1iO2_w_lg_q6w(0);
	wire_ni1O_w_lg_w_lg_ni1i2w4w(0) <= wire_ni1O_w_lg_ni1i2w(0) AND wire_ni1O_w_lg_n0OO3w(0);
	wire_ni1O_w_lg_n0Oi34w(0) <= n0Oi AND wire_ni1O_w_lg_n0lO33w(0);
	wire_ni1O_w_lg_n0lO33w(0) <= NOT n0lO;
	wire_ni1O_w_lg_n0OO3w(0) <= NOT n0OO;
	wire_ni1O_w_lg_ni1i2w(0) <= NOT ni1i;
	wire_ni1O_w_lg_n00i107w(0) <= n00i XOR wire_w_dev_addr_range106w(0);
	wire_ni1O_w_lg_n00l115w(0) <= n00l XOR wire_w_dev_addr_range114w(0);
	wire_ni1O_w_lg_n0li84w(0) <= n0li XOR wire_w_port_addr_range83w(0);
	wire_ni1O_w_lg_n0ll92w(0) <= n0ll XOR wire_w_port_addr_range91w(0);
	wire_n0i_dataout <= n0OO WHEN nl11O = '1'  ELSE ni1i;
	wire_n0l_dataout <= ni1i WHEN nl11O = '1'  ELSE ni1l;
	wire_n0O_dataout <= ni1l WHEN nl11O = '1'  ELSE ni0i;
	wire_n1i_dataout <= n0lO WHEN nl11O = '1'  ELSE n0Oi;
	wire_n1l_dataout <= n0Oi WHEN nl11O = '1'  ELSE n0Ol;
	wire_n1O_dataout <= n0Ol WHEN nl11O = '1'  ELSE n0OO;
	wire_n1Ol_dataout <= niOll WHEN latch_ctl = '1'  ELSE ((n01l AND n1iO) AND (niOiO12 XOR niOiO11));
	wire_n1OO_dataout <= niOll AND latch_ctl;
	wire_ni0l_dataout <= mbus_out(15) WHEN ld_data = '1'  ELSE wire_nl0O_dataout;
	wire_ni0O_dataout <= mbus_out(0) WHEN ld_data = '1'  ELSE wire_nlii_dataout;
	wire_niii_dataout <= mbus_out(1) WHEN ld_data = '1'  ELSE wire_nlil_dataout;
	wire_niil_dataout <= mbus_out(2) WHEN ld_data = '1'  ELSE wire_nliO_dataout;
	wire_niiO_dataout <= mbus_out(3) WHEN ld_data = '1'  ELSE wire_nlli_dataout;
	wire_nili_dataout <= mbus_out(4) WHEN ld_data = '1'  ELSE wire_nlll_dataout;
	wire_nill_dataout <= mbus_out(5) WHEN ld_data = '1'  ELSE wire_nllO_dataout;
	wire_nilO_dataout <= mbus_out(6) WHEN ld_data = '1'  ELSE wire_nlOi_dataout;
	wire_niOi_dataout <= mbus_out(7) WHEN ld_data = '1'  ELSE wire_nlOl_dataout;
	wire_niOl_dataout <= mbus_out(8) WHEN ld_data = '1'  ELSE wire_nlOO_dataout;
	wire_niOO_dataout <= mbus_out(9) WHEN ld_data = '1'  ELSE wire_n1i_dataout;
	wire_nl_dataout <= mbus_out(15) WHEN ld_data = '1'  ELSE wire_nO_dataout;
	wire_nl0i_dataout <= mbus_out(13) WHEN ld_data = '1'  ELSE wire_n0l_dataout;
	wire_nl0l_dataout <= mbus_out(14) WHEN ld_data = '1'  ELSE wire_n0O_dataout;
	wire_nl0O_dataout <= n1Oi WHEN nl11O = '1'  ELSE n01O;
	wire_nl1i_dataout <= mbus_out(10) WHEN ld_data = '1'  ELSE wire_n1l_dataout;
	wire_nl1l_dataout <= mbus_out(11) WHEN ld_data = '1'  ELSE wire_n1O_dataout;
	wire_nl1O_dataout <= mbus_out(12) WHEN ld_data = '1'  ELSE wire_n0i_dataout;
	wire_nlii_dataout <= n01O WHEN nl11O = '1'  ELSE n00i;
	wire_nlil_dataout <= n00i WHEN nl11O = '1'  ELSE n00l;
	wire_nliO_dataout <= n00l WHEN nl11O = '1'  ELSE n00O;
	wire_nlli_dataout <= n00O WHEN nl11O = '1'  ELSE n0ii;
	wire_nlll_dataout <= n0ii WHEN nl11O = '1'  ELSE n0il;
	wire_nllO_dataout <= n0il WHEN nl11O = '1'  ELSE n0iO;
	wire_nlOi_dataout <= n0iO WHEN nl11O = '1'  ELSE n0li;
	wire_nlOl_dataout <= n0li WHEN nl11O = '1'  ELSE n0ll;
	wire_nlOO_dataout <= n0ll WHEN nl11O = '1'  ELSE n0lO;
	wire_nO_dataout <= ni0i AND shift_out;

 END RTL; --stratixiv_hssi_cmu_dprio_ctl_data
--synopsys translate_on
--VALID FILE


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_dprio_sm IS
   GENERIC (
      
      IDLE           : INTEGER := 0;
      PREAMBLE       : INTEGER := 1;
      CONTROL        : INTEGER := 2;
      TURN_ARND_0    : INTEGER := 3;
      TURN_ARND_1    : INTEGER := 4;
      ADDR_DATA      : INTEGER := 5;
      ADDR_OP        : INTEGER := 0;
      WR_OP          : INTEGER := 1;
      RD_INC_OP      : INTEGER := 2;
      RD_OP          : INTEGER := 3
   );
   PORT (
      mdc            : IN STD_LOGIC;		-- Clock for MDIO interface
      mdio_in        : IN STD_LOGIC;		-- Signal bit data
      reset          : IN STD_LOGIC;		-- Active high Hard Reset
      opcode         : IN STD_LOGIC_VECTOR(1 DOWNTO 0);		-- 2 bit opcode from mdio_ctl_data module
      -- 00 - Address
      -- 01 - Write
      -- 10 - Read with no post Increment
      -- 11 - Read with post increment
      valid_addr     : IN STD_LOGIC;		-- When set the Port and Dev Address
      -- corresponds to this module
      cnt_eq_0       : IN STD_LOGIC;		-- From mdio_cnt module, down counter is 0
      shift_in       : OUT STD_LOGIC;		-- Shift in enable for either data or control
      shift_out      : OUT STD_LOGIC;		-- Shift out enable for mdio_ctl_data
      latch_ctl      : OUT STD_LOGIC;		-- Latch the Opcode, to mdio_ctl_data
      incr_addr      : OUT STD_LOGIC;		-- Increment signal for mdio_addr
      mdio_wr        : OUT STD_LOGIC;		-- This is used for writing the mdio registers
      mdio_rd        : OUT STD_LOGIC;		-- This is used for clearing the mdio status registers
      shift_addr     : OUT STD_LOGIC;		-- Shift in Enable for mdio_addr
      ld_data        : OUT STD_LOGIC;		-- When set, the shift register is mdio_ctl_data is parallely
      -- loaded with the data from mdio_reg module
      --output       ld_data_d;
      ld_cnt         : OUT STD_LOGIC;		-- Load Down counter
      cnt_val        : OUT STD_LOGIC_VECTOR(4 DOWNTO 0);		-- Value to load the down counter
      valid_addr_lt  : OUT STD_LOGIC;
      curr_state     : OUT STD_LOGIC_VECTOR(2 DOWNTO 0)
   );
END stratixiv_hssi_cmu_dprio_sm;

ARCHITECTURE trans OF stratixiv_hssi_cmu_dprio_sm IS
   
   --wire      ld_data_d;
   
   -- Allowed states for curr_state and next_state
   
   -- Decode for opcode
   
   SIGNAL next_state       : STD_LOGIC_VECTOR(2 DOWNTO 0);
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL cnt_val_xhdl0    : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL curr_state_xhdl1 : STD_LOGIC_VECTOR(2 DOWNTO 0);
BEGIN
   -- Drive referenced outputs
   cnt_val <= cnt_val_xhdl0;
   curr_state <= curr_state_xhdl1;
   
   -- Latch Curr State
   
   PROCESS (reset, mdc)
VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         curr_state_xhdl1 <= int2bin(IDLE, 3);
      ELSIF (mdc'EVENT AND mdc = '1') THEN
         curr_state_xhdl1 <= next_state;
      END IF;
   END PROCESS;
   
   -- Next State loic for mdio_sm
   
   PROCESS (curr_state_xhdl1, mdio_in, cnt_eq_0, valid_addr, opcode)
VARIABLE  txt : LINE;
   BEGIN
-- shawn manual fix      IF (curr_state_xhdl1'EVENT) THEN
         
         CASE curr_state_xhdl1 IS
            
            WHEN "000" =>
               IF (mdio_in = '1') THEN
                  next_state <= int2bin(PREAMBLE, 3);
               ELSE
                  next_state <= int2bin(IDLE, 3);
               END IF;
            WHEN "001" =>
               IF ((NOT(mdio_in) AND NOT(cnt_eq_0)) = '1') THEN
                  next_state <= int2bin(IDLE, 3);
               ELSIF ((NOT(mdio_in) AND cnt_eq_0) = '1') THEN
                  next_state <= int2bin(CONTROL, 3);
               ELSE
                  next_state <= int2bin(PREAMBLE, 3);
               END IF;
            
            WHEN "010" =>
               IF (cnt_eq_0 = '1') THEN
                  IF ((NOT(mdio_in)) = '1') THEN
                     next_state <= int2bin(IDLE, 3);
                  ELSE
                     next_state <= int2bin(TURN_ARND_0, 3);
                  END IF;
               ELSE
                  next_state <= int2bin(CONTROL, 3);
               END IF;
            
            WHEN "011" =>
               IF ((mdio_in OR NOT(valid_addr)) = '1') THEN
                  next_state <= int2bin(IDLE, 3);
               ELSIF (opcode = int2bin(WR_OP, 2) OR opcode = int2bin(ADDR_OP, 2)) THEN
                  next_state <= int2bin(TURN_ARND_1, 3);
               ELSE
                  next_state <= int2bin(ADDR_DATA, 3);
               END IF;
            --                     if (mdio_in)
            --                         next_state <= IDLE;
            --                     else
            
            WHEN "100" =>
               next_state <= int2bin(ADDR_DATA, 3);
            
            WHEN "101" =>
               IF ((cnt_eq_0 AND mdio_in) = '1' AND (opcode = int2bin(WR_OP, 2) OR opcode = int2bin(ADDR_OP, 2))) THEN
                  next_state <= int2bin(PREAMBLE, 3);
               ELSIF (cnt_eq_0 = '1') THEN
                  next_state <= int2bin(IDLE, 3);
               ELSE
                  next_state <= int2bin(ADDR_DATA, 3);
               END IF;
            
            WHEN OTHERS =>
               next_state <= int2bin(IDLE, 3);
         END CASE;
-- shawn manual fix      END IF;
   END PROCESS;
   
   -- Valid_addr_lt is used to enable mdio_out
   
   PROCESS (reset, mdc)
VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         valid_addr_lt <= '0';
      ELSIF (mdc'EVENT AND mdc = '1') THEN
         IF (valid_addr = '1' AND curr_state_xhdl1 = int2bin(TURN_ARND_0, 3)) THEN
            valid_addr_lt <= '1';
         ELSIF (curr_state_xhdl1 = int2bin(ADDR_DATA, 3) AND cnt_eq_0 = '1') THEN
            valid_addr_lt <= '0';
         END IF;
      END IF;
   END PROCESS;
   
   -- Logic for shift_in, This signal is used for shifting in
   -- control logic, during all commands, and data during
   -- Write command
   
   PROCESS (reset, mdc)
VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         shift_in <= '0';
      ELSIF (mdc'EVENT AND mdc = '1') THEN
         IF ((curr_state_xhdl1 = int2bin(PREAMBLE, 3) AND next_state = int2bin(CONTROL, 3)) OR (next_state = int2bin(CONTROL, 3)) OR (next_state = int2bin(ADDR_DATA, 3) AND opcode = int2bin(WR_OP, 2))) THEN
            shift_in <= '1';
         ELSE
            shift_in <= '0';
         END IF;
      END IF;
   END PROCESS;
   
   -- Shift_out logic, shift_out is set when data is shifted out on
   -- a RD_OP or RD_INC_OP command
   
   PROCESS (reset, mdc)
VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         shift_out <= '0';
      ELSIF (mdc'EVENT AND mdc = '1') THEN
         IF ((curr_state_xhdl1 = int2bin(TURN_ARND_0, 3) AND next_state = int2bin(ADDR_DATA, 3)) OR (curr_state_xhdl1 = int2bin(ADDR_DATA, 3) AND (opcode = int2bin(RD_OP, 2) OR opcode = int2bin(RD_INC_OP, 2)) AND ((NOT(cnt_eq_0))) = '1')) THEN
            shift_out <= '1';
         ELSE
            shift_out <= '0';
         END IF;
      END IF;
   END PROCESS;
   
   -- Logic for latch_ctl, this signal is used for latching the opcode
   -- This signal is set when in Control state and moving to TURN_ARND_0
   -- state
   
   PROCESS (cnt_eq_0, curr_state_xhdl1)
VARIABLE  txt : LINE;
   BEGIN
      IF (curr_state_xhdl1'EVENT) THEN
         
         -- Logic for incr_addr, incr_addr is set for opcode RD_INC_OP and
         -- after completely shifting out the read data for the current command
         
         latch_ctl <= cnt_eq_0 AND int2bit(curr_state_xhdl1 = int2bin(CONTROL, 3));
      END IF;
   END PROCESS;
   PROCESS (reset, mdc)
VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         incr_addr <= '0';
      ELSIF (mdc'EVENT AND mdc = '1') THEN
         IF (curr_state_xhdl1 = int2bin(ADDR_DATA, 3) AND cnt_eq_0 = '1' AND opcode = int2bin(RD_INC_OP, 2)) THEN
            incr_addr <= '1';
         ELSE
            incr_addr <= '0';
         END IF;
      END IF;
   END PROCESS;
   
   -- Logic for shift addr, this bit is set when moving to ADDR_DATA 
   -- state and when in ADDR_DATA state for ADDR_OP command
   
   PROCESS (reset, mdc)
VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         shift_addr <= '0';
      ELSIF (mdc'EVENT AND mdc = '1') THEN
         IF (next_state = int2bin(ADDR_DATA, 3) AND opcode = int2bin(ADDR_OP, 2)) THEN
            shift_addr <= '1';
         ELSE
            shift_addr <= '0';
         END IF;
      END IF;
   END PROCESS;
   
   -- Logic for mdio_wr, this bit is set when moving from ADDR_DATA to the
   -- IDLE for a WR_OP command
   -- Logic for mdio_rd, this bit is set when moving from ADDR_DATA to the
   -- IDLE for a RD_OP/RD_INC_OP command
   
   PROCESS (reset, mdc)
VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         mdio_wr <= '0';
         mdio_rd <= '0';
      ELSIF (mdc'EVENT AND mdc = '1') THEN
         IF (curr_state_xhdl1 = int2bin(ADDR_DATA, 3) AND cnt_eq_0 = '1') THEN
            IF (opcode = int2bin(WR_OP, 2)) THEN
               mdio_wr <= '1';
            ELSE
               mdio_wr <= '0';
            END IF;
            IF (opcode = int2bin(RD_OP, 2) OR opcode = int2bin(RD_INC_OP, 2)) THEN
               mdio_rd <= '1';
            ELSE
               mdio_rd <= '0';
            END IF;
         ELSE
            mdio_wr <= '0';
            mdio_rd <= '0';
         END IF;
      END IF;
   END PROCESS;
   
   -- Logic for ld_data, this signal is used for parallely loading the
   -- shift register in mdio_ctl_data module with the data from mdio_reg
   -- module. This set is set for RD_OP and RD_INC_OP commands when the
   -- SM transitions from TURN_ARND_0 to ADDR_DATA state
   -- assign ld_data_d = (curr_state == TURN_ARND_0 && (opcode == RD_OP | opcode == RD_INC_OP));
   
   PROCESS (reset, mdc)
VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         ld_data <= '0';
      ELSIF (mdc'EVENT AND mdc = '1') THEN
         ld_data <= int2bit((curr_state_xhdl1 = int2bin(TURN_ARND_0, 3) AND next_state = int2bin(ADDR_DATA, 3)));
      END IF;
   END PROCESS;
   
   -- Logic for ld_cnt, this signal is used for loading the down counter
   -- with cnt_val signal. This signal is set when going to
   -- CONTROL state or ADDR_DATA state or PREAMBLE states
   
   PROCESS (reset, mdc)
VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         ld_cnt <= '0';
      ELSIF (mdc'EVENT AND mdc = '1') THEN
         IF ((curr_state_xhdl1 = int2bin(IDLE, 3) AND next_state = int2bin(PREAMBLE, 3)) OR (curr_state_xhdl1 = int2bin(ADDR_DATA, 3) AND next_state = int2bin(PREAMBLE, 3)) OR (curr_state_xhdl1 = int2bin(PREAMBLE, 3) AND next_state = int2bin(CONTROL, 3)) OR (curr_state_xhdl1 = int2bin(TURN_ARND_0, 3) AND next_state = int2bin(ADDR_DATA, 3)) OR (curr_state_xhdl1 = int2bin(TURN_ARND_1, 3) AND next_state = int2bin(ADDR_DATA, 3))) THEN
            ld_cnt <= '1';
         ELSE
            ld_cnt <= '0';
         END IF;
      END IF;
   END PROCESS;
   
   -- Logic for cnt_val, this counter value is used for sown counting
   -- the mdio_cnt, when the counter reaches zero, the cnt_eq_0 is
   -- set. The counter is loading with 31 for PREAMBLE, 13 for 
   -- CONTROL, and 15 for ADDR_DATA
   
   PROCESS (reset, mdc)
VARIABLE  txt : LINE;
   BEGIN
      IF (reset = '1') THEN
         cnt_val_xhdl0 <= "00000";
      ELSIF (mdc'EVENT AND mdc = '1') THEN
         IF ((curr_state_xhdl1 = int2bin(IDLE, 3) OR curr_state_xhdl1 = int2bin(ADDR_DATA, 3)) AND next_state = int2bin(PREAMBLE, 3)) THEN
            cnt_val_xhdl0 <= "11110";
         ELSIF (curr_state_xhdl1 = int2bin(PREAMBLE, 3) AND next_state = int2bin(CONTROL, 3)) THEN
            cnt_val_xhdl0 <= "01100";
         ELSIF (curr_state_xhdl1 = int2bin(TURN_ARND_0, 3) AND next_state = int2bin(ADDR_DATA, 3)) THEN
            cnt_val_xhdl0 <= "01110";
         ELSIF (curr_state_xhdl1 = int2bin(TURN_ARND_1, 3) AND next_state = int2bin(ADDR_DATA, 3)) THEN
            cnt_val_xhdl0 <= "01110";
         ELSE
            cnt_val_xhdl0 <= cnt_val_xhdl0;
         END IF;
      END IF;
   END PROCESS;
   
END trans;





LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_dprio_reg_centrl IS
   PORT (
      -- CSR input
      -- DPRIO register output
      
      mdio_rst            : IN STD_LOGIC;
      mdio_wr             : IN STD_LOGIC;
      reg_addr            : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      mdc                 : IN STD_LOGIC;
      mbus_in             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      serial_mode         : IN STD_LOGIC;
      mdio_dis            : IN STD_LOGIC;
      pma_cram_test       : IN STD_LOGIC;
      ser_shift_load      : IN STD_LOGIC;
      si                  : IN STD_LOGIC;
      ext_centrl_ctrl_1   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_2   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_3   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_4   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_5   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_6   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_7   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_8   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_9   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_10  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_11  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_12  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_13  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_14  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_15  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_16  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_17  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_18  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_19  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_20  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_21  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_22  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_23  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_24  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_25  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_26  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_27  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_28  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_29  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_30  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_31  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_32  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_33  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_34  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_35  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_36  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_37  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_38  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_39  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_40  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_41  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_42  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_43  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_44  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_45  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ext_centrl_ctrl_46  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      
      targ_addr_ctrl_1    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_2    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_3    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_4    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_5    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_6    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_7    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_8    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_9    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_10   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_11   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_12   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_13   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_14   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_15   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_16   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_17   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_18   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_19   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_20   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_21   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_22   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_23   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_24   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_25   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_26   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_27   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_28   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_29   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_30   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_31   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_32   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_33   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_34   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_35   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_36   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_37   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_38   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_39   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_40   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_41   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_42   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_43   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_44   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_45   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      targ_addr_ctrl_46   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      
      out_centrl_ctrl_1   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_2   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_3   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_4   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_5   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_6   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_7   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_8   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_9   : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_10  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_11  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_12  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_13  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_14  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_15  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_16  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_17  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_18  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_19  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_20  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_21  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_22  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_23  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_24  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_25  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_26  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_27  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_28  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_29  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_30  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_31  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_32  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_33  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_34  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_35  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_36  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_37  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_38  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_39  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_40  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_41  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_42  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_43  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_44  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_45  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      out_centrl_ctrl_46  : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      
      so                  : OUT STD_LOGIC
   );
END stratixiv_hssi_cmu_dprio_reg_centrl;

ARCHITECTURE trans OF stratixiv_hssi_cmu_dprio_reg_centrl IS
   COMPONENT stratixiv_hssi_cmu_dprio_16bit
      PORT (
         reset               : IN STD_LOGIC;
         mdio_wr             : IN STD_LOGIC;
         reg_addr            : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         target_addr         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         clk                 : IN STD_LOGIC;
         sig_in              : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_in              : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         serial_mode         : IN STD_LOGIC;
         si                  : IN STD_LOGIC;
         shift               : IN STD_LOGIC;
         mdio_dis            : IN STD_LOGIC;
         sig_out             : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         so                  : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_dprio_16bit_pma
      PORT (
         reset               : IN STD_LOGIC;
         mdio_wr             : IN STD_LOGIC;
         reg_addr            : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         target_addr         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         clk                 : IN STD_LOGIC;
         sig_in              : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ext_in              : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         serial_mode         : IN STD_LOGIC;
         si                  : IN STD_LOGIC;
         shift               : IN STD_LOGIC;
         mdio_dis            : IN STD_LOGIC;
         pma_cram_test       : IN STD_LOGIC;
         sig_out             : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         so                  : OUT STD_LOGIC
      );
   END COMPONENT;
   
   
   SIGNAL chain                     : STD_LOGIC_VECTOR(44 DOWNTO 0);
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL out_centrl_ctrl_1_xhdl0   : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_2_xhdl11  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_3_xhdl22  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_4_xhdl33  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_5_xhdl39  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_6_xhdl40  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_7_xhdl41  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_8_xhdl42  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_9_xhdl43  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_10_xhdl1  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_11_xhdl2  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_12_xhdl3  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_13_xhdl4  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_14_xhdl5  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_15_xhdl6  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_16_xhdl7  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_17_xhdl8  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_18_xhdl9  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_19_xhdl10 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_20_xhdl12 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_21_xhdl13 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_22_xhdl14 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_23_xhdl15 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_24_xhdl16 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_25_xhdl17 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_26_xhdl18 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_27_xhdl19 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_28_xhdl20 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_29_xhdl21 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_30_xhdl23 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_31_xhdl24 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_32_xhdl25 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_33_xhdl26 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_34_xhdl27 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_35_xhdl28 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_36_xhdl29 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_37_xhdl30 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_38_xhdl31 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_39_xhdl32 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_40_xhdl34 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_41_xhdl35 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_42_xhdl36 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_43_xhdl37 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_44_xhdl38 : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_45_tmp : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL out_centrl_ctrl_46_tmp : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL so_tmp                 : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   out_centrl_ctrl_1 <= out_centrl_ctrl_1_xhdl0;
   out_centrl_ctrl_2 <= out_centrl_ctrl_2_xhdl11;
   out_centrl_ctrl_3 <= out_centrl_ctrl_3_xhdl22;
   out_centrl_ctrl_4 <= out_centrl_ctrl_4_xhdl33;
   out_centrl_ctrl_5 <= out_centrl_ctrl_5_xhdl39;
   out_centrl_ctrl_6 <= out_centrl_ctrl_6_xhdl40;
   out_centrl_ctrl_7 <= out_centrl_ctrl_7_xhdl41;
   out_centrl_ctrl_8 <= out_centrl_ctrl_8_xhdl42;
   out_centrl_ctrl_9 <= out_centrl_ctrl_9_xhdl43;
   out_centrl_ctrl_10 <= out_centrl_ctrl_10_xhdl1;
   out_centrl_ctrl_11 <= out_centrl_ctrl_11_xhdl2;
   out_centrl_ctrl_12 <= out_centrl_ctrl_12_xhdl3;
   out_centrl_ctrl_13 <= out_centrl_ctrl_13_xhdl4;
   out_centrl_ctrl_14 <= out_centrl_ctrl_14_xhdl5;
   out_centrl_ctrl_15 <= out_centrl_ctrl_15_xhdl6;
   out_centrl_ctrl_16 <= out_centrl_ctrl_16_xhdl7;
   out_centrl_ctrl_17 <= out_centrl_ctrl_17_xhdl8;
   out_centrl_ctrl_18 <= out_centrl_ctrl_18_xhdl9;
   out_centrl_ctrl_19 <= out_centrl_ctrl_19_xhdl10;
   out_centrl_ctrl_20 <= out_centrl_ctrl_20_xhdl12;
   out_centrl_ctrl_21 <= out_centrl_ctrl_21_xhdl13;
   out_centrl_ctrl_22 <= out_centrl_ctrl_22_xhdl14;
   out_centrl_ctrl_23 <= out_centrl_ctrl_23_xhdl15;
   out_centrl_ctrl_24 <= out_centrl_ctrl_24_xhdl16;
   out_centrl_ctrl_25 <= out_centrl_ctrl_25_xhdl17;
   out_centrl_ctrl_26 <= out_centrl_ctrl_26_xhdl18;
   out_centrl_ctrl_27 <= out_centrl_ctrl_27_xhdl19;
   out_centrl_ctrl_28 <= out_centrl_ctrl_28_xhdl20;
   out_centrl_ctrl_29 <= out_centrl_ctrl_29_xhdl21;
   out_centrl_ctrl_30 <= out_centrl_ctrl_30_xhdl23;
   out_centrl_ctrl_31 <= out_centrl_ctrl_31_xhdl24;
   out_centrl_ctrl_32 <= out_centrl_ctrl_32_xhdl25;
   out_centrl_ctrl_33 <= out_centrl_ctrl_33_xhdl26;
   out_centrl_ctrl_34 <= out_centrl_ctrl_34_xhdl27;
   out_centrl_ctrl_35 <= out_centrl_ctrl_35_xhdl28;
   out_centrl_ctrl_36 <= out_centrl_ctrl_36_xhdl29;
   out_centrl_ctrl_37 <= out_centrl_ctrl_37_xhdl30;
   out_centrl_ctrl_38 <= out_centrl_ctrl_38_xhdl31;
   out_centrl_ctrl_39 <= out_centrl_ctrl_39_xhdl32;
   out_centrl_ctrl_40 <= out_centrl_ctrl_40_xhdl34;
   out_centrl_ctrl_41 <= out_centrl_ctrl_41_xhdl35;
   out_centrl_ctrl_42 <= out_centrl_ctrl_42_xhdl36;
   out_centrl_ctrl_43 <= out_centrl_ctrl_43_xhdl37;
   out_centrl_ctrl_44 <= out_centrl_ctrl_44_xhdl38;
   out_centrl_ctrl_45 <= out_centrl_ctrl_45_tmp;
   out_centrl_ctrl_46 <= out_centrl_ctrl_46_tmp;
   
   so <= so_tmp;
   
   
   
   centrl_ctrl_1 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_1,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_1,
         serial_mode    => serial_mode,
         si             => si,
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_1_xhdl0,
         so             => chain(0)
      );
   
   
   
   centrl_ctrl_2 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_2,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_2,
         serial_mode    => serial_mode,
         si             => chain(0),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_2_xhdl11,
         so             => chain(1)
      );
   
   
   
   centrl_ctrl_3 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_3,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_3,
         serial_mode    => serial_mode,
         si             => chain(1),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_3_xhdl22,
         so             => chain(2)
      );
   
   
   
   centrl_ctrl_4 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_4,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_4,
         serial_mode    => serial_mode,
         si             => chain(2),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_4_xhdl33,
         so             => chain(3)
      );
   
   
   
   centrl_ctrl_5 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_5,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_5,
         serial_mode    => serial_mode,
         si             => chain(3),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_5_xhdl39,
         so             => chain(4)
      );
   
   
   
   centrl_ctrl_6 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_6,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_6,
         serial_mode    => serial_mode,
         si             => chain(4),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_6_xhdl40,
         so             => chain(5)
      );
   
   
   
   centrl_ctrl_7 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_7,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_7,
         serial_mode    => serial_mode,
         si             => chain(5),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_7_xhdl41,
         so             => chain(6)
      );
   
   
   
   centrl_ctrl_8 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_8,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_8,
         serial_mode    => serial_mode,
         si             => chain(6),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_8_xhdl42,
         so             => chain(7)
      );
   
   
   
   centrl_ctrl_9 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_9,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_9,
         serial_mode    => serial_mode,
         si             => chain(7),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_9_xhdl43,
         so             => chain(8)
      );
   
   
   
   centrl_ctrl_10 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_10,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_10,
         serial_mode    => serial_mode,
         si             => chain(8),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_10_xhdl1,
         so             => chain(9)
      );
   
   
   
   centrl_ctrl_11 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_11,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_11,
         serial_mode    => serial_mode,
         si             => chain(9),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_11_xhdl2,
         so             => chain(10)
      );
   
   
   
   centrl_ctrl_12 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_12,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_12,
         serial_mode    => serial_mode,
         si             => chain(10),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_12_xhdl3,
         so             => chain(11)
      );
   
   
   
   centrl_ctrl_13 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_13,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_13,
         serial_mode    => serial_mode,
         si             => chain(11),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_13_xhdl4,
         so             => chain(12)
      );
   
   
   
   centrl_ctrl_14 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_14,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_14,
         serial_mode    => serial_mode,
         si             => chain(12),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_14_xhdl5,
         so             => chain(13)
      );
   
   
   
   centrl_ctrl_15 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_15,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_15,
         serial_mode    => serial_mode,
         si             => chain(13),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_15_xhdl6,
         so             => chain(14)
      );
   
   
   
   centrl_ctrl_16 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_16,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_16,
         serial_mode    => serial_mode,
         si             => chain(14),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_16_xhdl7,
         so             => chain(15)
      );
   
   
   
   centrl_ctrl_17 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_17,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_17,
         serial_mode    => serial_mode,
         si             => chain(15),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_17_xhdl8,
         so             => chain(16)
      );
   
   
   
   centrl_ctrl_18 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_18,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_18,
         serial_mode    => serial_mode,
         si             => chain(16),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_18_xhdl9,
         so             => chain(17)
      );
   
   
   
   centrl_ctrl_19 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_19,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_19,
         serial_mode    => serial_mode,
         si             => chain(17),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_19_xhdl10,
         so             => chain(18)
      );
   
   
   
   centrl_ctrl_20 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_20,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_20,
         serial_mode    => serial_mode,
         si             => chain(18),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_20_xhdl12,
         so             => chain(19)
      );
   
   
   
   centrl_ctrl_21 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_21,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_21,
         serial_mode    => serial_mode,
         si             => chain(19),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_21_xhdl13,
         so             => chain(20)
      );
   
   
   
   centrl_ctrl_22 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_22,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_22,
         serial_mode    => serial_mode,
         si             => chain(20),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_22_xhdl14,
         so             => chain(21)
      );
   
   
   
   centrl_ctrl_23 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_23,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_23,
         serial_mode    => serial_mode,
         si             => chain(21),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_23_xhdl15,
         so             => chain(22)
      );
   
   
   
   centrl_ctrl_24 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_24,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_24,
         serial_mode    => serial_mode,
         si             => chain(22),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_24_xhdl16,
         so             => chain(23)
      );
   
   
   
   centrl_ctrl_25 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_25,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_25,
         serial_mode    => serial_mode,
         si             => chain(23),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_25_xhdl17,
         so             => chain(24)
      );
   
   
   
   centrl_ctrl_26 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_26,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_26,
         serial_mode    => serial_mode,
         si             => chain(24),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_26_xhdl18,
         so             => chain(25)
      );
   
   
   
   centrl_ctrl_27 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_27,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_27,
         serial_mode    => serial_mode,
         si             => chain(25),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_27_xhdl19,
         so             => chain(26)
      );
   
   
   
   centrl_ctrl_28 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_28,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_28,
         serial_mode    => serial_mode,
         si             => chain(26),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_28_xhdl20,
         so             => chain(27)
      );
   
   
   
   centrl_ctrl_29 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_29,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_29,
         serial_mode    => serial_mode,
         si             => chain(27),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_29_xhdl21,
         so             => chain(28)
      );
   
   
   
   centrl_ctrl_30 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_30,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_30,
         serial_mode    => serial_mode,
         si             => chain(28),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_30_xhdl23,
         so             => chain(29)
      );
   
   
   
   centrl_ctrl_31 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_31,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_31,
         serial_mode    => serial_mode,
         si             => chain(29),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_31_xhdl24,
         so             => chain(30)
      );
   
   
   
   centrl_ctrl_32 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_32,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_32,
         serial_mode    => serial_mode,
         si             => chain(30),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_32_xhdl25,
         so             => chain(31)
      );
   
   
   
   centrl_ctrl_33 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_33,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_33,
         serial_mode    => serial_mode,
         si             => chain(31),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_33_xhdl26,
         so             => chain(32)
      );
   
   
   
   centrl_ctrl_34 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_34,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_34,
         serial_mode    => serial_mode,
         si             => chain(32),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_34_xhdl27,
         so             => chain(33)
      );
   
   
   
   centrl_ctrl_35 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_35,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_35,
         serial_mode    => serial_mode,
         si             => chain(33),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_35_xhdl28,
         so             => chain(34)
      );
   
   
   
   centrl_ctrl_36 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_36,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_36,
         serial_mode    => serial_mode,
         si             => chain(34),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_36_xhdl29,
         so             => chain(35)
      );
   
   
   
   centrl_ctrl_37 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_37,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_37,
         serial_mode    => serial_mode,
         si             => chain(35),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_37_xhdl30,
         so             => chain(36)
      );
   
   
   
   centrl_ctrl_38 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_38,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_38,
         serial_mode    => serial_mode,
         si             => chain(36),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_38_xhdl31,
         so             => chain(37)
      );
   
   
   
   centrl_ctrl_39 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_39,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_39,
         serial_mode    => serial_mode,
         si             => chain(37),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_39_xhdl32,
         so             => chain(38)
      );
   
   
   
   centrl_ctrl_40 : stratixiv_hssi_cmu_dprio_16bit_pma
      PORT MAP (
         reset          => mdio_rst,
         mdio_wr        => mdio_wr,
         reg_addr       => reg_addr,
         target_addr    => targ_addr_ctrl_40,
         clk            => mdc,
         sig_in         => mbus_in,
         ext_in         => ext_centrl_ctrl_40,
         serial_mode    => serial_mode,
         si             => chain(38),
         shift          => ser_shift_load,
         mdio_dis       => mdio_dis,
         pma_cram_test  => pma_cram_test,
         sig_out        => out_centrl_ctrl_40_xhdl34,
         so             => chain(39)
      );
   
   
   
   centrl_ctrl_41 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_41,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_centrl_ctrl_41,
         serial_mode  => serial_mode,
         si           => chain(39),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_centrl_ctrl_41_xhdl35,
         so           => chain(40)
      );
   
   
   
   centrl_ctrl_42 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_42,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_centrl_ctrl_42,
         serial_mode  => serial_mode,
         si           => chain(40),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_centrl_ctrl_42_xhdl36,
         so           => chain(41)
      );
   
   
   
   centrl_ctrl_43 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_43,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_centrl_ctrl_43,
         serial_mode  => serial_mode,
         si           => chain(41),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_centrl_ctrl_43_xhdl37,
         so           => chain(42)
      );
   
   
   
   centrl_ctrl_44 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_44,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_centrl_ctrl_44,
         serial_mode  => serial_mode,
         si           => chain(42),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_centrl_ctrl_44_xhdl38,
         so           => chain(43)
      );
   
   -- new ww25
   centrl_ctrl_45 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_45,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_centrl_ctrl_45,
         serial_mode  => serial_mode,
         si           => chain(43),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_centrl_ctrl_45_tmp,
         so           => chain(44)
      );
   
   centrl_ctrl_46 : stratixiv_hssi_cmu_dprio_16bit
      PORT MAP (
         reset        => mdio_rst,
         mdio_wr      => mdio_wr,
         reg_addr     => reg_addr,
         target_addr  => targ_addr_ctrl_46,
         clk          => mdc,
         sig_in       => mbus_in,
         ext_in       => ext_centrl_ctrl_46,
         serial_mode  => serial_mode,
         si           => chain(44),
         shift        => ser_shift_load,
         mdio_dis     => mdio_dis,
         sig_out      => out_centrl_ctrl_46_tmp,
         so           => so_tmp
      );

END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_dprio_centrl_bus_out_mux IS
   PORT (
      
      centrl_ctrl_in1       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in2       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in3       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in4       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in5       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in6       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in7       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in8       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in9       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in10      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in11      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in12      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in13      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in14      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in15      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in16      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in17      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in18      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in19      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in20      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in21      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in22      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in23      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in24      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in25      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in26      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in27      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in28      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in29      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in30      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in31      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in32      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in33      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in34      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in35      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in36      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in37      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in38      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in39      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in40      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in41      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in42      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in43      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in44      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in45      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      centrl_ctrl_in46      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      
      hw_address_ctrl_in1   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in2   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in3   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in4   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in5   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in6   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in7   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in8   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in9   : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in10  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in11  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in12  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in13  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in14  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in15  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in16  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in17  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in18  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in19  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in20  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in21  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in22  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in23  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in24  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in25  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in26  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in27  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in28  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in29  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in30  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in31  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in32  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in33  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in34  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in35  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in36  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in37  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in38  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in39  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in40  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in41  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in42  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in43  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in44  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in45  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      hw_address_ctrl_in46  : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      
      reg_addr              : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      
      centrl_ctrl_out       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0)
   );
END stratixiv_hssi_cmu_dprio_centrl_bus_out_mux;

ARCHITECTURE trans OF stratixiv_hssi_cmu_dprio_centrl_bus_out_mux IS
BEGIN
   
   centrl_ctrl_out <= centrl_ctrl_in1 WHEN (reg_addr = hw_address_ctrl_in1) ELSE
                      centrl_ctrl_in2 WHEN (reg_addr = hw_address_ctrl_in2) ELSE
                      centrl_ctrl_in3 WHEN (reg_addr = hw_address_ctrl_in3) ELSE
                      centrl_ctrl_in4 WHEN (reg_addr = hw_address_ctrl_in4) ELSE
                      centrl_ctrl_in5 WHEN (reg_addr = hw_address_ctrl_in5) ELSE
                      centrl_ctrl_in6 WHEN (reg_addr = hw_address_ctrl_in6) ELSE
                      centrl_ctrl_in7 WHEN (reg_addr = hw_address_ctrl_in7) ELSE
                      centrl_ctrl_in8 WHEN (reg_addr = hw_address_ctrl_in8) ELSE
                      centrl_ctrl_in9 WHEN (reg_addr = hw_address_ctrl_in9) ELSE
                      centrl_ctrl_in10 WHEN (reg_addr = hw_address_ctrl_in10) ELSE
                      centrl_ctrl_in11 WHEN (reg_addr = hw_address_ctrl_in11) ELSE
                      centrl_ctrl_in12 WHEN (reg_addr = hw_address_ctrl_in12) ELSE
                      centrl_ctrl_in13 WHEN (reg_addr = hw_address_ctrl_in13) ELSE
                      centrl_ctrl_in14 WHEN (reg_addr = hw_address_ctrl_in14) ELSE
                      centrl_ctrl_in15 WHEN (reg_addr = hw_address_ctrl_in15) ELSE
                      centrl_ctrl_in16 WHEN (reg_addr = hw_address_ctrl_in16) ELSE
                      centrl_ctrl_in17 WHEN (reg_addr = hw_address_ctrl_in17) ELSE
                      centrl_ctrl_in18 WHEN (reg_addr = hw_address_ctrl_in18) ELSE
                      centrl_ctrl_in19 WHEN (reg_addr = hw_address_ctrl_in19) ELSE
                      centrl_ctrl_in20 WHEN (reg_addr = hw_address_ctrl_in20) ELSE
                      centrl_ctrl_in21 WHEN (reg_addr = hw_address_ctrl_in21) ELSE
                      centrl_ctrl_in22 WHEN (reg_addr = hw_address_ctrl_in22) ELSE
                      centrl_ctrl_in23 WHEN (reg_addr = hw_address_ctrl_in23) ELSE
                      centrl_ctrl_in24 WHEN (reg_addr = hw_address_ctrl_in24) ELSE
                      centrl_ctrl_in25 WHEN (reg_addr = hw_address_ctrl_in25) ELSE
                      centrl_ctrl_in26 WHEN (reg_addr = hw_address_ctrl_in26) ELSE
                      centrl_ctrl_in27 WHEN (reg_addr = hw_address_ctrl_in27) ELSE
                      centrl_ctrl_in28 WHEN (reg_addr = hw_address_ctrl_in28) ELSE
                      centrl_ctrl_in29 WHEN (reg_addr = hw_address_ctrl_in29) ELSE
                      centrl_ctrl_in30 WHEN (reg_addr = hw_address_ctrl_in30) ELSE
                      centrl_ctrl_in31 WHEN (reg_addr = hw_address_ctrl_in31) ELSE
                      centrl_ctrl_in32 WHEN (reg_addr = hw_address_ctrl_in32) ELSE
                      centrl_ctrl_in33 WHEN (reg_addr = hw_address_ctrl_in33) ELSE
                      centrl_ctrl_in34 WHEN (reg_addr = hw_address_ctrl_in34) ELSE
                      centrl_ctrl_in35 WHEN (reg_addr = hw_address_ctrl_in35) ELSE
                      centrl_ctrl_in36 WHEN (reg_addr = hw_address_ctrl_in36) ELSE
                      centrl_ctrl_in37 WHEN (reg_addr = hw_address_ctrl_in37) ELSE
                      centrl_ctrl_in38 WHEN (reg_addr = hw_address_ctrl_in38) ELSE
                      centrl_ctrl_in39 WHEN (reg_addr = hw_address_ctrl_in39) ELSE
                      centrl_ctrl_in40 WHEN (reg_addr = hw_address_ctrl_in40) ELSE
                      centrl_ctrl_in41 WHEN (reg_addr = hw_address_ctrl_in41) ELSE
                      centrl_ctrl_in42 WHEN (reg_addr = hw_address_ctrl_in42) ELSE
                      centrl_ctrl_in43 WHEN (reg_addr = hw_address_ctrl_in43) ELSE
                      centrl_ctrl_in44 WHEN (reg_addr = hw_address_ctrl_in44) ELSE
                      centrl_ctrl_in45 WHEN (reg_addr = hw_address_ctrl_in45) ELSE
                      centrl_ctrl_in46 WHEN (reg_addr = hw_address_ctrl_in46) ELSE
                      "0000000000000000";
   
END trans;




LIBRARY ieee;
USE ieee.std_logic_1164.all;
--USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_dprio_centrl_top IS
    PORT (
        mdio_rst                : IN STD_LOGIC;		-- DPRIO reset input
        mdio_wr                 : IN STD_LOGIC;		-- DPRIO register write enable
        reg_addr                : IN STD_LOGIC_VECTOR(15 DOWNTO 0);		-- DPRIO register address from SM
        mdc                     : IN STD_LOGIC;		-- DPRIO clock
        mbus_in                 : IN STD_LOGIC_VECTOR(15 DOWNTO 0);		-- DPRIO data in from SM
        serial_mode             : IN STD_LOGIC;		-- DPRIO serial mode enable
        mdio_dis                : IN STD_LOGIC;		-- DPRIO disable signal (using CSR input)
        pma_cram_test           : IN STD_LOGIC;		-- PLD dynamic signal for PMA DPRIO cell for coverage for PE/TE
        ser_shift_load          : IN STD_LOGIC;		-- DPRIO serial shift or load control signal
        si                      : IN STD_LOGIC;		-- DPRIO serial input
        csr_centrl_in           : IN STD_LOGIC_VECTOR(703 DOWNTO 0);		-- CSR inputs
        csr_centrl_in_reserved  : IN STD_LOGIC_VECTOR(31 DOWNTO 0);
        
        dp_centrl_out           : OUT STD_LOGIC_VECTOR(703 DOWNTO 0);		-- CSR inputs
        dp_centrl_out_reserved  : OUT STD_LOGIC_VECTOR(31 DOWNTO 0);
        so                      : OUT STD_LOGIC;		-- DPRIO serial out
        mbus_out                : OUT STD_LOGIC_VECTOR(15 DOWNTO 0)		-- DPRIO dataout
    );
END ENTITY stratixiv_hssi_cmu_dprio_centrl_top;

ARCHITECTURE trans OF stratixiv_hssi_cmu_dprio_centrl_top IS
    COMPONENT stratixiv_hssi_cmu_dprio_centrl_bus_out_mux IS
        PORT (
            centrl_ctrl_in1         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in2         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in3         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in4         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in5         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in6         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in7         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in8         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in9         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in10        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in11        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in12        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in13        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in14        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in15        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in16        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in17        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in18        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in19        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in20        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in21        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in22        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in23        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in24        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in25        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in26        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in27        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in28        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in29        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in30        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in31        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in32        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in33        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in34        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in35        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in36        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in37        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in38        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in39        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in40        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in41        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in42        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in43        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in44        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in45        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_in46        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in1     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in2     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in3     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in4     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in5     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in6     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in7     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in8     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in9     : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in10    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in11    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in12    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in13    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in14    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in15    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in16    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in17    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in18    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in19    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in20    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in21    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in22    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in23    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in24    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in25    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in26    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in27    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in28    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in29    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in30    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in31    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in32    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in33    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in34    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in35    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in36    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in37    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in38    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in39    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in40    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in41    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in42    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in43    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in44    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in45    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            hw_address_ctrl_in46    : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            reg_addr                : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            centrl_ctrl_out         : OUT STD_LOGIC_VECTOR(15 DOWNTO 0)
        );
    END COMPONENT;
    
    COMPONENT stratixiv_hssi_cmu_dprio_reg_centrl IS
        PORT (
            mdio_rst                : IN STD_LOGIC;
            mdio_wr                 : IN STD_LOGIC;
            reg_addr                : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            mdc                     : IN STD_LOGIC;
            mbus_in                 : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            serial_mode             : IN STD_LOGIC;
            mdio_dis                : IN STD_LOGIC;
            pma_cram_test           : IN STD_LOGIC;
            ser_shift_load          : IN STD_LOGIC;
            si                      : IN STD_LOGIC;
            ext_centrl_ctrl_1       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_2       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_3       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_4       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_5       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_6       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_7       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_8       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_9       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_10      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_11      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_12      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_13      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_14      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_15      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_16      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_17      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_18      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_19      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_20      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_21      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_22      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_23      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_24      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_25      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_26      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_27      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_28      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_29      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_30      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_31      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_32      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_33      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_34      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_35      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_36      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_37      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_38      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_39      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_40      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_41      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_42      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_43      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_44      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_45      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            ext_centrl_ctrl_46      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_1        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_2        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_3        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_4        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_5        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_6        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_7        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_8        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_9        : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_10       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_11       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_12       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_13       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_14       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_15       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_16       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_17       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_18       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_19       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_20       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_21       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_22       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_23       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_24       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_25       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_26       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_27       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_28       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_29       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_30       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_31       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_32       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_33       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_34       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_35       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_36       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_37       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_38       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_39       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_40       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_41       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_42       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_43       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_44       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_45       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            targ_addr_ctrl_46       : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_1       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_2       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_3       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_4       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_5       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_6       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_7       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_8       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_9       : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_10      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_11      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_12      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_13      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_14      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_15      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_16      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_17      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_18      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_19      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_20      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_21      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_22      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_23      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_24      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_25      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_26      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_27      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_28      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_29      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_30      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_31      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_32      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_33      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_34      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_35      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_36      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_37      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_38      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_39      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_40      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_41      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_42      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_43      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_44      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_45      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            out_centrl_ctrl_46      : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
            so                      : OUT STD_LOGIC
        );
    END COMPONENT;
    
    
    --////////////////////////////////////////////////////////////////////////
    -- begin of CRAM output -------------------------------------------------
    --////////////////////////////////////////////////////////////////////////
    
    -- CRAM output
    -- Central PCS CRAMs
    SIGNAL rs_lpbk_all              : STD_LOGIC;		-- Global serial loopback enable CRAM
    SIGNAL rpowerdown               : STD_LOGIC;		-- Output CRAM of RPOWERDOWN
    SIGNAL rtest_bus_centrl_sel     : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- Central Test bus selection CRAMs
    SIGNAL rx16_x12_sel_tx          : STD_LOGIC;		-- Enable/Disable x16/x12
    SIGNAL rx16_x12_sel_rx          : STD_LOGIC;		-- Enable/Disable x16/x12
    SIGNAL rphfifo_master_sel_tx    : STD_LOGIC;		-- TX Phase comp. FIFO pointers selection CRAM
    SIGNAL rphfifo_master_sel_rx    : STD_LOGIC;		-- TX Phase comp. FIFO pointers selection CRAM
    SIGNAL rendec_data_sel_tx       : STD_LOGIC;		-- TX 8B10B encoder data in selection CRAM
    SIGNAL rendec_data_sel_rx       : STD_LOGIC;		-- RX 8B10B decoder data out selection CRAM
    SIGNAL rnenbpin                 : STD_LOGIC;		-- Output CRAM of RNENBPIN
    SIGNAL rpllurst                 : STD_LOGIC;		-- Output CRAM of RPLLURST
    SIGNAL rreset                   : STD_LOGIC;		-- Output CRAM of RRESET
    SIGNAL rdeskewen                : STD_LOGIC;		-- Deskew function enable CRAM
    SIGNAL rindv_tx                 : STD_LOGIC;		-- TX SM bypassing CRAM
    SIGNAL rindv_rx                 : STD_LOGIC;		-- RX SM bypassing CRAM
    SIGNAL rfreerun_centrl          : STD_LOGIC;		-- REFCLK_OUT free running enable CRAM
    SIGNAL rcentrl_clk_sel          : STD_LOGIC;		-- REFCLK_PMA global clock selection CRAM
    SIGNAL rrefclk_out_div2         : STD_LOGIC;		-- REFCLK_OUT divide by 2 enable CRAM
    SIGNAL rxaui_s2gx_en_rx         : STD_LOGIC;		-- Enable S2GX XAUI RX SM behavior
    SIGNAL ralgnopt                 : STD_LOGIC;		-- De-skew SM Hysteresis Option
    SIGNAL rdskposdisp              : STD_LOGIC;		-- Match the programmed de-skew pattern only
    SIGNAL rdskchrp                 : STD_LOGIC_VECTOR(9 DOWNTO 0);		-- Programmable Deskew Char. Pos. Disp.
    SIGNAL rxaui_s2gx_en_tx         : STD_LOGIC;		-- Enable S2GX XAUI TX SM behavior 
    SIGNAL rpcs_centrl_rsvd_cram    : STD_LOGIC_VECTOR(10 DOWNTO 0);		-- Central PCS reserved CRAMs
    SIGNAL rmaster_rx               : STD_LOGIC;		-- Please see S4GX DPRIO spreadsheet for description
    SIGNAL rmaster_up_rx            : STD_LOGIC;
    SIGNAL rmaster_tx               : STD_LOGIC;
    SIGNAL rmaster_up_tx            : STD_LOGIC;
    
    -- CMU0 PMA CRAMs
    -- Clock Output Buffer - refer to PMA TX section for description
    SIGNAL rcmu0_vod_sel            : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu0_powdnt             : STD_LOGIC;
    SIGNAL rcmu0_pre_em_1t          : STD_LOGIC_VECTOR(4 DOWNTO 0);
    SIGNAL rcmu0_pre_em_2t          : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu0_pre_em_pt          : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu0_tx_term_sel        : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu0_tx_vtt             : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_tx_lst             : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu0_rslew              : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_sig_inv_ptap       : STD_LOGIC;
    SIGNAL rcmu0_sig_inv_2t         : STD_LOGIC;
    SIGNAL rcmu0_rx_det             : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_lowv               : STD_LOGIC;
    SIGNAL rcmu0_tx_dft_sel         : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu0_tx_ob_pdb          : STD_LOGIC;
    
    -- Central Clock Generation (refer to CGB section for description)
    -- Serializer (Refer to serializer section for description)
    SIGNAL rcmu0_cgb_x_en           : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_cgb_cmu_sel        : STD_LOGIC;
    SIGNAL rcmu0_cgb_m_sel          : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_pma_doublewidth_tx : STD_LOGIC;
    SIGNAL rcmu0_pmadwidth_tx       : STD_LOGIC;
    SIGNAL rcmu0_delay_sel          : STD_LOGIC;
    SIGNAL rcmu0_dynamic_sw         : STD_LOGIC;
    SIGNAL rcmu0_pclksel            : STD_LOGIC;
    SIGNAL rcmu0_tx_cgb_pdb         : STD_LOGIC;
    SIGNAL rcmu0_iqsel              : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_refsel             : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_vcobypass          : STD_LOGIC;
    SIGNAL rcmu0_revlb_sw           : STD_LOGIC;
    SIGNAL rcmu0_pcs_sd_sel         : STD_LOGIC;
    SIGNAL rcmu0_reserved           : STD_LOGIC_VECTOR(31 DOWNTO 0);		--divided into 2 sixteen bit busses
    
    -- CMU0 RX CRAMs
    -- CDR/TXPLL - refer to CDR section for description
    SIGNAL rcmu0_rx_lst             : STD_LOGIC_VECTOR(4 DOWNTO 0);
    SIGNAL rcmu0_rx_bit_dc          : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu0_s_rdlpbk           : STD_LOGIC;
    SIGNAL rcmu0_rx_vtt             : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu0_term               : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu0_rx_sdlv            : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu0_rx_oc_en           : STD_LOGIC;
    SIGNAL rcmu0_rx_oc              : STD_LOGIC_VECTOR(7 DOWNTO 0);
    SIGNAL rcmu0_sd_force           : STD_LOGIC;
    SIGNAL rcmu0_rx_test            : STD_LOGIC;
    SIGNAL rcmu0_rxurst             : STD_LOGIC;
    SIGNAL rcmu0_rx_sd_on           : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu0_rx_sd_off          : STD_LOGIC_VECTOR(4 DOWNTO 0);
    SIGNAL rcmu0_rx_oc_calpd        : STD_LOGIC;
    SIGNAL rcmu0_urx_pdb            : STD_LOGIC;
    SIGNAL rcmu0_rx_ib_pdb          : STD_LOGIC;
    SIGNAL rcmu0_powdnr             : STD_LOGIC;
    SIGNAL rcmu0_div2               : STD_LOGIC;
    SIGNAL rcmu0_m_sel              : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_m                  : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu0_l                  : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_ctl0               : STD_LOGIC;
    SIGNAL rcmu0_crplctrl           : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_pfdbwctrl          : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_pdbwctrl           : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_rlbk               : STD_LOGIC;
    SIGNAL rcmu0_lst                : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu0_testen             : STD_LOGIC;
    SIGNAL rcmu0_testupen           : STD_LOGIC;
    SIGNAL rcmu0_testdnen           : STD_LOGIC;
    SIGNAL rcmu0_isel               : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu0_iselpd             : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu0_rcp_mode           : STD_LOGIC;
    SIGNAL rcmu0_cru_pdb            : STD_LOGIC;
    SIGNAL rcmu0_rx_cmu_rst         : STD_LOGIC;
    SIGNAL rcmu0_cmu_mode           : STD_LOGIC;
    SIGNAL rcmu0_ignore_phslck      : STD_LOGIC;
    SIGNAL rcmu0_sd_sel             : STD_LOGIC;
    SIGNAL rcmu0_pdfl               : STD_LOGIC;
    SIGNAL rcmu0_pdof_test          : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu0_rgla_isel          : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu0_pdof_0i            : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu0_pdof_90i           : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu0_pdof_180i          : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu0_pdof_270i          : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu0_eye_monitor        : STD_LOGIC_VECTOR(7 DOWNTO 0);
    
    --wire [15:0] rcmu0_reserved[15:0];	declared above
    -- DeSerializer - refer to deserializer section for description
    SIGNAL rcmu0_pma_doublewidth_rx : STD_LOGIC;
    SIGNAL rcmu0_pmadwidth_rx       : STD_LOGIC;
    SIGNAL rcmu0_test_fastsd        : STD_LOGIC;
    SIGNAL rcmu0_fastsd             : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu0_ppmsel             : STD_LOGIC_VECTOR(5 DOWNTO 0);
    SIGNAL rcmu0_force0_freqdet     : STD_LOGIC;
    SIGNAL rcmu0_force1_freqdet     : STD_LOGIC;
    
    --DFE
    SIGNAL rcmu0_dfe_1t             : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu0_dfe_2t             : STD_LOGIC_VECTOR(2 DOWNTO 0);
    
    -- RX/D2A - Refer to RX and ADCE for description
    SIGNAL rcmu0_eqa_set            : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_eqb_set            : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_eqc_set            : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_eqd_set            : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_eqv_set            : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_d2a_res            : STD_LOGIC_VECTOR(5 DOWNTO 0);
    SIGNAL rcmu0_clk_div2           : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu0_ht_sel             : STD_LOGIC;
    SIGNAL rcmu0_fbclk_sel          : STD_LOGIC;
    SIGNAL rcmu0_clk_pdb            : STD_LOGIC;
    SIGNAL rcmu0_rx_det_pdb         : STD_LOGIC;
    SIGNAL rcmu0_iqclk_sel          : STD_LOGIC;
    SIGNAL rcmu0_detect_on          : STD_LOGIC;
    -- END CMU0 CRAMs
    
    -- CMU1 PMA CRAMs
    -- Clock Output Buffer - refer to PMA TX section for description
    SIGNAL rcmu1_vod_sel            : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu1_powdnt             : STD_LOGIC;
    SIGNAL rcmu1_pre_em_1t          : STD_LOGIC_VECTOR(4 DOWNTO 0);
    SIGNAL rcmu1_pre_em_2t          : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu1_pre_em_pt          : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu1_tx_term_sel        : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu1_tx_vtt             : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_tx_lst             : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu1_rslew              : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_sig_inv_ptap       : STD_LOGIC;
    SIGNAL rcmu1_sig_inv_2t         : STD_LOGIC;
    SIGNAL rcmu1_rx_det             : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_lowv               : STD_LOGIC;
    SIGNAL rcmu1_tx_dft_sel         : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu1_tx_ob_pdb          : STD_LOGIC;
    
    -- Central Clock Generation (refer to CGB section for description)
    -- Serializer (Refer to serializer section for description)
    SIGNAL rcmu1_cgb_x_en           : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_cgb_cmu_sel        : STD_LOGIC;
    SIGNAL rcmu1_cgb_m_sel          : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_pma_doublewidth_tx : STD_LOGIC;
    SIGNAL rcmu1_pmadwidth_tx       : STD_LOGIC;
    SIGNAL rcmu1_delay_sel          : STD_LOGIC;
    SIGNAL rcmu1_dynamic_sw         : STD_LOGIC;
    SIGNAL rcmu1_pclksel            : STD_LOGIC;
    SIGNAL rcmu1_tx_cgb_pdb         : STD_LOGIC;
    SIGNAL rcmu1_iqsel              : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_refsel             : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_vcobypass          : STD_LOGIC;
    SIGNAL rcmu1_revlb_sw           : STD_LOGIC;
    SIGNAL rcmu1_pcs_sd_sel         : STD_LOGIC;
    SIGNAL rcmu1_reserved           : STD_LOGIC_VECTOR(31 DOWNTO 0);		--divided into 2 sixteen bit busses
    
    -- cmu1 RX CRAMs
    -- CDR/TXPLL - refer to CDR section for description
    SIGNAL rcmu1_rx_lst             : STD_LOGIC_VECTOR(4 DOWNTO 0);
    SIGNAL rcmu1_rx_bit_dc          : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu1_s_rdlpbk           : STD_LOGIC;
    SIGNAL rcmu1_rx_vtt             : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu1_term               : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu1_rx_sdlv            : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu1_rx_oc_en           : STD_LOGIC;
    SIGNAL rcmu1_rx_oc              : STD_LOGIC_VECTOR(7 DOWNTO 0);
    SIGNAL rcmu1_sd_force           : STD_LOGIC;
    SIGNAL rcmu1_rx_test            : STD_LOGIC;
    SIGNAL rcmu1_rxurst             : STD_LOGIC;
    SIGNAL rcmu1_rx_sd_on           : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu1_rx_sd_off          : STD_LOGIC_VECTOR(4 DOWNTO 0);
    SIGNAL rcmu1_rx_oc_calpd        : STD_LOGIC;
    SIGNAL rcmu1_urx_pdb            : STD_LOGIC;
    SIGNAL rcmu1_rx_ib_pdb          : STD_LOGIC;
    SIGNAL rcmu1_powdnr             : STD_LOGIC;
    SIGNAL rcmu1_div2               : STD_LOGIC;
    SIGNAL rcmu1_m_sel              : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_m                  : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu1_l                  : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_ctl0               : STD_LOGIC;
    SIGNAL rcmu1_crplctrl           : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_pfdbwctrl          : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_pdbwctrl           : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_rlbk               : STD_LOGIC;
    SIGNAL rcmu1_lst                : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu1_testen             : STD_LOGIC;
    SIGNAL rcmu1_testupen           : STD_LOGIC;
    SIGNAL rcmu1_testdnen           : STD_LOGIC;
    SIGNAL rcmu1_isel               : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu1_iselpd             : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu1_rcp_mode           : STD_LOGIC;
    SIGNAL rcmu1_cru_pdb            : STD_LOGIC;
    SIGNAL rcmu1_rx_cmu_rst         : STD_LOGIC;
    SIGNAL rcmu1_cmu_mode           : STD_LOGIC;
    SIGNAL rcmu1_ignore_phslck      : STD_LOGIC;
    SIGNAL rcmu1_sd_sel             : STD_LOGIC;
    SIGNAL rcmu1_pdfl               : STD_LOGIC;
    SIGNAL rcmu1_pdof_test          : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu1_rgla_isel          : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu1_pdof_0i            : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu1_pdof_90i           : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu1_pdof_180i          : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu1_pdof_270i          : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu1_eye_monitor        : STD_LOGIC_VECTOR(7 DOWNTO 0);
    
    --wire [15:0] rcmu1_reserved[15:0];	//declared above
    -- DeSerializer - refer to deserializer section for description
    SIGNAL rcmu1_pma_doublewidth_rx : STD_LOGIC;
    SIGNAL rcmu1_pmadwidth_rx       : STD_LOGIC;
    SIGNAL rcmu1_test_fastsd        : STD_LOGIC;
    SIGNAL rcmu1_fastsd             : STD_LOGIC_VECTOR(3 DOWNTO 0);
    SIGNAL rcmu1_ppmsel             : STD_LOGIC_VECTOR(5 DOWNTO 0);
    SIGNAL rcmu1_force0_freqdet     : STD_LOGIC;
    SIGNAL rcmu1_force1_freqdet     : STD_LOGIC;
    
    --DFE
    SIGNAL rcmu1_dfe_1t             : STD_LOGIC_VECTOR(2 DOWNTO 0);
    SIGNAL rcmu1_dfe_2t             : STD_LOGIC_VECTOR(2 DOWNTO 0);
    
    -- RX/D2A - Refer to RX and ADCE for description
    SIGNAL rcmu1_eqa_set            : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_eqb_set            : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_eqc_set            : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_eqd_set            : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_eqv_set            : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_d2a_res            : STD_LOGIC_VECTOR(5 DOWNTO 0);
    SIGNAL rcmu1_clk_div2           : STD_LOGIC_VECTOR(1 DOWNTO 0);
    SIGNAL rcmu1_ht_sel             : STD_LOGIC;
    SIGNAL rcmu1_fbclk_sel          : STD_LOGIC;
    SIGNAL rcmu1_clk_pdb            : STD_LOGIC;
    SIGNAL rcmu1_rx_det_pdb         : STD_LOGIC;
    SIGNAL rcmu1_iqclk_sel          : STD_LOGIC;
    SIGNAL rcmu1_detect_on          : STD_LOGIC;
    -- END CMU1 CRAMs
    
    --////////////////////////////////////////////////////////////////////////
    -- end of CRAM output ---------------------------------------------------
    --////////////////////////////////////////////////////////////////////////
    
    SIGNAL targ_addr_ctrl_1         : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_2         : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_3         : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_4         : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_5         : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_6         : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_7         : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_8         : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_9         : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_10        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_11        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_12        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_13        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_14        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_15        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_16        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_17        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_18        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_19        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_20        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_21        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_22        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_23        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_24        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_25        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_26        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_27        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_28        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_29        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_30        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_31        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_32        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_33        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_34        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_35        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_36        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_37        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_38        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_39        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_40        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_41        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_42        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_43        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_44        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_45        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL targ_addr_ctrl_46        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    
    SIGNAL out_centrl_ctrl_1        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_2        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_3        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_4        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_5        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_6        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_7        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_8        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_9        : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_10       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_11       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_12       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_13       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_14       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_15       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_16       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_17       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_18       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_19       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_20       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_21       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_22       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_23       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_24       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_25       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_26       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_27       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_28       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_29       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_30       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_31       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_32       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_33       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_34       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_35       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_36       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_37       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_38       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_39       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_40       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_41       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_42       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_43       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_44       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_45       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    SIGNAL out_centrl_ctrl_46       : STD_LOGIC_VECTOR(15 DOWNTO 0);
    
    -- Declare intermediate signals for referenced outputs
    SIGNAL so_xhdl1                 : STD_LOGIC;
    SIGNAL mbus_out_xhdl0           : STD_LOGIC_VECTOR(15 DOWNTO 0);
BEGIN
    -- Drive referenced outputs
    so <= so_xhdl1;
    mbus_out <= mbus_out_xhdl0;
    
    --////////////////////////////////////////////////////////////////////////
    -- begin of CRAM output -------------------------------------------------
    --////////////////////////////////////////////////////////////////////////
    
    dp_centrl_out(15 DOWNTO 0) <= out_centrl_ctrl_1;
    dp_centrl_out(31 DOWNTO 16) <= out_centrl_ctrl_2;
    dp_centrl_out(47 DOWNTO 32) <= out_centrl_ctrl_3;
    dp_centrl_out(63 DOWNTO 48) <= out_centrl_ctrl_4;
    dp_centrl_out(79 DOWNTO 64) <= out_centrl_ctrl_5;
    dp_centrl_out(95 DOWNTO 80) <= out_centrl_ctrl_6;
    dp_centrl_out(111 DOWNTO 96) <= out_centrl_ctrl_7;
    dp_centrl_out(127 DOWNTO 112) <= out_centrl_ctrl_8;
    dp_centrl_out(143 DOWNTO 128) <= out_centrl_ctrl_9;
    dp_centrl_out(159 DOWNTO 144) <= out_centrl_ctrl_10;
    dp_centrl_out(175 DOWNTO 160) <= out_centrl_ctrl_11;
    dp_centrl_out(191 DOWNTO 176) <= out_centrl_ctrl_12;
    dp_centrl_out(207 DOWNTO 192) <= out_centrl_ctrl_13;
    dp_centrl_out(223 DOWNTO 208) <= out_centrl_ctrl_14;
    dp_centrl_out(239 DOWNTO 224) <= out_centrl_ctrl_15;
    dp_centrl_out_reserved(15 DOWNTO 0) <= out_centrl_ctrl_16;
    dp_centrl_out(255 DOWNTO 240) <= out_centrl_ctrl_17;
    dp_centrl_out(271 DOWNTO 256) <= out_centrl_ctrl_18;
    dp_centrl_out(287 DOWNTO 272) <= out_centrl_ctrl_19;
    dp_centrl_out(303 DOWNTO 288) <= out_centrl_ctrl_20;
    dp_centrl_out(319 DOWNTO 304) <= out_centrl_ctrl_21;
    dp_centrl_out(335 DOWNTO 320) <= out_centrl_ctrl_22;
    dp_centrl_out(351 DOWNTO 336) <= out_centrl_ctrl_23;
    dp_centrl_out(367 DOWNTO 352) <= out_centrl_ctrl_24;
    dp_centrl_out(383 DOWNTO 368) <= out_centrl_ctrl_25;
    dp_centrl_out(399 DOWNTO 384) <= out_centrl_ctrl_26;
    dp_centrl_out(415 DOWNTO 400) <= out_centrl_ctrl_27;
    dp_centrl_out(431 DOWNTO 416) <= out_centrl_ctrl_28;
    dp_centrl_out(447 DOWNTO 432) <= out_centrl_ctrl_29;
    dp_centrl_out(463 DOWNTO 448) <= out_centrl_ctrl_30;
    dp_centrl_out(479 DOWNTO 464) <= out_centrl_ctrl_31;
    dp_centrl_out(495 DOWNTO 480) <= out_centrl_ctrl_32;
    dp_centrl_out(511 DOWNTO 496) <= out_centrl_ctrl_33;
    dp_centrl_out(527 DOWNTO 512) <= out_centrl_ctrl_34;
    dp_centrl_out(543 DOWNTO 528) <= out_centrl_ctrl_35;
    dp_centrl_out(559 DOWNTO 544) <= out_centrl_ctrl_36;
    dp_centrl_out_reserved(31 DOWNTO 16) <= out_centrl_ctrl_37;
    dp_centrl_out(575 DOWNTO 560) <= out_centrl_ctrl_38;
    dp_centrl_out(591 DOWNTO 576) <= out_centrl_ctrl_39;
    dp_centrl_out(607 DOWNTO 592) <= out_centrl_ctrl_40;
    dp_centrl_out(623 DOWNTO 608) <= out_centrl_ctrl_41;
    dp_centrl_out(639 DOWNTO 624) <= out_centrl_ctrl_42;
    dp_centrl_out(655 DOWNTO 640) <= out_centrl_ctrl_43;
    dp_centrl_out(671 DOWNTO 656) <= out_centrl_ctrl_44;
    dp_centrl_out(687 DOWNTO 672) <= out_centrl_ctrl_45;
    dp_centrl_out(703 DOWNTO 688) <= out_centrl_ctrl_46;
    
    --////////////////////////////////////////////////////////////////////////
    -- end of CRAM output ---------------------------------------------------
    --////////////////////////////////////////////////////////////////////////
    
    -- Control register address assignment
    -- CMU0 PMA address space
    targ_addr_ctrl_1 <= "0100100000000000" + "0000000000000000";
    targ_addr_ctrl_2 <= "0100100000000000" + "0000000000000001";
    targ_addr_ctrl_3 <= "0100100000000000" + "0000000000000010";
    targ_addr_ctrl_4 <= "0100100000000000" + "0000000000000011";
    targ_addr_ctrl_5 <= "0100100000000000" + "0000000000000100";
    targ_addr_ctrl_6 <= "0100100000000000" + "0000000000000101";
    targ_addr_ctrl_7 <= "0100100000000000" + "0000000000000110";
    targ_addr_ctrl_8 <= "0100100000000000" + "0000000000000111";
    targ_addr_ctrl_9 <= "0100110000000000" + "0000000000000000";
    targ_addr_ctrl_10 <= "0100110000000000" + "0000000000000001";
    targ_addr_ctrl_11 <= "0100110000000000" + "0000000000000010";
    targ_addr_ctrl_12 <= "0100110000000000" + "0000000000000011";
    targ_addr_ctrl_13 <= "0100110000000000" + "0000000000000100";
    targ_addr_ctrl_14 <= "0100110000000000" + "0000000000000101";
    targ_addr_ctrl_15 <= "0100110000000000" + "0000000000000110";
    targ_addr_ctrl_16 <= "0100110000000000" + "0000000000000111";
    targ_addr_ctrl_17 <= "0100110000000000" + "0000000000001000";
    targ_addr_ctrl_18 <= "0100110000000000" + "0000000000001001";
    targ_addr_ctrl_19 <= "0100110000000000" + "0000000000001010";
    targ_addr_ctrl_20 <= "0100110000000000" + "0000000000001011";
    targ_addr_ctrl_21 <= "0100110000000000" + "0000000000001100";
    
    -- CMU1 PMA address space
    targ_addr_ctrl_22 <= "0101100000000000" + "0000000000000000";
    targ_addr_ctrl_23 <= "0101100000000000" + "0000000000000001";
    targ_addr_ctrl_24 <= "0101100000000000" + "0000000000000010";
    targ_addr_ctrl_25 <= "0101100000000000" + "0000000000000011";
    targ_addr_ctrl_26 <= "0101100000000000" + "0000000000000100";
    targ_addr_ctrl_27 <= "0101100000000000" + "0000000000000101";
    targ_addr_ctrl_28 <= "0101100000000000" + "0000000000000110";
    targ_addr_ctrl_29 <= "0101100000000000" + "0000000000000111";
    targ_addr_ctrl_30 <= "0101110000000000" + "0000000000000000";
    targ_addr_ctrl_31 <= "0101110000000000" + "0000000000000001";
    targ_addr_ctrl_32 <= "0101110000000000" + "0000000000000010";
    targ_addr_ctrl_33 <= "0101110000000000" + "0000000000000011";
    targ_addr_ctrl_34 <= "0101110000000000" + "0000000000000100";
    targ_addr_ctrl_35 <= "0101110000000000" + "0000000000000101";
    targ_addr_ctrl_36 <= "0101110000000000" + "0000000000000110";
    targ_addr_ctrl_37 <= "0101110000000000" + "0000000000000111";
    targ_addr_ctrl_38 <= "0101110000000000" + "0000000000001000";
    targ_addr_ctrl_39 <= "0101110000000000" + "0000000000001001";
    targ_addr_ctrl_40 <= "0101110000000000" + "0000000000001010";
    targ_addr_ctrl_41 <= "0101110000000000" + "0000000000001011";
    targ_addr_ctrl_42 <= "0101110000000000" + "0000000000001100";
    
    -- Central PCS address space
    targ_addr_ctrl_43 <= "0110000000000000" + "0000000000000000";
    targ_addr_ctrl_44 <= "0110000000000000" + "0000000000000001";
    targ_addr_ctrl_45 <= "0110000000000000" + "0000000000000010";
    targ_addr_ctrl_46 <= "0110000000000000" + "0000000000000011";
    
    -- CRAM output assignment
    -- CMU0 PMA CRAMs
    -- CMU0 control register 1
    rcmu0_vod_sel(2 DOWNTO 0) <= out_centrl_ctrl_1(15 DOWNTO 13);
    rcmu0_powdnt <= out_centrl_ctrl_1(0);
    -- CMU0 control register 2
    rcmu0_pre_em_1t(4 DOWNTO 0) <= out_centrl_ctrl_2(15 DOWNTO 11);
    -- CMU0 control register 3
    rcmu0_pre_em_2t(3 DOWNTO 0) <= out_centrl_ctrl_3(7 DOWNTO 4);
    rcmu0_pre_em_pt(3 DOWNTO 0) <= out_centrl_ctrl_3(3 DOWNTO 0);
    -- CMU0 control register 4
    rcmu0_tx_term_sel(2 DOWNTO 0) <= out_centrl_ctrl_4(15 DOWNTO 13);
    rcmu0_tx_vtt(1 DOWNTO 0) <= out_centrl_ctrl_4(12 DOWNTO 11);
    rcmu0_tx_lst(3 DOWNTO 0) <= out_centrl_ctrl_4(10 DOWNTO 7);
    rcmu0_rslew(1 DOWNTO 0) <= out_centrl_ctrl_4(6 DOWNTO 5);
    rcmu0_sig_inv_ptap <= out_centrl_ctrl_4(4);
    rcmu0_sig_inv_2t <= out_centrl_ctrl_4(3);
    rcmu0_rx_det(1 DOWNTO 0) <= out_centrl_ctrl_4(2 DOWNTO 1);
    rcmu0_lowv <= out_centrl_ctrl_4(0);
    -- CMU0 control register 5
    rcmu0_tx_dft_sel(2 DOWNTO 0) <= out_centrl_ctrl_5(15 DOWNTO 13);
    rcmu0_tx_ob_pdb <= out_centrl_ctrl_5(11);
    -- CMU0 control register 6
    rcmu0_cgb_x_en(1 DOWNTO 0) <= out_centrl_ctrl_6(15 DOWNTO 14);
    rcmu0_cgb_cmu_sel <= out_centrl_ctrl_6(13);
    rcmu0_cgb_m_sel(1 DOWNTO 0) <= out_centrl_ctrl_6(12 DOWNTO 11);
    rcmu0_pma_doublewidth_tx <= out_centrl_ctrl_6(10);
    rcmu0_pmadwidth_tx <= out_centrl_ctrl_6(9);
    rcmu0_delay_sel <= out_centrl_ctrl_6(8);
    rcmu0_dynamic_sw <= out_centrl_ctrl_6(6);
    rcmu0_pclksel <= out_centrl_ctrl_6(5);
    rcmu0_tx_cgb_pdb <= out_centrl_ctrl_6(4);
    -- CMU0 control register 7
    rcmu0_iqsel(1 DOWNTO 0) <= out_centrl_ctrl_7(15 DOWNTO 14);
    rcmu0_refsel(1 DOWNTO 0) <= out_centrl_ctrl_7(13 DOWNTO 12);
    rcmu0_vcobypass <= out_centrl_ctrl_7(11);
    rcmu0_revlb_sw <= out_centrl_ctrl_7(10);
    rcmu0_pcs_sd_sel <= out_centrl_ctrl_7(3);
    -- CMU0 control register 8
    rcmu0_reserved(31 DOWNTO 16) <= out_centrl_ctrl_8(15 DOWNTO 0);
    -- CMU0 RX CRAMs
    -- CMU0 control register 9
    rcmu0_rx_lst(4 DOWNTO 0) <= out_centrl_ctrl_9(15 DOWNTO 11);
    rcmu0_rx_bit_dc(3 DOWNTO 0) <= out_centrl_ctrl_9(10 DOWNTO 7);
    rcmu0_s_rdlpbk <= out_centrl_ctrl_9(6);
    rcmu0_rx_vtt(2 DOWNTO 0) <= out_centrl_ctrl_9(5 DOWNTO 3);
    rcmu0_term(2 DOWNTO 0) <= out_centrl_ctrl_9(2 DOWNTO 0);
    -- CMU0 control register 10
    rcmu0_rx_sdlv(3 DOWNTO 0) <= out_centrl_ctrl_10(15 DOWNTO 12);
    rcmu0_rx_oc_en <= out_centrl_ctrl_10(11);
    rcmu0_rx_oc(7 DOWNTO 0) <= out_centrl_ctrl_10(10 DOWNTO 3);
    rcmu0_sd_force <= out_centrl_ctrl_10(2);
    rcmu0_rx_test <= out_centrl_ctrl_10(1);
    rcmu0_rxurst <= out_centrl_ctrl_10(0);
    -- CMU0 control register 11
    rcmu0_rx_sd_on(3 DOWNTO 0) <= out_centrl_ctrl_11(15 DOWNTO 12);
    rcmu0_rx_sd_off(4 DOWNTO 0) <= out_centrl_ctrl_11(11 DOWNTO 7);
    rcmu0_rx_oc_calpd <= out_centrl_ctrl_11(6);
    rcmu0_urx_pdb <= out_centrl_ctrl_11(5);
    rcmu0_rx_ib_pdb <= out_centrl_ctrl_11(4);
    rcmu0_powdnr <= out_centrl_ctrl_11(3);
    -- CMU0 control register 12
    rcmu0_div2 <= out_centrl_ctrl_12(15);
    rcmu0_m_sel(1 DOWNTO 0) <= out_centrl_ctrl_12(14 DOWNTO 13);
    rcmu0_m(3 DOWNTO 0) <= out_centrl_ctrl_12(12 DOWNTO 9);
    rcmu0_l(1 DOWNTO 0) <= out_centrl_ctrl_12(8 DOWNTO 7);
    rcmu0_ctl0 <= out_centrl_ctrl_12(6);
    rcmu0_crplctrl(1 DOWNTO 0) <= out_centrl_ctrl_12(5 DOWNTO 4);
    rcmu0_pfdbwctrl(1 DOWNTO 0) <= out_centrl_ctrl_12(3 DOWNTO 2);
    rcmu0_pdbwctrl(1 DOWNTO 0) <= out_centrl_ctrl_12(1 DOWNTO 0);
    -- CMU0 control register 13
    rcmu0_rlbk <= out_centrl_ctrl_13(15);
    rcmu0_lst(3 DOWNTO 0) <= out_centrl_ctrl_13(14 DOWNTO 11);
    rcmu0_testen <= out_centrl_ctrl_13(10);
    rcmu0_testupen <= out_centrl_ctrl_13(9);
    rcmu0_testdnen <= out_centrl_ctrl_13(8);
    rcmu0_isel(2 DOWNTO 0) <= out_centrl_ctrl_13(7 DOWNTO 5);
    rcmu0_iselpd(2 DOWNTO 0) <= out_centrl_ctrl_13(4 DOWNTO 2);
    -- CMU0 control register 14
    rcmu0_rcp_mode <= out_centrl_ctrl_14(15);
    rcmu0_cru_pdb <= out_centrl_ctrl_14(12);
    rcmu0_rx_cmu_rst <= out_centrl_ctrl_14(11);
    rcmu0_cmu_mode <= out_centrl_ctrl_14(10);
    rcmu0_ignore_phslck <= out_centrl_ctrl_14(9);
    rcmu0_sd_sel <= out_centrl_ctrl_14(7);
    rcmu0_pdfl <= out_centrl_ctrl_14(6);
    rcmu0_pdof_test(2 DOWNTO 0) <= out_centrl_ctrl_14(5 DOWNTO 3);
    rcmu0_rgla_isel(2 DOWNTO 0) <= out_centrl_ctrl_14(2 DOWNTO 0);
    -- CMU0 control register 15
    rcmu0_pdof_0i(3 DOWNTO 0) <= out_centrl_ctrl_15(15 DOWNTO 12);
    rcmu0_pdof_90i(3 DOWNTO 0) <= out_centrl_ctrl_15(11 DOWNTO 8);
    rcmu0_pdof_180i(3 DOWNTO 0) <= out_centrl_ctrl_15(7 DOWNTO 4);
    rcmu0_pdof_270i(3 DOWNTO 0) <= out_centrl_ctrl_15(3 DOWNTO 0);
    -- CMU0 control register 16
    rcmu0_eye_monitor(7 DOWNTO 0) <= out_centrl_ctrl_16(7 DOWNTO 0);
    -- CMU0 control register 17
    rcmu0_reserved(15 DOWNTO 0) <= out_centrl_ctrl_17(15 DOWNTO 0);
    -- CMU0 control register 18
    rcmu0_pma_doublewidth_rx <= out_centrl_ctrl_18(15);
    rcmu0_pmadwidth_rx <= out_centrl_ctrl_18(14);
    rcmu0_test_fastsd <= out_centrl_ctrl_18(13);
    rcmu0_fastsd(3 DOWNTO 0) <= out_centrl_ctrl_18(12 DOWNTO 9);
    rcmu0_ppmsel(5 DOWNTO 0) <= out_centrl_ctrl_18(8 DOWNTO 3);
    rcmu0_force0_freqdet <= out_centrl_ctrl_18(2);
    rcmu0_force1_freqdet <= out_centrl_ctrl_18(1);
    -- CMU0 control register 19
    rcmu0_dfe_1t(2 DOWNTO 0) <= out_centrl_ctrl_19(15 DOWNTO 13);
    rcmu0_dfe_2t(2 DOWNTO 0) <= out_centrl_ctrl_19(12 DOWNTO 10);
    -- CMU0 control register 20
    rcmu0_eqa_set(1 DOWNTO 0) <= out_centrl_ctrl_20(13 DOWNTO 12);
    rcmu0_eqb_set(1 DOWNTO 0) <= out_centrl_ctrl_20(10 DOWNTO 9);
    rcmu0_eqc_set(1 DOWNTO 0) <= out_centrl_ctrl_20(7 DOWNTO 6);
    rcmu0_eqd_set(1 DOWNTO 0) <= out_centrl_ctrl_20(4 DOWNTO 3);
    rcmu0_eqv_set(1 DOWNTO 0) <= out_centrl_ctrl_20(1 DOWNTO 0);
    -- CMU0 control register 21
    rcmu0_d2a_res(5 DOWNTO 0) <= out_centrl_ctrl_21(15 DOWNTO 10);
    rcmu0_clk_div2(1 DOWNTO 0) <= out_centrl_ctrl_21(9 DOWNTO 8);
    rcmu0_ht_sel <= out_centrl_ctrl_21(7);
    rcmu0_fbclk_sel <= out_centrl_ctrl_21(6);
    rcmu0_clk_pdb <= out_centrl_ctrl_21(5);
    rcmu0_rx_det_pdb <= out_centrl_ctrl_21(4);
    rcmu0_iqclk_sel <= out_centrl_ctrl_21(2);
    rcmu0_detect_on <= out_centrl_ctrl_21(1);
    -- END CMU0 CRAMs
    
    -- CMU1 PMA CRAMs
    -- CMU1 control register 1
    rcmu1_vod_sel(2 DOWNTO 0) <= out_centrl_ctrl_22(15 DOWNTO 13);
    rcmu1_powdnt <= out_centrl_ctrl_22(0);
    -- CMU1 control register 2
    rcmu1_pre_em_1t(4 DOWNTO 0) <= out_centrl_ctrl_23(15 DOWNTO 11);
    -- CMU1 control register 3
    rcmu1_pre_em_2t(3 DOWNTO 0) <= out_centrl_ctrl_24(7 DOWNTO 4);
    rcmu1_pre_em_pt(3 DOWNTO 0) <= out_centrl_ctrl_24(3 DOWNTO 0);
    -- CMU1 control register 4
    rcmu1_tx_term_sel(2 DOWNTO 0) <= out_centrl_ctrl_25(15 DOWNTO 13);
    rcmu1_tx_vtt(1 DOWNTO 0) <= out_centrl_ctrl_25(12 DOWNTO 11);
    rcmu1_tx_lst(3 DOWNTO 0) <= out_centrl_ctrl_25(10 DOWNTO 7);
    rcmu1_rslew(1 DOWNTO 0) <= out_centrl_ctrl_25(6 DOWNTO 5);
    rcmu1_sig_inv_ptap <= out_centrl_ctrl_25(4);
    rcmu1_sig_inv_2t <= out_centrl_ctrl_25(3);
    rcmu1_rx_det(1 DOWNTO 0) <= out_centrl_ctrl_25(2 DOWNTO 1);
    rcmu1_lowv <= out_centrl_ctrl_25(0);
    -- CMU1 control register 5
    rcmu1_tx_dft_sel(2 DOWNTO 0) <= out_centrl_ctrl_26(15 DOWNTO 13);
    rcmu1_tx_ob_pdb <= out_centrl_ctrl_26(11);
    -- CMU1 control register 6
    rcmu1_cgb_x_en(1 DOWNTO 0) <= out_centrl_ctrl_27(15 DOWNTO 14);
    rcmu1_cgb_cmu_sel <= out_centrl_ctrl_27(13);
    rcmu1_cgb_m_sel(1 DOWNTO 0) <= out_centrl_ctrl_27(12 DOWNTO 11);
    rcmu1_pma_doublewidth_tx <= out_centrl_ctrl_27(10);
    rcmu1_pmadwidth_tx <= out_centrl_ctrl_27(9);
    rcmu1_delay_sel <= out_centrl_ctrl_27(8);
    rcmu1_dynamic_sw <= out_centrl_ctrl_27(6);
    rcmu1_pclksel <= out_centrl_ctrl_27(5);
    rcmu1_tx_cgb_pdb <= out_centrl_ctrl_27(4);
    -- CMU1 control register 7
    rcmu1_iqsel <= out_centrl_ctrl_28(15 DOWNTO 14);
    rcmu1_refsel(1 DOWNTO 0) <= out_centrl_ctrl_28(13 DOWNTO 12);
    rcmu1_vcobypass <= out_centrl_ctrl_28(11);
    rcmu1_revlb_sw <= out_centrl_ctrl_28(10);
    rcmu1_pcs_sd_sel <= out_centrl_ctrl_28(3);
    -- CMU1 control register 8
    rcmu1_reserved(31 DOWNTO 16) <= out_centrl_ctrl_29(15 DOWNTO 0);
    -- CMU1 RX CRAMs
    -- CMU1 control register 9
    rcmu1_rx_lst(4 DOWNTO 0) <= out_centrl_ctrl_30(15 DOWNTO 11);
    rcmu1_rx_bit_dc(3 DOWNTO 0) <= out_centrl_ctrl_30(10 DOWNTO 7);
    rcmu1_s_rdlpbk <= out_centrl_ctrl_30(6);
    rcmu1_rx_vtt(2 DOWNTO 0) <= out_centrl_ctrl_30(5 DOWNTO 3);
    rcmu1_term(2 DOWNTO 0) <= out_centrl_ctrl_30(2 DOWNTO 0);
    -- CMU1 control register 10
    rcmu1_rx_sdlv(3 DOWNTO 0) <= out_centrl_ctrl_31(15 DOWNTO 12);
    rcmu1_rx_oc_en <= out_centrl_ctrl_31(11);
    rcmu1_rx_oc(7 DOWNTO 0) <= out_centrl_ctrl_31(10 DOWNTO 3);
    rcmu1_sd_force <= out_centrl_ctrl_31(2);
    rcmu1_rx_test <= out_centrl_ctrl_31(1);
    rcmu1_rxurst <= out_centrl_ctrl_31(0);
    -- CMU1 control register 11
    rcmu1_rx_sd_on(3 DOWNTO 0) <= out_centrl_ctrl_32(15 DOWNTO 12);
    rcmu1_rx_sd_off(4 DOWNTO 0) <= out_centrl_ctrl_32(11 DOWNTO 7);
    rcmu1_rx_oc_calpd <= out_centrl_ctrl_32(6);
    rcmu1_urx_pdb <= out_centrl_ctrl_32(5);
    rcmu1_rx_ib_pdb <= out_centrl_ctrl_32(4);
    rcmu1_powdnr <= out_centrl_ctrl_32(3);
    -- CMU1 control register 12
    rcmu1_div2 <= out_centrl_ctrl_33(15);
    rcmu1_m_sel(1 DOWNTO 0) <= out_centrl_ctrl_33(14 DOWNTO 13);
    rcmu1_m(3 DOWNTO 0) <= out_centrl_ctrl_33(12 DOWNTO 9);
    rcmu1_l(1 DOWNTO 0) <= out_centrl_ctrl_33(8 DOWNTO 7);
    rcmu1_ctl0 <= out_centrl_ctrl_33(6);
    rcmu1_crplctrl(1 DOWNTO 0) <= out_centrl_ctrl_33(5 DOWNTO 4);
    rcmu1_pfdbwctrl(1 DOWNTO 0) <= out_centrl_ctrl_33(3 DOWNTO 2);
    rcmu1_pdbwctrl(1 DOWNTO 0) <= out_centrl_ctrl_33(1 DOWNTO 0);
    -- CMU1 control register 13
    rcmu1_rlbk <= out_centrl_ctrl_34(15);
    rcmu1_lst(3 DOWNTO 0) <= out_centrl_ctrl_34(14 DOWNTO 11);
    rcmu1_testen <= out_centrl_ctrl_34(10);
    rcmu1_testupen <= out_centrl_ctrl_34(9);
    rcmu1_testdnen <= out_centrl_ctrl_34(8);
    rcmu1_isel(2 DOWNTO 0) <= out_centrl_ctrl_34(7 DOWNTO 5);
    rcmu1_iselpd(2 DOWNTO 0) <= out_centrl_ctrl_34(4 DOWNTO 2);
    -- CMU1 control register 14
    rcmu1_rcp_mode <= out_centrl_ctrl_35(15);
    rcmu1_cru_pdb <= out_centrl_ctrl_35(12);
    rcmu1_rx_cmu_rst <= out_centrl_ctrl_35(11);
    rcmu1_cmu_mode <= out_centrl_ctrl_35(10);
    rcmu1_ignore_phslck <= out_centrl_ctrl_35(9);
    rcmu1_sd_sel <= out_centrl_ctrl_35(7);
    rcmu1_pdfl <= out_centrl_ctrl_35(6);
    rcmu1_pdof_test(2 DOWNTO 0) <= out_centrl_ctrl_35(5 DOWNTO 3);
    rcmu1_rgla_isel(2 DOWNTO 0) <= out_centrl_ctrl_35(2 DOWNTO 0);
    -- CMU1 control register 15
    rcmu1_pdof_0i(3 DOWNTO 0) <= out_centrl_ctrl_36(15 DOWNTO 12);
    rcmu1_pdof_90i(3 DOWNTO 0) <= out_centrl_ctrl_36(11 DOWNTO 8);
    rcmu1_pdof_180i(3 DOWNTO 0) <= out_centrl_ctrl_36(7 DOWNTO 4);
    rcmu1_pdof_270i(3 DOWNTO 0) <= out_centrl_ctrl_36(3 DOWNTO 0);
    -- CMU1 control register 16
    rcmu1_eye_monitor(7 DOWNTO 0) <= out_centrl_ctrl_37(7 DOWNTO 0);
    -- CMU1 control register 17
    rcmu1_reserved(15 DOWNTO 0) <= out_centrl_ctrl_38(15 DOWNTO 0);
    -- CMU1 control register 18
    rcmu1_pma_doublewidth_rx <= out_centrl_ctrl_39(15);
    rcmu1_pmadwidth_rx <= out_centrl_ctrl_39(14);
    rcmu1_test_fastsd <= out_centrl_ctrl_39(13);
    rcmu1_fastsd(3 DOWNTO 0) <= out_centrl_ctrl_39(12 DOWNTO 9);
    rcmu1_ppmsel(5 DOWNTO 0) <= out_centrl_ctrl_39(8 DOWNTO 3);
    rcmu1_force0_freqdet <= out_centrl_ctrl_39(2);
    rcmu1_force1_freqdet <= out_centrl_ctrl_39(1);
    -- CMU1 control register 19
    rcmu1_dfe_1t(2 DOWNTO 0) <= out_centrl_ctrl_40(15 DOWNTO 13);
    rcmu1_dfe_2t(2 DOWNTO 0) <= out_centrl_ctrl_40(12 DOWNTO 10);
    -- CMU1 control register 20
    rcmu1_eqa_set(1 DOWNTO 0) <= out_centrl_ctrl_41(13 DOWNTO 12);
    rcmu1_eqb_set(1 DOWNTO 0) <= out_centrl_ctrl_41(10 DOWNTO 9);
    rcmu1_eqc_set(1 DOWNTO 0) <= out_centrl_ctrl_41(7 DOWNTO 6);
    rcmu1_eqd_set(1 DOWNTO 0) <= out_centrl_ctrl_41(4 DOWNTO 3);
    rcmu1_eqv_set(1 DOWNTO 0) <= out_centrl_ctrl_41(1 DOWNTO 0);
    -- CMU1 control register 21
    rcmu1_d2a_res(5 DOWNTO 0) <= out_centrl_ctrl_42(15 DOWNTO 10);
    rcmu1_clk_div2(1 DOWNTO 0) <= out_centrl_ctrl_42(9 DOWNTO 8);
    rcmu1_ht_sel <= out_centrl_ctrl_42(7);
    rcmu1_fbclk_sel <= out_centrl_ctrl_42(6);
    rcmu1_clk_pdb <= out_centrl_ctrl_42(5);
    rcmu1_rx_det_pdb <= out_centrl_ctrl_42(4);
    rcmu1_iqclk_sel <= out_centrl_ctrl_42(2);
    rcmu1_detect_on <= out_centrl_ctrl_42(1);
    -- END CMU1 CRAMs
    
    -- Central PCS CRAMs
    -- PCS central channel control register: DTE XS register
    rs_lpbk_all <= out_centrl_ctrl_43(14);
    rpowerdown <= out_centrl_ctrl_43(11);
    -- PCS central channel control register 1
    rtest_bus_centrl_sel(3) <= out_centrl_ctrl_44(15);
    rx16_x12_sel_tx <= out_centrl_ctrl_44(14);
    rx16_x12_sel_rx <= out_centrl_ctrl_44(13);
    rtest_bus_centrl_sel(2 DOWNTO 0) <= out_centrl_ctrl_44(12 DOWNTO 10);
    rphfifo_master_sel_tx <= out_centrl_ctrl_44(9);
    rphfifo_master_sel_rx <= out_centrl_ctrl_44(8);
    rendec_data_sel_tx <= out_centrl_ctrl_44(7);
    rendec_data_sel_rx <= out_centrl_ctrl_44(6);
    rnenbpin <= out_centrl_ctrl_44(5);
    rpllurst <= out_centrl_ctrl_44(4);
    rreset <= out_centrl_ctrl_44(3);
    rdeskewen <= out_centrl_ctrl_44(2);
    rindv_tx <= out_centrl_ctrl_44(1);
    rindv_rx <= out_centrl_ctrl_44(0);
    -- PCS central channel control register 2
    rfreerun_centrl <= out_centrl_ctrl_45(15);
    rcentrl_clk_sel <= out_centrl_ctrl_45(14);
    rrefclk_out_div2 <= out_centrl_ctrl_45(13);
    rxaui_s2gx_en_rx <= out_centrl_ctrl_45(12);
    ralgnopt <= out_centrl_ctrl_45(11);
    rdskposdisp <= out_centrl_ctrl_45(10);
    rdskchrp <= out_centrl_ctrl_45(9 DOWNTO 0);
    -- PCS central channel control register 3
    rxaui_s2gx_en_tx <= out_centrl_ctrl_46(15);
    rpcs_centrl_rsvd_cram <= out_centrl_ctrl_46(14 DOWNTO 4);
    rmaster_rx <= out_centrl_ctrl_46(3);
    rmaster_up_rx <= out_centrl_ctrl_46(2);
    rmaster_tx <= out_centrl_ctrl_46(1);
    rmaster_up_tx <= out_centrl_ctrl_46(0);
    
    -- DPRIO registers
    
    
    reg_centrl_inst : stratixiv_hssi_cmu_dprio_reg_centrl
        PORT MAP (
            mdio_rst            => mdio_rst,
            mdio_wr             => mdio_wr,
            reg_addr            => reg_addr,
            mdc                 => mdc,
            mbus_in             => mbus_in,
            serial_mode         => serial_mode,
            mdio_dis            => mdio_dis,
            pma_cram_test       => pma_cram_test,
            ser_shift_load      => ser_shift_load,
            si                  => si,
            -- CSR input
            ext_centrl_ctrl_1   => csr_centrl_in(15 DOWNTO 0),
            ext_centrl_ctrl_2   => csr_centrl_in(31 DOWNTO 16),
            ext_centrl_ctrl_3   => csr_centrl_in(47 DOWNTO 32),
            ext_centrl_ctrl_4   => csr_centrl_in(63 DOWNTO 48),
            ext_centrl_ctrl_5   => csr_centrl_in(79 DOWNTO 64),
            ext_centrl_ctrl_6   => csr_centrl_in(95 DOWNTO 80),
            ext_centrl_ctrl_7   => csr_centrl_in(111 DOWNTO 96),
            ext_centrl_ctrl_8   => csr_centrl_in(127 DOWNTO 112),
            ext_centrl_ctrl_9   => csr_centrl_in(143 DOWNTO 128),
            ext_centrl_ctrl_10  => csr_centrl_in(159 DOWNTO 144),
            ext_centrl_ctrl_11  => csr_centrl_in(175 DOWNTO 160),
            ext_centrl_ctrl_12  => csr_centrl_in(191 DOWNTO 176),
            ext_centrl_ctrl_13  => csr_centrl_in(207 DOWNTO 192),
            ext_centrl_ctrl_14  => csr_centrl_in(223 DOWNTO 208),
            ext_centrl_ctrl_15  => csr_centrl_in(239 DOWNTO 224),
            ext_centrl_ctrl_16  => csr_centrl_in_reserved(15 DOWNTO 0),
            ext_centrl_ctrl_17  => csr_centrl_in(255 DOWNTO 240),
            ext_centrl_ctrl_18  => csr_centrl_in(271 DOWNTO 256),
            ext_centrl_ctrl_19  => csr_centrl_in(287 DOWNTO 272),
            ext_centrl_ctrl_20  => csr_centrl_in(303 DOWNTO 288),
            ext_centrl_ctrl_21  => csr_centrl_in(319 DOWNTO 304),
            ext_centrl_ctrl_22  => csr_centrl_in(335 DOWNTO 320),
            ext_centrl_ctrl_23  => csr_centrl_in(351 DOWNTO 336),
            ext_centrl_ctrl_24  => csr_centrl_in(367 DOWNTO 352),
            ext_centrl_ctrl_25  => csr_centrl_in(383 DOWNTO 368),
            ext_centrl_ctrl_26  => csr_centrl_in(399 DOWNTO 384),
            ext_centrl_ctrl_27  => csr_centrl_in(415 DOWNTO 400),
            ext_centrl_ctrl_28  => csr_centrl_in(431 DOWNTO 416),
            ext_centrl_ctrl_29  => csr_centrl_in(447 DOWNTO 432),
            ext_centrl_ctrl_30  => csr_centrl_in(463 DOWNTO 448),
            ext_centrl_ctrl_31  => csr_centrl_in(479 DOWNTO 464),
            ext_centrl_ctrl_32  => csr_centrl_in(495 DOWNTO 480),
            ext_centrl_ctrl_33  => csr_centrl_in(511 DOWNTO 496),
            ext_centrl_ctrl_34  => csr_centrl_in(527 DOWNTO 512),
            ext_centrl_ctrl_35  => csr_centrl_in(543 DOWNTO 528),
            ext_centrl_ctrl_36  => csr_centrl_in(559 DOWNTO 544),
            ext_centrl_ctrl_37  => csr_centrl_in_reserved(31 DOWNTO 16),
            ext_centrl_ctrl_38  => csr_centrl_in(575 DOWNTO 560),
            ext_centrl_ctrl_39  => csr_centrl_in(591 DOWNTO 576),
            ext_centrl_ctrl_40  => csr_centrl_in(607 DOWNTO 592),
            ext_centrl_ctrl_41  => csr_centrl_in(623 DOWNTO 608),
            ext_centrl_ctrl_42  => csr_centrl_in(639 DOWNTO 624),
            ext_centrl_ctrl_43  => csr_centrl_in(655 DOWNTO 640),
            ext_centrl_ctrl_44  => csr_centrl_in(671 DOWNTO 656),
            ext_centrl_ctrl_45  => csr_centrl_in(687 DOWNTO 672),
            ext_centrl_ctrl_46  => csr_centrl_in(703 DOWNTO 688),
            targ_addr_ctrl_1    => targ_addr_ctrl_1,
            targ_addr_ctrl_2    => targ_addr_ctrl_2,
            targ_addr_ctrl_3    => targ_addr_ctrl_3,
            targ_addr_ctrl_4    => targ_addr_ctrl_4,
            targ_addr_ctrl_5    => targ_addr_ctrl_5,
            targ_addr_ctrl_6    => targ_addr_ctrl_6,
            targ_addr_ctrl_7    => targ_addr_ctrl_7,
            targ_addr_ctrl_8    => targ_addr_ctrl_8,
            targ_addr_ctrl_9    => targ_addr_ctrl_9,
            targ_addr_ctrl_10   => targ_addr_ctrl_10,
            targ_addr_ctrl_11   => targ_addr_ctrl_11,
            targ_addr_ctrl_12   => targ_addr_ctrl_12,
            targ_addr_ctrl_13   => targ_addr_ctrl_13,
            targ_addr_ctrl_14   => targ_addr_ctrl_14,
            targ_addr_ctrl_15   => targ_addr_ctrl_15,
            targ_addr_ctrl_16   => targ_addr_ctrl_16,
            targ_addr_ctrl_17   => targ_addr_ctrl_17,
            targ_addr_ctrl_18   => targ_addr_ctrl_18,
            targ_addr_ctrl_19   => targ_addr_ctrl_19,
            targ_addr_ctrl_20   => targ_addr_ctrl_20,
            targ_addr_ctrl_21   => targ_addr_ctrl_21,
            targ_addr_ctrl_22   => targ_addr_ctrl_22,
            targ_addr_ctrl_23   => targ_addr_ctrl_23,
            targ_addr_ctrl_24   => targ_addr_ctrl_24,
            targ_addr_ctrl_25   => targ_addr_ctrl_25,
            targ_addr_ctrl_26   => targ_addr_ctrl_26,
            targ_addr_ctrl_27   => targ_addr_ctrl_27,
            targ_addr_ctrl_28   => targ_addr_ctrl_28,
            targ_addr_ctrl_29   => targ_addr_ctrl_29,
            targ_addr_ctrl_30   => targ_addr_ctrl_30,
            targ_addr_ctrl_31   => targ_addr_ctrl_31,
            targ_addr_ctrl_32   => targ_addr_ctrl_32,
            targ_addr_ctrl_33   => targ_addr_ctrl_33,
            targ_addr_ctrl_34   => targ_addr_ctrl_34,
            targ_addr_ctrl_35   => targ_addr_ctrl_35,
            targ_addr_ctrl_36   => targ_addr_ctrl_36,
            targ_addr_ctrl_37   => targ_addr_ctrl_37,
            targ_addr_ctrl_38   => targ_addr_ctrl_38,
            targ_addr_ctrl_39   => targ_addr_ctrl_39,
            targ_addr_ctrl_40   => targ_addr_ctrl_40,
            targ_addr_ctrl_41   => targ_addr_ctrl_41,
            targ_addr_ctrl_42   => targ_addr_ctrl_42,
            targ_addr_ctrl_43   => targ_addr_ctrl_43,
            targ_addr_ctrl_44   => targ_addr_ctrl_44,
            targ_addr_ctrl_45   => targ_addr_ctrl_45,
            targ_addr_ctrl_46   => targ_addr_ctrl_46,
            -- DPRIO register output
            out_centrl_ctrl_1   => out_centrl_ctrl_1,
            out_centrl_ctrl_2   => out_centrl_ctrl_2,
            out_centrl_ctrl_3   => out_centrl_ctrl_3,
            out_centrl_ctrl_4   => out_centrl_ctrl_4,
            out_centrl_ctrl_5   => out_centrl_ctrl_5,
            out_centrl_ctrl_6   => out_centrl_ctrl_6,
            out_centrl_ctrl_7   => out_centrl_ctrl_7,
            out_centrl_ctrl_8   => out_centrl_ctrl_8,
            out_centrl_ctrl_9   => out_centrl_ctrl_9,
            out_centrl_ctrl_10  => out_centrl_ctrl_10,
            out_centrl_ctrl_11  => out_centrl_ctrl_11,
            out_centrl_ctrl_12  => out_centrl_ctrl_12,
            out_centrl_ctrl_13  => out_centrl_ctrl_13,
            out_centrl_ctrl_14  => out_centrl_ctrl_14,
            out_centrl_ctrl_15  => out_centrl_ctrl_15,
            out_centrl_ctrl_16  => out_centrl_ctrl_16,
            out_centrl_ctrl_17  => out_centrl_ctrl_17,
            out_centrl_ctrl_18  => out_centrl_ctrl_18,
            out_centrl_ctrl_19  => out_centrl_ctrl_19,
            out_centrl_ctrl_20  => out_centrl_ctrl_20,
            out_centrl_ctrl_21  => out_centrl_ctrl_21,
            out_centrl_ctrl_22  => out_centrl_ctrl_22,
            out_centrl_ctrl_23  => out_centrl_ctrl_23,
            out_centrl_ctrl_24  => out_centrl_ctrl_24,
            out_centrl_ctrl_25  => out_centrl_ctrl_25,
            out_centrl_ctrl_26  => out_centrl_ctrl_26,
            out_centrl_ctrl_27  => out_centrl_ctrl_27,
            out_centrl_ctrl_28  => out_centrl_ctrl_28,
            out_centrl_ctrl_29  => out_centrl_ctrl_29,
            out_centrl_ctrl_30  => out_centrl_ctrl_30,
            out_centrl_ctrl_31  => out_centrl_ctrl_31,
            out_centrl_ctrl_32  => out_centrl_ctrl_32,
            out_centrl_ctrl_33  => out_centrl_ctrl_33,
            out_centrl_ctrl_34  => out_centrl_ctrl_34,
            out_centrl_ctrl_35  => out_centrl_ctrl_35,
            out_centrl_ctrl_36  => out_centrl_ctrl_36,
            out_centrl_ctrl_37  => out_centrl_ctrl_37,
            out_centrl_ctrl_38  => out_centrl_ctrl_38,
            out_centrl_ctrl_39  => out_centrl_ctrl_39,
            out_centrl_ctrl_40  => out_centrl_ctrl_40,
            out_centrl_ctrl_41  => out_centrl_ctrl_41,
            out_centrl_ctrl_42  => out_centrl_ctrl_42,
            out_centrl_ctrl_43  => out_centrl_ctrl_43,
            out_centrl_ctrl_44  => out_centrl_ctrl_44,
            out_centrl_ctrl_45  => out_centrl_ctrl_45,
            out_centrl_ctrl_46  => out_centrl_ctrl_46,
            so                  => so_xhdl1
        );
    
    -- MBUS_OUT muxing for central channel
    
    
    mbus_mux_inst : stratixiv_hssi_cmu_dprio_centrl_bus_out_mux
        PORT MAP (
            centrl_ctrl_in1       => out_centrl_ctrl_1,
            centrl_ctrl_in2       => out_centrl_ctrl_2,
            centrl_ctrl_in3       => out_centrl_ctrl_3,
            centrl_ctrl_in4       => out_centrl_ctrl_4,
            centrl_ctrl_in5       => out_centrl_ctrl_5,
            centrl_ctrl_in6       => out_centrl_ctrl_6,
            centrl_ctrl_in7       => out_centrl_ctrl_7,
            centrl_ctrl_in8       => out_centrl_ctrl_8,
            centrl_ctrl_in9       => out_centrl_ctrl_9,
            centrl_ctrl_in10      => out_centrl_ctrl_10,
            centrl_ctrl_in11      => out_centrl_ctrl_11,
            centrl_ctrl_in12      => out_centrl_ctrl_12,
            centrl_ctrl_in13      => out_centrl_ctrl_13,
            centrl_ctrl_in14      => out_centrl_ctrl_14,
            centrl_ctrl_in15      => out_centrl_ctrl_15,
            centrl_ctrl_in16      => out_centrl_ctrl_16,
            centrl_ctrl_in17      => out_centrl_ctrl_17,
            centrl_ctrl_in18      => out_centrl_ctrl_18,
            centrl_ctrl_in19      => out_centrl_ctrl_19,
            centrl_ctrl_in20      => out_centrl_ctrl_20,
            centrl_ctrl_in21      => out_centrl_ctrl_21,
            centrl_ctrl_in22      => out_centrl_ctrl_22,
            centrl_ctrl_in23      => out_centrl_ctrl_23,
            centrl_ctrl_in24      => out_centrl_ctrl_24,
            centrl_ctrl_in25      => out_centrl_ctrl_25,
            centrl_ctrl_in26      => out_centrl_ctrl_26,
            centrl_ctrl_in27      => out_centrl_ctrl_27,
            centrl_ctrl_in28      => out_centrl_ctrl_28,
            centrl_ctrl_in29      => out_centrl_ctrl_29,
            centrl_ctrl_in30      => out_centrl_ctrl_30,
            centrl_ctrl_in31      => out_centrl_ctrl_31,
            centrl_ctrl_in32      => out_centrl_ctrl_32,
            centrl_ctrl_in33      => out_centrl_ctrl_33,
            centrl_ctrl_in34      => out_centrl_ctrl_34,
            centrl_ctrl_in35      => out_centrl_ctrl_35,
            centrl_ctrl_in36      => out_centrl_ctrl_36,
            centrl_ctrl_in37      => out_centrl_ctrl_37,
            centrl_ctrl_in38      => out_centrl_ctrl_38,
            centrl_ctrl_in39      => out_centrl_ctrl_39,
            centrl_ctrl_in40      => out_centrl_ctrl_40,
            centrl_ctrl_in41      => out_centrl_ctrl_41,
            centrl_ctrl_in42      => out_centrl_ctrl_42,
            centrl_ctrl_in43      => out_centrl_ctrl_43,
            centrl_ctrl_in44      => out_centrl_ctrl_44,
            centrl_ctrl_in45      => out_centrl_ctrl_45,
            centrl_ctrl_in46      => out_centrl_ctrl_46,
            hw_address_ctrl_in1   => targ_addr_ctrl_1,
            hw_address_ctrl_in2   => targ_addr_ctrl_2,
            hw_address_ctrl_in3   => targ_addr_ctrl_3,
            hw_address_ctrl_in4   => targ_addr_ctrl_4,
            hw_address_ctrl_in5   => targ_addr_ctrl_5,
            hw_address_ctrl_in6   => targ_addr_ctrl_6,
            hw_address_ctrl_in7   => targ_addr_ctrl_7,
            hw_address_ctrl_in8   => targ_addr_ctrl_8,
            hw_address_ctrl_in9   => targ_addr_ctrl_9,
            hw_address_ctrl_in10  => targ_addr_ctrl_10,
            hw_address_ctrl_in11  => targ_addr_ctrl_11,
            hw_address_ctrl_in12  => targ_addr_ctrl_12,
            hw_address_ctrl_in13  => targ_addr_ctrl_13,
            hw_address_ctrl_in14  => targ_addr_ctrl_14,
            hw_address_ctrl_in15  => targ_addr_ctrl_15,
            hw_address_ctrl_in16  => targ_addr_ctrl_16,
            hw_address_ctrl_in17  => targ_addr_ctrl_17,
            hw_address_ctrl_in18  => targ_addr_ctrl_18,
            hw_address_ctrl_in19  => targ_addr_ctrl_19,
            hw_address_ctrl_in20  => targ_addr_ctrl_20,
            hw_address_ctrl_in21  => targ_addr_ctrl_21,
            hw_address_ctrl_in22  => targ_addr_ctrl_22,
            hw_address_ctrl_in23  => targ_addr_ctrl_23,
            hw_address_ctrl_in24  => targ_addr_ctrl_24,
            hw_address_ctrl_in25  => targ_addr_ctrl_25,
            hw_address_ctrl_in26  => targ_addr_ctrl_26,
            hw_address_ctrl_in27  => targ_addr_ctrl_27,
            hw_address_ctrl_in28  => targ_addr_ctrl_28,
            hw_address_ctrl_in29  => targ_addr_ctrl_29,
            hw_address_ctrl_in30  => targ_addr_ctrl_30,
            hw_address_ctrl_in31  => targ_addr_ctrl_31,
            hw_address_ctrl_in32  => targ_addr_ctrl_32,
            hw_address_ctrl_in33  => targ_addr_ctrl_33,
            hw_address_ctrl_in34  => targ_addr_ctrl_34,
            hw_address_ctrl_in35  => targ_addr_ctrl_35,
            hw_address_ctrl_in36  => targ_addr_ctrl_36,
            hw_address_ctrl_in37  => targ_addr_ctrl_37,
            hw_address_ctrl_in38  => targ_addr_ctrl_38,
            hw_address_ctrl_in39  => targ_addr_ctrl_39,
            hw_address_ctrl_in40  => targ_addr_ctrl_40,
            hw_address_ctrl_in41  => targ_addr_ctrl_41,
            hw_address_ctrl_in42  => targ_addr_ctrl_42,
            hw_address_ctrl_in43  => targ_addr_ctrl_43,
            hw_address_ctrl_in44  => targ_addr_ctrl_44,
            hw_address_ctrl_in45  => targ_addr_ctrl_45,
            hw_address_ctrl_in46  => targ_addr_ctrl_46,
            reg_addr              => reg_addr,
            centrl_ctrl_out       => mbus_out_xhdl0
        );
    
END ARCHITECTURE trans;


LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;

ENTITY stratixiv_hssi_cmu_dprio_map_index IS
   GENERIC (
      -- Simulation Only 
      clkdiv0_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv0_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv1_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv1_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv2_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv2_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv3_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv3_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv4_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv4_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv5_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv5_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      
      pll0_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll0_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll0_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll0_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll0_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll0_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll0_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll0_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll0_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll0_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll1_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll1_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll1_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll1_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll1_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll1_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll1_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll1_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll1_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll1_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll2_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll2_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll2_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll2_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll2_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll2_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll2_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll2_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll2_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll2_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll3_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll3_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll3_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll3_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll3_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll3_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll3_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll3_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll3_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll3_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll4_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll4_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll4_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll4_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll4_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll4_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll4_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll4_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll4_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll4_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll5_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll5_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll5_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll5_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll5_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll5_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll5_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll5_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll5_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll5_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
            
      pll0_logical_to_physical_mapping    :    INTEGER := 0;
      pll1_logical_to_physical_mapping    :    INTEGER := 1;
      pll2_logical_to_physical_mapping    :    INTEGER := 2;
      pll3_logical_to_physical_mapping    :    INTEGER := 3;
      pll4_logical_to_physical_mapping    :    INTEGER := 4;
      pll5_logical_to_physical_mapping    :    INTEGER := 5;
            
      refclk_divider0_logical_to_physical_mapping	:	INTEGER := 0;
      refclk_divider1_logical_to_physical_mapping	:	INTEGER := 1;
      
      rx0_logical_to_physical_mapping	:	INTEGER := 0;
      rx1_logical_to_physical_mapping	:	INTEGER := 1;
      rx2_logical_to_physical_mapping	:	INTEGER := 2;
      rx3_logical_to_physical_mapping	:	INTEGER := 3;
      rx4_logical_to_physical_mapping	:	INTEGER := 4;
      rx5_logical_to_physical_mapping	:	INTEGER := 5;
      
      tx0_logical_to_physical_mapping	:	INTEGER := 0;
      tx1_logical_to_physical_mapping	:	INTEGER := 1;
      tx2_logical_to_physical_mapping	:	INTEGER := 2;
      tx3_logical_to_physical_mapping	:	INTEGER := 3;
      tx4_logical_to_physical_mapping	:	INTEGER := 4;
      tx5_logical_to_physical_mapping	:	INTEGER := 5;
      
      
      tx0_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx0_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx0_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx0_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx0_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx1_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx1_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx1_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx1_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx1_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx2_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx2_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx2_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx2_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx2_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx3_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx3_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx3_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx3_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx3_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx4_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx4_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx4_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx4_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx4_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx5_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx5_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx5_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx5_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx5_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport"
   );
   PORT (
      pll0_init_pfd_clk_sel  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll0_dp_riqclk_sel     : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll0_dp_rrefclk_sel    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll0_csr_riqclk_sel    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll0_csr_rrefclk_sel   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll0_dp_pfd_clk_sel    : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll1_init_pfd_clk_sel  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll1_dp_riqclk_sel     : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll1_dp_rrefclk_sel    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll1_csr_riqclk_sel    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll1_csr_rrefclk_sel   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll1_dp_pfd_clk_sel    : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll2_init_pfd_clk_sel  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll2_dp_riqclk_sel     : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll2_dp_rrefclk_sel    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll2_csr_riqclk_sel    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll2_csr_rrefclk_sel   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll2_dp_pfd_clk_sel    : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll3_init_pfd_clk_sel  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll3_dp_riqclk_sel     : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll3_dp_rrefclk_sel    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll3_csr_riqclk_sel    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll3_csr_rrefclk_sel   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll3_dp_pfd_clk_sel    : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll4_init_pfd_clk_sel  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll4_dp_riqclk_sel     : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll4_dp_rrefclk_sel    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll4_csr_riqclk_sel    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll4_csr_rrefclk_sel   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll4_dp_pfd_clk_sel    : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll5_init_pfd_clk_sel  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll5_dp_riqclk_sel     : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll5_dp_rrefclk_sel    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll5_csr_riqclk_sel    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll5_csr_rrefclk_sel   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll5_dp_pfd_clk_sel    : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      
      txpma0_init_clkin_sel  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      txpma0_csr_rcgb_x_en   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma0_dp_rcgb_x_en    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma0_dp_clkin_sel    : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      txpma1_init_clkin_sel  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      txpma1_csr_rcgb_x_en   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma1_dp_rcgb_x_en    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma1_dp_clkin_sel    : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      txpma2_init_clkin_sel  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      txpma2_csr_rcgb_x_en   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma2_dp_rcgb_x_en    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma2_dp_clkin_sel    : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      txpma3_init_clkin_sel  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      txpma3_csr_rcgb_x_en   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma3_dp_rcgb_x_en    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma3_dp_clkin_sel    : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      txpma4_init_clkin_sel  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      txpma4_csr_rcgb_x_en   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma4_dp_rcgb_x_en    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma4_dp_clkin_sel    : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      txpma5_init_clkin_sel  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      txpma5_csr_rcgb_x_en   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma5_dp_rcgb_x_en    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma5_dp_clkin_sel    : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      clkdiv0_init_inclk_select : IN STD_LOGIC;
      clkdiv0_csr_rcgb_cmu_sel  : OUT STD_LOGIC;
      clkdiv0_dp_rcgb_cmu_sel   : IN STD_LOGIC;
      clkdiv0_dp_inclk_select   : OUT STD_LOGIC;
      clkdiv1_init_inclk_select : IN STD_LOGIC;
      clkdiv1_csr_rcgb_cmu_sel  : OUT STD_LOGIC;
      clkdiv1_dp_rcgb_cmu_sel   : IN STD_LOGIC;
      clkdiv1_dp_inclk_select   : OUT STD_LOGIC;
      clkdiv2_init_inclk_select : IN STD_LOGIC;
      clkdiv2_csr_rcgb_cmu_sel  : OUT STD_LOGIC;
      clkdiv2_dp_rcgb_cmu_sel   : IN STD_LOGIC;
      clkdiv2_dp_inclk_select   : OUT STD_LOGIC;
      clkdiv3_init_inclk_select : IN STD_LOGIC;
      clkdiv3_csr_rcgb_cmu_sel  : OUT STD_LOGIC;
      clkdiv3_dp_rcgb_cmu_sel   : IN STD_LOGIC;
      clkdiv3_dp_inclk_select   : OUT STD_LOGIC;
      clkdiv4_init_inclk_select : IN STD_LOGIC;
      clkdiv4_csr_rcgb_cmu_sel  : OUT STD_LOGIC;
      clkdiv4_dp_rcgb_cmu_sel   : IN STD_LOGIC;
      clkdiv4_dp_inclk_select   : OUT STD_LOGIC;
      clkdiv5_init_inclk_select : IN STD_LOGIC;
      clkdiv5_csr_rcgb_cmu_sel  : OUT STD_LOGIC;
      clkdiv5_dp_rcgb_cmu_sel   : IN STD_LOGIC;
      clkdiv5_dp_inclk_select   : OUT STD_LOGIC
   );   
END stratixiv_hssi_cmu_dprio_map_index;

ARCHITECTURE trans OF stratixiv_hssi_cmu_dprio_map_index IS   
   SIGNAL gnd_wire                    : STD_LOGIC := '0';
   SIGNAL vcc_wire                    : STD_LOGIC := '1';
   
-- types ---------------------------------------------------------------
type DPRIO_REG_ARRAY_OF_INT is array (natural range <>) of integer;
type DPRIO_REG_ARRAY_OF_VEC is array (natural range <>) of std_logic_vector(4 downto 0);
type DPRIO_REG_ARRAY_OF_VEC1 is array (natural range <>) of std_logic;
type DPRIO_REG_ARRAY_OF_VEC2 is array (natural range <>) of std_logic_vector(1 downto 0);

-- common functions ----------------------------------------------------
FUNCTION dprio_reg_to_int(arg : IN STD_LOGIC_VECTOR) RETURN INTEGER IS
    VARIABLE result : INTEGER;
BEGIN
    result := 0;
    FOR i IN arg'RANGE LOOP
       IF arg(i) = '1' THEN
           result := result + 2**i;
       END IF;
    END LOOP;
    RETURN result;
END dprio_reg_to_int;
   
---------------------------------------------------------------------------
-- PLL clock selection ----------------------------------------------------  
---------------------------------------------------------------------------

constant PLL_CLOCK_SELECT_CLKREFCLK0        : INTEGER := 0;
constant PLL_CLOCK_SELECT_CLKREFCLK1        : INTEGER := 1;
constant PLL_CLOCK_SELECT_IQ2               : INTEGER := 2;
constant PLL_CLOCK_SELECT_IQ3               : INTEGER := 3;
constant PLL_CLOCK_SELECT_IQ4               : INTEGER := 4;
constant PLL_CLOCK_SELECT_IQ5               : INTEGER := 5;
constant PLL_CLOCK_SELECT_IQ6               : INTEGER := 6;
constant PLL_CLOCK_SELECT_IQ7               : INTEGER := 7;
constant PLL_CLOCK_SELECT_PLD_CLK           : INTEGER := 8;
constant PLL_CLOCK_SELECT_GPLL_CLK          : INTEGER := 9;
constant PLL_CLOCK_SELECT_ERR               : INTEGER := 10;

FUNCTION convert_pll_clock_cram_to_phyport (
    rrefclk_sel : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
    pldiq       : IN STD_LOGIC_VECTOR(1 DOWNTO 0)) RETURN INTEGER IS
    
    VARIABLE res : INTEGER := PLL_CLOCK_SELECT_ERR;
    VARIABLE tmp_in : STD_LOGIC_VECTOR(3 DOWNTO 0) := "0000";
BEGIN
    tmp_in := rrefclk_sel & pldiq;
    if (rrefclk_sel = "00") THEN
        res := PLL_CLOCK_SELECT_CLKREFCLK0; 
    ELSIF (rrefclk_sel = "01") THEN
        res := PLL_CLOCK_SELECT_CLKREFCLK1;
    ELSE
        CASE tmp_in IS
            WHEN "1000" => res := PLL_CLOCK_SELECT_IQ2;
            WHEN "1001" => res := PLL_CLOCK_SELECT_IQ3;
            WHEN "1010" => res := PLL_CLOCK_SELECT_IQ4;
            WHEN "1100" => res := PLL_CLOCK_SELECT_IQ5;
            WHEN "1101" => res := PLL_CLOCK_SELECT_IQ6;
            WHEN "1110" => res := PLL_CLOCK_SELECT_IQ7;
            WHEN "1011" => res := PLL_CLOCK_SELECT_PLD_CLK;
            WHEN "1111" => res := PLL_CLOCK_SELECT_GPLL_CLK; 
            WHEN OTHERS => res := PLL_CLOCK_SELECT_ERR;
         END CASE;
    END IF;
      
    RETURN res;
END convert_pll_clock_cram_to_phyport;

-- input is at most 15 characters
FUNCTION convert_pll_phyport_str_to_phyport_enum (
    phyport_str : IN STRING) RETURN INTEGER IS
    VARIABLE res : INTEGER := 0;
BEGIN
    IF (phyport_str = "iq2") THEN
        res := PLL_CLOCK_SELECT_IQ2;
    ELSIF (phyport_str = "iq3") THEN
        res := PLL_CLOCK_SELECT_IQ3;
    ELSIF (phyport_str = "iq4") THEN
        res := PLL_CLOCK_SELECT_IQ4;
    ELSIF (phyport_str = "iq5") THEN
        res := PLL_CLOCK_SELECT_IQ5;
    ELSIF (phyport_str = "iq6") THEN
        res := PLL_CLOCK_SELECT_IQ6;
    ELSIF (phyport_str = "iq7") THEN
        res := PLL_CLOCK_SELECT_IQ7;
    ELSIF (phyport_str = "refclk0" OR phyport_str = "clkrefclk0") THEN
        res := PLL_CLOCK_SELECT_CLKREFCLK0;
    ELSIF (phyport_str = "refclk1" OR phyport_str = "clkrefclk1") THEN
        res := PLL_CLOCK_SELECT_CLKREFCLK1;
    ELSIF (phyport_str = "pld_clk") THEN
        res := PLL_CLOCK_SELECT_PLD_CLK;
    ELSIF (phyport_str = "gpll_clk") THEN
        res := PLL_CLOCK_SELECT_GPLL_CLK;
    ELSE  -- like "none"
        res := PLL_CLOCK_SELECT_ERR;
    END IF;
         
    RETURN res;
END convert_pll_phyport_str_to_phyport_enum;

-- common to all PLL channels 
SIGNAL pll_clock_phyport_to_cram : DPRIO_REG_ARRAY_OF_VEC (10 DOWNTO 0) := (OTHERS => "00000");

-- READ  --------------- ch0
SIGNAL pll0_clock_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (9 DOWNTO 0) := (OTHERS => 0);
SIGNAL tmp_pll0_clock_select_vec   : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll0_clock_select   : INTEGER := 0;
SIGNAL pll0_clock_phyport  : INTEGER := 0;
SIGNAL pll0_clock_cram     : STD_LOGIC_VECTOR (4 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll0_clock_cram_phy : STD_LOGIC_VECTOR (4 DOWNTO 0) := (OTHERS => '0'); 

-- Write --------------- ch0
SIGNAL pll0_clock_phyport_out       : INTEGER := 0;      
SIGNAL pll0_clock_phyport_out_logic : INTEGER := 0; 
SIGNAL pll0_clock_select_out_logic  : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll0_clock_select_out        : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 

-- READ  --------------- ch1
SIGNAL pll1_clock_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (9 DOWNTO 0) := (OTHERS => 0);
SIGNAL tmp_pll1_clock_select_vec   : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll1_clock_select   : INTEGER := 0;
SIGNAL pll1_clock_phyport  : INTEGER := 0;
SIGNAL pll1_clock_cram     : STD_LOGIC_VECTOR (4 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll1_clock_cram_phy : STD_LOGIC_VECTOR (4 DOWNTO 0) := (OTHERS => '0'); 

-- Write --------------- ch1
SIGNAL pll1_clock_phyport_out       : INTEGER := 0;      
SIGNAL pll1_clock_phyport_out_logic : INTEGER := 0; 
SIGNAL pll1_clock_select_out_logic  : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll1_clock_select_out        : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 

-- READ  --------------- ch2
SIGNAL pll2_clock_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (9 DOWNTO 0) := (OTHERS => 0);
SIGNAL tmp_pll2_clock_select_vec   : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll2_clock_select   : INTEGER := 0;
SIGNAL pll2_clock_phyport  : INTEGER := 0;
SIGNAL pll2_clock_cram     : STD_LOGIC_VECTOR (4 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll2_clock_cram_phy : STD_LOGIC_VECTOR (4 DOWNTO 0) := (OTHERS => '0'); 

-- Write --------------- ch2
SIGNAL pll2_clock_phyport_out       : INTEGER := 0;      
SIGNAL pll2_clock_phyport_out_logic : INTEGER := 0; 
SIGNAL pll2_clock_select_out_logic  : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll2_clock_select_out        : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 

-- READ  --------------- ch3
SIGNAL pll3_clock_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (9 DOWNTO 0) := (OTHERS => 0);
SIGNAL tmp_pll3_clock_select_vec   : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll3_clock_select   : INTEGER := 0;
SIGNAL pll3_clock_phyport  : INTEGER := 0;
SIGNAL pll3_clock_cram     : STD_LOGIC_VECTOR (4 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll3_clock_cram_phy : STD_LOGIC_VECTOR (4 DOWNTO 0) := (OTHERS => '0'); 

-- Write --------------- ch3
SIGNAL pll3_clock_phyport_out       : INTEGER := 0;      
SIGNAL pll3_clock_phyport_out_logic : INTEGER := 0; 
SIGNAL pll3_clock_select_out_logic  : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll3_clock_select_out        : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 

-- READ  --------------- ch4
SIGNAL pll4_clock_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (9 DOWNTO 0) := (OTHERS => 0);
SIGNAL tmp_pll4_clock_select_vec   : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll4_clock_select   : INTEGER := 0;
SIGNAL pll4_clock_phyport  : INTEGER := 0;
SIGNAL pll4_clock_cram     : STD_LOGIC_VECTOR (4 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll4_clock_cram_phy : STD_LOGIC_VECTOR (4 DOWNTO 0) := (OTHERS => '0'); 

-- Write --------------- ch4
SIGNAL pll4_clock_phyport_out       : INTEGER := 0;      
SIGNAL pll4_clock_phyport_out_logic : INTEGER := 0; 
SIGNAL pll4_clock_select_out_logic  : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll4_clock_select_out        : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 

-- READ  --------------- ch5
SIGNAL pll5_clock_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (9 DOWNTO 0) := (OTHERS => 0);
SIGNAL tmp_pll5_clock_select_vec   : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll5_clock_select   : INTEGER := 0;
SIGNAL pll5_clock_phyport  : INTEGER := 0;
SIGNAL pll5_clock_cram     : STD_LOGIC_VECTOR (4 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll5_clock_cram_phy : STD_LOGIC_VECTOR (4 DOWNTO 0) := (OTHERS => '0'); 

-- Write --------------- ch5
SIGNAL pll5_clock_phyport_out       : INTEGER := 0;      
SIGNAL pll5_clock_phyport_out_logic : INTEGER := 0; 
SIGNAL pll5_clock_select_out_logic  : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 
SIGNAL pll5_clock_select_out        : STD_LOGIC_VECTOR (3 DOWNTO 0) := (OTHERS => '0'); 

---------------------------------------------------------------------------
-- TX PMA selection -------------------------------------------------------  
---------------------------------------------------------------------------

constant TXPMA_CLKIN_SELECT_X1         : INTEGER := 0;
constant TXPMA_CLKIN_SELECT_X4         : INTEGER := 1;
constant TXPMA_CLKIN_SELECT_XN_TOP     : INTEGER := 2;
constant TXPMA_CLKIN_SELECT_XN_BOTTOM  : INTEGER := 3;
constant TXPMA_CLKIN_SELECT_HT         : INTEGER := 4;
constant TXPMA_CLKIN_SELECT_ERR        : INTEGER := 7;

FUNCTION convert_txpma_clock_cram_to_phyport (
             rcgb_x_en : IN STD_LOGIC_VECTOR(1 DOWNTO 0)) RETURN INTEGER IS
      VARIABLE res : INTEGER := 0;
BEGIN
    CASE rcgb_x_en IS
        WHEN "00"     =>  res := TXPMA_CLKIN_SELECT_X1; 
        WHEN "01"     =>  res := TXPMA_CLKIN_SELECT_X4;
        WHEN "10"     =>  res := TXPMA_CLKIN_SELECT_XN_TOP;
        WHEN "11"     =>  res := TXPMA_CLKIN_SELECT_XN_BOTTOM;
        WHEN OTHERS   =>  res := TXPMA_CLKIN_SELECT_ERR;
    END CASE;
      
    RETURN res;
END convert_txpma_clock_cram_to_phyport;

-- input is at most 20 characters
FUNCTION convert_txpma_phyport_str_to_phyport_enum (
             phyport_str : IN STRING ) RETURN INTEGER IS
             
    VARIABLE res : INTEGER := 0;
BEGIN
    IF (phyport_str = "x1" OR phyport_str = "X1") THEN
        res := TXPMA_CLKIN_SELECT_X1;
    ELSIF (phyport_str = "x4" OR phyport_str = "X4") THEN
        res := TXPMA_CLKIN_SELECT_X4;
    ELSIF (phyport_str = "xn_top" OR phyport_str = "XN_TOP") THEN
        res := TXPMA_CLKIN_SELECT_XN_TOP;
    ELSIF (phyport_str = "xn_bottom" OR phyport_str = "XN_BOTTOM") THEN
        res := TXPMA_CLKIN_SELECT_XN_BOTTOM;
    ELSIF (phyport_str = "hypertransport" OR phyport_str = "HYPERTRANSPORT") THEN
        res := TXPMA_CLKIN_SELECT_HT;
    ELSE  -- like "none"
        res := TXPMA_CLKIN_SELECT_ERR;
    END IF;
         
    RETURN res;
END convert_txpma_phyport_str_to_phyport_enum;

-- common to all channels ------------------------------------------------
       -- phyport to cram - include error string
SIGNAL txpma_clock_phyport_to_cram : DPRIO_REG_ARRAY_OF_VEC2 (7 DOWNTO 0) := (OTHERS => "00");   

-- READ  --------------- ch0
       -- map table - index to phyport integer
SIGNAL txpma0_clock_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (4 DOWNTO 0) := (OTHERS => 0); 
SIGNAL tmp_txpma0_clock_select_vec   : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 
SIGNAL txpma0_clock_select           : INTEGER := 0;
SIGNAL txpma0_clock_phyport          : INTEGER := 0;
SIGNAL txpma0_clock_cram             : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00"; 
SIGNAL txpma0_clock_cram_phy         : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00"; 
-- Write --------------- ch0
SIGNAL txpma0_clock_phyport_out       : INTEGER := 0;
SIGNAL txpma0_clock_phyport_out_logic : INTEGER := 0; 
SIGNAL txpma0_clock_select_out_logic  : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 
SIGNAL txpma0_clock_select_out        : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 

-- READ  --------------- ch1
       -- map table - index to phyport integer
SIGNAL txpma1_clock_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (4 DOWNTO 0) := (OTHERS => 0); 
SIGNAL tmp_txpma1_clock_select_vec   : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 
SIGNAL txpma1_clock_select           : INTEGER := 0;
SIGNAL txpma1_clock_phyport          : INTEGER := 0;
SIGNAL txpma1_clock_cram             : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00"; 
SIGNAL txpma1_clock_cram_phy         : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00"; 
-- Write --------------- ch1
SIGNAL txpma1_clock_phyport_out       : INTEGER := 0;
SIGNAL txpma1_clock_phyport_out_logic : INTEGER := 0; 
SIGNAL txpma1_clock_select_out_logic  : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 
SIGNAL txpma1_clock_select_out        : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 

-- READ  --------------- ch2
       -- map table - index to phyport integer
SIGNAL txpma2_clock_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (4 DOWNTO 0) := (OTHERS => 0); 
SIGNAL tmp_txpma2_clock_select_vec   : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 
SIGNAL txpma2_clock_select           : INTEGER := 0;
SIGNAL txpma2_clock_phyport          : INTEGER := 0;
SIGNAL txpma2_clock_cram             : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00"; 
SIGNAL txpma2_clock_cram_phy         : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00"; 
-- Write --------------- ch2
SIGNAL txpma2_clock_phyport_out       : INTEGER := 0;
SIGNAL txpma2_clock_phyport_out_logic : INTEGER := 0; 
SIGNAL txpma2_clock_select_out_logic  : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 
SIGNAL txpma2_clock_select_out        : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 

-- READ  --------------- ch3
       -- map table - index to phyport integer
SIGNAL txpma3_clock_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (4 DOWNTO 0) := (OTHERS => 0); 
SIGNAL tmp_txpma3_clock_select_vec   : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 
SIGNAL txpma3_clock_select           : INTEGER := 0;
SIGNAL txpma3_clock_phyport          : INTEGER := 0;
SIGNAL txpma3_clock_cram             : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00"; 
SIGNAL txpma3_clock_cram_phy         : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00"; 
-- Write --------------- ch3
SIGNAL txpma3_clock_phyport_out       : INTEGER := 0;
SIGNAL txpma3_clock_phyport_out_logic : INTEGER := 0; 
SIGNAL txpma3_clock_select_out_logic  : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 
SIGNAL txpma3_clock_select_out        : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 

-- READ  --------------- ch4
       -- map table - index to phyport integer
SIGNAL txpma4_clock_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (4 DOWNTO 0) := (OTHERS => 0); 
SIGNAL tmp_txpma4_clock_select_vec   : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 
SIGNAL txpma4_clock_select           : INTEGER := 0;
SIGNAL txpma4_clock_phyport          : INTEGER := 0;
SIGNAL txpma4_clock_cram             : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00"; 
SIGNAL txpma4_clock_cram_phy         : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00"; 
-- Write --------------- ch4
SIGNAL txpma4_clock_phyport_out       : INTEGER := 0;
SIGNAL txpma4_clock_phyport_out_logic : INTEGER := 0; 
SIGNAL txpma4_clock_select_out_logic  : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 
SIGNAL txpma4_clock_select_out        : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 

-- READ  --------------- ch5
       -- map table - index to phyport integer
SIGNAL txpma5_clock_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (4 DOWNTO 0) := (OTHERS => 0); 
SIGNAL tmp_txpma5_clock_select_vec   : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 
SIGNAL txpma5_clock_select           : INTEGER := 0;
SIGNAL txpma5_clock_phyport          : INTEGER := 0;
SIGNAL txpma5_clock_cram             : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00"; 
SIGNAL txpma5_clock_cram_phy         : STD_LOGIC_VECTOR(1 DOWNTO 0) := "00"; 
-- Write --------------- ch5
SIGNAL txpma5_clock_phyport_out       : INTEGER := 0;
SIGNAL txpma5_clock_phyport_out_logic : INTEGER := 0; 
SIGNAL txpma5_clock_select_out_logic  : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 
SIGNAL txpma5_clock_select_out        : STD_LOGIC_VECTOR(2 DOWNTO 0) := "000"; 

---------------------------------------------------------------------------
-- PLL0/PLL1 selection ----------------------------------------------------  
---------------------------------------------------------------------------

constant CLKDIV_INCLK_SELECT_PLL0     : INTEGER := 0;
constant CLKDIV_INCLK_SELECT_PLL1     : INTEGER := 1;
constant CLKDIV_INCLK_SELECT_ERR      : INTEGER := 2;

FUNCTION convert_clkdiv_pll_cram_to_phyport (
    rcgb_cmu_sel : IN STD_LOGIC) RETURN INTEGER IS
       
    VARIABLE res : INTEGER := 0;
BEGIN
    CASE rcgb_cmu_sel IS
        WHEN '0'    =>    res := CLKDIV_INCLK_SELECT_PLL0; 
        WHEN '1'    =>    res := CLKDIV_INCLK_SELECT_PLL1; 
        WHEN OTHERS =>    res := CLKDIV_INCLK_SELECT_ERR;
    END CASE;
      
    RETURN res;
END convert_clkdiv_pll_cram_to_phyport;

FUNCTION convert_clkdiv_pll_phyport_str_to_phyport_enum(
    phyport_str : IN STRING) RETURN INTEGER IS

    VARIABLE res : INTEGER := 0;
BEGIN
    IF (phyport_str = "pll0") THEN
        res := CLKDIV_INCLK_SELECT_PLL0;
    ELSIF (phyport_str = "pll1") THEN
        res := CLKDIV_INCLK_SELECT_PLL1;
    ELSE  -- like "none"
        res := CLKDIV_INCLK_SELECT_ERR;
    END IF;
         
    RETURN res;

END convert_clkdiv_pll_phyport_str_to_phyport_enum;

-- common to all PLL channels
SIGNAL clkdiv_pll_phyport_to_cram : DPRIO_REG_ARRAY_OF_VEC1 (2 DOWNTO 0) := (OTHERS => '0');

-- READ  --------------- ch0
SIGNAL clkdiv0_pll_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (1 DOWNTO 0) := (OTHERS => 0);
SIGNAL tmp_clkdiv0_pll_select       : STD_LOGIC := '0';
SIGNAL clkdiv0_pll_select           : INTEGER := 0;
SIGNAL clkdiv0_pll_phyport          : INTEGER := 0;
SIGNAL clkdiv0_pll_cram             : STD_LOGIC := '0';
SIGNAL clkdiv0_pll_cram_phy         : STD_LOGIC := '0';
-- Write --------------- ch0
SIGNAL clkdiv0_pll_phyport_out       : INTEGER := 0;      
SIGNAL clkdiv0_pll_phyport_out_logic : INTEGER := 0; 
SIGNAL clkdiv0_pll_select_out_logic  : STD_LOGIC := '0'; 
SIGNAL clkdiv0_pll_select_out        : STD_LOGIC := '0';

-- READ  --------------- ch1
SIGNAL clkdiv1_pll_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (1 DOWNTO 0) := (OTHERS => 0);
SIGNAL tmp_clkdiv1_pll_select       : STD_LOGIC := '0';
SIGNAL clkdiv1_pll_select           : INTEGER := 0;
SIGNAL clkdiv1_pll_phyport          : INTEGER := 0;
SIGNAL clkdiv1_pll_cram             : STD_LOGIC := '0';
SIGNAL clkdiv1_pll_cram_phy         : STD_LOGIC := '0';
-- Write --------------- ch1
SIGNAL clkdiv1_pll_phyport_out       : INTEGER := 0;      
SIGNAL clkdiv1_pll_phyport_out_logic : INTEGER := 0; 
SIGNAL clkdiv1_pll_select_out_logic  : STD_LOGIC := '0'; 
SIGNAL clkdiv1_pll_select_out        : STD_LOGIC := '0';

-- READ  --------------- ch2
SIGNAL clkdiv2_pll_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (1 DOWNTO 0) := (OTHERS => 0);
SIGNAL tmp_clkdiv2_pll_select       : STD_LOGIC := '0';
SIGNAL clkdiv2_pll_select           : INTEGER := 0;
SIGNAL clkdiv2_pll_phyport          : INTEGER := 0;
SIGNAL clkdiv2_pll_cram             : STD_LOGIC := '0';
SIGNAL clkdiv2_pll_cram_phy         : STD_LOGIC := '0';
-- Write --------------- ch2
SIGNAL clkdiv2_pll_phyport_out       : INTEGER := 0;      
SIGNAL clkdiv2_pll_phyport_out_logic : INTEGER := 0; 
SIGNAL clkdiv2_pll_select_out_logic  : STD_LOGIC := '0'; 
SIGNAL clkdiv2_pll_select_out        : STD_LOGIC := '0';

-- READ  --------------- ch3
SIGNAL clkdiv3_pll_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (1 DOWNTO 0) := (OTHERS => 0);
SIGNAL tmp_clkdiv3_pll_select       : STD_LOGIC := '0';
SIGNAL clkdiv3_pll_select           : INTEGER := 0;
SIGNAL clkdiv3_pll_phyport          : INTEGER := 0;
SIGNAL clkdiv3_pll_cram             : STD_LOGIC := '0';
SIGNAL clkdiv3_pll_cram_phy         : STD_LOGIC := '0';
-- Write --------------- ch3
SIGNAL clkdiv3_pll_phyport_out       : INTEGER := 0;      
SIGNAL clkdiv3_pll_phyport_out_logic : INTEGER := 0; 
SIGNAL clkdiv3_pll_select_out_logic  : STD_LOGIC := '0'; 
SIGNAL clkdiv3_pll_select_out        : STD_LOGIC := '0';

-- READ  --------------- ch4
SIGNAL clkdiv4_pll_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (1 DOWNTO 0) := (OTHERS => 0);
SIGNAL tmp_clkdiv4_pll_select       : STD_LOGIC := '0';
SIGNAL clkdiv4_pll_select           : INTEGER := 0;
SIGNAL clkdiv4_pll_phyport          : INTEGER := 0;
SIGNAL clkdiv4_pll_cram             : STD_LOGIC := '0';
SIGNAL clkdiv4_pll_cram_phy         : STD_LOGIC := '0';
-- Write --------------- ch4
SIGNAL clkdiv4_pll_phyport_out       : INTEGER := 0;      
SIGNAL clkdiv4_pll_phyport_out_logic : INTEGER := 0; 
SIGNAL clkdiv4_pll_select_out_logic  : STD_LOGIC := '0'; 
SIGNAL clkdiv4_pll_select_out        : STD_LOGIC := '0';

-- READ  --------------- ch5
SIGNAL clkdiv5_pll_index_to_phyport : DPRIO_REG_ARRAY_OF_INT (1 DOWNTO 0) := (OTHERS => 0);
SIGNAL tmp_clkdiv5_pll_select       : STD_LOGIC := '0';
SIGNAL clkdiv5_pll_select           : INTEGER := 0;
SIGNAL clkdiv5_pll_phyport          : INTEGER := 0;
SIGNAL clkdiv5_pll_cram             : STD_LOGIC := '0';
SIGNAL clkdiv5_pll_cram_phy         : STD_LOGIC := '0';
-- Write --------------- ch5
SIGNAL clkdiv5_pll_phyport_out       : INTEGER := 0;      
SIGNAL clkdiv5_pll_phyport_out_logic : INTEGER := 0; 
SIGNAL clkdiv5_pll_select_out_logic  : STD_LOGIC := '0'; 
SIGNAL clkdiv5_pll_select_out        : STD_LOGIC := '0';


BEGIN

---------------------------------------------------------------------------
-- PLL clock selection ----------------------------------------------------  
---------------------------------------------------------------------------

PROCESS  -- initialize the TABLE
  VARIABLE init_table                : STD_LOGIC := '1';  
  VARIABLE tmp_int                   : INTEGER := 0; 
        
  BEGIN
  IF (init_table = '1') THEN
    pll_clock_phyport_to_cram(PLL_CLOCK_SELECT_IQ2)        <= "10U00";
    pll_clock_phyport_to_cram(PLL_CLOCK_SELECT_IQ3)        <= "10U01";
    pll_clock_phyport_to_cram(PLL_CLOCK_SELECT_IQ4)        <= "10U10";
    pll_clock_phyport_to_cram(PLL_CLOCK_SELECT_IQ5)        <= "11U00"; -- skip
    pll_clock_phyport_to_cram(PLL_CLOCK_SELECT_IQ6)        <= "11U01";
    pll_clock_phyport_to_cram(PLL_CLOCK_SELECT_IQ7)        <= "11U10";
    pll_clock_phyport_to_cram(PLL_CLOCK_SELECT_PLD_CLK)    <= "10U11";
    pll_clock_phyport_to_cram(PLL_CLOCK_SELECT_GPLL_CLK)   <= "11U11";
    -- iqsel below is donot care so take default for preventing X values passing around
    pll_clock_phyport_to_cram(PLL_CLOCK_SELECT_CLKREFCLK0) <= "00U00"; 
    pll_clock_phyport_to_cram(PLL_CLOCK_SELECT_CLKREFCLK1) <= "01U00";
    pll_clock_phyport_to_cram(PLL_CLOCK_SELECT_ERR)        <= "11111";    

    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll0_inclk0_logical_to_physical_mapping);
    pll0_clock_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll0_inclk1_logical_to_physical_mapping);
    pll0_clock_index_to_phyport(1) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll0_inclk2_logical_to_physical_mapping);
    pll0_clock_index_to_phyport(2) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll0_inclk3_logical_to_physical_mapping);
    pll0_clock_index_to_phyport(3) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll0_inclk4_logical_to_physical_mapping);
    pll0_clock_index_to_phyport(4) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll0_inclk5_logical_to_physical_mapping);
    pll0_clock_index_to_phyport(5) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll0_inclk6_logical_to_physical_mapping);
    pll0_clock_index_to_phyport(6) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll0_inclk7_logical_to_physical_mapping);
    pll0_clock_index_to_phyport(7) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll0_inclk8_logical_to_physical_mapping);
    pll0_clock_index_to_phyport(8) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll0_inclk9_logical_to_physical_mapping);
    pll0_clock_index_to_phyport(9) <= tmp_int;

    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll1_inclk0_logical_to_physical_mapping);
    pll1_clock_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll1_inclk1_logical_to_physical_mapping);
    pll1_clock_index_to_phyport(1) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll1_inclk2_logical_to_physical_mapping);
    pll1_clock_index_to_phyport(2) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll1_inclk3_logical_to_physical_mapping);
    pll1_clock_index_to_phyport(3) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll1_inclk4_logical_to_physical_mapping);
    pll1_clock_index_to_phyport(4) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll1_inclk5_logical_to_physical_mapping);
    pll1_clock_index_to_phyport(5) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll1_inclk6_logical_to_physical_mapping);
    pll1_clock_index_to_phyport(6) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll1_inclk7_logical_to_physical_mapping);
    pll1_clock_index_to_phyport(7) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll1_inclk8_logical_to_physical_mapping);
    pll1_clock_index_to_phyport(8) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll1_inclk9_logical_to_physical_mapping);
    pll1_clock_index_to_phyport(9) <= tmp_int;

    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll2_inclk0_logical_to_physical_mapping);
    pll2_clock_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll2_inclk1_logical_to_physical_mapping);
    pll2_clock_index_to_phyport(1) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll2_inclk2_logical_to_physical_mapping);
    pll2_clock_index_to_phyport(2) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll2_inclk3_logical_to_physical_mapping);
    pll2_clock_index_to_phyport(3) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll2_inclk4_logical_to_physical_mapping);
    pll2_clock_index_to_phyport(4) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll2_inclk5_logical_to_physical_mapping);
    pll2_clock_index_to_phyport(5) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll2_inclk6_logical_to_physical_mapping);
    pll2_clock_index_to_phyport(6) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll2_inclk7_logical_to_physical_mapping);
    pll2_clock_index_to_phyport(7) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll2_inclk8_logical_to_physical_mapping);
    pll2_clock_index_to_phyport(8) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll2_inclk9_logical_to_physical_mapping);
    pll2_clock_index_to_phyport(9) <= tmp_int;

    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll3_inclk0_logical_to_physical_mapping);
    pll3_clock_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll3_inclk1_logical_to_physical_mapping);
    pll3_clock_index_to_phyport(1) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll3_inclk2_logical_to_physical_mapping);
    pll3_clock_index_to_phyport(2) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll3_inclk3_logical_to_physical_mapping);
    pll3_clock_index_to_phyport(3) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll3_inclk4_logical_to_physical_mapping);
    pll3_clock_index_to_phyport(4) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll3_inclk5_logical_to_physical_mapping);
    pll3_clock_index_to_phyport(5) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll3_inclk6_logical_to_physical_mapping);
    pll3_clock_index_to_phyport(6) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll3_inclk7_logical_to_physical_mapping);
    pll3_clock_index_to_phyport(7) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll3_inclk8_logical_to_physical_mapping);
    pll3_clock_index_to_phyport(8) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll3_inclk9_logical_to_physical_mapping);
    pll3_clock_index_to_phyport(9) <= tmp_int;

    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll4_inclk0_logical_to_physical_mapping);
    pll4_clock_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll4_inclk1_logical_to_physical_mapping);
    pll4_clock_index_to_phyport(1) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll4_inclk2_logical_to_physical_mapping);
    pll4_clock_index_to_phyport(2) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll4_inclk3_logical_to_physical_mapping);
    pll4_clock_index_to_phyport(3) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll4_inclk4_logical_to_physical_mapping);
    pll4_clock_index_to_phyport(4) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll4_inclk5_logical_to_physical_mapping);
    pll4_clock_index_to_phyport(5) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll4_inclk6_logical_to_physical_mapping);
    pll4_clock_index_to_phyport(6) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll4_inclk7_logical_to_physical_mapping);
    pll4_clock_index_to_phyport(7) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll4_inclk8_logical_to_physical_mapping);
    pll4_clock_index_to_phyport(8) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll4_inclk9_logical_to_physical_mapping);
    pll4_clock_index_to_phyport(9) <= tmp_int;

    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll5_inclk0_logical_to_physical_mapping);
    pll5_clock_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll5_inclk1_logical_to_physical_mapping);
    pll5_clock_index_to_phyport(1) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll5_inclk2_logical_to_physical_mapping);
    pll5_clock_index_to_phyport(2) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll5_inclk3_logical_to_physical_mapping);
    pll5_clock_index_to_phyport(3) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll5_inclk4_logical_to_physical_mapping);
    pll5_clock_index_to_phyport(4) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll5_inclk5_logical_to_physical_mapping);
    pll5_clock_index_to_phyport(5) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll5_inclk6_logical_to_physical_mapping);
    pll5_clock_index_to_phyport(6) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll5_inclk7_logical_to_physical_mapping);
    pll5_clock_index_to_phyport(7) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll5_inclk8_logical_to_physical_mapping);
    pll5_clock_index_to_phyport(8) <= tmp_int;
    tmp_int := convert_pll_phyport_str_to_phyport_enum(pll5_inclk9_logical_to_physical_mapping);
    pll5_clock_index_to_phyport(9) <= tmp_int;
      
    init_table := '0';
   END IF;
    
   WAIT; 
END PROCESS;  -- end of initializing tables

-- DPRIO read - logical pll channel
tmp_pll0_clock_select_vec <= pll0_init_pfd_clk_sel WHEN 
                             ( (pll0_init_pfd_clk_sel(0) = '0' OR pll0_init_pfd_clk_sel(0) = '1') AND
                               (pll0_init_pfd_clk_sel(1) = '0' OR pll0_init_pfd_clk_sel(1) = '1') AND
                               (pll0_init_pfd_clk_sel(2) = '0' OR pll0_init_pfd_clk_sel(2) = '1') AND
                               (pll0_init_pfd_clk_sel(3) = '0' OR pll0_init_pfd_clk_sel(3) = '1')) ELSE
                             "0000";
                              
pll0_clock_select  <= dprio_reg_to_int(tmp_pll0_clock_select_vec);
pll0_clock_phyport <= pll0_clock_index_to_phyport(pll0_clock_select);
                            
pll0_clock_cram    <= pll_clock_phyport_to_cram(pll0_clock_phyport);

-- switch to physical pll number
pll0_clock_cram_phy <= pll0_clock_cram WHEN (pll0_logical_to_physical_mapping = 0)  ELSE
                       pll1_clock_cram WHEN (pll1_logical_to_physical_mapping = 0) ELSE
                       pll2_clock_cram WHEN (pll2_logical_to_physical_mapping = 0) ELSE
                       pll3_clock_cram WHEN (pll3_logical_to_physical_mapping = 0) ELSE
                       pll4_clock_cram WHEN (pll4_logical_to_physical_mapping = 0) ELSE
                       pll5_clock_cram WHEN (pll5_logical_to_physical_mapping = 0) ELSE
                       pll0_clock_cram;
                            
pll0_csr_riqclk_sel  <= pll0_clock_cram_phy(1 DOWNTO 0); 
pll0_csr_rrefclk_sel <= pll0_clock_cram_phy(4 DOWNTO 3); 

-- DPRIO write - CRAM on physical 
pll0_clock_phyport_out <= convert_pll_clock_cram_to_phyport(pll0_dp_rrefclk_sel, pll0_dp_riqclk_sel);
       -- but the map is on logic channel 
pll0_clock_phyport_out_logic <= pll0_clock_phyport_out WHEN (pll0_logical_to_physical_mapping = 0) ELSE 
                                pll1_clock_phyport_out WHEN (pll0_logical_to_physical_mapping = 1) ELSE
                                pll2_clock_phyport_out WHEN (pll0_logical_to_physical_mapping = 2) ELSE
                                pll3_clock_phyport_out WHEN (pll0_logical_to_physical_mapping = 3) ELSE
                                pll4_clock_phyport_out WHEN (pll0_logical_to_physical_mapping = 4) ELSE
                                pll5_clock_phyport_out WHEN (pll0_logical_to_physical_mapping = 5) ELSE
                                pll0_clock_phyport_out;

pll0_clock_select_out_logic <=  "0000" WHEN (pll0_clock_index_to_phyport(0) = pll0_clock_phyport_out_logic) ELSE 
                                "0001" WHEN (pll0_clock_index_to_phyport(1) = pll0_clock_phyport_out_logic) ELSE 
                                "0010" WHEN (pll0_clock_index_to_phyport(2) = pll0_clock_phyport_out_logic) ELSE 
                                "0011" WHEN (pll0_clock_index_to_phyport(3) = pll0_clock_phyport_out_logic) ELSE 
                                "0100" WHEN (pll0_clock_index_to_phyport(4) = pll0_clock_phyport_out_logic) ELSE 
                                "0101" WHEN (pll0_clock_index_to_phyport(5) = pll0_clock_phyport_out_logic) ELSE 
                                "0110" WHEN (pll0_clock_index_to_phyport(6) = pll0_clock_phyport_out_logic) ELSE 
                                "0111" WHEN (pll0_clock_index_to_phyport(7) = pll0_clock_phyport_out_logic) ELSE 
                                "1000" WHEN (pll0_clock_index_to_phyport(8) = pll0_clock_phyport_out_logic) ELSE 
                                "1001" WHEN (pll0_clock_index_to_phyport(9) = pll0_clock_phyport_out_logic) ELSE 
                                "1111";  -- invalid cram values
       -- back to physical
pll0_clock_select_out <=   pll0_clock_select_out_logic WHEN (pll0_logical_to_physical_mapping = 0) ELSE 
                           pll1_clock_select_out_logic WHEN (pll1_logical_to_physical_mapping = 0) ELSE
                           pll2_clock_select_out_logic WHEN (pll2_logical_to_physical_mapping = 0) ELSE
                           pll3_clock_select_out_logic WHEN (pll3_logical_to_physical_mapping = 0) ELSE
                           pll4_clock_select_out_logic WHEN (pll4_logical_to_physical_mapping = 0) ELSE
                           pll5_clock_select_out_logic WHEN (pll5_logical_to_physical_mapping = 0) ELSE
                           pll0_clock_select_out_logic;
                               
pll0_dp_pfd_clk_sel  <=  pll0_clock_select_out;  


-- DPRIO read - logical pll channel
tmp_pll1_clock_select_vec <= pll1_init_pfd_clk_sel WHEN 
                             ( (pll1_init_pfd_clk_sel(0) = '0' OR pll1_init_pfd_clk_sel(0) = '1') AND
                               (pll1_init_pfd_clk_sel(1) = '0' OR pll1_init_pfd_clk_sel(1) = '1') AND
                               (pll1_init_pfd_clk_sel(2) = '0' OR pll1_init_pfd_clk_sel(2) = '1') AND
                               (pll1_init_pfd_clk_sel(3) = '0' OR pll1_init_pfd_clk_sel(3) = '1')) ELSE
                             "0000";
                              
pll1_clock_select  <= dprio_reg_to_int(tmp_pll1_clock_select_vec);
pll1_clock_phyport <= pll1_clock_index_to_phyport(pll1_clock_select);
                            
pll1_clock_cram    <= pll_clock_phyport_to_cram(pll1_clock_phyport);

-- switch to physical pll number
pll1_clock_cram_phy <= pll0_clock_cram WHEN (pll0_logical_to_physical_mapping = 1) ELSE
                       pll1_clock_cram WHEN (pll1_logical_to_physical_mapping = 1) ELSE
                       pll2_clock_cram WHEN (pll2_logical_to_physical_mapping = 1) ELSE
                       pll3_clock_cram WHEN (pll3_logical_to_physical_mapping = 1) ELSE
                       pll4_clock_cram WHEN (pll4_logical_to_physical_mapping = 1) ELSE
                       pll5_clock_cram WHEN (pll5_logical_to_physical_mapping = 1) ELSE
                       pll1_clock_cram;
                            
pll1_csr_riqclk_sel  <= pll1_clock_cram_phy(1 DOWNTO 0); 
pll1_csr_rrefclk_sel <= pll1_clock_cram_phy(4 DOWNTO 3); 

-- DPRIO write - CRAM on physical 
pll1_clock_phyport_out <= convert_pll_clock_cram_to_phyport(pll1_dp_rrefclk_sel, pll1_dp_riqclk_sel);
       -- but the map is on logic channel 
pll1_clock_phyport_out_logic <= pll0_clock_phyport_out WHEN (pll1_logical_to_physical_mapping = 0) ELSE 
                                pll1_clock_phyport_out WHEN (pll1_logical_to_physical_mapping = 1) ELSE
                                pll2_clock_phyport_out WHEN (pll1_logical_to_physical_mapping = 2) ELSE
                                pll3_clock_phyport_out WHEN (pll1_logical_to_physical_mapping = 3) ELSE
                                pll4_clock_phyport_out WHEN (pll1_logical_to_physical_mapping = 4) ELSE
                                pll5_clock_phyport_out WHEN (pll1_logical_to_physical_mapping = 5) ELSE
                                pll1_clock_phyport_out;

pll1_clock_select_out_logic <=  "0000" WHEN (pll1_clock_index_to_phyport(0) = pll1_clock_phyport_out_logic) ELSE 
                                "0001" WHEN (pll1_clock_index_to_phyport(1) = pll1_clock_phyport_out_logic) ELSE 
                                "0010" WHEN (pll1_clock_index_to_phyport(2) = pll1_clock_phyport_out_logic) ELSE 
                                "0011" WHEN (pll1_clock_index_to_phyport(3) = pll1_clock_phyport_out_logic) ELSE 
                                "0100" WHEN (pll1_clock_index_to_phyport(4) = pll1_clock_phyport_out_logic) ELSE 
                                "0101" WHEN (pll1_clock_index_to_phyport(5) = pll1_clock_phyport_out_logic) ELSE 
                                "0110" WHEN (pll1_clock_index_to_phyport(6) = pll1_clock_phyport_out_logic) ELSE 
                                "0111" WHEN (pll1_clock_index_to_phyport(7) = pll1_clock_phyport_out_logic) ELSE 
                                "1000" WHEN (pll1_clock_index_to_phyport(8) = pll1_clock_phyport_out_logic) ELSE 
                                "1001" WHEN (pll1_clock_index_to_phyport(9) = pll1_clock_phyport_out_logic) ELSE 
                                "1111";  -- invalid cram values
       -- back to physical
pll1_clock_select_out <=   pll0_clock_select_out_logic WHEN (pll0_logical_to_physical_mapping = 1) ELSE 
                           pll1_clock_select_out_logic WHEN (pll1_logical_to_physical_mapping = 1) ELSE
                           pll2_clock_select_out_logic WHEN (pll2_logical_to_physical_mapping = 1) ELSE
                           pll3_clock_select_out_logic WHEN (pll3_logical_to_physical_mapping = 1) ELSE
                           pll4_clock_select_out_logic WHEN (pll4_logical_to_physical_mapping = 1) ELSE
                           pll5_clock_select_out_logic WHEN (pll5_logical_to_physical_mapping = 1) ELSE
                           pll1_clock_select_out_logic;
                               
pll1_dp_pfd_clk_sel  <=  pll1_clock_select_out;  


-- DPRIO read - logical pll channel
tmp_pll2_clock_select_vec <= pll2_init_pfd_clk_sel WHEN 
                             ( (pll2_init_pfd_clk_sel(0) = '0' OR pll2_init_pfd_clk_sel(0) = '1') AND
                               (pll2_init_pfd_clk_sel(1) = '0' OR pll2_init_pfd_clk_sel(1) = '1') AND
                               (pll2_init_pfd_clk_sel(2) = '0' OR pll2_init_pfd_clk_sel(2) = '1') AND
                               (pll2_init_pfd_clk_sel(3) = '0' OR pll2_init_pfd_clk_sel(3) = '1')) ELSE
                             "0000";
                              
pll2_clock_select  <= dprio_reg_to_int(tmp_pll2_clock_select_vec);
pll2_clock_phyport <= pll2_clock_index_to_phyport(pll2_clock_select);
                            
pll2_clock_cram    <= pll_clock_phyport_to_cram(pll2_clock_phyport);

-- switch to physical pll number
pll2_clock_cram_phy <= pll0_clock_cram WHEN (pll0_logical_to_physical_mapping = 2) ELSE
                       pll1_clock_cram WHEN (pll1_logical_to_physical_mapping = 2) ELSE
                       pll2_clock_cram WHEN (pll2_logical_to_physical_mapping = 2) ELSE
                       pll3_clock_cram WHEN (pll3_logical_to_physical_mapping = 2) ELSE
                       pll4_clock_cram WHEN (pll4_logical_to_physical_mapping = 2) ELSE
                       pll5_clock_cram WHEN (pll5_logical_to_physical_mapping = 2) ELSE
                       pll2_clock_cram;
                            
pll2_csr_riqclk_sel  <= pll2_clock_cram_phy(1 DOWNTO 0); 
pll2_csr_rrefclk_sel <= pll2_clock_cram_phy(4 DOWNTO 3); 

-- DPRIO write - CRAM on physical 
pll2_clock_phyport_out <= convert_pll_clock_cram_to_phyport(pll2_dp_rrefclk_sel, pll2_dp_riqclk_sel);
       -- but the map is on logic channel 
pll2_clock_phyport_out_logic <= pll0_clock_phyport_out WHEN (pll2_logical_to_physical_mapping = 0) ELSE 
                                pll1_clock_phyport_out WHEN (pll2_logical_to_physical_mapping = 1) ELSE
                                pll2_clock_phyport_out WHEN (pll2_logical_to_physical_mapping = 2) ELSE
                                pll3_clock_phyport_out WHEN (pll2_logical_to_physical_mapping = 3) ELSE
                                pll4_clock_phyport_out WHEN (pll2_logical_to_physical_mapping = 4) ELSE
                                pll5_clock_phyport_out WHEN (pll2_logical_to_physical_mapping = 5) ELSE
                                pll2_clock_phyport_out;

pll2_clock_select_out_logic <=  "0000" WHEN (pll2_clock_index_to_phyport(0) = pll2_clock_phyport_out_logic) ELSE 
                                "0001" WHEN (pll2_clock_index_to_phyport(1) = pll2_clock_phyport_out_logic) ELSE 
                                "0010" WHEN (pll2_clock_index_to_phyport(2) = pll2_clock_phyport_out_logic) ELSE 
                                "0011" WHEN (pll2_clock_index_to_phyport(3) = pll2_clock_phyport_out_logic) ELSE 
                                "0100" WHEN (pll2_clock_index_to_phyport(4) = pll2_clock_phyport_out_logic) ELSE 
                                "0101" WHEN (pll2_clock_index_to_phyport(5) = pll2_clock_phyport_out_logic) ELSE 
                                "0110" WHEN (pll2_clock_index_to_phyport(6) = pll2_clock_phyport_out_logic) ELSE 
                                "0111" WHEN (pll2_clock_index_to_phyport(7) = pll2_clock_phyport_out_logic) ELSE 
                                "1000" WHEN (pll2_clock_index_to_phyport(8) = pll2_clock_phyport_out_logic) ELSE 
                                "1001" WHEN (pll2_clock_index_to_phyport(9) = pll2_clock_phyport_out_logic) ELSE 
                                "1111";  -- invalid cram values
       -- back to physical
pll2_clock_select_out <=   pll0_clock_select_out_logic WHEN (pll0_logical_to_physical_mapping = 2) ELSE 
                           pll1_clock_select_out_logic WHEN (pll1_logical_to_physical_mapping = 2) ELSE
                           pll2_clock_select_out_logic WHEN (pll2_logical_to_physical_mapping = 2) ELSE
                           pll3_clock_select_out_logic WHEN (pll3_logical_to_physical_mapping = 2) ELSE
                           pll4_clock_select_out_logic WHEN (pll4_logical_to_physical_mapping = 2) ELSE
                           pll5_clock_select_out_logic WHEN (pll5_logical_to_physical_mapping = 2) ELSE
                           pll2_clock_select_out_logic;
                               
pll2_dp_pfd_clk_sel  <=  pll2_clock_select_out;  


-- DPRIO read - logical pll channel
tmp_pll3_clock_select_vec <= pll3_init_pfd_clk_sel WHEN 
                             ( (pll3_init_pfd_clk_sel(0) = '0' OR pll3_init_pfd_clk_sel(0) = '1') AND
                               (pll3_init_pfd_clk_sel(1) = '0' OR pll3_init_pfd_clk_sel(1) = '1') AND
                               (pll3_init_pfd_clk_sel(2) = '0' OR pll3_init_pfd_clk_sel(2) = '1') AND
                               (pll3_init_pfd_clk_sel(3) = '0' OR pll3_init_pfd_clk_sel(3) = '1')) ELSE
                             "0000";
                              
pll3_clock_select  <= dprio_reg_to_int(tmp_pll3_clock_select_vec);
pll3_clock_phyport <= pll3_clock_index_to_phyport(pll3_clock_select);
                            
pll3_clock_cram    <= pll_clock_phyport_to_cram(pll3_clock_phyport);

-- switch to physical pll number
pll3_clock_cram_phy <= pll0_clock_cram WHEN (pll0_logical_to_physical_mapping = 3)  ELSE
                       pll1_clock_cram WHEN (pll1_logical_to_physical_mapping = 3) ELSE
                       pll2_clock_cram WHEN (pll2_logical_to_physical_mapping = 3) ELSE
                       pll3_clock_cram WHEN (pll3_logical_to_physical_mapping = 3) ELSE
                       pll4_clock_cram WHEN (pll4_logical_to_physical_mapping = 3) ELSE
                       pll5_clock_cram WHEN (pll5_logical_to_physical_mapping = 3) ELSE
                       pll3_clock_cram;
                            
pll3_csr_riqclk_sel  <= pll3_clock_cram_phy(1 DOWNTO 0); 
pll3_csr_rrefclk_sel <= pll3_clock_cram_phy(4 DOWNTO 3); 

-- DPRIO write - CRAM on physical 
pll3_clock_phyport_out <= convert_pll_clock_cram_to_phyport(pll3_dp_rrefclk_sel, pll3_dp_riqclk_sel);
       -- but the map is on logic channel 
pll3_clock_phyport_out_logic <= pll0_clock_phyport_out WHEN (pll3_logical_to_physical_mapping = 0) ELSE 
                                pll1_clock_phyport_out WHEN (pll3_logical_to_physical_mapping = 1) ELSE
                                pll2_clock_phyport_out WHEN (pll3_logical_to_physical_mapping = 2) ELSE
                                pll3_clock_phyport_out WHEN (pll3_logical_to_physical_mapping = 3) ELSE
                                pll4_clock_phyport_out WHEN (pll3_logical_to_physical_mapping = 4) ELSE
                                pll5_clock_phyport_out WHEN (pll3_logical_to_physical_mapping = 5) ELSE
                                pll3_clock_phyport_out;

pll3_clock_select_out_logic <=  "0000" WHEN (pll3_clock_index_to_phyport(0) = pll3_clock_phyport_out_logic) ELSE 
                                "0001" WHEN (pll3_clock_index_to_phyport(1) = pll3_clock_phyport_out_logic) ELSE 
                                "0010" WHEN (pll3_clock_index_to_phyport(2) = pll3_clock_phyport_out_logic) ELSE 
                                "0011" WHEN (pll3_clock_index_to_phyport(3) = pll3_clock_phyport_out_logic) ELSE 
                                "0100" WHEN (pll3_clock_index_to_phyport(4) = pll3_clock_phyport_out_logic) ELSE 
                                "0101" WHEN (pll3_clock_index_to_phyport(5) = pll3_clock_phyport_out_logic) ELSE 
                                "0110" WHEN (pll3_clock_index_to_phyport(6) = pll3_clock_phyport_out_logic) ELSE 
                                "0111" WHEN (pll3_clock_index_to_phyport(7) = pll3_clock_phyport_out_logic) ELSE 
                                "1000" WHEN (pll3_clock_index_to_phyport(8) = pll3_clock_phyport_out_logic) ELSE 
                                "1001" WHEN (pll3_clock_index_to_phyport(9) = pll3_clock_phyport_out_logic) ELSE 
                                "1111";  -- invalid cram values
       -- back to physical
pll3_clock_select_out <=   pll0_clock_select_out_logic WHEN (pll0_logical_to_physical_mapping = 3) ELSE 
                           pll1_clock_select_out_logic WHEN (pll1_logical_to_physical_mapping = 3) ELSE
                           pll2_clock_select_out_logic WHEN (pll2_logical_to_physical_mapping = 3) ELSE
                           pll3_clock_select_out_logic WHEN (pll3_logical_to_physical_mapping = 3) ELSE
                           pll4_clock_select_out_logic WHEN (pll4_logical_to_physical_mapping = 3) ELSE
                           pll5_clock_select_out_logic WHEN (pll5_logical_to_physical_mapping = 3) ELSE
                           pll3_clock_select_out_logic;
                               
pll3_dp_pfd_clk_sel  <=  pll3_clock_select_out;  


-- DPRIO read - logical pll channel
tmp_pll4_clock_select_vec <= pll4_init_pfd_clk_sel WHEN 
                             ( (pll4_init_pfd_clk_sel(0) = '0' OR pll4_init_pfd_clk_sel(0) = '1') AND
                               (pll4_init_pfd_clk_sel(1) = '0' OR pll4_init_pfd_clk_sel(1) = '1') AND
                               (pll4_init_pfd_clk_sel(2) = '0' OR pll4_init_pfd_clk_sel(2) = '1') AND
                               (pll4_init_pfd_clk_sel(3) = '0' OR pll4_init_pfd_clk_sel(3) = '1')) ELSE
                             "0000";
                              
pll4_clock_select  <= dprio_reg_to_int(tmp_pll4_clock_select_vec);
pll4_clock_phyport <= pll4_clock_index_to_phyport(pll4_clock_select);
                            
pll4_clock_cram    <= pll_clock_phyport_to_cram(pll4_clock_phyport);

-- switch to physical pll number
pll4_clock_cram_phy <= pll0_clock_cram WHEN (pll0_logical_to_physical_mapping = 4)  ELSE
                       pll1_clock_cram WHEN (pll1_logical_to_physical_mapping = 4) ELSE
                       pll2_clock_cram WHEN (pll2_logical_to_physical_mapping = 4) ELSE
                       pll3_clock_cram WHEN (pll3_logical_to_physical_mapping = 4) ELSE
                       pll4_clock_cram WHEN (pll4_logical_to_physical_mapping = 4) ELSE
                       pll5_clock_cram WHEN (pll5_logical_to_physical_mapping = 4) ELSE
                       pll4_clock_cram;
                            
pll4_csr_riqclk_sel  <= pll4_clock_cram_phy(1 DOWNTO 0); 
pll4_csr_rrefclk_sel <= pll4_clock_cram_phy(4 DOWNTO 3); 

-- DPRIO write - CRAM on physical 
pll4_clock_phyport_out <= convert_pll_clock_cram_to_phyport(pll4_dp_rrefclk_sel, pll4_dp_riqclk_sel);
       -- but the map is on logic channel 
pll4_clock_phyport_out_logic <= pll0_clock_phyport_out WHEN (pll4_logical_to_physical_mapping = 0) ELSE 
                                pll1_clock_phyport_out WHEN (pll4_logical_to_physical_mapping = 1) ELSE
                                pll2_clock_phyport_out WHEN (pll4_logical_to_physical_mapping = 2) ELSE
                                pll3_clock_phyport_out WHEN (pll4_logical_to_physical_mapping = 3) ELSE
                                pll4_clock_phyport_out WHEN (pll4_logical_to_physical_mapping = 4) ELSE
                                pll5_clock_phyport_out WHEN (pll4_logical_to_physical_mapping = 5) ELSE
                                pll4_clock_phyport_out;

pll4_clock_select_out_logic <=  "0000" WHEN (pll4_clock_index_to_phyport(0) = pll4_clock_phyport_out_logic) ELSE 
                                "0001" WHEN (pll4_clock_index_to_phyport(1) = pll4_clock_phyport_out_logic) ELSE 
                                "0010" WHEN (pll4_clock_index_to_phyport(2) = pll4_clock_phyport_out_logic) ELSE 
                                "0011" WHEN (pll4_clock_index_to_phyport(3) = pll4_clock_phyport_out_logic) ELSE 
                                "0100" WHEN (pll4_clock_index_to_phyport(4) = pll4_clock_phyport_out_logic) ELSE 
                                "0101" WHEN (pll4_clock_index_to_phyport(5) = pll4_clock_phyport_out_logic) ELSE 
                                "0110" WHEN (pll4_clock_index_to_phyport(6) = pll4_clock_phyport_out_logic) ELSE 
                                "0111" WHEN (pll4_clock_index_to_phyport(7) = pll4_clock_phyport_out_logic) ELSE 
                                "1000" WHEN (pll4_clock_index_to_phyport(8) = pll4_clock_phyport_out_logic) ELSE 
                                "1001" WHEN (pll4_clock_index_to_phyport(9) = pll4_clock_phyport_out_logic) ELSE 
                                "1111";  -- invalid cram values
       -- back to physical
pll4_clock_select_out <=   pll0_clock_select_out_logic WHEN (pll0_logical_to_physical_mapping = 4) ELSE 
                           pll1_clock_select_out_logic WHEN (pll1_logical_to_physical_mapping = 4) ELSE
                           pll2_clock_select_out_logic WHEN (pll2_logical_to_physical_mapping = 4) ELSE
                           pll3_clock_select_out_logic WHEN (pll3_logical_to_physical_mapping = 4) ELSE
                           pll4_clock_select_out_logic WHEN (pll4_logical_to_physical_mapping = 4) ELSE
                           pll5_clock_select_out_logic WHEN (pll5_logical_to_physical_mapping = 4) ELSE
                           pll4_clock_select_out_logic;
                               
pll4_dp_pfd_clk_sel  <=  pll4_clock_select_out;  


-- DPRIO read - logical pll channel
tmp_pll5_clock_select_vec <= pll5_init_pfd_clk_sel WHEN 
                             ( (pll5_init_pfd_clk_sel(0) = '0' OR pll5_init_pfd_clk_sel(0) = '1') AND
                               (pll5_init_pfd_clk_sel(1) = '0' OR pll5_init_pfd_clk_sel(1) = '1') AND
                               (pll5_init_pfd_clk_sel(2) = '0' OR pll5_init_pfd_clk_sel(2) = '1') AND
                               (pll5_init_pfd_clk_sel(3) = '0' OR pll5_init_pfd_clk_sel(3) = '1')) ELSE
                             "0000";
                              
pll5_clock_select  <= dprio_reg_to_int(tmp_pll5_clock_select_vec);
pll5_clock_phyport <= pll5_clock_index_to_phyport(pll5_clock_select);
                            
pll5_clock_cram    <= pll_clock_phyport_to_cram(pll5_clock_phyport);

-- switch to physical pll number
pll5_clock_cram_phy <= pll0_clock_cram WHEN (pll0_logical_to_physical_mapping = 5) ELSE
                       pll1_clock_cram WHEN (pll1_logical_to_physical_mapping = 5) ELSE
                       pll2_clock_cram WHEN (pll2_logical_to_physical_mapping = 5) ELSE
                       pll3_clock_cram WHEN (pll3_logical_to_physical_mapping = 5) ELSE
                       pll4_clock_cram WHEN (pll4_logical_to_physical_mapping = 5) ELSE
                       pll5_clock_cram WHEN (pll5_logical_to_physical_mapping = 5) ELSE
                       pll5_clock_cram;
                            
pll5_csr_riqclk_sel  <= pll5_clock_cram_phy(1 DOWNTO 0); 
pll5_csr_rrefclk_sel <= pll5_clock_cram_phy(4 DOWNTO 3); 

-- DPRIO write - CRAM on physical 
pll5_clock_phyport_out <= convert_pll_clock_cram_to_phyport(pll5_dp_rrefclk_sel, pll5_dp_riqclk_sel);
       -- but the map is on logic channel 
pll5_clock_phyport_out_logic <= pll0_clock_phyport_out WHEN (pll5_logical_to_physical_mapping = 0) ELSE 
                                pll1_clock_phyport_out WHEN (pll5_logical_to_physical_mapping = 1) ELSE
                                pll2_clock_phyport_out WHEN (pll5_logical_to_physical_mapping = 2) ELSE
                                pll3_clock_phyport_out WHEN (pll5_logical_to_physical_mapping = 3) ELSE
                                pll4_clock_phyport_out WHEN (pll5_logical_to_physical_mapping = 4) ELSE
                                pll5_clock_phyport_out WHEN (pll5_logical_to_physical_mapping = 5) ELSE
                                pll5_clock_phyport_out;

pll5_clock_select_out_logic <=  "0000" WHEN (pll5_clock_index_to_phyport(0) = pll5_clock_phyport_out_logic) ELSE 
                                "0001" WHEN (pll5_clock_index_to_phyport(1) = pll5_clock_phyport_out_logic) ELSE 
                                "0010" WHEN (pll5_clock_index_to_phyport(2) = pll5_clock_phyport_out_logic) ELSE 
                                "0011" WHEN (pll5_clock_index_to_phyport(3) = pll5_clock_phyport_out_logic) ELSE 
                                "0100" WHEN (pll5_clock_index_to_phyport(4) = pll5_clock_phyport_out_logic) ELSE 
                                "0101" WHEN (pll5_clock_index_to_phyport(5) = pll5_clock_phyport_out_logic) ELSE 
                                "0110" WHEN (pll5_clock_index_to_phyport(6) = pll5_clock_phyport_out_logic) ELSE 
                                "0111" WHEN (pll5_clock_index_to_phyport(7) = pll5_clock_phyport_out_logic) ELSE 
                                "1000" WHEN (pll5_clock_index_to_phyport(8) = pll5_clock_phyport_out_logic) ELSE 
                                "1001" WHEN (pll5_clock_index_to_phyport(9) = pll5_clock_phyport_out_logic) ELSE 
                                "1111";  -- invalid cram values
       -- back to physical
pll5_clock_select_out <=   pll0_clock_select_out_logic WHEN (pll0_logical_to_physical_mapping = 5) ELSE 
                           pll1_clock_select_out_logic WHEN (pll1_logical_to_physical_mapping = 5) ELSE
                           pll2_clock_select_out_logic WHEN (pll2_logical_to_physical_mapping = 5) ELSE
                           pll3_clock_select_out_logic WHEN (pll3_logical_to_physical_mapping = 5) ELSE
                           pll4_clock_select_out_logic WHEN (pll4_logical_to_physical_mapping = 5) ELSE
                           pll5_clock_select_out_logic WHEN (pll5_logical_to_physical_mapping = 5) ELSE
                           pll5_clock_select_out_logic;
                               
pll5_dp_pfd_clk_sel  <=  pll5_clock_select_out;  



---------------------------------------------------------------------------
-- TXPMA clock selection --------------------------------------------------  
---------------------------------------------------------------------------

PROCESS  -- initialize the TABLE
  VARIABLE init_table                : STD_LOGIC := '1';  
  VARIABLE tmp_int                   : INTEGER := 0; 
        
  BEGIN
  IF (init_table = '1') THEN
    txpma_clock_phyport_to_cram(TXPMA_CLKIN_SELECT_X1)        <= "00";
    txpma_clock_phyport_to_cram(TXPMA_CLKIN_SELECT_X4)        <= "01";
    txpma_clock_phyport_to_cram(TXPMA_CLKIN_SELECT_XN_TOP)    <= "10";
    txpma_clock_phyport_to_cram(TXPMA_CLKIN_SELECT_XN_BOTTOM) <= "11";
    txpma_clock_phyport_to_cram(TXPMA_CLKIN_SELECT_HT)        <= "00";
    txpma_clock_phyport_to_cram(TXPMA_CLKIN_SELECT_ERR)       <= "11";    

    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx0_pma_inclk0_logical_to_physical_mapping);
    txpma0_clock_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx0_pma_inclk1_logical_to_physical_mapping);
    txpma0_clock_index_to_phyport(1) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx0_pma_inclk2_logical_to_physical_mapping);
    txpma0_clock_index_to_phyport(2) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx0_pma_inclk3_logical_to_physical_mapping);
    txpma0_clock_index_to_phyport(3) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx0_pma_inclk4_logical_to_physical_mapping);
    txpma0_clock_index_to_phyport(4) <= tmp_int;
     
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx1_pma_inclk0_logical_to_physical_mapping);
    txpma1_clock_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx1_pma_inclk1_logical_to_physical_mapping);
    txpma1_clock_index_to_phyport(1) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx1_pma_inclk2_logical_to_physical_mapping);
    txpma1_clock_index_to_phyport(2) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx1_pma_inclk3_logical_to_physical_mapping);
    txpma1_clock_index_to_phyport(3) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx1_pma_inclk4_logical_to_physical_mapping);
    txpma1_clock_index_to_phyport(4) <= tmp_int;

    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx2_pma_inclk0_logical_to_physical_mapping);
    txpma2_clock_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx2_pma_inclk1_logical_to_physical_mapping);
    txpma2_clock_index_to_phyport(1) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx2_pma_inclk2_logical_to_physical_mapping);
    txpma2_clock_index_to_phyport(2) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx2_pma_inclk3_logical_to_physical_mapping);
    txpma2_clock_index_to_phyport(3) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx2_pma_inclk4_logical_to_physical_mapping);
    txpma2_clock_index_to_phyport(4) <= tmp_int;

    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx3_pma_inclk0_logical_to_physical_mapping);
    txpma3_clock_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx3_pma_inclk1_logical_to_physical_mapping);
    txpma3_clock_index_to_phyport(1) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx3_pma_inclk2_logical_to_physical_mapping);
    txpma3_clock_index_to_phyport(2) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx3_pma_inclk3_logical_to_physical_mapping);
    txpma3_clock_index_to_phyport(3) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx3_pma_inclk4_logical_to_physical_mapping);
    txpma3_clock_index_to_phyport(4) <= tmp_int;

    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx4_pma_inclk0_logical_to_physical_mapping);
    txpma4_clock_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx4_pma_inclk1_logical_to_physical_mapping);
    txpma4_clock_index_to_phyport(1) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx4_pma_inclk2_logical_to_physical_mapping);
    txpma4_clock_index_to_phyport(2) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx4_pma_inclk3_logical_to_physical_mapping);
    txpma4_clock_index_to_phyport(3) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx4_pma_inclk4_logical_to_physical_mapping);
    txpma4_clock_index_to_phyport(4) <= tmp_int;

    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx5_pma_inclk0_logical_to_physical_mapping);
    txpma5_clock_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx5_pma_inclk1_logical_to_physical_mapping);
    txpma5_clock_index_to_phyport(1) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx5_pma_inclk2_logical_to_physical_mapping);
    txpma5_clock_index_to_phyport(2) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx5_pma_inclk3_logical_to_physical_mapping);
    txpma5_clock_index_to_phyport(3) <= tmp_int;
    tmp_int := convert_txpma_phyport_str_to_phyport_enum(tx5_pma_inclk4_logical_to_physical_mapping);
    txpma5_clock_index_to_phyport(4) <= tmp_int;
    init_table := '0';
   END IF;
    
   WAIT; 
END PROCESS;  -- end of initializing tables
    
-- DPRIO read - physical pll channel
tmp_txpma0_clock_select_vec <= txpma0_init_clkin_sel WHEN 
                               ( (txpma0_init_clkin_sel(0) = '0' OR txpma0_init_clkin_sel(0) = '1') AND
                                 (txpma0_init_clkin_sel(1) = '0' OR txpma0_init_clkin_sel(1) = '1') AND
                                 (txpma0_init_clkin_sel(2) = '0' OR txpma0_init_clkin_sel(2) = '1') ) ELSE
                                "000";
                               
txpma0_clock_select  <= dprio_reg_to_int(tmp_txpma0_clock_select_vec);

txpma0_clock_phyport <= txpma0_clock_index_to_phyport(txpma0_clock_select);
txpma0_clock_cram    <= txpma_clock_phyport_to_cram(0) WHEN (txpma0_clock_phyport = 0) ELSE
                        txpma_clock_phyport_to_cram(1) WHEN (txpma0_clock_phyport = 1) ELSE
                        txpma_clock_phyport_to_cram(2) WHEN (txpma0_clock_phyport = 2) ELSE
                        txpma_clock_phyport_to_cram(3) WHEN (txpma0_clock_phyport = 3) ELSE
                        txpma_clock_phyport_to_cram(4) WHEN (txpma0_clock_phyport = 4) ELSE
                        txpma_clock_phyport_to_cram(7) WHEN (txpma0_clock_phyport = 7)ELSE
                        txpma_clock_phyport_to_cram(0);

txpma0_clock_cram_phy <= txpma0_clock_cram WHEN (tx0_logical_to_physical_mapping = 0) ELSE
                         txpma1_clock_cram WHEN (tx1_logical_to_physical_mapping = 0) ELSE
                         txpma2_clock_cram WHEN (tx2_logical_to_physical_mapping = 0) ELSE
                         txpma3_clock_cram WHEN (tx3_logical_to_physical_mapping = 0) ELSE
                         txpma4_clock_cram WHEN (tx4_logical_to_physical_mapping = 0) ELSE
                         txpma5_clock_cram WHEN (tx5_logical_to_physical_mapping = 0) ELSE
                         txpma0_clock_cram;
txpma0_csr_rcgb_x_en <= txpma0_clock_cram_phy; 

-- DPRIO write - CRAM on physical 
txpma0_clock_phyport_out <= convert_txpma_clock_cram_to_phyport(txpma0_dp_rcgb_x_en);
       -- but the map is on logic channel 
txpma0_clock_phyport_out_logic <= txpma0_clock_phyport_out WHEN (tx0_logical_to_physical_mapping = 0) ELSE
                                  txpma1_clock_phyport_out WHEN (tx0_logical_to_physical_mapping = 1) ELSE
                                  txpma2_clock_phyport_out WHEN (tx0_logical_to_physical_mapping = 2) ELSE
                                  txpma3_clock_phyport_out WHEN (tx0_logical_to_physical_mapping = 3) ELSE
                                  txpma4_clock_phyport_out WHEN (tx0_logical_to_physical_mapping = 4) ELSE
                                  txpma5_clock_phyport_out WHEN (tx0_logical_to_physical_mapping = 5) ELSE
                                  txpma0_clock_phyport_out;

txpma0_clock_select_out_logic <=  "000" WHEN (txpma0_clock_index_to_phyport(0) = txpma0_clock_phyport_out_logic) ELSE
                                  "001" WHEN (txpma0_clock_index_to_phyport(1) = txpma0_clock_phyport_out_logic) ELSE
                                  "010" WHEN (txpma0_clock_index_to_phyport(2) = txpma0_clock_phyport_out_logic) ELSE
                                  "011" WHEN (txpma0_clock_index_to_phyport(3) = txpma0_clock_phyport_out_logic) ELSE
                                  "100" WHEN (txpma0_clock_index_to_phyport(4) = txpma0_clock_phyport_out_logic) ELSE
                                  "111";  -- invalid cram values
       -- back to physical
txpma0_clock_select_out <= txpma0_clock_select_out_logic WHEN (tx0_logical_to_physical_mapping = 0) ELSE
                           txpma1_clock_select_out_logic WHEN (tx1_logical_to_physical_mapping = 0) ELSE
                           txpma2_clock_select_out_logic WHEN (tx2_logical_to_physical_mapping = 0) ELSE
                           txpma3_clock_select_out_logic WHEN (tx3_logical_to_physical_mapping = 0) ELSE
                           txpma4_clock_select_out_logic WHEN (tx4_logical_to_physical_mapping = 0) ELSE
                           txpma5_clock_select_out_logic WHEN (tx5_logical_to_physical_mapping = 0) ELSE
                           txpma0_clock_select_out_logic;
                               
txpma0_dp_clkin_sel  <=  txpma0_clock_select_out;  
                                                                 
    
-- DPRIO read - physical pll channel
tmp_txpma1_clock_select_vec <= txpma1_init_clkin_sel WHEN 
                               ( (txpma1_init_clkin_sel(0) = '0' OR txpma1_init_clkin_sel(0) = '1') AND
                                 (txpma1_init_clkin_sel(1) = '0' OR txpma1_init_clkin_sel(1) = '1') AND
                                 (txpma1_init_clkin_sel(2) = '0' OR txpma1_init_clkin_sel(2) = '1') ) ELSE
                                "000";
                               
txpma1_clock_select  <= dprio_reg_to_int(tmp_txpma1_clock_select_vec);

txpma1_clock_phyport <= txpma1_clock_index_to_phyport(txpma1_clock_select);
txpma1_clock_cram    <= txpma_clock_phyport_to_cram(0) WHEN (txpma1_clock_phyport = 0) ELSE
                        txpma_clock_phyport_to_cram(1) WHEN (txpma1_clock_phyport = 1) ELSE
                        txpma_clock_phyport_to_cram(2) WHEN (txpma1_clock_phyport = 2) ELSE
                        txpma_clock_phyport_to_cram(3) WHEN (txpma1_clock_phyport = 3) ELSE
                        txpma_clock_phyport_to_cram(4) WHEN (txpma1_clock_phyport = 4) ELSE
                        txpma_clock_phyport_to_cram(7) WHEN (txpma1_clock_phyport = 7)ELSE
                        txpma_clock_phyport_to_cram(0);

txpma1_clock_cram_phy <= txpma0_clock_cram WHEN (tx0_logical_to_physical_mapping = 1) ELSE
                         txpma1_clock_cram WHEN (tx1_logical_to_physical_mapping = 1) ELSE
                         txpma2_clock_cram WHEN (tx2_logical_to_physical_mapping = 1) ELSE
                         txpma3_clock_cram WHEN (tx3_logical_to_physical_mapping = 1) ELSE
                         txpma4_clock_cram WHEN (tx4_logical_to_physical_mapping = 1) ELSE
                         txpma5_clock_cram WHEN (tx5_logical_to_physical_mapping = 1) ELSE
                         txpma0_clock_cram;
txpma1_csr_rcgb_x_en <= txpma1_clock_cram_phy; 

-- DPRIO write - CRAM on physical 
txpma1_clock_phyport_out <= convert_txpma_clock_cram_to_phyport(txpma1_dp_rcgb_x_en);
       -- but the map is on logic channel 
txpma1_clock_phyport_out_logic <= txpma0_clock_phyport_out WHEN (tx1_logical_to_physical_mapping = 0) ELSE
                                  txpma1_clock_phyport_out WHEN (tx1_logical_to_physical_mapping = 1) ELSE
                                  txpma2_clock_phyport_out WHEN (tx1_logical_to_physical_mapping = 2) ELSE
                                  txpma3_clock_phyport_out WHEN (tx1_logical_to_physical_mapping = 3) ELSE
                                  txpma4_clock_phyport_out WHEN (tx1_logical_to_physical_mapping = 4) ELSE
                                  txpma5_clock_phyport_out WHEN (tx1_logical_to_physical_mapping = 5) ELSE
                                  txpma0_clock_phyport_out;

txpma1_clock_select_out_logic <=  "000" WHEN (txpma1_clock_index_to_phyport(0) = txpma1_clock_phyport_out_logic) ELSE
                                  "001" WHEN (txpma1_clock_index_to_phyport(1) = txpma1_clock_phyport_out_logic) ELSE
                                  "010" WHEN (txpma1_clock_index_to_phyport(2) = txpma1_clock_phyport_out_logic) ELSE
                                  "011" WHEN (txpma1_clock_index_to_phyport(3) = txpma1_clock_phyport_out_logic) ELSE
                                  "100" WHEN (txpma1_clock_index_to_phyport(4) = txpma1_clock_phyport_out_logic) ELSE
                                  "111";  -- invalid cram values
       -- back to physical
txpma1_clock_select_out <= txpma0_clock_select_out_logic WHEN (tx0_logical_to_physical_mapping = 1) ELSE
                           txpma1_clock_select_out_logic WHEN (tx1_logical_to_physical_mapping = 1) ELSE
                           txpma2_clock_select_out_logic WHEN (tx2_logical_to_physical_mapping = 1) ELSE
                           txpma3_clock_select_out_logic WHEN (tx3_logical_to_physical_mapping = 1) ELSE
                           txpma4_clock_select_out_logic WHEN (tx4_logical_to_physical_mapping = 1) ELSE
                           txpma5_clock_select_out_logic WHEN (tx5_logical_to_physical_mapping = 1) ELSE
                           txpma0_clock_select_out_logic;
                               
txpma1_dp_clkin_sel  <=  txpma1_clock_select_out;  
                                                                          
    
-- DPRIO read - physical pll channel
tmp_txpma2_clock_select_vec <= txpma2_init_clkin_sel WHEN 
                               ( (txpma2_init_clkin_sel(0) = '0' OR txpma2_init_clkin_sel(0) = '1') AND
                                 (txpma2_init_clkin_sel(1) = '0' OR txpma2_init_clkin_sel(1) = '1') AND
                                 (txpma2_init_clkin_sel(2) = '0' OR txpma2_init_clkin_sel(2) = '1') ) ELSE
                                "000";
                               
txpma2_clock_select  <= dprio_reg_to_int(tmp_txpma2_clock_select_vec);

txpma2_clock_phyport <= txpma2_clock_index_to_phyport(txpma2_clock_select);
txpma2_clock_cram    <= txpma_clock_phyport_to_cram(0) WHEN (txpma2_clock_phyport = 0) ELSE
                        txpma_clock_phyport_to_cram(1) WHEN (txpma2_clock_phyport = 1) ELSE
                        txpma_clock_phyport_to_cram(2) WHEN (txpma2_clock_phyport = 2) ELSE
                        txpma_clock_phyport_to_cram(3) WHEN (txpma2_clock_phyport = 3) ELSE
                        txpma_clock_phyport_to_cram(4) WHEN (txpma2_clock_phyport = 4) ELSE
                        txpma_clock_phyport_to_cram(7) WHEN (txpma2_clock_phyport = 7)ELSE
                        txpma_clock_phyport_to_cram(0);

txpma2_clock_cram_phy <= txpma0_clock_cram WHEN (tx0_logical_to_physical_mapping = 2) ELSE
                         txpma1_clock_cram WHEN (tx1_logical_to_physical_mapping = 2) ELSE
                         txpma2_clock_cram WHEN (tx2_logical_to_physical_mapping = 2) ELSE
                         txpma3_clock_cram WHEN (tx3_logical_to_physical_mapping = 2) ELSE
                         txpma4_clock_cram WHEN (tx4_logical_to_physical_mapping = 2) ELSE
                         txpma5_clock_cram WHEN (tx5_logical_to_physical_mapping = 2) ELSE
                         txpma2_clock_cram;
txpma2_csr_rcgb_x_en <= txpma2_clock_cram_phy; 

-- DPRIO write - CRAM on physical 
txpma2_clock_phyport_out <= convert_txpma_clock_cram_to_phyport(txpma2_dp_rcgb_x_en);
       -- but the map is on logic channel 
txpma2_clock_phyport_out_logic <= txpma0_clock_phyport_out WHEN (tx2_logical_to_physical_mapping = 0) ELSE
                                  txpma1_clock_phyport_out WHEN (tx2_logical_to_physical_mapping = 1) ELSE
                                  txpma2_clock_phyport_out WHEN (tx2_logical_to_physical_mapping = 2) ELSE
                                  txpma3_clock_phyport_out WHEN (tx2_logical_to_physical_mapping = 3) ELSE
                                  txpma4_clock_phyport_out WHEN (tx2_logical_to_physical_mapping = 4) ELSE
                                  txpma5_clock_phyport_out WHEN (tx2_logical_to_physical_mapping = 5) ELSE
                                  txpma2_clock_phyport_out;

txpma2_clock_select_out_logic <=  "000" WHEN (txpma2_clock_index_to_phyport(0) = txpma2_clock_phyport_out_logic) ELSE
                                  "001" WHEN (txpma2_clock_index_to_phyport(1) = txpma2_clock_phyport_out_logic) ELSE
                                  "010" WHEN (txpma2_clock_index_to_phyport(2) = txpma2_clock_phyport_out_logic) ELSE
                                  "011" WHEN (txpma2_clock_index_to_phyport(3) = txpma2_clock_phyport_out_logic) ELSE
                                  "100" WHEN (txpma2_clock_index_to_phyport(4) = txpma2_clock_phyport_out_logic) ELSE
                                  "111";  -- invalid cram values
       -- back to physical
txpma2_clock_select_out <= txpma0_clock_select_out_logic WHEN (tx0_logical_to_physical_mapping = 2) ELSE
                           txpma1_clock_select_out_logic WHEN (tx1_logical_to_physical_mapping = 2) ELSE
                           txpma2_clock_select_out_logic WHEN (tx2_logical_to_physical_mapping = 2) ELSE
                           txpma3_clock_select_out_logic WHEN (tx3_logical_to_physical_mapping = 2) ELSE
                           txpma4_clock_select_out_logic WHEN (tx4_logical_to_physical_mapping = 2) ELSE
                           txpma5_clock_select_out_logic WHEN (tx5_logical_to_physical_mapping = 2) ELSE
                           txpma2_clock_select_out_logic;
                               
txpma2_dp_clkin_sel  <=  txpma2_clock_select_out;  

    
-- DPRIO read - physical pll channel
tmp_txpma3_clock_select_vec <= txpma3_init_clkin_sel WHEN 
                               ( (txpma3_init_clkin_sel(0) = '0' OR txpma3_init_clkin_sel(0) = '1') AND
                                 (txpma3_init_clkin_sel(1) = '0' OR txpma3_init_clkin_sel(1) = '1') AND
                                 (txpma3_init_clkin_sel(2) = '0' OR txpma3_init_clkin_sel(2) = '1') ) ELSE
                                "000";
                               
txpma3_clock_select  <= dprio_reg_to_int(tmp_txpma3_clock_select_vec);

txpma3_clock_phyport <= txpma3_clock_index_to_phyport(txpma3_clock_select);
txpma3_clock_cram    <= txpma_clock_phyport_to_cram(0) WHEN (txpma3_clock_phyport = 0) ELSE
                        txpma_clock_phyport_to_cram(1) WHEN (txpma3_clock_phyport = 1) ELSE
                        txpma_clock_phyport_to_cram(2) WHEN (txpma3_clock_phyport = 2) ELSE
                        txpma_clock_phyport_to_cram(3) WHEN (txpma3_clock_phyport = 3) ELSE
                        txpma_clock_phyport_to_cram(4) WHEN (txpma3_clock_phyport = 4) ELSE
                        txpma_clock_phyport_to_cram(7) WHEN (txpma3_clock_phyport = 7)ELSE
                        txpma_clock_phyport_to_cram(0);

txpma3_clock_cram_phy <= txpma0_clock_cram WHEN (tx0_logical_to_physical_mapping = 3) ELSE
                         txpma1_clock_cram WHEN (tx1_logical_to_physical_mapping = 3) ELSE
                         txpma2_clock_cram WHEN (tx2_logical_to_physical_mapping = 3) ELSE
                         txpma3_clock_cram WHEN (tx3_logical_to_physical_mapping = 3) ELSE
                         txpma4_clock_cram WHEN (tx4_logical_to_physical_mapping = 3) ELSE
                         txpma5_clock_cram WHEN (tx5_logical_to_physical_mapping = 3) ELSE
                         txpma3_clock_cram;
txpma3_csr_rcgb_x_en <= txpma3_clock_cram_phy; 

-- DPRIO write - CRAM on physical 
txpma3_clock_phyport_out <= convert_txpma_clock_cram_to_phyport(txpma3_dp_rcgb_x_en);
       -- but the map is on logic channel 
txpma3_clock_phyport_out_logic <= txpma0_clock_phyport_out WHEN (tx3_logical_to_physical_mapping = 0) ELSE
                                  txpma1_clock_phyport_out WHEN (tx3_logical_to_physical_mapping = 1) ELSE
                                  txpma2_clock_phyport_out WHEN (tx3_logical_to_physical_mapping = 2) ELSE
                                  txpma3_clock_phyport_out WHEN (tx3_logical_to_physical_mapping = 3) ELSE
                                  txpma4_clock_phyport_out WHEN (tx3_logical_to_physical_mapping = 4) ELSE
                                  txpma5_clock_phyport_out WHEN (tx3_logical_to_physical_mapping = 5) ELSE
                                  txpma3_clock_phyport_out;

txpma3_clock_select_out_logic <=  "000" WHEN (txpma3_clock_index_to_phyport(0) = txpma3_clock_phyport_out_logic) ELSE
                                  "001" WHEN (txpma3_clock_index_to_phyport(1) = txpma3_clock_phyport_out_logic) ELSE
                                  "010" WHEN (txpma3_clock_index_to_phyport(2) = txpma3_clock_phyport_out_logic) ELSE
                                  "011" WHEN (txpma3_clock_index_to_phyport(3) = txpma3_clock_phyport_out_logic) ELSE
                                  "100" WHEN (txpma3_clock_index_to_phyport(4) = txpma3_clock_phyport_out_logic) ELSE
                                  "111";  -- invalid cram values
       -- back to physical
txpma3_clock_select_out <= txpma0_clock_select_out_logic WHEN (tx0_logical_to_physical_mapping = 3) ELSE
                           txpma1_clock_select_out_logic WHEN (tx1_logical_to_physical_mapping = 3) ELSE
                           txpma2_clock_select_out_logic WHEN (tx2_logical_to_physical_mapping = 3) ELSE
                           txpma3_clock_select_out_logic WHEN (tx3_logical_to_physical_mapping = 3) ELSE
                           txpma4_clock_select_out_logic WHEN (tx4_logical_to_physical_mapping = 3) ELSE
                           txpma5_clock_select_out_logic WHEN (tx5_logical_to_physical_mapping = 3) ELSE
                           txpma3_clock_select_out_logic;
                               
txpma3_dp_clkin_sel  <=  txpma3_clock_select_out;  
                                                                 
    
-- DPRIO read - physical pll channel
tmp_txpma4_clock_select_vec <= txpma4_init_clkin_sel WHEN 
                               ( (txpma4_init_clkin_sel(0) = '0' OR txpma4_init_clkin_sel(0) = '1') AND
                                 (txpma4_init_clkin_sel(1) = '0' OR txpma4_init_clkin_sel(1) = '1') AND
                                 (txpma4_init_clkin_sel(2) = '0' OR txpma4_init_clkin_sel(2) = '1') ) ELSE
                                "000";
                               
txpma4_clock_select  <= dprio_reg_to_int(tmp_txpma4_clock_select_vec);

txpma4_clock_phyport <= txpma4_clock_index_to_phyport(txpma4_clock_select);
txpma4_clock_cram    <= txpma_clock_phyport_to_cram(0) WHEN (txpma4_clock_phyport = 0) ELSE
                        txpma_clock_phyport_to_cram(1) WHEN (txpma4_clock_phyport = 1) ELSE
                        txpma_clock_phyport_to_cram(2) WHEN (txpma4_clock_phyport = 2) ELSE
                        txpma_clock_phyport_to_cram(3) WHEN (txpma4_clock_phyport = 3) ELSE
                        txpma_clock_phyport_to_cram(4) WHEN (txpma4_clock_phyport = 4) ELSE
                        txpma_clock_phyport_to_cram(7) WHEN (txpma4_clock_phyport = 7)ELSE
                        txpma_clock_phyport_to_cram(0);

txpma4_clock_cram_phy <= txpma0_clock_cram WHEN (tx0_logical_to_physical_mapping = 4) ELSE
                         txpma1_clock_cram WHEN (tx1_logical_to_physical_mapping = 4) ELSE
                         txpma2_clock_cram WHEN (tx2_logical_to_physical_mapping = 4) ELSE
                         txpma3_clock_cram WHEN (tx3_logical_to_physical_mapping = 4) ELSE
                         txpma4_clock_cram WHEN (tx4_logical_to_physical_mapping = 4) ELSE
                         txpma5_clock_cram WHEN (tx5_logical_to_physical_mapping = 4) ELSE
                         txpma4_clock_cram;
txpma4_csr_rcgb_x_en <= txpma4_clock_cram_phy; 

-- DPRIO write - CRAM on physical 
txpma4_clock_phyport_out <= convert_txpma_clock_cram_to_phyport(txpma4_dp_rcgb_x_en);
       -- but the map is on logic channel 
txpma4_clock_phyport_out_logic <= txpma0_clock_phyport_out WHEN (tx4_logical_to_physical_mapping = 0) ELSE
                                  txpma1_clock_phyport_out WHEN (tx4_logical_to_physical_mapping = 1) ELSE
                                  txpma2_clock_phyport_out WHEN (tx4_logical_to_physical_mapping = 2) ELSE
                                  txpma3_clock_phyport_out WHEN (tx4_logical_to_physical_mapping = 3) ELSE
                                  txpma4_clock_phyport_out WHEN (tx4_logical_to_physical_mapping = 4) ELSE
                                  txpma5_clock_phyport_out WHEN (tx4_logical_to_physical_mapping = 5) ELSE
                                  txpma4_clock_phyport_out;

txpma4_clock_select_out_logic <=  "000" WHEN (txpma4_clock_index_to_phyport(0) = txpma4_clock_phyport_out_logic) ELSE
                                  "001" WHEN (txpma4_clock_index_to_phyport(1) = txpma4_clock_phyport_out_logic) ELSE
                                  "010" WHEN (txpma4_clock_index_to_phyport(2) = txpma4_clock_phyport_out_logic) ELSE
                                  "011" WHEN (txpma4_clock_index_to_phyport(3) = txpma4_clock_phyport_out_logic) ELSE
                                  "100" WHEN (txpma4_clock_index_to_phyport(4) = txpma4_clock_phyport_out_logic) ELSE
                                  "111";  -- invalid cram values
       -- back to physical
txpma4_clock_select_out <= txpma0_clock_select_out_logic WHEN (tx0_logical_to_physical_mapping = 4) ELSE
                           txpma1_clock_select_out_logic WHEN (tx1_logical_to_physical_mapping = 4) ELSE
                           txpma2_clock_select_out_logic WHEN (tx2_logical_to_physical_mapping = 4) ELSE
                           txpma3_clock_select_out_logic WHEN (tx3_logical_to_physical_mapping = 4) ELSE
                           txpma4_clock_select_out_logic WHEN (tx4_logical_to_physical_mapping = 4) ELSE
                           txpma5_clock_select_out_logic WHEN (tx5_logical_to_physical_mapping = 4) ELSE
                           txpma4_clock_select_out_logic;
                               
txpma4_dp_clkin_sel  <=  txpma4_clock_select_out;  

    
-- DPRIO read - physical pll channel
tmp_txpma5_clock_select_vec <= txpma5_init_clkin_sel WHEN 
                               ( (txpma5_init_clkin_sel(0) = '0' OR txpma5_init_clkin_sel(0) = '1') AND
                                 (txpma5_init_clkin_sel(1) = '0' OR txpma5_init_clkin_sel(1) = '1') AND
                                 (txpma5_init_clkin_sel(2) = '0' OR txpma5_init_clkin_sel(2) = '1') ) ELSE
                                "000";
                               
txpma5_clock_select  <= dprio_reg_to_int(tmp_txpma5_clock_select_vec);

txpma5_clock_phyport <= txpma5_clock_index_to_phyport(txpma5_clock_select);
txpma5_clock_cram    <= txpma_clock_phyport_to_cram(0) WHEN (txpma5_clock_phyport = 0) ELSE
                        txpma_clock_phyport_to_cram(1) WHEN (txpma5_clock_phyport = 1) ELSE
                        txpma_clock_phyport_to_cram(2) WHEN (txpma5_clock_phyport = 2) ELSE
                        txpma_clock_phyport_to_cram(3) WHEN (txpma5_clock_phyport = 3) ELSE
                        txpma_clock_phyport_to_cram(4) WHEN (txpma5_clock_phyport = 4) ELSE
                        txpma_clock_phyport_to_cram(7) WHEN (txpma5_clock_phyport = 7)ELSE
                        txpma_clock_phyport_to_cram(0);

txpma5_clock_cram_phy <= txpma0_clock_cram WHEN (tx0_logical_to_physical_mapping = 5) ELSE
                         txpma1_clock_cram WHEN (tx1_logical_to_physical_mapping = 5) ELSE
                         txpma2_clock_cram WHEN (tx2_logical_to_physical_mapping = 5) ELSE
                         txpma3_clock_cram WHEN (tx3_logical_to_physical_mapping = 5) ELSE
                         txpma4_clock_cram WHEN (tx4_logical_to_physical_mapping = 5) ELSE
                         txpma5_clock_cram WHEN (tx5_logical_to_physical_mapping = 5) ELSE
                         txpma5_clock_cram;
txpma5_csr_rcgb_x_en <= txpma5_clock_cram_phy; 

-- DPRIO write - CRAM on physical 
txpma5_clock_phyport_out <= convert_txpma_clock_cram_to_phyport(txpma5_dp_rcgb_x_en);
       -- but the map is on logic channel 
txpma5_clock_phyport_out_logic <= txpma0_clock_phyport_out WHEN (tx5_logical_to_physical_mapping = 0) ELSE
                                  txpma1_clock_phyport_out WHEN (tx5_logical_to_physical_mapping = 1) ELSE
                                  txpma2_clock_phyport_out WHEN (tx5_logical_to_physical_mapping = 2) ELSE
                                  txpma3_clock_phyport_out WHEN (tx5_logical_to_physical_mapping = 3) ELSE
                                  txpma4_clock_phyport_out WHEN (tx5_logical_to_physical_mapping = 4) ELSE
                                  txpma5_clock_phyport_out WHEN (tx5_logical_to_physical_mapping = 5) ELSE
                                  txpma5_clock_phyport_out;

txpma5_clock_select_out_logic <=  "000" WHEN (txpma5_clock_index_to_phyport(0) = txpma5_clock_phyport_out_logic) ELSE
                                  "001" WHEN (txpma5_clock_index_to_phyport(1) = txpma5_clock_phyport_out_logic) ELSE
                                  "010" WHEN (txpma5_clock_index_to_phyport(2) = txpma5_clock_phyport_out_logic) ELSE
                                  "011" WHEN (txpma5_clock_index_to_phyport(3) = txpma5_clock_phyport_out_logic) ELSE
                                  "100" WHEN (txpma5_clock_index_to_phyport(4) = txpma5_clock_phyport_out_logic) ELSE
                                  "111";  -- invalid cram values
       -- back to physical
txpma5_clock_select_out <= txpma0_clock_select_out_logic WHEN (tx0_logical_to_physical_mapping = 5) ELSE
                           txpma1_clock_select_out_logic WHEN (tx1_logical_to_physical_mapping = 5) ELSE
                           txpma2_clock_select_out_logic WHEN (tx2_logical_to_physical_mapping = 5) ELSE
                           txpma3_clock_select_out_logic WHEN (tx3_logical_to_physical_mapping = 5) ELSE
                           txpma4_clock_select_out_logic WHEN (tx4_logical_to_physical_mapping = 5) ELSE
                           txpma5_clock_select_out_logic WHEN (tx5_logical_to_physical_mapping = 5) ELSE
                           txpma5_clock_select_out_logic;
                               
txpma5_dp_clkin_sel  <=  txpma5_clock_select_out;  
                                                                                                                                                                                           
---------------------------------------------------------------------------
-- PLL0/PLL1 selection ----------------------------------------------------  
---------------------------------------------------------------------------

PROCESS  -- initialize the TABLE
  VARIABLE init_table                : STD_LOGIC := '1';  
  VARIABLE tmp_int                   : INTEGER := 0; 
        
  BEGIN
  IF (init_table = '1') THEN
    clkdiv_pll_phyport_to_cram(CLKDIV_INCLK_SELECT_PLL0)    <= '0';
    clkdiv_pll_phyport_to_cram(CLKDIV_INCLK_SELECT_PLL1)    <= '1';
    clkdiv_pll_phyport_to_cram(CLKDIV_INCLK_SELECT_ERR)     <= '1';  
      
    tmp_int := convert_clkdiv_pll_phyport_str_to_phyport_enum(clkdiv0_inclk0_logical_to_physical_mapping);
    clkdiv0_pll_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_clkdiv_pll_phyport_str_to_phyport_enum(clkdiv0_inclk1_logical_to_physical_mapping);
    clkdiv0_pll_index_to_phyport(1) <= tmp_int;
      
    tmp_int := convert_clkdiv_pll_phyport_str_to_phyport_enum(clkdiv1_inclk0_logical_to_physical_mapping);
    clkdiv1_pll_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_clkdiv_pll_phyport_str_to_phyport_enum(clkdiv1_inclk1_logical_to_physical_mapping);
    clkdiv1_pll_index_to_phyport(1) <= tmp_int;
      
    tmp_int := convert_clkdiv_pll_phyport_str_to_phyport_enum(clkdiv2_inclk0_logical_to_physical_mapping);
    clkdiv2_pll_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_clkdiv_pll_phyport_str_to_phyport_enum(clkdiv2_inclk1_logical_to_physical_mapping);
    clkdiv2_pll_index_to_phyport(1) <= tmp_int;
      
    tmp_int := convert_clkdiv_pll_phyport_str_to_phyport_enum(clkdiv3_inclk0_logical_to_physical_mapping);
    clkdiv3_pll_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_clkdiv_pll_phyport_str_to_phyport_enum(clkdiv3_inclk1_logical_to_physical_mapping);
    clkdiv3_pll_index_to_phyport(1) <= tmp_int;
      
    tmp_int := convert_clkdiv_pll_phyport_str_to_phyport_enum(clkdiv4_inclk0_logical_to_physical_mapping);
    clkdiv4_pll_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_clkdiv_pll_phyport_str_to_phyport_enum(clkdiv4_inclk1_logical_to_physical_mapping);
    clkdiv4_pll_index_to_phyport(1) <= tmp_int;
      
    tmp_int := convert_clkdiv_pll_phyport_str_to_phyport_enum(clkdiv5_inclk0_logical_to_physical_mapping);
    clkdiv5_pll_index_to_phyport(0) <= tmp_int;
    tmp_int := convert_clkdiv_pll_phyport_str_to_phyport_enum(clkdiv5_inclk1_logical_to_physical_mapping);
    clkdiv5_pll_index_to_phyport(1) <= tmp_int;
      
    init_table := '0';
   END IF;
    
   WAIT; 
END PROCESS;  -- end of initializing tables

-- DPRIO read - logical clkdiv channel
tmp_clkdiv0_pll_select  <= clkdiv0_init_inclk_select WHEN (clkdiv0_init_inclk_select = '0' OR clkdiv0_init_inclk_select = '1') ELSE '0';
clkdiv0_pll_select      <= 0 WHEN (tmp_clkdiv0_pll_select = '0') ELSE 1;
clkdiv0_pll_phyport     <= clkdiv0_pll_index_to_phyport(clkdiv0_pll_select);
                            
clkdiv0_pll_cram    <= clkdiv_pll_phyport_to_cram(clkdiv0_pll_phyport); 

-- switch to physical pll number
clkdiv0_pll_cram_phy <= clkdiv0_pll_cram WHEN (tx0_logical_to_physical_mapping = 0) ELSE 
                        clkdiv1_pll_cram WHEN (tx1_logical_to_physical_mapping = 0) ELSE
                        clkdiv2_pll_cram WHEN (tx2_logical_to_physical_mapping = 0) ELSE
                        clkdiv3_pll_cram WHEN (tx3_logical_to_physical_mapping = 0) ELSE
                        clkdiv4_pll_cram WHEN (tx4_logical_to_physical_mapping = 0) ELSE
                        clkdiv5_pll_cram WHEN (tx5_logical_to_physical_mapping = 0) ELSE
                        clkdiv0_pll_cram;
                            
clkdiv0_csr_rcgb_cmu_sel <= clkdiv0_pll_cram_phy; 

-- DPRIO write - CRAM on physical 
clkdiv0_pll_phyport_out <= convert_clkdiv_pll_cram_to_phyport(clkdiv0_dp_rcgb_cmu_sel);
       -- but the map is on logic channel 
clkdiv0_pll_phyport_out_logic <= clkdiv0_pll_phyport_out WHEN (tx0_logical_to_physical_mapping = 0) ELSE 
                                 clkdiv1_pll_phyport_out WHEN (tx0_logical_to_physical_mapping = 1) ELSE
                                 clkdiv2_pll_phyport_out WHEN (tx0_logical_to_physical_mapping = 2) ELSE
                                 clkdiv3_pll_phyport_out WHEN (tx0_logical_to_physical_mapping = 3) ELSE
                                 clkdiv4_pll_phyport_out WHEN (tx0_logical_to_physical_mapping = 4) ELSE
                                 clkdiv5_pll_phyport_out WHEN (tx0_logical_to_physical_mapping = 5) ELSE
                                 clkdiv0_pll_phyport_out;

clkdiv0_pll_select_out_logic <=  '0' WHEN (clkdiv0_pll_index_to_phyport(0) = clkdiv0_pll_phyport_out_logic) ELSE 
                                 '1' WHEN (clkdiv0_pll_index_to_phyport(1) = clkdiv0_pll_phyport_out_logic) ELSE 
                                 '1';
       -- back to physical
clkdiv0_pll_select_out <= clkdiv0_pll_select_out_logic WHEN (tx0_logical_to_physical_mapping = 0) ELSE 
                          clkdiv1_pll_select_out_logic WHEN (tx1_logical_to_physical_mapping = 0) ELSE
                          clkdiv2_pll_select_out_logic WHEN (tx2_logical_to_physical_mapping = 0) ELSE
                          clkdiv3_pll_select_out_logic WHEN (tx3_logical_to_physical_mapping = 0) ELSE
                          clkdiv4_pll_select_out_logic WHEN (tx4_logical_to_physical_mapping = 0) ELSE
                          clkdiv5_pll_select_out_logic WHEN (tx5_logical_to_physical_mapping = 0) ELSE
                          clkdiv0_pll_select_out_logic;
                               
clkdiv0_dp_inclk_select <= clkdiv0_pll_select_out;  


-- DPRIO read - logical clkdiv channel
tmp_clkdiv1_pll_select  <= clkdiv1_init_inclk_select WHEN (clkdiv1_init_inclk_select = '0' OR clkdiv1_init_inclk_select = '1') ELSE '0';
clkdiv1_pll_select      <= 0 WHEN (tmp_clkdiv1_pll_select = '0') ELSE 1;
clkdiv1_pll_phyport     <= clkdiv1_pll_index_to_phyport(clkdiv1_pll_select);
                            
clkdiv1_pll_cram    <= clkdiv_pll_phyport_to_cram(clkdiv1_pll_phyport); 

-- switch to physical pll number
clkdiv1_pll_cram_phy <= clkdiv0_pll_cram WHEN (tx0_logical_to_physical_mapping = 1) ELSE 
                        clkdiv1_pll_cram WHEN (tx1_logical_to_physical_mapping = 1) ELSE
                        clkdiv2_pll_cram WHEN (tx2_logical_to_physical_mapping = 1) ELSE
                        clkdiv3_pll_cram WHEN (tx3_logical_to_physical_mapping = 1) ELSE
                        clkdiv4_pll_cram WHEN (tx4_logical_to_physical_mapping = 1) ELSE
                        clkdiv5_pll_cram WHEN (tx5_logical_to_physical_mapping = 1) ELSE
                        clkdiv1_pll_cram;
                            
clkdiv1_csr_rcgb_cmu_sel <= clkdiv1_pll_cram_phy; 

-- DPRIO write - CRAM on physical 
clkdiv1_pll_phyport_out <= convert_clkdiv_pll_cram_to_phyport(clkdiv1_dp_rcgb_cmu_sel);
       -- but the map is on logic channel 
clkdiv1_pll_phyport_out_logic <= clkdiv0_pll_phyport_out WHEN (tx1_logical_to_physical_mapping = 0) ELSE 
                                 clkdiv1_pll_phyport_out WHEN (tx1_logical_to_physical_mapping = 1) ELSE
                                 clkdiv2_pll_phyport_out WHEN (tx1_logical_to_physical_mapping = 2) ELSE
                                 clkdiv3_pll_phyport_out WHEN (tx1_logical_to_physical_mapping = 3) ELSE
                                 clkdiv4_pll_phyport_out WHEN (tx1_logical_to_physical_mapping = 4) ELSE
                                 clkdiv5_pll_phyport_out WHEN (tx1_logical_to_physical_mapping = 5) ELSE
                                 clkdiv1_pll_phyport_out;

clkdiv1_pll_select_out_logic <=  '0' WHEN (clkdiv1_pll_index_to_phyport(0) = clkdiv1_pll_phyport_out_logic) ELSE 
                                 '1' WHEN (clkdiv1_pll_index_to_phyport(1) = clkdiv1_pll_phyport_out_logic) ELSE 
                                 '1';
       -- back to physical
clkdiv1_pll_select_out <= clkdiv0_pll_select_out_logic WHEN (tx0_logical_to_physical_mapping = 1) ELSE 
                          clkdiv1_pll_select_out_logic WHEN (tx1_logical_to_physical_mapping = 1) ELSE
                          clkdiv2_pll_select_out_logic WHEN (tx2_logical_to_physical_mapping = 1) ELSE
                          clkdiv3_pll_select_out_logic WHEN (tx3_logical_to_physical_mapping = 1) ELSE
                          clkdiv4_pll_select_out_logic WHEN (tx4_logical_to_physical_mapping = 1) ELSE
                          clkdiv5_pll_select_out_logic WHEN (tx5_logical_to_physical_mapping = 1) ELSE
                          clkdiv1_pll_select_out_logic;
                               
clkdiv1_dp_inclk_select <= clkdiv1_pll_select_out;  


-- DPRIO read - logical clkdiv channel
tmp_clkdiv2_pll_select  <= clkdiv2_init_inclk_select WHEN (clkdiv2_init_inclk_select = '0' OR clkdiv2_init_inclk_select = '1') ELSE '0';
clkdiv2_pll_select      <= 0 WHEN (tmp_clkdiv2_pll_select = '0') ELSE 1;
clkdiv2_pll_phyport     <= clkdiv2_pll_index_to_phyport(clkdiv2_pll_select);
                            
clkdiv2_pll_cram    <= clkdiv_pll_phyport_to_cram(clkdiv2_pll_phyport); 

-- switch to physical pll number
clkdiv2_pll_cram_phy <= clkdiv0_pll_cram WHEN (tx0_logical_to_physical_mapping = 2) ELSE 
                        clkdiv1_pll_cram WHEN (tx1_logical_to_physical_mapping = 2) ELSE
                        clkdiv2_pll_cram WHEN (tx2_logical_to_physical_mapping = 2) ELSE
                        clkdiv3_pll_cram WHEN (tx3_logical_to_physical_mapping = 2) ELSE
                        clkdiv4_pll_cram WHEN (tx4_logical_to_physical_mapping = 2) ELSE
                        clkdiv5_pll_cram WHEN (tx5_logical_to_physical_mapping = 2) ELSE
                        clkdiv2_pll_cram;
                            
clkdiv2_csr_rcgb_cmu_sel <= clkdiv2_pll_cram_phy; 

-- DPRIO write - CRAM on physical 
clkdiv2_pll_phyport_out <= convert_clkdiv_pll_cram_to_phyport(clkdiv2_dp_rcgb_cmu_sel);
       -- but the map is on logic channel 
clkdiv2_pll_phyport_out_logic <= clkdiv0_pll_phyport_out WHEN (tx2_logical_to_physical_mapping = 0) ELSE 
                                 clkdiv1_pll_phyport_out WHEN (tx2_logical_to_physical_mapping = 1) ELSE
                                 clkdiv2_pll_phyport_out WHEN (tx2_logical_to_physical_mapping = 2) ELSE
                                 clkdiv3_pll_phyport_out WHEN (tx2_logical_to_physical_mapping = 3) ELSE
                                 clkdiv4_pll_phyport_out WHEN (tx2_logical_to_physical_mapping = 4) ELSE
                                 clkdiv5_pll_phyport_out WHEN (tx2_logical_to_physical_mapping = 5) ELSE
                                 clkdiv2_pll_phyport_out;

clkdiv2_pll_select_out_logic <=  '0' WHEN (clkdiv2_pll_index_to_phyport(0) = clkdiv2_pll_phyport_out_logic) ELSE 
                                 '1' WHEN (clkdiv2_pll_index_to_phyport(1) = clkdiv2_pll_phyport_out_logic) ELSE 
                                 '1';
       -- back to physical
clkdiv2_pll_select_out <= clkdiv0_pll_select_out_logic WHEN (tx0_logical_to_physical_mapping = 2) ELSE 
                          clkdiv1_pll_select_out_logic WHEN (tx1_logical_to_physical_mapping = 2) ELSE
                          clkdiv2_pll_select_out_logic WHEN (tx2_logical_to_physical_mapping = 2) ELSE
                          clkdiv3_pll_select_out_logic WHEN (tx3_logical_to_physical_mapping = 2) ELSE
                          clkdiv4_pll_select_out_logic WHEN (tx4_logical_to_physical_mapping = 2) ELSE
                          clkdiv5_pll_select_out_logic WHEN (tx5_logical_to_physical_mapping = 2) ELSE
                          clkdiv2_pll_select_out_logic;
                               
clkdiv2_dp_inclk_select <= clkdiv2_pll_select_out;  


-- DPRIO read - logical clkdiv channel
tmp_clkdiv3_pll_select  <= clkdiv3_init_inclk_select WHEN (clkdiv3_init_inclk_select = '0' OR clkdiv3_init_inclk_select = '1') ELSE '0';
clkdiv3_pll_select      <= 0 WHEN (tmp_clkdiv3_pll_select = '0') ELSE 1;
clkdiv3_pll_phyport     <= clkdiv3_pll_index_to_phyport(clkdiv3_pll_select);
                            
clkdiv3_pll_cram    <= clkdiv_pll_phyport_to_cram(clkdiv3_pll_phyport); 

-- switch to physical pll number
clkdiv3_pll_cram_phy <= clkdiv0_pll_cram WHEN (tx0_logical_to_physical_mapping = 3) ELSE 
                        clkdiv1_pll_cram WHEN (tx1_logical_to_physical_mapping = 3) ELSE
                        clkdiv2_pll_cram WHEN (tx2_logical_to_physical_mapping = 3) ELSE
                        clkdiv3_pll_cram WHEN (tx3_logical_to_physical_mapping = 3) ELSE
                        clkdiv4_pll_cram WHEN (tx4_logical_to_physical_mapping = 3) ELSE
                        clkdiv5_pll_cram WHEN (tx5_logical_to_physical_mapping = 3) ELSE
                        clkdiv3_pll_cram;
                            
clkdiv3_csr_rcgb_cmu_sel <= clkdiv3_pll_cram_phy; 

-- DPRIO write - CRAM on physical 
clkdiv3_pll_phyport_out <= convert_clkdiv_pll_cram_to_phyport(clkdiv3_dp_rcgb_cmu_sel);
       -- but the map is on logic channel 
clkdiv3_pll_phyport_out_logic <= clkdiv0_pll_phyport_out WHEN (tx3_logical_to_physical_mapping = 0) ELSE 
                                 clkdiv1_pll_phyport_out WHEN (tx3_logical_to_physical_mapping = 1) ELSE
                                 clkdiv2_pll_phyport_out WHEN (tx3_logical_to_physical_mapping = 2) ELSE
                                 clkdiv3_pll_phyport_out WHEN (tx3_logical_to_physical_mapping = 3) ELSE
                                 clkdiv4_pll_phyport_out WHEN (tx3_logical_to_physical_mapping = 4) ELSE
                                 clkdiv5_pll_phyport_out WHEN (tx3_logical_to_physical_mapping = 5) ELSE
                                 clkdiv3_pll_phyport_out;

clkdiv3_pll_select_out_logic <=  '0' WHEN (clkdiv3_pll_index_to_phyport(0) = clkdiv3_pll_phyport_out_logic) ELSE 
                                 '1' WHEN (clkdiv3_pll_index_to_phyport(1) = clkdiv3_pll_phyport_out_logic) ELSE 
                                 '1';
       -- back to physical
clkdiv3_pll_select_out <= clkdiv0_pll_select_out_logic WHEN (tx0_logical_to_physical_mapping = 3) ELSE 
                          clkdiv1_pll_select_out_logic WHEN (tx1_logical_to_physical_mapping = 3) ELSE
                          clkdiv2_pll_select_out_logic WHEN (tx2_logical_to_physical_mapping = 3) ELSE
                          clkdiv3_pll_select_out_logic WHEN (tx3_logical_to_physical_mapping = 3) ELSE
                          clkdiv4_pll_select_out_logic WHEN (tx4_logical_to_physical_mapping = 3) ELSE
                          clkdiv5_pll_select_out_logic WHEN (tx5_logical_to_physical_mapping = 3) ELSE
                          clkdiv3_pll_select_out_logic;
                               
clkdiv3_dp_inclk_select <= clkdiv3_pll_select_out;  


-- DPRIO read - logical clkdiv channel
tmp_clkdiv4_pll_select  <= clkdiv4_init_inclk_select WHEN (clkdiv4_init_inclk_select = '0' OR clkdiv4_init_inclk_select = '1') ELSE '0';
clkdiv4_pll_select      <= 0 WHEN (tmp_clkdiv4_pll_select = '0') ELSE 1;
clkdiv4_pll_phyport     <= clkdiv4_pll_index_to_phyport(clkdiv4_pll_select);
                            
clkdiv4_pll_cram    <= clkdiv_pll_phyport_to_cram(clkdiv4_pll_phyport); 

-- switch to physical pll number
clkdiv4_pll_cram_phy <= clkdiv0_pll_cram WHEN (tx0_logical_to_physical_mapping = 4) ELSE 
                        clkdiv1_pll_cram WHEN (tx1_logical_to_physical_mapping = 4) ELSE
                        clkdiv2_pll_cram WHEN (tx2_logical_to_physical_mapping = 4) ELSE
                        clkdiv3_pll_cram WHEN (tx3_logical_to_physical_mapping = 4) ELSE
                        clkdiv4_pll_cram WHEN (tx4_logical_to_physical_mapping = 4) ELSE
                        clkdiv5_pll_cram WHEN (tx5_logical_to_physical_mapping = 4) ELSE
                        clkdiv4_pll_cram;
                            
clkdiv4_csr_rcgb_cmu_sel <= clkdiv4_pll_cram_phy; 

-- DPRIO write - CRAM on physical 
clkdiv4_pll_phyport_out <= convert_clkdiv_pll_cram_to_phyport(clkdiv4_dp_rcgb_cmu_sel);
       -- but the map is on logic channel 
clkdiv4_pll_phyport_out_logic <= clkdiv0_pll_phyport_out WHEN (tx4_logical_to_physical_mapping = 0) ELSE 
                                 clkdiv1_pll_phyport_out WHEN (tx4_logical_to_physical_mapping = 1) ELSE
                                 clkdiv2_pll_phyport_out WHEN (tx4_logical_to_physical_mapping = 2) ELSE
                                 clkdiv3_pll_phyport_out WHEN (tx4_logical_to_physical_mapping = 3) ELSE
                                 clkdiv4_pll_phyport_out WHEN (tx4_logical_to_physical_mapping = 4) ELSE
                                 clkdiv5_pll_phyport_out WHEN (tx4_logical_to_physical_mapping = 5) ELSE
                                 clkdiv4_pll_phyport_out;

clkdiv4_pll_select_out_logic <=  '0' WHEN (clkdiv4_pll_index_to_phyport(0) = clkdiv4_pll_phyport_out_logic) ELSE 
                                 '1' WHEN (clkdiv4_pll_index_to_phyport(1) = clkdiv4_pll_phyport_out_logic) ELSE 
                                 '1';
       -- back to physical
clkdiv4_pll_select_out <= clkdiv0_pll_select_out_logic WHEN (tx0_logical_to_physical_mapping = 4) ELSE 
                          clkdiv1_pll_select_out_logic WHEN (tx1_logical_to_physical_mapping = 4) ELSE
                          clkdiv2_pll_select_out_logic WHEN (tx2_logical_to_physical_mapping = 4) ELSE
                          clkdiv3_pll_select_out_logic WHEN (tx3_logical_to_physical_mapping = 4) ELSE
                          clkdiv4_pll_select_out_logic WHEN (tx4_logical_to_physical_mapping = 4) ELSE
                          clkdiv5_pll_select_out_logic WHEN (tx5_logical_to_physical_mapping = 4) ELSE
                          clkdiv4_pll_select_out_logic;
                               
clkdiv4_dp_inclk_select <= clkdiv4_pll_select_out;  


-- DPRIO read - logical clkdiv channel
tmp_clkdiv5_pll_select  <= clkdiv5_init_inclk_select WHEN (clkdiv5_init_inclk_select = '0' OR clkdiv5_init_inclk_select = '1') ELSE '0';
clkdiv5_pll_select      <= 0 WHEN (tmp_clkdiv5_pll_select = '0') ELSE 1;
clkdiv5_pll_phyport     <= clkdiv5_pll_index_to_phyport(clkdiv5_pll_select);
                            
clkdiv5_pll_cram    <= clkdiv_pll_phyport_to_cram(clkdiv5_pll_phyport); 

-- switch to physical pll number
clkdiv5_pll_cram_phy <= clkdiv0_pll_cram WHEN (tx0_logical_to_physical_mapping = 5) ELSE 
                        clkdiv1_pll_cram WHEN (tx1_logical_to_physical_mapping = 5) ELSE
                        clkdiv2_pll_cram WHEN (tx2_logical_to_physical_mapping = 5) ELSE
                        clkdiv3_pll_cram WHEN (tx3_logical_to_physical_mapping = 5) ELSE
                        clkdiv4_pll_cram WHEN (tx4_logical_to_physical_mapping = 5) ELSE
                        clkdiv5_pll_cram WHEN (tx5_logical_to_physical_mapping = 5) ELSE
                        clkdiv5_pll_cram;
                            
clkdiv5_csr_rcgb_cmu_sel <= clkdiv5_pll_cram_phy; 

-- DPRIO write - CRAM on physical 
clkdiv5_pll_phyport_out <= convert_clkdiv_pll_cram_to_phyport(clkdiv5_dp_rcgb_cmu_sel);
       -- but the map is on logic channel 
clkdiv5_pll_phyport_out_logic <= clkdiv0_pll_phyport_out WHEN (tx5_logical_to_physical_mapping = 0) ELSE 
                                 clkdiv1_pll_phyport_out WHEN (tx5_logical_to_physical_mapping = 1) ELSE
                                 clkdiv2_pll_phyport_out WHEN (tx5_logical_to_physical_mapping = 2) ELSE
                                 clkdiv3_pll_phyport_out WHEN (tx5_logical_to_physical_mapping = 3) ELSE
                                 clkdiv4_pll_phyport_out WHEN (tx5_logical_to_physical_mapping = 4) ELSE
                                 clkdiv5_pll_phyport_out WHEN (tx5_logical_to_physical_mapping = 5) ELSE
                                 clkdiv5_pll_phyport_out;

clkdiv5_pll_select_out_logic <=  '0' WHEN (clkdiv5_pll_index_to_phyport(0) = clkdiv5_pll_phyport_out_logic) ELSE 
                                 '1' WHEN (clkdiv5_pll_index_to_phyport(1) = clkdiv5_pll_phyport_out_logic) ELSE 
                                 '1';
       -- back to physical
clkdiv5_pll_select_out <= clkdiv0_pll_select_out_logic WHEN (tx0_logical_to_physical_mapping = 5) ELSE 
                          clkdiv1_pll_select_out_logic WHEN (tx1_logical_to_physical_mapping = 5) ELSE
                          clkdiv2_pll_select_out_logic WHEN (tx2_logical_to_physical_mapping = 5) ELSE
                          clkdiv3_pll_select_out_logic WHEN (tx3_logical_to_physical_mapping = 5) ELSE
                          clkdiv4_pll_select_out_logic WHEN (tx4_logical_to_physical_mapping = 5) ELSE
                          clkdiv5_pll_select_out_logic WHEN (tx5_logical_to_physical_mapping = 5) ELSE
                          clkdiv5_pll_select_out_logic;
                               
clkdiv5_dp_inclk_select <= clkdiv5_pll_select_out;  

END trans;

--/////////////////////////////////////////////////////////////////////////////
-- DPRIO INDEX TABLE --------------------------------------------------------//
--/////////////////////////////////////////////////////////////////////////////

-- make sure indices with _DP_ in the middle to distiguish from rx/tx

-- *******************************************************************
-- RXPLL and CMUPLL must have same indices since they share same Atom
-- *******************************************************************

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_dprio_map IS
   GENERIC (
      
      -- external parameters
      -- Simulation Only 
      clkdiv0_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv0_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv1_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv1_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv2_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv2_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv3_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv3_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv4_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv4_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv5_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv5_inclk1_logical_to_physical_mapping   : STRING := "pll1";
            
      pll0_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll0_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll0_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll0_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll0_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll0_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll0_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll0_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll0_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll0_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll1_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll1_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll1_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll1_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll1_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll1_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll1_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll1_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll1_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll1_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll2_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll2_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll2_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll2_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll2_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll2_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll2_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll2_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll2_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll2_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll3_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll3_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll3_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll3_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll3_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll3_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll3_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll3_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll3_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll3_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll4_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll4_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll4_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll4_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll4_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll4_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll4_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll4_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll4_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll4_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll5_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll5_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll5_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll5_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll5_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll5_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll5_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll5_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll5_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll5_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
                  
      pll0_logical_to_physical_mapping    :    INTEGER := 0;
      pll1_logical_to_physical_mapping    :    INTEGER := 1;
      pll2_logical_to_physical_mapping    :    INTEGER := 2;
      pll3_logical_to_physical_mapping    :    INTEGER := 3;
      pll4_logical_to_physical_mapping    :    INTEGER := 4;
      pll5_logical_to_physical_mapping    :    INTEGER := 5;
            
      refclk_divider0_logical_to_physical_mapping	:	INTEGER := 0;
      refclk_divider1_logical_to_physical_mapping	:	INTEGER := 1;
      
      rx0_logical_to_physical_mapping	:	INTEGER := 0;
      rx1_logical_to_physical_mapping	:	INTEGER := 1;
      rx2_logical_to_physical_mapping	:	INTEGER := 2;
      rx3_logical_to_physical_mapping	:	INTEGER := 3;
      rx4_logical_to_physical_mapping	:	INTEGER := 4;
      rx5_logical_to_physical_mapping	:	INTEGER := 5;
      
      tx0_logical_to_physical_mapping	:	INTEGER := 0;
      tx1_logical_to_physical_mapping	:	INTEGER := 1;
      tx2_logical_to_physical_mapping	:	INTEGER := 2;
      tx3_logical_to_physical_mapping	:	INTEGER := 3;
      tx4_logical_to_physical_mapping	:	INTEGER := 4;
      tx5_logical_to_physical_mapping	:	INTEGER := 5;
      
      tx0_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx0_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx0_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx0_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx0_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx1_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx1_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx1_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx1_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx1_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx2_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx2_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx2_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx2_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx2_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx3_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx3_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx3_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx3_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx3_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx4_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx4_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx4_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx4_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx4_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx5_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx5_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx5_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx5_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx5_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      
      -- DEBUG dump
      
      sim_dump_dprio_internal_reg_at_time  : INTEGER := 0;		-- in ps
      sim_dump_filename                    : STRING := "sim_dprio_dump.txt"
   );
   PORT (
      cmudividerdprioin                    : IN STD_LOGIC_VECTOR(599 DOWNTO 0);
      cmuplldprioin                        : IN STD_LOGIC_VECTOR(1799 DOWNTO 0);
      refclkdividerdprioin                 : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rxpcsdprioin                         : IN STD_LOGIC_VECTOR(1599 DOWNTO 0);
      rxpmadprioin                         : IN STD_LOGIC_VECTOR(1799 DOWNTO 0);
      txpcsdprioin                         : IN STD_LOGIC_VECTOR(599 DOWNTO 0);
      txpmadprioin                         : IN STD_LOGIC_VECTOR(1799 DOWNTO 0);
      
      ch0_dp_chnl_out                      : IN STD_LOGIC_VECTOR(831 DOWNTO 0);
      ch1_dp_chnl_out                      : IN STD_LOGIC_VECTOR(831 DOWNTO 0);
      ch2_dp_chnl_out                      : IN STD_LOGIC_VECTOR(831 DOWNTO 0);
      ch3_dp_chnl_out                      : IN STD_LOGIC_VECTOR(831 DOWNTO 0);
      ch0_dp_chnl_out_reserved             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ch1_dp_chnl_out_reserved             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ch2_dp_chnl_out_reserved             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      ch3_dp_chnl_out_reserved             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
      dp_centrl_out                        : IN STD_LOGIC_VECTOR(703 DOWNTO 0);  
      dp_centrl_out_reserved               : IN STD_LOGIC_VECTOR(31 DOWNTO 0);  
      
      ch0_csr_chnl_in                      : OUT STD_LOGIC_VECTOR(831 DOWNTO 0);
      ch1_csr_chnl_in                      : OUT STD_LOGIC_VECTOR(831 DOWNTO 0);
      ch2_csr_chnl_in                      : OUT STD_LOGIC_VECTOR(831 DOWNTO 0);
      ch3_csr_chnl_in                      : OUT STD_LOGIC_VECTOR(831 DOWNTO 0);
      ch0_csr_chnl_in_reserved             : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      ch1_csr_chnl_in_reserved             : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      ch2_csr_chnl_in_reserved             : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      ch3_csr_chnl_in_reserved             : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
      csr_centrl_in                        : OUT STD_LOGIC_VECTOR(703 DOWNTO 0);
      csr_centrl_in_reserved               : OUT STD_LOGIC_VECTOR(31 DOWNTO 0);
      
      cmudividerdprioout                   : OUT STD_LOGIC_VECTOR(599 DOWNTO 0);
      cmuplldprioout                       : OUT STD_LOGIC_VECTOR(1799 DOWNTO 0);
      refclkdividerdprioout                : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      rxpcsdprioout                        : OUT STD_LOGIC_VECTOR(1599 DOWNTO 0);
      rxpmadprioout                        : OUT STD_LOGIC_VECTOR(1799 DOWNTO 0);
      txpcsdprioout                        : OUT STD_LOGIC_VECTOR(599 DOWNTO 0);
      txpmadprioout                        : OUT STD_LOGIC_VECTOR(1799 DOWNTO 0)
   );
END stratixiv_hssi_cmu_dprio_map;

ARCHITECTURE trans OF stratixiv_hssi_cmu_dprio_map IS

  COMPONENT stratixiv_hssi_cmu_dprio_map_index
    GENERIC (
      -- Simulation Only 
      clkdiv0_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv0_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv1_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv1_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv2_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv2_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv3_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv3_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv4_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv4_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv5_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv5_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      
      pll0_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll0_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll0_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll0_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll0_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll0_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll0_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll0_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll0_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll0_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll1_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll1_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll1_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll1_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll1_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll1_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll1_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll1_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll1_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll1_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll2_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll2_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll2_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll2_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll2_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll2_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll2_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll2_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll2_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll2_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll3_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll3_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll3_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll3_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll3_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll3_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll3_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll3_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll3_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll3_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll4_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll4_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll4_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll4_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll4_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll4_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll4_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll4_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll4_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll4_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll5_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll5_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll5_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll5_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll5_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll5_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll5_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll5_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll5_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll5_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
            
      pll0_logical_to_physical_mapping    :    INTEGER := 0;
      pll1_logical_to_physical_mapping    :    INTEGER := 1;
      pll2_logical_to_physical_mapping    :    INTEGER := 2;
      pll3_logical_to_physical_mapping    :    INTEGER := 3;
      pll4_logical_to_physical_mapping    :    INTEGER := 4;
      pll5_logical_to_physical_mapping    :    INTEGER := 5;
            
      refclk_divider0_logical_to_physical_mapping	:	INTEGER := 0;
      refclk_divider1_logical_to_physical_mapping	:	INTEGER := 1;
      
      rx0_logical_to_physical_mapping	:	INTEGER := 0;
      rx1_logical_to_physical_mapping	:	INTEGER := 1;
      rx2_logical_to_physical_mapping	:	INTEGER := 2;
      rx3_logical_to_physical_mapping	:	INTEGER := 3;
      rx4_logical_to_physical_mapping	:	INTEGER := 4;
      rx5_logical_to_physical_mapping	:	INTEGER := 5;
      
      tx0_logical_to_physical_mapping	:	INTEGER := 0;
      tx1_logical_to_physical_mapping	:	INTEGER := 1;
      tx2_logical_to_physical_mapping	:	INTEGER := 2;
      tx3_logical_to_physical_mapping	:	INTEGER := 3;
      tx4_logical_to_physical_mapping	:	INTEGER := 4;
      tx5_logical_to_physical_mapping	:	INTEGER := 5;
      
      
      tx0_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx0_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx0_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx0_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx0_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx1_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx1_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx1_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx1_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx1_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx2_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx2_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx2_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx2_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx2_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx3_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx3_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx3_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx3_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx3_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx4_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx4_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx4_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx4_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx4_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx5_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx5_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx5_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx5_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx5_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport"
   );
   PORT (
      pll0_init_pfd_clk_sel  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll0_dp_riqclk_sel     : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll0_dp_rrefclk_sel    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll0_csr_riqclk_sel    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll0_csr_rrefclk_sel   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll0_dp_pfd_clk_sel    : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll1_init_pfd_clk_sel  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll1_dp_riqclk_sel     : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll1_dp_rrefclk_sel    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll1_csr_riqclk_sel    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll1_csr_rrefclk_sel   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll1_dp_pfd_clk_sel    : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll2_init_pfd_clk_sel  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll2_dp_riqclk_sel     : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll2_dp_rrefclk_sel    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll2_csr_riqclk_sel    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll2_csr_rrefclk_sel   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll2_dp_pfd_clk_sel    : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll3_init_pfd_clk_sel  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll3_dp_riqclk_sel     : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll3_dp_rrefclk_sel    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll3_csr_riqclk_sel    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll3_csr_rrefclk_sel   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll3_dp_pfd_clk_sel    : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll4_init_pfd_clk_sel  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll4_dp_riqclk_sel     : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll4_dp_rrefclk_sel    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll4_csr_riqclk_sel    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll4_csr_rrefclk_sel   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll4_dp_pfd_clk_sel    : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll5_init_pfd_clk_sel  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      pll5_dp_riqclk_sel     : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll5_dp_rrefclk_sel    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll5_csr_riqclk_sel    : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll5_csr_rrefclk_sel   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pll5_dp_pfd_clk_sel    : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      
      txpma0_init_clkin_sel  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      txpma0_csr_rcgb_x_en   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma0_dp_rcgb_x_en    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma0_dp_clkin_sel    : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      txpma1_init_clkin_sel  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      txpma1_csr_rcgb_x_en   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma1_dp_rcgb_x_en    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma1_dp_clkin_sel    : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      txpma2_init_clkin_sel  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      txpma2_csr_rcgb_x_en   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma2_dp_rcgb_x_en    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma2_dp_clkin_sel    : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      txpma3_init_clkin_sel  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      txpma3_csr_rcgb_x_en   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma3_dp_rcgb_x_en    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma3_dp_clkin_sel    : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      txpma4_init_clkin_sel  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      txpma4_csr_rcgb_x_en   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma4_dp_rcgb_x_en    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma4_dp_clkin_sel    : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      txpma5_init_clkin_sel  : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
      txpma5_csr_rcgb_x_en   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma5_dp_rcgb_x_en    : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      txpma5_dp_clkin_sel    : OUT STD_LOGIC_VECTOR(2 DOWNTO 0);
      
      clkdiv0_init_inclk_select : IN STD_LOGIC;
      clkdiv0_csr_rcgb_cmu_sel  : OUT STD_LOGIC;
      clkdiv0_dp_rcgb_cmu_sel   : IN STD_LOGIC;
      clkdiv0_dp_inclk_select   : OUT STD_LOGIC;
      clkdiv1_init_inclk_select : IN STD_LOGIC;
      clkdiv1_csr_rcgb_cmu_sel  : OUT STD_LOGIC;
      clkdiv1_dp_rcgb_cmu_sel   : IN STD_LOGIC;
      clkdiv1_dp_inclk_select   : OUT STD_LOGIC;
      clkdiv2_init_inclk_select : IN STD_LOGIC;
      clkdiv2_csr_rcgb_cmu_sel  : OUT STD_LOGIC;
      clkdiv2_dp_rcgb_cmu_sel   : IN STD_LOGIC;
      clkdiv2_dp_inclk_select   : OUT STD_LOGIC;
      clkdiv3_init_inclk_select : IN STD_LOGIC;
      clkdiv3_csr_rcgb_cmu_sel  : OUT STD_LOGIC;
      clkdiv3_dp_rcgb_cmu_sel   : IN STD_LOGIC;
      clkdiv3_dp_inclk_select   : OUT STD_LOGIC;
      clkdiv4_init_inclk_select : IN STD_LOGIC;
      clkdiv4_csr_rcgb_cmu_sel  : OUT STD_LOGIC;
      clkdiv4_dp_rcgb_cmu_sel   : IN STD_LOGIC;
      clkdiv4_dp_inclk_select   : OUT STD_LOGIC;
      clkdiv5_init_inclk_select : IN STD_LOGIC;
      clkdiv5_csr_rcgb_cmu_sel  : OUT STD_LOGIC;
      clkdiv5_dp_rcgb_cmu_sel   : IN STD_LOGIC;
      clkdiv5_dp_inclk_select   : OUT STD_LOGIC
    );   
  END COMPONENT;

-- Table1: PCS Per Channel TX Control Register 1 for Channel 0
constant rforce_disp_DP_TXPCS_IDX_0	: integer := 0;
constant rrev_loopbk_DP_TXPCS_IDX_0	: integer := 1;
constant rtxrdclksel_DP_TXPCS_IDX_0	: integer := 2;
constant rtxwrclksel_DP_TXPCS_IDX_0	: integer := 3;
constant rfreerun_tx_DP_TXPCS_IDX_0	: integer := 4;
constant rtxurstpcs_DP_TXPCS_IDX_0	: integer := 5;
constant reserved_0_TB1_DP_TXPCS_IDX_0	: integer := 6;
constant rphfifoursttx_DP_TXPCS_IDX_0	: integer := 7;
constant rphfifopldentx_DP_TXPCS_IDX_0	: integer := 8;
constant rge_xaui_tx_DP_TXPCS_IDX_0	: integer := 9;
constant rdwidth_tx_DP_TXPCS_IDX_0	: integer := 10;
constant rtxfifo_lowlatency_en_DP_TXPCS_IDX_0	: integer := 11;
constant rib_force_disp_DP_TXPCS_IDX_0	: integer := 12;
constant rtxfifo_dis_DP_TXPCS_IDX_0	: integer := 13;
constant rforce_echar_DP_TXPCS_IDX_0	: integer := 14;
constant rforce_kchar_DP_TXPCS_IDX_0	: integer := 15;

-- Table2: PCS Per Channel TX Control Register 2 for Channel 0
constant rtxpcsbypass_en_DP_TXPCS_IDX_0	: integer := 16;
constant rcxpat_chnl_en_DP_TXPCS_IDX_0	: integer := 17;
constant rcxpat_chnl_en_DP_TXPCS_IDX_1	: integer := 18;
constant rbist_sel_DP_TXPCS_IDX_0	: integer := 19;
constant rbist_sel_DP_TXPCS_IDX_1	: integer := 20;
constant rbisten_tx_DP_TXPCS_IDX_0	: integer := 21;
constant rprbs_sel_DP_TXPCS_IDX_0	: integer := 22;
constant rprbs_sel_DP_TXPCS_IDX_1	: integer := 23;
constant rprbs_sel_DP_TXPCS_IDX_2	: integer := 24;
constant rprbsen_tx_DP_TXPCS_IDX_0	: integer := 25;
constant renbitrev_tx_DP_TXPCS_IDX_0	: integer := 26;
constant renpolinv_tx_DP_TXPCS_IDX_0	: integer := 27;
constant rensymswap_tx_DP_TXPCS_IDX_0	: integer := 28;
constant rcascaded_8b10b_en_tx_DP_TXPCS_IDX_0	: integer := 29;
constant r8b10b_enc_ibm_en_DP_TXPCS_IDX_0	: integer := 30;
constant rendec_tx_DP_TXPCS_IDX_0	: integer := 31;

-- Table3: PCS Per Channel TX Control Register 3 for Channel 0
constant reserved_0_TB3_DP_TXPCS_IDX_0	: integer := 32;
constant rcid_len_tx_DP_TXPCS_IDX_0	: integer := 33;
constant rcid_len_tx_DP_TXPCS_IDX_1	: integer := 34;
constant rcid_len_tx_DP_TXPCS_IDX_2	: integer := 35;
constant rcid_len_tx_DP_TXPCS_IDX_3	: integer := 36;
constant rcid_len_tx_DP_TXPCS_IDX_4	: integer := 37;
constant rcid_len_tx_DP_TXPCS_IDX_5	: integer := 38;
constant rcid_len_tx_DP_TXPCS_IDX_6	: integer := 39;
constant rcid_len_tx_DP_TXPCS_IDX_7	: integer := 40;
constant rcid_pattern_tx_DP_TXPCS_IDX_0	: integer := 41;
constant rtxpcsclkpwdn_DP_TXPCS_IDX_0	: integer := 42;
constant rtxswing_sel_ena_DP_TXPCS_IDX_0	: integer := 43;
constant rtx_elec_idle_delay_DP_TXPCS_IDX_0	: integer := 44;
constant rtx_elec_idle_delay_DP_TXPCS_IDX_1	: integer := 45;
constant rtx_elec_idle_delay_DP_TXPCS_IDX_2	: integer := 46;
constant rtx_pipe_enable_DP_TXPCS_IDX_0	: integer := 47;

-- Table4: PCS Per Channel TX Control Register 4 for Channel 0
constant reserved_0_TB4_DP_TXPCS_IDX_0	: integer := 48;
constant reserved_0_TB4_DP_TXPCS_IDX_1	: integer := 49;
constant reserved_0_TB4_DP_TXPCS_IDX_2	: integer := 50;
constant reserved_0_TB4_DP_TXPCS_IDX_3	: integer := 51;
constant reserved_0_TB4_DP_TXPCS_IDX_4	: integer := 52;
constant reserved_0_TB4_DP_TXPCS_IDX_5	: integer := 53;
constant reserved_0_TB4_DP_TXPCS_IDX_6	: integer := 54;
constant reserved_0_TB4_DP_TXPCS_IDX_7	: integer := 55;
constant reserved_0_TB4_DP_TXPCS_IDX_8	: integer := 56;
constant reserved_0_TB4_DP_TXPCS_IDX_9	: integer := 57;
constant reserved_0_TB4_DP_TXPCS_IDX_10	: integer := 58;
constant reserved_0_TB4_DP_TXPCS_IDX_11	: integer := 59;
constant rtxbitslip_en_DP_TXPCS_IDX_0	: integer := 60;
constant rphfifo_regmode_tx_DP_TXPCS_IDX_0	: integer := 61;
constant rpipeline_bypass_tx_DP_TXPCS_IDX_0	: integer := 62;
constant rself_sw_en_tx_DP_TXPCS_IDX_0	: integer := 63;

-- Table5: PCS Per Channel RX Control Register 1 for Channel 0
constant rrxpcsbypass_en_DP_RXPCS_IDX_0	: integer := 0;
constant rall_one_dect_only_DP_RXPCS_IDX_0	: integer := 1;
constant rbist_clr_rx_DP_RXPCS_IDX_0	: integer := 2;
constant rbisten_rx_DP_RXPCS_IDX_0	: integer := 3;
constant rprbs_clr_rslt_rx_DP_RXPCS_IDX_0	: integer := 4;
constant rprbsen_rx_DP_RXPCS_IDX_0	: integer := 5;
constant rrx_rd_clk_sel_DP_RXPCS_IDX_0	: integer := 6;
constant rclk_2_sel_DP_RXPCS_IDX_0	: integer := 7;
constant rclk_2_sel_DP_RXPCS_IDX_1	: integer := 8;
constant rclk_1_sel_DP_RXPCS_IDX_0	: integer := 9;
constant rclk_1_sel_DP_RXPCS_IDX_1	: integer := 10;
constant rrcvd_clk_sel_DP_RXPCS_IDX_0	: integer := 11;
constant rrcvd_clk_sel_DP_RXPCS_IDX_1	: integer := 12;
constant rfreerun_rx_DP_RXPCS_IDX_0	: integer := 13;
constant rrxurstpcs_DP_RXPCS_IDX_0	: integer := 14;
constant reserved_0_TB5_DP_RXPCS_IDX_0	: integer := 15;

-- Table6: PCS Per Channel RX Control Register 2 for Channel 0
constant rcomp_pat_32_DP_RXPCS_IDX_0	: integer := 16;
constant rcomp_pat_33_DP_RXPCS_IDX_0	: integer := 17;
constant rcomp_pat_34_DP_RXPCS_IDX_0	: integer := 18;
constant rcomp_pat_35_DP_RXPCS_IDX_0	: integer := 19;
constant rcomp_pat_36_DP_RXPCS_IDX_0	: integer := 20;
constant rcomp_pat_37_DP_RXPCS_IDX_0	: integer := 21;
constant rcomp_pat_38_DP_RXPCS_IDX_0	: integer := 22;
constant rcomp_pat_39_DP_RXPCS_IDX_0	: integer := 23;
constant rcomp_size_DP_RXPCS_IDX_0	: integer := 24;
constant rcomp_size_DP_RXPCS_IDX_1	: integer := 25;
constant rcomp_size_DP_RXPCS_IDX_2	: integer := 26;
constant rcomp_pat_porn_DP_RXPCS_IDX_0	: integer := 27;
constant rdis_rx_disp_DP_RXPCS_IDX_0	: integer := 28;
constant rencdt_rising_DP_RXPCS_IDX_0	: integer := 29;
constant resync_badcg_en_DP_RXPCS_IDX_0	: integer := 30;
constant resync_badcg_en_DP_RXPCS_IDX_1	: integer := 31;

-- Table7: PCS Per Channel RX Control Register 3 for Channel 0
constant rcomp_pat_16_DP_RXPCS_IDX_0	: integer := 32;
constant rcomp_pat_17_DP_RXPCS_IDX_0	: integer := 33;
constant rcomp_pat_18_DP_RXPCS_IDX_0	: integer := 34;
constant rcomp_pat_19_DP_RXPCS_IDX_0	: integer := 35;
constant rcomp_pat_20_DP_RXPCS_IDX_0	: integer := 36;
constant rcomp_pat_21_DP_RXPCS_IDX_0	: integer := 37;
constant rcomp_pat_22_DP_RXPCS_IDX_0	: integer := 38;
constant rcomp_pat_23_DP_RXPCS_IDX_0	: integer := 39;
constant rcomp_pat_24_DP_RXPCS_IDX_0	: integer := 40;
constant rcomp_pat_25_DP_RXPCS_IDX_0	: integer := 41;
constant rcomp_pat_26_DP_RXPCS_IDX_0	: integer := 42;
constant rcomp_pat_27_DP_RXPCS_IDX_0	: integer := 43;
constant rcomp_pat_28_DP_RXPCS_IDX_0	: integer := 44;
constant rcomp_pat_29_DP_RXPCS_IDX_0	: integer := 45;
constant rcomp_pat_30_DP_RXPCS_IDX_0	: integer := 46;
constant rcomp_pat_31_DP_RXPCS_IDX_0	: integer := 47;

-- Table8: PCS Per Channel RX Control Register 4 for Channel 0
constant rcomp_pat_0_DP_RXPCS_IDX_0	: integer := 48;
constant rcomp_pat_1_DP_RXPCS_IDX_0	: integer := 49;
constant rcomp_pat_2_DP_RXPCS_IDX_0	: integer := 50;
constant rcomp_pat_3_DP_RXPCS_IDX_0	: integer := 51;
constant rcomp_pat_4_DP_RXPCS_IDX_0	: integer := 52;
constant rcomp_pat_5_DP_RXPCS_IDX_0	: integer := 53;
constant rcomp_pat_6_DP_RXPCS_IDX_0	: integer := 54;
constant rcomp_pat_7_DP_RXPCS_IDX_0	: integer := 55;
constant rcomp_pat_8_DP_RXPCS_IDX_0	: integer := 56;
constant rcomp_pat_9_DP_RXPCS_IDX_0	: integer := 57;
constant rcomp_pat_10_DP_RXPCS_IDX_0	: integer := 58;
constant rcomp_pat_11_DP_RXPCS_IDX_0	: integer := 59;
constant rcomp_pat_12_DP_RXPCS_IDX_0	: integer := 60;
constant rcomp_pat_13_DP_RXPCS_IDX_0	: integer := 61;
constant rcomp_pat_14_DP_RXPCS_IDX_0	: integer := 62;
constant rcomp_pat_15_DP_RXPCS_IDX_0	: integer := 63;

-- Table9: PCS Per Channel RX Control Register 5 for Channel 0
constant rbitloc_rev_en_DP_RXPCS_IDX_0	: integer := 64;
constant rbysync_polinv_en_DP_RXPCS_IDX_0	: integer := 65;
constant rwa_6g_en_DP_RXPCS_IDX_0	: integer := 66;
constant rosnumber_DP_RXPCS_IDX_0	: integer := 67;
constant rosnumber_DP_RXPCS_IDX_1	: integer := 68;
constant rosbased_DP_RXPCS_IDX_0	: integer := 69;
constant rkchar_DP_RXPCS_IDX_0	: integer := 70;
constant renumber_DP_RXPCS_IDX_0	: integer := 71;
constant renumber_DP_RXPCS_IDX_1	: integer := 72;
constant renumber_DP_RXPCS_IDX_2	: integer := 73;
constant renumber_DP_RXPCS_IDX_3	: integer := 74;
constant renumber_DP_RXPCS_IDX_4	: integer := 75;
constant renumber_DP_RXPCS_IDX_5	: integer := 76;
constant rib_inv_cd_DP_RXPCS_IDX_0	: integer := 77;
constant rib_inv_cd_DP_RXPCS_IDX_1	: integer := 78;
constant rsync_sm_dis_DP_RXPCS_IDX_0	: integer := 79;

-- Table10: PCS Per Channel RX Control Register 6 for Channel 0
constant rknumber_DP_RXPCS_IDX_0	: integer := 80;
constant rknumber_DP_RXPCS_IDX_1	: integer := 81;
constant rknumber_DP_RXPCS_IDX_2	: integer := 82;
constant rknumber_DP_RXPCS_IDX_3	: integer := 83;
constant rknumber_DP_RXPCS_IDX_4	: integer := 84;
constant rknumber_DP_RXPCS_IDX_5	: integer := 85;
constant rknumber_DP_RXPCS_IDX_6	: integer := 86;
constant rknumber_DP_RXPCS_IDX_7	: integer := 87;
constant rgnumber_DP_RXPCS_IDX_0	: integer := 88;
constant rgnumber_DP_RXPCS_IDX_1	: integer := 89;
constant rgnumber_DP_RXPCS_IDX_2	: integer := 90;
constant rgnumber_DP_RXPCS_IDX_3	: integer := 91;
constant rgnumber_DP_RXPCS_IDX_4	: integer := 92;
constant rgnumber_DP_RXPCS_IDX_5	: integer := 93;
constant rgnumber_DP_RXPCS_IDX_6	: integer := 94;
constant rgnumber_DP_RXPCS_IDX_7	: integer := 95;

-- Table11: PCS Per Channel RX Control Register 7 for Channel 0
constant renpolinv_rx_DP_RXPCS_IDX_0	: integer := 96;
constant rcascaded_8b10b_en_rx_DP_RXPCS_IDX_0	: integer := 97;
constant r8b10b_dec_ibm_en_DP_RXPCS_IDX_0	: integer := 98;
constant r8b10b_dec_ibm_en_DP_RXPCS_IDX_1	: integer := 99;
constant rendec_rx_DP_RXPCS_IDX_0	: integer := 100;
constant rautobtalg_dis_DP_RXPCS_IDX_0	: integer := 101;
constant rrlv_en_DP_RXPCS_IDX_0	: integer := 102;
constant rlp20ben_DP_RXPCS_IDX_0	: integer := 103;
constant rforce_sig_det_pcs_DP_RXPCS_IDX_0	: integer := 104;
constant rbyte_rev_en_DP_RXPCS_IDX_0	: integer := 105;
constant rrundisp_DP_RXPCS_IDX_0	: integer := 106;
constant rrundisp_DP_RXPCS_IDX_1	: integer := 107;
constant rrundisp_DP_RXPCS_IDX_2	: integer := 108;
constant rrundisp_DP_RXPCS_IDX_3	: integer := 109;
constant rrundisp_DP_RXPCS_IDX_4	: integer := 110;
constant rrundisp_DP_RXPCS_IDX_5	: integer := 111;

-- Table12: PCS Per Channel RX Control Register 8 for Channel 0
constant rclkcmpsq1p_DP_RXPCS_IDX_0	: integer := 112;
constant rclkcmpsq1p_DP_RXPCS_IDX_1	: integer := 113;
constant rclkcmpsq1p_DP_RXPCS_IDX_2	: integer := 114;
constant rclkcmpsq1p_DP_RXPCS_IDX_3	: integer := 115;
constant rclkcmpsq1p_DP_RXPCS_IDX_4	: integer := 116;
constant rclkcmpsq1p_DP_RXPCS_IDX_5	: integer := 117;
constant rclkcmpsq1p_DP_RXPCS_IDX_6	: integer := 118;
constant rclkcmpsq1p_DP_RXPCS_IDX_7	: integer := 119;
constant rclkcmpsq1p_DP_RXPCS_IDX_8	: integer := 120;
constant rclkcmpsq1p_DP_RXPCS_IDX_9	: integer := 121;
constant rclkcmpsqmd_DP_RXPCS_IDX_0	: integer := 122;
constant rclkcmpinsertpad_DP_RXPCS_IDX_0	: integer := 123;
constant rtruebac2bac_DP_RXPCS_IDX_0	: integer := 124;
constant rskpsetbased_DP_RXPCS_IDX_0	: integer := 125;
constant rgenericfifo_DP_RXPCS_IDX_0	: integer := 126;
constant rmatchen_DP_RXPCS_IDX_0	: integer := 127;

-- Table13: PCS Per Channel RX Control Register 9 for Channel 0
constant rclkcmpsq1p_10_DP_RXPCS_IDX_0	: integer := 128;
constant rclkcmpsq1p_11_DP_RXPCS_IDX_0	: integer := 129;
constant rclkcmpsq1p_12_DP_RXPCS_IDX_0	: integer := 130;
constant rclkcmpsq1p_13_DP_RXPCS_IDX_0	: integer := 131;
constant rclkcmpsq1p_14_DP_RXPCS_IDX_0	: integer := 132;
constant rclkcmpsq1p_15_DP_RXPCS_IDX_0	: integer := 133;
constant rclkcmpsq1p_16_DP_RXPCS_IDX_0	: integer := 134;
constant rclkcmpsq1p_17_DP_RXPCS_IDX_0	: integer := 135;
constant rclkcmpsq1p_18_DP_RXPCS_IDX_0	: integer := 136;
constant rclkcmpsq1p_19_DP_RXPCS_IDX_0	: integer := 137;
constant reserved_0_TB13_DP_RXPCS_IDX_0	: integer := 138;
constant rclkcmpsq1n_15_DP_RXPCS_IDX_0	: integer := 139;
constant rclkcmpsq1n_16_DP_RXPCS_IDX_0	: integer := 140;
constant rclkcmpsq1n_17_DP_RXPCS_IDX_0	: integer := 141;
constant rclkcmpsq1n_18_DP_RXPCS_IDX_0	: integer := 142;
constant rclkcmpsq1n_19_DP_RXPCS_IDX_0	: integer := 143;

-- Table14: PCS Per Channel RX Control Register 10 for Channel 0
constant rclkcmpsq1n_0_DP_RXPCS_IDX_0	: integer := 144;
constant rclkcmpsq1n_1_DP_RXPCS_IDX_0	: integer := 145;
constant rclkcmpsq1n_2_DP_RXPCS_IDX_0	: integer := 146;
constant rclkcmpsq1n_3_DP_RXPCS_IDX_0	: integer := 147;
constant rclkcmpsq1n_4_DP_RXPCS_IDX_0	: integer := 148;
constant rclkcmpsq1n_5_DP_RXPCS_IDX_0	: integer := 149;
constant rclkcmpsq1n_6_DP_RXPCS_IDX_0	: integer := 150;
constant rclkcmpsq1n_7_DP_RXPCS_IDX_0	: integer := 151;
constant rclkcmpsq1n_8_DP_RXPCS_IDX_0	: integer := 152;
constant rclkcmpsq1n_9_DP_RXPCS_IDX_0	: integer := 153;
constant reserved_0_TB14_DP_RXPCS_IDX_0	: integer := 154;
constant rclkcmpsq1n_10_DP_RXPCS_IDX_0	: integer := 155;
constant rclkcmpsq1n_11_DP_RXPCS_IDX_0	: integer := 156;
constant rclkcmpsq1n_12_DP_RXPCS_IDX_0	: integer := 157;
constant rclkcmpsq1n_13_DP_RXPCS_IDX_0	: integer := 158;
constant rclkcmpsq1n_14_DP_RXPCS_IDX_0	: integer := 159;

-- Table15: PCS Per Channel RX Control Register 11 for Channel 0
constant rfull_threshold_DP_RXPCS_IDX_0	: integer := 160;
constant rfull_threshold_DP_RXPCS_IDX_1	: integer := 161;
constant rfull_threshold_DP_RXPCS_IDX_2	: integer := 162;
constant rfull_threshold_DP_RXPCS_IDX_3	: integer := 163;
constant rfull_threshold_DP_RXPCS_IDX_4	: integer := 164;
constant rdel_threshold_DP_RXPCS_IDX_0	: integer := 165;
constant rdel_threshold_DP_RXPCS_IDX_1	: integer := 166;
constant rdel_threshold_DP_RXPCS_IDX_2	: integer := 167;
constant rdel_threshold_DP_RXPCS_IDX_3	: integer := 168;
constant rdel_threshold_DP_RXPCS_IDX_4	: integer := 169;
constant rins_threshold_DP_RXPCS_IDX_0	: integer := 170;
constant rins_threshold_DP_RXPCS_IDX_1	: integer := 171;
constant rins_threshold_DP_RXPCS_IDX_2	: integer := 172;
constant rins_threshold_DP_RXPCS_IDX_3	: integer := 173;
constant rins_threshold_DP_RXPCS_IDX_4	: integer := 174;
constant rclkcmp_pipe_en_DP_RXPCS_IDX_0	: integer := 175;

-- Table16: PCS Per Channel RX Control Register 12 for Channel 0
constant rfreq_sel_DP_RXPCS_IDX_0	: integer := 176;
constant rauto_speed_ena_DP_RXPCS_IDX_0	: integer := 177;
constant rhip_ena_DP_RXPCS_IDX_0	: integer := 178;
constant rpma_done_gen_ena_DP_RXPCS_IDX_0	: integer := 179;
constant rpma_done_count_DP_RXPCS_IDX_0	: integer := 180;
constant rpma_done_count_DP_RXPCS_IDX_1	: integer := 181;
constant reserved_0_TB16_DP_RXPCS_IDX_0	: integer := 182;
constant reserved_0_TB16_DP_RXPCS_IDX_1	: integer := 183;
constant reserved_0_TB16_DP_RXPCS_IDX_2	: integer := 184;
constant reserved_0_TB16_DP_RXPCS_IDX_3	: integer := 185;
constant rstart_threshold_DP_RXPCS_IDX_0	: integer := 186;
constant rstart_threshold_DP_RXPCS_IDX_1	: integer := 187;
constant rstart_threshold_DP_RXPCS_IDX_2	: integer := 188;
constant rempty_threshold_DP_RXPCS_IDX_0	: integer := 189;
constant rempty_threshold_DP_RXPCS_IDX_1	: integer := 190;
constant rempty_threshold_DP_RXPCS_IDX_2	: integer := 191;

-- Table17: PCS Per Channel RX Control Register 13 for Channel 0
constant rtest_bus_sel_DP_RXPCS_IDX_0	: integer := 192;
constant rtest_bus_sel_DP_RXPCS_IDX_1	: integer := 193;
constant rtest_bus_sel_DP_RXPCS_IDX_2	: integer := 194;
constant rtest_bus_sel_DP_RXPCS_IDX_3	: integer := 195;
constant rautoinsdis_DP_RXPCS_IDX_0	: integer := 196;
constant rphfifopldenrx_DP_RXPCS_IDX_0	: integer := 197;
constant rbytordplden_DP_RXPCS_IDX_0	: integer := 198;
constant rbyteorden_DP_RXPCS_IDX_0	: integer := 199;
constant rbyteorden_DP_RXPCS_IDX_1	: integer := 200;
constant rbytord_2sym_en_DP_RXPCS_IDX_0	: integer := 201;
constant rinvalid_code_err_only_DP_RXPCS_IDX_0	: integer := 202;
constant rcmpfifourst_DP_RXPCS_IDX_0	: integer := 203;
constant rphfifourstrx_DP_RXPCS_IDX_0	: integer := 204;
constant rdwidth_rx_DP_RXPCS_IDX_0	: integer := 205;
constant rrxfifo_lowlatency_en_DP_RXPCS_IDX_0	: integer := 206;
constant rrxfifo_dis_DP_RXPCS_IDX_0	: integer := 207;

-- Table18: PCS Per Channel RX Control Register 14 for Channel 0
constant rbytordpat_0_DP_RXPCS_IDX_0	: integer := 208;
constant rbytordpat_1_DP_RXPCS_IDX_0	: integer := 209;
constant rbytordpat_2_DP_RXPCS_IDX_0	: integer := 210;
constant rbytordpat_3_DP_RXPCS_IDX_0	: integer := 211;
constant rbytordpat_4_DP_RXPCS_IDX_0	: integer := 212;
constant rbytordpat_5_DP_RXPCS_IDX_0	: integer := 213;
constant rbytordpat_6_DP_RXPCS_IDX_0	: integer := 214;
constant rbytordpat_7_DP_RXPCS_IDX_0	: integer := 215;
constant rbytordpat_8_DP_RXPCS_IDX_0	: integer := 216;
constant rbytordpat_9_DP_RXPCS_IDX_0	: integer := 217;
constant reserved_0_TB18_DP_RXPCS_IDX_0	: integer := 218;
constant reserved_0_TB18_DP_RXPCS_IDX_1	: integer := 219;
constant reserved_0_TB18_DP_RXPCS_IDX_2	: integer := 220;
constant reserved_0_TB18_DP_RXPCS_IDX_3	: integer := 221;
constant reserved_0_TB18_DP_RXPCS_IDX_4	: integer := 222;
constant reserved_0_TB18_DP_RXPCS_IDX_5	: integer := 223;

-- Table19: PCS Per Channel RX Control Register 15 for Channel 0
constant rbytordpad_DP_RXPCS_IDX_0	: integer := 224;
constant rbytordpad_DP_RXPCS_IDX_1	: integer := 225;
constant rbytordpad_DP_RXPCS_IDX_2	: integer := 226;
constant rbytordpad_DP_RXPCS_IDX_3	: integer := 227;
constant rbytordpad_DP_RXPCS_IDX_4	: integer := 228;
constant rbytordpad_DP_RXPCS_IDX_5	: integer := 229;
constant rbytordpad_DP_RXPCS_IDX_6	: integer := 230;
constant rbytordpad_DP_RXPCS_IDX_7	: integer := 231;
constant rbytordpad_DP_RXPCS_IDX_8	: integer := 232;
constant rbytordpad_DP_RXPCS_IDX_9	: integer := 233;
constant reserved_0_TB19_DP_RXPCS_IDX_0	: integer := 234;
constant reserved_0_TB19_DP_RXPCS_IDX_1	: integer := 235;
constant reserved_0_TB19_DP_RXPCS_IDX_2	: integer := 236;
constant reserved_0_TB19_DP_RXPCS_IDX_3	: integer := 237;
constant reserved_0_TB19_DP_RXPCS_IDX_4	: integer := 238;
constant reserved_0_TB19_DP_RXPCS_IDX_5	: integer := 239;

-- Table20: PCS Per Channel RX Control Register 16 for Channel 0
constant rload_shreg_del_DP_RXPCS_IDX_0	: integer := 240;
constant rload_shreg_del_DP_RXPCS_IDX_1	: integer := 241;
constant rload_shreg_del_DP_RXPCS_IDX_2	: integer := 242;
constant rload_shreg_del_DP_RXPCS_IDX_3	: integer := 243;
constant rload_shreg_del_DP_RXPCS_IDX_4	: integer := 244;
constant rphystatus_rst_toggle_DP_RXPCS_IDX_0	: integer := 245;
constant reidle_com_detect_DP_RXPCS_IDX_0	: integer := 246;
constant reidle_com_detect_DP_RXPCS_IDX_1	: integer := 247;
constant rk285detect_DP_RXPCS_IDX_0	: integer := 248;
constant reidleinferenable_DP_RXPCS_IDX_0	: integer := 249;
constant rphystatus_delay_DP_RXPCS_IDX_0	: integer := 250;
constant rphystatus_delay_DP_RXPCS_IDX_1	: integer := 251;
constant rphystatus_delay_DP_RXPCS_IDX_2	: integer := 252;
constant rind_error_reporting_DP_RXPCS_IDX_0	: integer := 253;
constant rrx_detect_bypass_DP_RXPCS_IDX_0	: integer := 254;
constant rrx_pipe_enable_DP_RXPCS_IDX_0	: integer := 255;

-- Table21: PCS Per Channel RX Control Register 17 for Channel 0
constant rpma_done_count_0_DP_RXPCS_IDX_0	: integer := 256;
constant rpma_done_count_1_DP_RXPCS_IDX_0	: integer := 257;
constant rpma_done_count_2_DP_RXPCS_IDX_0	: integer := 258;
constant rpma_done_count_3_DP_RXPCS_IDX_0	: integer := 259;
constant rpma_done_count_4_DP_RXPCS_IDX_0	: integer := 260;
constant rpma_done_count_5_DP_RXPCS_IDX_0	: integer := 261;
constant rpma_done_count_6_DP_RXPCS_IDX_0	: integer := 262;
constant rpma_done_count_7_DP_RXPCS_IDX_0	: integer := 263;
constant rpma_done_count_8_DP_RXPCS_IDX_0	: integer := 264;
constant rpma_done_count_9_DP_RXPCS_IDX_0	: integer := 265;
constant rpma_done_count_10_DP_RXPCS_IDX_0	: integer := 266;
constant rpma_done_count_11_DP_RXPCS_IDX_0	: integer := 267;
constant rpma_done_count_12_DP_RXPCS_IDX_0	: integer := 268;
constant rpma_done_count_13_DP_RXPCS_IDX_0	: integer := 269;
constant rpma_done_count_14_DP_RXPCS_IDX_0	: integer := 270;
constant rpma_done_count_15_DP_RXPCS_IDX_0	: integer := 271;

-- Table22: PCS Per Channel RX Control Register 18 for Channel 0
constant rbytordpat_10_DP_RXPCS_IDX_0	: integer := 272;
constant rbytordpat_11_DP_RXPCS_IDX_0	: integer := 273;
constant rbytordpat_12_DP_RXPCS_IDX_0	: integer := 274;
constant rbytordpat_13_DP_RXPCS_IDX_0	: integer := 275;
constant rbytordpat_14_DP_RXPCS_IDX_0	: integer := 276;
constant rbytordpat_15_DP_RXPCS_IDX_0	: integer := 277;
constant rbytordpat_16_DP_RXPCS_IDX_0	: integer := 278;
constant rbytordpat_17_DP_RXPCS_IDX_0	: integer := 279;
constant rbytordpat_18_DP_RXPCS_IDX_0	: integer := 280;
constant rbytordpat_19_DP_RXPCS_IDX_0	: integer := 281;
constant rbytord_6g_mask_en_DP_RXPCS_IDX_0	: integer := 282;
constant rbytord_s2gx_DP_RXPCS_IDX_0	: integer := 283;
constant reserved_0_TB22_DP_RXPCS_IDX_0	: integer := 284;
constant rcdr_ctrl_en_DP_RXPCS_IDX_0	: integer := 285;
constant rrxpcsclkpwdn_DP_RXPCS_IDX_0	: integer := 286;
constant rerr_flags_sel_DP_RXPCS_IDX_0	: integer := 287;

-- Table23: PCS Per Channel RX Control Register 19 for Channel 0
constant rwait_count_DP_RXPCS_IDX_0	: integer := 288;
constant rwait_count_DP_RXPCS_IDX_1	: integer := 289;
constant rwait_count_DP_RXPCS_IDX_2	: integer := 290;
constant rwait_count_DP_RXPCS_IDX_3	: integer := 291;
constant rwait_count_DP_RXPCS_IDX_4	: integer := 292;
constant rwait_count_DP_RXPCS_IDX_5	: integer := 293;
constant rwait_count_DP_RXPCS_IDX_6	: integer := 294;
constant rwait_count_DP_RXPCS_IDX_7	: integer := 295;
constant reserved_0_TB23_DP_RXPCS_IDX_0	: integer := 296;
constant reserved_0_TB23_DP_RXPCS_IDX_1	: integer := 297;
constant reserved_0_TB23_DP_RXPCS_IDX_2	: integer := 298;
constant reserved_0_TB23_DP_RXPCS_IDX_3	: integer := 299;
constant reserved_0_TB23_DP_RXPCS_IDX_4	: integer := 300;
constant reserved_0_TB23_DP_RXPCS_IDX_5	: integer := 301;
constant reserved_0_TB23_DP_RXPCS_IDX_6	: integer := 302;
constant reserved_0_TB23_DP_RXPCS_IDX_7	: integer := 303;

-- Table24: PCS Per Channel RX Control Register 20 for Channel 0
constant rfts_count_DP_RXPCS_IDX_0	: integer := 304;
constant rfts_count_DP_RXPCS_IDX_1	: integer := 305;
constant rfts_count_DP_RXPCS_IDX_2	: integer := 306;
constant rfts_count_DP_RXPCS_IDX_3	: integer := 307;
constant rfts_count_DP_RXPCS_IDX_4	: integer := 308;
constant rfts_count_DP_RXPCS_IDX_5	: integer := 309;
constant rfts_count_DP_RXPCS_IDX_6	: integer := 310;
constant rfts_count_DP_RXPCS_IDX_7	: integer := 311;
constant rfts_count_DP_RXPCS_IDX_8	: integer := 312;
constant rfts_count_DP_RXPCS_IDX_9	: integer := 313;
constant rwait_for_phfifo_cnt_DP_RXPCS_IDX_0	: integer := 314;
constant rwait_for_phfifo_cnt_DP_RXPCS_IDX_1	: integer := 315;
constant rwait_for_phfifo_cnt_DP_RXPCS_IDX_2	: integer := 316;
constant rwait_for_phfifo_cnt_DP_RXPCS_IDX_3	: integer := 317;
constant rwait_for_phfifo_cnt_DP_RXPCS_IDX_4	: integer := 318;
constant rwait_for_phfifo_cnt_DP_RXPCS_IDX_5	: integer := 319;

-- Table25: PCS Per Channel RX Control Register 21 for Channel 0
constant rppm_meas_delay_DP_RXPCS_IDX_0	: integer := 320;
constant rcid_len_rx_DP_RXPCS_IDX_0	: integer := 321;
constant rcid_len_rx_DP_RXPCS_IDX_1	: integer := 322;
constant rcid_len_rx_DP_RXPCS_IDX_2	: integer := 323;
constant rcid_len_rx_DP_RXPCS_IDX_3	: integer := 324;
constant rcid_len_rx_DP_RXPCS_IDX_4	: integer := 325;
constant rcid_len_rx_DP_RXPCS_IDX_5	: integer := 326;
constant rcid_len_rx_DP_RXPCS_IDX_6	: integer := 327;
constant rcid_len_rx_DP_RXPCS_IDX_7	: integer := 328;
constant rcid_pattern_rx_DP_RXPCS_IDX_0	: integer := 329;
constant rpcs_wrapback_en_DP_RXPCS_IDX_0	: integer := 330;
constant reserved_0_TB25_DP_RXPCS_IDX_0	: integer := 331;
constant reserved_0_TB25_DP_RXPCS_IDX_1	: integer := 332;
constant reserved_0_TB25_DP_RXPCS_IDX_2	: integer := 333;
constant reserved_0_TB25_DP_RXPCS_IDX_3	: integer := 334;
constant reserved_0_TB25_DP_RXPCS_IDX_4	: integer := 335;

-- Table26: PCS Per Channel RX Control Register 22 for Channel 0
constant rauto_pc_en_cnt_DP_RXPCS_IDX_0	: integer := 336;
constant rauto_pc_en_cnt_DP_RXPCS_IDX_1	: integer := 337;
constant rauto_pc_en_cnt_DP_RXPCS_IDX_2	: integer := 338;
constant rauto_pc_en_cnt_DP_RXPCS_IDX_3	: integer := 339;
constant rauto_pc_en_cnt_DP_RXPCS_IDX_4	: integer := 340;
constant reserved_1_TB26_DP_RXPCS_IDX_0	: integer := 341;
constant rauto_deassert_pc_rst_cnt_DP_RXPCS_IDX_0	: integer := 342;
constant rauto_deassert_pc_rst_cnt_DP_RXPCS_IDX_1	: integer := 343;
constant rauto_deassert_pc_rst_cnt_DP_RXPCS_IDX_2	: integer := 344;
constant rauto_deassert_pc_rst_cnt_DP_RXPCS_IDX_3	: integer := 345;
constant reserved_0_TB26_DP_RXPCS_IDX_0	: integer := 346;
constant rpipeline_bypass_rx_DP_RXPCS_IDX_0	: integer := 347;
constant rself_sw_en_rx_DP_RXPCS_IDX_0	: integer := 348;
constant rrxvalid_mask_DP_RXPCS_IDX_0	: integer := 349;
constant rcid_en_DP_RXPCS_IDX_0	: integer := 350;
constant rphfifo_regmode_rx_DP_RXPCS_IDX_0	: integer := 351;

-- Table27: PCS Per Channel RX Control Register 23 for Channel 0
constant rmask_count_DP_RXPCS_IDX_0	: integer := 352;
constant rmask_count_DP_RXPCS_IDX_1	: integer := 353;
constant rmask_count_DP_RXPCS_IDX_2	: integer := 354;
constant rmask_count_DP_RXPCS_IDX_3	: integer := 355;
constant rmask_count_DP_RXPCS_IDX_4	: integer := 356;
constant rmask_count_DP_RXPCS_IDX_5	: integer := 357;
constant rmask_count_DP_RXPCS_IDX_6	: integer := 358;
constant rmask_count_DP_RXPCS_IDX_7	: integer := 359;
constant rmask_count_DP_RXPCS_IDX_8	: integer := 360;
constant rmask_count_DP_RXPCS_IDX_9	: integer := 361;
constant rgen1_sigdet_ena_DP_RXPCS_IDX_0	: integer := 362;
constant riei_eios_priority_dis_DP_RXPCS_IDX_0	: integer := 363;
constant reserved_0_TB27_DP_RXPCS_IDX_0	: integer := 364;
constant reserved_0_TB27_DP_RXPCS_IDX_1	: integer := 365;
constant reserved_0_TB27_DP_RXPCS_IDX_2	: integer := 366;
constant reserved_0_TB27_DP_RXPCS_IDX_3	: integer := 367;
   
-- Table28: PMA Per Channel TX Control Register 1 for Channel 0
constant rpowdnt_DP_TXPMA_IDX_0	: integer := 0;
constant rvod_seld_DP_TXPMA_IDX_0	: integer := 1;
constant rvod_seld_DP_TXPMA_IDX_1	: integer := 2;
constant rvod_seld_DP_TXPMA_IDX_2	: integer := 3;
constant rvod_selc_DP_TXPMA_IDX_0	: integer := 4;
constant rvod_selc_DP_TXPMA_IDX_1	: integer := 5;
constant rvod_selc_DP_TXPMA_IDX_2	: integer := 6;
constant rvod_selb_DP_TXPMA_IDX_0	: integer := 7;
constant rvod_selb_DP_TXPMA_IDX_1	: integer := 8;
constant rvod_selb_DP_TXPMA_IDX_2	: integer := 9;
constant rvod_sela_DP_TXPMA_IDX_0	: integer := 10;
constant rvod_sela_DP_TXPMA_IDX_1	: integer := 11;
constant rvod_sela_DP_TXPMA_IDX_2	: integer := 12;
constant rvod_sel_non_pcie_DP_TXPMA_IDX_0	: integer := 13;
constant rvod_sel_non_pcie_DP_TXPMA_IDX_1	: integer := 14;
constant rvod_sel_non_pcie_DP_TXPMA_IDX_2	: integer := 15;

-- Table29: PMA Per Channel TX Control Register 2 for Channel 0
constant reserved_0_TB29_DP_TXPMA_IDX_0	: integer := 16;
constant rpre_em_1t_b_DP_TXPMA_IDX_0	: integer := 17;
constant rpre_em_1t_b_DP_TXPMA_IDX_1	: integer := 18;
constant rpre_em_1t_b_DP_TXPMA_IDX_2	: integer := 19;
constant rpre_em_1t_b_DP_TXPMA_IDX_3	: integer := 20;
constant rpre_em_1t_b_DP_TXPMA_IDX_4	: integer := 21;
constant rpre_em_1t_a_DP_TXPMA_IDX_0	: integer := 22;
constant rpre_em_1t_a_DP_TXPMA_IDX_1	: integer := 23;
constant rpre_em_1t_a_DP_TXPMA_IDX_2	: integer := 24;
constant rpre_em_1t_a_DP_TXPMA_IDX_3	: integer := 25;
constant rpre_em_1t_a_DP_TXPMA_IDX_4	: integer := 26;
constant rpre_em_1t_no_pcie_DP_TXPMA_IDX_0	: integer := 27;
constant rpre_em_1t_no_pcie_DP_TXPMA_IDX_1	: integer := 28;
constant rpre_em_1t_no_pcie_DP_TXPMA_IDX_2	: integer := 29;
constant rpre_em_1t_no_pcie_DP_TXPMA_IDX_3	: integer := 30;
constant rpre_em_1t_no_pcie_DP_TXPMA_IDX_4	: integer := 31;

-- Table30: PMA Per Channel TX Control Register 3 for Channel 0
constant rpre_em_pt_DP_TXPMA_IDX_0	: integer := 32;
constant rpre_em_pt_DP_TXPMA_IDX_1	: integer := 33;
constant rpre_em_pt_DP_TXPMA_IDX_2	: integer := 34;
constant rpre_em_pt_DP_TXPMA_IDX_3	: integer := 35;
constant rpre_em_2t_DP_TXPMA_IDX_0	: integer := 36;
constant rpre_em_2t_DP_TXPMA_IDX_1	: integer := 37;
constant rpre_em_2t_DP_TXPMA_IDX_2	: integer := 38;
constant rpre_em_2t_DP_TXPMA_IDX_3	: integer := 39;
constant rpre_em_1t_c_DP_TXPMA_IDX_0	: integer := 40;
constant rpre_em_1t_c_DP_TXPMA_IDX_1	: integer := 41;
constant rpre_em_1t_c_DP_TXPMA_IDX_2	: integer := 42;
constant rpre_em_1t_c_DP_TXPMA_IDX_3	: integer := 43;
constant rpre_em_1t_c_DP_TXPMA_IDX_4	: integer := 44;
constant reserved_0_TB30_DP_TXPMA_IDX_0	: integer := 45;
constant reserved_0_TB30_DP_TXPMA_IDX_1	: integer := 46;
constant reserved_0_TB30_DP_TXPMA_IDX_2	: integer := 47;

-- Table31: PMA Per Channel TX Control Register 4 for Channel 0
constant rlowv_DP_TXPMA_IDX_0	: integer := 48;
constant rrx_det_DP_TXPMA_IDX_0	: integer := 49;
constant rrx_det_DP_TXPMA_IDX_1	: integer := 50;
constant rsig_inv_2t_DP_TXPMA_IDX_0	: integer := 51;
constant rsig_inv_ptap_DP_TXPMA_IDX_0	: integer := 52;
constant rslew_DP_TXPMA_IDX_0	: integer := 53;
constant rslew_DP_TXPMA_IDX_1	: integer := 54;
constant rtx_lst_DP_TXPMA_IDX_0	: integer := 55;
constant rtx_lst_DP_TXPMA_IDX_1	: integer := 56;
constant rtx_lst_DP_TXPMA_IDX_2	: integer := 57;
constant rtx_lst_DP_TXPMA_IDX_3	: integer := 58;
constant rtx_vtt_DP_TXPMA_IDX_0	: integer := 59;
constant rtx_vtt_DP_TXPMA_IDX_1	: integer := 60;
constant rtx_term_sel_DP_TXPMA_IDX_0	: integer := 61;
constant rtx_term_sel_DP_TXPMA_IDX_1	: integer := 62;
constant rtx_term_sel_DP_TXPMA_IDX_2	: integer := 63;

-- Table32: PMA Per Channel TX Control Register 5 for Channel 0
constant reserved_1_TB32_DP_TXPMA_IDX_0	: integer := 64;
constant reserved_1_TB32_DP_TXPMA_IDX_1	: integer := 65;
constant reserved_1_TB32_DP_TXPMA_IDX_2	: integer := 66;
constant reserved_1_TB32_DP_TXPMA_IDX_3	: integer := 67;
constant reserved_1_TB32_DP_TXPMA_IDX_4	: integer := 68;
constant reserved_1_TB32_DP_TXPMA_IDX_5	: integer := 69;
constant reserved_1_TB32_DP_TXPMA_IDX_6	: integer := 70;
constant reserved_1_TB32_DP_TXPMA_IDX_7	: integer := 71;
constant reserved_1_TB32_DP_TXPMA_IDX_8	: integer := 72;
constant reserved_1_TB32_DP_TXPMA_IDX_9	: integer := 73;
constant reserved_1_TB32_DP_TXPMA_IDX_10	: integer := 74;
constant rtx_ob_pdb_DP_TXPMA_IDX_0	: integer := 75;
constant reserved_0_TB32_DP_TXPMA_IDX_0	: integer := 76;
constant r_dft_sel_DP_TXPMA_IDX_0	: integer := 77;
constant r_dft_sel_DP_TXPMA_IDX_1	: integer := 78;
constant r_dft_sel_DP_TXPMA_IDX_2	: integer := 79;

-- Table33: PMA Per Channel TX Control Register 6 for Channel 0
constant reserved_0_TB33_DP_TXPMA_IDX_0	: integer := 80;
constant reserved_0_TB33_DP_TXPMA_IDX_1	: integer := 81;
constant reserved_0_TB33_DP_TXPMA_IDX_2	: integer := 82;
constant reserved_0_TB33_DP_TXPMA_IDX_3	: integer := 83;
constant rtx_cgb_pdb_DP_TXPMA_IDX_0	: integer := 84;
constant rpclksel_DP_TXPMA_IDX_0	: integer := 85;
constant rdynamic_sw_DP_TXPMA_IDX_0	: integer := 86;
constant rs_lpbk_DP_TXPMA_IDX_0	: integer := 87;
constant rcgb_delay_sel_DP_TXPMA_IDX_0	: integer := 88;
constant rpmadwidth_tx_DP_TXPMA_IDX_0	: integer := 89;
constant rpma_doublewidth_tx_DP_TXPMA_IDX_0	: integer := 90;
constant rcgb_m_sel_DP_TXPMA_IDX_0	: integer := 91;
constant rcgb_m_sel_DP_TXPMA_IDX_1	: integer := 92;
constant rcgb_cmu_sel_DP_TXPMA_IDX_0	: integer := 93;
constant rcgb_x_en_DP_TXPMA_IDX_0	: integer := 94;
constant rcgb_x_en_DP_TXPMA_IDX_1	: integer := 95;

-- Table34: PMA Per Channel TX Control Register 7 for Channel 0
constant reserved_1_TB34_DP_TXPMA_IDX_0	: integer := 96;
constant reserved_1_TB34_DP_TXPMA_IDX_1	: integer := 97;
constant reserved_1_TB34_DP_TXPMA_IDX_2	: integer := 98;
constant rpcs_sd_sel_DP_TXPMA_IDX_0	: integer := 99;
constant rrx_refclk_DP_TXPMA_IDX_0	: integer := 100;
constant rimpctrl_DP_TXPMA_IDX_0	: integer := 101;
constant reserved_0_TB34_DP_TXPMA_IDX_0	: integer := 102;
constant reserved_0_TB34_DP_TXPMA_IDX_1	: integer := 103;
constant reserved_0_TB34_DP_TXPMA_IDX_2	: integer := 104;
constant reserved_0_TB34_DP_TXPMA_IDX_3	: integer := 105;
constant rrevlb_sw_DP_TXPMA_IDX_0	: integer := 106;
constant rvcobypass_DP_TXPMA_IDX_0	: integer := 107;
constant rrefclk_sel_DP_TXPMA_IDX_0	: integer := 108;
constant rrefclk_sel_DP_TXPMA_IDX_1	: integer := 109;
constant riqclk_sel_DP_TXPMA_IDX_0	: integer := 110;
constant riqclk_sel_DP_TXPMA_IDX_1	: integer := 111;

-- Table35: PMA Per Channel TX Control Register 8 for Channel 0
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_0	: integer := 112;
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_1	: integer := 113;
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_2	: integer := 114;
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_3	: integer := 115;
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_4	: integer := 116;
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_5	: integer := 117;
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_6	: integer := 118;
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_7	: integer := 119;
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_8	: integer := 120;
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_9	: integer := 121;
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_10	: integer := 122;
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_11	: integer := 123;
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_12	: integer := 124;
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_13	: integer := 125;
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_14	: integer := 126;
constant rpma_reserved_0_TB35_DP_TXPMA_IDX_15	: integer := 127;

-- Table36: PMA Per Channel RX Control Register 1 for Channel 0
constant rrx_term_sel_DP_RXPMA_IDX_0	: integer := 0;
constant rrx_term_sel_DP_RXPMA_IDX_1	: integer := 1;
constant rrx_term_sel_DP_RXPMA_IDX_2	: integer := 2;
constant rrx_vtt_DP_RXPMA_IDX_0	: integer := 3;
constant rrx_vtt_DP_RXPMA_IDX_1	: integer := 4;
constant rrx_vtt_DP_RXPMA_IDX_2	: integer := 5;
constant rrx_s_rdlpbk_DP_RXPMA_IDX_0	: integer := 6;
constant rrx_bit_dc_DP_RXPMA_IDX_0	: integer := 7;
constant rrx_bit_dc_DP_RXPMA_IDX_1	: integer := 8;
constant rrx_bit_dc_DP_RXPMA_IDX_2	: integer := 9;
constant rrx_bit_dc_DP_RXPMA_IDX_3	: integer := 10;
constant rrx_lst_DP_RXPMA_IDX_0	: integer := 11;
constant rrx_lst_DP_RXPMA_IDX_1	: integer := 12;
constant rrx_lst_DP_RXPMA_IDX_2	: integer := 13;
constant rrx_lst_DP_RXPMA_IDX_3	: integer := 14;
constant rrx_lst_DP_RXPMA_IDX_4	: integer := 15;

-- Table37: PMA Per Channel RX Control Register 2 for Channel 0
constant rrxurstpma_DP_RXPMA_IDX_0	: integer := 16;
constant rrx_test_DP_RXPMA_IDX_0	: integer := 17;
constant rrx_sd_force_DP_RXPMA_IDX_0	: integer := 18;
constant rrx_oc_DP_RXPMA_IDX_0	: integer := 19;
constant rrx_oc_DP_RXPMA_IDX_1	: integer := 20;
constant rrx_oc_DP_RXPMA_IDX_2	: integer := 21;
constant rrx_oc_DP_RXPMA_IDX_3	: integer := 22;
constant rrx_oc_DP_RXPMA_IDX_4	: integer := 23;
constant rrx_oc_DP_RXPMA_IDX_5	: integer := 24;
constant rrx_oc_DP_RXPMA_IDX_6	: integer := 25;
constant rrx_oc_DP_RXPMA_IDX_7	: integer := 26;
constant rrx_oc_en_DP_RXPMA_IDX_0	: integer := 27;
constant rrx_sdlv_DP_RXPMA_IDX_0	: integer := 28;
constant rrx_sdlv_DP_RXPMA_IDX_1	: integer := 29;
constant rrx_sdlv_DP_RXPMA_IDX_2	: integer := 30;
constant rrx_sdlv_DP_RXPMA_IDX_3	: integer := 31;

-- Table38: PMA Per Channel RX Control Register 3 for Channel 0
constant reserved_0_TB38_DP_RXPMA_IDX_0	: integer := 32;
constant reserved_0_TB38_DP_RXPMA_IDX_1	: integer := 33;
constant reserved_0_TB38_DP_RXPMA_IDX_2	: integer := 34;
constant rpowdnr_DP_RXPMA_IDX_0	: integer := 35;
constant rrx_ib_pdb_DP_RXPMA_IDX_0	: integer := 36;
constant rurx_pdb_DP_RXPMA_IDX_0	: integer := 37;
constant rrx_oc_calpd_DP_RXPMA_IDX_0	: integer := 38;
constant rrx_sd_off_DP_RXPMA_IDX_0	: integer := 39;
constant rrx_sd_off_DP_RXPMA_IDX_1	: integer := 40;
constant rrx_sd_off_DP_RXPMA_IDX_2	: integer := 41;
constant rrx_sd_off_DP_RXPMA_IDX_3	: integer := 42;
constant rrx_sd_off_DP_RXPMA_IDX_4	: integer := 43;
constant rrx_sd_on_DP_RXPMA_IDX_0	: integer := 44;
constant rrx_sd_on_DP_RXPMA_IDX_1	: integer := 45;
constant rrx_sd_on_DP_RXPMA_IDX_2	: integer := 46;
constant rrx_sd_on_DP_RXPMA_IDX_3	: integer := 47;

-- Table39: PMA Per Channel RX Control Register 4 for Channel 0	(RXPLL)
constant rcru_pdbwctrl_DP_PLL_IDX_0	: integer := 0;
constant rcru_pdbwctrl_DP_PLL_IDX_1	: integer := 1;
constant rcru_pfdbwctrl_DP_PLL_IDX_0	: integer := 2;
constant rcru_pfdbwctrl_DP_PLL_IDX_1	: integer := 3;
constant rcru_crplctrl_DP_PLL_IDX_0	: integer := 4;
constant rcru_crplctrl_DP_PLL_IDX_1	: integer := 5;
constant rcru_ctl0_DP_PLL_IDX_0	: integer := 6;
constant rcru_l_DP_PLL_IDX_0	: integer := 7;
constant rcru_l_DP_PLL_IDX_1	: integer := 8;
constant rcru_m_DP_PLL_IDX_0	: integer := 9;
constant rcru_m_DP_PLL_IDX_1	: integer := 10;
constant rcru_m_DP_PLL_IDX_2	: integer := 11;
constant rcru_m_DP_PLL_IDX_3	: integer := 12;
constant rcru_m_sel_DP_PLL_IDX_0	: integer := 13;
constant rcru_m_sel_DP_PLL_IDX_1	: integer := 14;
constant rcru_div2_DP_PLL_IDX_0	: integer := 15;

-- Table40: PMA Per Channel RX Control Register 5 for Channel 0	(RXPLL)
constant reserved_0_TB40_DP_PLL_IDX_0	: integer := 16;
constant reserved_0_TB40_DP_PLL_IDX_1	: integer := 17;
constant rcru_iselpd_DP_PLL_IDX_0	: integer := 18;
constant rcru_iselpd_DP_PLL_IDX_1	: integer := 19;
constant rcru_iselpd_DP_PLL_IDX_2	: integer := 20;
constant rcru_isel_DP_PLL_IDX_0	: integer := 21;
constant rcru_isel_DP_PLL_IDX_1	: integer := 22;
constant rcru_isel_DP_PLL_IDX_2	: integer := 23;
constant rcru_testdnen_DP_PLL_IDX_0	: integer := 24;
constant rcru_testupen_DP_PLL_IDX_0	: integer := 25;
constant rcru_testen_DP_PLL_IDX_0	: integer := 26;
constant rcru_lst_DP_PLL_IDX_0	: integer := 27;
constant rcru_lst_DP_PLL_IDX_1	: integer := 28;
constant rcru_lst_DP_PLL_IDX_2	: integer := 29;
constant rcru_lst_DP_PLL_IDX_3	: integer := 30;
constant rcru_rlbk_DP_PLL_IDX_0	: integer := 31;

-- Table41: PMA Per Channel RX Control Register 6 for Channel 0	(RXPLL)
constant rcru_rgla_isel_DP_PLL_IDX_0	: integer := 32;
constant rcru_rgla_isel_DP_PLL_IDX_1	: integer := 33;
constant rcru_rgla_isel_DP_PLL_IDX_2	: integer := 34;
constant rcru_pdof_test_DP_PLL_IDX_0	: integer := 35;
constant rcru_pdof_test_DP_PLL_IDX_1	: integer := 36;
constant rcru_pdof_test_DP_PLL_IDX_2	: integer := 37;
constant rcru_pdfl_DP_PLL_IDX_0	: integer := 38;
constant rcru_sd_sel_DP_PLL_IDX_0	: integer := 39;
constant reserved_0_TB41_DP_PLL_IDX_0	: integer := 40;
constant rcru_ignore_phslck_DP_PLL_IDX_0	: integer := 41;
constant rcru_cmu_mode_DP_PLL_IDX_0	: integer := 42;
constant rrx_cru_rst_DP_PLL_IDX_0	: integer := 43;
constant rrx_cru_pdb_DP_PLL_IDX_0	: integer := 44;
constant rltr_DP_PLL_IDX_0	: integer := 45;
constant rltd_DP_PLL_IDX_0	: integer := 46;
constant rcp_mode_DP_PLL_IDX_0	: integer := 47;

-- Table42: PMA Per Channel RX Control Register 7 for Channel 0	(RXPLL)
constant rcru_pdof_270i_DP_PLL_IDX_0	: integer := 48;
constant rcru_pdof_270i_DP_PLL_IDX_1	: integer := 49;
constant rcru_pdof_270i_DP_PLL_IDX_2	: integer := 50;
constant rcru_pdof_270i_DP_PLL_IDX_3	: integer := 51;
constant rcru_pdof_180i_DP_PLL_IDX_0	: integer := 52;
constant rcru_pdof_180i_DP_PLL_IDX_1	: integer := 53;
constant rcru_pdof_180i_DP_PLL_IDX_2	: integer := 54;
constant rcru_pdof_180i_DP_PLL_IDX_3	: integer := 55;
constant rcru_pdof_90i_DP_PLL_IDX_0	: integer := 56;
constant rcru_pdof_90i_DP_PLL_IDX_1	: integer := 57;
constant rcru_pdof_90i_DP_PLL_IDX_2	: integer := 58;
constant rcru_pdof_90i_DP_PLL_IDX_3	: integer := 59;
constant rcru_pdof_0i_DP_PLL_IDX_0	: integer := 60;
constant rcru_pdof_0i_DP_PLL_IDX_1	: integer := 61;
constant rcru_pdof_0i_DP_PLL_IDX_2	: integer := 62;
constant rcru_pdof_0i_DP_PLL_IDX_3	: integer := 63;

-- Table43: PMA Per Channel RX Control Register 8 for Channel 0
constant reye_monitor_DP_RXPMA_IDX_0	: integer := 112;
constant reye_monitor_DP_RXPMA_IDX_1	: integer := 113;
constant reye_monitor_DP_RXPMA_IDX_2	: integer := 114;
constant reye_monitor_DP_RXPMA_IDX_3	: integer := 115;
constant reye_monitor_DP_RXPMA_IDX_4	: integer := 116;
constant reye_monitor_DP_RXPMA_IDX_5	: integer := 117;
constant reye_monitor_DP_RXPMA_IDX_6	: integer := 118;
constant reye_monitor_DP_RXPMA_IDX_7	: integer := 119;
constant reserved_0_TB43_DP_RXPMA_IDX_0	: integer := 120;
constant reserved_0_TB43_DP_RXPMA_IDX_1	: integer := 121;
constant reserved_0_TB43_DP_RXPMA_IDX_2	: integer := 122;
constant reserved_0_TB43_DP_RXPMA_IDX_3	: integer := 123;
constant reserved_0_TB43_DP_RXPMA_IDX_4	: integer := 124;
constant reserved_0_TB43_DP_RXPMA_IDX_5	: integer := 125;
constant reserved_0_TB43_DP_RXPMA_IDX_6	: integer := 126;
constant reserved_0_TB43_DP_RXPMA_IDX_7	: integer := 127;

-- Table44: PMA Per Channel RX Control Register 9 for Channel 0
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_0	: integer := 128;
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_1	: integer := 129;
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_2	: integer := 130;
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_3	: integer := 131;
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_4	: integer := 132;
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_5	: integer := 133;
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_6	: integer := 134;
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_7	: integer := 135;
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_8	: integer := 136;
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_9	: integer := 137;
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_10	: integer := 138;
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_11	: integer := 139;
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_12	: integer := 140;
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_13	: integer := 141;
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_14	: integer := 142;
constant rpma_reserved_0_TB44_DP_RXPMA_IDX_15	: integer := 143;

-- Table45: PMA Per Channel RX Control Register 10 for Channel 0
constant rppm_cnt_reset_DP_RXPMA_IDX_0	: integer := 144;
constant rforce1_freqdet_DP_RXPMA_IDX_0	: integer := 145;
constant rforce0_freqdet_DP_RXPMA_IDX_0	: integer := 146;
constant rppmsel_DP_RXPMA_IDX_0	: integer := 147;
constant rppmsel_DP_RXPMA_IDX_1	: integer := 148;
constant rppmsel_DP_RXPMA_IDX_2	: integer := 149;
constant rppmsel_DP_RXPMA_IDX_3	: integer := 150;
constant rppmsel_DP_RXPMA_IDX_4	: integer := 151;
constant rppmsel_DP_RXPMA_IDX_5	: integer := 152;
constant rfastsd_DP_RXPMA_IDX_0	: integer := 153;
constant rfastsd_DP_RXPMA_IDX_1	: integer := 154;
constant rfastsd_DP_RXPMA_IDX_2	: integer := 155;
constant rfastsd_DP_RXPMA_IDX_3	: integer := 156;
constant rtest_fastsd_DP_RXPMA_IDX_0	: integer := 157;
constant rpmadwidth_rx_DP_RXPMA_IDX_0	: integer := 158;
constant rpma_doublewidth_rx_DP_RXPMA_IDX_0	: integer := 159;

-- Table46: PMA Per Channel RX Control Register 11 for Channel 0
constant reserved_0_TB46_DP_RXPMA_IDX_0	: integer := 160;
constant reserved_0_TB46_DP_RXPMA_IDX_1	: integer := 161;
constant reserved_0_TB46_DP_RXPMA_IDX_2	: integer := 162;
constant reserved_0_TB46_DP_RXPMA_IDX_3	: integer := 163;
constant reserved_0_TB46_DP_RXPMA_IDX_4	: integer := 164;
constant reserved_0_TB46_DP_RXPMA_IDX_5	: integer := 165;
constant reserved_0_TB46_DP_RXPMA_IDX_6	: integer := 166;
constant reserved_0_TB46_DP_RXPMA_IDX_7	: integer := 167;
constant rppm_gen1_2xcnt_en_DP_RXPMA_IDX_0	: integer := 168;
constant rppm_post_eidle_del_DP_RXPMA_IDX_0	: integer := 169;
constant r_dfe_2t_DP_RXPMA_IDX_0	: integer := 170;
constant r_dfe_2t_DP_RXPMA_IDX_1	: integer := 171;
constant r_dfe_2t_DP_RXPMA_IDX_2	: integer := 172;
constant r_dfe_1t_DP_RXPMA_IDX_0	: integer := 173;
constant r_dfe_1t_DP_RXPMA_IDX_1	: integer := 174;
constant r_dfe_1t_DP_RXPMA_IDX_2	: integer := 175;

-- Table47: PMA Per Channel RX Control Register 12 for Channel 0
constant reqv_set_DP_RXPMA_IDX_0	: integer := 176;
constant reqv_set_DP_RXPMA_IDX_1	: integer := 177;
constant reqv_set_DP_RXPMA_IDX_2	: integer := 178;
constant reqd_set_DP_RXPMA_IDX_0	: integer := 179;
constant reqd_set_DP_RXPMA_IDX_1	: integer := 180;
constant reqd_set_DP_RXPMA_IDX_2	: integer := 181;
constant reqc_set_DP_RXPMA_IDX_0	: integer := 182;
constant reqc_set_DP_RXPMA_IDX_1	: integer := 183;
constant reqc_set_DP_RXPMA_IDX_2	: integer := 184;
constant reqb_set_DP_RXPMA_IDX_0	: integer := 185;
constant reqb_set_DP_RXPMA_IDX_1	: integer := 186;
constant reqb_set_DP_RXPMA_IDX_2	: integer := 187;
constant reqa_set_DP_RXPMA_IDX_0	: integer := 188;
constant reqa_set_DP_RXPMA_IDX_1	: integer := 189;
constant reqa_set_DP_RXPMA_IDX_2	: integer := 190;
constant reserved_0_TB47_DP_RXPMA_IDX_0	: integer := 191;

-- Table48: PMA Per Channel RX Control Register 13 for Channel 0
constant rdc_freq_DP_RXPMA_IDX_0	: integer := 192;
constant rdc_freq_DP_RXPMA_IDX_1	: integer := 193;
constant rhyst_lf_DP_RXPMA_IDX_0	: integer := 194;
constant rhyst_lf_DP_RXPMA_IDX_1	: integer := 195;
constant rhyst_lf_DP_RXPMA_IDX_2	: integer := 196;
constant rclkdiv_DP_RXPMA_IDX_0	: integer := 197;
constant rclkdiv_DP_RXPMA_IDX_1	: integer := 198;
constant rclkdiv_DP_RXPMA_IDX_2	: integer := 199;
constant rclkdiv_DP_RXPMA_IDX_3	: integer := 200;
constant rrgen_set_DP_RXPMA_IDX_0	: integer := 201;
constant rrgen_set_DP_RXPMA_IDX_1	: integer := 202;
constant rrgen_set_DP_RXPMA_IDX_2	: integer := 203;
constant radce_adapt_DP_RXPMA_IDX_0	: integer := 204;
constant rseq_sel_DP_RXPMA_IDX_0	: integer := 205;
constant rseq_sel_DP_RXPMA_IDX_1	: integer := 206;
constant rlock_lf_ovd_DP_RXPMA_IDX_0	: integer := 207;

-- Table49: PMA Per Channel RX Control Register 14 for Channel 0
constant rrgen_vod_DP_RXPMA_IDX_0	: integer := 208;
constant rrgen_vod_DP_RXPMA_IDX_1	: integer := 209;
constant rrgen_vod_DP_RXPMA_IDX_2	: integer := 210;
constant rf_hpf_DP_RXPMA_IDX_0	: integer := 211;
constant rf_hpf_DP_RXPMA_IDX_1	: integer := 212;
constant rf_lpf_DP_RXPMA_IDX_0	: integer := 213;
constant rf_lpf_DP_RXPMA_IDX_1	: integer := 214;
constant reserved_1_TB49_DP_RXPMA_IDX_0	: integer := 215;
constant reserved_1_TB49_DP_RXPMA_IDX_1	: integer := 216;
constant reserved_1_TB49_DP_RXPMA_IDX_2	: integer := 217;
constant reserved_0_TB49_DP_RXPMA_IDX_0	: integer := 218;
constant reserved_0_TB49_DP_RXPMA_IDX_1	: integer := 219;
constant reserved_0_TB49_DP_RXPMA_IDX_2	: integer := 220;
constant rhyst_hf_DP_RXPMA_IDX_0	: integer := 221;
constant rhyst_hf_DP_RXPMA_IDX_1	: integer := 222;
constant rhyst_hf_DP_RXPMA_IDX_2	: integer := 223;

-- Table50: PMA Per Channel RX Control Register 15 for Channel 0
constant radce_pdb_DP_RXPMA_IDX_0	: integer := 224;
constant radce_rst_DP_RXPMA_IDX_0	: integer := 225;
constant rhf_os_DP_RXPMA_IDX_0	: integer := 226;
constant rhf_os_DP_RXPMA_IDX_1	: integer := 227;
constant rhf_os_DP_RXPMA_IDX_2	: integer := 228;
constant rhf_os_DP_RXPMA_IDX_3	: integer := 229;
constant rlf_os_DP_RXPMA_IDX_0	: integer := 230;
constant rlf_os_DP_RXPMA_IDX_1	: integer := 231;
constant rlf_os_DP_RXPMA_IDX_2	: integer := 232;
constant rlf_os_DP_RXPMA_IDX_3	: integer := 233;
constant rd2a_res_DP_RXPMA_IDX_0	: integer := 234;
constant rd2a_res_DP_RXPMA_IDX_1	: integer := 235;
constant rrect_adj_DP_RXPMA_IDX_0	: integer := 236;
constant rrect_adj_DP_RXPMA_IDX_1	: integer := 237;
constant rrgen_bw_DP_RXPMA_IDX_0	: integer := 238;
constant rrgen_bw_DP_RXPMA_IDX_1	: integer := 239;

-- Table51: PMA Per Channel RX Control Register 16 for Channel 0
constant radce_hflck_DP_RXPMA_IDX_0	: integer := 240;
constant radce_hflck_DP_RXPMA_IDX_1	: integer := 241;
constant radce_hflck_DP_RXPMA_IDX_2	: integer := 242;
constant radce_hflck_DP_RXPMA_IDX_3	: integer := 243;
constant radce_hflck_DP_RXPMA_IDX_4	: integer := 244;
constant radce_hflck_DP_RXPMA_IDX_5	: integer := 245;
constant radce_hflck_DP_RXPMA_IDX_6	: integer := 246;
constant radce_hflck_DP_RXPMA_IDX_7	: integer := 247;
constant radce_hflck_DP_RXPMA_IDX_8	: integer := 248;
constant radce_hflck_DP_RXPMA_IDX_9	: integer := 249;
constant radce_hflck_DP_RXPMA_IDX_10	: integer := 250;
constant radce_hflck_DP_RXPMA_IDX_11	: integer := 251;
constant radce_hflck_DP_RXPMA_IDX_12	: integer := 252;
constant radce_hflck_DP_RXPMA_IDX_13	: integer := 253;
constant radce_hflck_DP_RXPMA_IDX_14	: integer := 254;
constant reserved_0_TB51_DP_RXPMA_IDX_0	: integer := 255;

-- Table52: PMA Per Channel RX Control Register 17 for Channel 0
constant radce_lflck_DP_RXPMA_IDX_0	: integer := 256;
constant radce_lflck_DP_RXPMA_IDX_1	: integer := 257;
constant radce_lflck_DP_RXPMA_IDX_2	: integer := 258;
constant radce_lflck_DP_RXPMA_IDX_3	: integer := 259;
constant radce_lflck_DP_RXPMA_IDX_4	: integer := 260;
constant radce_lflck_DP_RXPMA_IDX_5	: integer := 261;
constant radce_lflck_DP_RXPMA_IDX_6	: integer := 262;
constant radce_lflck_DP_RXPMA_IDX_7	: integer := 263;
constant radce_lflck_DP_RXPMA_IDX_8	: integer := 264;
constant radce_lflck_DP_RXPMA_IDX_9	: integer := 265;
constant radce_lflck_DP_RXPMA_IDX_10	: integer := 266;
constant radce_lflck_DP_RXPMA_IDX_11	: integer := 267;
constant radce_lflck_DP_RXPMA_IDX_12	: integer := 268;
constant radce_lflck_DP_RXPMA_IDX_13	: integer := 269;
constant radce_lflck_DP_RXPMA_IDX_14	: integer := 270;
constant reserved_0_TB52_DP_RXPMA_IDX_0	: integer := 271;

-- Table53: PMA Per Channel RX Control Register 18 for Channel 0
constant radce_digital_DP_RXPMA_IDX_0	: integer := 272;
constant radce_digital_DP_RXPMA_IDX_1	: integer := 273;
constant radce_digital_DP_RXPMA_IDX_2	: integer := 274;
constant radce_digital_DP_RXPMA_IDX_3	: integer := 275;
constant radce_digital_DP_RXPMA_IDX_4	: integer := 276;
constant radce_digital_DP_RXPMA_IDX_5	: integer := 277;
constant radce_digital_DP_RXPMA_IDX_6	: integer := 278;
constant radce_digital_DP_RXPMA_IDX_7	: integer := 279;
constant radce_digital_DP_RXPMA_IDX_8	: integer := 280;
constant radce_digital_DP_RXPMA_IDX_9	: integer := 281;
constant reserved_0_TB53_DP_RXPMA_IDX_0	: integer := 282;
constant reserved_0_TB53_DP_RXPMA_IDX_1	: integer := 283;
constant reserved_0_TB53_DP_RXPMA_IDX_2	: integer := 284;
constant reserved_0_TB53_DP_RXPMA_IDX_3	: integer := 285;
constant reserved_0_TB53_DP_RXPMA_IDX_4	: integer := 286;
constant reserved_0_TB53_DP_RXPMA_IDX_5	: integer := 287;

---------------------------------------------------------------
-- Manual section due to one ICD CRAM mapped to multiple Atoms
---------------------------------------------------------------
-- Manual: TX_PCS section -------------------------------------
constant rauto_speed_ena_DP_TXPCS_IDX   	: integer := 64;
constant rendec_data_sel_tx_DP_TXPCS_IDX    : integer := 65;
constant rfreq_sel_DP_TXPCS_IDX             : integer := 66;
constant rhip_ena_DP_TXPCS_IDX              : integer := 67;
constant rindv_tx_DP_TXPCS_IDX              : integer := 68;
constant rphfifo_master_sel_tx_DP_TXPCS_IDX : integer := 69;
constant rpma_doublewidth_tx_DP_TXPCS_IDX   : integer := 70;
constant rpmadwidth_tx_DP_TXPCS_IDX         : integer := 71;
constant rtx_cmu_sel_DP_TXPCS_IDX           : integer := 72;
constant rmaster_tx_DP_TXPCS_IDX          	: integer := 73;
constant rmaster_up_tx_DP_TXPCS_IDX        	: integer := 74;

-- Manual: RX PMA section -------------------------------------
constant rrevlb_sw_DP_RXPMA_IDX             : integer := 291;
constant rs_lpbk_DP_RXPMA_IDX               : integer := 292; -- match rx_pma.RRX_S_LPBK_RXPMA_IDX
constant rpmadwidth_rx_DP_RXPCS_IDX    		: integer := 368;
constant rpma_doublewidth_rx_DP_RXPCS_IDX   : integer := 369;

-- RX portion of global_ctrl 1
--constant rphfifo_master_sel_rx_DP_RXPCS_IDX 
constant rendec_data_sel_rx_DP_RXPCS_IDX    : integer := 370;
constant rdeskewen_DP_RXPCS_IDX             : integer := 371;
constant rindv_rx_DP_RXPCS_IDX              : integer := 372;

-- RX portion of global_ctrl 2
constant rdskposdisp_DP_RXPCS_IDX           : integer := 373;
--constant ralgnopt_DP_RXPCS_IDX        
--constant rdskchrp[9:0]

-- RX portion of global_ctrl 3
constant rmaster_rx_DP_RXPCS_IDX            : integer := 374;
constant rmaster_up_rx_DP_RXPCS_IDX         : integer := 375;

-- not used - legacy from rx_pcs.v
constant rdwidth_rx_DP_RXPCS_IDX            : integer := 380;
constant rtx_idle_delay_DP_RXPCS_IDX_0      : integer := 381;
constant rtx_idle_delay_DP_RXPCS_IDX_1      : integer := 382;
constant rclkcmppos_DP_RXPCS_IDX            : integer := 383;
constant rppmsel_DP_RXPCS_IDX_0             : integer := 384;
constant rppmsel_DP_RXPCS_IDX_5             : integer := 385;
constant rforce0_freqdet_DP_RXPCS_IDX       : integer := 386;
constant rforce1_freqdet_DP_RXPCS_IDX       : integer := 387;
constant rs_lpbk_DP_RXPCS_IDX               : integer := 388;
constant rrx_revlb_sw_DP_RXPCS_IDX          : integer := 389;

-- central clock divider section
constant rfreerun_centrl_DP_CLOCK_DIV_IDX   : integer := 10;
constant rcentrl_clk_sel_DP_CLOCK_DIV_IDX   : integer := 11;
constant rrefclk_out_div2_DP_CLOCK_DIV_IDX  : integer := 12;

-- CMU-central PCS section - (FIFO ptr, xaui sm)
--constant rxaui_s2gx_en_rx_DP_CENTRL_PCS_IDX   : integer := 10;
--constant rxaui_s2gx_en_tx_DP_CENTRL_PCS_IDX   : integer := 11;

-- Manual: PLL (only rx_cdr_pll uses it: table 33 & 59) --------------
constant rdynamic_sw_DP_PLL_IDX_0 		    : integer := 70;   -- continue PLL index

--====================================================================
-- Manually added code to handle PLL clock select indices            =     
--====================================================================
constant  PFD_CLK_SELECT_DP_PLL_IDX_0   : integer := 100;
constant  PFD_CLK_SELECT_DP_PLL_IDX_1   : integer := 101;
constant  PFD_CLK_SELECT_DP_PLL_IDX_2   : integer := 102;
constant  PFD_CLK_SELECT_DP_PLL_IDX_3   : integer := 103;

SIGNAL pll0_init_pfd_clk_sel : STD_LOGIC_VECTOR (3 DOWNTO 0);  -- logical index from (log0)PLL_Atom
SIGNAL pll0_dp_pfd_clk_sel   : STD_LOGIC_VECTOR (3 DOWNTO 0);  -- logical index to (Phy0)PLL_Atom
SIGNAL pll0_csr_riqclk_sel   : STD_LOGIC_VECTOR (1 DOWNTO 0);  -- PHY to DPRIO
SIGNAL pll0_csr_rrefclk_sel  : STD_LOGIC_VECTOR (1 DOWNTO 0);   
SIGNAL pll0_dp_riqclk_sel    : STD_LOGIC_VECTOR (1 DOWNTO 0);  -- PHY from DPRIO
SIGNAL pll0_dp_rrefclk_sel   : STD_LOGIC_VECTOR (1 DOWNTO 0);    

SIGNAL pll1_init_pfd_clk_sel : STD_LOGIC_VECTOR (3 DOWNTO 0); 
SIGNAL pll1_dp_pfd_clk_sel   : STD_LOGIC_VECTOR (3 DOWNTO 0);  
SIGNAL pll1_csr_riqclk_sel   : STD_LOGIC_VECTOR (1 DOWNTO 0);  
SIGNAL pll1_csr_rrefclk_sel  : STD_LOGIC_VECTOR (1 DOWNTO 0);   
SIGNAL pll1_dp_riqclk_sel    : STD_LOGIC_VECTOR (1 DOWNTO 0); 
SIGNAL pll1_dp_rrefclk_sel   : STD_LOGIC_VECTOR (1 DOWNTO 0);    

SIGNAL pll2_init_pfd_clk_sel : STD_LOGIC_VECTOR (3 DOWNTO 0); 
SIGNAL pll2_dp_pfd_clk_sel   : STD_LOGIC_VECTOR (3 DOWNTO 0);  
SIGNAL pll2_csr_riqclk_sel   : STD_LOGIC_VECTOR (1 DOWNTO 0);  
SIGNAL pll2_csr_rrefclk_sel  : STD_LOGIC_VECTOR (1 DOWNTO 0);   
SIGNAL pll2_dp_riqclk_sel    : STD_LOGIC_VECTOR (1 DOWNTO 0); 
SIGNAL pll2_dp_rrefclk_sel   : STD_LOGIC_VECTOR (1 DOWNTO 0);    

SIGNAL pll3_init_pfd_clk_sel : STD_LOGIC_VECTOR (3 DOWNTO 0); 
SIGNAL pll3_dp_pfd_clk_sel   : STD_LOGIC_VECTOR (3 DOWNTO 0);  
SIGNAL pll3_csr_riqclk_sel   : STD_LOGIC_VECTOR (1 DOWNTO 0);  
SIGNAL pll3_csr_rrefclk_sel  : STD_LOGIC_VECTOR (1 DOWNTO 0);   
SIGNAL pll3_dp_riqclk_sel    : STD_LOGIC_VECTOR (1 DOWNTO 0); 
SIGNAL pll3_dp_rrefclk_sel   : STD_LOGIC_VECTOR (1 DOWNTO 0);    

SIGNAL pll4_init_pfd_clk_sel : STD_LOGIC_VECTOR (3 DOWNTO 0); 
SIGNAL pll4_dp_pfd_clk_sel   : STD_LOGIC_VECTOR (3 DOWNTO 0);  
SIGNAL pll4_csr_riqclk_sel   : STD_LOGIC_VECTOR (1 DOWNTO 0);  
SIGNAL pll4_csr_rrefclk_sel  : STD_LOGIC_VECTOR (1 DOWNTO 0);   
SIGNAL pll4_dp_riqclk_sel    : STD_LOGIC_VECTOR (1 DOWNTO 0); 
SIGNAL pll4_dp_rrefclk_sel   : STD_LOGIC_VECTOR (1 DOWNTO 0);    

SIGNAL pll5_init_pfd_clk_sel : STD_LOGIC_VECTOR (3 DOWNTO 0); 
SIGNAL pll5_dp_pfd_clk_sel   : STD_LOGIC_VECTOR (3 DOWNTO 0);  
SIGNAL pll5_csr_riqclk_sel   : STD_LOGIC_VECTOR (1 DOWNTO 0);  
SIGNAL pll5_csr_rrefclk_sel  : STD_LOGIC_VECTOR (1 DOWNTO 0);   
SIGNAL pll5_dp_riqclk_sel    : STD_LOGIC_VECTOR (1 DOWNTO 0); 
SIGNAL pll5_dp_rrefclk_sel   : STD_LOGIC_VECTOR (1 DOWNTO 0);    

--====================================================================
-- Manually added code to handle TXPMA clock select indices          =     
--====================================================================
constant  CLKIN_SELECT_DP_TXPMA_IDX_0   : integer := 200;
constant  CLKIN_SELECT_DP_TXPMA_IDX_1   : integer := 201;
constant  CLKIN_SELECT_DP_TXPMA_IDX_2   : integer := 202;

SIGNAL          txpma0_init_clkin_sel : STD_LOGIC_VECTOR(2 DOWNTO 0); -- logical index from log0 Atom
SIGNAL          txpma0_dp_clkin_sel   : STD_LOGIC_VECTOR(2 DOWNTO 0);   -- logical index to PHY0 Atom
SIGNAL          txpma0_csr_rcgb_x_en  : STD_LOGIC_VECTOR(1 DOWNTO 0);  -- PHY to DPRIO
SIGNAL          txpma0_dp_rcgb_x_en   : STD_LOGIC_VECTOR(1 DOWNTO 0);   -- PHY from DPRIO

SIGNAL          txpma1_init_clkin_sel : STD_LOGIC_VECTOR(2 DOWNTO 0); -- logical index from PHY0 Atom
SIGNAL          txpma1_dp_clkin_sel   : STD_LOGIC_VECTOR(2 DOWNTO 0);   -- logical index to PHY0 Atom
SIGNAL          txpma1_csr_rcgb_x_en  : STD_LOGIC_VECTOR(1 DOWNTO 0);  -- PHY to DPRIO
SIGNAL          txpma1_dp_rcgb_x_en   : STD_LOGIC_VECTOR(1 DOWNTO 0);   -- PHY from DPRIO

SIGNAL          txpma2_init_clkin_sel : STD_LOGIC_VECTOR(2 DOWNTO 0); -- logical index from PHY0 Atom
SIGNAL          txpma2_dp_clkin_sel   : STD_LOGIC_VECTOR(2 DOWNTO 0);   -- logical index to PHY0 Atom
SIGNAL          txpma2_csr_rcgb_x_en  : STD_LOGIC_VECTOR(1 DOWNTO 0);  -- PHY to DPRIO
SIGNAL          txpma2_dp_rcgb_x_en   : STD_LOGIC_VECTOR(1 DOWNTO 0);   -- PHY from DPRIO

SIGNAL          txpma3_init_clkin_sel : STD_LOGIC_VECTOR(2 DOWNTO 0); -- logical index from PHY0 Atom
SIGNAL          txpma3_dp_clkin_sel   : STD_LOGIC_VECTOR(2 DOWNTO 0);   -- logical index to PHY0 Atom
SIGNAL          txpma3_csr_rcgb_x_en  : STD_LOGIC_VECTOR(1 DOWNTO 0);  -- PHY to DPRIO
SIGNAL          txpma3_dp_rcgb_x_en   : STD_LOGIC_VECTOR(1 DOWNTO 0);   -- PHY from DPRIO

SIGNAL          txpma4_init_clkin_sel : STD_LOGIC_VECTOR(2 DOWNTO 0); -- logical index from PHY0 Atom
SIGNAL          txpma4_dp_clkin_sel   : STD_LOGIC_VECTOR(2 DOWNTO 0);   -- logical index to PHY0 Atom
SIGNAL          txpma4_csr_rcgb_x_en  : STD_LOGIC_VECTOR(1 DOWNTO 0);  -- PHY to DPRIO
SIGNAL          txpma4_dp_rcgb_x_en   : STD_LOGIC_VECTOR(1 DOWNTO 0);   -- PHY from DPRIO

SIGNAL          txpma5_init_clkin_sel : STD_LOGIC_VECTOR(2 DOWNTO 0); -- logical index from PHY0 Atom
SIGNAL          txpma5_dp_clkin_sel   : STD_LOGIC_VECTOR(2 DOWNTO 0);   -- logical index to PHY0 Atom
SIGNAL          txpma5_csr_rcgb_x_en  : STD_LOGIC_VECTOR(1 DOWNTO 0);  -- PHY to DPRIO
SIGNAL          txpma5_dp_rcgb_x_en   : STD_LOGIC_VECTOR(1 DOWNTO 0);   -- PHY from DPRIO

--====================================================================
-- Manually added code to handle clkdiv PLL0/1 select                =
--====================================================================
constant  INCLK_SELECT_DP_CLOCK_DIV_IDX  : integer := 0;

SIGNAL          clkdiv0_init_inclk_select : STD_LOGIC; -- logical index from logic Atom
SIGNAL          clkdiv0_dp_inclk_select   : STD_LOGIC;   -- logical index to PHY Atom
SIGNAL          clkdiv0_csr_rcgb_cmu_sel  : STD_LOGIC;  -- PHY to DPRIO
SIGNAL          clkdiv0_dp_rcgb_cmu_sel   : STD_LOGIC;   -- PHY from DPRIO

SIGNAL          clkdiv1_init_inclk_select : STD_LOGIC; -- logical index from PHY1 Atom
SIGNAL          clkdiv1_dp_inclk_select   : STD_LOGIC;   -- logical index to PHY1 Atom
SIGNAL          clkdiv1_csr_rcgb_cmu_sel  : STD_LOGIC;  -- PHY to DPRIO
SIGNAL          clkdiv1_dp_rcgb_cmu_sel   : STD_LOGIC;   -- PHY from DPRIO

SIGNAL          clkdiv2_init_inclk_select : STD_LOGIC; -- logical index from PHY2 Atom
SIGNAL          clkdiv2_dp_inclk_select   : STD_LOGIC;   -- logical index to PHY2 Atom
SIGNAL          clkdiv2_csr_rcgb_cmu_sel  : STD_LOGIC;  -- PHY to DPRIO
SIGNAL          clkdiv2_dp_rcgb_cmu_sel   : STD_LOGIC;   -- PHY from DPRIO

SIGNAL          clkdiv3_init_inclk_select : STD_LOGIC; -- logical index from PHY3 Atom
SIGNAL          clkdiv3_dp_inclk_select   : STD_LOGIC;   -- logical index to PHY3 Atom
SIGNAL          clkdiv3_csr_rcgb_cmu_sel  : STD_LOGIC;  -- PHY to DPRIO
SIGNAL          clkdiv3_dp_rcgb_cmu_sel   : STD_LOGIC;   -- PHY from DPRIO

SIGNAL          clkdiv4_init_inclk_select : STD_LOGIC; -- logical index from PHY4 Atom
SIGNAL          clkdiv4_dp_inclk_select   : STD_LOGIC;   -- logical index to PHY4 Atom
SIGNAL          clkdiv4_csr_rcgb_cmu_sel  : STD_LOGIC;  -- PHY to DPRIO
SIGNAL          clkdiv4_dp_rcgb_cmu_sel   : STD_LOGIC;   -- PHY from DPRIO

SIGNAL          clkdiv5_init_inclk_select : STD_LOGIC; -- logical index from PHY5 Atom
SIGNAL          clkdiv5_dp_inclk_select   : STD_LOGIC;   -- logical index to PHY5 Atom
SIGNAL          clkdiv5_csr_rcgb_cmu_sel  : STD_LOGIC;  -- PHY to DPRIO
SIGNAL          clkdiv5_dp_rcgb_cmu_sel   : STD_LOGIC;   -- PHY from DPRIO

---------------------------------------------------------------
-- Phy channel in ICD -----------------------------------------
---------------------------------------------------------------
SIGNAL ch0_in_chnl_ctrl_1	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_1	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_1	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_1	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_1	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_1	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_1	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_1	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_2	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_2	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_2	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_2	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_2	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_2	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_2	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_2	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_3	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_3	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_3	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_3	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_3	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_3	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_3	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_3	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_4	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_4	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_4	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_4	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_4	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_4	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_4	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_4	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_5	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_5	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_5	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_5	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_5	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_5	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_5	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_5	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_6	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_6	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_6	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_6	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_6	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_6	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_6	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_6	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_7	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_7	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_7	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_7	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_7	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_7	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_7	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_7	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_8	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_8	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_8	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_8	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_8	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_8	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_8	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_8	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_9	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_9	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_9	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_9	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_9	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_9	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_9	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_9	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_10	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_10	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_10	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_10	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_10	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_10	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_10	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_10	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_11	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_11	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_11	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_11	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_11	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_11	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_11	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_11	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_12	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_12	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_12	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_12	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_12	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_12	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_12	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_12	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_13	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_13	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_13	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_13	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_13	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_13	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_13	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_13	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_14	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_14	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_14	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_14	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_14	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_14	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_14	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_14	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_15	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_15	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_15	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_15	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_15	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_15	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_15	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_15	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_16	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_16	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_16	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_16	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_16	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_16	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_16	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_16	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_17	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_17	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_17	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_17	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_17	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_17	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_17	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_17	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_18	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_18	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_18	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_18	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_18	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_18	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_18	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_18	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_19	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_19	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_19	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_19	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_19	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_19	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_19	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_19	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_20	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_20	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_20	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_20	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_20	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_20	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_20	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_20	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_21	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_21	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_21	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_21	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_21	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_21	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_21	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_21	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_22	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_22	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_22	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_22	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_22	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_22	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_22	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_22	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_23	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_23	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_23	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_23	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_23	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_23	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_23	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_23	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_24	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_24	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_24	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_24	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_24	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_24	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_24	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_24	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_25	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_25	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_25	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_25	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_25	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_25	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_25	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_25	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_26	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_26	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_26	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_26	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_26	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_26	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_26	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_26	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_27	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_27	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_27	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_27	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_27	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_27	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_27	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_27	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_28	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_28	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_28	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_28	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_28	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_28	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_28	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_28	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_29	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_29	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_29	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_29	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_29	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_29	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_29	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_29	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_30	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_30	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_30	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_30	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_30	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_30	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_30	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_30	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_31	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_31	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_31	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_31	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_31	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_31	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_31	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_31	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_32	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_32	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_32	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_32	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_32	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_32	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_32	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_32	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_33	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_33	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_33	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_33	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_33	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_33	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_33	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_33	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_34	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_34	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_34	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_34	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_34	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_34	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_34	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_34	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_35	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_35	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_35	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_35	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_35	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_35	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_35	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_35	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_36	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_36	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_36	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_36	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_36	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_36	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_36	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_36	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_37	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_37	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_37	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_37	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_37	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_37	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_37	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_37	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_38	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_38	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_38	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_38	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_38	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_38	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_38	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_38	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_39	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_39	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_39	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_39	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_39	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_39	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_39	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_39	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_40	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_40	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_40	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_40	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_40	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_40	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_40	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_40	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_41	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_41	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_41	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_41	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_41	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_41	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_41	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_41	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_42	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_42	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_42	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_42	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_42	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_42	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_42	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_42	: STD_LOGIC_VECTOR(15 DOWNTO 0);

-- reserved
SIGNAL ch0_in_chnl_ctrl_43	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_43	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_43	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_43	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_43	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_43	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_43	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_43	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_44	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_44	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_44	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_44	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_44	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_44	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_44	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_44	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_45	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_45	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_45	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_45	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_45	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_45	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_45	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_45	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_46	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_46	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_46	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_46	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_46	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_46	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_46	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_46	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_47	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_47	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_47	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_47	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_47	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_47	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_47	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_47	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_48	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_48	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_48	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_48	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_48	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_48	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_48	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_48	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_49	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_49	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_49	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_49	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_49	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_49	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_49	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_49	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_50	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_50	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_50	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_50	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_50	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_50	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_50	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_50	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_51	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_51	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_51	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_51	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_51	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_51	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_51	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_51	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_52	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_52	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_52	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_52	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_52	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_52	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_52	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_52	: STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL ch0_in_chnl_ctrl_53	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_in_chnl_ctrl_53	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_in_chnl_ctrl_53	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_in_chnl_ctrl_53	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch0_out_chnl_ctrl_53	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch1_out_chnl_ctrl_53	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch2_out_chnl_ctrl_53	: STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL ch3_out_chnl_ctrl_53	: STD_LOGIC_VECTOR(15 DOWNTO 0);

---------------------------------------------------------------
-- TXPCS CRAM -------------------------------------------------
---------------------------------------------------------------
SIGNAL ch0_txpcsdprioin_logic	: STD_LOGIC_VECTOR(149 DOWNTO 0);
SIGNAL ch1_txpcsdprioin_logic	: STD_LOGIC_VECTOR(149 DOWNTO 0);
SIGNAL ch2_txpcsdprioin_logic	: STD_LOGIC_VECTOR(149 DOWNTO 0);
SIGNAL ch3_txpcsdprioin_logic	: STD_LOGIC_VECTOR(149 DOWNTO 0);

SIGNAL ch0_txpcsdprioin_phy	: STD_LOGIC_VECTOR(149 DOWNTO 0);
SIGNAL ch1_txpcsdprioin_phy	: STD_LOGIC_VECTOR(149 DOWNTO 0);
SIGNAL ch2_txpcsdprioin_phy	: STD_LOGIC_VECTOR(149 DOWNTO 0);
SIGNAL ch3_txpcsdprioin_phy	: STD_LOGIC_VECTOR(149 DOWNTO 0);

SIGNAL ch0_txpcsdprioout_logic	: STD_LOGIC_VECTOR(149 DOWNTO 0);
SIGNAL ch1_txpcsdprioout_logic	: STD_LOGIC_VECTOR(149 DOWNTO 0);
SIGNAL ch2_txpcsdprioout_logic	: STD_LOGIC_VECTOR(149 DOWNTO 0);
SIGNAL ch3_txpcsdprioout_logic	: STD_LOGIC_VECTOR(149 DOWNTO 0);

SIGNAL ch0_txpcsdprioout_phy	: STD_LOGIC_VECTOR(149 DOWNTO 0);
SIGNAL ch1_txpcsdprioout_phy	: STD_LOGIC_VECTOR(149 DOWNTO 0);
SIGNAL ch2_txpcsdprioout_phy	: STD_LOGIC_VECTOR(149 DOWNTO 0);
SIGNAL ch3_txpcsdprioout_phy	: STD_LOGIC_VECTOR(149 DOWNTO 0);

---------------------------------------------------------------
-- RXPCS CRAM -------------------------------------------------
---------------------------------------------------------------
SIGNAL ch0_rxpcsdprioin_logic	: STD_LOGIC_VECTOR(399 DOWNTO 0);
SIGNAL ch1_rxpcsdprioin_logic	: STD_LOGIC_VECTOR(399 DOWNTO 0);
SIGNAL ch2_rxpcsdprioin_logic	: STD_LOGIC_VECTOR(399 DOWNTO 0);
SIGNAL ch3_rxpcsdprioin_logic	: STD_LOGIC_VECTOR(399 DOWNTO 0);

SIGNAL ch0_rxpcsdprioin_phy	: STD_LOGIC_VECTOR(399 DOWNTO 0);
SIGNAL ch1_rxpcsdprioin_phy	: STD_LOGIC_VECTOR(399 DOWNTO 0);
SIGNAL ch2_rxpcsdprioin_phy	: STD_LOGIC_VECTOR(399 DOWNTO 0);
SIGNAL ch3_rxpcsdprioin_phy	: STD_LOGIC_VECTOR(399 DOWNTO 0);

SIGNAL ch0_rxpcsdprioout_logic	: STD_LOGIC_VECTOR(399 DOWNTO 0);
SIGNAL ch1_rxpcsdprioout_logic	: STD_LOGIC_VECTOR(399 DOWNTO 0);
SIGNAL ch2_rxpcsdprioout_logic	: STD_LOGIC_VECTOR(399 DOWNTO 0);
SIGNAL ch3_rxpcsdprioout_logic	: STD_LOGIC_VECTOR(399 DOWNTO 0);

SIGNAL ch0_rxpcsdprioout_phy	: STD_LOGIC_VECTOR(399 DOWNTO 0);
SIGNAL ch1_rxpcsdprioout_phy	: STD_LOGIC_VECTOR(399 DOWNTO 0);
SIGNAL ch2_rxpcsdprioout_phy	: STD_LOGIC_VECTOR(399 DOWNTO 0);
SIGNAL ch3_rxpcsdprioout_phy	: STD_LOGIC_VECTOR(399 DOWNTO 0);

---------------------------------------------------------------
-- TXPMA CRAM -------------------------------------------------
---------------------------------------------------------------
SIGNAL ch0_txpmadprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch1_txpmadprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch2_txpmadprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch3_txpmadprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch4_txpmadprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch5_txpmadprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);

SIGNAL ch0_txpmadprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch1_txpmadprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch2_txpmadprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch3_txpmadprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch4_txpmadprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch5_txpmadprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);

SIGNAL ch0_txpmadprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch1_txpmadprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch2_txpmadprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch3_txpmadprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch4_txpmadprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch5_txpmadprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);

SIGNAL ch0_txpmadprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch1_txpmadprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch2_txpmadprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch3_txpmadprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch4_txpmadprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch5_txpmadprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);

---------------------------------------------------------------
-- RXPMA CRAM -------------------------------------------------
---------------------------------------------------------------
SIGNAL ch0_rxpmadprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch1_rxpmadprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch2_rxpmadprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch3_rxpmadprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch4_rxpmadprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch5_rxpmadprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);

SIGNAL ch0_rxpmadprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch1_rxpmadprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch2_rxpmadprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch3_rxpmadprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch4_rxpmadprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch5_rxpmadprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);

SIGNAL ch0_rxpmadprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch1_rxpmadprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch2_rxpmadprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch3_rxpmadprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch4_rxpmadprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch5_rxpmadprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);

SIGNAL ch0_rxpmadprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch1_rxpmadprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch2_rxpmadprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch3_rxpmadprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch4_rxpmadprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch5_rxpmadprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);

---------------------------------------------------------------
-- PLL CRAM -------------------------------------------------
---------------------------------------------------------------
SIGNAL ch0_rxplldprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch1_rxplldprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch2_rxplldprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch3_rxplldprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch4_rxtxplldprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch5_rxtxplldprioin_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);

SIGNAL ch0_rxplldprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch1_rxplldprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch2_rxplldprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch3_rxplldprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch4_rxtxplldprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch5_rxtxplldprioin_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);

SIGNAL ch0_rxplldprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch1_rxplldprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch2_rxplldprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch3_rxplldprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch4_rxtxplldprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch5_rxtxplldprioout_logic	: STD_LOGIC_VECTOR(299 DOWNTO 0);

SIGNAL ch0_rxplldprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch1_rxplldprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch2_rxplldprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch3_rxplldprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch4_rxtxplldprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);
SIGNAL ch5_rxtxplldprioout_phy	: STD_LOGIC_VECTOR(299 DOWNTO 0);

---------------------------------------------------------------
-- CMUDivider CRAM --------------------------------------------
---------------------------------------------------------------
SIGNAL ch0_cmudividerdprioin_logic : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch1_cmudividerdprioin_logic : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch2_cmudividerdprioin_logic : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch3_cmudividerdprioin_logic : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch4_cmudividerdprioin_logic : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch5_cmudividerdprioin_logic : STD_LOGIC_VECTOR(99 DOWNTO 0);

SIGNAL ch0_cmudividerdprioin_phy : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch1_cmudividerdprioin_phy : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch2_cmudividerdprioin_phy : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch3_cmudividerdprioin_phy : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch4_cmudividerdprioin_phy : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch5_cmudividerdprioin_phy : STD_LOGIC_VECTOR(99 DOWNTO 0);

SIGNAL ch0_cmudividerdprioout_logic : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch1_cmudividerdprioout_logic : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch2_cmudividerdprioout_logic : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch3_cmudividerdprioout_logic : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch4_cmudividerdprioout_logic : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch5_cmudividerdprioout_logic : STD_LOGIC_VECTOR(99 DOWNTO 0);

SIGNAL ch0_cmudividerdprioout_phy : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch1_cmudividerdprioout_phy : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch2_cmudividerdprioout_phy : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch3_cmudividerdprioout_phy : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch4_cmudividerdprioout_phy : STD_LOGIC_VECTOR(99 DOWNTO 0);
SIGNAL ch5_cmudividerdprioout_phy : STD_LOGIC_VECTOR(99 DOWNTO 0);

--====================================================================
-- Manually added code to handle 5th/6th PMA                         =
-- === begin                                                         =
-- use ch4/5_in_chnl ch4/5_out_chnl interacting with Quartus Int Con =
-- use cmu0 and cmu1 to interface ICD/Phy                            =
--====================================================================
SIGNAL  ch4_in_chnl_ctrl_28, cmu0_in_centrl_ctrl_1 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_29, cmu0_in_centrl_ctrl_2 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_30, cmu0_in_centrl_ctrl_3 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_31, cmu0_in_centrl_ctrl_4 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_32, cmu0_in_centrl_ctrl_5 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_33, cmu0_in_centrl_ctrl_6 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_34, cmu0_in_centrl_ctrl_7 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_35, cmu0_in_centrl_ctrl_8 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_36, cmu0_in_centrl_ctrl_9 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_37, cmu0_in_centrl_ctrl_10 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_38, cmu0_in_centrl_ctrl_11 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_39, cmu0_in_centrl_ctrl_12 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_40, cmu0_in_centrl_ctrl_13 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_41, cmu0_in_centrl_ctrl_14 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_42, cmu0_in_centrl_ctrl_15 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_43, cmu0_in_centrl_ctrl_16 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_44, cmu0_in_centrl_ctrl_17 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_45, cmu0_in_centrl_ctrl_18 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_46, cmu0_in_centrl_ctrl_19 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_in_chnl_ctrl_47, cmu0_in_centrl_ctrl_20 : STD_LOGIC_VECTOR (15 DOWNTO 0);

SIGNAL  ch5_in_chnl_ctrl_28, cmu1_in_centrl_ctrl_1 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_29, cmu1_in_centrl_ctrl_2 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_30, cmu1_in_centrl_ctrl_3 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_31, cmu1_in_centrl_ctrl_4 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_32, cmu1_in_centrl_ctrl_5 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_33, cmu1_in_centrl_ctrl_6 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_34, cmu1_in_centrl_ctrl_7 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_35, cmu1_in_centrl_ctrl_8 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_36, cmu1_in_centrl_ctrl_9 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_37, cmu1_in_centrl_ctrl_10 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_38, cmu1_in_centrl_ctrl_11 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_39, cmu1_in_centrl_ctrl_12 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_40, cmu1_in_centrl_ctrl_13 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_41, cmu1_in_centrl_ctrl_14 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_42, cmu1_in_centrl_ctrl_15 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_43, cmu1_in_centrl_ctrl_16 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_44, cmu1_in_centrl_ctrl_17 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_45, cmu1_in_centrl_ctrl_18 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_46, cmu1_in_centrl_ctrl_19 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_in_chnl_ctrl_47, cmu1_in_centrl_ctrl_20 : STD_LOGIC_VECTOR (15 DOWNTO 0);

-- CMU only or global
SIGNAL  cmu0_in_centrl_ctrl_21, cmu1_in_centrl_ctrl_21 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  cmu_in_centrl_global_0, cmu_in_centrl_global_1 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  cmu_in_centrl_global_2, cmu_in_centrl_global_3 : STD_LOGIC_VECTOR (15 DOWNTO 0);

SIGNAL  ch4_out_chnl_ctrl_28, cmu0_out_centrl_ctrl_1 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_29, cmu0_out_centrl_ctrl_2 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_30, cmu0_out_centrl_ctrl_3 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_31, cmu0_out_centrl_ctrl_4 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_32, cmu0_out_centrl_ctrl_5 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_33, cmu0_out_centrl_ctrl_6 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_34, cmu0_out_centrl_ctrl_7 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_35, cmu0_out_centrl_ctrl_8 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_36, cmu0_out_centrl_ctrl_9 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_37, cmu0_out_centrl_ctrl_10 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_38, cmu0_out_centrl_ctrl_11 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_39, cmu0_out_centrl_ctrl_12 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_40, cmu0_out_centrl_ctrl_13 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_41, cmu0_out_centrl_ctrl_14 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_42, cmu0_out_centrl_ctrl_15 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_43, cmu0_out_centrl_ctrl_16 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_44, cmu0_out_centrl_ctrl_17 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_45, cmu0_out_centrl_ctrl_18 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_46, cmu0_out_centrl_ctrl_19 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch4_out_chnl_ctrl_47, cmu0_out_centrl_ctrl_20 : STD_LOGIC_VECTOR (15 DOWNTO 0);

SIGNAL  ch5_out_chnl_ctrl_28, cmu1_out_centrl_ctrl_1 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_29, cmu1_out_centrl_ctrl_2 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_30, cmu1_out_centrl_ctrl_3 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_31, cmu1_out_centrl_ctrl_4 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_32, cmu1_out_centrl_ctrl_5 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_33, cmu1_out_centrl_ctrl_6 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_34, cmu1_out_centrl_ctrl_7 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_35, cmu1_out_centrl_ctrl_8 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_36, cmu1_out_centrl_ctrl_9 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_37, cmu1_out_centrl_ctrl_10 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_38, cmu1_out_centrl_ctrl_11 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_39, cmu1_out_centrl_ctrl_12 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_40, cmu1_out_centrl_ctrl_13 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_41, cmu1_out_centrl_ctrl_14 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_42, cmu1_out_centrl_ctrl_15 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_43, cmu1_out_centrl_ctrl_16 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_44, cmu1_out_centrl_ctrl_17 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_45, cmu1_out_centrl_ctrl_18 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_46, cmu1_out_centrl_ctrl_19 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  ch5_out_chnl_ctrl_47, cmu1_out_centrl_ctrl_20 : STD_LOGIC_VECTOR (15 DOWNTO 0);

-- CMU only or global
SIGNAL  cmu0_out_centrl_ctrl_21, cmu1_out_centrl_ctrl_21 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  cmu_out_centrl_global_0, cmu_out_centrl_global_1 : STD_LOGIC_VECTOR (15 DOWNTO 0);
SIGNAL  cmu_out_centrl_global_2, cmu_out_centrl_global_3 : STD_LOGIC_VECTOR (15 DOWNTO 0);

--============================================================
-- Manually added code to handle 5th/6th PMA =================
-- === end                                                   =
--============================================================

BEGIN
   
---------------------------------------------------------------
-- read in para and populate csr ------------------------------
---------------------------------------------------------------
-- TXPCS
ch0_txpcsdprioin_logic <= txpcsdprioin (149 DOWNTO 0);
ch1_txpcsdprioin_logic <= txpcsdprioin (299 DOWNTO 150);
ch2_txpcsdprioin_logic <= txpcsdprioin (449 DOWNTO 300);
ch3_txpcsdprioin_logic <= txpcsdprioin (599 DOWNTO 450);
-- RXPCS
ch0_rxpcsdprioin_logic <= rxpcsdprioin (399 DOWNTO 0);
ch1_rxpcsdprioin_logic <= rxpcsdprioin (799 DOWNTO 400);
ch2_rxpcsdprioin_logic <= rxpcsdprioin (1199 DOWNTO 800);
ch3_rxpcsdprioin_logic <= rxpcsdprioin (1599 DOWNTO 1200);
-- TXPMA
ch0_txpmadprioin_logic <= txpmadprioin (299 DOWNTO 0);
ch1_txpmadprioin_logic <= txpmadprioin (599 DOWNTO 300);
ch2_txpmadprioin_logic <= txpmadprioin (899 DOWNTO 600);
ch3_txpmadprioin_logic <= txpmadprioin (1199 DOWNTO 900);
ch4_txpmadprioin_logic <= txpmadprioin (1499 DOWNTO 1200);
ch5_txpmadprioin_logic <= txpmadprioin (1799 DOWNTO 1500);
-- RXPMA
ch0_rxpmadprioin_logic <= rxpmadprioin (299 DOWNTO 0);
ch1_rxpmadprioin_logic <= rxpmadprioin (599 DOWNTO 300);
ch2_rxpmadprioin_logic <= rxpmadprioin (899 DOWNTO 600);
ch3_rxpmadprioin_logic <= rxpmadprioin (1199 DOWNTO 900);
ch4_rxpmadprioin_logic <= rxpmadprioin (1499 DOWNTO 1200);
ch5_rxpmadprioin_logic <= rxpmadprioin (1799 DOWNTO 1500);
-- PLL
ch0_rxplldprioin_logic <= cmuplldprioin (299 DOWNTO 0);
ch1_rxplldprioin_logic <= cmuplldprioin (599 DOWNTO 300);
ch2_rxplldprioin_logic <= cmuplldprioin (899 DOWNTO 600);
ch3_rxplldprioin_logic <= cmuplldprioin (1199 DOWNTO 900);
ch4_rxtxplldprioin_logic <= cmuplldprioin (1499 DOWNTO 1200);
ch5_rxtxplldprioin_logic <= cmuplldprioin (1799 DOWNTO 1500);
-- CMUDivider
ch0_cmudividerdprioin_logic <= cmudividerdprioin (99 DOWNTO 0);
ch1_cmudividerdprioin_logic <= cmudividerdprioin (199 DOWNTO 100);
ch2_cmudividerdprioin_logic <= cmudividerdprioin (299 DOWNTO 200);
ch3_cmudividerdprioin_logic <= cmudividerdprioin (399 DOWNTO 300);
ch4_cmudividerdprioin_logic <= cmudividerdprioin (499 DOWNTO 400);
ch5_cmudividerdprioin_logic <= cmudividerdprioin (599 DOWNTO 500);

-- ------- logic to physical mapping -------------------------
-- TXPCS
ch0_txpcsdprioin_phy <= ch0_txpcsdprioin_logic WHEN (tx0_logical_to_physical_mapping = 0) ELSE
						ch1_txpcsdprioin_logic WHEN (tx1_logical_to_physical_mapping = 0) ELSE
						ch2_txpcsdprioin_logic WHEN (tx2_logical_to_physical_mapping = 0) ELSE
						ch3_txpcsdprioin_logic WHEN (tx3_logical_to_physical_mapping = 0) ELSE
						ch0_txpcsdprioin_logic;

ch1_txpcsdprioin_phy <= ch0_txpcsdprioin_logic WHEN (tx0_logical_to_physical_mapping = 1) ELSE
						ch1_txpcsdprioin_logic WHEN (tx1_logical_to_physical_mapping = 1) ELSE
						ch2_txpcsdprioin_logic WHEN (tx2_logical_to_physical_mapping = 1) ELSE
						ch3_txpcsdprioin_logic WHEN (tx3_logical_to_physical_mapping = 1) ELSE
						ch1_txpcsdprioin_logic;

ch2_txpcsdprioin_phy <= ch0_txpcsdprioin_logic WHEN (tx0_logical_to_physical_mapping = 2) ELSE
						ch1_txpcsdprioin_logic WHEN (tx1_logical_to_physical_mapping = 2) ELSE
						ch2_txpcsdprioin_logic WHEN (tx2_logical_to_physical_mapping = 2) ELSE
						ch3_txpcsdprioin_logic WHEN (tx3_logical_to_physical_mapping = 2) ELSE
						ch2_txpcsdprioin_logic;

ch3_txpcsdprioin_phy <= ch0_txpcsdprioin_logic WHEN (tx0_logical_to_physical_mapping = 3) ELSE
						ch1_txpcsdprioin_logic WHEN (tx1_logical_to_physical_mapping = 3) ELSE
						ch2_txpcsdprioin_logic WHEN (tx2_logical_to_physical_mapping = 3) ELSE
						ch3_txpcsdprioin_logic WHEN (tx3_logical_to_physical_mapping = 3) ELSE
						ch3_txpcsdprioin_logic;

-- RXPCS
ch0_rxpcsdprioin_phy <= ch0_rxpcsdprioin_logic WHEN (rx0_logical_to_physical_mapping = 0) ELSE
						ch1_rxpcsdprioin_logic WHEN (rx1_logical_to_physical_mapping = 0) ELSE
						ch2_rxpcsdprioin_logic WHEN (rx2_logical_to_physical_mapping = 0) ELSE
						ch3_rxpcsdprioin_logic WHEN (rx3_logical_to_physical_mapping = 0) ELSE
						ch0_rxpcsdprioin_logic;

ch1_rxpcsdprioin_phy <= ch0_rxpcsdprioin_logic WHEN (rx0_logical_to_physical_mapping = 1) ELSE
						ch1_rxpcsdprioin_logic WHEN (rx1_logical_to_physical_mapping = 1) ELSE
						ch2_rxpcsdprioin_logic WHEN (rx2_logical_to_physical_mapping = 1) ELSE
						ch3_rxpcsdprioin_logic WHEN (rx3_logical_to_physical_mapping = 1) ELSE
						ch1_rxpcsdprioin_logic;

ch2_rxpcsdprioin_phy <= ch0_rxpcsdprioin_logic WHEN (rx0_logical_to_physical_mapping = 2) ELSE
						ch1_rxpcsdprioin_logic WHEN (rx1_logical_to_physical_mapping = 2) ELSE
						ch2_rxpcsdprioin_logic WHEN (rx2_logical_to_physical_mapping = 2) ELSE
						ch3_rxpcsdprioin_logic WHEN (rx3_logical_to_physical_mapping = 2) ELSE
						ch2_rxpcsdprioin_logic;

ch3_rxpcsdprioin_phy <= ch0_rxpcsdprioin_logic WHEN (rx0_logical_to_physical_mapping = 3) ELSE
						ch1_rxpcsdprioin_logic WHEN (rx1_logical_to_physical_mapping = 3) ELSE
						ch2_rxpcsdprioin_logic WHEN (rx2_logical_to_physical_mapping = 3) ELSE
						ch3_rxpcsdprioin_logic WHEN (rx3_logical_to_physical_mapping = 3) ELSE
						ch3_rxpcsdprioin_logic;

-- TXPMA
ch0_txpmadprioin_phy <= ch0_txpmadprioin_logic WHEN (tx0_logical_to_physical_mapping = 0) ELSE 
                        ch1_txpmadprioin_logic WHEN (tx1_logical_to_physical_mapping = 0) ELSE 
                        ch2_txpmadprioin_logic WHEN (tx2_logical_to_physical_mapping = 0) ELSE 
                        ch3_txpmadprioin_logic WHEN (tx3_logical_to_physical_mapping = 0) ELSE 
                        ch4_txpmadprioin_logic WHEN (tx4_logical_to_physical_mapping = 0) ELSE 
                        ch5_txpmadprioin_logic WHEN (tx5_logical_to_physical_mapping = 0) ELSE 
                        ch0_txpmadprioin_logic;
                        
ch1_txpmadprioin_phy <= ch0_txpmadprioin_logic WHEN (tx0_logical_to_physical_mapping = 1) ELSE 
                        ch1_txpmadprioin_logic WHEN (tx1_logical_to_physical_mapping = 1) ELSE 
                        ch2_txpmadprioin_logic WHEN (tx2_logical_to_physical_mapping = 1) ELSE 
                        ch3_txpmadprioin_logic WHEN (tx3_logical_to_physical_mapping = 1) ELSE 
                        ch4_txpmadprioin_logic WHEN (tx4_logical_to_physical_mapping = 1) ELSE 
                        ch5_txpmadprioin_logic WHEN (tx5_logical_to_physical_mapping = 1) ELSE 
                        ch1_txpmadprioin_logic;
                        
ch2_txpmadprioin_phy <= ch0_txpmadprioin_logic WHEN (tx0_logical_to_physical_mapping = 2) ELSE 
                        ch1_txpmadprioin_logic WHEN (tx1_logical_to_physical_mapping = 2) ELSE 
                        ch2_txpmadprioin_logic WHEN (tx2_logical_to_physical_mapping = 2) ELSE 
                        ch3_txpmadprioin_logic WHEN (tx3_logical_to_physical_mapping = 2) ELSE 
                        ch4_txpmadprioin_logic WHEN (tx4_logical_to_physical_mapping = 2) ELSE 
                        ch5_txpmadprioin_logic WHEN (tx5_logical_to_physical_mapping = 2) ELSE 
                        ch2_txpmadprioin_logic;
                        
ch3_txpmadprioin_phy <= ch0_txpmadprioin_logic WHEN (tx0_logical_to_physical_mapping = 3) ELSE 
                        ch1_txpmadprioin_logic WHEN (tx1_logical_to_physical_mapping = 3) ELSE 
                        ch2_txpmadprioin_logic WHEN (tx2_logical_to_physical_mapping = 3) ELSE 
                        ch3_txpmadprioin_logic WHEN (tx3_logical_to_physical_mapping = 3) ELSE 
                        ch4_txpmadprioin_logic WHEN (tx4_logical_to_physical_mapping = 3) ELSE 
                        ch5_txpmadprioin_logic WHEN (tx5_logical_to_physical_mapping = 3) ELSE 
                        ch3_txpmadprioin_logic;
                        
ch4_txpmadprioin_phy <= ch0_txpmadprioin_logic WHEN (tx0_logical_to_physical_mapping = 4) ELSE 
                        ch1_txpmadprioin_logic WHEN (tx1_logical_to_physical_mapping = 4) ELSE 
                        ch2_txpmadprioin_logic WHEN (tx2_logical_to_physical_mapping = 4) ELSE 
                        ch3_txpmadprioin_logic WHEN (tx3_logical_to_physical_mapping = 4) ELSE 
                        ch4_txpmadprioin_logic WHEN (tx4_logical_to_physical_mapping = 4) ELSE 
                        ch5_txpmadprioin_logic WHEN (tx5_logical_to_physical_mapping = 4) ELSE 
                        ch4_txpmadprioin_logic;
                        
ch5_txpmadprioin_phy <= ch0_txpmadprioin_logic WHEN (tx0_logical_to_physical_mapping = 5) ELSE 
                        ch1_txpmadprioin_logic WHEN (tx1_logical_to_physical_mapping = 5) ELSE 
                        ch2_txpmadprioin_logic WHEN (tx2_logical_to_physical_mapping = 5) ELSE 
                        ch3_txpmadprioin_logic WHEN (tx3_logical_to_physical_mapping = 5) ELSE 
                        ch4_txpmadprioin_logic WHEN (tx4_logical_to_physical_mapping = 5) ELSE 
                        ch5_txpmadprioin_logic WHEN (tx5_logical_to_physical_mapping = 5) ELSE 
                        ch5_txpmadprioin_logic;

-- RXPMA
ch0_rxpmadprioin_phy <= ch0_rxpmadprioin_logic WHEN (rx0_logical_to_physical_mapping = 0) ELSE 
                        ch1_rxpmadprioin_logic WHEN (rx1_logical_to_physical_mapping = 0) ELSE 
                        ch2_rxpmadprioin_logic WHEN (rx2_logical_to_physical_mapping = 0) ELSE 
                        ch3_rxpmadprioin_logic WHEN (rx3_logical_to_physical_mapping = 0) ELSE 
                        ch4_rxpmadprioin_logic WHEN (rx4_logical_to_physical_mapping = 0) ELSE 
                        ch5_rxpmadprioin_logic WHEN (rx5_logical_to_physical_mapping = 0) ELSE 
                        ch0_rxpmadprioin_logic;
                        
ch1_rxpmadprioin_phy <= ch0_rxpmadprioin_logic WHEN (rx0_logical_to_physical_mapping = 1) ELSE 
                        ch1_rxpmadprioin_logic WHEN (rx1_logical_to_physical_mapping = 1) ELSE 
                        ch2_rxpmadprioin_logic WHEN (rx2_logical_to_physical_mapping = 1) ELSE 
                        ch3_rxpmadprioin_logic WHEN (rx3_logical_to_physical_mapping = 1) ELSE 
                        ch4_rxpmadprioin_logic WHEN (rx4_logical_to_physical_mapping = 1) ELSE 
                        ch5_rxpmadprioin_logic WHEN (rx5_logical_to_physical_mapping = 1) ELSE 
                        ch1_rxpmadprioin_logic;
                        
ch2_rxpmadprioin_phy <= ch0_rxpmadprioin_logic WHEN (rx0_logical_to_physical_mapping = 2) ELSE 
                        ch1_rxpmadprioin_logic WHEN (rx1_logical_to_physical_mapping = 2) ELSE 
                        ch2_rxpmadprioin_logic WHEN (rx2_logical_to_physical_mapping = 2) ELSE 
                        ch3_rxpmadprioin_logic WHEN (rx3_logical_to_physical_mapping = 2) ELSE 
                        ch4_rxpmadprioin_logic WHEN (rx4_logical_to_physical_mapping = 2) ELSE 
                        ch5_rxpmadprioin_logic WHEN (rx5_logical_to_physical_mapping = 2) ELSE 
                        ch2_rxpmadprioin_logic;
                        
ch3_rxpmadprioin_phy <= ch0_rxpmadprioin_logic WHEN (rx0_logical_to_physical_mapping = 3) ELSE 
                        ch1_rxpmadprioin_logic WHEN (rx1_logical_to_physical_mapping = 3) ELSE 
                        ch2_rxpmadprioin_logic WHEN (rx2_logical_to_physical_mapping = 3) ELSE 
                        ch3_rxpmadprioin_logic WHEN (rx3_logical_to_physical_mapping = 3) ELSE 
                        ch4_rxpmadprioin_logic WHEN (rx4_logical_to_physical_mapping = 3) ELSE 
                        ch5_rxpmadprioin_logic WHEN (rx5_logical_to_physical_mapping = 3) ELSE 
                        ch3_rxpmadprioin_logic;
                        
ch4_rxpmadprioin_phy <= ch0_rxpmadprioin_logic WHEN (rx0_logical_to_physical_mapping = 4) ELSE 
                        ch1_rxpmadprioin_logic WHEN (rx1_logical_to_physical_mapping = 4) ELSE 
                        ch2_rxpmadprioin_logic WHEN (rx2_logical_to_physical_mapping = 4) ELSE 
                        ch3_rxpmadprioin_logic WHEN (rx3_logical_to_physical_mapping = 4) ELSE 
                        ch4_rxpmadprioin_logic WHEN (rx4_logical_to_physical_mapping = 4) ELSE 
                        ch5_rxpmadprioin_logic WHEN (rx5_logical_to_physical_mapping = 4) ELSE 
                        ch4_rxpmadprioin_logic;

ch5_rxpmadprioin_phy <= ch0_rxpmadprioin_logic WHEN (rx0_logical_to_physical_mapping = 5) ELSE 
                        ch1_rxpmadprioin_logic WHEN (rx1_logical_to_physical_mapping = 5) ELSE 
                        ch2_rxpmadprioin_logic WHEN (rx2_logical_to_physical_mapping = 5) ELSE 
                        ch3_rxpmadprioin_logic WHEN (rx3_logical_to_physical_mapping = 5) ELSE 
                        ch4_rxpmadprioin_logic WHEN (rx4_logical_to_physical_mapping = 5) ELSE 
                        ch5_rxpmadprioin_logic WHEN (rx5_logical_to_physical_mapping = 5) ELSE 
                        ch5_rxpmadprioin_logic;

-- PLL
ch0_rxplldprioin_phy <= ch0_rxplldprioin_logic   WHEN (pll0_logical_to_physical_mapping = 0) ELSE
                        ch1_rxplldprioin_logic   WHEN (pll1_logical_to_physical_mapping = 0)  ELSE
                        ch2_rxplldprioin_logic   WHEN (pll2_logical_to_physical_mapping = 0)  ELSE
                        ch3_rxplldprioin_logic   WHEN (pll3_logical_to_physical_mapping = 0)  ELSE
                        ch4_rxtxplldprioin_logic WHEN (pll4_logical_to_physical_mapping = 0)  ELSE
                        ch5_rxtxplldprioin_logic WHEN (pll5_logical_to_physical_mapping = 0)  ELSE
                        ch0_rxplldprioin_logic;

ch1_rxplldprioin_phy <= ch0_rxplldprioin_logic   WHEN (pll0_logical_to_physical_mapping = 1) ELSE
                        ch1_rxplldprioin_logic   WHEN (pll1_logical_to_physical_mapping = 1)  ELSE
                        ch2_rxplldprioin_logic   WHEN (pll2_logical_to_physical_mapping = 1)  ELSE
                        ch3_rxplldprioin_logic   WHEN (pll3_logical_to_physical_mapping = 1)  ELSE
                        ch4_rxtxplldprioin_logic WHEN (pll4_logical_to_physical_mapping = 1)  ELSE
                        ch5_rxtxplldprioin_logic WHEN (pll5_logical_to_physical_mapping = 1)  ELSE
                        ch1_rxplldprioin_logic;

ch2_rxplldprioin_phy <= ch0_rxplldprioin_logic   WHEN (pll0_logical_to_physical_mapping = 2) ELSE
                        ch1_rxplldprioin_logic   WHEN (pll1_logical_to_physical_mapping = 2)  ELSE
                        ch2_rxplldprioin_logic   WHEN (pll2_logical_to_physical_mapping = 2)  ELSE
                        ch3_rxplldprioin_logic   WHEN (pll3_logical_to_physical_mapping = 2)  ELSE
                        ch4_rxtxplldprioin_logic WHEN (pll4_logical_to_physical_mapping = 2)  ELSE
                        ch5_rxtxplldprioin_logic WHEN (pll5_logical_to_physical_mapping = 2)  ELSE
                        ch2_rxplldprioin_logic;

ch3_rxplldprioin_phy <= ch0_rxplldprioin_logic   WHEN (pll0_logical_to_physical_mapping = 3) ELSE
                        ch1_rxplldprioin_logic   WHEN (pll1_logical_to_physical_mapping = 3)  ELSE
                        ch2_rxplldprioin_logic   WHEN (pll2_logical_to_physical_mapping = 3)  ELSE
                        ch3_rxplldprioin_logic   WHEN (pll3_logical_to_physical_mapping = 3)  ELSE
                        ch4_rxtxplldprioin_logic WHEN (pll4_logical_to_physical_mapping = 3)  ELSE
                        ch5_rxtxplldprioin_logic WHEN (pll5_logical_to_physical_mapping = 3)  ELSE
                        ch3_rxplldprioin_logic;

ch4_rxtxplldprioin_phy <= ch0_rxplldprioin_logic WHEN (pll0_logical_to_physical_mapping = 4)  ELSE
                        ch1_rxplldprioin_logic   WHEN (pll1_logical_to_physical_mapping = 4)  ELSE
                        ch2_rxplldprioin_logic   WHEN (pll2_logical_to_physical_mapping = 4)  ELSE
                        ch3_rxplldprioin_logic   WHEN (pll3_logical_to_physical_mapping = 4)  ELSE
                        ch4_rxtxplldprioin_logic WHEN (pll4_logical_to_physical_mapping = 4)  ELSE
                        ch5_rxtxplldprioin_logic WHEN (pll5_logical_to_physical_mapping = 4)  ELSE
                        ch4_rxtxplldprioin_logic;
                        
ch5_rxtxplldprioin_phy <= ch0_rxplldprioin_logic WHEN (pll0_logical_to_physical_mapping = 5)  ELSE
                        ch1_rxplldprioin_logic   WHEN (pll1_logical_to_physical_mapping = 5)  ELSE
                        ch2_rxplldprioin_logic   WHEN (pll2_logical_to_physical_mapping = 5)  ELSE
                        ch3_rxplldprioin_logic   WHEN (pll3_logical_to_physical_mapping = 5)  ELSE
                        ch4_rxtxplldprioin_logic WHEN (pll4_logical_to_physical_mapping = 5)  ELSE
                        ch5_rxtxplldprioin_logic WHEN (pll5_logical_to_physical_mapping = 5)  ELSE
                        ch5_rxtxplldprioin_logic;

-- CMUDivider
ch0_cmudividerdprioin_phy <= ch0_cmudividerdprioin_logic WHEN (tx0_logical_to_physical_mapping = 0) ELSE
                             ch1_cmudividerdprioin_logic WHEN (tx1_logical_to_physical_mapping = 0) ELSE
                             ch2_cmudividerdprioin_logic WHEN (tx2_logical_to_physical_mapping = 0) ELSE 
                             ch3_cmudividerdprioin_logic WHEN (tx3_logical_to_physical_mapping = 0) ELSE 
                             ch4_cmudividerdprioin_logic WHEN (tx4_logical_to_physical_mapping = 0) ELSE
                             ch5_cmudividerdprioin_logic WHEN (tx5_logical_to_physical_mapping = 0) ELSE 
                             ch0_cmudividerdprioin_logic;
                              
ch1_cmudividerdprioin_phy <= ch0_cmudividerdprioin_logic WHEN (tx0_logical_to_physical_mapping = 1) ELSE 
                             ch1_cmudividerdprioin_logic WHEN (tx1_logical_to_physical_mapping = 1) ELSE 
                             ch2_cmudividerdprioin_logic WHEN (tx2_logical_to_physical_mapping = 1) ELSE 
                             ch3_cmudividerdprioin_logic WHEN (tx3_logical_to_physical_mapping = 1) ELSE 
                             ch4_cmudividerdprioin_logic WHEN (tx4_logical_to_physical_mapping = 1) ELSE 
                             ch5_cmudividerdprioin_logic WHEN (tx5_logical_to_physical_mapping = 1) ELSE 
                             ch1_cmudividerdprioin_logic;
                              
ch2_cmudividerdprioin_phy <= ch0_cmudividerdprioin_logic WHEN (tx0_logical_to_physical_mapping = 2) ELSE 
                             ch1_cmudividerdprioin_logic WHEN (tx1_logical_to_physical_mapping = 2) ELSE 
  		                     ch2_cmudividerdprioin_logic WHEN (tx2_logical_to_physical_mapping = 2) ELSE 
        		             ch3_cmudividerdprioin_logic WHEN (tx3_logical_to_physical_mapping = 2) ELSE 
                		     ch4_cmudividerdprioin_logic WHEN (tx4_logical_to_physical_mapping = 2) ELSE 
                             ch5_cmudividerdprioin_logic WHEN (tx5_logical_to_physical_mapping = 2) ELSE 
                             ch2_cmudividerdprioin_logic;
                              
ch3_cmudividerdprioin_phy <= ch0_cmudividerdprioin_logic WHEN (tx0_logical_to_physical_mapping = 3) ELSE 
                             ch1_cmudividerdprioin_logic WHEN (tx1_logical_to_physical_mapping = 3) ELSE 
                             ch2_cmudividerdprioin_logic WHEN (tx2_logical_to_physical_mapping = 3) ELSE 
                             ch3_cmudividerdprioin_logic WHEN (tx3_logical_to_physical_mapping = 3) ELSE 
                             ch4_cmudividerdprioin_logic WHEN (tx4_logical_to_physical_mapping = 3) ELSE 
                             ch5_cmudividerdprioin_logic WHEN (tx5_logical_to_physical_mapping = 3) ELSE 
                             ch3_cmudividerdprioin_logic;
                              
ch4_cmudividerdprioin_phy <= ch0_cmudividerdprioin_logic WHEN (tx0_logical_to_physical_mapping = 4) ELSE 
                             ch1_cmudividerdprioin_logic WHEN (tx1_logical_to_physical_mapping = 4) ELSE 
                             ch2_cmudividerdprioin_logic WHEN (tx2_logical_to_physical_mapping = 4) ELSE 
                             ch3_cmudividerdprioin_logic WHEN (tx3_logical_to_physical_mapping = 4) ELSE 
                             ch4_cmudividerdprioin_logic WHEN (tx4_logical_to_physical_mapping = 4) ELSE 
                             ch5_cmudividerdprioin_logic WHEN (tx5_logical_to_physical_mapping = 4) ELSE 
                             ch4_cmudividerdprioin_logic;
                              
ch5_cmudividerdprioin_phy <= ch0_cmudividerdprioin_logic WHEN (tx0_logical_to_physical_mapping = 5) ELSE 
                             ch1_cmudividerdprioin_logic WHEN (tx1_logical_to_physical_mapping = 5) ELSE 
                             ch2_cmudividerdprioin_logic WHEN (tx2_logical_to_physical_mapping = 5) ELSE 
                             ch3_cmudividerdprioin_logic WHEN (tx3_logical_to_physical_mapping = 5) ELSE 
                             ch4_cmudividerdprioin_logic WHEN (tx4_logical_to_physical_mapping = 5) ELSE 
                             ch5_cmudividerdprioin_logic WHEN (tx5_logical_to_physical_mapping = 5) ELSE 
                             ch5_cmudividerdprioin_logic;                        
                             
-- -------- SW ordering  ------------------------------------
--TXPCS
ch0_in_chnl_ctrl_1 <= ch0_txpcsdprioin_phy (rforce_kchar_DP_TXPCS_IDX_0 DOWNTO rforce_disp_DP_TXPCS_IDX_0);
ch1_in_chnl_ctrl_1 <= ch1_txpcsdprioin_phy (rforce_kchar_DP_TXPCS_IDX_0 DOWNTO rforce_disp_DP_TXPCS_IDX_0);
ch2_in_chnl_ctrl_1 <= ch2_txpcsdprioin_phy (rforce_kchar_DP_TXPCS_IDX_0 DOWNTO rforce_disp_DP_TXPCS_IDX_0);
ch3_in_chnl_ctrl_1 <= ch3_txpcsdprioin_phy (rforce_kchar_DP_TXPCS_IDX_0 DOWNTO rforce_disp_DP_TXPCS_IDX_0);

ch0_in_chnl_ctrl_2 <= ch0_txpcsdprioin_phy (rendec_tx_DP_TXPCS_IDX_0 DOWNTO rtxpcsbypass_en_DP_TXPCS_IDX_0);
ch1_in_chnl_ctrl_2 <= ch1_txpcsdprioin_phy (rendec_tx_DP_TXPCS_IDX_0 DOWNTO rtxpcsbypass_en_DP_TXPCS_IDX_0);
ch2_in_chnl_ctrl_2 <= ch2_txpcsdprioin_phy (rendec_tx_DP_TXPCS_IDX_0 DOWNTO rtxpcsbypass_en_DP_TXPCS_IDX_0);
ch3_in_chnl_ctrl_2 <= ch3_txpcsdprioin_phy (rendec_tx_DP_TXPCS_IDX_0 DOWNTO rtxpcsbypass_en_DP_TXPCS_IDX_0);

ch0_in_chnl_ctrl_3 <= ch0_txpcsdprioin_phy (rtx_pipe_enable_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB3_DP_TXPCS_IDX_0);
ch1_in_chnl_ctrl_3 <= ch1_txpcsdprioin_phy (rtx_pipe_enable_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB3_DP_TXPCS_IDX_0);
ch2_in_chnl_ctrl_3 <= ch2_txpcsdprioin_phy (rtx_pipe_enable_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB3_DP_TXPCS_IDX_0);
ch3_in_chnl_ctrl_3 <= ch3_txpcsdprioin_phy (rtx_pipe_enable_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB3_DP_TXPCS_IDX_0);

ch0_in_chnl_ctrl_4 <= ch0_txpcsdprioin_phy (rself_sw_en_tx_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB4_DP_TXPCS_IDX_0);
ch1_in_chnl_ctrl_4 <= ch1_txpcsdprioin_phy (rself_sw_en_tx_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB4_DP_TXPCS_IDX_0);
ch2_in_chnl_ctrl_4 <= ch2_txpcsdprioin_phy (rself_sw_en_tx_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB4_DP_TXPCS_IDX_0);
ch3_in_chnl_ctrl_4 <= ch3_txpcsdprioin_phy (rself_sw_en_tx_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB4_DP_TXPCS_IDX_0);

ch0_in_chnl_ctrl_5 <= ch0_rxpcsdprioin_phy (reserved_0_TB5_DP_RXPCS_IDX_0 DOWNTO rrxpcsbypass_en_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_5 <= ch1_rxpcsdprioin_phy (reserved_0_TB5_DP_RXPCS_IDX_0 DOWNTO rrxpcsbypass_en_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_5 <= ch2_rxpcsdprioin_phy (reserved_0_TB5_DP_RXPCS_IDX_0 DOWNTO rrxpcsbypass_en_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_5 <= ch3_rxpcsdprioin_phy (reserved_0_TB5_DP_RXPCS_IDX_0 DOWNTO rrxpcsbypass_en_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_6 <= ch0_rxpcsdprioin_phy (resync_badcg_en_DP_RXPCS_IDX_1 DOWNTO rcomp_pat_32_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_6 <= ch1_rxpcsdprioin_phy (resync_badcg_en_DP_RXPCS_IDX_1 DOWNTO rcomp_pat_32_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_6 <= ch2_rxpcsdprioin_phy (resync_badcg_en_DP_RXPCS_IDX_1 DOWNTO rcomp_pat_32_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_6 <= ch3_rxpcsdprioin_phy (resync_badcg_en_DP_RXPCS_IDX_1 DOWNTO rcomp_pat_32_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_7 <= ch0_rxpcsdprioin_phy (rcomp_pat_31_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_16_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_7 <= ch1_rxpcsdprioin_phy (rcomp_pat_31_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_16_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_7 <= ch2_rxpcsdprioin_phy (rcomp_pat_31_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_16_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_7 <= ch3_rxpcsdprioin_phy (rcomp_pat_31_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_16_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_8 <= ch0_rxpcsdprioin_phy (rcomp_pat_15_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_0_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_8 <= ch1_rxpcsdprioin_phy (rcomp_pat_15_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_0_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_8 <= ch2_rxpcsdprioin_phy (rcomp_pat_15_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_0_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_8 <= ch3_rxpcsdprioin_phy (rcomp_pat_15_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_0_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_9 <= ch0_rxpcsdprioin_phy (rsync_sm_dis_DP_RXPCS_IDX_0 DOWNTO rbitloc_rev_en_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_9 <= ch1_rxpcsdprioin_phy (rsync_sm_dis_DP_RXPCS_IDX_0 DOWNTO rbitloc_rev_en_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_9 <= ch2_rxpcsdprioin_phy (rsync_sm_dis_DP_RXPCS_IDX_0 DOWNTO rbitloc_rev_en_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_9 <= ch3_rxpcsdprioin_phy (rsync_sm_dis_DP_RXPCS_IDX_0 DOWNTO rbitloc_rev_en_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_10 <= ch0_rxpcsdprioin_phy (rgnumber_DP_RXPCS_IDX_7 DOWNTO rknumber_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_10 <= ch1_rxpcsdprioin_phy (rgnumber_DP_RXPCS_IDX_7 DOWNTO rknumber_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_10 <= ch2_rxpcsdprioin_phy (rgnumber_DP_RXPCS_IDX_7 DOWNTO rknumber_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_10 <= ch3_rxpcsdprioin_phy (rgnumber_DP_RXPCS_IDX_7 DOWNTO rknumber_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_11 <= ch0_rxpcsdprioin_phy (rrundisp_DP_RXPCS_IDX_5 DOWNTO renpolinv_rx_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_11 <= ch1_rxpcsdprioin_phy (rrundisp_DP_RXPCS_IDX_5 DOWNTO renpolinv_rx_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_11 <= ch2_rxpcsdprioin_phy (rrundisp_DP_RXPCS_IDX_5 DOWNTO renpolinv_rx_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_11 <= ch3_rxpcsdprioin_phy (rrundisp_DP_RXPCS_IDX_5 DOWNTO renpolinv_rx_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_12 <= ch0_rxpcsdprioin_phy (rmatchen_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_12 <= ch1_rxpcsdprioin_phy (rmatchen_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_12 <= ch2_rxpcsdprioin_phy (rmatchen_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_12 <= ch3_rxpcsdprioin_phy (rmatchen_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_13 <= ch0_rxpcsdprioin_phy (rclkcmpsq1n_19_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_10_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_13 <= ch1_rxpcsdprioin_phy (rclkcmpsq1n_19_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_10_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_13 <= ch2_rxpcsdprioin_phy (rclkcmpsq1n_19_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_10_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_13 <= ch3_rxpcsdprioin_phy (rclkcmpsq1n_19_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_10_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_14 <= ch0_rxpcsdprioin_phy (rclkcmpsq1n_14_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1n_0_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_14 <= ch1_rxpcsdprioin_phy (rclkcmpsq1n_14_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1n_0_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_14 <= ch2_rxpcsdprioin_phy (rclkcmpsq1n_14_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1n_0_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_14 <= ch3_rxpcsdprioin_phy (rclkcmpsq1n_14_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1n_0_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_15 <= ch0_rxpcsdprioin_phy (rclkcmp_pipe_en_DP_RXPCS_IDX_0 DOWNTO rfull_threshold_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_15 <= ch1_rxpcsdprioin_phy (rclkcmp_pipe_en_DP_RXPCS_IDX_0 DOWNTO rfull_threshold_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_15 <= ch2_rxpcsdprioin_phy (rclkcmp_pipe_en_DP_RXPCS_IDX_0 DOWNTO rfull_threshold_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_15 <= ch3_rxpcsdprioin_phy (rclkcmp_pipe_en_DP_RXPCS_IDX_0 DOWNTO rfull_threshold_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_16 <= ch0_rxpcsdprioin_phy (rempty_threshold_DP_RXPCS_IDX_2 DOWNTO rfreq_sel_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_16 <= ch1_rxpcsdprioin_phy (rempty_threshold_DP_RXPCS_IDX_2 DOWNTO rfreq_sel_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_16 <= ch2_rxpcsdprioin_phy (rempty_threshold_DP_RXPCS_IDX_2 DOWNTO rfreq_sel_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_16 <= ch3_rxpcsdprioin_phy (rempty_threshold_DP_RXPCS_IDX_2 DOWNTO rfreq_sel_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_17 <= ch0_rxpcsdprioin_phy (rrxfifo_dis_DP_RXPCS_IDX_0 DOWNTO rtest_bus_sel_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_17 <= ch1_rxpcsdprioin_phy (rrxfifo_dis_DP_RXPCS_IDX_0 DOWNTO rtest_bus_sel_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_17 <= ch2_rxpcsdprioin_phy (rrxfifo_dis_DP_RXPCS_IDX_0 DOWNTO rtest_bus_sel_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_17 <= ch3_rxpcsdprioin_phy (rrxfifo_dis_DP_RXPCS_IDX_0 DOWNTO rtest_bus_sel_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_18 <= ch0_rxpcsdprioin_phy (reserved_0_TB18_DP_RXPCS_IDX_5 DOWNTO rbytordpat_0_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_18 <= ch1_rxpcsdprioin_phy (reserved_0_TB18_DP_RXPCS_IDX_5 DOWNTO rbytordpat_0_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_18 <= ch2_rxpcsdprioin_phy (reserved_0_TB18_DP_RXPCS_IDX_5 DOWNTO rbytordpat_0_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_18 <= ch3_rxpcsdprioin_phy (reserved_0_TB18_DP_RXPCS_IDX_5 DOWNTO rbytordpat_0_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_19 <= ch0_rxpcsdprioin_phy (reserved_0_TB19_DP_RXPCS_IDX_5 DOWNTO rbytordpad_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_19 <= ch1_rxpcsdprioin_phy (reserved_0_TB19_DP_RXPCS_IDX_5 DOWNTO rbytordpad_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_19 <= ch2_rxpcsdprioin_phy (reserved_0_TB19_DP_RXPCS_IDX_5 DOWNTO rbytordpad_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_19 <= ch3_rxpcsdprioin_phy (reserved_0_TB19_DP_RXPCS_IDX_5 DOWNTO rbytordpad_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_20 <= ch0_rxpcsdprioin_phy (rrx_pipe_enable_DP_RXPCS_IDX_0 DOWNTO rload_shreg_del_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_20 <= ch1_rxpcsdprioin_phy (rrx_pipe_enable_DP_RXPCS_IDX_0 DOWNTO rload_shreg_del_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_20 <= ch2_rxpcsdprioin_phy (rrx_pipe_enable_DP_RXPCS_IDX_0 DOWNTO rload_shreg_del_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_20 <= ch3_rxpcsdprioin_phy (rrx_pipe_enable_DP_RXPCS_IDX_0 DOWNTO rload_shreg_del_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_21 <= ch0_rxpcsdprioin_phy (rpma_done_count_15_DP_RXPCS_IDX_0 DOWNTO rpma_done_count_0_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_21 <= ch1_rxpcsdprioin_phy (rpma_done_count_15_DP_RXPCS_IDX_0 DOWNTO rpma_done_count_0_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_21 <= ch2_rxpcsdprioin_phy (rpma_done_count_15_DP_RXPCS_IDX_0 DOWNTO rpma_done_count_0_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_21 <= ch3_rxpcsdprioin_phy (rpma_done_count_15_DP_RXPCS_IDX_0 DOWNTO rpma_done_count_0_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_22 <= ch0_rxpcsdprioin_phy (rerr_flags_sel_DP_RXPCS_IDX_0 DOWNTO rbytordpat_10_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_22 <= ch1_rxpcsdprioin_phy (rerr_flags_sel_DP_RXPCS_IDX_0 DOWNTO rbytordpat_10_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_22 <= ch2_rxpcsdprioin_phy (rerr_flags_sel_DP_RXPCS_IDX_0 DOWNTO rbytordpat_10_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_22 <= ch3_rxpcsdprioin_phy (rerr_flags_sel_DP_RXPCS_IDX_0 DOWNTO rbytordpat_10_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_23 <= ch0_rxpcsdprioin_phy (reserved_0_TB23_DP_RXPCS_IDX_7 DOWNTO rwait_count_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_23 <= ch1_rxpcsdprioin_phy (reserved_0_TB23_DP_RXPCS_IDX_7 DOWNTO rwait_count_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_23 <= ch2_rxpcsdprioin_phy (reserved_0_TB23_DP_RXPCS_IDX_7 DOWNTO rwait_count_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_23 <= ch3_rxpcsdprioin_phy (reserved_0_TB23_DP_RXPCS_IDX_7 DOWNTO rwait_count_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_24 <= ch0_rxpcsdprioin_phy (rwait_for_phfifo_cnt_DP_RXPCS_IDX_5 DOWNTO rfts_count_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_24 <= ch1_rxpcsdprioin_phy (rwait_for_phfifo_cnt_DP_RXPCS_IDX_5 DOWNTO rfts_count_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_24 <= ch2_rxpcsdprioin_phy (rwait_for_phfifo_cnt_DP_RXPCS_IDX_5 DOWNTO rfts_count_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_24 <= ch3_rxpcsdprioin_phy (rwait_for_phfifo_cnt_DP_RXPCS_IDX_5 DOWNTO rfts_count_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_25 <= ch0_rxpcsdprioin_phy (reserved_0_TB25_DP_RXPCS_IDX_4 DOWNTO rppm_meas_delay_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_25 <= ch1_rxpcsdprioin_phy (reserved_0_TB25_DP_RXPCS_IDX_4 DOWNTO rppm_meas_delay_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_25 <= ch2_rxpcsdprioin_phy (reserved_0_TB25_DP_RXPCS_IDX_4 DOWNTO rppm_meas_delay_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_25 <= ch3_rxpcsdprioin_phy (reserved_0_TB25_DP_RXPCS_IDX_4 DOWNTO rppm_meas_delay_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_26 <= ch0_rxpcsdprioin_phy (rphfifo_regmode_rx_DP_RXPCS_IDX_0 DOWNTO rauto_pc_en_cnt_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_26 <= ch1_rxpcsdprioin_phy (rphfifo_regmode_rx_DP_RXPCS_IDX_0 DOWNTO rauto_pc_en_cnt_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_26 <= ch2_rxpcsdprioin_phy (rphfifo_regmode_rx_DP_RXPCS_IDX_0 DOWNTO rauto_pc_en_cnt_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_26 <= ch3_rxpcsdprioin_phy (rphfifo_regmode_rx_DP_RXPCS_IDX_0 DOWNTO rauto_pc_en_cnt_DP_RXPCS_IDX_0);

ch0_in_chnl_ctrl_27 <= ch0_rxpcsdprioin_phy (reserved_0_TB27_DP_RXPCS_IDX_3 DOWNTO rmask_count_DP_RXPCS_IDX_0);
ch1_in_chnl_ctrl_27 <= ch1_rxpcsdprioin_phy (reserved_0_TB27_DP_RXPCS_IDX_3 DOWNTO rmask_count_DP_RXPCS_IDX_0);
ch2_in_chnl_ctrl_27 <= ch2_rxpcsdprioin_phy (reserved_0_TB27_DP_RXPCS_IDX_3 DOWNTO rmask_count_DP_RXPCS_IDX_0);
ch3_in_chnl_ctrl_27 <= ch3_rxpcsdprioin_phy (reserved_0_TB27_DP_RXPCS_IDX_3 DOWNTO rmask_count_DP_RXPCS_IDX_0);

--TXPMA
ch0_in_chnl_ctrl_28 <= ch0_txpmadprioin_phy (rvod_sel_non_pcie_DP_TXPMA_IDX_2 DOWNTO rpowdnt_DP_TXPMA_IDX_0);
ch1_in_chnl_ctrl_28 <= ch1_txpmadprioin_phy (rvod_sel_non_pcie_DP_TXPMA_IDX_2 DOWNTO rpowdnt_DP_TXPMA_IDX_0);
ch2_in_chnl_ctrl_28 <= ch2_txpmadprioin_phy (rvod_sel_non_pcie_DP_TXPMA_IDX_2 DOWNTO rpowdnt_DP_TXPMA_IDX_0);
ch3_in_chnl_ctrl_28 <= ch3_txpmadprioin_phy (rvod_sel_non_pcie_DP_TXPMA_IDX_2 DOWNTO rpowdnt_DP_TXPMA_IDX_0);
ch4_in_chnl_ctrl_28 <= ch4_txpmadprioin_phy (rvod_sel_non_pcie_DP_TXPMA_IDX_2 DOWNTO rpowdnt_DP_TXPMA_IDX_0);
ch5_in_chnl_ctrl_28 <= ch5_txpmadprioin_phy (rvod_sel_non_pcie_DP_TXPMA_IDX_2 DOWNTO rpowdnt_DP_TXPMA_IDX_0);

ch0_in_chnl_ctrl_29 <= ch0_txpmadprioin_phy (rpre_em_1t_no_pcie_DP_TXPMA_IDX_4 DOWNTO reserved_0_TB29_DP_TXPMA_IDX_0);
ch1_in_chnl_ctrl_29 <= ch1_txpmadprioin_phy (rpre_em_1t_no_pcie_DP_TXPMA_IDX_4 DOWNTO reserved_0_TB29_DP_TXPMA_IDX_0);
ch2_in_chnl_ctrl_29 <= ch2_txpmadprioin_phy (rpre_em_1t_no_pcie_DP_TXPMA_IDX_4 DOWNTO reserved_0_TB29_DP_TXPMA_IDX_0);
ch3_in_chnl_ctrl_29 <= ch3_txpmadprioin_phy (rpre_em_1t_no_pcie_DP_TXPMA_IDX_4 DOWNTO reserved_0_TB29_DP_TXPMA_IDX_0);
ch4_in_chnl_ctrl_29 <= ch4_txpmadprioin_phy (rpre_em_1t_no_pcie_DP_TXPMA_IDX_4 DOWNTO reserved_0_TB29_DP_TXPMA_IDX_0);
ch5_in_chnl_ctrl_29 <= ch5_txpmadprioin_phy (rpre_em_1t_no_pcie_DP_TXPMA_IDX_4 DOWNTO reserved_0_TB29_DP_TXPMA_IDX_0);

ch0_in_chnl_ctrl_30 <= ch0_txpmadprioin_phy (reserved_0_TB30_DP_TXPMA_IDX_2 DOWNTO rpre_em_pt_DP_TXPMA_IDX_0);
ch1_in_chnl_ctrl_30 <= ch1_txpmadprioin_phy (reserved_0_TB30_DP_TXPMA_IDX_2 DOWNTO rpre_em_pt_DP_TXPMA_IDX_0);
ch2_in_chnl_ctrl_30 <= ch2_txpmadprioin_phy (reserved_0_TB30_DP_TXPMA_IDX_2 DOWNTO rpre_em_pt_DP_TXPMA_IDX_0);
ch3_in_chnl_ctrl_30 <= ch3_txpmadprioin_phy (reserved_0_TB30_DP_TXPMA_IDX_2 DOWNTO rpre_em_pt_DP_TXPMA_IDX_0);
ch4_in_chnl_ctrl_30 <= ch4_txpmadprioin_phy (reserved_0_TB30_DP_TXPMA_IDX_2 DOWNTO rpre_em_pt_DP_TXPMA_IDX_0);
ch5_in_chnl_ctrl_30 <= ch5_txpmadprioin_phy (reserved_0_TB30_DP_TXPMA_IDX_2 DOWNTO rpre_em_pt_DP_TXPMA_IDX_0);

ch0_in_chnl_ctrl_31 <= ch0_txpmadprioin_phy (rtx_term_sel_DP_TXPMA_IDX_2 DOWNTO rlowv_DP_TXPMA_IDX_0);
ch1_in_chnl_ctrl_31 <= ch1_txpmadprioin_phy (rtx_term_sel_DP_TXPMA_IDX_2 DOWNTO rlowv_DP_TXPMA_IDX_0);
ch2_in_chnl_ctrl_31 <= ch2_txpmadprioin_phy (rtx_term_sel_DP_TXPMA_IDX_2 DOWNTO rlowv_DP_TXPMA_IDX_0);
ch3_in_chnl_ctrl_31 <= ch3_txpmadprioin_phy (rtx_term_sel_DP_TXPMA_IDX_2 DOWNTO rlowv_DP_TXPMA_IDX_0);
ch4_in_chnl_ctrl_31 <= ch4_txpmadprioin_phy (rtx_term_sel_DP_TXPMA_IDX_2 DOWNTO rlowv_DP_TXPMA_IDX_0);
ch5_in_chnl_ctrl_31 <= ch5_txpmadprioin_phy (rtx_term_sel_DP_TXPMA_IDX_2 DOWNTO rlowv_DP_TXPMA_IDX_0);

ch0_in_chnl_ctrl_32 <= ch0_txpmadprioin_phy (r_dft_sel_DP_TXPMA_IDX_2 DOWNTO reserved_1_TB32_DP_TXPMA_IDX_0);
ch1_in_chnl_ctrl_32 <= ch1_txpmadprioin_phy (r_dft_sel_DP_TXPMA_IDX_2 DOWNTO reserved_1_TB32_DP_TXPMA_IDX_0);
ch2_in_chnl_ctrl_32 <= ch2_txpmadprioin_phy (r_dft_sel_DP_TXPMA_IDX_2 DOWNTO reserved_1_TB32_DP_TXPMA_IDX_0);
ch3_in_chnl_ctrl_32 <= ch3_txpmadprioin_phy (r_dft_sel_DP_TXPMA_IDX_2 DOWNTO reserved_1_TB32_DP_TXPMA_IDX_0);
ch4_in_chnl_ctrl_32 <= ch4_txpmadprioin_phy (r_dft_sel_DP_TXPMA_IDX_2 DOWNTO reserved_1_TB32_DP_TXPMA_IDX_0);
ch5_in_chnl_ctrl_32 <= ch5_txpmadprioin_phy (r_dft_sel_DP_TXPMA_IDX_2 DOWNTO reserved_1_TB32_DP_TXPMA_IDX_0);

-- performed in manual section between table33 splits between tx_pma and clock divider
--ch0_in_chnl_ctrl_33 <= ch0_txpmadprioin_phy (rcgb_x_en_DP_TXPMA_IDX_1 DOWNTO reserved_0_TB33_DP_TXPMA_IDX_0);
--ch1_in_chnl_ctrl_33 <= ch1_txpmadprioin_phy (rcgb_x_en_DP_TXPMA_IDX_1 DOWNTO reserved_0_TB33_DP_TXPMA_IDX_0);
--ch2_in_chnl_ctrl_33 <= ch2_txpmadprioin_phy (rcgb_x_en_DP_TXPMA_IDX_1 DOWNTO reserved_0_TB33_DP_TXPMA_IDX_0);
--ch3_in_chnl_ctrl_33 <= ch3_txpmadprioin_phy (rcgb_x_en_DP_TXPMA_IDX_1 DOWNTO reserved_0_TB33_DP_TXPMA_IDX_0);
--ch4_in_chnl_ctrl_33 <= ch4_txpmadprioin_phy (rcgb_x_en_DP_TXPMA_IDX_1 DOWNTO reserved_0_TB33_DP_TXPMA_IDX_0);
--ch5_in_chnl_ctrl_33 <= ch5_txpmadprioin_phy (rcgb_x_en_DP_TXPMA_IDX_1 DOWNTO reserved_0_TB33_DP_TXPMA_IDX_0);

-- Done in manual section because of logical PLL indices
--ch0_in_chnl_ctrl_34 <= ch0_txpmadprioin_phy (riqclk_sel_DP_TXPMA_IDX_1 DOWNTO reserved_1_TB34_DP_TXPMA_IDX_0);
--ch1_in_chnl_ctrl_34 <= ch1_txpmadprioin_phy (riqclk_sel_DP_TXPMA_IDX_1 DOWNTO reserved_1_TB34_DP_TXPMA_IDX_0);
--ch2_in_chnl_ctrl_34 <= ch2_txpmadprioin_phy (riqclk_sel_DP_TXPMA_IDX_1 DOWNTO reserved_1_TB34_DP_TXPMA_IDX_0);
--ch3_in_chnl_ctrl_34 <= ch3_txpmadprioin_phy (riqclk_sel_DP_TXPMA_IDX_1 DOWNTO reserved_1_TB34_DP_TXPMA_IDX_0);
--ch4_in_chnl_ctrl_34 <= ch4_txpmadprioin_phy (riqclk_sel_DP_TXPMA_IDX_1 DOWNTO reserved_1_TB34_DP_TXPMA_IDX_0);
--ch5_in_chnl_ctrl_34 <= ch5_txpmadprioin_phy (riqclk_sel_DP_TXPMA_IDX_1 DOWNTO reserved_1_TB34_DP_TXPMA_IDX_0);

ch0_in_chnl_ctrl_35 <= ch0_txpmadprioin_phy (rpma_reserved_0_TB35_DP_TXPMA_IDX_15 DOWNTO rpma_reserved_0_TB35_DP_TXPMA_IDX_0);
ch1_in_chnl_ctrl_35 <= ch1_txpmadprioin_phy (rpma_reserved_0_TB35_DP_TXPMA_IDX_15 DOWNTO rpma_reserved_0_TB35_DP_TXPMA_IDX_0);
ch2_in_chnl_ctrl_35 <= ch2_txpmadprioin_phy (rpma_reserved_0_TB35_DP_TXPMA_IDX_15 DOWNTO rpma_reserved_0_TB35_DP_TXPMA_IDX_0);
ch3_in_chnl_ctrl_35 <= ch3_txpmadprioin_phy (rpma_reserved_0_TB35_DP_TXPMA_IDX_15 DOWNTO rpma_reserved_0_TB35_DP_TXPMA_IDX_0);
ch4_in_chnl_ctrl_35 <= ch4_txpmadprioin_phy (rpma_reserved_0_TB35_DP_TXPMA_IDX_15 DOWNTO rpma_reserved_0_TB35_DP_TXPMA_IDX_0);
ch5_in_chnl_ctrl_35 <= ch5_txpmadprioin_phy (rpma_reserved_0_TB35_DP_TXPMA_IDX_15 DOWNTO rpma_reserved_0_TB35_DP_TXPMA_IDX_0);

ch0_in_chnl_ctrl_36 <= ch0_rxpmadprioin_phy (rrx_lst_DP_RXPMA_IDX_4 DOWNTO rrx_term_sel_DP_RXPMA_IDX_0);
ch1_in_chnl_ctrl_36 <= ch1_rxpmadprioin_phy (rrx_lst_DP_RXPMA_IDX_4 DOWNTO rrx_term_sel_DP_RXPMA_IDX_0);
ch2_in_chnl_ctrl_36 <= ch2_rxpmadprioin_phy (rrx_lst_DP_RXPMA_IDX_4 DOWNTO rrx_term_sel_DP_RXPMA_IDX_0);
ch3_in_chnl_ctrl_36 <= ch3_rxpmadprioin_phy (rrx_lst_DP_RXPMA_IDX_4 DOWNTO rrx_term_sel_DP_RXPMA_IDX_0);
ch4_in_chnl_ctrl_36 <= ch4_rxpmadprioin_phy (rrx_lst_DP_RXPMA_IDX_4 DOWNTO rrx_term_sel_DP_RXPMA_IDX_0);
ch5_in_chnl_ctrl_36 <= ch5_rxpmadprioin_phy (rrx_lst_DP_RXPMA_IDX_4 DOWNTO rrx_term_sel_DP_RXPMA_IDX_0);

ch0_in_chnl_ctrl_37 <= ch0_rxpmadprioin_phy (rrx_sdlv_DP_RXPMA_IDX_3 DOWNTO rrxurstpma_DP_RXPMA_IDX_0);
ch1_in_chnl_ctrl_37 <= ch1_rxpmadprioin_phy (rrx_sdlv_DP_RXPMA_IDX_3 DOWNTO rrxurstpma_DP_RXPMA_IDX_0);
ch2_in_chnl_ctrl_37 <= ch2_rxpmadprioin_phy (rrx_sdlv_DP_RXPMA_IDX_3 DOWNTO rrxurstpma_DP_RXPMA_IDX_0);
ch3_in_chnl_ctrl_37 <= ch3_rxpmadprioin_phy (rrx_sdlv_DP_RXPMA_IDX_3 DOWNTO rrxurstpma_DP_RXPMA_IDX_0);
ch4_in_chnl_ctrl_37 <= ch4_rxpmadprioin_phy (rrx_sdlv_DP_RXPMA_IDX_3 DOWNTO rrxurstpma_DP_RXPMA_IDX_0);
ch5_in_chnl_ctrl_37 <= ch5_rxpmadprioin_phy (rrx_sdlv_DP_RXPMA_IDX_3 DOWNTO rrxurstpma_DP_RXPMA_IDX_0);

ch0_in_chnl_ctrl_38 <= ch0_rxpmadprioin_phy (rrx_sd_on_DP_RXPMA_IDX_3 DOWNTO reserved_0_TB38_DP_RXPMA_IDX_0);
ch1_in_chnl_ctrl_38 <= ch1_rxpmadprioin_phy (rrx_sd_on_DP_RXPMA_IDX_3 DOWNTO reserved_0_TB38_DP_RXPMA_IDX_0);
ch2_in_chnl_ctrl_38 <= ch2_rxpmadprioin_phy (rrx_sd_on_DP_RXPMA_IDX_3 DOWNTO reserved_0_TB38_DP_RXPMA_IDX_0);
ch3_in_chnl_ctrl_38 <= ch3_rxpmadprioin_phy (rrx_sd_on_DP_RXPMA_IDX_3 DOWNTO reserved_0_TB38_DP_RXPMA_IDX_0);
ch4_in_chnl_ctrl_38 <= ch4_rxpmadprioin_phy (rrx_sd_on_DP_RXPMA_IDX_3 DOWNTO reserved_0_TB38_DP_RXPMA_IDX_0);
ch5_in_chnl_ctrl_38 <= ch5_rxpmadprioin_phy (rrx_sd_on_DP_RXPMA_IDX_3 DOWNTO reserved_0_TB38_DP_RXPMA_IDX_0);

ch0_in_chnl_ctrl_39 <= ch0_rxplldprioin_phy (rcru_div2_DP_PLL_IDX_0 DOWNTO rcru_pdbwctrl_DP_PLL_IDX_0);
ch1_in_chnl_ctrl_39 <= ch1_rxplldprioin_phy (rcru_div2_DP_PLL_IDX_0 DOWNTO rcru_pdbwctrl_DP_PLL_IDX_0);
ch2_in_chnl_ctrl_39 <= ch2_rxplldprioin_phy (rcru_div2_DP_PLL_IDX_0 DOWNTO rcru_pdbwctrl_DP_PLL_IDX_0);
ch3_in_chnl_ctrl_39 <= ch3_rxplldprioin_phy (rcru_div2_DP_PLL_IDX_0 DOWNTO rcru_pdbwctrl_DP_PLL_IDX_0);
ch4_in_chnl_ctrl_39 <= ch4_rxtxplldprioin_phy (rcru_div2_DP_PLL_IDX_0 DOWNTO rcru_pdbwctrl_DP_PLL_IDX_0);
ch5_in_chnl_ctrl_39 <= ch5_rxtxplldprioin_phy (rcru_div2_DP_PLL_IDX_0 DOWNTO rcru_pdbwctrl_DP_PLL_IDX_0);

-- some bit like bit[15] is from tx_pma - moved to Manual section
--ch0_in_chnl_ctrl_40 <= ch0_rxplldprioin_phy (rcru_rlbk_DP_PLL_IDX_0 DOWNTO reserved_0_TB40_DP_PLL_IDX_0);
--ch1_in_chnl_ctrl_40 <= ch1_rxplldprioin_phy (rcru_rlbk_DP_PLL_IDX_0 DOWNTO reserved_0_TB40_DP_PLL_IDX_0);
--ch2_in_chnl_ctrl_40 <= ch2_rxplldprioin_phy (rcru_rlbk_DP_PLL_IDX_0 DOWNTO reserved_0_TB40_DP_PLL_IDX_0);
--ch3_in_chnl_ctrl_40 <= ch3_rxplldprioin_phy (rcru_rlbk_DP_PLL_IDX_0 DOWNTO reserved_0_TB40_DP_PLL_IDX_0);
--ch4_in_chnl_ctrl_40 <= ch4_rxtxplldprioin_phy (rcru_rlbk_DP_PLL_IDX_0 DOWNTO reserved_0_TB40_DP_PLL_IDX_0);
--ch5_in_chnl_ctrl_40 <= ch5_rxtxplldprioin_phy (rcru_rlbk_DP_PLL_IDX_0 DOWNTO reserved_0_TB40_DP_PLL_IDX_0);

ch0_in_chnl_ctrl_41 <= ch0_rxplldprioin_phy (rcp_mode_DP_PLL_IDX_0 DOWNTO rcru_rgla_isel_DP_PLL_IDX_0);
ch1_in_chnl_ctrl_41 <= ch1_rxplldprioin_phy (rcp_mode_DP_PLL_IDX_0 DOWNTO rcru_rgla_isel_DP_PLL_IDX_0);
ch2_in_chnl_ctrl_41 <= ch2_rxplldprioin_phy (rcp_mode_DP_PLL_IDX_0 DOWNTO rcru_rgla_isel_DP_PLL_IDX_0);
ch3_in_chnl_ctrl_41 <= ch3_rxplldprioin_phy (rcp_mode_DP_PLL_IDX_0 DOWNTO rcru_rgla_isel_DP_PLL_IDX_0);
ch4_in_chnl_ctrl_41 <= ch4_rxtxplldprioin_phy (rcp_mode_DP_PLL_IDX_0 DOWNTO rcru_rgla_isel_DP_PLL_IDX_0);
ch5_in_chnl_ctrl_41 <= ch5_rxtxplldprioin_phy (rcp_mode_DP_PLL_IDX_0 DOWNTO rcru_rgla_isel_DP_PLL_IDX_0);

ch0_in_chnl_ctrl_42 <= ch0_rxplldprioin_phy (rcru_pdof_0i_DP_PLL_IDX_3 DOWNTO rcru_pdof_270i_DP_PLL_IDX_0);
ch1_in_chnl_ctrl_42 <= ch1_rxplldprioin_phy (rcru_pdof_0i_DP_PLL_IDX_3 DOWNTO rcru_pdof_270i_DP_PLL_IDX_0);
ch2_in_chnl_ctrl_42 <= ch2_rxplldprioin_phy (rcru_pdof_0i_DP_PLL_IDX_3 DOWNTO rcru_pdof_270i_DP_PLL_IDX_0);
ch3_in_chnl_ctrl_42 <= ch3_rxplldprioin_phy (rcru_pdof_0i_DP_PLL_IDX_3 DOWNTO rcru_pdof_270i_DP_PLL_IDX_0);
ch4_in_chnl_ctrl_42 <= ch4_rxtxplldprioin_phy (rcru_pdof_0i_DP_PLL_IDX_3 DOWNTO rcru_pdof_270i_DP_PLL_IDX_0);
ch5_in_chnl_ctrl_42 <= ch5_rxtxplldprioin_phy (rcru_pdof_0i_DP_PLL_IDX_3 DOWNTO rcru_pdof_270i_DP_PLL_IDX_0);

-- reserved
ch0_in_chnl_ctrl_43 <= ch0_rxpmadprioin_phy (reserved_0_TB43_DP_RXPMA_IDX_7 DOWNTO reye_monitor_DP_RXPMA_IDX_0);
ch1_in_chnl_ctrl_43 <= ch1_rxpmadprioin_phy (reserved_0_TB43_DP_RXPMA_IDX_7 DOWNTO reye_monitor_DP_RXPMA_IDX_0);
ch2_in_chnl_ctrl_43 <= ch2_rxpmadprioin_phy (reserved_0_TB43_DP_RXPMA_IDX_7 DOWNTO reye_monitor_DP_RXPMA_IDX_0);
ch3_in_chnl_ctrl_43 <= ch3_rxpmadprioin_phy (reserved_0_TB43_DP_RXPMA_IDX_7 DOWNTO reye_monitor_DP_RXPMA_IDX_0);
ch4_in_chnl_ctrl_43 <= ch4_rxpmadprioin_phy (reserved_0_TB43_DP_RXPMA_IDX_7 DOWNTO reye_monitor_DP_RXPMA_IDX_0);
ch5_in_chnl_ctrl_43 <= ch5_rxpmadprioin_phy (reserved_0_TB43_DP_RXPMA_IDX_7 DOWNTO reye_monitor_DP_RXPMA_IDX_0);

ch0_in_chnl_ctrl_44 <= ch0_rxpmadprioin_phy (rpma_reserved_0_TB44_DP_RXPMA_IDX_15 DOWNTO rpma_reserved_0_TB44_DP_RXPMA_IDX_0);
ch1_in_chnl_ctrl_44 <= ch1_rxpmadprioin_phy (rpma_reserved_0_TB44_DP_RXPMA_IDX_15 DOWNTO rpma_reserved_0_TB44_DP_RXPMA_IDX_0);
ch2_in_chnl_ctrl_44 <= ch2_rxpmadprioin_phy (rpma_reserved_0_TB44_DP_RXPMA_IDX_15 DOWNTO rpma_reserved_0_TB44_DP_RXPMA_IDX_0);
ch3_in_chnl_ctrl_44 <= ch3_rxpmadprioin_phy (rpma_reserved_0_TB44_DP_RXPMA_IDX_15 DOWNTO rpma_reserved_0_TB44_DP_RXPMA_IDX_0);
ch4_in_chnl_ctrl_44 <= ch4_rxpmadprioin_phy (rpma_reserved_0_TB44_DP_RXPMA_IDX_15 DOWNTO rpma_reserved_0_TB44_DP_RXPMA_IDX_0);
ch5_in_chnl_ctrl_44 <= ch5_rxpmadprioin_phy (rpma_reserved_0_TB44_DP_RXPMA_IDX_15 DOWNTO rpma_reserved_0_TB44_DP_RXPMA_IDX_0);

ch0_in_chnl_ctrl_45 <= ch0_rxpmadprioin_phy (rpma_doublewidth_rx_DP_RXPMA_IDX_0 DOWNTO rppm_cnt_reset_DP_RXPMA_IDX_0);
ch1_in_chnl_ctrl_45 <= ch1_rxpmadprioin_phy (rpma_doublewidth_rx_DP_RXPMA_IDX_0 DOWNTO rppm_cnt_reset_DP_RXPMA_IDX_0);
ch2_in_chnl_ctrl_45 <= ch2_rxpmadprioin_phy (rpma_doublewidth_rx_DP_RXPMA_IDX_0 DOWNTO rppm_cnt_reset_DP_RXPMA_IDX_0);
ch3_in_chnl_ctrl_45 <= ch3_rxpmadprioin_phy (rpma_doublewidth_rx_DP_RXPMA_IDX_0 DOWNTO rppm_cnt_reset_DP_RXPMA_IDX_0);
ch4_in_chnl_ctrl_45 <= ch4_rxpmadprioin_phy (rpma_doublewidth_rx_DP_RXPMA_IDX_0 DOWNTO rppm_cnt_reset_DP_RXPMA_IDX_0);
ch5_in_chnl_ctrl_45 <= ch5_rxpmadprioin_phy (rpma_doublewidth_rx_DP_RXPMA_IDX_0 DOWNTO rppm_cnt_reset_DP_RXPMA_IDX_0);

ch0_in_chnl_ctrl_46 <= ch0_rxpmadprioin_phy (r_dfe_1t_DP_RXPMA_IDX_2 DOWNTO reserved_0_TB46_DP_RXPMA_IDX_0);
ch1_in_chnl_ctrl_46 <= ch1_rxpmadprioin_phy (r_dfe_1t_DP_RXPMA_IDX_2 DOWNTO reserved_0_TB46_DP_RXPMA_IDX_0);
ch2_in_chnl_ctrl_46 <= ch2_rxpmadprioin_phy (r_dfe_1t_DP_RXPMA_IDX_2 DOWNTO reserved_0_TB46_DP_RXPMA_IDX_0);
ch3_in_chnl_ctrl_46 <= ch3_rxpmadprioin_phy (r_dfe_1t_DP_RXPMA_IDX_2 DOWNTO reserved_0_TB46_DP_RXPMA_IDX_0);
ch4_in_chnl_ctrl_46 <= ch4_rxpmadprioin_phy (r_dfe_1t_DP_RXPMA_IDX_2 DOWNTO reserved_0_TB46_DP_RXPMA_IDX_0);
ch5_in_chnl_ctrl_46 <= ch5_rxpmadprioin_phy (r_dfe_1t_DP_RXPMA_IDX_2 DOWNTO reserved_0_TB46_DP_RXPMA_IDX_0);

ch0_in_chnl_ctrl_47 <= ch0_rxpmadprioin_phy (reserved_0_TB47_DP_RXPMA_IDX_0 DOWNTO reqv_set_DP_RXPMA_IDX_0);
ch1_in_chnl_ctrl_47 <= ch1_rxpmadprioin_phy (reserved_0_TB47_DP_RXPMA_IDX_0 DOWNTO reqv_set_DP_RXPMA_IDX_0);
ch2_in_chnl_ctrl_47 <= ch2_rxpmadprioin_phy (reserved_0_TB47_DP_RXPMA_IDX_0 DOWNTO reqv_set_DP_RXPMA_IDX_0);
ch3_in_chnl_ctrl_47 <= ch3_rxpmadprioin_phy (reserved_0_TB47_DP_RXPMA_IDX_0 DOWNTO reqv_set_DP_RXPMA_IDX_0);
ch4_in_chnl_ctrl_47 <= ch4_rxpmadprioin_phy (reserved_0_TB47_DP_RXPMA_IDX_0 DOWNTO reqv_set_DP_RXPMA_IDX_0);
ch5_in_chnl_ctrl_47 <= ch5_rxpmadprioin_phy (reserved_0_TB47_DP_RXPMA_IDX_0 DOWNTO reqv_set_DP_RXPMA_IDX_0);

ch0_in_chnl_ctrl_48 <= ch0_rxpmadprioin_phy (rlock_lf_ovd_DP_RXPMA_IDX_0 DOWNTO rdc_freq_DP_RXPMA_IDX_0);
ch1_in_chnl_ctrl_48 <= ch1_rxpmadprioin_phy (rlock_lf_ovd_DP_RXPMA_IDX_0 DOWNTO rdc_freq_DP_RXPMA_IDX_0);
ch2_in_chnl_ctrl_48 <= ch2_rxpmadprioin_phy (rlock_lf_ovd_DP_RXPMA_IDX_0 DOWNTO rdc_freq_DP_RXPMA_IDX_0);
ch3_in_chnl_ctrl_48 <= ch3_rxpmadprioin_phy (rlock_lf_ovd_DP_RXPMA_IDX_0 DOWNTO rdc_freq_DP_RXPMA_IDX_0);
--ch4_in_chnl_ctrl_48 <= ch4_rxpmadprioin_phy (rlock_lf_ovd_DP_RXPMA_IDX_0 DOWNTO rdc_freq_DP_RXPMA_IDX_0); not exist on cmu0/1
--ch5_in_chnl_ctrl_48 <= ch5_rxpmadprioin_phy (rlock_lf_ovd_DP_RXPMA_IDX_0 DOWNTO rdc_freq_DP_RXPMA_IDX_0);

ch0_in_chnl_ctrl_49 <= ch0_rxpmadprioin_phy (rhyst_hf_DP_RXPMA_IDX_2 DOWNTO rrgen_vod_DP_RXPMA_IDX_0);
ch1_in_chnl_ctrl_49 <= ch1_rxpmadprioin_phy (rhyst_hf_DP_RXPMA_IDX_2 DOWNTO rrgen_vod_DP_RXPMA_IDX_0);
ch2_in_chnl_ctrl_49 <= ch2_rxpmadprioin_phy (rhyst_hf_DP_RXPMA_IDX_2 DOWNTO rrgen_vod_DP_RXPMA_IDX_0);
ch3_in_chnl_ctrl_49 <= ch3_rxpmadprioin_phy (rhyst_hf_DP_RXPMA_IDX_2 DOWNTO rrgen_vod_DP_RXPMA_IDX_0);
--ch4_in_chnl_ctrl_49 <= ch4_rxpmadprioin_phy (rhyst_hf_DP_RXPMA_IDX_2 DOWNTO rrgen_vod_DP_RXPMA_IDX_0);
--ch5_in_chnl_ctrl_49 <= ch5_rxpmadprioin_phy (rhyst_hf_DP_RXPMA_IDX_2 DOWNTO rrgen_vod_DP_RXPMA_IDX_0);

ch0_in_chnl_ctrl_50 <= ch0_rxpmadprioin_phy (rrgen_bw_DP_RXPMA_IDX_1 DOWNTO radce_pdb_DP_RXPMA_IDX_0);
ch1_in_chnl_ctrl_50 <= ch1_rxpmadprioin_phy (rrgen_bw_DP_RXPMA_IDX_1 DOWNTO radce_pdb_DP_RXPMA_IDX_0);
ch2_in_chnl_ctrl_50 <= ch2_rxpmadprioin_phy (rrgen_bw_DP_RXPMA_IDX_1 DOWNTO radce_pdb_DP_RXPMA_IDX_0);
ch3_in_chnl_ctrl_50 <= ch3_rxpmadprioin_phy (rrgen_bw_DP_RXPMA_IDX_1 DOWNTO radce_pdb_DP_RXPMA_IDX_0);
--ch4_in_chnl_ctrl_50 <= ch4_rxpmadprioin_phy (rrgen_bw_DP_RXPMA_IDX_1 DOWNTO radce_pdb_DP_RXPMA_IDX_0);
--ch5_in_chnl_ctrl_50 <= ch5_rxpmadprioin_phy (rrgen_bw_DP_RXPMA_IDX_1 DOWNTO radce_pdb_DP_RXPMA_IDX_0);

ch0_in_chnl_ctrl_51 <= ch0_rxpmadprioin_phy (reserved_0_TB51_DP_RXPMA_IDX_0 DOWNTO radce_hflck_DP_RXPMA_IDX_0);
ch1_in_chnl_ctrl_51 <= ch1_rxpmadprioin_phy (reserved_0_TB51_DP_RXPMA_IDX_0 DOWNTO radce_hflck_DP_RXPMA_IDX_0);
ch2_in_chnl_ctrl_51 <= ch2_rxpmadprioin_phy (reserved_0_TB51_DP_RXPMA_IDX_0 DOWNTO radce_hflck_DP_RXPMA_IDX_0);
ch3_in_chnl_ctrl_51 <= ch3_rxpmadprioin_phy (reserved_0_TB51_DP_RXPMA_IDX_0 DOWNTO radce_hflck_DP_RXPMA_IDX_0);
--ch4_in_chnl_ctrl_51 <= ch4_rxpmadprioin_phy (reserved_0_TB51_DP_RXPMA_IDX_0 DOWNTO radce_hflck_DP_RXPMA_IDX_0);
--ch5_in_chnl_ctrl_51 <= ch5_rxpmadprioin_phy (reserved_0_TB51_DP_RXPMA_IDX_0 DOWNTO radce_hflck_DP_RXPMA_IDX_0);

ch0_in_chnl_ctrl_52 <= ch0_rxpmadprioin_phy (reserved_0_TB52_DP_RXPMA_IDX_0 DOWNTO radce_lflck_DP_RXPMA_IDX_0);
ch1_in_chnl_ctrl_52 <= ch1_rxpmadprioin_phy (reserved_0_TB52_DP_RXPMA_IDX_0 DOWNTO radce_lflck_DP_RXPMA_IDX_0);
ch2_in_chnl_ctrl_52 <= ch2_rxpmadprioin_phy (reserved_0_TB52_DP_RXPMA_IDX_0 DOWNTO radce_lflck_DP_RXPMA_IDX_0);
ch3_in_chnl_ctrl_52 <= ch3_rxpmadprioin_phy (reserved_0_TB52_DP_RXPMA_IDX_0 DOWNTO radce_lflck_DP_RXPMA_IDX_0);
--ch4_in_chnl_ctrl_52 <= ch4_rxpmadprioin_phy (reserved_0_TB52_DP_RXPMA_IDX_0 DOWNTO radce_lflck_DP_RXPMA_IDX_0);
--ch5_in_chnl_ctrl_52 <= ch5_rxpmadprioin_phy (reserved_0_TB52_DP_RXPMA_IDX_0 DOWNTO radce_lflck_DP_RXPMA_IDX_0);

ch0_in_chnl_ctrl_53 <= ch0_rxpmadprioin_phy (reserved_0_TB53_DP_RXPMA_IDX_5 DOWNTO radce_digital_DP_RXPMA_IDX_0);
ch1_in_chnl_ctrl_53 <= ch1_rxpmadprioin_phy (reserved_0_TB53_DP_RXPMA_IDX_5 DOWNTO radce_digital_DP_RXPMA_IDX_0);
ch2_in_chnl_ctrl_53 <= ch2_rxpmadprioin_phy (reserved_0_TB53_DP_RXPMA_IDX_5 DOWNTO radce_digital_DP_RXPMA_IDX_0);
ch3_in_chnl_ctrl_53 <= ch3_rxpmadprioin_phy (reserved_0_TB53_DP_RXPMA_IDX_5 DOWNTO radce_digital_DP_RXPMA_IDX_0);
--ch4_in_chnl_ctrl_53 <= ch4_rxpmadprioin_phy (reserved_0_TB53_DP_RXPMA_IDX_5 DOWNTO radce_digital_DP_RXPMA_IDX_0);
--ch5_in_chnl_ctrl_53 <= ch5_rxpmadprioin_phy (reserved_0_TB53_DP_RXPMA_IDX_5 DOWNTO radce_digital_DP_RXPMA_IDX_0);

-- -------- HW ordering  ------------------------------------
--TXPCS
ch0_csr_chnl_in(15 DOWNTO 0) <= ch0_in_chnl_ctrl_1;
ch1_csr_chnl_in(15 DOWNTO 0) <= ch1_in_chnl_ctrl_1;
ch2_csr_chnl_in(15 DOWNTO 0) <= ch2_in_chnl_ctrl_1;
ch3_csr_chnl_in(15 DOWNTO 0) <= ch3_in_chnl_ctrl_1;

ch0_csr_chnl_in(31 DOWNTO 16) <= ch0_in_chnl_ctrl_2;
ch1_csr_chnl_in(31 DOWNTO 16) <= ch1_in_chnl_ctrl_2;
ch2_csr_chnl_in(31 DOWNTO 16) <= ch2_in_chnl_ctrl_2;
ch3_csr_chnl_in(31 DOWNTO 16) <= ch3_in_chnl_ctrl_2;

ch0_csr_chnl_in(47 DOWNTO 32) <= ch0_in_chnl_ctrl_3;
ch1_csr_chnl_in(47 DOWNTO 32) <= ch1_in_chnl_ctrl_3;
ch2_csr_chnl_in(47 DOWNTO 32) <= ch2_in_chnl_ctrl_3;
ch3_csr_chnl_in(47 DOWNTO 32) <= ch3_in_chnl_ctrl_3;

ch0_csr_chnl_in(63 DOWNTO 48) <= ch0_in_chnl_ctrl_4;
ch1_csr_chnl_in(63 DOWNTO 48) <= ch1_in_chnl_ctrl_4;
ch2_csr_chnl_in(63 DOWNTO 48) <= ch2_in_chnl_ctrl_4;
ch3_csr_chnl_in(63 DOWNTO 48) <= ch3_in_chnl_ctrl_4;

ch0_csr_chnl_in(79 DOWNTO 64) <= ch0_in_chnl_ctrl_5;
ch1_csr_chnl_in(79 DOWNTO 64) <= ch1_in_chnl_ctrl_5;
ch2_csr_chnl_in(79 DOWNTO 64) <= ch2_in_chnl_ctrl_5;
ch3_csr_chnl_in(79 DOWNTO 64) <= ch3_in_chnl_ctrl_5;

ch0_csr_chnl_in(95 DOWNTO 80) <= ch0_in_chnl_ctrl_6;
ch1_csr_chnl_in(95 DOWNTO 80) <= ch1_in_chnl_ctrl_6;
ch2_csr_chnl_in(95 DOWNTO 80) <= ch2_in_chnl_ctrl_6;
ch3_csr_chnl_in(95 DOWNTO 80) <= ch3_in_chnl_ctrl_6;

ch0_csr_chnl_in(111 DOWNTO 96) <= ch0_in_chnl_ctrl_7;
ch1_csr_chnl_in(111 DOWNTO 96) <= ch1_in_chnl_ctrl_7;
ch2_csr_chnl_in(111 DOWNTO 96) <= ch2_in_chnl_ctrl_7;
ch3_csr_chnl_in(111 DOWNTO 96) <= ch3_in_chnl_ctrl_7;

ch0_csr_chnl_in(127 DOWNTO 112) <= ch0_in_chnl_ctrl_8;
ch1_csr_chnl_in(127 DOWNTO 112) <= ch1_in_chnl_ctrl_8;
ch2_csr_chnl_in(127 DOWNTO 112) <= ch2_in_chnl_ctrl_8;
ch3_csr_chnl_in(127 DOWNTO 112) <= ch3_in_chnl_ctrl_8;

ch0_csr_chnl_in(143 DOWNTO 128) <= ch0_in_chnl_ctrl_9;
ch1_csr_chnl_in(143 DOWNTO 128) <= ch1_in_chnl_ctrl_9;
ch2_csr_chnl_in(143 DOWNTO 128) <= ch2_in_chnl_ctrl_9;
ch3_csr_chnl_in(143 DOWNTO 128) <= ch3_in_chnl_ctrl_9;

ch0_csr_chnl_in(159 DOWNTO 144) <= ch0_in_chnl_ctrl_10;
ch1_csr_chnl_in(159 DOWNTO 144) <= ch1_in_chnl_ctrl_10;
ch2_csr_chnl_in(159 DOWNTO 144) <= ch2_in_chnl_ctrl_10;
ch3_csr_chnl_in(159 DOWNTO 144) <= ch3_in_chnl_ctrl_10;

ch0_csr_chnl_in(175 DOWNTO 160) <= ch0_in_chnl_ctrl_11;
ch1_csr_chnl_in(175 DOWNTO 160) <= ch1_in_chnl_ctrl_11;
ch2_csr_chnl_in(175 DOWNTO 160) <= ch2_in_chnl_ctrl_11;
ch3_csr_chnl_in(175 DOWNTO 160) <= ch3_in_chnl_ctrl_11;

ch0_csr_chnl_in(191 DOWNTO 176) <= ch0_in_chnl_ctrl_12;
ch1_csr_chnl_in(191 DOWNTO 176) <= ch1_in_chnl_ctrl_12;
ch2_csr_chnl_in(191 DOWNTO 176) <= ch2_in_chnl_ctrl_12;
ch3_csr_chnl_in(191 DOWNTO 176) <= ch3_in_chnl_ctrl_12;

ch0_csr_chnl_in(207 DOWNTO 192) <= ch0_in_chnl_ctrl_13;
ch1_csr_chnl_in(207 DOWNTO 192) <= ch1_in_chnl_ctrl_13;
ch2_csr_chnl_in(207 DOWNTO 192) <= ch2_in_chnl_ctrl_13;
ch3_csr_chnl_in(207 DOWNTO 192) <= ch3_in_chnl_ctrl_13;

ch0_csr_chnl_in(223 DOWNTO 208) <= ch0_in_chnl_ctrl_14;
ch1_csr_chnl_in(223 DOWNTO 208) <= ch1_in_chnl_ctrl_14;
ch2_csr_chnl_in(223 DOWNTO 208) <= ch2_in_chnl_ctrl_14;
ch3_csr_chnl_in(223 DOWNTO 208) <= ch3_in_chnl_ctrl_14;

ch0_csr_chnl_in(239 DOWNTO 224) <= ch0_in_chnl_ctrl_15;
ch1_csr_chnl_in(239 DOWNTO 224) <= ch1_in_chnl_ctrl_15;
ch2_csr_chnl_in(239 DOWNTO 224) <= ch2_in_chnl_ctrl_15;
ch3_csr_chnl_in(239 DOWNTO 224) <= ch3_in_chnl_ctrl_15;

ch0_csr_chnl_in(255 DOWNTO 240) <= ch0_in_chnl_ctrl_16;
ch1_csr_chnl_in(255 DOWNTO 240) <= ch1_in_chnl_ctrl_16;
ch2_csr_chnl_in(255 DOWNTO 240) <= ch2_in_chnl_ctrl_16;
ch3_csr_chnl_in(255 DOWNTO 240) <= ch3_in_chnl_ctrl_16;

ch0_csr_chnl_in(271 DOWNTO 256) <= ch0_in_chnl_ctrl_17;
ch1_csr_chnl_in(271 DOWNTO 256) <= ch1_in_chnl_ctrl_17;
ch2_csr_chnl_in(271 DOWNTO 256) <= ch2_in_chnl_ctrl_17;
ch3_csr_chnl_in(271 DOWNTO 256) <= ch3_in_chnl_ctrl_17;

ch0_csr_chnl_in(287 DOWNTO 272) <= ch0_in_chnl_ctrl_18;
ch1_csr_chnl_in(287 DOWNTO 272) <= ch1_in_chnl_ctrl_18;
ch2_csr_chnl_in(287 DOWNTO 272) <= ch2_in_chnl_ctrl_18;
ch3_csr_chnl_in(287 DOWNTO 272) <= ch3_in_chnl_ctrl_18;

ch0_csr_chnl_in(303 DOWNTO 288) <= ch0_in_chnl_ctrl_19;
ch1_csr_chnl_in(303 DOWNTO 288) <= ch1_in_chnl_ctrl_19;
ch2_csr_chnl_in(303 DOWNTO 288) <= ch2_in_chnl_ctrl_19;
ch3_csr_chnl_in(303 DOWNTO 288) <= ch3_in_chnl_ctrl_19;

ch0_csr_chnl_in(319 DOWNTO 304) <= ch0_in_chnl_ctrl_20;
ch1_csr_chnl_in(319 DOWNTO 304) <= ch1_in_chnl_ctrl_20;
ch2_csr_chnl_in(319 DOWNTO 304) <= ch2_in_chnl_ctrl_20;
ch3_csr_chnl_in(319 DOWNTO 304) <= ch3_in_chnl_ctrl_20;

ch0_csr_chnl_in(335 DOWNTO 320) <= ch0_in_chnl_ctrl_21;
ch1_csr_chnl_in(335 DOWNTO 320) <= ch1_in_chnl_ctrl_21;
ch2_csr_chnl_in(335 DOWNTO 320) <= ch2_in_chnl_ctrl_21;
ch3_csr_chnl_in(335 DOWNTO 320) <= ch3_in_chnl_ctrl_21;

ch0_csr_chnl_in(351 DOWNTO 336) <= ch0_in_chnl_ctrl_22;
ch1_csr_chnl_in(351 DOWNTO 336) <= ch1_in_chnl_ctrl_22;
ch2_csr_chnl_in(351 DOWNTO 336) <= ch2_in_chnl_ctrl_22;
ch3_csr_chnl_in(351 DOWNTO 336) <= ch3_in_chnl_ctrl_22;

ch0_csr_chnl_in(367 DOWNTO 352) <= ch0_in_chnl_ctrl_23;
ch1_csr_chnl_in(367 DOWNTO 352) <= ch1_in_chnl_ctrl_23;
ch2_csr_chnl_in(367 DOWNTO 352) <= ch2_in_chnl_ctrl_23;
ch3_csr_chnl_in(367 DOWNTO 352) <= ch3_in_chnl_ctrl_23;

ch0_csr_chnl_in(383 DOWNTO 368) <= ch0_in_chnl_ctrl_24;
ch1_csr_chnl_in(383 DOWNTO 368) <= ch1_in_chnl_ctrl_24;
ch2_csr_chnl_in(383 DOWNTO 368) <= ch2_in_chnl_ctrl_24;
ch3_csr_chnl_in(383 DOWNTO 368) <= ch3_in_chnl_ctrl_24;

ch0_csr_chnl_in(399 DOWNTO 384) <= ch0_in_chnl_ctrl_25;
ch1_csr_chnl_in(399 DOWNTO 384) <= ch1_in_chnl_ctrl_25;
ch2_csr_chnl_in(399 DOWNTO 384) <= ch2_in_chnl_ctrl_25;
ch3_csr_chnl_in(399 DOWNTO 384) <= ch3_in_chnl_ctrl_25;

ch0_csr_chnl_in(415 DOWNTO 400) <= ch0_in_chnl_ctrl_26;
ch1_csr_chnl_in(415 DOWNTO 400) <= ch1_in_chnl_ctrl_26;
ch2_csr_chnl_in(415 DOWNTO 400) <= ch2_in_chnl_ctrl_26;
ch3_csr_chnl_in(415 DOWNTO 400) <= ch3_in_chnl_ctrl_26;

ch0_csr_chnl_in(431 DOWNTO 416) <= ch0_in_chnl_ctrl_27;
ch1_csr_chnl_in(431 DOWNTO 416) <= ch1_in_chnl_ctrl_27;
ch2_csr_chnl_in(431 DOWNTO 416) <= ch2_in_chnl_ctrl_27;
ch3_csr_chnl_in(431 DOWNTO 416) <= ch3_in_chnl_ctrl_27;

--TXPMA
ch0_csr_chnl_in(447 DOWNTO 432) <= ch0_in_chnl_ctrl_28;
ch1_csr_chnl_in(447 DOWNTO 432) <= ch1_in_chnl_ctrl_28;
ch2_csr_chnl_in(447 DOWNTO 432) <= ch2_in_chnl_ctrl_28;
ch3_csr_chnl_in(447 DOWNTO 432) <= ch3_in_chnl_ctrl_28;
--ch4_csr_chnl_in(447 DOWNTO 432) <= ch4_in_chnl_ctrl_28; HW is cmu0_csr_in
--ch5_csr_chnl_in(447 DOWNTO 432) <= ch5_in_chnl_ctrl_28; CMU index 0 - 20

ch0_csr_chnl_in(463 DOWNTO 448) <= ch0_in_chnl_ctrl_29;
ch1_csr_chnl_in(463 DOWNTO 448) <= ch1_in_chnl_ctrl_29;
ch2_csr_chnl_in(463 DOWNTO 448) <= ch2_in_chnl_ctrl_29;
ch3_csr_chnl_in(463 DOWNTO 448) <= ch3_in_chnl_ctrl_29;
--ch4_csr_chnl_in(463 DOWNTO 448) <= ch4_in_chnl_ctrl_29;
--ch5_csr_chnl_in(463 DOWNTO 448) <= ch5_in_chnl_ctrl_29;

ch0_csr_chnl_in(479 DOWNTO 464) <= ch0_in_chnl_ctrl_30;
ch1_csr_chnl_in(479 DOWNTO 464) <= ch1_in_chnl_ctrl_30;
ch2_csr_chnl_in(479 DOWNTO 464) <= ch2_in_chnl_ctrl_30;
ch3_csr_chnl_in(479 DOWNTO 464) <= ch3_in_chnl_ctrl_30;
--ch4_csr_chnl_in(479 DOWNTO 464) <= ch4_in_chnl_ctrl_30;
--ch5_csr_chnl_in(479 DOWNTO 464) <= ch5_in_chnl_ctrl_30;

ch0_csr_chnl_in(495 DOWNTO 480) <= ch0_in_chnl_ctrl_31;
ch1_csr_chnl_in(495 DOWNTO 480) <= ch1_in_chnl_ctrl_31;
ch2_csr_chnl_in(495 DOWNTO 480) <= ch2_in_chnl_ctrl_31;
ch3_csr_chnl_in(495 DOWNTO 480) <= ch3_in_chnl_ctrl_31;
--ch4_csr_chnl_in(495 DOWNTO 480) <= ch4_in_chnl_ctrl_31;
--ch5_csr_chnl_in(495 DOWNTO 480) <= ch5_in_chnl_ctrl_31;

ch0_csr_chnl_in(511 DOWNTO 496) <= ch0_in_chnl_ctrl_32;
ch1_csr_chnl_in(511 DOWNTO 496) <= ch1_in_chnl_ctrl_32;
ch2_csr_chnl_in(511 DOWNTO 496) <= ch2_in_chnl_ctrl_32;
ch3_csr_chnl_in(511 DOWNTO 496) <= ch3_in_chnl_ctrl_32;
--ch4_csr_chnl_in(511 DOWNTO 496) <= ch4_in_chnl_ctrl_32;
--ch5_csr_chnl_in(511 DOWNTO 496) <= ch5_in_chnl_ctrl_32;

ch0_csr_chnl_in(527 DOWNTO 512) <= ch0_in_chnl_ctrl_33;
ch1_csr_chnl_in(527 DOWNTO 512) <= ch1_in_chnl_ctrl_33;
ch2_csr_chnl_in(527 DOWNTO 512) <= ch2_in_chnl_ctrl_33;
ch3_csr_chnl_in(527 DOWNTO 512) <= ch3_in_chnl_ctrl_33;
--ch4_csr_chnl_in(527 DOWNTO 512) <= ch4_in_chnl_ctrl_33;
--ch5_csr_chnl_in(527 DOWNTO 512) <= ch5_in_chnl_ctrl_33;

ch0_csr_chnl_in(543 DOWNTO 528) <= ch0_in_chnl_ctrl_34;
ch1_csr_chnl_in(543 DOWNTO 528) <= ch1_in_chnl_ctrl_34;
ch2_csr_chnl_in(543 DOWNTO 528) <= ch2_in_chnl_ctrl_34;
ch3_csr_chnl_in(543 DOWNTO 528) <= ch3_in_chnl_ctrl_34;
--ch4_csr_chnl_in(543 DOWNTO 528) <= ch4_in_chnl_ctrl_34;
--ch5_csr_chnl_in(543 DOWNTO 528) <= ch5_in_chnl_ctrl_34;

ch0_csr_chnl_in(559 DOWNTO 544) <= ch0_in_chnl_ctrl_35;
ch1_csr_chnl_in(559 DOWNTO 544) <= ch1_in_chnl_ctrl_35;
ch2_csr_chnl_in(559 DOWNTO 544) <= ch2_in_chnl_ctrl_35;
ch3_csr_chnl_in(559 DOWNTO 544) <= ch3_in_chnl_ctrl_35;
--ch4_csr_chnl_in(559 DOWNTO 544) <= ch4_in_chnl_ctrl_35;
--ch5_csr_chnl_in(559 DOWNTO 544) <= ch5_in_chnl_ctrl_35;

ch0_csr_chnl_in(575 DOWNTO 560) <= ch0_in_chnl_ctrl_36;
ch1_csr_chnl_in(575 DOWNTO 560) <= ch1_in_chnl_ctrl_36;
ch2_csr_chnl_in(575 DOWNTO 560) <= ch2_in_chnl_ctrl_36;
ch3_csr_chnl_in(575 DOWNTO 560) <= ch3_in_chnl_ctrl_36;
--ch4_csr_chnl_in(575 DOWNTO 560) <= ch4_in_chnl_ctrl_36;
--ch5_csr_chnl_in(575 DOWNTO 560) <= ch5_in_chnl_ctrl_36;

ch0_csr_chnl_in(591 DOWNTO 576) <= ch0_in_chnl_ctrl_37;
ch1_csr_chnl_in(591 DOWNTO 576) <= ch1_in_chnl_ctrl_37;
ch2_csr_chnl_in(591 DOWNTO 576) <= ch2_in_chnl_ctrl_37;
ch3_csr_chnl_in(591 DOWNTO 576) <= ch3_in_chnl_ctrl_37;
--ch4_csr_chnl_in(591 DOWNTO 576) <= ch4_in_chnl_ctrl_37;
--ch5_csr_chnl_in(591 DOWNTO 576) <= ch5_in_chnl_ctrl_37;

ch0_csr_chnl_in(607 DOWNTO 592) <= ch0_in_chnl_ctrl_38;
ch1_csr_chnl_in(607 DOWNTO 592) <= ch1_in_chnl_ctrl_38;
ch2_csr_chnl_in(607 DOWNTO 592) <= ch2_in_chnl_ctrl_38;
ch3_csr_chnl_in(607 DOWNTO 592) <= ch3_in_chnl_ctrl_38;
--ch4_csr_chnl_in(607 DOWNTO 592) <= ch4_in_chnl_ctrl_38;
--ch5_csr_chnl_in(607 DOWNTO 592) <= ch5_in_chnl_ctrl_38;

ch0_csr_chnl_in(623 DOWNTO 608) <= ch0_in_chnl_ctrl_39;
ch1_csr_chnl_in(623 DOWNTO 608) <= ch1_in_chnl_ctrl_39;
ch2_csr_chnl_in(623 DOWNTO 608) <= ch2_in_chnl_ctrl_39;
ch3_csr_chnl_in(623 DOWNTO 608) <= ch3_in_chnl_ctrl_39;
--ch4_csr_chnl_in(623 DOWNTO 608) <= ch4_in_chnl_ctrl_39;
--ch5_csr_chnl_in(623 DOWNTO 608) <= ch5_in_chnl_ctrl_39;

ch0_csr_chnl_in(639 DOWNTO 624) <= ch0_in_chnl_ctrl_40;
ch1_csr_chnl_in(639 DOWNTO 624) <= ch1_in_chnl_ctrl_40;
ch2_csr_chnl_in(639 DOWNTO 624) <= ch2_in_chnl_ctrl_40;
ch3_csr_chnl_in(639 DOWNTO 624) <= ch3_in_chnl_ctrl_40;
--ch4_csr_chnl_in(639 DOWNTO 624) <= ch4_in_chnl_ctrl_40;
--ch5_csr_chnl_in(639 DOWNTO 624) <= ch5_in_chnl_ctrl_40;

ch0_csr_chnl_in(655 DOWNTO 640) <= ch0_in_chnl_ctrl_41;
ch1_csr_chnl_in(655 DOWNTO 640) <= ch1_in_chnl_ctrl_41;
ch2_csr_chnl_in(655 DOWNTO 640) <= ch2_in_chnl_ctrl_41;
ch3_csr_chnl_in(655 DOWNTO 640) <= ch3_in_chnl_ctrl_41;
--ch4_csr_chnl_in(655 DOWNTO 640) <= ch4_in_chnl_ctrl_41;
--ch5_csr_chnl_in(655 DOWNTO 640) <= ch5_in_chnl_ctrl_41;

ch0_csr_chnl_in(671 DOWNTO 656) <= ch0_in_chnl_ctrl_42;
ch1_csr_chnl_in(671 DOWNTO 656) <= ch1_in_chnl_ctrl_42;
ch2_csr_chnl_in(671 DOWNTO 656) <= ch2_in_chnl_ctrl_42;
ch3_csr_chnl_in(671 DOWNTO 656) <= ch3_in_chnl_ctrl_42;
--ch4_csr_chnl_in(671 DOWNTO 656) <= ch4_in_chnl_ctrl_42;
--ch5_csr_chnl_in(671 DOWNTO 656) <= ch5_in_chnl_ctrl_42;

ch0_csr_chnl_in_reserved(15 DOWNTO 0) <= ch0_in_chnl_ctrl_43;
ch1_csr_chnl_in_reserved(15 DOWNTO 0) <= ch1_in_chnl_ctrl_43;
ch2_csr_chnl_in_reserved(15 DOWNTO 0) <= ch2_in_chnl_ctrl_43;
ch3_csr_chnl_in_reserved(15 DOWNTO 0) <= ch3_in_chnl_ctrl_43;
--ch4_csr_chnl_in(15 DOWNTO 0) <= ch4_in_chnl_ctrl_43;
--ch5_csr_chnl_in(15 DOWNTO 0) <= ch5_in_chnl_ctrl_43;

ch0_csr_chnl_in(687 DOWNTO 672) <= ch0_in_chnl_ctrl_44;
ch1_csr_chnl_in(687 DOWNTO 672) <= ch1_in_chnl_ctrl_44;
ch2_csr_chnl_in(687 DOWNTO 672) <= ch2_in_chnl_ctrl_44;
ch3_csr_chnl_in(687 DOWNTO 672) <= ch3_in_chnl_ctrl_44;
--ch4_csr_chnl_in(687 DOWNTO 672) <= ch4_in_chnl_ctrl_44;
--ch5_csr_chnl_in(687 DOWNTO 672) <= ch5_in_chnl_ctrl_44;

ch0_csr_chnl_in(703 DOWNTO 688) <= ch0_in_chnl_ctrl_45;
ch1_csr_chnl_in(703 DOWNTO 688) <= ch1_in_chnl_ctrl_45;
ch2_csr_chnl_in(703 DOWNTO 688) <= ch2_in_chnl_ctrl_45;
ch3_csr_chnl_in(703 DOWNTO 688) <= ch3_in_chnl_ctrl_45;
--ch4_csr_chnl_in(703 DOWNTO 688) <= ch4_in_chnl_ctrl_45;
--ch5_csr_chnl_in(703 DOWNTO 688) <= ch5_in_chnl_ctrl_45;

ch0_csr_chnl_in(719 DOWNTO 704) <= ch0_in_chnl_ctrl_46;
ch1_csr_chnl_in(719 DOWNTO 704) <= ch1_in_chnl_ctrl_46;
ch2_csr_chnl_in(719 DOWNTO 704) <= ch2_in_chnl_ctrl_46;
ch3_csr_chnl_in(719 DOWNTO 704) <= ch3_in_chnl_ctrl_46;
--ch4_csr_chnl_in(719 DOWNTO 704) <= ch4_in_chnl_ctrl_46;
--ch5_csr_chnl_in(719 DOWNTO 704) <= ch5_in_chnl_ctrl_46;

ch0_csr_chnl_in(735 DOWNTO 720) <= ch0_in_chnl_ctrl_47;
ch1_csr_chnl_in(735 DOWNTO 720) <= ch1_in_chnl_ctrl_47;
ch2_csr_chnl_in(735 DOWNTO 720) <= ch2_in_chnl_ctrl_47;
ch3_csr_chnl_in(735 DOWNTO 720) <= ch3_in_chnl_ctrl_47;
--ch4_csr_chnl_in(735 DOWNTO 720) <= ch4_in_chnl_ctrl_47;
--ch5_csr_chnl_in(735 DOWNTO 720) <= ch5_in_chnl_ctrl_47;

ch0_csr_chnl_in(751 DOWNTO 736) <= ch0_in_chnl_ctrl_48;
ch1_csr_chnl_in(751 DOWNTO 736) <= ch1_in_chnl_ctrl_48;
ch2_csr_chnl_in(751 DOWNTO 736) <= ch2_in_chnl_ctrl_48;
ch3_csr_chnl_in(751 DOWNTO 736) <= ch3_in_chnl_ctrl_48;
--ch4_csr_chnl_in(751 DOWNTO 736) <= ch4_in_chnl_ctrl_48;
--ch5_csr_chnl_in(751 DOWNTO 736) <= ch5_in_chnl_ctrl_48;

ch0_csr_chnl_in(767 DOWNTO 752) <= ch0_in_chnl_ctrl_49;
ch1_csr_chnl_in(767 DOWNTO 752) <= ch1_in_chnl_ctrl_49;
ch2_csr_chnl_in(767 DOWNTO 752) <= ch2_in_chnl_ctrl_49;
ch3_csr_chnl_in(767 DOWNTO 752) <= ch3_in_chnl_ctrl_49;
--ch4_csr_chnl_in(767 DOWNTO 752) <= ch4_in_chnl_ctrl_49;
--ch5_csr_chnl_in(767 DOWNTO 752) <= ch5_in_chnl_ctrl_49;

ch0_csr_chnl_in(783 DOWNTO 768) <= ch0_in_chnl_ctrl_50;
ch1_csr_chnl_in(783 DOWNTO 768) <= ch1_in_chnl_ctrl_50;
ch2_csr_chnl_in(783 DOWNTO 768) <= ch2_in_chnl_ctrl_50;
ch3_csr_chnl_in(783 DOWNTO 768) <= ch3_in_chnl_ctrl_50;
--ch4_csr_chnl_in(783 DOWNTO 768) <= ch4_in_chnl_ctrl_50;
--ch5_csr_chnl_in(783 DOWNTO 768) <= ch5_in_chnl_ctrl_50;

ch0_csr_chnl_in(799 DOWNTO 784) <= ch0_in_chnl_ctrl_51;
ch1_csr_chnl_in(799 DOWNTO 784) <= ch1_in_chnl_ctrl_51;
ch2_csr_chnl_in(799 DOWNTO 784) <= ch2_in_chnl_ctrl_51;
ch3_csr_chnl_in(799 DOWNTO 784) <= ch3_in_chnl_ctrl_51;
--ch4_csr_chnl_in(799 DOWNTO 784) <= ch4_in_chnl_ctrl_51;
--ch5_csr_chnl_in(799 DOWNTO 784) <= ch5_in_chnl_ctrl_51;

ch0_csr_chnl_in(815 DOWNTO 800) <= ch0_in_chnl_ctrl_52;
ch1_csr_chnl_in(815 DOWNTO 800) <= ch1_in_chnl_ctrl_52;
ch2_csr_chnl_in(815 DOWNTO 800) <= ch2_in_chnl_ctrl_52;
ch3_csr_chnl_in(815 DOWNTO 800) <= ch3_in_chnl_ctrl_52;
--ch4_csr_chnl_in(815 DOWNTO 800) <= ch4_in_chnl_ctrl_52;
--ch5_csr_chnl_in(815 DOWNTO 800) <= ch5_in_chnl_ctrl_52;

ch0_csr_chnl_in(831 DOWNTO 816) <= ch0_in_chnl_ctrl_53;
ch1_csr_chnl_in(831 DOWNTO 816) <= ch1_in_chnl_ctrl_53;
ch2_csr_chnl_in(831 DOWNTO 816) <= ch2_in_chnl_ctrl_53;
ch3_csr_chnl_in(831 DOWNTO 816) <= ch3_in_chnl_ctrl_53;
--ch4_csr_chnl_in(831 DOWNTO 816) <= ch4_in_chnl_ctrl_53;
--ch5_csr_chnl_in(831 DOWNTO 816) <= ch5_in_chnl_ctrl_53;

---------------------------------------------------------------
-- Read DPRIOIN -----------------------------------------------
---------------------------------------------------------------

-- -------- HW ordering  ------------------------------------
--TXPCS
ch0_out_chnl_ctrl_1 <= ch0_dp_chnl_out(15 DOWNTO 0);
ch1_out_chnl_ctrl_1 <= ch1_dp_chnl_out(15 DOWNTO 0);
ch2_out_chnl_ctrl_1 <= ch2_dp_chnl_out(15 DOWNTO 0);
ch3_out_chnl_ctrl_1 <= ch3_dp_chnl_out(15 DOWNTO 0);

ch0_out_chnl_ctrl_2 <= ch0_dp_chnl_out(31 DOWNTO 16);
ch1_out_chnl_ctrl_2 <= ch1_dp_chnl_out(31 DOWNTO 16);
ch2_out_chnl_ctrl_2 <= ch2_dp_chnl_out(31 DOWNTO 16);
ch3_out_chnl_ctrl_2 <= ch3_dp_chnl_out(31 DOWNTO 16);

ch0_out_chnl_ctrl_3 <= ch0_dp_chnl_out(47 DOWNTO 32);
ch1_out_chnl_ctrl_3 <= ch1_dp_chnl_out(47 DOWNTO 32);
ch2_out_chnl_ctrl_3 <= ch2_dp_chnl_out(47 DOWNTO 32);
ch3_out_chnl_ctrl_3 <= ch3_dp_chnl_out(47 DOWNTO 32);

ch0_out_chnl_ctrl_4 <= ch0_dp_chnl_out(63 DOWNTO 48);
ch1_out_chnl_ctrl_4 <= ch1_dp_chnl_out(63 DOWNTO 48);
ch2_out_chnl_ctrl_4 <= ch2_dp_chnl_out(63 DOWNTO 48);
ch3_out_chnl_ctrl_4 <= ch3_dp_chnl_out(63 DOWNTO 48);

ch0_out_chnl_ctrl_5 <= ch0_dp_chnl_out(79 DOWNTO 64);
ch1_out_chnl_ctrl_5 <= ch1_dp_chnl_out(79 DOWNTO 64);
ch2_out_chnl_ctrl_5 <= ch2_dp_chnl_out(79 DOWNTO 64);
ch3_out_chnl_ctrl_5 <= ch3_dp_chnl_out(79 DOWNTO 64);

ch0_out_chnl_ctrl_6 <= ch0_dp_chnl_out(95 DOWNTO 80);
ch1_out_chnl_ctrl_6 <= ch1_dp_chnl_out(95 DOWNTO 80);
ch2_out_chnl_ctrl_6 <= ch2_dp_chnl_out(95 DOWNTO 80);
ch3_out_chnl_ctrl_6 <= ch3_dp_chnl_out(95 DOWNTO 80);

ch0_out_chnl_ctrl_7 <= ch0_dp_chnl_out(111 DOWNTO 96);
ch1_out_chnl_ctrl_7 <= ch1_dp_chnl_out(111 DOWNTO 96);
ch2_out_chnl_ctrl_7 <= ch2_dp_chnl_out(111 DOWNTO 96);
ch3_out_chnl_ctrl_7 <= ch3_dp_chnl_out(111 DOWNTO 96);

ch0_out_chnl_ctrl_8 <= ch0_dp_chnl_out(127 DOWNTO 112);
ch1_out_chnl_ctrl_8 <= ch1_dp_chnl_out(127 DOWNTO 112);
ch2_out_chnl_ctrl_8 <= ch2_dp_chnl_out(127 DOWNTO 112);
ch3_out_chnl_ctrl_8 <= ch3_dp_chnl_out(127 DOWNTO 112);

ch0_out_chnl_ctrl_9 <= ch0_dp_chnl_out(143 DOWNTO 128);
ch1_out_chnl_ctrl_9 <= ch1_dp_chnl_out(143 DOWNTO 128);
ch2_out_chnl_ctrl_9 <= ch2_dp_chnl_out(143 DOWNTO 128);
ch3_out_chnl_ctrl_9 <= ch3_dp_chnl_out(143 DOWNTO 128);

ch0_out_chnl_ctrl_10 <= ch0_dp_chnl_out(159 DOWNTO 144);
ch1_out_chnl_ctrl_10 <= ch1_dp_chnl_out(159 DOWNTO 144);
ch2_out_chnl_ctrl_10 <= ch2_dp_chnl_out(159 DOWNTO 144);
ch3_out_chnl_ctrl_10 <= ch3_dp_chnl_out(159 DOWNTO 144);

ch0_out_chnl_ctrl_11 <= ch0_dp_chnl_out(175 DOWNTO 160);
ch1_out_chnl_ctrl_11 <= ch1_dp_chnl_out(175 DOWNTO 160);
ch2_out_chnl_ctrl_11 <= ch2_dp_chnl_out(175 DOWNTO 160);
ch3_out_chnl_ctrl_11 <= ch3_dp_chnl_out(175 DOWNTO 160);

ch0_out_chnl_ctrl_12 <= ch0_dp_chnl_out(191 DOWNTO 176);
ch1_out_chnl_ctrl_12 <= ch1_dp_chnl_out(191 DOWNTO 176);
ch2_out_chnl_ctrl_12 <= ch2_dp_chnl_out(191 DOWNTO 176);
ch3_out_chnl_ctrl_12 <= ch3_dp_chnl_out(191 DOWNTO 176);

ch0_out_chnl_ctrl_13 <= ch0_dp_chnl_out(207 DOWNTO 192);
ch1_out_chnl_ctrl_13 <= ch1_dp_chnl_out(207 DOWNTO 192);
ch2_out_chnl_ctrl_13 <= ch2_dp_chnl_out(207 DOWNTO 192);
ch3_out_chnl_ctrl_13 <= ch3_dp_chnl_out(207 DOWNTO 192);

ch0_out_chnl_ctrl_14 <= ch0_dp_chnl_out(223 DOWNTO 208);
ch1_out_chnl_ctrl_14 <= ch1_dp_chnl_out(223 DOWNTO 208);
ch2_out_chnl_ctrl_14 <= ch2_dp_chnl_out(223 DOWNTO 208);
ch3_out_chnl_ctrl_14 <= ch3_dp_chnl_out(223 DOWNTO 208);

ch0_out_chnl_ctrl_15 <= ch0_dp_chnl_out(239 DOWNTO 224);
ch1_out_chnl_ctrl_15 <= ch1_dp_chnl_out(239 DOWNTO 224);
ch2_out_chnl_ctrl_15 <= ch2_dp_chnl_out(239 DOWNTO 224);
ch3_out_chnl_ctrl_15 <= ch3_dp_chnl_out(239 DOWNTO 224);

ch0_out_chnl_ctrl_16 <= ch0_dp_chnl_out(255 DOWNTO 240);
ch1_out_chnl_ctrl_16 <= ch1_dp_chnl_out(255 DOWNTO 240);
ch2_out_chnl_ctrl_16 <= ch2_dp_chnl_out(255 DOWNTO 240);
ch3_out_chnl_ctrl_16 <= ch3_dp_chnl_out(255 DOWNTO 240);

ch0_out_chnl_ctrl_17 <= ch0_dp_chnl_out(271 DOWNTO 256);
ch1_out_chnl_ctrl_17 <= ch1_dp_chnl_out(271 DOWNTO 256);
ch2_out_chnl_ctrl_17 <= ch2_dp_chnl_out(271 DOWNTO 256);
ch3_out_chnl_ctrl_17 <= ch3_dp_chnl_out(271 DOWNTO 256);

ch0_out_chnl_ctrl_18 <= ch0_dp_chnl_out(287 DOWNTO 272);
ch1_out_chnl_ctrl_18 <= ch1_dp_chnl_out(287 DOWNTO 272);
ch2_out_chnl_ctrl_18 <= ch2_dp_chnl_out(287 DOWNTO 272);
ch3_out_chnl_ctrl_18 <= ch3_dp_chnl_out(287 DOWNTO 272);

ch0_out_chnl_ctrl_19 <= ch0_dp_chnl_out(303 DOWNTO 288);
ch1_out_chnl_ctrl_19 <= ch1_dp_chnl_out(303 DOWNTO 288);
ch2_out_chnl_ctrl_19 <= ch2_dp_chnl_out(303 DOWNTO 288);
ch3_out_chnl_ctrl_19 <= ch3_dp_chnl_out(303 DOWNTO 288);

ch0_out_chnl_ctrl_20 <= ch0_dp_chnl_out(319 DOWNTO 304);
ch1_out_chnl_ctrl_20 <= ch1_dp_chnl_out(319 DOWNTO 304);
ch2_out_chnl_ctrl_20 <= ch2_dp_chnl_out(319 DOWNTO 304);
ch3_out_chnl_ctrl_20 <= ch3_dp_chnl_out(319 DOWNTO 304);

ch0_out_chnl_ctrl_21 <= ch0_dp_chnl_out(335 DOWNTO 320);
ch1_out_chnl_ctrl_21 <= ch1_dp_chnl_out(335 DOWNTO 320);
ch2_out_chnl_ctrl_21 <= ch2_dp_chnl_out(335 DOWNTO 320);
ch3_out_chnl_ctrl_21 <= ch3_dp_chnl_out(335 DOWNTO 320);

ch0_out_chnl_ctrl_22 <= ch0_dp_chnl_out(351 DOWNTO 336);
ch1_out_chnl_ctrl_22 <= ch1_dp_chnl_out(351 DOWNTO 336);
ch2_out_chnl_ctrl_22 <= ch2_dp_chnl_out(351 DOWNTO 336);
ch3_out_chnl_ctrl_22 <= ch3_dp_chnl_out(351 DOWNTO 336);

ch0_out_chnl_ctrl_23 <= ch0_dp_chnl_out(367 DOWNTO 352);
ch1_out_chnl_ctrl_23 <= ch1_dp_chnl_out(367 DOWNTO 352);
ch2_out_chnl_ctrl_23 <= ch2_dp_chnl_out(367 DOWNTO 352);
ch3_out_chnl_ctrl_23 <= ch3_dp_chnl_out(367 DOWNTO 352);

ch0_out_chnl_ctrl_24 <= ch0_dp_chnl_out(383 DOWNTO 368);
ch1_out_chnl_ctrl_24 <= ch1_dp_chnl_out(383 DOWNTO 368);
ch2_out_chnl_ctrl_24 <= ch2_dp_chnl_out(383 DOWNTO 368);
ch3_out_chnl_ctrl_24 <= ch3_dp_chnl_out(383 DOWNTO 368);

ch0_out_chnl_ctrl_25 <= ch0_dp_chnl_out(399 DOWNTO 384);
ch1_out_chnl_ctrl_25 <= ch1_dp_chnl_out(399 DOWNTO 384);
ch2_out_chnl_ctrl_25 <= ch2_dp_chnl_out(399 DOWNTO 384);
ch3_out_chnl_ctrl_25 <= ch3_dp_chnl_out(399 DOWNTO 384);

ch0_out_chnl_ctrl_26 <= ch0_dp_chnl_out(415 DOWNTO 400);
ch1_out_chnl_ctrl_26 <= ch1_dp_chnl_out(415 DOWNTO 400);
ch2_out_chnl_ctrl_26 <= ch2_dp_chnl_out(415 DOWNTO 400);
ch3_out_chnl_ctrl_26 <= ch3_dp_chnl_out(415 DOWNTO 400);

ch0_out_chnl_ctrl_27 <= ch0_dp_chnl_out(431 DOWNTO 416);
ch1_out_chnl_ctrl_27 <= ch1_dp_chnl_out(431 DOWNTO 416);
ch2_out_chnl_ctrl_27 <= ch2_dp_chnl_out(431 DOWNTO 416);
ch3_out_chnl_ctrl_27 <= ch3_dp_chnl_out(431 DOWNTO 416);

--TXPMA
ch0_out_chnl_ctrl_28 <= ch0_dp_chnl_out(447 DOWNTO 432);
ch1_out_chnl_ctrl_28 <= ch1_dp_chnl_out(447 DOWNTO 432);
ch2_out_chnl_ctrl_28 <= ch2_dp_chnl_out(447 DOWNTO 432);
ch3_out_chnl_ctrl_28 <= ch3_dp_chnl_out(447 DOWNTO 432);
--ch4_out_chnl_ctrl_28 <= ch4_dp_chnl_out(447 DOWNTO 432);
--ch5_out_chnl_ctrl_28 <= ch5_dp_chnl_out(447 DOWNTO 432);

ch0_out_chnl_ctrl_29 <= ch0_dp_chnl_out(463 DOWNTO 448);
ch1_out_chnl_ctrl_29 <= ch1_dp_chnl_out(463 DOWNTO 448);
ch2_out_chnl_ctrl_29 <= ch2_dp_chnl_out(463 DOWNTO 448);
ch3_out_chnl_ctrl_29 <= ch3_dp_chnl_out(463 DOWNTO 448);
--ch4_out_chnl_ctrl_29 <= ch4_dp_chnl_out(463 DOWNTO 448);
--ch5_out_chnl_ctrl_29 <= ch5_dp_chnl_out(463 DOWNTO 448);

ch0_out_chnl_ctrl_30 <= ch0_dp_chnl_out(479 DOWNTO 464);
ch1_out_chnl_ctrl_30 <= ch1_dp_chnl_out(479 DOWNTO 464);
ch2_out_chnl_ctrl_30 <= ch2_dp_chnl_out(479 DOWNTO 464);
ch3_out_chnl_ctrl_30 <= ch3_dp_chnl_out(479 DOWNTO 464);
--ch4_out_chnl_ctrl_30 <= ch4_dp_chnl_out(479 DOWNTO 464);
--ch5_out_chnl_ctrl_30 <= ch5_dp_chnl_out(479 DOWNTO 464);

ch0_out_chnl_ctrl_31 <= ch0_dp_chnl_out(495 DOWNTO 480);
ch1_out_chnl_ctrl_31 <= ch1_dp_chnl_out(495 DOWNTO 480);
ch2_out_chnl_ctrl_31 <= ch2_dp_chnl_out(495 DOWNTO 480);
ch3_out_chnl_ctrl_31 <= ch3_dp_chnl_out(495 DOWNTO 480);
--ch4_out_chnl_ctrl_31 <= ch4_dp_chnl_out(495 DOWNTO 480);
--ch5_out_chnl_ctrl_31 <= ch5_dp_chnl_out(495 DOWNTO 480);

ch0_out_chnl_ctrl_32 <= ch0_dp_chnl_out(511 DOWNTO 496);
ch1_out_chnl_ctrl_32 <= ch1_dp_chnl_out(511 DOWNTO 496);
ch2_out_chnl_ctrl_32 <= ch2_dp_chnl_out(511 DOWNTO 496);
ch3_out_chnl_ctrl_32 <= ch3_dp_chnl_out(511 DOWNTO 496);
--ch4_out_chnl_ctrl_32 <= ch4_dp_chnl_out(511 DOWNTO 496);
--ch5_out_chnl_ctrl_32 <= ch5_dp_chnl_out(511 DOWNTO 496);

ch0_out_chnl_ctrl_33 <= ch0_dp_chnl_out(527 DOWNTO 512);
ch1_out_chnl_ctrl_33 <= ch1_dp_chnl_out(527 DOWNTO 512);
ch2_out_chnl_ctrl_33 <= ch2_dp_chnl_out(527 DOWNTO 512);
ch3_out_chnl_ctrl_33 <= ch3_dp_chnl_out(527 DOWNTO 512);
--ch4_out_chnl_ctrl_33 <= ch4_dp_chnl_out(527 DOWNTO 512);
--ch5_out_chnl_ctrl_33 <= ch5_dp_chnl_out(527 DOWNTO 512);

ch0_out_chnl_ctrl_34 <= ch0_dp_chnl_out(543 DOWNTO 528);
ch1_out_chnl_ctrl_34 <= ch1_dp_chnl_out(543 DOWNTO 528);
ch2_out_chnl_ctrl_34 <= ch2_dp_chnl_out(543 DOWNTO 528);
ch3_out_chnl_ctrl_34 <= ch3_dp_chnl_out(543 DOWNTO 528);
--ch4_out_chnl_ctrl_34 <= ch4_dp_chnl_out(543 DOWNTO 528);
--ch5_out_chnl_ctrl_34 <= ch5_dp_chnl_out(543 DOWNTO 528);

ch0_out_chnl_ctrl_35 <= ch0_dp_chnl_out(559 DOWNTO 544);
ch1_out_chnl_ctrl_35 <= ch1_dp_chnl_out(559 DOWNTO 544);
ch2_out_chnl_ctrl_35 <= ch2_dp_chnl_out(559 DOWNTO 544);
ch3_out_chnl_ctrl_35 <= ch3_dp_chnl_out(559 DOWNTO 544);
--ch4_out_chnl_ctrl_35 <= ch4_dp_chnl_out(559 DOWNTO 544);
--ch5_out_chnl_ctrl_35 <= ch5_dp_chnl_out(559 DOWNTO 544);

ch0_out_chnl_ctrl_36 <= ch0_dp_chnl_out(575 DOWNTO 560);
ch1_out_chnl_ctrl_36 <= ch1_dp_chnl_out(575 DOWNTO 560);
ch2_out_chnl_ctrl_36 <= ch2_dp_chnl_out(575 DOWNTO 560);
ch3_out_chnl_ctrl_36 <= ch3_dp_chnl_out(575 DOWNTO 560);
--ch4_out_chnl_ctrl_36 <= ch4_dp_chnl_out(575 DOWNTO 560);
--ch5_out_chnl_ctrl_36 <= ch5_dp_chnl_out(575 DOWNTO 560);

ch0_out_chnl_ctrl_37 <= ch0_dp_chnl_out(591 DOWNTO 576);
ch1_out_chnl_ctrl_37 <= ch1_dp_chnl_out(591 DOWNTO 576);
ch2_out_chnl_ctrl_37 <= ch2_dp_chnl_out(591 DOWNTO 576);
ch3_out_chnl_ctrl_37 <= ch3_dp_chnl_out(591 DOWNTO 576);
--ch4_out_chnl_ctrl_37 <= ch4_dp_chnl_out(591 DOWNTO 576);
--ch5_out_chnl_ctrl_37 <= ch5_dp_chnl_out(591 DOWNTO 576);

ch0_out_chnl_ctrl_38 <= ch0_dp_chnl_out(607 DOWNTO 592);
ch1_out_chnl_ctrl_38 <= ch1_dp_chnl_out(607 DOWNTO 592);
ch2_out_chnl_ctrl_38 <= ch2_dp_chnl_out(607 DOWNTO 592);
ch3_out_chnl_ctrl_38 <= ch3_dp_chnl_out(607 DOWNTO 592);
--ch4_out_chnl_ctrl_38 <= ch4_dp_chnl_out(607 DOWNTO 592);
--ch5_out_chnl_ctrl_38 <= ch5_dp_chnl_out(607 DOWNTO 592);

ch0_out_chnl_ctrl_39 <= ch0_dp_chnl_out(623 DOWNTO 608);
ch1_out_chnl_ctrl_39 <= ch1_dp_chnl_out(623 DOWNTO 608);
ch2_out_chnl_ctrl_39 <= ch2_dp_chnl_out(623 DOWNTO 608);
ch3_out_chnl_ctrl_39 <= ch3_dp_chnl_out(623 DOWNTO 608);
--ch4_out_chnl_ctrl_39 <= ch4_dp_chnl_out(623 DOWNTO 608);
--ch5_out_chnl_ctrl_39 <= ch5_dp_chnl_out(623 DOWNTO 608);

ch0_out_chnl_ctrl_40 <= ch0_dp_chnl_out(639 DOWNTO 624);
ch1_out_chnl_ctrl_40 <= ch1_dp_chnl_out(639 DOWNTO 624);
ch2_out_chnl_ctrl_40 <= ch2_dp_chnl_out(639 DOWNTO 624);
ch3_out_chnl_ctrl_40 <= ch3_dp_chnl_out(639 DOWNTO 624);
--ch4_out_chnl_ctrl_40 <= ch4_dp_chnl_out(639 DOWNTO 624);
--ch5_out_chnl_ctrl_40 <= ch5_dp_chnl_out(639 DOWNTO 624);

ch0_out_chnl_ctrl_41 <= ch0_dp_chnl_out(655 DOWNTO 640);
ch1_out_chnl_ctrl_41 <= ch1_dp_chnl_out(655 DOWNTO 640);
ch2_out_chnl_ctrl_41 <= ch2_dp_chnl_out(655 DOWNTO 640);
ch3_out_chnl_ctrl_41 <= ch3_dp_chnl_out(655 DOWNTO 640);
--ch4_out_chnl_ctrl_41 <= ch4_dp_chnl_out(655 DOWNTO 640);
--ch5_out_chnl_ctrl_41 <= ch5_dp_chnl_out(655 DOWNTO 640);

ch0_out_chnl_ctrl_42 <= ch0_dp_chnl_out(671 DOWNTO 656);
ch1_out_chnl_ctrl_42 <= ch1_dp_chnl_out(671 DOWNTO 656);
ch2_out_chnl_ctrl_42 <= ch2_dp_chnl_out(671 DOWNTO 656);
ch3_out_chnl_ctrl_42 <= ch3_dp_chnl_out(671 DOWNTO 656);
--ch4_out_chnl_ctrl_42 <= ch4_dp_chnl_out(671 DOWNTO 656);
--ch5_out_chnl_ctrl_42 <= ch5_dp_chnl_out(671 DOWNTO 656);

-- reserved
ch0_out_chnl_ctrl_43 <= ch0_dp_chnl_out_reserved(15 DOWNTO 0);
ch1_out_chnl_ctrl_43 <= ch1_dp_chnl_out_reserved(15 DOWNTO 0);
ch2_out_chnl_ctrl_43 <= ch2_dp_chnl_out_reserved(15 DOWNTO 0);
ch3_out_chnl_ctrl_43 <= ch3_dp_chnl_out_reserved(15 DOWNTO 0);
--ch4_out_chnl_ctrl_43 <= ch4_dp_chnl_out(15 DOWNTO 0);
--ch5_out_chnl_ctrl_43 <= ch5_dp_chnl_out(15 DOWNTO 0);

ch0_out_chnl_ctrl_44 <= ch0_dp_chnl_out(687 DOWNTO 672);
ch1_out_chnl_ctrl_44 <= ch1_dp_chnl_out(687 DOWNTO 672);
ch2_out_chnl_ctrl_44 <= ch2_dp_chnl_out(687 DOWNTO 672);
ch3_out_chnl_ctrl_44 <= ch3_dp_chnl_out(687 DOWNTO 672);
--ch4_out_chnl_ctrl_44 <= ch4_dp_chnl_out(687 DOWNTO 672);
--ch5_out_chnl_ctrl_44 <= ch5_dp_chnl_out(687 DOWNTO 672);

ch0_out_chnl_ctrl_45 <= ch0_dp_chnl_out(703 DOWNTO 688);
ch1_out_chnl_ctrl_45 <= ch1_dp_chnl_out(703 DOWNTO 688);
ch2_out_chnl_ctrl_45 <= ch2_dp_chnl_out(703 DOWNTO 688);
ch3_out_chnl_ctrl_45 <= ch3_dp_chnl_out(703 DOWNTO 688);
--ch4_out_chnl_ctrl_45 <= ch4_dp_chnl_out(703 DOWNTO 688);
--ch5_out_chnl_ctrl_45 <= ch5_dp_chnl_out(703 DOWNTO 688);

ch0_out_chnl_ctrl_46 <= ch0_dp_chnl_out(719 DOWNTO 704);
ch1_out_chnl_ctrl_46 <= ch1_dp_chnl_out(719 DOWNTO 704);
ch2_out_chnl_ctrl_46 <= ch2_dp_chnl_out(719 DOWNTO 704);
ch3_out_chnl_ctrl_46 <= ch3_dp_chnl_out(719 DOWNTO 704);
--ch4_out_chnl_ctrl_46 <= ch4_dp_chnl_out(719 DOWNTO 704);
--ch5_out_chnl_ctrl_46 <= ch5_dp_chnl_out(719 DOWNTO 704);

ch0_out_chnl_ctrl_47 <= ch0_dp_chnl_out(735 DOWNTO 720);
ch1_out_chnl_ctrl_47 <= ch1_dp_chnl_out(735 DOWNTO 720);
ch2_out_chnl_ctrl_47 <= ch2_dp_chnl_out(735 DOWNTO 720);
ch3_out_chnl_ctrl_47 <= ch3_dp_chnl_out(735 DOWNTO 720);
--ch4_out_chnl_ctrl_47 <= ch4_dp_chnl_out(735 DOWNTO 720);
--ch5_out_chnl_ctrl_47 <= ch5_dp_chnl_out(735 DOWNTO 720);

ch0_out_chnl_ctrl_48 <= ch0_dp_chnl_out(751 DOWNTO 736);
ch1_out_chnl_ctrl_48 <= ch1_dp_chnl_out(751 DOWNTO 736);
ch2_out_chnl_ctrl_48 <= ch2_dp_chnl_out(751 DOWNTO 736);
ch3_out_chnl_ctrl_48 <= ch3_dp_chnl_out(751 DOWNTO 736);
--ch4_out_chnl_ctrl_48 <= ch4_dp_chnl_out(751 DOWNTO 736);
--ch5_out_chnl_ctrl_48 <= ch5_dp_chnl_out(751 DOWNTO 736);

ch0_out_chnl_ctrl_49 <= ch0_dp_chnl_out(767 DOWNTO 752);
ch1_out_chnl_ctrl_49 <= ch1_dp_chnl_out(767 DOWNTO 752);
ch2_out_chnl_ctrl_49 <= ch2_dp_chnl_out(767 DOWNTO 752);
ch3_out_chnl_ctrl_49 <= ch3_dp_chnl_out(767 DOWNTO 752);
--ch4_out_chnl_ctrl_49 <= ch4_dp_chnl_out(767 DOWNTO 752);
--ch5_out_chnl_ctrl_49 <= ch5_dp_chnl_out(767 DOWNTO 752);

ch0_out_chnl_ctrl_50 <= ch0_dp_chnl_out(783 DOWNTO 768);
ch1_out_chnl_ctrl_50 <= ch1_dp_chnl_out(783 DOWNTO 768);
ch2_out_chnl_ctrl_50 <= ch2_dp_chnl_out(783 DOWNTO 768);
ch3_out_chnl_ctrl_50 <= ch3_dp_chnl_out(783 DOWNTO 768);
--ch4_out_chnl_ctrl_50 <= ch4_dp_chnl_out(783 DOWNTO 768);
--ch5_out_chnl_ctrl_50 <= ch5_dp_chnl_out(783 DOWNTO 768);

ch0_out_chnl_ctrl_51 <= ch0_dp_chnl_out(799 DOWNTO 784);
ch1_out_chnl_ctrl_51 <= ch1_dp_chnl_out(799 DOWNTO 784);
ch2_out_chnl_ctrl_51 <= ch2_dp_chnl_out(799 DOWNTO 784);
ch3_out_chnl_ctrl_51 <= ch3_dp_chnl_out(799 DOWNTO 784);
--ch4_out_chnl_ctrl_51 <= ch4_dp_chnl_out(799 DOWNTO 784);
--ch5_out_chnl_ctrl_51 <= ch5_dp_chnl_out(799 DOWNTO 784);

ch0_out_chnl_ctrl_52 <= ch0_dp_chnl_out(815 DOWNTO 800);
ch1_out_chnl_ctrl_52 <= ch1_dp_chnl_out(815 DOWNTO 800);
ch2_out_chnl_ctrl_52 <= ch2_dp_chnl_out(815 DOWNTO 800);
ch3_out_chnl_ctrl_52 <= ch3_dp_chnl_out(815 DOWNTO 800);
--ch4_out_chnl_ctrl_52 <= ch4_dp_chnl_out(815 DOWNTO 800);
--ch5_out_chnl_ctrl_52 <= ch5_dp_chnl_out(815 DOWNTO 800);

ch0_out_chnl_ctrl_53 <= ch0_dp_chnl_out(831 DOWNTO 816);
ch1_out_chnl_ctrl_53 <= ch1_dp_chnl_out(831 DOWNTO 816);
ch2_out_chnl_ctrl_53 <= ch2_dp_chnl_out(831 DOWNTO 816);
ch3_out_chnl_ctrl_53 <= ch3_dp_chnl_out(831 DOWNTO 816);
--ch4_out_chnl_ctrl_53 <= ch4_dp_chnl_out(831 DOWNTO 816);
--ch5_out_chnl_ctrl_53 <= ch5_dp_chnl_out(831 DOWNTO 816);

-- -------- SW ordering  ------------------------------------
--TXPCS
ch0_txpcsdprioout_phy(rforce_kchar_DP_TXPCS_IDX_0 DOWNTO rforce_disp_DP_TXPCS_IDX_0) <= ch0_out_chnl_ctrl_1;
ch1_txpcsdprioout_phy(rforce_kchar_DP_TXPCS_IDX_0 DOWNTO rforce_disp_DP_TXPCS_IDX_0) <= ch1_out_chnl_ctrl_1;
ch2_txpcsdprioout_phy(rforce_kchar_DP_TXPCS_IDX_0 DOWNTO rforce_disp_DP_TXPCS_IDX_0) <= ch2_out_chnl_ctrl_1;
ch3_txpcsdprioout_phy(rforce_kchar_DP_TXPCS_IDX_0 DOWNTO rforce_disp_DP_TXPCS_IDX_0) <= ch3_out_chnl_ctrl_1;

ch0_txpcsdprioout_phy(rendec_tx_DP_TXPCS_IDX_0 DOWNTO rtxpcsbypass_en_DP_TXPCS_IDX_0) <= ch0_out_chnl_ctrl_2;
ch1_txpcsdprioout_phy(rendec_tx_DP_TXPCS_IDX_0 DOWNTO rtxpcsbypass_en_DP_TXPCS_IDX_0) <= ch1_out_chnl_ctrl_2;
ch2_txpcsdprioout_phy(rendec_tx_DP_TXPCS_IDX_0 DOWNTO rtxpcsbypass_en_DP_TXPCS_IDX_0) <= ch2_out_chnl_ctrl_2;
ch3_txpcsdprioout_phy(rendec_tx_DP_TXPCS_IDX_0 DOWNTO rtxpcsbypass_en_DP_TXPCS_IDX_0) <= ch3_out_chnl_ctrl_2;

ch0_txpcsdprioout_phy(rtx_pipe_enable_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB3_DP_TXPCS_IDX_0) <= ch0_out_chnl_ctrl_3;
ch1_txpcsdprioout_phy(rtx_pipe_enable_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB3_DP_TXPCS_IDX_0) <= ch1_out_chnl_ctrl_3;
ch2_txpcsdprioout_phy(rtx_pipe_enable_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB3_DP_TXPCS_IDX_0) <= ch2_out_chnl_ctrl_3;
ch3_txpcsdprioout_phy(rtx_pipe_enable_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB3_DP_TXPCS_IDX_0) <= ch3_out_chnl_ctrl_3;

ch0_txpcsdprioout_phy(rself_sw_en_tx_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB4_DP_TXPCS_IDX_0) <= ch0_out_chnl_ctrl_4;
ch1_txpcsdprioout_phy(rself_sw_en_tx_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB4_DP_TXPCS_IDX_0) <= ch1_out_chnl_ctrl_4;
ch2_txpcsdprioout_phy(rself_sw_en_tx_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB4_DP_TXPCS_IDX_0) <= ch2_out_chnl_ctrl_4;
ch3_txpcsdprioout_phy(rself_sw_en_tx_DP_TXPCS_IDX_0 DOWNTO reserved_0_TB4_DP_TXPCS_IDX_0) <= ch3_out_chnl_ctrl_4;

ch0_rxpcsdprioout_phy(reserved_0_TB5_DP_RXPCS_IDX_0 DOWNTO rrxpcsbypass_en_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_5;
ch1_rxpcsdprioout_phy(reserved_0_TB5_DP_RXPCS_IDX_0 DOWNTO rrxpcsbypass_en_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_5;
ch2_rxpcsdprioout_phy(reserved_0_TB5_DP_RXPCS_IDX_0 DOWNTO rrxpcsbypass_en_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_5;
ch3_rxpcsdprioout_phy(reserved_0_TB5_DP_RXPCS_IDX_0 DOWNTO rrxpcsbypass_en_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_5;

ch0_rxpcsdprioout_phy(resync_badcg_en_DP_RXPCS_IDX_1 DOWNTO rcomp_pat_32_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_6;
ch1_rxpcsdprioout_phy(resync_badcg_en_DP_RXPCS_IDX_1 DOWNTO rcomp_pat_32_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_6;
ch2_rxpcsdprioout_phy(resync_badcg_en_DP_RXPCS_IDX_1 DOWNTO rcomp_pat_32_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_6;
ch3_rxpcsdprioout_phy(resync_badcg_en_DP_RXPCS_IDX_1 DOWNTO rcomp_pat_32_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_6;

ch0_rxpcsdprioout_phy(rcomp_pat_31_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_16_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_7;
ch1_rxpcsdprioout_phy(rcomp_pat_31_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_16_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_7;
ch2_rxpcsdprioout_phy(rcomp_pat_31_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_16_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_7;
ch3_rxpcsdprioout_phy(rcomp_pat_31_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_16_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_7;

ch0_rxpcsdprioout_phy(rcomp_pat_15_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_0_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_8;
ch1_rxpcsdprioout_phy(rcomp_pat_15_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_0_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_8;
ch2_rxpcsdprioout_phy(rcomp_pat_15_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_0_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_8;
ch3_rxpcsdprioout_phy(rcomp_pat_15_DP_RXPCS_IDX_0 DOWNTO rcomp_pat_0_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_8;

ch0_rxpcsdprioout_phy(rsync_sm_dis_DP_RXPCS_IDX_0 DOWNTO rbitloc_rev_en_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_9;
ch1_rxpcsdprioout_phy(rsync_sm_dis_DP_RXPCS_IDX_0 DOWNTO rbitloc_rev_en_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_9;
ch2_rxpcsdprioout_phy(rsync_sm_dis_DP_RXPCS_IDX_0 DOWNTO rbitloc_rev_en_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_9;
ch3_rxpcsdprioout_phy(rsync_sm_dis_DP_RXPCS_IDX_0 DOWNTO rbitloc_rev_en_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_9;

ch0_rxpcsdprioout_phy(rgnumber_DP_RXPCS_IDX_7 DOWNTO rknumber_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_10;
ch1_rxpcsdprioout_phy(rgnumber_DP_RXPCS_IDX_7 DOWNTO rknumber_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_10;
ch2_rxpcsdprioout_phy(rgnumber_DP_RXPCS_IDX_7 DOWNTO rknumber_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_10;
ch3_rxpcsdprioout_phy(rgnumber_DP_RXPCS_IDX_7 DOWNTO rknumber_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_10;

ch0_rxpcsdprioout_phy(rrundisp_DP_RXPCS_IDX_5 DOWNTO renpolinv_rx_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_11;
ch1_rxpcsdprioout_phy(rrundisp_DP_RXPCS_IDX_5 DOWNTO renpolinv_rx_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_11;
ch2_rxpcsdprioout_phy(rrundisp_DP_RXPCS_IDX_5 DOWNTO renpolinv_rx_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_11;
ch3_rxpcsdprioout_phy(rrundisp_DP_RXPCS_IDX_5 DOWNTO renpolinv_rx_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_11;

ch0_rxpcsdprioout_phy(rmatchen_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_12;
ch1_rxpcsdprioout_phy(rmatchen_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_12;
ch2_rxpcsdprioout_phy(rmatchen_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_12;
ch3_rxpcsdprioout_phy(rmatchen_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_12;

ch0_rxpcsdprioout_phy(rclkcmpsq1n_19_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_10_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_13;
ch1_rxpcsdprioout_phy(rclkcmpsq1n_19_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_10_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_13;
ch2_rxpcsdprioout_phy(rclkcmpsq1n_19_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_10_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_13;
ch3_rxpcsdprioout_phy(rclkcmpsq1n_19_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1p_10_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_13;

ch0_rxpcsdprioout_phy(rclkcmpsq1n_14_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1n_0_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_14;
ch1_rxpcsdprioout_phy(rclkcmpsq1n_14_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1n_0_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_14;
ch2_rxpcsdprioout_phy(rclkcmpsq1n_14_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1n_0_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_14;
ch3_rxpcsdprioout_phy(rclkcmpsq1n_14_DP_RXPCS_IDX_0 DOWNTO rclkcmpsq1n_0_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_14;

ch0_rxpcsdprioout_phy(rclkcmp_pipe_en_DP_RXPCS_IDX_0 DOWNTO rfull_threshold_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_15;
ch1_rxpcsdprioout_phy(rclkcmp_pipe_en_DP_RXPCS_IDX_0 DOWNTO rfull_threshold_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_15;
ch2_rxpcsdprioout_phy(rclkcmp_pipe_en_DP_RXPCS_IDX_0 DOWNTO rfull_threshold_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_15;
ch3_rxpcsdprioout_phy(rclkcmp_pipe_en_DP_RXPCS_IDX_0 DOWNTO rfull_threshold_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_15;

ch0_rxpcsdprioout_phy(rempty_threshold_DP_RXPCS_IDX_2 DOWNTO rfreq_sel_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_16;
ch1_rxpcsdprioout_phy(rempty_threshold_DP_RXPCS_IDX_2 DOWNTO rfreq_sel_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_16;
ch2_rxpcsdprioout_phy(rempty_threshold_DP_RXPCS_IDX_2 DOWNTO rfreq_sel_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_16;
ch3_rxpcsdprioout_phy(rempty_threshold_DP_RXPCS_IDX_2 DOWNTO rfreq_sel_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_16;

ch0_rxpcsdprioout_phy(rrxfifo_dis_DP_RXPCS_IDX_0 DOWNTO rtest_bus_sel_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_17;
ch1_rxpcsdprioout_phy(rrxfifo_dis_DP_RXPCS_IDX_0 DOWNTO rtest_bus_sel_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_17;
ch2_rxpcsdprioout_phy(rrxfifo_dis_DP_RXPCS_IDX_0 DOWNTO rtest_bus_sel_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_17;
ch3_rxpcsdprioout_phy(rrxfifo_dis_DP_RXPCS_IDX_0 DOWNTO rtest_bus_sel_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_17;

ch0_rxpcsdprioout_phy(reserved_0_TB18_DP_RXPCS_IDX_5 DOWNTO rbytordpat_0_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_18;
ch1_rxpcsdprioout_phy(reserved_0_TB18_DP_RXPCS_IDX_5 DOWNTO rbytordpat_0_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_18;
ch2_rxpcsdprioout_phy(reserved_0_TB18_DP_RXPCS_IDX_5 DOWNTO rbytordpat_0_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_18;
ch3_rxpcsdprioout_phy(reserved_0_TB18_DP_RXPCS_IDX_5 DOWNTO rbytordpat_0_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_18;

ch0_rxpcsdprioout_phy(reserved_0_TB19_DP_RXPCS_IDX_5 DOWNTO rbytordpad_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_19;
ch1_rxpcsdprioout_phy(reserved_0_TB19_DP_RXPCS_IDX_5 DOWNTO rbytordpad_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_19;
ch2_rxpcsdprioout_phy(reserved_0_TB19_DP_RXPCS_IDX_5 DOWNTO rbytordpad_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_19;
ch3_rxpcsdprioout_phy(reserved_0_TB19_DP_RXPCS_IDX_5 DOWNTO rbytordpad_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_19;

ch0_rxpcsdprioout_phy(rrx_pipe_enable_DP_RXPCS_IDX_0 DOWNTO rload_shreg_del_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_20;
ch1_rxpcsdprioout_phy(rrx_pipe_enable_DP_RXPCS_IDX_0 DOWNTO rload_shreg_del_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_20;
ch2_rxpcsdprioout_phy(rrx_pipe_enable_DP_RXPCS_IDX_0 DOWNTO rload_shreg_del_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_20;
ch3_rxpcsdprioout_phy(rrx_pipe_enable_DP_RXPCS_IDX_0 DOWNTO rload_shreg_del_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_20;

ch0_rxpcsdprioout_phy(rpma_done_count_15_DP_RXPCS_IDX_0 DOWNTO rpma_done_count_0_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_21;
ch1_rxpcsdprioout_phy(rpma_done_count_15_DP_RXPCS_IDX_0 DOWNTO rpma_done_count_0_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_21;
ch2_rxpcsdprioout_phy(rpma_done_count_15_DP_RXPCS_IDX_0 DOWNTO rpma_done_count_0_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_21;
ch3_rxpcsdprioout_phy(rpma_done_count_15_DP_RXPCS_IDX_0 DOWNTO rpma_done_count_0_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_21;

ch0_rxpcsdprioout_phy(rerr_flags_sel_DP_RXPCS_IDX_0 DOWNTO rbytordpat_10_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_22;
ch1_rxpcsdprioout_phy(rerr_flags_sel_DP_RXPCS_IDX_0 DOWNTO rbytordpat_10_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_22;
ch2_rxpcsdprioout_phy(rerr_flags_sel_DP_RXPCS_IDX_0 DOWNTO rbytordpat_10_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_22;
ch3_rxpcsdprioout_phy(rerr_flags_sel_DP_RXPCS_IDX_0 DOWNTO rbytordpat_10_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_22;

ch0_rxpcsdprioout_phy(reserved_0_TB23_DP_RXPCS_IDX_7 DOWNTO rwait_count_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_23;
ch1_rxpcsdprioout_phy(reserved_0_TB23_DP_RXPCS_IDX_7 DOWNTO rwait_count_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_23;
ch2_rxpcsdprioout_phy(reserved_0_TB23_DP_RXPCS_IDX_7 DOWNTO rwait_count_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_23;
ch3_rxpcsdprioout_phy(reserved_0_TB23_DP_RXPCS_IDX_7 DOWNTO rwait_count_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_23;

ch0_rxpcsdprioout_phy(rwait_for_phfifo_cnt_DP_RXPCS_IDX_5 DOWNTO rfts_count_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_24;
ch1_rxpcsdprioout_phy(rwait_for_phfifo_cnt_DP_RXPCS_IDX_5 DOWNTO rfts_count_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_24;
ch2_rxpcsdprioout_phy(rwait_for_phfifo_cnt_DP_RXPCS_IDX_5 DOWNTO rfts_count_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_24;
ch3_rxpcsdprioout_phy(rwait_for_phfifo_cnt_DP_RXPCS_IDX_5 DOWNTO rfts_count_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_24;

ch0_rxpcsdprioout_phy(reserved_0_TB25_DP_RXPCS_IDX_4 DOWNTO rppm_meas_delay_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_25;
ch1_rxpcsdprioout_phy(reserved_0_TB25_DP_RXPCS_IDX_4 DOWNTO rppm_meas_delay_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_25;
ch2_rxpcsdprioout_phy(reserved_0_TB25_DP_RXPCS_IDX_4 DOWNTO rppm_meas_delay_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_25;
ch3_rxpcsdprioout_phy(reserved_0_TB25_DP_RXPCS_IDX_4 DOWNTO rppm_meas_delay_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_25;

ch0_rxpcsdprioout_phy(rphfifo_regmode_rx_DP_RXPCS_IDX_0 DOWNTO rauto_pc_en_cnt_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_26;
ch1_rxpcsdprioout_phy(rphfifo_regmode_rx_DP_RXPCS_IDX_0 DOWNTO rauto_pc_en_cnt_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_26;
ch2_rxpcsdprioout_phy(rphfifo_regmode_rx_DP_RXPCS_IDX_0 DOWNTO rauto_pc_en_cnt_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_26;
ch3_rxpcsdprioout_phy(rphfifo_regmode_rx_DP_RXPCS_IDX_0 DOWNTO rauto_pc_en_cnt_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_26;

ch0_rxpcsdprioout_phy(reserved_0_TB27_DP_RXPCS_IDX_3 DOWNTO rmask_count_DP_RXPCS_IDX_0) <= ch0_out_chnl_ctrl_27;
ch1_rxpcsdprioout_phy(reserved_0_TB27_DP_RXPCS_IDX_3 DOWNTO rmask_count_DP_RXPCS_IDX_0) <= ch1_out_chnl_ctrl_27;
ch2_rxpcsdprioout_phy(reserved_0_TB27_DP_RXPCS_IDX_3 DOWNTO rmask_count_DP_RXPCS_IDX_0) <= ch2_out_chnl_ctrl_27;
ch3_rxpcsdprioout_phy(reserved_0_TB27_DP_RXPCS_IDX_3 DOWNTO rmask_count_DP_RXPCS_IDX_0) <= ch3_out_chnl_ctrl_27;

--TXPMA
ch0_txpmadprioout_phy(rvod_sel_non_pcie_DP_TXPMA_IDX_2 DOWNTO rpowdnt_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_28;
ch1_txpmadprioout_phy(rvod_sel_non_pcie_DP_TXPMA_IDX_2 DOWNTO rpowdnt_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_28;
ch2_txpmadprioout_phy(rvod_sel_non_pcie_DP_TXPMA_IDX_2 DOWNTO rpowdnt_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_28;
ch3_txpmadprioout_phy(rvod_sel_non_pcie_DP_TXPMA_IDX_2 DOWNTO rpowdnt_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_28;
ch4_txpmadprioout_phy(rvod_sel_non_pcie_DP_TXPMA_IDX_2 DOWNTO rpowdnt_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_28;
ch5_txpmadprioout_phy(rvod_sel_non_pcie_DP_TXPMA_IDX_2 DOWNTO rpowdnt_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_28;

ch0_txpmadprioout_phy(rpre_em_1t_no_pcie_DP_TXPMA_IDX_4 DOWNTO reserved_0_TB29_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_29;
ch1_txpmadprioout_phy(rpre_em_1t_no_pcie_DP_TXPMA_IDX_4 DOWNTO reserved_0_TB29_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_29;
ch2_txpmadprioout_phy(rpre_em_1t_no_pcie_DP_TXPMA_IDX_4 DOWNTO reserved_0_TB29_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_29;
ch3_txpmadprioout_phy(rpre_em_1t_no_pcie_DP_TXPMA_IDX_4 DOWNTO reserved_0_TB29_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_29;
ch4_txpmadprioout_phy(rpre_em_1t_no_pcie_DP_TXPMA_IDX_4 DOWNTO reserved_0_TB29_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_29;
ch5_txpmadprioout_phy(rpre_em_1t_no_pcie_DP_TXPMA_IDX_4 DOWNTO reserved_0_TB29_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_29;

ch0_txpmadprioout_phy(reserved_0_TB30_DP_TXPMA_IDX_2 DOWNTO rpre_em_pt_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_30;
ch1_txpmadprioout_phy(reserved_0_TB30_DP_TXPMA_IDX_2 DOWNTO rpre_em_pt_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_30;
ch2_txpmadprioout_phy(reserved_0_TB30_DP_TXPMA_IDX_2 DOWNTO rpre_em_pt_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_30;
ch3_txpmadprioout_phy(reserved_0_TB30_DP_TXPMA_IDX_2 DOWNTO rpre_em_pt_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_30;
ch4_txpmadprioout_phy(reserved_0_TB30_DP_TXPMA_IDX_2 DOWNTO rpre_em_pt_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_30;
ch5_txpmadprioout_phy(reserved_0_TB30_DP_TXPMA_IDX_2 DOWNTO rpre_em_pt_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_30;

ch0_txpmadprioout_phy(rtx_term_sel_DP_TXPMA_IDX_2 DOWNTO rlowv_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_31;
ch1_txpmadprioout_phy(rtx_term_sel_DP_TXPMA_IDX_2 DOWNTO rlowv_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_31;
ch2_txpmadprioout_phy(rtx_term_sel_DP_TXPMA_IDX_2 DOWNTO rlowv_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_31;
ch3_txpmadprioout_phy(rtx_term_sel_DP_TXPMA_IDX_2 DOWNTO rlowv_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_31;
ch4_txpmadprioout_phy(rtx_term_sel_DP_TXPMA_IDX_2 DOWNTO rlowv_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_31;
ch5_txpmadprioout_phy(rtx_term_sel_DP_TXPMA_IDX_2 DOWNTO rlowv_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_31;

ch0_txpmadprioout_phy(r_dft_sel_DP_TXPMA_IDX_2 DOWNTO reserved_1_TB32_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_32;
ch1_txpmadprioout_phy(r_dft_sel_DP_TXPMA_IDX_2 DOWNTO reserved_1_TB32_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_32;
ch2_txpmadprioout_phy(r_dft_sel_DP_TXPMA_IDX_2 DOWNTO reserved_1_TB32_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_32;
ch3_txpmadprioout_phy(r_dft_sel_DP_TXPMA_IDX_2 DOWNTO reserved_1_TB32_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_32;
ch4_txpmadprioout_phy(r_dft_sel_DP_TXPMA_IDX_2 DOWNTO reserved_1_TB32_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_32;
ch5_txpmadprioout_phy(r_dft_sel_DP_TXPMA_IDX_2 DOWNTO reserved_1_TB32_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_32;

-- does not hurt for tx_pma to receiver clock_divider cram - bit[7] goes to rx_pma - manual section
-- ch0_txpmadprioout_phy(rcgb_x_en_DP_TXPMA_IDX_1 DOWNTO reserved_0_TB33_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_33;
-- ch1_txpmadprioout_phy(rcgb_x_en_DP_TXPMA_IDX_1 DOWNTO reserved_0_TB33_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_33;
-- ch2_txpmadprioout_phy(rcgb_x_en_DP_TXPMA_IDX_1 DOWNTO reserved_0_TB33_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_33;
-- ch3_txpmadprioout_phy(rcgb_x_en_DP_TXPMA_IDX_1 DOWNTO reserved_0_TB33_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_33;
-- ch4_txpmadprioout_phy(rcgb_x_en_DP_TXPMA_IDX_1 DOWNTO reserved_0_TB33_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_33;
-- ch5_txpmadprioout_phy(rcgb_x_en_DP_TXPMA_IDX_1 DOWNTO reserved_0_TB33_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_33;

ch0_txpmadprioout_phy(riqclk_sel_DP_TXPMA_IDX_1 DOWNTO reserved_1_TB34_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_34;
ch1_txpmadprioout_phy(riqclk_sel_DP_TXPMA_IDX_1 DOWNTO reserved_1_TB34_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_34;
ch2_txpmadprioout_phy(riqclk_sel_DP_TXPMA_IDX_1 DOWNTO reserved_1_TB34_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_34;
ch3_txpmadprioout_phy(riqclk_sel_DP_TXPMA_IDX_1 DOWNTO reserved_1_TB34_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_34;
ch4_txpmadprioout_phy(riqclk_sel_DP_TXPMA_IDX_1 DOWNTO reserved_1_TB34_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_34;
ch5_txpmadprioout_phy(riqclk_sel_DP_TXPMA_IDX_1 DOWNTO reserved_1_TB34_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_34;

ch0_txpmadprioout_phy(rpma_reserved_0_TB35_DP_TXPMA_IDX_15 DOWNTO rpma_reserved_0_TB35_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_35;
ch1_txpmadprioout_phy(rpma_reserved_0_TB35_DP_TXPMA_IDX_15 DOWNTO rpma_reserved_0_TB35_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_35;
ch2_txpmadprioout_phy(rpma_reserved_0_TB35_DP_TXPMA_IDX_15 DOWNTO rpma_reserved_0_TB35_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_35;
ch3_txpmadprioout_phy(rpma_reserved_0_TB35_DP_TXPMA_IDX_15 DOWNTO rpma_reserved_0_TB35_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_35;
ch4_txpmadprioout_phy(rpma_reserved_0_TB35_DP_TXPMA_IDX_15 DOWNTO rpma_reserved_0_TB35_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_35;
ch5_txpmadprioout_phy(rpma_reserved_0_TB35_DP_TXPMA_IDX_15 DOWNTO rpma_reserved_0_TB35_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_35;

ch0_rxpmadprioout_phy(rrx_lst_DP_RXPMA_IDX_4 DOWNTO rrx_term_sel_DP_RXPMA_IDX_0) <= ch0_out_chnl_ctrl_36;
ch1_rxpmadprioout_phy(rrx_lst_DP_RXPMA_IDX_4 DOWNTO rrx_term_sel_DP_RXPMA_IDX_0) <= ch1_out_chnl_ctrl_36;
ch2_rxpmadprioout_phy(rrx_lst_DP_RXPMA_IDX_4 DOWNTO rrx_term_sel_DP_RXPMA_IDX_0) <= ch2_out_chnl_ctrl_36;
ch3_rxpmadprioout_phy(rrx_lst_DP_RXPMA_IDX_4 DOWNTO rrx_term_sel_DP_RXPMA_IDX_0) <= ch3_out_chnl_ctrl_36;
ch4_rxpmadprioout_phy(rrx_lst_DP_RXPMA_IDX_4 DOWNTO rrx_term_sel_DP_RXPMA_IDX_0) <= ch4_out_chnl_ctrl_36;
ch5_rxpmadprioout_phy(rrx_lst_DP_RXPMA_IDX_4 DOWNTO rrx_term_sel_DP_RXPMA_IDX_0) <= ch5_out_chnl_ctrl_36;

ch0_rxpmadprioout_phy(rrx_sdlv_DP_RXPMA_IDX_3 DOWNTO rrxurstpma_DP_RXPMA_IDX_0) <= ch0_out_chnl_ctrl_37;
ch1_rxpmadprioout_phy(rrx_sdlv_DP_RXPMA_IDX_3 DOWNTO rrxurstpma_DP_RXPMA_IDX_0) <= ch1_out_chnl_ctrl_37;
ch2_rxpmadprioout_phy(rrx_sdlv_DP_RXPMA_IDX_3 DOWNTO rrxurstpma_DP_RXPMA_IDX_0) <= ch2_out_chnl_ctrl_37;
ch3_rxpmadprioout_phy(rrx_sdlv_DP_RXPMA_IDX_3 DOWNTO rrxurstpma_DP_RXPMA_IDX_0) <= ch3_out_chnl_ctrl_37;
ch4_rxpmadprioout_phy(rrx_sdlv_DP_RXPMA_IDX_3 DOWNTO rrxurstpma_DP_RXPMA_IDX_0) <= ch4_out_chnl_ctrl_37;
ch5_rxpmadprioout_phy(rrx_sdlv_DP_RXPMA_IDX_3 DOWNTO rrxurstpma_DP_RXPMA_IDX_0) <= ch5_out_chnl_ctrl_37;

ch0_rxpmadprioout_phy(rrx_sd_on_DP_RXPMA_IDX_3 DOWNTO reserved_0_TB38_DP_RXPMA_IDX_0) <= ch0_out_chnl_ctrl_38;
ch1_rxpmadprioout_phy(rrx_sd_on_DP_RXPMA_IDX_3 DOWNTO reserved_0_TB38_DP_RXPMA_IDX_0) <= ch1_out_chnl_ctrl_38;
ch2_rxpmadprioout_phy(rrx_sd_on_DP_RXPMA_IDX_3 DOWNTO reserved_0_TB38_DP_RXPMA_IDX_0) <= ch2_out_chnl_ctrl_38;
ch3_rxpmadprioout_phy(rrx_sd_on_DP_RXPMA_IDX_3 DOWNTO reserved_0_TB38_DP_RXPMA_IDX_0) <= ch3_out_chnl_ctrl_38;
ch4_rxpmadprioout_phy(rrx_sd_on_DP_RXPMA_IDX_3 DOWNTO reserved_0_TB38_DP_RXPMA_IDX_0) <= ch4_out_chnl_ctrl_38;
ch5_rxpmadprioout_phy(rrx_sd_on_DP_RXPMA_IDX_3 DOWNTO reserved_0_TB38_DP_RXPMA_IDX_0) <= ch5_out_chnl_ctrl_38;

ch0_rxplldprioout_phy(rcru_div2_DP_PLL_IDX_0 DOWNTO rcru_pdbwctrl_DP_PLL_IDX_0) <= ch0_out_chnl_ctrl_39;
ch1_rxplldprioout_phy(rcru_div2_DP_PLL_IDX_0 DOWNTO rcru_pdbwctrl_DP_PLL_IDX_0) <= ch1_out_chnl_ctrl_39;
ch2_rxplldprioout_phy(rcru_div2_DP_PLL_IDX_0 DOWNTO rcru_pdbwctrl_DP_PLL_IDX_0) <= ch2_out_chnl_ctrl_39;
ch3_rxplldprioout_phy(rcru_div2_DP_PLL_IDX_0 DOWNTO rcru_pdbwctrl_DP_PLL_IDX_0) <= ch3_out_chnl_ctrl_39;
ch4_rxtxplldprioout_phy(rcru_div2_DP_PLL_IDX_0 DOWNTO rcru_pdbwctrl_DP_PLL_IDX_0) <= ch4_out_chnl_ctrl_39;
ch5_rxtxplldprioout_phy(rcru_div2_DP_PLL_IDX_0 DOWNTO rcru_pdbwctrl_DP_PLL_IDX_0) <= ch5_out_chnl_ctrl_39;

ch0_rxplldprioout_phy(rcru_rlbk_DP_PLL_IDX_0 DOWNTO reserved_0_TB40_DP_PLL_IDX_0) <= ch0_out_chnl_ctrl_40;
ch1_rxplldprioout_phy(rcru_rlbk_DP_PLL_IDX_0 DOWNTO reserved_0_TB40_DP_PLL_IDX_0) <= ch1_out_chnl_ctrl_40;
ch2_rxplldprioout_phy(rcru_rlbk_DP_PLL_IDX_0 DOWNTO reserved_0_TB40_DP_PLL_IDX_0) <= ch2_out_chnl_ctrl_40;
ch3_rxplldprioout_phy(rcru_rlbk_DP_PLL_IDX_0 DOWNTO reserved_0_TB40_DP_PLL_IDX_0) <= ch3_out_chnl_ctrl_40;
ch4_rxtxplldprioout_phy(rcru_rlbk_DP_PLL_IDX_0 DOWNTO reserved_0_TB40_DP_PLL_IDX_0) <= ch4_out_chnl_ctrl_40;
ch5_rxtxplldprioout_phy(rcru_rlbk_DP_PLL_IDX_0 DOWNTO reserved_0_TB40_DP_PLL_IDX_0) <= ch5_out_chnl_ctrl_40;

ch0_rxplldprioout_phy(rcp_mode_DP_PLL_IDX_0 DOWNTO rcru_rgla_isel_DP_PLL_IDX_0) <= ch0_out_chnl_ctrl_41;
ch1_rxplldprioout_phy(rcp_mode_DP_PLL_IDX_0 DOWNTO rcru_rgla_isel_DP_PLL_IDX_0) <= ch1_out_chnl_ctrl_41;
ch2_rxplldprioout_phy(rcp_mode_DP_PLL_IDX_0 DOWNTO rcru_rgla_isel_DP_PLL_IDX_0) <= ch2_out_chnl_ctrl_41;
ch3_rxplldprioout_phy(rcp_mode_DP_PLL_IDX_0 DOWNTO rcru_rgla_isel_DP_PLL_IDX_0) <= ch3_out_chnl_ctrl_41;
ch4_rxtxplldprioout_phy(rcp_mode_DP_PLL_IDX_0 DOWNTO rcru_rgla_isel_DP_PLL_IDX_0) <= ch4_out_chnl_ctrl_41;
ch5_rxtxplldprioout_phy(rcp_mode_DP_PLL_IDX_0 DOWNTO rcru_rgla_isel_DP_PLL_IDX_0) <= ch5_out_chnl_ctrl_41;

ch0_rxplldprioout_phy(rcru_pdof_0i_DP_PLL_IDX_3 DOWNTO rcru_pdof_270i_DP_PLL_IDX_0) <= ch0_out_chnl_ctrl_42;
ch1_rxplldprioout_phy(rcru_pdof_0i_DP_PLL_IDX_3 DOWNTO rcru_pdof_270i_DP_PLL_IDX_0) <= ch1_out_chnl_ctrl_42;
ch2_rxplldprioout_phy(rcru_pdof_0i_DP_PLL_IDX_3 DOWNTO rcru_pdof_270i_DP_PLL_IDX_0) <= ch2_out_chnl_ctrl_42;
ch3_rxplldprioout_phy(rcru_pdof_0i_DP_PLL_IDX_3 DOWNTO rcru_pdof_270i_DP_PLL_IDX_0) <= ch3_out_chnl_ctrl_42;
ch4_rxtxplldprioout_phy(rcru_pdof_0i_DP_PLL_IDX_3 DOWNTO rcru_pdof_270i_DP_PLL_IDX_0) <= ch4_out_chnl_ctrl_42;
ch5_rxtxplldprioout_phy(rcru_pdof_0i_DP_PLL_IDX_3 DOWNTO rcru_pdof_270i_DP_PLL_IDX_0) <= ch5_out_chnl_ctrl_42;

-- reserved
ch0_rxpmadprioout_phy(reserved_0_TB43_DP_RXPMA_IDX_7 DOWNTO reye_monitor_DP_RXPMA_IDX_0) <= ch0_out_chnl_ctrl_43;
ch1_rxpmadprioout_phy(reserved_0_TB43_DP_RXPMA_IDX_7 DOWNTO reye_monitor_DP_RXPMA_IDX_0) <= ch1_out_chnl_ctrl_43;
ch2_rxpmadprioout_phy(reserved_0_TB43_DP_RXPMA_IDX_7 DOWNTO reye_monitor_DP_RXPMA_IDX_0) <= ch2_out_chnl_ctrl_43;
ch3_rxpmadprioout_phy(reserved_0_TB43_DP_RXPMA_IDX_7 DOWNTO reye_monitor_DP_RXPMA_IDX_0) <= ch3_out_chnl_ctrl_43;
ch4_rxpmadprioout_phy(reserved_0_TB43_DP_RXPMA_IDX_7 DOWNTO reye_monitor_DP_RXPMA_IDX_0) <= ch4_out_chnl_ctrl_43;
ch5_rxpmadprioout_phy(reserved_0_TB43_DP_RXPMA_IDX_7 DOWNTO reye_monitor_DP_RXPMA_IDX_0) <= ch5_out_chnl_ctrl_43;

ch0_rxpmadprioout_phy(rpma_reserved_0_TB44_DP_RXPMA_IDX_15 DOWNTO rpma_reserved_0_TB44_DP_RXPMA_IDX_0) <= ch0_out_chnl_ctrl_44;
ch1_rxpmadprioout_phy(rpma_reserved_0_TB44_DP_RXPMA_IDX_15 DOWNTO rpma_reserved_0_TB44_DP_RXPMA_IDX_0) <= ch1_out_chnl_ctrl_44;
ch2_rxpmadprioout_phy(rpma_reserved_0_TB44_DP_RXPMA_IDX_15 DOWNTO rpma_reserved_0_TB44_DP_RXPMA_IDX_0) <= ch2_out_chnl_ctrl_44;
ch3_rxpmadprioout_phy(rpma_reserved_0_TB44_DP_RXPMA_IDX_15 DOWNTO rpma_reserved_0_TB44_DP_RXPMA_IDX_0) <= ch3_out_chnl_ctrl_44;
ch4_rxpmadprioout_phy(rpma_reserved_0_TB44_DP_RXPMA_IDX_15 DOWNTO rpma_reserved_0_TB44_DP_RXPMA_IDX_0) <= ch4_out_chnl_ctrl_44;
ch5_rxpmadprioout_phy(rpma_reserved_0_TB44_DP_RXPMA_IDX_15 DOWNTO rpma_reserved_0_TB44_DP_RXPMA_IDX_0) <= ch5_out_chnl_ctrl_44;

ch0_rxpmadprioout_phy(rpma_doublewidth_rx_DP_RXPMA_IDX_0 DOWNTO rppm_cnt_reset_DP_RXPMA_IDX_0) <= ch0_out_chnl_ctrl_45;
ch1_rxpmadprioout_phy(rpma_doublewidth_rx_DP_RXPMA_IDX_0 DOWNTO rppm_cnt_reset_DP_RXPMA_IDX_0) <= ch1_out_chnl_ctrl_45;
ch2_rxpmadprioout_phy(rpma_doublewidth_rx_DP_RXPMA_IDX_0 DOWNTO rppm_cnt_reset_DP_RXPMA_IDX_0) <= ch2_out_chnl_ctrl_45;
ch3_rxpmadprioout_phy(rpma_doublewidth_rx_DP_RXPMA_IDX_0 DOWNTO rppm_cnt_reset_DP_RXPMA_IDX_0) <= ch3_out_chnl_ctrl_45;
ch4_rxpmadprioout_phy(rpma_doublewidth_rx_DP_RXPMA_IDX_0 DOWNTO rppm_cnt_reset_DP_RXPMA_IDX_0) <= ch4_out_chnl_ctrl_45;
ch5_rxpmadprioout_phy(rpma_doublewidth_rx_DP_RXPMA_IDX_0 DOWNTO rppm_cnt_reset_DP_RXPMA_IDX_0) <= ch5_out_chnl_ctrl_45;

ch0_rxpmadprioout_phy(r_dfe_1t_DP_RXPMA_IDX_2 DOWNTO reserved_0_TB46_DP_RXPMA_IDX_0) <= ch0_out_chnl_ctrl_46;
ch1_rxpmadprioout_phy(r_dfe_1t_DP_RXPMA_IDX_2 DOWNTO reserved_0_TB46_DP_RXPMA_IDX_0) <= ch1_out_chnl_ctrl_46;
ch2_rxpmadprioout_phy(r_dfe_1t_DP_RXPMA_IDX_2 DOWNTO reserved_0_TB46_DP_RXPMA_IDX_0) <= ch2_out_chnl_ctrl_46;
ch3_rxpmadprioout_phy(r_dfe_1t_DP_RXPMA_IDX_2 DOWNTO reserved_0_TB46_DP_RXPMA_IDX_0) <= ch3_out_chnl_ctrl_46;
ch4_rxpmadprioout_phy(r_dfe_1t_DP_RXPMA_IDX_2 DOWNTO reserved_0_TB46_DP_RXPMA_IDX_0) <= ch4_out_chnl_ctrl_46;
ch5_rxpmadprioout_phy(r_dfe_1t_DP_RXPMA_IDX_2 DOWNTO reserved_0_TB46_DP_RXPMA_IDX_0) <= ch5_out_chnl_ctrl_46;

ch0_rxpmadprioout_phy(reserved_0_TB47_DP_RXPMA_IDX_0 DOWNTO reqv_set_DP_RXPMA_IDX_0) <= ch0_out_chnl_ctrl_47;
ch1_rxpmadprioout_phy(reserved_0_TB47_DP_RXPMA_IDX_0 DOWNTO reqv_set_DP_RXPMA_IDX_0) <= ch1_out_chnl_ctrl_47;
ch2_rxpmadprioout_phy(reserved_0_TB47_DP_RXPMA_IDX_0 DOWNTO reqv_set_DP_RXPMA_IDX_0) <= ch2_out_chnl_ctrl_47;
ch3_rxpmadprioout_phy(reserved_0_TB47_DP_RXPMA_IDX_0 DOWNTO reqv_set_DP_RXPMA_IDX_0) <= ch3_out_chnl_ctrl_47;
ch4_rxpmadprioout_phy(reserved_0_TB47_DP_RXPMA_IDX_0 DOWNTO reqv_set_DP_RXPMA_IDX_0) <= ch4_out_chnl_ctrl_47;
ch5_rxpmadprioout_phy(reserved_0_TB47_DP_RXPMA_IDX_0 DOWNTO reqv_set_DP_RXPMA_IDX_0) <= ch5_out_chnl_ctrl_47;

ch0_rxpmadprioout_phy(rlock_lf_ovd_DP_RXPMA_IDX_0 DOWNTO rdc_freq_DP_RXPMA_IDX_0) <= ch0_out_chnl_ctrl_48;
ch1_rxpmadprioout_phy(rlock_lf_ovd_DP_RXPMA_IDX_0 DOWNTO rdc_freq_DP_RXPMA_IDX_0) <= ch1_out_chnl_ctrl_48;
ch2_rxpmadprioout_phy(rlock_lf_ovd_DP_RXPMA_IDX_0 DOWNTO rdc_freq_DP_RXPMA_IDX_0) <= ch2_out_chnl_ctrl_48;
ch3_rxpmadprioout_phy(rlock_lf_ovd_DP_RXPMA_IDX_0 DOWNTO rdc_freq_DP_RXPMA_IDX_0) <= ch3_out_chnl_ctrl_48;
--ch4_rxpmadprioout_phy(rlock_lf_ovd_DP_RXPMA_IDX_0 DOWNTO rdc_freq_DP_RXPMA_IDX_0) <= ch4_out_chnl_ctrl_48;
--ch5_rxpmadprioout_phy(rlock_lf_ovd_DP_RXPMA_IDX_0 DOWNTO rdc_freq_DP_RXPMA_IDX_0) <= ch5_out_chnl_ctrl_48;

ch0_rxpmadprioout_phy(rhyst_hf_DP_RXPMA_IDX_2 DOWNTO rrgen_vod_DP_RXPMA_IDX_0) <= ch0_out_chnl_ctrl_49;
ch1_rxpmadprioout_phy(rhyst_hf_DP_RXPMA_IDX_2 DOWNTO rrgen_vod_DP_RXPMA_IDX_0) <= ch1_out_chnl_ctrl_49;
ch2_rxpmadprioout_phy(rhyst_hf_DP_RXPMA_IDX_2 DOWNTO rrgen_vod_DP_RXPMA_IDX_0) <= ch2_out_chnl_ctrl_49;
ch3_rxpmadprioout_phy(rhyst_hf_DP_RXPMA_IDX_2 DOWNTO rrgen_vod_DP_RXPMA_IDX_0) <= ch3_out_chnl_ctrl_49;
--ch4_rxpmadprioout_phy(rhyst_hf_DP_RXPMA_IDX_2 DOWNTO rrgen_vod_DP_RXPMA_IDX_0) <= ch4_out_chnl_ctrl_49;
--ch5_rxpmadprioout_phy(rhyst_hf_DP_RXPMA_IDX_2 DOWNTO rrgen_vod_DP_RXPMA_IDX_0) <= ch5_out_chnl_ctrl_49;

ch0_rxpmadprioout_phy(rrgen_bw_DP_RXPMA_IDX_1 DOWNTO radce_pdb_DP_RXPMA_IDX_0) <= ch0_out_chnl_ctrl_50;
ch1_rxpmadprioout_phy(rrgen_bw_DP_RXPMA_IDX_1 DOWNTO radce_pdb_DP_RXPMA_IDX_0) <= ch1_out_chnl_ctrl_50;
ch2_rxpmadprioout_phy(rrgen_bw_DP_RXPMA_IDX_1 DOWNTO radce_pdb_DP_RXPMA_IDX_0) <= ch2_out_chnl_ctrl_50;
ch3_rxpmadprioout_phy(rrgen_bw_DP_RXPMA_IDX_1 DOWNTO radce_pdb_DP_RXPMA_IDX_0) <= ch3_out_chnl_ctrl_50;
--ch4_rxpmadprioout_phy(rrgen_bw_DP_RXPMA_IDX_1 DOWNTO radce_pdb_DP_RXPMA_IDX_0) <= ch4_out_chnl_ctrl_50;
--ch5_rxpmadprioout_phy(rrgen_bw_DP_RXPMA_IDX_1 DOWNTO radce_pdb_DP_RXPMA_IDX_0) <= ch5_out_chnl_ctrl_50;

ch0_rxpmadprioout_phy(reserved_0_TB51_DP_RXPMA_IDX_0 DOWNTO radce_hflck_DP_RXPMA_IDX_0) <= ch0_out_chnl_ctrl_51;
ch1_rxpmadprioout_phy(reserved_0_TB51_DP_RXPMA_IDX_0 DOWNTO radce_hflck_DP_RXPMA_IDX_0) <= ch1_out_chnl_ctrl_51;
ch2_rxpmadprioout_phy(reserved_0_TB51_DP_RXPMA_IDX_0 DOWNTO radce_hflck_DP_RXPMA_IDX_0) <= ch2_out_chnl_ctrl_51;
ch3_rxpmadprioout_phy(reserved_0_TB51_DP_RXPMA_IDX_0 DOWNTO radce_hflck_DP_RXPMA_IDX_0) <= ch3_out_chnl_ctrl_51;
--ch4_rxpmadprioout_phy(reserved_0_TB51_DP_RXPMA_IDX_0 DOWNTO radce_hflck_DP_RXPMA_IDX_0) <= ch4_out_chnl_ctrl_51;
--ch5_rxpmadprioout_phy(reserved_0_TB51_DP_RXPMA_IDX_0 DOWNTO radce_hflck_DP_RXPMA_IDX_0) <= ch5_out_chnl_ctrl_51;

ch0_rxpmadprioout_phy(reserved_0_TB52_DP_RXPMA_IDX_0 DOWNTO radce_lflck_DP_RXPMA_IDX_0) <= ch0_out_chnl_ctrl_52;
ch1_rxpmadprioout_phy(reserved_0_TB52_DP_RXPMA_IDX_0 DOWNTO radce_lflck_DP_RXPMA_IDX_0) <= ch1_out_chnl_ctrl_52;
ch2_rxpmadprioout_phy(reserved_0_TB52_DP_RXPMA_IDX_0 DOWNTO radce_lflck_DP_RXPMA_IDX_0) <= ch2_out_chnl_ctrl_52;
ch3_rxpmadprioout_phy(reserved_0_TB52_DP_RXPMA_IDX_0 DOWNTO radce_lflck_DP_RXPMA_IDX_0) <= ch3_out_chnl_ctrl_52;
--ch4_rxpmadprioout_phy(reserved_0_TB52_DP_RXPMA_IDX_0 DOWNTO radce_lflck_DP_RXPMA_IDX_0) <= ch4_out_chnl_ctrl_52;
--ch5_rxpmadprioout_phy(reserved_0_TB52_DP_RXPMA_IDX_0 DOWNTO radce_lflck_DP_RXPMA_IDX_0) <= ch5_out_chnl_ctrl_52;

ch0_rxpmadprioout_phy(reserved_0_TB53_DP_RXPMA_IDX_5 DOWNTO radce_digital_DP_RXPMA_IDX_0) <= ch0_out_chnl_ctrl_53;
ch1_rxpmadprioout_phy(reserved_0_TB53_DP_RXPMA_IDX_5 DOWNTO radce_digital_DP_RXPMA_IDX_0) <= ch1_out_chnl_ctrl_53;
ch2_rxpmadprioout_phy(reserved_0_TB53_DP_RXPMA_IDX_5 DOWNTO radce_digital_DP_RXPMA_IDX_0) <= ch2_out_chnl_ctrl_53;
ch3_rxpmadprioout_phy(reserved_0_TB53_DP_RXPMA_IDX_5 DOWNTO radce_digital_DP_RXPMA_IDX_0) <= ch3_out_chnl_ctrl_53;
--ch4_rxpmadprioout_phy(reserved_0_TB53_DP_RXPMA_IDX_5 DOWNTO radce_digital_DP_RXPMA_IDX_0) <= ch4_out_chnl_ctrl_53;
--ch5_rxpmadprioout_phy(reserved_0_TB53_DP_RXPMA_IDX_5 DOWNTO radce_digital_DP_RXPMA_IDX_0) <= ch5_out_chnl_ctrl_53;

---------------------------------------------------------------
-- Manual section due to one ICD CRAM mapped to multiple Atoms
---------------------------------------------------------------
-- RX_PCS -----------------------------------------------------
ch0_rxpcsdprioout_phy(rpmadwidth_rx_DP_RXPCS_IDX) <= ch0_out_chnl_ctrl_45(14);
ch1_rxpcsdprioout_phy(rpmadwidth_rx_DP_RXPCS_IDX) <= ch1_out_chnl_ctrl_45(14);
ch2_rxpcsdprioout_phy(rpmadwidth_rx_DP_RXPCS_IDX) <= ch2_out_chnl_ctrl_45(14);
ch3_rxpcsdprioout_phy(rpmadwidth_rx_DP_RXPCS_IDX) <= ch3_out_chnl_ctrl_45(14);

ch0_rxpcsdprioout_phy(rpma_doublewidth_rx_DP_RXPCS_IDX) <= ch0_out_chnl_ctrl_45(15);
ch1_rxpcsdprioout_phy(rpma_doublewidth_rx_DP_RXPCS_IDX) <= ch1_out_chnl_ctrl_45(15);
ch2_rxpcsdprioout_phy(rpma_doublewidth_rx_DP_RXPCS_IDX) <= ch2_out_chnl_ctrl_45(15);
ch3_rxpcsdprioout_phy(rpma_doublewidth_rx_DP_RXPCS_IDX) <= ch3_out_chnl_ctrl_45(15);

-- ----------------------------------------------------------------------------------------------------------------
-- Manual section - global CRAMs to individual channels
-- ----------------------------------------------------------------------------------------------------------------

-- global ctrl 1 - centrl_ctrl_44
ch0_rxpcsdprioout_phy(rendec_data_sel_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_1(6);
ch1_rxpcsdprioout_phy(rendec_data_sel_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_1(6);
ch2_rxpcsdprioout_phy(rendec_data_sel_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_1(6);
ch3_rxpcsdprioout_phy(rendec_data_sel_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_1(6);

ch0_rxpcsdprioout_phy(rdeskewen_DP_RXPCS_IDX) <= cmu_out_centrl_global_1(2);
ch1_rxpcsdprioout_phy(rdeskewen_DP_RXPCS_IDX) <= cmu_out_centrl_global_1(2);
ch2_rxpcsdprioout_phy(rdeskewen_DP_RXPCS_IDX) <= cmu_out_centrl_global_1(2);
ch3_rxpcsdprioout_phy(rdeskewen_DP_RXPCS_IDX) <= cmu_out_centrl_global_1(2);

ch0_rxpcsdprioout_phy(rindv_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_1(0);
ch1_rxpcsdprioout_phy(rindv_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_1(0);
ch2_rxpcsdprioout_phy(rindv_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_1(0);
ch3_rxpcsdprioout_phy(rindv_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_1(0);

-- global ctrl 2 - centrl_ctrl_45
ch0_rxpcsdprioout_phy(rdskposdisp_DP_RXPCS_IDX) <= cmu_out_centrl_global_2(10);
ch1_rxpcsdprioout_phy(rdskposdisp_DP_RXPCS_IDX) <= cmu_out_centrl_global_2(10);
ch2_rxpcsdprioout_phy(rdskposdisp_DP_RXPCS_IDX) <= cmu_out_centrl_global_2(10);
ch3_rxpcsdprioout_phy(rdskposdisp_DP_RXPCS_IDX) <= cmu_out_centrl_global_2(10);

-- global ctrl 3 - centrl_ctrl_46
ch0_rxpcsdprioout_phy(rmaster_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_3(3);
ch1_rxpcsdprioout_phy(rmaster_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_3(3);
ch2_rxpcsdprioout_phy(rmaster_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_3(3);
ch3_rxpcsdprioout_phy(rmaster_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_3(3);

ch0_rxpcsdprioout_phy(rmaster_up_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_3(2);
ch1_rxpcsdprioout_phy(rmaster_up_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_3(2);
ch2_rxpcsdprioout_phy(rmaster_up_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_3(2);
ch3_rxpcsdprioout_phy(rmaster_up_rx_DP_RXPCS_IDX) <= cmu_out_centrl_global_3(2);

-- TX_PCS -----------------------------------------------------
ch0_txpcsdprioout_phy(rfreq_sel_DP_TXPCS_IDX) <= ch0_out_chnl_ctrl_16(0);
ch1_txpcsdprioout_phy(rfreq_sel_DP_TXPCS_IDX) <= ch1_out_chnl_ctrl_16(0);
ch2_txpcsdprioout_phy(rfreq_sel_DP_TXPCS_IDX) <= ch2_out_chnl_ctrl_16(0);
ch3_txpcsdprioout_phy(rfreq_sel_DP_TXPCS_IDX) <= ch3_out_chnl_ctrl_16(0);

ch0_txpcsdprioout_phy(rauto_speed_ena_DP_TXPCS_IDX) <= ch0_out_chnl_ctrl_16(1);
ch1_txpcsdprioout_phy(rauto_speed_ena_DP_TXPCS_IDX) <= ch1_out_chnl_ctrl_16(1);
ch2_txpcsdprioout_phy(rauto_speed_ena_DP_TXPCS_IDX) <= ch2_out_chnl_ctrl_16(1);
ch3_txpcsdprioout_phy(rauto_speed_ena_DP_TXPCS_IDX) <= ch3_out_chnl_ctrl_16(1);

ch0_txpcsdprioout_phy(rhip_ena_DP_TXPCS_IDX) <= ch0_out_chnl_ctrl_16(2);
ch1_txpcsdprioout_phy(rhip_ena_DP_TXPCS_IDX) <= ch1_out_chnl_ctrl_16(2);
ch2_txpcsdprioout_phy(rhip_ena_DP_TXPCS_IDX) <= ch2_out_chnl_ctrl_16(2);
ch3_txpcsdprioout_phy(rhip_ena_DP_TXPCS_IDX) <= ch3_out_chnl_ctrl_16(2);

ch0_txpcsdprioout_phy(rpma_doublewidth_tx_DP_TXPCS_IDX) <= ch0_out_chnl_ctrl_33(10);
ch1_txpcsdprioout_phy(rpma_doublewidth_tx_DP_TXPCS_IDX) <= ch1_out_chnl_ctrl_33(10);
ch2_txpcsdprioout_phy(rpma_doublewidth_tx_DP_TXPCS_IDX) <= ch2_out_chnl_ctrl_33(10);
ch3_txpcsdprioout_phy(rpma_doublewidth_tx_DP_TXPCS_IDX) <= ch3_out_chnl_ctrl_33(10);

ch0_txpcsdprioout_phy(rpmadwidth_tx_DP_TXPCS_IDX) <= ch0_out_chnl_ctrl_33(9);
ch1_txpcsdprioout_phy(rpmadwidth_tx_DP_TXPCS_IDX) <= ch1_out_chnl_ctrl_33(9);
ch2_txpcsdprioout_phy(rpmadwidth_tx_DP_TXPCS_IDX) <= ch2_out_chnl_ctrl_33(9);
ch3_txpcsdprioout_phy(rpmadwidth_tx_DP_TXPCS_IDX) <= ch3_out_chnl_ctrl_33(9);

-- global control 1 - cetnrl_ctrl_44
ch0_txpcsdprioout_phy(rendec_data_sel_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_1(7);
ch1_txpcsdprioout_phy(rendec_data_sel_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_1(7);
ch2_txpcsdprioout_phy(rendec_data_sel_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_1(7);
ch3_txpcsdprioout_phy(rendec_data_sel_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_1(7);

ch0_txpcsdprioout_phy(rindv_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_1(1);
ch1_txpcsdprioout_phy(rindv_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_1(1);
ch2_txpcsdprioout_phy(rindv_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_1(1);
ch3_txpcsdprioout_phy(rindv_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_1(1);

-- global control 3 - cetnrl_ctrl_46
ch0_txpcsdprioout_phy(rmaster_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_3(1);
ch1_txpcsdprioout_phy(rmaster_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_3(1);
ch2_txpcsdprioout_phy(rmaster_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_3(1);
ch3_txpcsdprioout_phy(rmaster_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_3(1);

ch0_txpcsdprioout_phy(rmaster_up_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_3(0);
ch1_txpcsdprioout_phy(rmaster_up_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_3(0);
ch2_txpcsdprioout_phy(rmaster_up_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_3(0);
ch3_txpcsdprioout_phy(rmaster_up_tx_DP_TXPCS_IDX) <= cmu_out_centrl_global_3(0);

-- global control 2 - cetnrl_ctrl_44 to central clock divider only
ch4_cmudividerdprioout_phy(rfreerun_centrl_DP_CLOCK_DIV_IDX) <= cmu_out_centrl_global_2(15);
ch5_cmudividerdprioout_phy(rfreerun_centrl_DP_CLOCK_DIV_IDX) <= cmu_out_centrl_global_2(15);

ch4_cmudividerdprioout_phy(rcentrl_clk_sel_DP_CLOCK_DIV_IDX) <= cmu_out_centrl_global_2(14);
ch5_cmudividerdprioout_phy(rcentrl_clk_sel_DP_CLOCK_DIV_IDX) <= cmu_out_centrl_global_2(14);

ch4_cmudividerdprioout_phy(rrefclk_out_div2_DP_CLOCK_DIV_IDX) <= cmu_out_centrl_global_2(13);
ch5_cmudividerdprioout_phy(rrefclk_out_div2_DP_CLOCK_DIV_IDX) <= cmu_out_centrl_global_2(13);

-- RX_PMA ---------------------------------------------------------
ch0_rxpmadprioout_phy(rs_lpbk_DP_RXPMA_IDX) <= ch0_out_chnl_ctrl_33(7);
ch1_rxpmadprioout_phy(rs_lpbk_DP_RXPMA_IDX) <= ch1_out_chnl_ctrl_33(7);
ch2_rxpmadprioout_phy(rs_lpbk_DP_RXPMA_IDX) <= ch2_out_chnl_ctrl_33(7);
ch3_rxpmadprioout_phy(rs_lpbk_DP_RXPMA_IDX) <= ch3_out_chnl_ctrl_33(7);
ch4_rxpmadprioout_phy(rs_lpbk_DP_RXPMA_IDX) <= ch4_out_chnl_ctrl_33(7);
ch5_rxpmadprioout_phy(rs_lpbk_DP_RXPMA_IDX) <= ch5_out_chnl_ctrl_33(7);

ch0_rxpmadprioout_phy(rrevlb_sw_DP_RXPMA_IDX) <= ch0_out_chnl_ctrl_34(10);
ch1_rxpmadprioout_phy(rrevlb_sw_DP_RXPMA_IDX) <= ch1_out_chnl_ctrl_34(10);
ch2_rxpmadprioout_phy(rrevlb_sw_DP_RXPMA_IDX) <= ch2_out_chnl_ctrl_34(10);
ch3_rxpmadprioout_phy(rrevlb_sw_DP_RXPMA_IDX) <= ch3_out_chnl_ctrl_34(10);
ch4_rxpmadprioout_phy(rrevlb_sw_DP_RXPMA_IDX) <= ch2_out_chnl_ctrl_34(10);
ch5_rxpmadprioout_phy(rrevlb_sw_DP_RXPMA_IDX) <= ch3_out_chnl_ctrl_34(10);

-- table40[15] = rcru_rlbk (revere_lpbk) using rs_lpbk_DP_IDX to map to tx_pam.rtx_rlpbk RTL name 
ch0_txpmadprioout_phy(rs_lpbk_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_40(15);
ch1_txpmadprioout_phy(rs_lpbk_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_40(15);
ch2_txpmadprioout_phy(rs_lpbk_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_40(15);
ch3_txpmadprioout_phy(rs_lpbk_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_40(15);
ch4_txpmadprioout_phy(rs_lpbk_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_40(15);
ch5_txpmadprioout_phy(rs_lpbk_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_40(15);

-- CMUDivider ------------------------------------------------------------------
-- Table33: PMA Per Channel TX Control Register 6 for Channel 0
-- Table33 is split between clock divider and TX_PMA

-- TX_PMA portion of dprio - does not hurt to receive clock divider cram 
-- - already implemented in the same section as other TX_PMA ctrl

-- Output - CMU Clock Divider Portion
ch0_cmudividerdprioout_phy(rdynamic_sw_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_33(6);
ch1_cmudividerdprioout_phy(rdynamic_sw_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_33(6);
ch2_cmudividerdprioout_phy(rdynamic_sw_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_33(6);
ch3_cmudividerdprioout_phy(rdynamic_sw_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_33(6);
ch4_cmudividerdprioout_phy(rdynamic_sw_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_33(6);
ch5_cmudividerdprioout_phy(rdynamic_sw_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_33(6);

ch0_cmudividerdprioout_phy(rpmadwidth_tx_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_33(9);
ch1_cmudividerdprioout_phy(rpmadwidth_tx_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_33(9);
ch2_cmudividerdprioout_phy(rpmadwidth_tx_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_33(9);
ch3_cmudividerdprioout_phy(rpmadwidth_tx_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_33(9);
ch4_cmudividerdprioout_phy(rpmadwidth_tx_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_33(9);
ch5_cmudividerdprioout_phy(rpmadwidth_tx_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_33(9);

ch0_cmudividerdprioout_phy(rpma_doublewidth_tx_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_33(10);
ch1_cmudividerdprioout_phy(rpma_doublewidth_tx_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_33(10);
ch2_cmudividerdprioout_phy(rpma_doublewidth_tx_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_33(10);
ch3_cmudividerdprioout_phy(rpma_doublewidth_tx_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_33(10);
ch4_cmudividerdprioout_phy(rpma_doublewidth_tx_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_33(10);
ch5_cmudividerdprioout_phy(rpma_doublewidth_tx_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_33(10);

ch0_cmudividerdprioout_phy(rcgb_m_sel_DP_TXPMA_IDX_1 DOWNTO rcgb_m_sel_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_33(12 DOWNTO 11);
ch1_cmudividerdprioout_phy(rcgb_m_sel_DP_TXPMA_IDX_1 DOWNTO rcgb_m_sel_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_33(12 DOWNTO 11);
ch2_cmudividerdprioout_phy(rcgb_m_sel_DP_TXPMA_IDX_1 DOWNTO rcgb_m_sel_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_33(12 DOWNTO 11);
ch3_cmudividerdprioout_phy(rcgb_m_sel_DP_TXPMA_IDX_1 DOWNTO rcgb_m_sel_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_33(12 DOWNTO 11);
ch4_cmudividerdprioout_phy(rcgb_m_sel_DP_TXPMA_IDX_1 DOWNTO rcgb_m_sel_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_33(12 DOWNTO 11);
ch5_cmudividerdprioout_phy(rcgb_m_sel_DP_TXPMA_IDX_1 DOWNTO rcgb_m_sel_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_33(12 DOWNTO 11);

ch0_cmudividerdprioout_phy(rcgb_cmu_sel_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_33(13);
ch1_cmudividerdprioout_phy(rcgb_cmu_sel_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_33(13);
ch2_cmudividerdprioout_phy(rcgb_cmu_sel_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_33(13);
ch3_cmudividerdprioout_phy(rcgb_cmu_sel_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_33(13);
ch4_cmudividerdprioout_phy(rcgb_cmu_sel_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_33(13);
ch5_cmudividerdprioout_phy(rcgb_cmu_sel_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_33(13);

-- TX_PMA portion
-- bit(7) goes to rx_pma
ch0_txpmadprioout_phy(rcgb_x_en_DP_TXPMA_IDX_1  DOWNTO  rcgb_delay_sel_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_33(15 DOWNTO 8);
ch1_txpmadprioout_phy(rcgb_x_en_DP_TXPMA_IDX_1  DOWNTO  rcgb_delay_sel_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_33(15 DOWNTO 8);
ch2_txpmadprioout_phy(rcgb_x_en_DP_TXPMA_IDX_1  DOWNTO  rcgb_delay_sel_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_33(15 DOWNTO 8);
ch3_txpmadprioout_phy(rcgb_x_en_DP_TXPMA_IDX_1  DOWNTO  rcgb_delay_sel_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_33(15 DOWNTO 8);
ch4_txpmadprioout_phy(rcgb_x_en_DP_TXPMA_IDX_1  DOWNTO  rcgb_delay_sel_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_33(15 DOWNTO 8);
ch5_txpmadprioout_phy(rcgb_x_en_DP_TXPMA_IDX_1  DOWNTO  rcgb_delay_sel_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_33(15 DOWNTO 8);
-- this bit is from table_40 (rx_pma) bit(15)
-- ch0_txpmadprioout_phy(rs_lpbk_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_33(7);
ch0_txpmadprioout_phy(rdynamic_sw_DP_TXPMA_IDX_0  DOWNTO  reserved_0_TB33_DP_TXPMA_IDX_0) <= ch0_out_chnl_ctrl_33(6 DOWNTO 0);
ch1_txpmadprioout_phy(rdynamic_sw_DP_TXPMA_IDX_0  DOWNTO  reserved_0_TB33_DP_TXPMA_IDX_0) <= ch1_out_chnl_ctrl_33(6 DOWNTO 0);
ch2_txpmadprioout_phy(rdynamic_sw_DP_TXPMA_IDX_0  DOWNTO  reserved_0_TB33_DP_TXPMA_IDX_0) <= ch2_out_chnl_ctrl_33(6 DOWNTO 0);
ch3_txpmadprioout_phy(rdynamic_sw_DP_TXPMA_IDX_0  DOWNTO  reserved_0_TB33_DP_TXPMA_IDX_0) <= ch3_out_chnl_ctrl_33(6 DOWNTO 0);
ch4_txpmadprioout_phy(rdynamic_sw_DP_TXPMA_IDX_0  DOWNTO  reserved_0_TB33_DP_TXPMA_IDX_0) <= ch4_out_chnl_ctrl_33(6 DOWNTO 0);
ch5_txpmadprioout_phy(rdynamic_sw_DP_TXPMA_IDX_0  DOWNTO  reserved_0_TB33_DP_TXPMA_IDX_0) <= ch5_out_chnl_ctrl_33(6 DOWNTO 0);

-- PLL portion - rx_cdr needs dynamic_sw for gating
-- For x4 gen2: there is no channel clock divider so one has to use centrl_clk_div (to get init_)
-- For HIP genx1: centrl clk div sets enable_dynamic_divider = true and tied rate=1 (293245) - incompatible with rx_pll
-- using centrl clk_div data in x4 and chl_div in x1 - here cmu_out_centrl_global[0] = rx[0].rindv_rx
ch0_rxplldprioout_phy(rdynamic_sw_DP_PLL_IDX_0) <= ch4_out_chnl_ctrl_33(6) WHEN (cmu_out_centrl_global_1(0) = '0') ELSE ch0_out_chnl_ctrl_33(6);	 
ch1_rxplldprioout_phy(rdynamic_sw_DP_PLL_IDX_0) <= ch4_out_chnl_ctrl_33(6) WHEN (cmu_out_centrl_global_1(0) = '0') ELSE ch1_out_chnl_ctrl_33(6);	 
ch2_rxplldprioout_phy(rdynamic_sw_DP_PLL_IDX_0) <= ch4_out_chnl_ctrl_33(6) WHEN (cmu_out_centrl_global_1(0) = '0') ELSE ch2_out_chnl_ctrl_33(6);	 
ch3_rxplldprioout_phy(rdynamic_sw_DP_PLL_IDX_0) <= ch4_out_chnl_ctrl_33(6) WHEN (cmu_out_centrl_global_1(0) = '0') ELSE ch3_out_chnl_ctrl_33(6);	 

-- not needed below if we do not switch rx_cdr_pll into txpll
ch4_rxtxplldprioout_phy(rdynamic_sw_DP_PLL_IDX_0) <= ch4_out_chnl_ctrl_33(6);
ch5_rxtxplldprioout_phy(rdynamic_sw_DP_PLL_IDX_0) <= ch5_out_chnl_ctrl_33(6);

-- Input  portion of CLOCK_DIVIDER in table 33
ch0_in_chnl_ctrl_33(6)     <=  ch0_cmudividerdprioin_phy(rdynamic_sw_DP_TXPMA_IDX_0)                         ;
ch1_in_chnl_ctrl_33(6)     <=  ch1_cmudividerdprioin_phy(rdynamic_sw_DP_TXPMA_IDX_0)                         ;
ch2_in_chnl_ctrl_33(6)     <=  ch2_cmudividerdprioin_phy(rdynamic_sw_DP_TXPMA_IDX_0)                         ;
ch3_in_chnl_ctrl_33(6)     <=  ch3_cmudividerdprioin_phy(rdynamic_sw_DP_TXPMA_IDX_0)                         ;
ch4_in_chnl_ctrl_33(6)     <=  ch4_cmudividerdprioin_phy(rdynamic_sw_DP_TXPMA_IDX_0)                         ;
ch5_in_chnl_ctrl_33(6)     <=  ch5_cmudividerdprioin_phy(rdynamic_sw_DP_TXPMA_IDX_0)                         ;
ch0_in_chnl_ctrl_33(12 DOWNTO 11) <=  ch0_cmudividerdprioin_phy(rcgb_m_sel_DP_TXPMA_IDX_1  DOWNTO  rcgb_m_sel_DP_TXPMA_IDX_0) ;
ch1_in_chnl_ctrl_33(12 DOWNTO 11) <=  ch1_cmudividerdprioin_phy(rcgb_m_sel_DP_TXPMA_IDX_1  DOWNTO  rcgb_m_sel_DP_TXPMA_IDX_0) ;
ch2_in_chnl_ctrl_33(12 DOWNTO 11) <=  ch2_cmudividerdprioin_phy(rcgb_m_sel_DP_TXPMA_IDX_1  DOWNTO  rcgb_m_sel_DP_TXPMA_IDX_0) ;
ch3_in_chnl_ctrl_33(12 DOWNTO 11) <=  ch3_cmudividerdprioin_phy(rcgb_m_sel_DP_TXPMA_IDX_1  DOWNTO  rcgb_m_sel_DP_TXPMA_IDX_0) ;
ch4_in_chnl_ctrl_33(12 DOWNTO 11) <=  ch4_cmudividerdprioin_phy(rcgb_m_sel_DP_TXPMA_IDX_1  DOWNTO  rcgb_m_sel_DP_TXPMA_IDX_0) ;
ch5_in_chnl_ctrl_33(12 DOWNTO 11) <=  ch5_cmudividerdprioin_phy(rcgb_m_sel_DP_TXPMA_IDX_1  DOWNTO  rcgb_m_sel_DP_TXPMA_IDX_0) ;
--                         Handled in inclk_select manual section of clock_div
--ch0_in_chnl_ctrl_33(13)    <=  ch0_cmudividerdprioin_phy(rcgb_cmu_sel_DP_TXPMA_IDX_0)                         ;
--ch1_in_chnl_ctrl_33(13)    <=  ch1_cmudividerdprioin_phy(rcgb_cmu_sel_DP_TXPMA_IDX_0)                         ;
--ch2_in_chnl_ctrl_33(13)    <=  ch2_cmudividerdprioin_phy(rcgb_cmu_sel_DP_TXPMA_IDX_0)                         ;
--ch3_in_chnl_ctrl_33(13)    <=  ch3_cmudividerdprioin_phy(rcgb_cmu_sel_DP_TXPMA_IDX_0)                         ;
--ch4_in_chnl_ctrl_33(13)    <=  ch4_cmudividerdprioin_phy(rcgb_cmu_sel_DP_TXPMA_IDX_0)                         ;
--ch5_in_chnl_ctrl_33(13)    <=  ch5_cmudividerdprioin_phy(rcgb_cmu_sel_DP_TXPMA_IDX_0)                         ;

-- Input DOWNTO  portion of TX_PMA in table 33
ch0_in_chnl_ctrl_33(3 DOWNTO 0)   <=  ch0_txpmadprioin_phy(reserved_0_TB33_DP_TXPMA_IDX_3  DOWNTO  reserved_0_TB33_DP_TXPMA_IDX_0);
ch1_in_chnl_ctrl_33(3 DOWNTO 0)   <=  ch1_txpmadprioin_phy(reserved_0_TB33_DP_TXPMA_IDX_3  DOWNTO  reserved_0_TB33_DP_TXPMA_IDX_0);
ch2_in_chnl_ctrl_33(3 DOWNTO 0)   <=  ch2_txpmadprioin_phy(reserved_0_TB33_DP_TXPMA_IDX_3  DOWNTO  reserved_0_TB33_DP_TXPMA_IDX_0);
ch3_in_chnl_ctrl_33(3 DOWNTO 0)   <=  ch3_txpmadprioin_phy(reserved_0_TB33_DP_TXPMA_IDX_3  DOWNTO  reserved_0_TB33_DP_TXPMA_IDX_0);
ch4_in_chnl_ctrl_33(3 DOWNTO 0)   <=  ch4_txpmadprioin_phy(reserved_0_TB33_DP_TXPMA_IDX_3  DOWNTO  reserved_0_TB33_DP_TXPMA_IDX_0);
ch5_in_chnl_ctrl_33(3 DOWNTO 0)   <=  ch5_txpmadprioin_phy(reserved_0_TB33_DP_TXPMA_IDX_3  DOWNTO  reserved_0_TB33_DP_TXPMA_IDX_0);
ch0_in_chnl_ctrl_33(4)     <=  ch0_txpmadprioin_phy(rtx_cgb_pdb_DP_TXPMA_IDX_0);
ch1_in_chnl_ctrl_33(4)     <=  ch1_txpmadprioin_phy(rtx_cgb_pdb_DP_TXPMA_IDX_0);
ch2_in_chnl_ctrl_33(4)     <=  ch2_txpmadprioin_phy(rtx_cgb_pdb_DP_TXPMA_IDX_0);
ch3_in_chnl_ctrl_33(4)     <=  ch3_txpmadprioin_phy(rtx_cgb_pdb_DP_TXPMA_IDX_0);
ch4_in_chnl_ctrl_33(4)     <=  ch4_txpmadprioin_phy(rtx_cgb_pdb_DP_TXPMA_IDX_0);
ch5_in_chnl_ctrl_33(4)     <=  ch5_txpmadprioin_phy(rtx_cgb_pdb_DP_TXPMA_IDX_0);
ch0_in_chnl_ctrl_33(5)     <=  ch0_txpmadprioin_phy(rpclksel_DP_TXPMA_IDX_0);
ch1_in_chnl_ctrl_33(5)     <=  ch1_txpmadprioin_phy(rpclksel_DP_TXPMA_IDX_0);
ch2_in_chnl_ctrl_33(5)     <=  ch2_txpmadprioin_phy(rpclksel_DP_TXPMA_IDX_0);
ch3_in_chnl_ctrl_33(5)     <=  ch3_txpmadprioin_phy(rpclksel_DP_TXPMA_IDX_0);
ch4_in_chnl_ctrl_33(5)     <=  ch4_txpmadprioin_phy(rpclksel_DP_TXPMA_IDX_0);
ch5_in_chnl_ctrl_33(5)     <=  ch5_txpmadprioin_phy(rpclksel_DP_TXPMA_IDX_0);

--            clock divide(6)

-- allow_serial_loopback mapped into rx_pma.RRX_S_LPBK_RXPMA_IDX - ICD XLS cram doc error
ch0_in_chnl_ctrl_33(7)     <=  ch0_rxpmadprioin_phy(rs_lpbk_DP_RXPMA_IDX);
ch1_in_chnl_ctrl_33(7)     <=  ch1_rxpmadprioin_phy(rs_lpbk_DP_RXPMA_IDX);
ch2_in_chnl_ctrl_33(7)     <=  ch2_rxpmadprioin_phy(rs_lpbk_DP_RXPMA_IDX);
ch3_in_chnl_ctrl_33(7)     <=  ch3_rxpmadprioin_phy(rs_lpbk_DP_RXPMA_IDX);
ch4_in_chnl_ctrl_33(7)     <=  ch4_rxpmadprioin_phy(rs_lpbk_DP_RXPMA_IDX);
ch5_in_chnl_ctrl_33(7)     <=  ch5_rxpmadprioin_phy(rs_lpbk_DP_RXPMA_IDX);

ch0_in_chnl_ctrl_33(8)     <=  ch0_txpmadprioin_phy(rcgb_delay_sel_DP_TXPMA_IDX_0);
ch1_in_chnl_ctrl_33(8)     <=  ch1_txpmadprioin_phy(rcgb_delay_sel_DP_TXPMA_IDX_0);
ch2_in_chnl_ctrl_33(8)     <=  ch2_txpmadprioin_phy(rcgb_delay_sel_DP_TXPMA_IDX_0);
ch3_in_chnl_ctrl_33(8)     <=  ch3_txpmadprioin_phy(rcgb_delay_sel_DP_TXPMA_IDX_0);
ch4_in_chnl_ctrl_33(8)     <=  ch4_txpmadprioin_phy(rcgb_delay_sel_DP_TXPMA_IDX_0);
ch5_in_chnl_ctrl_33(8)     <=  ch5_txpmadprioin_phy(rcgb_delay_sel_DP_TXPMA_IDX_0);     
                 
ch0_in_chnl_ctrl_33(9)     <=  ch0_txpmadprioin_phy(rpmadwidth_tx_DP_TXPMA_IDX_0);
ch1_in_chnl_ctrl_33(9)     <=  ch1_txpmadprioin_phy(rpmadwidth_tx_DP_TXPMA_IDX_0);
ch2_in_chnl_ctrl_33(9)     <=  ch2_txpmadprioin_phy(rpmadwidth_tx_DP_TXPMA_IDX_0);
ch3_in_chnl_ctrl_33(9)     <=  ch3_txpmadprioin_phy(rpmadwidth_tx_DP_TXPMA_IDX_0);
-- spr 317392 - when clock divider is used as global (x4) but corresponding tx_pma not available
-- ch4, 5 <--> with corresponding CMU_CTRL registers (in this case table 59)
ch4_in_chnl_ctrl_33(9)     <=  ch4_cmudividerdprioin_phy(rpmadwidth_tx_DP_TXPMA_IDX_0);
ch5_in_chnl_ctrl_33(9)     <=  ch5_cmudividerdprioin_phy(rpmadwidth_tx_DP_TXPMA_IDX_0);

ch0_in_chnl_ctrl_33(10)    <=  ch0_txpmadprioin_phy(rpma_doublewidth_tx_DP_TXPMA_IDX_0);
ch1_in_chnl_ctrl_33(10)    <=  ch1_txpmadprioin_phy(rpma_doublewidth_tx_DP_TXPMA_IDX_0);
ch2_in_chnl_ctrl_33(10)    <=  ch2_txpmadprioin_phy(rpma_doublewidth_tx_DP_TXPMA_IDX_0);
ch3_in_chnl_ctrl_33(10)    <=  ch3_txpmadprioin_phy(rpma_doublewidth_tx_DP_TXPMA_IDX_0);
-- same as rpmadwidth
ch4_in_chnl_ctrl_33(10)    <=  ch4_cmudividerdprioin_phy(rpma_doublewidth_tx_DP_TXPMA_IDX_0);
ch5_in_chnl_ctrl_33(10)    <=  ch5_cmudividerdprioin_phy(rpma_doublewidth_tx_DP_TXPMA_IDX_0); 
--           clock_divider(12 DOWNTO 11)
--           clock_divider(13)
--                                Handled in clkin_select manual section next
--ch0_in_chnl_ctrl_33(15 DOWNTO 14) <=  ch0_txpmadprioin_phy(rcgb_x_en_DP_TXPMA_IDX_1  DOWNTO  rcgb_x_en_DP_TXPMA_IDX_0);
--ch1_in_chnl_ctrl_33(15 DOWNTO 14) <=  ch1_txpmadprioin_phy(rcgb_x_en_DP_TXPMA_IDX_1  DOWNTO  rcgb_x_en_DP_TXPMA_IDX_0);
--ch2_in_chnl_ctrl_33(15 DOWNTO 14) <=  ch2_txpmadprioin_phy(rcgb_x_en_DP_TXPMA_IDX_1  DOWNTO  rcgb_x_en_DP_TXPMA_IDX_0);
--ch3_in_chnl_ctrl_33(15 DOWNTO 14) <=  ch3_txpmadprioin_phy(rcgb_x_en_DP_TXPMA_IDX_1  DOWNTO  rcgb_x_en_DP_TXPMA_IDX_0);
--ch4_in_chnl_ctrl_33(15 DOWNTO 14) <=  ch4_txpmadprioin_phy(rcgb_x_en_DP_TXPMA_IDX_1  DOWNTO  rcgb_x_en_DP_TXPMA_IDX_0);
--ch5_in_chnl_ctrl_33(15 DOWNTO 14) <=  ch5_txpmadprioin_phy(rcgb_x_en_DP_TXPMA_IDX_1  DOWNTO  rcgb_x_en_DP_TXPMA_IDX_0);

-- Table34: PMA Per Channel TX Control Register 7 for Channel 0
-- rrevlb_sw is modeled at rx_pma
ch0_in_chnl_ctrl_34(10) <= ch0_rxpmadprioin_phy(rrevlb_sw_DP_RXPMA_IDX);
ch1_in_chnl_ctrl_34(10) <= ch1_rxpmadprioin_phy(rrevlb_sw_DP_RXPMA_IDX);
ch2_in_chnl_ctrl_34(10) <= ch2_rxpmadprioin_phy(rrevlb_sw_DP_RXPMA_IDX);
ch3_in_chnl_ctrl_34(10) <= ch3_rxpmadprioin_phy(rrevlb_sw_DP_RXPMA_IDX);
ch4_in_chnl_ctrl_34(10) <= ch4_rxpmadprioin_phy(rrevlb_sw_DP_RXPMA_IDX);
ch5_in_chnl_ctrl_34(10) <= ch5_rxpmadprioin_phy(rrevlb_sw_DP_RXPMA_IDX);

-- Table 40: 
-- bit(15) goes to TX_PMA - moved to Manual section as this CRAM sends to TX_PMA

-- table40(15) <= rcru_rlbk (revere_lpbk) using rs_lpbk_DP_IDX to map to tx_pam.rtx_rlpbk RTL name
ch0_in_chnl_ctrl_40(15) <= ch0_txpmadprioin_phy(rs_lpbk_DP_TXPMA_IDX_0);
ch1_in_chnl_ctrl_40(15) <= ch1_txpmadprioin_phy(rs_lpbk_DP_TXPMA_IDX_0);
ch2_in_chnl_ctrl_40(15) <= ch2_txpmadprioin_phy(rs_lpbk_DP_TXPMA_IDX_0);
ch3_in_chnl_ctrl_40(15) <= ch3_txpmadprioin_phy(rs_lpbk_DP_TXPMA_IDX_0);
ch4_in_chnl_ctrl_40(15) <= ch4_txpmadprioin_phy(rs_lpbk_DP_TXPMA_IDX_0);
ch5_in_chnl_ctrl_40(15) <= ch5_txpmadprioin_phy(rs_lpbk_DP_TXPMA_IDX_0);

-- rest bits from RX_PLL
ch0_in_chnl_ctrl_40(14 DOWNTO 0) <= ch0_rxplldprioin_phy(rcru_lst_DP_PLL_IDX_3 DOWNTO reserved_0_TB40_DP_PLL_IDX_0);
ch1_in_chnl_ctrl_40(14 DOWNTO 0) <= ch1_rxplldprioin_phy(rcru_lst_DP_PLL_IDX_3 DOWNTO reserved_0_TB40_DP_PLL_IDX_0);
ch2_in_chnl_ctrl_40(14 DOWNTO 0) <= ch2_rxplldprioin_phy(rcru_lst_DP_PLL_IDX_3 DOWNTO reserved_0_TB40_DP_PLL_IDX_0);
ch3_in_chnl_ctrl_40(14 DOWNTO 0) <= ch3_rxplldprioin_phy(rcru_lst_DP_PLL_IDX_3 DOWNTO reserved_0_TB40_DP_PLL_IDX_0);
ch4_in_chnl_ctrl_40(14 DOWNTO 0) <= ch4_rxtxplldprioin_phy(rcru_lst_DP_PLL_IDX_3 DOWNTO reserved_0_TB40_DP_PLL_IDX_0);
ch5_in_chnl_ctrl_40(14 DOWNTO 0) <= ch5_rxtxplldprioin_phy(rcru_lst_DP_PLL_IDX_3 DOWNTO reserved_0_TB40_DP_PLL_IDX_0);

-- ----------------------------------------------------------------------------------------------------------------
-- Manual section - inputs: only ch0 --> global CRAMs
-- ----------------------------------------------------------------------------------------------------------------

-- Extra word in CMU (no correspondence in channel) - not modeled in MIF and SIM
cmu0_in_centrl_ctrl_21 <= "0000000000000000";
cmu1_in_centrl_ctrl_21 <= "0000000000000000";

-- global ctrl 0 - centrl_ctrl_43 - table 75
cmu_in_centrl_global_0 <= "0000000000000000";

-- global ctrl 1 - centrl_ctrl_44
cmu_in_centrl_global_1(15 DOWNTO 8) <= "00000000";
cmu_in_centrl_global_1(7)    <= ch0_txpcsdprioin_phy(rendec_data_sel_tx_DP_TXPCS_IDX);
cmu_in_centrl_global_1(6)    <= ch0_rxpcsdprioin_phy(rendec_data_sel_rx_DP_RXPCS_IDX);
cmu_in_centrl_global_1(5 DOWNTO 3)  <= "000";
cmu_in_centrl_global_1(2)    <= ch0_rxpcsdprioin_phy(rdeskewen_DP_RXPCS_IDX);
cmu_in_centrl_global_1(1)    <= ch0_txpcsdprioin_phy(rindv_tx_DP_TXPCS_IDX);
cmu_in_centrl_global_1(0)    <= ch0_rxpcsdprioin_phy(rindv_rx_DP_RXPCS_IDX);

-- global ctrl 2 - centrl_ctrl_45
cmu_in_centrl_global_2(15)    <= ch4_cmudividerdprioin_phy(rfreerun_centrl_DP_CLOCK_DIV_IDX);
cmu_in_centrl_global_2(14)    <= ch4_cmudividerdprioin_phy(rcentrl_clk_sel_DP_CLOCK_DIV_IDX);
cmu_in_centrl_global_2(13)    <= ch4_cmudividerdprioin_phy(rrefclk_out_div2_DP_CLOCK_DIV_IDX);

cmu_in_centrl_global_2(12 DOWNTO 11) <= "00";
cmu_in_centrl_global_2(10)    <= ch0_rxpcsdprioin_phy(rdskposdisp_DP_RXPCS_IDX);
cmu_in_centrl_global_2(9 DOWNTO 0)   <= "0000000000";

-- global ctrl 3 - centrl_ctrl_46
cmu_in_centrl_global_3(15 DOWNTO 4) <= "000000000000";
cmu_in_centrl_global_3(3) <= ch0_rxpcsdprioin_phy(rmaster_rx_DP_RXPCS_IDX);
cmu_in_centrl_global_3(2) <= ch0_rxpcsdprioin_phy(rmaster_up_rx_DP_RXPCS_IDX);
cmu_in_centrl_global_3(1) <= ch0_txpcsdprioin_phy(rmaster_tx_DP_TXPCS_IDX);
cmu_in_centrl_global_3(0) <= ch0_txpcsdprioin_phy(rmaster_up_tx_DP_TXPCS_IDX);

--====================================================================
-- Manually added code to handle PLL clock select                    =
--====================================================================

-- Table 34 - pll's pfd_clk_select -----------------------------------

-- preparing inputs to index_cram_map 
pll0_init_pfd_clk_sel <= ch0_rxplldprioin_logic(PFD_CLK_SELECT_DP_PLL_IDX_3 DOWNTO PFD_CLK_SELECT_DP_PLL_IDX_0);
pll0_dp_riqclk_sel    <= ch0_out_chnl_ctrl_34(15 DOWNTO 14);
pll0_dp_rrefclk_sel   <= ch0_out_chnl_ctrl_34(13 DOWNTO 12);

-- using outputs from index_cram_map
ch0_rxplldprioout_phy(PFD_CLK_SELECT_DP_PLL_IDX_3 DOWNTO PFD_CLK_SELECT_DP_PLL_IDX_0) <= pll0_dp_pfd_clk_sel;
ch0_in_chnl_ctrl_34(15 DOWNTO 14) <= pll0_csr_riqclk_sel;
ch0_in_chnl_ctrl_34(13 DOWNTO 12) <= pll0_csr_rrefclk_sel;

-- preparing inputs to index_cram_map 
pll1_init_pfd_clk_sel <= ch1_rxplldprioin_logic(PFD_CLK_SELECT_DP_PLL_IDX_3 DOWNTO PFD_CLK_SELECT_DP_PLL_IDX_0);
pll1_dp_riqclk_sel    <= ch1_out_chnl_ctrl_34(15 DOWNTO 14);
pll1_dp_rrefclk_sel   <= ch1_out_chnl_ctrl_34(13 DOWNTO 12);

-- using outputs from index_cram_map
ch1_rxplldprioout_phy(PFD_CLK_SELECT_DP_PLL_IDX_3 DOWNTO PFD_CLK_SELECT_DP_PLL_IDX_0) <= pll1_dp_pfd_clk_sel;
ch1_in_chnl_ctrl_34(15 DOWNTO 14) <= pll1_csr_riqclk_sel;
ch1_in_chnl_ctrl_34(13 DOWNTO 12) <= pll1_csr_rrefclk_sel;

-- preparing inputs to index_cram_map 
pll2_init_pfd_clk_sel <= ch2_rxplldprioin_logic(PFD_CLK_SELECT_DP_PLL_IDX_3 DOWNTO PFD_CLK_SELECT_DP_PLL_IDX_0);
pll2_dp_riqclk_sel    <= ch2_out_chnl_ctrl_34(15 DOWNTO 14);
pll2_dp_rrefclk_sel   <= ch2_out_chnl_ctrl_34(13 DOWNTO 12);

-- using outputs from index_cram_map
ch2_rxplldprioout_phy(PFD_CLK_SELECT_DP_PLL_IDX_3 DOWNTO PFD_CLK_SELECT_DP_PLL_IDX_0) <= pll2_dp_pfd_clk_sel;
ch2_in_chnl_ctrl_34(15 DOWNTO 14) <= pll2_csr_riqclk_sel;
ch2_in_chnl_ctrl_34(13 DOWNTO 12) <= pll2_csr_rrefclk_sel;

-- preparing inputs to index_cram_map 
pll3_init_pfd_clk_sel <= ch3_rxplldprioin_logic(PFD_CLK_SELECT_DP_PLL_IDX_3 DOWNTO PFD_CLK_SELECT_DP_PLL_IDX_0);
pll3_dp_riqclk_sel    <= ch3_out_chnl_ctrl_34(15 DOWNTO 14);
pll3_dp_rrefclk_sel   <= ch3_out_chnl_ctrl_34(13 DOWNTO 12);

-- using outputs from index_cram_map
ch3_rxplldprioout_phy(PFD_CLK_SELECT_DP_PLL_IDX_3 DOWNTO PFD_CLK_SELECT_DP_PLL_IDX_0) <= pll3_dp_pfd_clk_sel;
ch3_in_chnl_ctrl_34(15 DOWNTO 14) <= pll3_csr_riqclk_sel;
ch3_in_chnl_ctrl_34(13 DOWNTO 12) <= pll3_csr_rrefclk_sel;

-- preparing inputs to index_cram_map 
pll4_init_pfd_clk_sel <= ch4_rxtxplldprioin_logic(PFD_CLK_SELECT_DP_PLL_IDX_3 DOWNTO PFD_CLK_SELECT_DP_PLL_IDX_0);
pll4_dp_riqclk_sel    <= ch4_out_chnl_ctrl_34(15 DOWNTO 14);
pll4_dp_rrefclk_sel   <= ch4_out_chnl_ctrl_34(13 DOWNTO 12);

-- using outputs from index_cram_map
ch4_rxtxplldprioout_phy(PFD_CLK_SELECT_DP_PLL_IDX_3 DOWNTO PFD_CLK_SELECT_DP_PLL_IDX_0) <= pll4_dp_pfd_clk_sel;
ch4_in_chnl_ctrl_34(15 DOWNTO 14) <= pll4_csr_riqclk_sel;
ch4_in_chnl_ctrl_34(13 DOWNTO 12) <= pll4_csr_rrefclk_sel;

-- preparing inputs to index_cram_map 
pll5_init_pfd_clk_sel <= ch5_rxtxplldprioin_logic(PFD_CLK_SELECT_DP_PLL_IDX_3 DOWNTO PFD_CLK_SELECT_DP_PLL_IDX_0);
pll5_dp_riqclk_sel    <= ch5_out_chnl_ctrl_34(15 DOWNTO 14);
pll5_dp_rrefclk_sel   <= ch5_out_chnl_ctrl_34(13 DOWNTO 12);

-- using outputs from index_cram_map
ch5_rxtxplldprioout_phy(PFD_CLK_SELECT_DP_PLL_IDX_3 DOWNTO PFD_CLK_SELECT_DP_PLL_IDX_0) <= pll5_dp_pfd_clk_sel;
ch5_in_chnl_ctrl_34(15 DOWNTO 14) <= pll5_csr_riqclk_sel;
ch5_in_chnl_ctrl_34(13 DOWNTO 12) <= pll5_csr_rrefclk_sel;

--====================================================================
-- Manually added code to handle TX PMA clock select                 =
--====================================================================

-- Table 33 - TX PMA's clkin_select ---------------------------------

-- preparing inputs to index_cram_map 
txpma0_init_clkin_sel <= ch0_txpmadprioin_logic(CLKIN_SELECT_DP_TXPMA_IDX_2 DOWNTO CLKIN_SELECT_DP_TXPMA_IDX_0);
txpma0_dp_rcgb_x_en   <= ch0_out_chnl_ctrl_33(15 DOWNTO 14);

-- using outputs from index_cram_map
ch0_txpmadprioout_phy(CLKIN_SELECT_DP_TXPMA_IDX_2 DOWNTO CLKIN_SELECT_DP_TXPMA_IDX_0) <= txpma0_dp_clkin_sel;
ch0_in_chnl_ctrl_33(15 DOWNTO 14) <= txpma0_csr_rcgb_x_en;

-- preparing inputs to index_cram_map 
txpma1_init_clkin_sel <= ch1_txpmadprioin_logic(CLKIN_SELECT_DP_TXPMA_IDX_2 DOWNTO CLKIN_SELECT_DP_TXPMA_IDX_0);
txpma1_dp_rcgb_x_en   <= ch1_out_chnl_ctrl_33(15 DOWNTO 14);

-- using outputs from index_cram_map
ch1_txpmadprioout_phy(CLKIN_SELECT_DP_TXPMA_IDX_2 DOWNTO CLKIN_SELECT_DP_TXPMA_IDX_0) <= txpma1_dp_clkin_sel;
ch1_in_chnl_ctrl_33(15 DOWNTO 14) <= txpma1_csr_rcgb_x_en;

-- preparing inputs to index_cram_map 
txpma2_init_clkin_sel <= ch2_txpmadprioin_logic(CLKIN_SELECT_DP_TXPMA_IDX_2 DOWNTO CLKIN_SELECT_DP_TXPMA_IDX_0);
txpma2_dp_rcgb_x_en   <= ch2_out_chnl_ctrl_33(15 DOWNTO 14);

-- using outputs from index_cram_map
ch2_txpmadprioout_phy(CLKIN_SELECT_DP_TXPMA_IDX_2 DOWNTO CLKIN_SELECT_DP_TXPMA_IDX_0) <= txpma2_dp_clkin_sel;
ch2_in_chnl_ctrl_33(15 DOWNTO 14) <= txpma2_csr_rcgb_x_en;

-- preparing inputs to index_cram_map 
txpma3_init_clkin_sel <= ch3_txpmadprioin_logic(CLKIN_SELECT_DP_TXPMA_IDX_2 DOWNTO CLKIN_SELECT_DP_TXPMA_IDX_0);
txpma3_dp_rcgb_x_en   <= ch3_out_chnl_ctrl_33(15 DOWNTO 14);

-- using outputs from index_cram_map
ch3_txpmadprioout_phy(CLKIN_SELECT_DP_TXPMA_IDX_2 DOWNTO CLKIN_SELECT_DP_TXPMA_IDX_0) <= txpma3_dp_clkin_sel;
ch3_in_chnl_ctrl_33(15 DOWNTO 14) <= txpma3_csr_rcgb_x_en;

-- preparing inputs to index_cram_map 
txpma4_init_clkin_sel <= ch4_txpmadprioin_logic(CLKIN_SELECT_DP_TXPMA_IDX_2 DOWNTO CLKIN_SELECT_DP_TXPMA_IDX_0);
txpma4_dp_rcgb_x_en   <= ch4_out_chnl_ctrl_33(15 DOWNTO 14);

-- using outputs from index_cram_map
ch4_txpmadprioout_phy(CLKIN_SELECT_DP_TXPMA_IDX_2 DOWNTO CLKIN_SELECT_DP_TXPMA_IDX_0) <= txpma4_dp_clkin_sel;
ch4_in_chnl_ctrl_33(15 DOWNTO 14) <= txpma4_csr_rcgb_x_en;

-- preparing inputs to index_cram_map 
txpma5_init_clkin_sel <= ch5_txpmadprioin_logic(CLKIN_SELECT_DP_TXPMA_IDX_2 DOWNTO CLKIN_SELECT_DP_TXPMA_IDX_0);
txpma5_dp_rcgb_x_en   <= ch5_out_chnl_ctrl_33(15 DOWNTO 14);

-- using outputs from index_cram_map
ch5_txpmadprioout_phy(CLKIN_SELECT_DP_TXPMA_IDX_2 DOWNTO CLKIN_SELECT_DP_TXPMA_IDX_0) <= txpma5_dp_clkin_sel;
ch5_in_chnl_ctrl_33(15 DOWNTO 14) <= txpma5_csr_rcgb_x_en;

--====================================================================
-- Manually added code to handle clkdiv PLL0/1 select                =
--====================================================================

-- Table 33 - clock divider's inclk_select  --------------------------

-- preparing inputs to index_cram_map 
clkdiv0_init_inclk_select <= ch0_cmudividerdprioin_logic(INCLK_SELECT_DP_CLOCK_DIV_IDX);
clkdiv0_dp_rcgb_cmu_sel   <= ch0_out_chnl_ctrl_33(13);

-- using outputs from index_cram_map
ch0_cmudividerdprioout_phy(INCLK_SELECT_DP_CLOCK_DIV_IDX) <= clkdiv0_dp_inclk_select;
ch0_in_chnl_ctrl_33(13)   <= clkdiv0_csr_rcgb_cmu_sel;

-- preparing inputs to index_cram_map 
clkdiv1_init_inclk_select <= ch1_cmudividerdprioin_logic(INCLK_SELECT_DP_CLOCK_DIV_IDX);
clkdiv1_dp_rcgb_cmu_sel   <= ch1_out_chnl_ctrl_33(13);

-- using outputs from index_cram_map
ch1_cmudividerdprioout_phy(INCLK_SELECT_DP_CLOCK_DIV_IDX) <= clkdiv1_dp_inclk_select;
ch1_in_chnl_ctrl_33(13)   <= clkdiv1_csr_rcgb_cmu_sel;

-- preparing inputs to index_cram_map 
clkdiv2_init_inclk_select <= ch2_cmudividerdprioin_logic(INCLK_SELECT_DP_CLOCK_DIV_IDX);
clkdiv2_dp_rcgb_cmu_sel   <= ch2_out_chnl_ctrl_33(13);

-- using outputs from index_cram_map
ch2_cmudividerdprioout_phy(INCLK_SELECT_DP_CLOCK_DIV_IDX) <= clkdiv2_dp_inclk_select;
ch2_in_chnl_ctrl_33(13)   <= clkdiv2_csr_rcgb_cmu_sel;

-- preparing inputs to index_cram_map 
clkdiv3_init_inclk_select <= ch3_cmudividerdprioin_logic(INCLK_SELECT_DP_CLOCK_DIV_IDX);
clkdiv3_dp_rcgb_cmu_sel   <= ch3_out_chnl_ctrl_33(13);

-- using outputs from index_cram_map
ch3_cmudividerdprioout_phy(INCLK_SELECT_DP_CLOCK_DIV_IDX) <= clkdiv3_dp_inclk_select;
ch3_in_chnl_ctrl_33(13)   <= clkdiv3_csr_rcgb_cmu_sel;

-- preparing inputs to index_cram_map 
clkdiv4_init_inclk_select <= ch4_cmudividerdprioin_logic(INCLK_SELECT_DP_CLOCK_DIV_IDX);
clkdiv4_dp_rcgb_cmu_sel   <= ch4_out_chnl_ctrl_33(13);

-- using outputs from index_cram_map
ch4_cmudividerdprioout_phy(INCLK_SELECT_DP_CLOCK_DIV_IDX) <= clkdiv4_dp_inclk_select;
ch4_in_chnl_ctrl_33(13)   <= clkdiv4_csr_rcgb_cmu_sel;

-- preparing inputs to index_cram_map 
clkdiv5_init_inclk_select <= ch5_cmudividerdprioin_logic(INCLK_SELECT_DP_CLOCK_DIV_IDX);
clkdiv5_dp_rcgb_cmu_sel   <= ch5_out_chnl_ctrl_33(13);

-- using outputs from index_cram_map
ch5_cmudividerdprioout_phy(INCLK_SELECT_DP_CLOCK_DIV_IDX) <= clkdiv5_dp_inclk_select;
ch5_in_chnl_ctrl_33(13)   <= clkdiv5_csr_rcgb_cmu_sel;

--====================================================================
-- Instantiating the map resolver                                    =
--====================================================================

m_clksel_index_cram_map : stratixiv_hssi_cmu_dprio_map_index 
   GENERIC MAP (
       clkdiv0_inclk0_logical_to_physical_mapping  => clkdiv0_inclk0_logical_to_physical_mapping,
       clkdiv0_inclk1_logical_to_physical_mapping  => clkdiv0_inclk1_logical_to_physical_mapping,
       clkdiv1_inclk0_logical_to_physical_mapping  => clkdiv1_inclk0_logical_to_physical_mapping,
       clkdiv1_inclk1_logical_to_physical_mapping  => clkdiv1_inclk1_logical_to_physical_mapping,
       clkdiv2_inclk0_logical_to_physical_mapping  => clkdiv2_inclk0_logical_to_physical_mapping,
       clkdiv2_inclk1_logical_to_physical_mapping  => clkdiv2_inclk1_logical_to_physical_mapping,
       clkdiv3_inclk0_logical_to_physical_mapping  => clkdiv3_inclk0_logical_to_physical_mapping,
       clkdiv3_inclk1_logical_to_physical_mapping  => clkdiv3_inclk1_logical_to_physical_mapping,
       clkdiv4_inclk0_logical_to_physical_mapping  => clkdiv4_inclk0_logical_to_physical_mapping,
       clkdiv4_inclk1_logical_to_physical_mapping  => clkdiv4_inclk1_logical_to_physical_mapping,
       clkdiv5_inclk0_logical_to_physical_mapping  => clkdiv5_inclk0_logical_to_physical_mapping,
       clkdiv5_inclk1_logical_to_physical_mapping  => clkdiv5_inclk1_logical_to_physical_mapping,
       pll0_inclk0_logical_to_physical_mapping     => pll0_inclk0_logical_to_physical_mapping,
       pll0_inclk1_logical_to_physical_mapping     => pll0_inclk1_logical_to_physical_mapping,
       pll0_inclk2_logical_to_physical_mapping     => pll0_inclk2_logical_to_physical_mapping,
       pll0_inclk3_logical_to_physical_mapping     => pll0_inclk3_logical_to_physical_mapping,
       pll0_inclk4_logical_to_physical_mapping     => pll0_inclk4_logical_to_physical_mapping,
       pll0_inclk5_logical_to_physical_mapping     => pll0_inclk5_logical_to_physical_mapping,
       pll0_inclk6_logical_to_physical_mapping     => pll0_inclk6_logical_to_physical_mapping,
       pll0_inclk7_logical_to_physical_mapping     => pll0_inclk7_logical_to_physical_mapping,
       pll0_inclk8_logical_to_physical_mapping     => pll0_inclk8_logical_to_physical_mapping,
       pll0_inclk9_logical_to_physical_mapping     => pll0_inclk9_logical_to_physical_mapping,
       pll1_inclk0_logical_to_physical_mapping     => pll1_inclk0_logical_to_physical_mapping,
       pll1_inclk1_logical_to_physical_mapping     => pll1_inclk1_logical_to_physical_mapping,
       pll1_inclk2_logical_to_physical_mapping     => pll1_inclk2_logical_to_physical_mapping,
       pll1_inclk3_logical_to_physical_mapping     => pll1_inclk3_logical_to_physical_mapping,
       pll1_inclk4_logical_to_physical_mapping     => pll1_inclk4_logical_to_physical_mapping,
       pll1_inclk5_logical_to_physical_mapping     => pll1_inclk5_logical_to_physical_mapping,
       pll1_inclk6_logical_to_physical_mapping     => pll1_inclk6_logical_to_physical_mapping,
       pll1_inclk7_logical_to_physical_mapping     => pll1_inclk7_logical_to_physical_mapping,
       pll1_inclk8_logical_to_physical_mapping     => pll1_inclk8_logical_to_physical_mapping,
       pll1_inclk9_logical_to_physical_mapping     => pll1_inclk9_logical_to_physical_mapping,
       pll2_inclk0_logical_to_physical_mapping     => pll2_inclk0_logical_to_physical_mapping,
       pll2_inclk1_logical_to_physical_mapping     => pll2_inclk1_logical_to_physical_mapping,
       pll2_inclk2_logical_to_physical_mapping     => pll2_inclk2_logical_to_physical_mapping,
       pll2_inclk3_logical_to_physical_mapping     => pll2_inclk3_logical_to_physical_mapping,
       pll2_inclk4_logical_to_physical_mapping     => pll2_inclk4_logical_to_physical_mapping,
       pll2_inclk5_logical_to_physical_mapping     => pll2_inclk5_logical_to_physical_mapping,
       pll2_inclk6_logical_to_physical_mapping     => pll2_inclk6_logical_to_physical_mapping,
       pll2_inclk7_logical_to_physical_mapping     => pll2_inclk7_logical_to_physical_mapping,
       pll2_inclk8_logical_to_physical_mapping     => pll2_inclk8_logical_to_physical_mapping,
       pll2_inclk9_logical_to_physical_mapping     => pll2_inclk9_logical_to_physical_mapping,
       pll3_inclk0_logical_to_physical_mapping     => pll3_inclk0_logical_to_physical_mapping,
       pll3_inclk1_logical_to_physical_mapping     => pll3_inclk1_logical_to_physical_mapping,
       pll3_inclk2_logical_to_physical_mapping     => pll3_inclk2_logical_to_physical_mapping,
       pll3_inclk3_logical_to_physical_mapping     => pll3_inclk3_logical_to_physical_mapping,
       pll3_inclk4_logical_to_physical_mapping     => pll3_inclk4_logical_to_physical_mapping,
       pll3_inclk5_logical_to_physical_mapping     => pll3_inclk5_logical_to_physical_mapping,
       pll3_inclk6_logical_to_physical_mapping     => pll3_inclk6_logical_to_physical_mapping,
       pll3_inclk7_logical_to_physical_mapping     => pll3_inclk7_logical_to_physical_mapping,
       pll3_inclk8_logical_to_physical_mapping     => pll3_inclk8_logical_to_physical_mapping,
       pll3_inclk9_logical_to_physical_mapping     => pll3_inclk9_logical_to_physical_mapping,
       pll4_inclk0_logical_to_physical_mapping     => pll4_inclk0_logical_to_physical_mapping,
       pll4_inclk1_logical_to_physical_mapping     => pll4_inclk1_logical_to_physical_mapping,
       pll4_inclk2_logical_to_physical_mapping     => pll4_inclk2_logical_to_physical_mapping,
       pll4_inclk3_logical_to_physical_mapping     => pll4_inclk3_logical_to_physical_mapping,
       pll4_inclk4_logical_to_physical_mapping     => pll4_inclk4_logical_to_physical_mapping,
       pll4_inclk5_logical_to_physical_mapping     => pll4_inclk5_logical_to_physical_mapping,
       pll4_inclk6_logical_to_physical_mapping     => pll4_inclk6_logical_to_physical_mapping,
       pll4_inclk7_logical_to_physical_mapping     => pll4_inclk7_logical_to_physical_mapping,
       pll4_inclk8_logical_to_physical_mapping     => pll4_inclk8_logical_to_physical_mapping,
       pll4_inclk9_logical_to_physical_mapping     => pll4_inclk9_logical_to_physical_mapping,
       pll5_inclk0_logical_to_physical_mapping     => pll5_inclk0_logical_to_physical_mapping,
       pll5_inclk1_logical_to_physical_mapping     => pll5_inclk1_logical_to_physical_mapping,
       pll5_inclk2_logical_to_physical_mapping     => pll5_inclk2_logical_to_physical_mapping,
       pll5_inclk3_logical_to_physical_mapping     => pll5_inclk3_logical_to_physical_mapping,
       pll5_inclk4_logical_to_physical_mapping     => pll5_inclk4_logical_to_physical_mapping,
       pll5_inclk5_logical_to_physical_mapping     => pll5_inclk5_logical_to_physical_mapping,
       pll5_inclk6_logical_to_physical_mapping     => pll5_inclk6_logical_to_physical_mapping,
       pll5_inclk7_logical_to_physical_mapping     => pll5_inclk7_logical_to_physical_mapping,
       pll5_inclk8_logical_to_physical_mapping     => pll5_inclk8_logical_to_physical_mapping,
       pll5_inclk9_logical_to_physical_mapping     => pll5_inclk9_logical_to_physical_mapping,
       pll0_logical_to_physical_mapping            => pll0_logical_to_physical_mapping,
       pll1_logical_to_physical_mapping            => pll1_logical_to_physical_mapping,
       pll2_logical_to_physical_mapping            => pll2_logical_to_physical_mapping,
       pll3_logical_to_physical_mapping            => pll3_logical_to_physical_mapping,
       pll4_logical_to_physical_mapping            => pll4_logical_to_physical_mapping,
       pll5_logical_to_physical_mapping            => pll5_logical_to_physical_mapping,
       refclk_divider0_logical_to_physical_mapping => refclk_divider0_logical_to_physical_mapping,
       refclk_divider1_logical_to_physical_mapping => refclk_divider1_logical_to_physical_mapping,
       rx0_logical_to_physical_mapping             => rx0_logical_to_physical_mapping,
       rx1_logical_to_physical_mapping             => rx1_logical_to_physical_mapping,
       rx2_logical_to_physical_mapping             => rx2_logical_to_physical_mapping,
       rx3_logical_to_physical_mapping             => rx3_logical_to_physical_mapping,
       rx4_logical_to_physical_mapping             => rx4_logical_to_physical_mapping,
       rx5_logical_to_physical_mapping             => rx5_logical_to_physical_mapping,
       tx0_logical_to_physical_mapping             => tx0_logical_to_physical_mapping,
       tx1_logical_to_physical_mapping             => tx1_logical_to_physical_mapping,
       tx2_logical_to_physical_mapping             => tx2_logical_to_physical_mapping,
       tx3_logical_to_physical_mapping             => tx3_logical_to_physical_mapping,
       tx4_logical_to_physical_mapping             => tx4_logical_to_physical_mapping,
       tx5_logical_to_physical_mapping             => tx5_logical_to_physical_mapping,
       tx0_pma_inclk0_logical_to_physical_mapping  => tx0_pma_inclk0_logical_to_physical_mapping,
       tx0_pma_inclk1_logical_to_physical_mapping  => tx0_pma_inclk1_logical_to_physical_mapping,
       tx0_pma_inclk2_logical_to_physical_mapping  => tx0_pma_inclk2_logical_to_physical_mapping,
       tx0_pma_inclk3_logical_to_physical_mapping  => tx0_pma_inclk3_logical_to_physical_mapping,
       tx0_pma_inclk4_logical_to_physical_mapping  => tx0_pma_inclk4_logical_to_physical_mapping,
       tx1_pma_inclk0_logical_to_physical_mapping  => tx1_pma_inclk0_logical_to_physical_mapping,
       tx1_pma_inclk1_logical_to_physical_mapping  => tx1_pma_inclk1_logical_to_physical_mapping,
       tx1_pma_inclk2_logical_to_physical_mapping  => tx1_pma_inclk2_logical_to_physical_mapping,
       tx1_pma_inclk3_logical_to_physical_mapping  => tx1_pma_inclk3_logical_to_physical_mapping,
       tx1_pma_inclk4_logical_to_physical_mapping  => tx1_pma_inclk4_logical_to_physical_mapping,
       tx2_pma_inclk0_logical_to_physical_mapping  => tx2_pma_inclk0_logical_to_physical_mapping,
       tx2_pma_inclk1_logical_to_physical_mapping  => tx2_pma_inclk1_logical_to_physical_mapping,
       tx2_pma_inclk2_logical_to_physical_mapping  => tx2_pma_inclk2_logical_to_physical_mapping,
       tx2_pma_inclk3_logical_to_physical_mapping  => tx2_pma_inclk3_logical_to_physical_mapping,
       tx2_pma_inclk4_logical_to_physical_mapping  => tx2_pma_inclk4_logical_to_physical_mapping,
       tx3_pma_inclk0_logical_to_physical_mapping  => tx3_pma_inclk0_logical_to_physical_mapping,
       tx3_pma_inclk1_logical_to_physical_mapping  => tx3_pma_inclk1_logical_to_physical_mapping,
       tx3_pma_inclk2_logical_to_physical_mapping  => tx3_pma_inclk2_logical_to_physical_mapping,
       tx3_pma_inclk3_logical_to_physical_mapping  => tx3_pma_inclk3_logical_to_physical_mapping,
       tx3_pma_inclk4_logical_to_physical_mapping  => tx3_pma_inclk4_logical_to_physical_mapping,
       tx4_pma_inclk0_logical_to_physical_mapping  => tx4_pma_inclk0_logical_to_physical_mapping,
       tx4_pma_inclk1_logical_to_physical_mapping  => tx4_pma_inclk1_logical_to_physical_mapping,
       tx4_pma_inclk2_logical_to_physical_mapping  => tx4_pma_inclk2_logical_to_physical_mapping,
       tx4_pma_inclk3_logical_to_physical_mapping  => tx4_pma_inclk3_logical_to_physical_mapping,
       tx4_pma_inclk4_logical_to_physical_mapping  => tx4_pma_inclk4_logical_to_physical_mapping,
       tx5_pma_inclk0_logical_to_physical_mapping  => tx5_pma_inclk0_logical_to_physical_mapping,
       tx5_pma_inclk1_logical_to_physical_mapping  => tx5_pma_inclk1_logical_to_physical_mapping,
       tx5_pma_inclk2_logical_to_physical_mapping  => tx5_pma_inclk2_logical_to_physical_mapping,
       tx5_pma_inclk3_logical_to_physical_mapping  => tx5_pma_inclk3_logical_to_physical_mapping,
       tx5_pma_inclk4_logical_to_physical_mapping  => tx5_pma_inclk4_logical_to_physical_mapping
   )
   PORT MAP (
       pll0_init_pfd_clk_sel  => pll0_init_pfd_clk_sel,   -- input
       pll0_csr_riqclk_sel    => pll0_csr_riqclk_sel,
       pll0_csr_rrefclk_sel   => pll0_csr_rrefclk_sel,
       pll0_dp_riqclk_sel     => pll0_dp_riqclk_sel,      -- input
       pll0_dp_rrefclk_sel    => pll0_dp_rrefclk_sel,     -- input
       pll0_dp_pfd_clk_sel    => pll0_dp_pfd_clk_sel,    
       pll1_init_pfd_clk_sel  => pll1_init_pfd_clk_sel,   -- input
       pll1_csr_riqclk_sel    => pll1_csr_riqclk_sel,
       pll1_csr_rrefclk_sel   => pll1_csr_rrefclk_sel,
       pll1_dp_riqclk_sel     => pll1_dp_riqclk_sel,      -- input
       pll1_dp_rrefclk_sel    => pll1_dp_rrefclk_sel,     -- input
       pll1_dp_pfd_clk_sel    => pll1_dp_pfd_clk_sel,     
       pll2_init_pfd_clk_sel  => pll2_init_pfd_clk_sel,   -- input
       pll2_csr_riqclk_sel    => pll2_csr_riqclk_sel,
       pll2_csr_rrefclk_sel   => pll2_csr_rrefclk_sel,
       pll2_dp_riqclk_sel     => pll2_dp_riqclk_sel,      -- input
       pll2_dp_rrefclk_sel    => pll2_dp_rrefclk_sel,     -- input
       pll2_dp_pfd_clk_sel    => pll2_dp_pfd_clk_sel,   
       pll3_init_pfd_clk_sel  => pll3_init_pfd_clk_sel,   -- input
       pll3_csr_riqclk_sel    => pll3_csr_riqclk_sel,
       pll3_csr_rrefclk_sel   => pll3_csr_rrefclk_sel,
       pll3_dp_riqclk_sel     => pll3_dp_riqclk_sel,      -- input
       pll3_dp_rrefclk_sel    => pll3_dp_rrefclk_sel,     -- input
       pll3_dp_pfd_clk_sel    => pll3_dp_pfd_clk_sel,    
       pll4_init_pfd_clk_sel  => pll4_init_pfd_clk_sel,   -- input
       pll4_csr_riqclk_sel    => pll4_csr_riqclk_sel,
       pll4_csr_rrefclk_sel   => pll4_csr_rrefclk_sel,
       pll4_dp_riqclk_sel     => pll4_dp_riqclk_sel,      -- input
       pll4_dp_rrefclk_sel    => pll4_dp_rrefclk_sel,     -- input
       pll4_dp_pfd_clk_sel    => pll4_dp_pfd_clk_sel,     
       pll5_init_pfd_clk_sel  => pll5_init_pfd_clk_sel,   -- input
       pll5_csr_riqclk_sel    => pll5_csr_riqclk_sel,
       pll5_csr_rrefclk_sel   => pll5_csr_rrefclk_sel,
       pll5_dp_riqclk_sel     => pll5_dp_riqclk_sel,      -- input
       pll5_dp_rrefclk_sel    => pll5_dp_rrefclk_sel,     -- input
       pll5_dp_pfd_clk_sel    => pll5_dp_pfd_clk_sel,
       
       txpma0_init_clkin_sel  => txpma0_init_clkin_sel, -- input
       txpma0_csr_rcgb_x_en   => txpma0_csr_rcgb_x_en,  
       txpma0_dp_rcgb_x_en    => txpma0_dp_rcgb_x_en,   -- input
       txpma0_dp_clkin_sel    => txpma0_dp_clkin_sel,   
       txpma1_init_clkin_sel  => txpma1_init_clkin_sel, -- input
       txpma1_csr_rcgb_x_en   => txpma1_csr_rcgb_x_en,  
       txpma1_dp_rcgb_x_en    => txpma1_dp_rcgb_x_en,   -- input
       txpma1_dp_clkin_sel    => txpma1_dp_clkin_sel,   
       txpma2_init_clkin_sel  => txpma2_init_clkin_sel, -- input
       txpma2_csr_rcgb_x_en   => txpma2_csr_rcgb_x_en,  
       txpma2_dp_rcgb_x_en    => txpma2_dp_rcgb_x_en,   -- input
       txpma2_dp_clkin_sel    => txpma2_dp_clkin_sel,   
       txpma3_init_clkin_sel  => txpma3_init_clkin_sel, -- input
       txpma3_csr_rcgb_x_en   => txpma3_csr_rcgb_x_en,  
       txpma3_dp_rcgb_x_en    => txpma3_dp_rcgb_x_en,   -- input
       txpma3_dp_clkin_sel    => txpma3_dp_clkin_sel,   
       txpma4_init_clkin_sel  => txpma4_init_clkin_sel, -- input
       txpma4_csr_rcgb_x_en   => txpma4_csr_rcgb_x_en,  
       txpma4_dp_rcgb_x_en    => txpma4_dp_rcgb_x_en,   -- input
       txpma4_dp_clkin_sel    => txpma4_dp_clkin_sel,   
       txpma5_init_clkin_sel  => txpma5_init_clkin_sel, -- input
       txpma5_csr_rcgb_x_en   => txpma5_csr_rcgb_x_en,  
       txpma5_dp_rcgb_x_en    => txpma5_dp_rcgb_x_en,   -- input
       txpma5_dp_clkin_sel    => txpma5_dp_clkin_sel,
       
       clkdiv0_init_inclk_select => clkdiv0_init_inclk_select,
       clkdiv0_csr_rcgb_cmu_sel  => clkdiv0_csr_rcgb_cmu_sel,
       clkdiv0_dp_rcgb_cmu_sel   => clkdiv0_dp_rcgb_cmu_sel,
       clkdiv0_dp_inclk_select   => clkdiv0_dp_inclk_select,
       clkdiv1_init_inclk_select => clkdiv1_init_inclk_select,
       clkdiv1_csr_rcgb_cmu_sel  => clkdiv1_csr_rcgb_cmu_sel,
       clkdiv1_dp_rcgb_cmu_sel   => clkdiv1_dp_rcgb_cmu_sel,
       clkdiv1_dp_inclk_select   => clkdiv1_dp_inclk_select,
       clkdiv2_init_inclk_select => clkdiv2_init_inclk_select,
       clkdiv2_csr_rcgb_cmu_sel  => clkdiv2_csr_rcgb_cmu_sel,
       clkdiv2_dp_rcgb_cmu_sel   => clkdiv2_dp_rcgb_cmu_sel,
       clkdiv2_dp_inclk_select   => clkdiv2_dp_inclk_select,
       clkdiv3_init_inclk_select => clkdiv3_init_inclk_select,
       clkdiv3_csr_rcgb_cmu_sel  => clkdiv3_csr_rcgb_cmu_sel,
       clkdiv3_dp_rcgb_cmu_sel   => clkdiv3_dp_rcgb_cmu_sel,
       clkdiv3_dp_inclk_select   => clkdiv3_dp_inclk_select,
       clkdiv4_init_inclk_select => clkdiv4_init_inclk_select,
       clkdiv4_csr_rcgb_cmu_sel  => clkdiv4_csr_rcgb_cmu_sel,
       clkdiv4_dp_rcgb_cmu_sel   => clkdiv4_dp_rcgb_cmu_sel,
       clkdiv4_dp_inclk_select   => clkdiv4_dp_inclk_select,
       clkdiv5_init_inclk_select => clkdiv5_init_inclk_select,
       clkdiv5_csr_rcgb_cmu_sel  => clkdiv5_csr_rcgb_cmu_sel,
       clkdiv5_dp_rcgb_cmu_sel   => clkdiv5_dp_rcgb_cmu_sel,
       clkdiv5_dp_inclk_select   => clkdiv5_dp_inclk_select
);

--====================================================================
-- Manually added code to handle logical indices                     =
-- === end                                                           =
--====================================================================

-- ------- physical to logic mapping -------------------------
-- TXPCS
ch0_txpcsdprioout_logic <= ch0_txpcsdprioout_phy WHEN (tx0_logical_to_physical_mapping = 0) ELSE
							ch1_txpcsdprioout_phy WHEN (tx0_logical_to_physical_mapping = 1) ELSE
							ch2_txpcsdprioout_phy WHEN (tx0_logical_to_physical_mapping = 2) ELSE
							ch3_txpcsdprioout_phy WHEN (tx0_logical_to_physical_mapping = 3) ELSE
							ch0_txpcsdprioout_phy;

ch1_txpcsdprioout_logic <= ch0_txpcsdprioout_phy WHEN (tx1_logical_to_physical_mapping = 0) ELSE
							ch1_txpcsdprioout_phy WHEN (tx1_logical_to_physical_mapping = 1) ELSE
							ch2_txpcsdprioout_phy WHEN (tx1_logical_to_physical_mapping = 2) ELSE
							ch3_txpcsdprioout_phy WHEN (tx1_logical_to_physical_mapping = 3) ELSE
							ch1_txpcsdprioout_phy;

ch2_txpcsdprioout_logic <= ch0_txpcsdprioout_phy WHEN (tx2_logical_to_physical_mapping = 0) ELSE
							ch1_txpcsdprioout_phy WHEN (tx2_logical_to_physical_mapping = 1) ELSE
							ch2_txpcsdprioout_phy WHEN (tx2_logical_to_physical_mapping = 2) ELSE
							ch3_txpcsdprioout_phy WHEN (tx2_logical_to_physical_mapping = 3) ELSE
							ch2_txpcsdprioout_phy;

ch3_txpcsdprioout_logic <= ch0_txpcsdprioout_phy WHEN (tx3_logical_to_physical_mapping = 0) ELSE
							ch1_txpcsdprioout_phy WHEN (tx3_logical_to_physical_mapping = 1) ELSE
							ch2_txpcsdprioout_phy WHEN (tx3_logical_to_physical_mapping = 2) ELSE
							ch3_txpcsdprioout_phy WHEN (tx3_logical_to_physical_mapping = 3) ELSE
							ch3_txpcsdprioout_phy;

-- RXPCS
ch0_rxpcsdprioout_logic <= ch0_rxpcsdprioout_phy WHEN (rx0_logical_to_physical_mapping = 0) ELSE
							ch1_rxpcsdprioout_phy WHEN (rx0_logical_to_physical_mapping = 1) ELSE
							ch2_rxpcsdprioout_phy WHEN (rx0_logical_to_physical_mapping = 2) ELSE
							ch3_rxpcsdprioout_phy WHEN (rx0_logical_to_physical_mapping = 3) ELSE
							ch0_rxpcsdprioout_phy;

ch1_rxpcsdprioout_logic <= ch0_rxpcsdprioout_phy WHEN (rx1_logical_to_physical_mapping = 0) ELSE
							ch1_rxpcsdprioout_phy WHEN (rx1_logical_to_physical_mapping = 1) ELSE
							ch2_rxpcsdprioout_phy WHEN (rx1_logical_to_physical_mapping = 2) ELSE
							ch3_rxpcsdprioout_phy WHEN (rx1_logical_to_physical_mapping = 3) ELSE
							ch1_rxpcsdprioout_phy;

ch2_rxpcsdprioout_logic <= ch0_rxpcsdprioout_phy WHEN (rx2_logical_to_physical_mapping = 0) ELSE
							ch1_rxpcsdprioout_phy WHEN (rx2_logical_to_physical_mapping = 1) ELSE
							ch2_rxpcsdprioout_phy WHEN (rx2_logical_to_physical_mapping = 2) ELSE
							ch3_rxpcsdprioout_phy WHEN (rx2_logical_to_physical_mapping = 3) ELSE
							ch2_rxpcsdprioout_phy;

ch3_rxpcsdprioout_logic <= ch0_rxpcsdprioout_phy WHEN (rx3_logical_to_physical_mapping = 0) ELSE
							ch1_rxpcsdprioout_phy WHEN (rx3_logical_to_physical_mapping = 1) ELSE
							ch2_rxpcsdprioout_phy WHEN (rx3_logical_to_physical_mapping = 2) ELSE
							ch3_rxpcsdprioout_phy WHEN (rx3_logical_to_physical_mapping = 3) ELSE
							ch3_rxpcsdprioout_phy;

-- TXPMA
ch0_txpmadprioout_logic <= ch0_txpmadprioout_phy WHEN (tx0_logical_to_physical_mapping = 0)  ELSE
                           ch1_txpmadprioout_phy WHEN (tx0_logical_to_physical_mapping = 1)  ELSE
                           ch2_txpmadprioout_phy WHEN (tx0_logical_to_physical_mapping = 2)  ELSE
                           ch3_txpmadprioout_phy WHEN (tx0_logical_to_physical_mapping = 3)  ELSE
                           ch4_txpmadprioout_phy WHEN (tx0_logical_to_physical_mapping = 4)  ELSE
                           ch5_txpmadprioout_phy WHEN (tx0_logical_to_physical_mapping = 5)  ELSE
                           ch0_txpmadprioout_phy;

ch1_txpmadprioout_logic <= ch0_txpmadprioout_phy WHEN (tx1_logical_to_physical_mapping = 0)  ELSE
                           ch1_txpmadprioout_phy WHEN (tx1_logical_to_physical_mapping = 1)  ELSE
                           ch2_txpmadprioout_phy WHEN (tx1_logical_to_physical_mapping = 2)  ELSE
                           ch3_txpmadprioout_phy WHEN (tx1_logical_to_physical_mapping = 3)  ELSE
                           ch4_txpmadprioout_phy WHEN (tx1_logical_to_physical_mapping = 4)  ELSE
                           ch5_txpmadprioout_phy WHEN (tx1_logical_to_physical_mapping = 5)  ELSE
                           ch1_txpmadprioout_phy;

ch2_txpmadprioout_logic <= ch0_txpmadprioout_phy WHEN (tx2_logical_to_physical_mapping = 0)  ELSE
                           ch1_txpmadprioout_phy WHEN (tx2_logical_to_physical_mapping = 1)  ELSE
                           ch2_txpmadprioout_phy WHEN (tx2_logical_to_physical_mapping = 2)  ELSE
                           ch3_txpmadprioout_phy WHEN (tx2_logical_to_physical_mapping = 3)  ELSE
                           ch4_txpmadprioout_phy WHEN (tx2_logical_to_physical_mapping = 4)  ELSE
                           ch5_txpmadprioout_phy WHEN (tx2_logical_to_physical_mapping = 5)  ELSE
                           ch2_txpmadprioout_phy;

ch3_txpmadprioout_logic <= ch0_txpmadprioout_phy WHEN (tx3_logical_to_physical_mapping = 0)  ELSE
                           ch1_txpmadprioout_phy WHEN (tx3_logical_to_physical_mapping = 1)  ELSE
                           ch2_txpmadprioout_phy WHEN (tx3_logical_to_physical_mapping = 2)  ELSE
                           ch3_txpmadprioout_phy WHEN (tx3_logical_to_physical_mapping = 3)  ELSE
                           ch4_txpmadprioout_phy WHEN (tx3_logical_to_physical_mapping = 4)  ELSE
                           ch5_txpmadprioout_phy WHEN (tx3_logical_to_physical_mapping = 5)  ELSE
                           ch3_txpmadprioout_phy;

ch4_txpmadprioout_logic <= ch0_txpmadprioout_phy WHEN (tx4_logical_to_physical_mapping = 0)  ELSE
                           ch1_txpmadprioout_phy WHEN (tx4_logical_to_physical_mapping = 1)  ELSE
                           ch2_txpmadprioout_phy WHEN (tx4_logical_to_physical_mapping = 2)  ELSE
                           ch3_txpmadprioout_phy WHEN (tx4_logical_to_physical_mapping = 3)  ELSE
                           ch4_txpmadprioout_phy WHEN (tx4_logical_to_physical_mapping = 4)  ELSE
                           ch5_txpmadprioout_phy WHEN (tx4_logical_to_physical_mapping = 5)  ELSE
                           ch4_txpmadprioout_phy;

ch5_txpmadprioout_logic <= ch0_txpmadprioout_phy WHEN (tx5_logical_to_physical_mapping = 0)  ELSE
                           ch1_txpmadprioout_phy WHEN (tx5_logical_to_physical_mapping = 1)  ELSE
                           ch2_txpmadprioout_phy WHEN (tx5_logical_to_physical_mapping = 2)  ELSE
                           ch3_txpmadprioout_phy WHEN (tx5_logical_to_physical_mapping = 3)  ELSE
                           ch4_txpmadprioout_phy WHEN (tx5_logical_to_physical_mapping = 4)  ELSE
                           ch5_txpmadprioout_phy WHEN (tx5_logical_to_physical_mapping = 5)  ELSE
                           ch5_txpmadprioout_phy;
                           
-- RXPMA
ch0_rxpmadprioout_logic <= ch0_rxpmadprioout_phy WHEN (rx0_logical_to_physical_mapping = 0)  ELSE
                           ch1_rxpmadprioout_phy WHEN (rx0_logical_to_physical_mapping = 1)  ELSE
                           ch2_rxpmadprioout_phy WHEN (rx0_logical_to_physical_mapping = 2)  ELSE
                           ch3_rxpmadprioout_phy WHEN (rx0_logical_to_physical_mapping = 3)  ELSE
                           ch4_rxpmadprioout_phy WHEN (rx0_logical_to_physical_mapping = 4)  ELSE
                           ch5_rxpmadprioout_phy WHEN (rx0_logical_to_physical_mapping = 5)  ELSE
                           ch0_rxpmadprioout_phy;

ch1_rxpmadprioout_logic <= ch0_rxpmadprioout_phy WHEN (rx1_logical_to_physical_mapping = 0)  ELSE
                           ch1_rxpmadprioout_phy WHEN (rx1_logical_to_physical_mapping = 1)  ELSE
                           ch2_rxpmadprioout_phy WHEN (rx1_logical_to_physical_mapping = 2)  ELSE
                           ch3_rxpmadprioout_phy WHEN (rx1_logical_to_physical_mapping = 3)  ELSE
                           ch4_rxpmadprioout_phy WHEN (rx1_logical_to_physical_mapping = 4)  ELSE
                           ch5_rxpmadprioout_phy WHEN (rx1_logical_to_physical_mapping = 5)  ELSE
                           ch1_rxpmadprioout_phy;

ch2_rxpmadprioout_logic <= ch0_rxpmadprioout_phy WHEN (rx2_logical_to_physical_mapping = 0)  ELSE
                           ch1_rxpmadprioout_phy WHEN (rx2_logical_to_physical_mapping = 1)  ELSE
                           ch2_rxpmadprioout_phy WHEN (rx2_logical_to_physical_mapping = 2)  ELSE
                           ch3_rxpmadprioout_phy WHEN (rx2_logical_to_physical_mapping = 3)  ELSE
                           ch4_rxpmadprioout_phy WHEN (rx2_logical_to_physical_mapping = 4)  ELSE
                           ch5_rxpmadprioout_phy WHEN (rx2_logical_to_physical_mapping = 5)  ELSE
                           ch2_rxpmadprioout_phy;

ch3_rxpmadprioout_logic <= ch0_rxpmadprioout_phy WHEN (rx3_logical_to_physical_mapping = 0)  ELSE
                           ch1_rxpmadprioout_phy WHEN (rx3_logical_to_physical_mapping = 1)  ELSE
                           ch2_rxpmadprioout_phy WHEN (rx3_logical_to_physical_mapping = 2)  ELSE
                           ch3_rxpmadprioout_phy WHEN (rx3_logical_to_physical_mapping = 3)  ELSE
                           ch4_rxpmadprioout_phy WHEN (rx3_logical_to_physical_mapping = 4)  ELSE
                           ch5_rxpmadprioout_phy WHEN (rx3_logical_to_physical_mapping = 5)  ELSE
                           ch3_rxpmadprioout_phy;

ch4_rxpmadprioout_logic <= ch0_rxpmadprioout_phy WHEN (rx4_logical_to_physical_mapping = 0)  ELSE
                           ch1_rxpmadprioout_phy WHEN (rx4_logical_to_physical_mapping = 1)  ELSE
                           ch2_rxpmadprioout_phy WHEN (rx4_logical_to_physical_mapping = 2)  ELSE
                           ch3_rxpmadprioout_phy WHEN (rx4_logical_to_physical_mapping = 3)  ELSE
                           ch4_rxpmadprioout_phy WHEN (rx4_logical_to_physical_mapping = 4)  ELSE
                           ch5_rxpmadprioout_phy WHEN (rx4_logical_to_physical_mapping = 5)  ELSE
                           ch4_rxpmadprioout_phy;

ch5_rxpmadprioout_logic <= ch0_rxpmadprioout_phy WHEN (rx5_logical_to_physical_mapping = 0)  ELSE
                           ch1_rxpmadprioout_phy WHEN (rx5_logical_to_physical_mapping = 1)  ELSE
                           ch2_rxpmadprioout_phy WHEN (rx5_logical_to_physical_mapping = 2)  ELSE
                           ch3_rxpmadprioout_phy WHEN (rx5_logical_to_physical_mapping = 3)  ELSE
                           ch4_rxpmadprioout_phy WHEN (rx5_logical_to_physical_mapping = 4)  ELSE
                           ch5_rxpmadprioout_phy WHEN (rx5_logical_to_physical_mapping = 5)  ELSE
                           ch5_rxpmadprioout_phy;
                           
-- PLL
ch0_rxplldprioout_logic <= ch0_rxplldprioout_phy WHEN (pll0_logical_to_physical_mapping = 0)  ELSE 
                           ch1_rxplldprioout_phy WHEN (pll0_logical_to_physical_mapping = 1)  ELSE 
                           ch2_rxplldprioout_phy WHEN (pll0_logical_to_physical_mapping = 2)  ELSE 
                           ch3_rxplldprioout_phy WHEN (pll0_logical_to_physical_mapping = 3)  ELSE 
                           ch0_rxplldprioout_phy;

ch1_rxplldprioout_logic <= ch0_rxplldprioout_phy WHEN (pll1_logical_to_physical_mapping = 0)  ELSE 
                           ch1_rxplldprioout_phy WHEN (pll1_logical_to_physical_mapping = 1)  ELSE 
                           ch2_rxplldprioout_phy WHEN (pll1_logical_to_physical_mapping = 2)  ELSE 
                           ch3_rxplldprioout_phy WHEN (pll1_logical_to_physical_mapping = 3)  ELSE 
                           ch1_rxplldprioout_phy;

ch2_rxplldprioout_logic <= ch0_rxplldprioout_phy WHEN (pll2_logical_to_physical_mapping = 0)  ELSE 
                           ch1_rxplldprioout_phy WHEN (pll2_logical_to_physical_mapping = 1)  ELSE 
                           ch2_rxplldprioout_phy WHEN (pll2_logical_to_physical_mapping = 2)  ELSE 
                           ch3_rxplldprioout_phy WHEN (pll2_logical_to_physical_mapping = 3)  ELSE 
                           ch2_rxplldprioout_phy;

ch3_rxplldprioout_logic <= ch0_rxplldprioout_phy WHEN (pll3_logical_to_physical_mapping = 0)  ELSE 
                           ch1_rxplldprioout_phy WHEN (pll3_logical_to_physical_mapping = 1)  ELSE 
                           ch2_rxplldprioout_phy WHEN (pll3_logical_to_physical_mapping = 2)  ELSE 
                           ch3_rxplldprioout_phy WHEN (pll3_logical_to_physical_mapping = 3)  ELSE 
                           ch3_rxplldprioout_phy;

ch4_rxtxplldprioout_logic <= ch4_rxtxplldprioout_phy WHEN (pll4_logical_to_physical_mapping = 4) ELSE
                             ch5_rxtxplldprioin_phy;
                                  
ch5_rxtxplldprioout_logic <= ch5_rxtxplldprioout_phy WHEN (pll5_logical_to_physical_mapping = 5) ELSE
                             ch4_rxtxplldprioin_phy;
                             
-- CMUDivider
ch0_cmudividerdprioout_logic <= ch0_cmudividerdprioout_phy WHEN (tx0_logical_to_physical_mapping = 0) ELSE  
                                ch1_cmudividerdprioout_phy WHEN (tx0_logical_to_physical_mapping = 1) ELSE  
                                ch2_cmudividerdprioout_phy WHEN (tx0_logical_to_physical_mapping = 2) ELSE  
                                ch3_cmudividerdprioout_phy WHEN (tx0_logical_to_physical_mapping = 3) ELSE  
                                ch4_cmudividerdprioout_phy WHEN (tx0_logical_to_physical_mapping = 4) ELSE  
                                ch5_cmudividerdprioout_phy WHEN (tx0_logical_to_physical_mapping = 5) ELSE  
                                ch0_cmudividerdprioout_phy;
                                 
ch1_cmudividerdprioout_logic <= ch0_cmudividerdprioout_phy WHEN (tx1_logical_to_physical_mapping = 0) ELSE  
                                ch1_cmudividerdprioout_phy WHEN (tx1_logical_to_physical_mapping = 1) ELSE  
                                ch2_cmudividerdprioout_phy WHEN (tx1_logical_to_physical_mapping = 2) ELSE  
                                ch3_cmudividerdprioout_phy WHEN (tx1_logical_to_physical_mapping = 3) ELSE  
                                ch4_cmudividerdprioout_phy WHEN (tx1_logical_to_physical_mapping = 4) ELSE  
                                ch5_cmudividerdprioout_phy WHEN (tx1_logical_to_physical_mapping = 5) ELSE  
                                ch1_cmudividerdprioout_phy;
                                 
ch2_cmudividerdprioout_logic <= ch0_cmudividerdprioout_phy WHEN (tx2_logical_to_physical_mapping = 0) ELSE  
                                ch1_cmudividerdprioout_phy WHEN (tx2_logical_to_physical_mapping = 1) ELSE  
                                ch2_cmudividerdprioout_phy WHEN (tx2_logical_to_physical_mapping = 2) ELSE  
                                ch3_cmudividerdprioout_phy WHEN (tx2_logical_to_physical_mapping = 3) ELSE  
                                ch4_cmudividerdprioout_phy WHEN (tx2_logical_to_physical_mapping = 4) ELSE  
                                ch5_cmudividerdprioout_phy WHEN (tx2_logical_to_physical_mapping = 5) ELSE  
                                ch2_cmudividerdprioout_phy;
                                 
ch3_cmudividerdprioout_logic <= ch0_cmudividerdprioout_phy WHEN (tx3_logical_to_physical_mapping = 0) ELSE  
                                ch1_cmudividerdprioout_phy WHEN (tx3_logical_to_physical_mapping = 1) ELSE  
                                ch2_cmudividerdprioout_phy WHEN (tx3_logical_to_physical_mapping = 2) ELSE  
                                ch3_cmudividerdprioout_phy WHEN (tx3_logical_to_physical_mapping = 3) ELSE  
                                ch4_cmudividerdprioout_phy WHEN (tx3_logical_to_physical_mapping = 4) ELSE  
                                ch5_cmudividerdprioout_phy WHEN (tx3_logical_to_physical_mapping = 5) ELSE  
                                ch3_cmudividerdprioout_phy;
                                 
ch4_cmudividerdprioout_logic <= ch0_cmudividerdprioout_phy WHEN (tx4_logical_to_physical_mapping = 0) ELSE  
                                ch1_cmudividerdprioout_phy WHEN (tx4_logical_to_physical_mapping = 1) ELSE  
                                ch2_cmudividerdprioout_phy WHEN (tx4_logical_to_physical_mapping = 2) ELSE  
                                ch3_cmudividerdprioout_phy WHEN (tx4_logical_to_physical_mapping = 3) ELSE  
                                ch4_cmudividerdprioout_phy WHEN (tx4_logical_to_physical_mapping = 4) ELSE  
                                ch5_cmudividerdprioout_phy WHEN (tx4_logical_to_physical_mapping = 5) ELSE  
                                ch4_cmudividerdprioout_phy;
                                 
ch5_cmudividerdprioout_logic <= ch0_cmudividerdprioout_phy WHEN (tx5_logical_to_physical_mapping = 0) ELSE  
                                ch1_cmudividerdprioout_phy WHEN (tx5_logical_to_physical_mapping = 1) ELSE  
                                ch2_cmudividerdprioout_phy WHEN (tx5_logical_to_physical_mapping = 2) ELSE  
                                ch3_cmudividerdprioout_phy WHEN (tx5_logical_to_physical_mapping = 3) ELSE  
                                ch4_cmudividerdprioout_phy WHEN (tx5_logical_to_physical_mapping = 4) ELSE  
                                ch5_cmudividerdprioout_phy WHEN (tx5_logical_to_physical_mapping = 5) ELSE  
                                ch5_cmudividerdprioout_phy;

-- ------- output --------------------------------------------
-- TXPCS
txpcsdprioout(149 DOWNTO 0) <= ch0_txpcsdprioout_logic;
txpcsdprioout(299 DOWNTO 150) <= ch1_txpcsdprioout_logic;
txpcsdprioout(449 DOWNTO 300) <= ch2_txpcsdprioout_logic;
txpcsdprioout(599 DOWNTO 450) <= ch3_txpcsdprioout_logic;
-- RXPCS
rxpcsdprioout(399 DOWNTO 0) <= ch0_rxpcsdprioout_logic;
rxpcsdprioout(799 DOWNTO 400) <= ch1_rxpcsdprioout_logic;
rxpcsdprioout(1199 DOWNTO 800) <= ch2_rxpcsdprioout_logic;
rxpcsdprioout(1599 DOWNTO 1200) <= ch3_rxpcsdprioout_logic;
-- TXPMA
txpmadprioout(299 DOWNTO 0) <= ch0_txpmadprioout_logic;
txpmadprioout(599 DOWNTO 300) <= ch1_txpmadprioout_logic;
txpmadprioout(899 DOWNTO 600) <= ch2_txpmadprioout_logic;
txpmadprioout(1199 DOWNTO 900) <= ch3_txpmadprioout_logic;
txpmadprioout(1499 DOWNTO 1200) <= ch4_txpmadprioout_logic;
txpmadprioout(1799 DOWNTO 1500) <= ch5_txpmadprioout_logic;
-- RXPMA
rxpmadprioout(299 DOWNTO 0) <= ch0_rxpmadprioout_logic;
rxpmadprioout(599 DOWNTO 300) <= ch1_rxpmadprioout_logic;
rxpmadprioout(899 DOWNTO 600) <= ch2_rxpmadprioout_logic;
rxpmadprioout(1199 DOWNTO 900) <= ch3_rxpmadprioout_logic;
rxpmadprioout(1499 DOWNTO 1200) <= ch4_rxpmadprioout_logic;
rxpmadprioout(1799 DOWNTO 1500) <= ch5_rxpmadprioout_logic;
-- PLL
cmuplldprioout(299 DOWNTO 0) <= ch0_rxplldprioout_logic;
cmuplldprioout(599 DOWNTO 300) <= ch1_rxplldprioout_logic;
cmuplldprioout(899 DOWNTO 600) <= ch2_rxplldprioout_logic;
cmuplldprioout(1199 DOWNTO 900) <= ch3_rxplldprioout_logic;
cmuplldprioout(1499 DOWNTO 1200) <= ch4_rxtxplldprioout_logic;
cmuplldprioout(1799 DOWNTO 1500) <= ch5_rxtxplldprioout_logic;

-- CMUDivider
cmudividerdprioout (99 DOWNTO 0) <= ch0_cmudividerdprioout_logic;
cmudividerdprioout (199 DOWNTO 100) <= ch1_cmudividerdprioout_logic;
cmudividerdprioout (299 DOWNTO 200) <= ch2_cmudividerdprioout_logic;
cmudividerdprioout (399 DOWNTO 300) <= ch3_cmudividerdprioout_logic;
cmudividerdprioout (499 DOWNTO 400) <= ch4_cmudividerdprioout_logic;
cmudividerdprioout (599 DOWNTO 500) <= ch5_cmudividerdprioout_logic;


--============================================================
-- Manually added code to handle 5th/6th PMA =================
-- === begin                                                 =
--============================================================

-- centrl CSR physcial ---------------------------------------
cmu0_in_centrl_ctrl_1  <= ch4_in_chnl_ctrl_28;
cmu0_in_centrl_ctrl_2  <= ch4_in_chnl_ctrl_29;
cmu0_in_centrl_ctrl_3  <= ch4_in_chnl_ctrl_30;
cmu0_in_centrl_ctrl_4  <= ch4_in_chnl_ctrl_31;
cmu0_in_centrl_ctrl_5  <= ch4_in_chnl_ctrl_32;
cmu0_in_centrl_ctrl_6  <= ch4_in_chnl_ctrl_33;
cmu0_in_centrl_ctrl_7  <= ch4_in_chnl_ctrl_34;
cmu0_in_centrl_ctrl_8  <= ch4_in_chnl_ctrl_35;
cmu0_in_centrl_ctrl_9  <= ch4_in_chnl_ctrl_36;
cmu0_in_centrl_ctrl_10 <= ch4_in_chnl_ctrl_37;
cmu0_in_centrl_ctrl_11 <= ch4_in_chnl_ctrl_38;
cmu0_in_centrl_ctrl_12 <= ch4_in_chnl_ctrl_39;
cmu0_in_centrl_ctrl_13 <= ch4_in_chnl_ctrl_40;
cmu0_in_centrl_ctrl_14 <= ch4_in_chnl_ctrl_41;
cmu0_in_centrl_ctrl_15 <= ch4_in_chnl_ctrl_42;
cmu0_in_centrl_ctrl_16 <= ch4_in_chnl_ctrl_43;
cmu0_in_centrl_ctrl_17 <= ch4_in_chnl_ctrl_44;
cmu0_in_centrl_ctrl_18 <= ch4_in_chnl_ctrl_45;
cmu0_in_centrl_ctrl_19 <= ch4_in_chnl_ctrl_46;
cmu0_in_centrl_ctrl_20 <= ch4_in_chnl_ctrl_47;

cmu1_in_centrl_ctrl_1  <= ch5_in_chnl_ctrl_28;
cmu1_in_centrl_ctrl_2  <= ch5_in_chnl_ctrl_29;
cmu1_in_centrl_ctrl_3  <= ch5_in_chnl_ctrl_30;
cmu1_in_centrl_ctrl_4  <= ch5_in_chnl_ctrl_31;
cmu1_in_centrl_ctrl_5  <= ch5_in_chnl_ctrl_32;
cmu1_in_centrl_ctrl_6  <= ch5_in_chnl_ctrl_33;
cmu1_in_centrl_ctrl_7  <= ch5_in_chnl_ctrl_34;
cmu1_in_centrl_ctrl_8  <= ch5_in_chnl_ctrl_35;
cmu1_in_centrl_ctrl_9  <= ch5_in_chnl_ctrl_36;
cmu1_in_centrl_ctrl_10 <= ch5_in_chnl_ctrl_37;
cmu1_in_centrl_ctrl_11 <= ch5_in_chnl_ctrl_38;
cmu1_in_centrl_ctrl_12 <= ch5_in_chnl_ctrl_39;
cmu1_in_centrl_ctrl_13 <= ch5_in_chnl_ctrl_40;
cmu1_in_centrl_ctrl_14 <= ch5_in_chnl_ctrl_41;
cmu1_in_centrl_ctrl_15 <= ch5_in_chnl_ctrl_42;
cmu1_in_centrl_ctrl_16 <= ch5_in_chnl_ctrl_43;
cmu1_in_centrl_ctrl_17 <= ch5_in_chnl_ctrl_44;
cmu1_in_centrl_ctrl_18 <= ch5_in_chnl_ctrl_45;
cmu1_in_centrl_ctrl_19 <= ch5_in_chnl_ctrl_46;
cmu1_in_centrl_ctrl_20 <= ch5_in_chnl_ctrl_47;

csr_centrl_in(15 DOWNTO 0)    <= cmu0_in_centrl_ctrl_1;
csr_centrl_in(31 DOWNTO 16)   <= cmu0_in_centrl_ctrl_2;
csr_centrl_in(47 DOWNTO 32)   <= cmu0_in_centrl_ctrl_3;
csr_centrl_in(63 DOWNTO 48)   <= cmu0_in_centrl_ctrl_4;
csr_centrl_in(79 DOWNTO 64)   <= cmu0_in_centrl_ctrl_5;
csr_centrl_in(95 DOWNTO 80)   <= cmu0_in_centrl_ctrl_6;
csr_centrl_in(111 DOWNTO 96)  <= cmu0_in_centrl_ctrl_7;
csr_centrl_in(127 DOWNTO 112) <= cmu0_in_centrl_ctrl_8;
csr_centrl_in(143 DOWNTO 128) <= cmu0_in_centrl_ctrl_9;
csr_centrl_in(159 DOWNTO 144) <= cmu0_in_centrl_ctrl_10;
csr_centrl_in(175 DOWNTO 160) <= cmu0_in_centrl_ctrl_11;
csr_centrl_in(191 DOWNTO 176) <= cmu0_in_centrl_ctrl_12;
csr_centrl_in(207 DOWNTO 192) <= cmu0_in_centrl_ctrl_13;
csr_centrl_in(223 DOWNTO 208) <= cmu0_in_centrl_ctrl_14;
csr_centrl_in(239 DOWNTO 224) <= cmu0_in_centrl_ctrl_15;
csr_centrl_in_reserved(15 DOWNTO 0) <= cmu0_in_centrl_ctrl_16;
csr_centrl_in(255 DOWNTO 240) <= cmu0_in_centrl_ctrl_17;
csr_centrl_in(271 DOWNTO 256) <= cmu0_in_centrl_ctrl_18;
csr_centrl_in(287 DOWNTO 272) <= cmu0_in_centrl_ctrl_19;
csr_centrl_in(303 DOWNTO 288) <= cmu0_in_centrl_ctrl_20;
csr_centrl_in(319 DOWNTO 304) <= cmu0_in_centrl_ctrl_21;   -- cmu only

csr_centrl_in(335 DOWNTO 320) <= cmu1_in_centrl_ctrl_1;
csr_centrl_in(351 DOWNTO 336) <= cmu1_in_centrl_ctrl_2;
csr_centrl_in(367 DOWNTO 352) <= cmu1_in_centrl_ctrl_3;
csr_centrl_in(383 DOWNTO 368) <= cmu1_in_centrl_ctrl_4;
csr_centrl_in(399 DOWNTO 384) <= cmu1_in_centrl_ctrl_5;
csr_centrl_in(415 DOWNTO 400) <= cmu1_in_centrl_ctrl_6;
csr_centrl_in(431 DOWNTO 416) <= cmu1_in_centrl_ctrl_7;
csr_centrl_in(447 DOWNTO 432) <= cmu1_in_centrl_ctrl_8;
csr_centrl_in(463 DOWNTO 448) <= cmu1_in_centrl_ctrl_9;
csr_centrl_in(479 DOWNTO 464) <= cmu1_in_centrl_ctrl_10;
csr_centrl_in(495 DOWNTO 480) <= cmu1_in_centrl_ctrl_11;
csr_centrl_in(511 DOWNTO 496) <= cmu1_in_centrl_ctrl_12;
csr_centrl_in(527 DOWNTO 512) <= cmu1_in_centrl_ctrl_13;
csr_centrl_in(543 DOWNTO 528) <= cmu1_in_centrl_ctrl_14;
csr_centrl_in(559 DOWNTO 544) <= cmu1_in_centrl_ctrl_15;
csr_centrl_in_reserved(31 DOWNTO 16) <= cmu1_in_centrl_ctrl_16;
csr_centrl_in(575 DOWNTO 560) <= cmu1_in_centrl_ctrl_17;
csr_centrl_in(591 DOWNTO 576) <= cmu1_in_centrl_ctrl_18;
csr_centrl_in(607 DOWNTO 592) <= cmu1_in_centrl_ctrl_19;
csr_centrl_in(623 DOWNTO 608) <= cmu1_in_centrl_ctrl_20;
csr_centrl_in(639 DOWNTO 624) <= cmu1_in_centrl_ctrl_21;  -- cmu only Table 74

csr_centrl_in(655 DOWNTO 640) <= cmu_in_centrl_global_0;  -- global XAUI etc. Table 75
csr_centrl_in(671 DOWNTO 656) <= cmu_in_centrl_global_1;
csr_centrl_in(687 DOWNTO 672) <= cmu_in_centrl_global_2;
csr_centrl_in(703 DOWNTO 688) <= cmu_in_centrl_global_3;

-- centrl DPRIO out physcial ---------------------------------
cmu0_out_centrl_ctrl_1  <=  dp_centrl_out(15 DOWNTO 0)     ;
cmu0_out_centrl_ctrl_2  <=  dp_centrl_out(31 DOWNTO 16)    ;
cmu0_out_centrl_ctrl_3  <=  dp_centrl_out(47 DOWNTO 32)    ;
cmu0_out_centrl_ctrl_4  <=  dp_centrl_out(63 DOWNTO 48)    ;
cmu0_out_centrl_ctrl_5  <=  dp_centrl_out(79 DOWNTO 64)    ;
cmu0_out_centrl_ctrl_6  <=  dp_centrl_out(95 DOWNTO 80)    ;
cmu0_out_centrl_ctrl_7  <=  dp_centrl_out(111 DOWNTO 96)   ;
cmu0_out_centrl_ctrl_8  <=  dp_centrl_out(127 DOWNTO 112)  ;
cmu0_out_centrl_ctrl_9  <=  dp_centrl_out(143 DOWNTO 128)  ;
cmu0_out_centrl_ctrl_10 <=  dp_centrl_out(159 DOWNTO 144)  ;
cmu0_out_centrl_ctrl_11 <=  dp_centrl_out(175 DOWNTO 160)  ;
cmu0_out_centrl_ctrl_12 <=  dp_centrl_out(191 DOWNTO 176)  ;
cmu0_out_centrl_ctrl_13 <=  dp_centrl_out(207 DOWNTO 192)  ;
cmu0_out_centrl_ctrl_14 <=  dp_centrl_out(223 DOWNTO 208)  ;
cmu0_out_centrl_ctrl_15 <=  dp_centrl_out(239 DOWNTO 224)  ;
cmu0_out_centrl_ctrl_16 <=  dp_centrl_out_reserved(15 DOWNTO 0);
cmu0_out_centrl_ctrl_17 <=  dp_centrl_out(255 DOWNTO 240)  ;
cmu0_out_centrl_ctrl_18 <=  dp_centrl_out(271 DOWNTO 256)  ;
cmu0_out_centrl_ctrl_19 <=  dp_centrl_out(287 DOWNTO 272)  ;
cmu0_out_centrl_ctrl_20 <=  dp_centrl_out(303 DOWNTO 288)  ;
cmu0_out_centrl_ctrl_21 <=  dp_centrl_out(319 DOWNTO 304)  ;

cmu1_out_centrl_ctrl_1  <=  dp_centrl_out(335 DOWNTO 320)  ;
cmu1_out_centrl_ctrl_2  <=  dp_centrl_out(351 DOWNTO 336)  ;
cmu1_out_centrl_ctrl_3  <=  dp_centrl_out(367 DOWNTO 352)  ;
cmu1_out_centrl_ctrl_4  <=  dp_centrl_out(383 DOWNTO 368)  ;
cmu1_out_centrl_ctrl_5  <=  dp_centrl_out(399 DOWNTO 384)  ;
cmu1_out_centrl_ctrl_6  <=  dp_centrl_out(415 DOWNTO 400)  ;
cmu1_out_centrl_ctrl_7  <=  dp_centrl_out(431 DOWNTO 416)  ;
cmu1_out_centrl_ctrl_8  <=  dp_centrl_out(447 DOWNTO 432)  ;
cmu1_out_centrl_ctrl_9  <=  dp_centrl_out(463 DOWNTO 448)  ;
cmu1_out_centrl_ctrl_10 <=  dp_centrl_out(479 DOWNTO 464)  ;
cmu1_out_centrl_ctrl_11 <=  dp_centrl_out(495 DOWNTO 480)  ;
cmu1_out_centrl_ctrl_12 <=  dp_centrl_out(511 DOWNTO 496)  ;
cmu1_out_centrl_ctrl_13 <=  dp_centrl_out(527 DOWNTO 512)  ;
cmu1_out_centrl_ctrl_14 <=  dp_centrl_out(543 DOWNTO 528)  ;
cmu1_out_centrl_ctrl_15 <=  dp_centrl_out(559 DOWNTO 544)  ;
cmu1_out_centrl_ctrl_16 <=  dp_centrl_out_reserved(31 DOWNTO 16);
cmu1_out_centrl_ctrl_17 <=  dp_centrl_out(575 DOWNTO 560)  ;
cmu1_out_centrl_ctrl_18 <=  dp_centrl_out(591 DOWNTO 576)  ;
cmu1_out_centrl_ctrl_19 <=  dp_centrl_out(607 DOWNTO 592)  ;
cmu1_out_centrl_ctrl_20 <=  dp_centrl_out(623 DOWNTO 608)  ;
cmu1_out_centrl_ctrl_21 <=  dp_centrl_out(639 DOWNTO 624)  ;

cmu_out_centrl_global_0 <=  dp_centrl_out(655 DOWNTO 640)  ; -- global XAUI etc. Tables 75
cmu_out_centrl_global_1 <=  dp_centrl_out(671 DOWNTO 656)  ;
cmu_out_centrl_global_2 <=  dp_centrl_out(687 DOWNTO 672)  ;
cmu_out_centrl_global_3 <=  dp_centrl_out(703 DOWNTO 688)  ;

ch4_out_chnl_ctrl_28 <= cmu0_out_centrl_ctrl_1;  
ch4_out_chnl_ctrl_29 <= cmu0_out_centrl_ctrl_2;  
ch4_out_chnl_ctrl_30 <= cmu0_out_centrl_ctrl_3;  
ch4_out_chnl_ctrl_31 <= cmu0_out_centrl_ctrl_4;  
ch4_out_chnl_ctrl_32 <= cmu0_out_centrl_ctrl_5;  
ch4_out_chnl_ctrl_33 <= cmu0_out_centrl_ctrl_6;  
ch4_out_chnl_ctrl_34 <= cmu0_out_centrl_ctrl_7;  
ch4_out_chnl_ctrl_35 <= cmu0_out_centrl_ctrl_8;  
ch4_out_chnl_ctrl_36 <= cmu0_out_centrl_ctrl_9; 
ch4_out_chnl_ctrl_37 <= cmu0_out_centrl_ctrl_10; 
ch4_out_chnl_ctrl_38 <= cmu0_out_centrl_ctrl_11; 
ch4_out_chnl_ctrl_39 <= cmu0_out_centrl_ctrl_12; 
ch4_out_chnl_ctrl_40 <= cmu0_out_centrl_ctrl_13; 
ch4_out_chnl_ctrl_41 <= cmu0_out_centrl_ctrl_14; 
ch4_out_chnl_ctrl_42 <= cmu0_out_centrl_ctrl_15; 
ch4_out_chnl_ctrl_43 <= cmu0_out_centrl_ctrl_16; 
ch4_out_chnl_ctrl_44 <= cmu0_out_centrl_ctrl_17; 
ch4_out_chnl_ctrl_45 <= cmu0_out_centrl_ctrl_18; 
ch4_out_chnl_ctrl_46 <= cmu0_out_centrl_ctrl_19; 
ch4_out_chnl_ctrl_47 <= cmu0_out_centrl_ctrl_20; 

ch5_out_chnl_ctrl_28 <= cmu1_out_centrl_ctrl_1;  
ch5_out_chnl_ctrl_29 <= cmu1_out_centrl_ctrl_2;  
ch5_out_chnl_ctrl_30 <= cmu1_out_centrl_ctrl_3;  
ch5_out_chnl_ctrl_31 <= cmu1_out_centrl_ctrl_4;  
ch5_out_chnl_ctrl_32 <= cmu1_out_centrl_ctrl_5;  
ch5_out_chnl_ctrl_33 <= cmu1_out_centrl_ctrl_6;  
ch5_out_chnl_ctrl_34 <= cmu1_out_centrl_ctrl_7;  
ch5_out_chnl_ctrl_35 <= cmu1_out_centrl_ctrl_8;  
ch5_out_chnl_ctrl_36 <= cmu1_out_centrl_ctrl_9; 
ch5_out_chnl_ctrl_37 <= cmu1_out_centrl_ctrl_10; 
ch5_out_chnl_ctrl_38 <= cmu1_out_centrl_ctrl_11; 
ch5_out_chnl_ctrl_39 <= cmu1_out_centrl_ctrl_12; 
ch5_out_chnl_ctrl_40 <= cmu1_out_centrl_ctrl_13; 
ch5_out_chnl_ctrl_41 <= cmu1_out_centrl_ctrl_14; 
ch5_out_chnl_ctrl_42 <= cmu1_out_centrl_ctrl_15; 
ch5_out_chnl_ctrl_43 <= cmu1_out_centrl_ctrl_16; 
ch5_out_chnl_ctrl_44 <= cmu1_out_centrl_ctrl_17; 
ch5_out_chnl_ctrl_45 <= cmu1_out_centrl_ctrl_18; 
ch5_out_chnl_ctrl_46 <= cmu1_out_centrl_ctrl_19; 
ch5_out_chnl_ctrl_47 <= cmu1_out_centrl_ctrl_20; 

--============================================================
-- Manually added code to handle 5th/6th PMA =================
-- === end                                                   =
--============================================================
  
   
END trans;



LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

ENTITY stratixiv_hssi_cmu_dprio_top IS
   GENERIC (
      -- Simulation Only 
      clkdiv0_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv0_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv1_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv1_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv2_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv2_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv3_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv3_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv4_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv4_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv5_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv5_inclk1_logical_to_physical_mapping   : STRING := "pll1";
            
      pll0_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll0_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll0_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll0_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll0_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll0_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll0_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll0_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll0_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll0_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll1_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll1_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll1_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll1_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll1_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll1_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll1_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll1_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll1_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll1_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll2_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll2_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll2_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll2_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll2_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll2_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll2_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll2_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll2_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll2_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll3_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll3_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll3_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll3_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll3_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll3_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll3_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll3_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll3_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll3_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll4_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll4_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll4_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll4_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll4_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll4_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll4_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll4_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll4_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll4_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll5_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll5_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll5_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll5_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll5_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll5_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll5_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll5_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll5_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll5_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
            
      pll0_logical_to_physical_mapping    :    INTEGER := 0;
      pll1_logical_to_physical_mapping    :    INTEGER := 1;
      pll2_logical_to_physical_mapping    :    INTEGER := 2;
      pll3_logical_to_physical_mapping    :    INTEGER := 3;
      pll4_logical_to_physical_mapping    :    INTEGER := 4;
      pll5_logical_to_physical_mapping    :    INTEGER := 5;
            
      refclk_divider0_logical_to_physical_mapping	:	INTEGER := 0;
      refclk_divider1_logical_to_physical_mapping	:	INTEGER := 1;
      
      rx0_logical_to_physical_mapping	:	INTEGER := 0;
      rx1_logical_to_physical_mapping	:	INTEGER := 1;
      rx2_logical_to_physical_mapping	:	INTEGER := 2;
      rx3_logical_to_physical_mapping	:	INTEGER := 3;
      rx4_logical_to_physical_mapping	:	INTEGER := 4;
      rx5_logical_to_physical_mapping	:	INTEGER := 5;
      
      tx0_logical_to_physical_mapping	:	INTEGER := 0;
      tx1_logical_to_physical_mapping	:	INTEGER := 1;
      tx2_logical_to_physical_mapping	:	INTEGER := 2;
      tx3_logical_to_physical_mapping	:	INTEGER := 3;
      tx4_logical_to_physical_mapping	:	INTEGER := 4;
      tx5_logical_to_physical_mapping	:	INTEGER := 5;
      
      
      tx0_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx0_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx0_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx0_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx0_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx1_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx1_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx1_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx1_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx1_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx2_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx2_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx2_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx2_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx2_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx3_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx3_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx3_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx3_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx3_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx4_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx4_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx4_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx4_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx4_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx5_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx5_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx5_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx5_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx5_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";

      sim_dump_dprio_internal_reg_at_time  : INTEGER := 0;		-- in ps
      sim_dump_filename                    : STRING := "sim_dprio_dump.txt"
   );
   PORT (
      sync_status                          : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
      align_status                         : IN STD_LOGIC;
      
      -- MDIO inputs/outpus
      mdio_in                              : IN STD_LOGIC;
      mdc                                  : IN STD_LOGIC;
      port_addr                            : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
      dev_addr                             : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
      
      mdio_dis                             : IN STD_LOGIC;		-- 1'b1=output CRAM (para), 1'b0=output MDIO control register
      dprioload                            : IN STD_LOGIC;		-- load MDIO control register with CRAM_ext (parameter). SER_SHFIT_LOAD?
      mdio_rst                             : IN STD_LOGIC;
      
      cmudividerdprioin                    : IN STD_LOGIC_VECTOR(599 DOWNTO 0);
      cmuplldprioin                        : IN STD_LOGIC_VECTOR(1799 DOWNTO 0);
      refclkdividerdprioin                 : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
      rxpcsdprioin                         : IN STD_LOGIC_VECTOR(1599 DOWNTO 0);
      rxpmadprioin                         : IN STD_LOGIC_VECTOR(1799 DOWNTO 0);
      txpcsdprioin                         : IN STD_LOGIC_VECTOR(599 DOWNTO 0);
      txpmadprioin                         : IN STD_LOGIC_VECTOR(1799 DOWNTO 0);
      
      cmudividerdprioout                   : OUT STD_LOGIC_VECTOR(599 DOWNTO 0);
      cmuplldprioout                       : OUT STD_LOGIC_VECTOR(1799 DOWNTO 0);
      refclkdividerdprioout                : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      rxpcsdprioout                        : OUT STD_LOGIC_VECTOR(1599 DOWNTO 0);
      rxpmadprioout                        : OUT STD_LOGIC_VECTOR(1799 DOWNTO 0);
      txpcsdprioout                        : OUT STD_LOGIC_VECTOR(599 DOWNTO 0);
      txpmadprioout                        : OUT STD_LOGIC_VECTOR(1799 DOWNTO 0);
      
      mdio_out                             : OUT STD_LOGIC;
      data_enable_n                        : OUT STD_LOGIC;
      mdio_curr_st                         : OUT STD_LOGIC_VECTOR(2 DOWNTO 0)
   );
END stratixiv_hssi_cmu_dprio_top;

ARCHITECTURE trans OF stratixiv_hssi_cmu_dprio_top IS
   COMPONENT stratixiv_hssi_cmu_dprio_addr
      PORT (
         mdc                                  : IN STD_LOGIC;
         reset                                : IN STD_LOGIC;
         mdio_in                              : IN STD_LOGIC;
         shift_addr                           : IN STD_LOGIC;
         incr_addr                            : IN STD_LOGIC;
         reg_addr                             : OUT STD_LOGIC_VECTOR(15 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_dprio_ctl_data
      PORT (
         mdc                                  : IN STD_LOGIC;
         reset                                : IN STD_LOGIC;
         mdio_in                              : IN STD_LOGIC;
         shift_in                             : IN STD_LOGIC;
         shift_out                            : IN STD_LOGIC;
         ld_data                              : IN STD_LOGIC;
         latch_ctl                            : IN STD_LOGIC;
         port_addr                            : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         dev_addr                             : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         valid_addr_lt                        : IN STD_LOGIC;
         mbus_out                             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         mdio_out                             : OUT STD_LOGIC;
         data_enable_n                        : OUT STD_LOGIC;
         mbus_in                              : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         opcode                               : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         valid_addr                           : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_dprio_centrl_top
      PORT (
         mdio_rst                             : IN STD_LOGIC;
         mdio_wr                              : IN STD_LOGIC;
         reg_addr                             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         mdc                                  : IN STD_LOGIC;
         mbus_in                              : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         serial_mode                          : IN STD_LOGIC;
         mdio_dis                             : IN STD_LOGIC;
         pma_cram_test                        : IN STD_LOGIC;
         ser_shift_load                       : IN STD_LOGIC;
         si                                   : IN STD_LOGIC;
         csr_centrl_in                        : IN STD_LOGIC_VECTOR(703 DOWNTO 0);
         csr_centrl_in_reserved               : IN STD_LOGIC_VECTOR(31 DOWNTO 0);
         
         dp_centrl_out                        : OUT STD_LOGIC_VECTOR(703 DOWNTO 0);
         dp_centrl_out_reserved               : OUT STD_LOGIC_VECTOR(31 DOWNTO 0);
         so                                   : OUT STD_LOGIC;
         mbus_out                             : OUT STD_LOGIC_VECTOR(15 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_dprio_map
      GENERIC (
      -- Simulation Only 
      clkdiv0_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv0_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv1_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv1_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv2_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv2_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv3_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv3_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv4_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv4_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv5_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv5_inclk1_logical_to_physical_mapping   : STRING := "pll1";
                   
      pll0_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll0_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll0_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll0_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll0_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll0_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll0_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll0_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll0_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll0_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll1_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll1_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll1_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll1_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll1_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll1_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll1_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll1_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll1_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll1_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll2_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll2_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll2_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll2_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll2_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll2_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll2_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll2_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll2_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll2_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll3_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll3_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll3_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll3_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll3_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll3_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll3_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll3_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll3_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll3_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll4_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll4_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll4_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll4_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll4_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll4_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll4_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll4_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll4_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll4_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      pll5_inclk0_logical_to_physical_mapping	:	STRING := "clkrefclk0";
      pll5_inclk1_logical_to_physical_mapping	:	STRING := "clkrefclk1";
      pll5_inclk2_logical_to_physical_mapping	:	STRING := "iq2";
      pll5_inclk3_logical_to_physical_mapping	:	STRING := "iq3";
      pll5_inclk4_logical_to_physical_mapping	:	STRING := "iq4";
      pll5_inclk5_logical_to_physical_mapping	:	STRING := "iq5";
      pll5_inclk6_logical_to_physical_mapping	:	STRING := "iq6";
      pll5_inclk7_logical_to_physical_mapping	:	STRING := "iq7";
      pll5_inclk8_logical_to_physical_mapping	:	STRING := "pld_clk";
      pll5_inclk9_logical_to_physical_mapping	:	STRING := "gpll_clk";
      
      
      pll0_logical_to_physical_mapping    :    INTEGER := 0;
      pll1_logical_to_physical_mapping    :    INTEGER := 1;
      pll2_logical_to_physical_mapping    :    INTEGER := 2;
      pll3_logical_to_physical_mapping    :    INTEGER := 3;
      pll4_logical_to_physical_mapping    :    INTEGER := 4;
      pll5_logical_to_physical_mapping    :    INTEGER := 5;
            
      refclk_divider0_logical_to_physical_mapping	:	INTEGER := 0;
      refclk_divider1_logical_to_physical_mapping	:	INTEGER := 1;
      
      rx0_logical_to_physical_mapping	:	INTEGER := 0;
      rx1_logical_to_physical_mapping	:	INTEGER := 1;
      rx2_logical_to_physical_mapping	:	INTEGER := 2;
      rx3_logical_to_physical_mapping	:	INTEGER := 3;
      rx4_logical_to_physical_mapping	:	INTEGER := 4;
      rx5_logical_to_physical_mapping	:	INTEGER := 5;
      
      tx0_logical_to_physical_mapping	:	INTEGER := 0;
      tx1_logical_to_physical_mapping	:	INTEGER := 1;
      tx2_logical_to_physical_mapping	:	INTEGER := 2;
      tx3_logical_to_physical_mapping	:	INTEGER := 3;
      tx4_logical_to_physical_mapping	:	INTEGER := 4;
      tx5_logical_to_physical_mapping	:	INTEGER := 5;
      
      tx0_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx0_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx0_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx0_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx0_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx1_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx1_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx1_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx1_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx1_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx2_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx2_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx2_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx2_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx2_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx3_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx3_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx3_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx3_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx3_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx4_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx4_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx4_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx4_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx4_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx5_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx5_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx5_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx5_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx5_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      
         sim_dump_dprio_internal_reg_at_time  : INTEGER := 0;
         sim_dump_filename                    : STRING := "sim_dprio_dump.txt"
      );
      PORT (
         cmudividerdprioin                    : IN STD_LOGIC_VECTOR(599 DOWNTO 0);
         cmuplldprioin                        : IN STD_LOGIC_VECTOR(1799 DOWNTO 0);
         refclkdividerdprioin                 : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rxpcsdprioin                         : IN STD_LOGIC_VECTOR(1599 DOWNTO 0);
         rxpmadprioin                         : IN STD_LOGIC_VECTOR(1799 DOWNTO 0);
         txpcsdprioin                         : IN STD_LOGIC_VECTOR(599 DOWNTO 0);
         txpmadprioin                         : IN STD_LOGIC_VECTOR(1799 DOWNTO 0);
         
         ch0_dp_chnl_out                      : IN STD_LOGIC_VECTOR(831 DOWNTO 0);
         ch1_dp_chnl_out                      : IN STD_LOGIC_VECTOR(831 DOWNTO 0);
         ch2_dp_chnl_out                      : IN STD_LOGIC_VECTOR(831 DOWNTO 0);
         ch3_dp_chnl_out                      : IN STD_LOGIC_VECTOR(831 DOWNTO 0);
         ch0_dp_chnl_out_reserved             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ch1_dp_chnl_out_reserved             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ch2_dp_chnl_out_reserved             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         ch3_dp_chnl_out_reserved             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         dp_centrl_out                        : IN STD_LOGIC_VECTOR(703 DOWNTO 0);  
         dp_centrl_out_reserved               : IN STD_LOGIC_VECTOR(31 DOWNTO 0);  
      
         ch0_csr_chnl_in                      : OUT STD_LOGIC_VECTOR(831 DOWNTO 0);
         ch1_csr_chnl_in                      : OUT STD_LOGIC_VECTOR(831 DOWNTO 0);
         ch2_csr_chnl_in                      : OUT STD_LOGIC_VECTOR(831 DOWNTO 0);
         ch3_csr_chnl_in                      : OUT STD_LOGIC_VECTOR(831 DOWNTO 0);
         ch0_csr_chnl_in_reserved             : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         ch1_csr_chnl_in_reserved             : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         ch2_csr_chnl_in_reserved             : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         ch3_csr_chnl_in_reserved             : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         csr_centrl_in                        : OUT STD_LOGIC_VECTOR(703 DOWNTO 0);
         csr_centrl_in_reserved               : OUT STD_LOGIC_VECTOR(31 DOWNTO 0);
         
         cmudividerdprioout                   : OUT STD_LOGIC_VECTOR(599 DOWNTO 0);
         cmuplldprioout                       : OUT STD_LOGIC_VECTOR(1799 DOWNTO 0);
         refclkdividerdprioout                : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         rxpcsdprioout                        : OUT STD_LOGIC_VECTOR(1599 DOWNTO 0);
         rxpmadprioout                        : OUT STD_LOGIC_VECTOR(1799 DOWNTO 0);
         txpcsdprioout                        : OUT STD_LOGIC_VECTOR(599 DOWNTO 0);
         txpmadprioout                        : OUT STD_LOGIC_VECTOR(1799 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_dprio_cnt
      PORT (
         mdc                                  : IN STD_LOGIC;
         reset                                : IN STD_LOGIC;
         ld_cnt                               : IN STD_LOGIC;
         cnt_val                              : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         cnt_eq_0                             : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_dprio_chnl_top
      PORT (
         mdio_rst                             : IN STD_LOGIC;
         mdio_wr                              : IN STD_LOGIC;
         reg_addr                             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         mdc                                  : IN STD_LOGIC;
         mbus_in                              : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         serial_mode                          : IN STD_LOGIC;
         mdio_dis                             : IN STD_LOGIC;
         pma_cram_test                        : IN STD_LOGIC;
         ser_shift_load                       : IN STD_LOGIC;
         si                                   : IN STD_LOGIC;
         csr_chnl_in                          : IN STD_LOGIC_VECTOR(831 DOWNTO 0);
         csr_chnl_in_reserved                 : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         dprio_chnl_id                        : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         dp_chnl_out                          : OUT STD_LOGIC_VECTOR(831 DOWNTO 0);
         dp_chnl_out_reserved                 : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         so                                   : OUT STD_LOGIC;
         mbus_out                             : OUT STD_LOGIC_VECTOR(15 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_dprio_status
      GENERIC (
         XGXS_STATUS1                         : INTEGER := 24580;
         XGXS_STATUS2                         : INTEGER := 24581;
         XGXS_LANE_STATUS                     : INTEGER := 24582
      );
      PORT (
         mdio_rst                             : IN STD_LOGIC;
         mdio_rd                              : IN STD_LOGIC;
         reg_addr                             : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         dev_addr_0                           : IN STD_LOGIC;
         mdc                                  : IN STD_LOGIC;
         serial_mode                          : IN STD_LOGIC;
         ser_shift_load                       : IN STD_LOGIC;
         si                                   : IN STD_LOGIC;
         mbus_out_ch0                         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         mbus_out_ch1                         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         mbus_out_ch2                         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         mbus_out_ch3                         : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         mbus_out_centrl                      : IN STD_LOGIC_VECTOR(15 DOWNTO 0);
         align_status                         : IN STD_LOGIC;
         sync_status                          : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         xs_link_status                       : IN STD_LOGIC;
         rx_local_fault                       : IN STD_LOGIC;
         tx_local_fault                       : IN STD_LOGIC;
         rxs_link_status_set                  : OUT STD_LOGIC;
         rtx_rx_local_fault_clr               : OUT STD_LOGIC;
         mbus_out                             : OUT STD_LOGIC_VECTOR(15 DOWNTO 0);
         so                                   : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_dprio_sm
      GENERIC (
         IDLE                                 : INTEGER := 0;
         PREAMBLE                             : INTEGER := 1;
         CONTROL                              : INTEGER := 2;
         TURN_ARND_0                          : INTEGER := 3;
         TURN_ARND_1                          : INTEGER := 4;
         ADDR_DATA                            : INTEGER := 5;
         ADDR_OP                              : INTEGER := 0;
         WR_OP                                : INTEGER := 1;
         RD_INC_OP                            : INTEGER := 2;
         RD_OP                                : INTEGER := 3
      );
      PORT (
         mdc                                  : IN STD_LOGIC;
         mdio_in                              : IN STD_LOGIC;
         reset                                : IN STD_LOGIC;
         opcode                               : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         valid_addr                           : IN STD_LOGIC;
         cnt_eq_0                             : IN STD_LOGIC;
         shift_in                             : OUT STD_LOGIC;
         shift_out                            : OUT STD_LOGIC;
         latch_ctl                            : OUT STD_LOGIC;
         incr_addr                            : OUT STD_LOGIC;
         mdio_wr                              : OUT STD_LOGIC;
         mdio_rd                              : OUT STD_LOGIC;
         shift_addr                           : OUT STD_LOGIC;
         ld_data                              : OUT STD_LOGIC;
         ld_cnt                               : OUT STD_LOGIC;
         cnt_val                              : OUT STD_LOGIC_VECTOR(4 DOWNTO 0);
         valid_addr_lt                        : OUT STD_LOGIC;
         curr_state                           : OUT STD_LOGIC_VECTOR(2 DOWNTO 0)
      );
   END COMPONENT;
   
   
   -- --------------------------------------------------------------------
   -- status reg ---------------------------------------------------------
   -- --------------------------------------------------------------------
   
   SIGNAL gnd_wire                    : STD_LOGIC;
   SIGNAL vcc_wire                    : STD_LOGIC;
   
   SIGNAL so_status                   : STD_LOGIC;
   SIGNAL rxs_link_status_set         : STD_LOGIC;
   SIGNAL rtx_rx_local_fault_clr      : STD_LOGIC;
   
   -- --------------------------------------------------------------------
   -- interface to channel -----------------------------------------------
   -- --------------------------------------------------------------------
   SIGNAL csr_chnl_in_ch0             : STD_LOGIC_VECTOR(831 DOWNTO 0);		-- CSR inputs
   SIGNAL csr_chnl_in_ch1             : STD_LOGIC_VECTOR(831 DOWNTO 0);		-- CSR inputs
   SIGNAL csr_chnl_in_ch2             : STD_LOGIC_VECTOR(831 DOWNTO 0);		-- CSR inputs
   SIGNAL csr_chnl_in_ch3             : STD_LOGIC_VECTOR(831 DOWNTO 0);		-- CSR inputs
   SIGNAL csr_chnl_in_reserved_ch0  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL csr_chnl_in_reserved_ch1  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL csr_chnl_in_reserved_ch2  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL csr_chnl_in_reserved_ch3  : STD_LOGIC_VECTOR(15 DOWNTO 0);
   
   SIGNAL dprio_chnl_id0              : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- DPRIO channel base address ID
   SIGNAL dprio_chnl_id1              : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- DPRIO channel base address ID
   SIGNAL dprio_chnl_id2              : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- DPRIO channel base address ID
   SIGNAL dprio_chnl_id3              : STD_LOGIC_VECTOR(3 DOWNTO 0);		-- DPRIO channel base address ID
   
   SIGNAL si_ch0                      : STD_LOGIC;
   SIGNAL si_ch1                      : STD_LOGIC;
   SIGNAL si_ch2                      : STD_LOGIC;
   SIGNAL si_ch3                      : STD_LOGIC;
   
   SIGNAL dp_chnl_out_ch0             : STD_LOGIC_VECTOR(831 DOWNTO 0);		-- 
   SIGNAL dp_chnl_out_ch1             : STD_LOGIC_VECTOR(831 DOWNTO 0);		-- 
   SIGNAL dp_chnl_out_ch2             : STD_LOGIC_VECTOR(831 DOWNTO 0);		-- 
   SIGNAL dp_chnl_out_ch3             : STD_LOGIC_VECTOR(831 DOWNTO 0);		-- 
   SIGNAL dp_chnl_out_reserved_ch0    : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL dp_chnl_out_reserved_ch1    : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL dp_chnl_out_reserved_ch2    : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL dp_chnl_out_reserved_ch3    : STD_LOGIC_VECTOR(15 DOWNTO 0);
   
   SIGNAL so_ch0                      : STD_LOGIC;
   SIGNAL so_ch1                      : STD_LOGIC;
   SIGNAL so_ch2                      : STD_LOGIC;
   SIGNAL so_ch3                      : STD_LOGIC;
   
   SIGNAL mbus_out_ch0                : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL mbus_out_ch1                : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL mbus_out_ch2                : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL mbus_out_ch3                : STD_LOGIC_VECTOR(15 DOWNTO 0);
   
   -- --------------------------------------------------------------------
   -- interface to cmu ---------------------------------------------------
   -- --------------------------------------------------------------------
   SIGNAL csr_centrl_in               : STD_LOGIC_VECTOR(703 DOWNTO 0);		-- CSR inputs
   SIGNAL csr_centrl_in_reserved      : STD_LOGIC_VECTOR(31 DOWNTO 0);
   SIGNAL si_centrl                   : STD_LOGIC;
   
   SIGNAL dp_centrl_out               : STD_LOGIC_VECTOR(703 DOWNTO 0);		-- CSR inputs
   SIGNAL dp_centrl_out_reserved      : STD_LOGIC_VECTOR(31 DOWNTO 0);
   SIGNAL mbus_out_centrl             : STD_LOGIC_VECTOR(15 DOWNTO 0);
   SIGNAL so_centrl                   : STD_LOGIC;
   
   -- --------------------------------------------------------------------
   -- new in STRATIXIV common --------------------------------------------------
   -- --------------------------------------------------------------------
   
   -- input --------------------
   -- PLD dynamic signal for PMA DPRIO cell for coverage for PE/TE
   SIGNAL pma_cram_test               : STD_LOGIC;
   SIGNAL serial_mode                 : STD_LOGIC;
   
   -- unused ports to be moved into reg
   SIGNAL jtag_mode                   : STD_LOGIC;
   SIGNAL jtag_shift_load             : STD_LOGIC;
   SIGNAL jtag_si                     : STD_LOGIC;
   SIGNAL jtag_so                     : STD_LOGIC;		-- wire
   
   -- status signals generated by PCS
   SIGNAL tx_local_fault              : STD_LOGIC;		-- from tx_sm
   SIGNAL rx_local_fault              : STD_LOGIC;		-- from rcv_sm
   SIGNAL xs_link_status              : STD_LOGIC;		-- from rcv_sm
   
   SIGNAL local_fault_ext             : STD_LOGIC;		-- Status signal wire
   SIGNAL xs_link_status_ext          : STD_LOGIC;		-- Status signal wire
   SIGNAL rx_local_fault_ext          : STD_LOGIC;		-- Status signal wire
   SIGNAL tx_local_fault_ext          : STD_LOGIC;		-- Status signal wire
   
   -- interconnect wires --------------------------------------------------
   
   -- wires from addr
   SIGNAL reg_addr                    : STD_LOGIC_VECTOR(15 DOWNTO 0);		-- addr --> reg
   
   -- wires from sm
   SIGNAL shift_addr                  : STD_LOGIC;		-- sm --> addr
   SIGNAL incr_addr                   : STD_LOGIC;		-- sm --> addr
   
   SIGNAL ld_cnt                      : STD_LOGIC;		-- sm --> cnt
   SIGNAL cnt_val                     : STD_LOGIC_VECTOR(4 DOWNTO 0);		-- sm --> cnt
   SIGNAL ld_data                     : STD_LOGIC;		-- sm --> cnt
   
   SIGNAL shift_in                    : STD_LOGIC;		-- sm --> ctl_data
   SIGNAL shift_out                   : STD_LOGIC;		-- sm --> ctl_data
   SIGNAL latch_ctl                   : STD_LOGIC;		-- sm --> ctl_data
   SIGNAL valid_addr_lt               : STD_LOGIC;		-- sm --> ctl_data
   
   SIGNAL mdio_wr                     : STD_LOGIC;		-- sm --> reg         
   SIGNAL mdio_rd                     : STD_LOGIC;		-- sm --> reg         
   
   SIGNAL curr_state                  : STD_LOGIC_VECTOR(2 DOWNTO 0);		-- sm --> top (../../pcs_central_testbus in central_chnnl)
   
   -- wires from cnt
   SIGNAL cnt_eq_0                    : STD_LOGIC;		-- cnt --> sm
   
   -- wires from ctl_data
   SIGNAL mbus_in                     : STD_LOGIC_VECTOR(15 DOWNTO 0);		-- ctl_data --> reg
   SIGNAL valid_addr                  : STD_LOGIC;		-- ctl_data --> sm
   SIGNAL opcode                      : STD_LOGIC_VECTOR(1 DOWNTO 0);		-- ctl_data --> sm
   
   -- ctl_data --> top
   -- ctl_data --> top
   
   -- wires from reg
   SIGNAL mbus_out                    : STD_LOGIC_VECTOR(15 DOWNTO 0);		-- reg --> ctl_data
   
   --wires to reg
   SIGNAL dev_addr_0                  : STD_LOGIC;
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL cmudividerdprioout_xhdl0    : STD_LOGIC_VECTOR(599 DOWNTO 0);
   SIGNAL cmuplldprioout_xhdl1        : STD_LOGIC_VECTOR(1799 DOWNTO 0);
   SIGNAL refclkdividerdprioout_xhdl4 : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rxpcsdprioout_xhdl5         : STD_LOGIC_VECTOR(1599 DOWNTO 0);
   SIGNAL rxpmadprioout_xhdl6         : STD_LOGIC_VECTOR(1799 DOWNTO 0);
   SIGNAL txpcsdprioout_xhdl7         : STD_LOGIC_VECTOR(599 DOWNTO 0);
   SIGNAL txpmadprioout_xhdl8         : STD_LOGIC_VECTOR(1799 DOWNTO 0);
   SIGNAL mdio_out_xhdl3              : STD_LOGIC;
   SIGNAL data_enable_n_xhdl2         : STD_LOGIC;
BEGIN
   -- Drive referenced outputs
   cmudividerdprioout <= cmudividerdprioout_xhdl0;
   cmuplldprioout <= cmuplldprioout_xhdl1;
   refclkdividerdprioout <= refclkdividerdprioout_xhdl4;
   rxpcsdprioout <= rxpcsdprioout_xhdl5;
   rxpmadprioout <= rxpmadprioout_xhdl6;
   txpcsdprioout <= txpcsdprioout_xhdl7;
   txpmadprioout <= txpmadprioout_xhdl8;
   mdio_out <= mdio_out_xhdl3;
   data_enable_n <= data_enable_n_xhdl2;
   
   -- primary input/output connections ---------------------------------------
   
   -- outputs
   mdio_curr_st <= curr_state;		-- from SM
   
   -- module instantiatations ------------------------------------------------
   
   		-- from top
   
   mdio_addr_1 : stratixiv_hssi_cmu_dprio_addr
      PORT MAP (
         reset       => mdio_rst,
         mdc         => mdc,		-- from top
         mdio_in     => mdio_in,		-- from top
         shift_addr  => shift_addr,		-- from sm
         incr_addr   => incr_addr,		-- from sm
         reg_addr    => reg_addr		-- To (16-bit reg addr) reg 
      );
   
   
   
   mdio_cnt_1 : stratixiv_hssi_cmu_dprio_cnt
      PORT MAP (
         reset     => mdio_rst,
         mdc       => mdc,
         ld_cnt    => ld_cnt,		-- from sm
         cnt_val   => cnt_val,		-- from sm
         cnt_eq_0  => cnt_eq_0		-- to sm
      );
   
   
   
   mdio_sm_1 : stratixiv_hssi_cmu_dprio_sm
      PORT MAP (
         reset          => mdio_rst,
         mdio_in        => mdio_in,		-- from top                 
         mdc            => mdc,
         opcode         => opcode,		-- from ctl_data
         valid_addr     => valid_addr,		-- from ctl_data
         cnt_eq_0       => cnt_eq_0,		-- from cnt
         shift_addr     => shift_addr,		-- to addr
         incr_addr      => incr_addr,		-- to addr
         mdio_wr        => mdio_wr,		-- to reg
         mdio_rd        => mdio_rd,		-- to reg
         shift_in       => shift_in,		-- to ctl_data
         shift_out      => shift_out,		-- to ctl_data
         latch_ctl      => latch_ctl,		-- to ctl_data
         ld_data        => ld_data,		-- to ctl_data
         valid_addr_lt  => valid_addr_lt,		-- to cnt_data
         ld_cnt         => ld_cnt,		-- to cnt
         cnt_val        => cnt_val,		-- to cnt (5-bit)
         curr_state     => curr_state		-- to top
      );
   
   
   
   mdio_ctl_data_1 : stratixiv_hssi_cmu_dprio_ctl_data
      PORT MAP (
         reset          => mdio_rst,
         mdc            => mdc,
         mdio_in        => mdio_in,
         shift_in       => shift_in,		-- from sm
         shift_out      => shift_out,		-- frm sm
         ld_data        => ld_data,		-- from sm
         latch_ctl      => latch_ctl,		-- from sm
         port_addr      => port_addr,
         dev_addr       => dev_addr,
         valid_addr_lt  => valid_addr_lt,		-- from sm
         mbus_out       => mbus_out,		-- from reg
         mdio_out       => mdio_out_xhdl3,		-- to top
         mbus_in        => mbus_in,		-- to reg 
         opcode         => opcode,		-- to sm
         valid_addr     => valid_addr,		-- to sm
         data_enable_n  => data_enable_n_xhdl2		-- to top
      );
   
   -- --------------------------------------------------------------------
   -- Status registers and MBUS_OUT muxing for whole QUAD ----------------
   -- --------------------------------------------------------------------
   gnd_wire <= '0';
   vcc_wire <= '1';
   
   dev_addr_0 <= dev_addr(0);
   
   
   
   status_reg : stratixiv_hssi_cmu_dprio_status
      PORT MAP (
         mdio_rst                => mdio_rst,
         mdio_rd                 => mdio_rd,
         reg_addr                => reg_addr,
         dev_addr_0              => dev_addr(0),
         mdc                     => mdc,
         serial_mode             => gnd_wire,
         ser_shift_load          => '0',
         si                      => '0',
         mbus_out_ch0            => mbus_out_ch0,
         mbus_out_ch1            => mbus_out_ch1,
         mbus_out_ch2            => mbus_out_ch2,
         mbus_out_ch3            => mbus_out_ch3,
         mbus_out_centrl         => mbus_out_centrl,
         align_status            => align_status,
         sync_status             => sync_status,
         xs_link_status          => xs_link_status,
         rx_local_fault          => rx_local_fault,
         tx_local_fault          => tx_local_fault,
         rxs_link_status_set     => rxs_link_status_set,
         rtx_rx_local_fault_clr  => rtx_rx_local_fault_clr,
         mbus_out                => mbus_out,		-- to ctrl_data
         so                      => so_status
      );
   
   -- --------------------------------------------------------------------
   -- common -------------------------------------------------------------
   -- --------------------------------------------------------------------
   pma_cram_test <= '0';
   serial_mode <= '0';
   
   -- --------------------------------------------------------------------
   --  cmu ---------------------------------------------------------------
   -- --------------------------------------------------------------------
   si_centrl <= 'X';
   
   md_reg_centrl : stratixiv_hssi_cmu_dprio_centrl_top
      PORT MAP (
         mdio_rst        => mdio_rst,		-- from top
         mdio_wr         => mdio_wr,		-- from sm        
         reg_addr        => reg_addr,		-- from addr
         mdc             => mdc,		-- from top  
         mbus_in         => mbus_in,		-- from ctrl_data
         serial_mode     => serial_mode,		-- new: 
         mdio_dis        => mdio_dis,		-- from top
         pma_cram_test   => pma_cram_test,		-- new:
         --                      .dprioload(dprioload),                // from top     
         ser_shift_load  => dprioload,		-- from top 
         si              => si_centrl,		-- new    
         csr_centrl_in   => csr_centrl_in,		-- new
         csr_centrl_in_reserved => csr_centrl_in_reserved,
         --                      .align_status (align_status),         // moved to status_reg_ctrl   
         --                      .sync_status (sync_status),           // moved to status_reg_ctrl
         --                      .mdio_rd(mdio_rd),                    // moved to status_reg_ctrl
         --                      .dev_addr_0 (dev_addr_0),             // moved to status_reg_ctrl
         
         dp_centrl_out   => dp_centrl_out,		-- to top
         dp_centrl_out_reserved => dp_centrl_out_reserved,
         
         so              => so_centrl,		-- to ctrl_data
         mbus_out        => mbus_out_centrl		-- to status_reg
      );
   
   -- --------------------------------------------------------------------
   -- channel ------------------------------------------------------------
   -- --------------------------------------------------------------------
   
   dprio_chnl_id0 <= "0000";
   dprio_chnl_id1 <= "0001";
   dprio_chnl_id2 <= "0010";
   dprio_chnl_id3 <= "0011";
   
   si_ch0 <= 'X';
   si_ch1 <= 'X';
   si_ch2 <= 'X';
   si_ch3 <= 'X';   
   
   md_reg_ch0 : stratixiv_hssi_cmu_dprio_chnl_top
      PORT MAP (
         mdio_rst        => mdio_rst,		-- from top
         mdio_wr         => mdio_wr,		-- from sm        
         reg_addr        => reg_addr,		-- from addr
         mdc             => mdc,		-- from top  
         mbus_in         => mbus_in,		-- from ctrl_data
         serial_mode     => serial_mode,		-- new: 
         mdio_dis        => mdio_dis,		-- from top
         pma_cram_test   => pma_cram_test,		-- new:
         ser_shift_load  => dprioload,		-- from top 
         si              => si_ch0,		-- new    
         csr_chnl_in     => csr_chnl_in_ch0,		-- new
         csr_chnl_in_reserved => csr_chnl_in_reserved_ch0,
         dprio_chnl_id   => dprio_chnl_id0,		-- new - not in centrl
         
         dp_chnl_out     => dp_chnl_out_ch0,		-- to top
         dp_chnl_out_reserved => dp_chnl_out_reserved_ch0,
         so              => so_ch0,		-- to ctrl_data
         mbus_out        => mbus_out_ch0		-- to status_reg
      );
   
   
   
   md_reg_ch1 : stratixiv_hssi_cmu_dprio_chnl_top
      PORT MAP (
         mdio_rst        => mdio_rst,		-- from top
         mdio_wr         => mdio_wr,		-- from sm        
         reg_addr        => reg_addr,		-- from addr
         mdc             => mdc,		-- from top  
         mbus_in         => mbus_in,		-- from ctrl_data
         serial_mode     => serial_mode,		-- new: 
         mdio_dis        => mdio_dis,		-- from top
         pma_cram_test   => pma_cram_test,		-- new:
         ser_shift_load  => dprioload,		-- from top 
         si              => si_ch1,		-- new    
         csr_chnl_in     => csr_chnl_in_ch1,		-- new
         csr_chnl_in_reserved => csr_chnl_in_reserved_ch1,
         dprio_chnl_id   => dprio_chnl_id1,		-- new - not in centrl
         
         dp_chnl_out     => dp_chnl_out_ch1,		-- to top
         dp_chnl_out_reserved => dp_chnl_out_reserved_ch1,
         so              => so_ch1,		-- to ctrl_data
         mbus_out        => mbus_out_ch1		-- to status_reg
      );
   
   
   
   md_reg_ch2 : stratixiv_hssi_cmu_dprio_chnl_top
      PORT MAP (
         mdio_rst        => mdio_rst,		-- from top
         mdio_wr         => mdio_wr,		-- from sm        
         reg_addr        => reg_addr,		-- from addr
         mdc             => mdc,		-- from top  
         mbus_in         => mbus_in,		-- from ctrl_data
         serial_mode     => serial_mode,		-- new: 
         mdio_dis        => mdio_dis,		-- from top
         pma_cram_test   => pma_cram_test,		-- new:
         ser_shift_load  => dprioload,		-- from top 
         si              => si_ch2,		-- new    
         csr_chnl_in     => csr_chnl_in_ch2,		-- new
         csr_chnl_in_reserved => csr_chnl_in_reserved_ch2,
         dprio_chnl_id   => dprio_chnl_id2,		-- new - not in centrl
         
         dp_chnl_out     => dp_chnl_out_ch2,		-- to top
         dp_chnl_out_reserved => dp_chnl_out_reserved_ch2,
         so              => so_ch2,		-- to ctrl_data
         mbus_out        => mbus_out_ch2		-- to status_reg
      );
   
   
   
   md_reg_ch3 : stratixiv_hssi_cmu_dprio_chnl_top
      PORT MAP (
         mdio_rst        => mdio_rst,		-- from top
         mdio_wr         => mdio_wr,		-- from sm        
         reg_addr        => reg_addr,		-- from addr
         mdc             => mdc,		-- from top  
         mbus_in         => mbus_in,		-- from ctrl_data
         serial_mode     => serial_mode,		-- new: 
         mdio_dis        => mdio_dis,		-- from top
         pma_cram_test   => pma_cram_test,		-- new:
         ser_shift_load  => dprioload,		-- from top 
         si              => si_ch3,		-- new    
         csr_chnl_in     => csr_chnl_in_ch3,		-- new
         csr_chnl_in_reserved => csr_chnl_in_reserved_ch3,
         dprio_chnl_id   => dprio_chnl_id3,		-- new - not in centrl
         
         dp_chnl_out     => dp_chnl_out_ch3,		-- to top
         dp_chnl_out_reserved => dp_chnl_out_reserved_ch3,
         so              => so_ch3,		-- to ctrl_data
         mbus_out        => mbus_out_ch3		-- to status_reg
      );
   
   -- --------------------------------------------------------------------
   --  DPRIO SW <--> ICD -------------------------------------------------
   -- --------------------------------------------------------------------
   
   
   
   m_map : stratixiv_hssi_cmu_dprio_map
      GENERIC MAP (
         clkdiv0_inclk0_logical_to_physical_mapping  => clkdiv0_inclk0_logical_to_physical_mapping,
         clkdiv0_inclk1_logical_to_physical_mapping  => clkdiv0_inclk1_logical_to_physical_mapping,
         clkdiv1_inclk0_logical_to_physical_mapping  => clkdiv1_inclk0_logical_to_physical_mapping,
         clkdiv1_inclk1_logical_to_physical_mapping  => clkdiv1_inclk1_logical_to_physical_mapping,
         clkdiv2_inclk0_logical_to_physical_mapping  => clkdiv2_inclk0_logical_to_physical_mapping,
         clkdiv2_inclk1_logical_to_physical_mapping  => clkdiv2_inclk1_logical_to_physical_mapping,
         clkdiv3_inclk0_logical_to_physical_mapping  => clkdiv3_inclk0_logical_to_physical_mapping,
         clkdiv3_inclk1_logical_to_physical_mapping  => clkdiv3_inclk1_logical_to_physical_mapping,
         clkdiv4_inclk0_logical_to_physical_mapping  => clkdiv4_inclk0_logical_to_physical_mapping,
         clkdiv4_inclk1_logical_to_physical_mapping  => clkdiv4_inclk1_logical_to_physical_mapping,
         clkdiv5_inclk0_logical_to_physical_mapping  => clkdiv5_inclk0_logical_to_physical_mapping,
         clkdiv5_inclk1_logical_to_physical_mapping  => clkdiv5_inclk1_logical_to_physical_mapping,
      
         pll0_inclk0_logical_to_physical_mapping     => pll0_inclk0_logical_to_physical_mapping,
         pll0_inclk1_logical_to_physical_mapping     => pll0_inclk1_logical_to_physical_mapping,
         pll0_inclk2_logical_to_physical_mapping     => pll0_inclk2_logical_to_physical_mapping,
         pll0_inclk3_logical_to_physical_mapping     => pll0_inclk3_logical_to_physical_mapping,
         pll0_inclk4_logical_to_physical_mapping     => pll0_inclk4_logical_to_physical_mapping,
         pll0_inclk5_logical_to_physical_mapping     => pll0_inclk5_logical_to_physical_mapping,
         pll0_inclk6_logical_to_physical_mapping     => pll0_inclk6_logical_to_physical_mapping,
         pll0_inclk7_logical_to_physical_mapping     => pll0_inclk7_logical_to_physical_mapping,
         pll0_inclk8_logical_to_physical_mapping     => pll0_inclk8_logical_to_physical_mapping,
         pll0_inclk9_logical_to_physical_mapping     => pll0_inclk9_logical_to_physical_mapping,
         pll1_inclk0_logical_to_physical_mapping     => pll1_inclk0_logical_to_physical_mapping,
         pll1_inclk1_logical_to_physical_mapping     => pll1_inclk1_logical_to_physical_mapping,
         pll1_inclk2_logical_to_physical_mapping     => pll1_inclk2_logical_to_physical_mapping,
         pll1_inclk3_logical_to_physical_mapping     => pll1_inclk3_logical_to_physical_mapping,
         pll1_inclk4_logical_to_physical_mapping     => pll1_inclk4_logical_to_physical_mapping,
         pll1_inclk5_logical_to_physical_mapping     => pll1_inclk5_logical_to_physical_mapping,
         pll1_inclk6_logical_to_physical_mapping     => pll1_inclk6_logical_to_physical_mapping,
         pll1_inclk7_logical_to_physical_mapping     => pll1_inclk7_logical_to_physical_mapping,
         pll1_inclk8_logical_to_physical_mapping     => pll1_inclk8_logical_to_physical_mapping,
         pll1_inclk9_logical_to_physical_mapping     => pll1_inclk9_logical_to_physical_mapping,
         pll2_inclk0_logical_to_physical_mapping     => pll2_inclk0_logical_to_physical_mapping,
         pll2_inclk1_logical_to_physical_mapping     => pll2_inclk1_logical_to_physical_mapping,
         pll2_inclk2_logical_to_physical_mapping     => pll2_inclk2_logical_to_physical_mapping,
         pll2_inclk3_logical_to_physical_mapping     => pll2_inclk3_logical_to_physical_mapping,
         pll2_inclk4_logical_to_physical_mapping     => pll2_inclk4_logical_to_physical_mapping,
         pll2_inclk5_logical_to_physical_mapping     => pll2_inclk5_logical_to_physical_mapping,
         pll2_inclk6_logical_to_physical_mapping     => pll2_inclk6_logical_to_physical_mapping,
         pll2_inclk7_logical_to_physical_mapping     => pll2_inclk7_logical_to_physical_mapping,
         pll2_inclk8_logical_to_physical_mapping     => pll2_inclk8_logical_to_physical_mapping,
         pll2_inclk9_logical_to_physical_mapping     => pll2_inclk9_logical_to_physical_mapping,
         pll3_inclk0_logical_to_physical_mapping     => pll3_inclk0_logical_to_physical_mapping,
         pll3_inclk1_logical_to_physical_mapping     => pll3_inclk1_logical_to_physical_mapping,
         pll3_inclk2_logical_to_physical_mapping     => pll3_inclk2_logical_to_physical_mapping,
         pll3_inclk3_logical_to_physical_mapping     => pll3_inclk3_logical_to_physical_mapping,
         pll3_inclk4_logical_to_physical_mapping     => pll3_inclk4_logical_to_physical_mapping,
         pll3_inclk5_logical_to_physical_mapping     => pll3_inclk5_logical_to_physical_mapping,
         pll3_inclk6_logical_to_physical_mapping     => pll3_inclk6_logical_to_physical_mapping,
         pll3_inclk7_logical_to_physical_mapping     => pll3_inclk7_logical_to_physical_mapping,
         pll3_inclk8_logical_to_physical_mapping     => pll3_inclk8_logical_to_physical_mapping,
         pll3_inclk9_logical_to_physical_mapping     => pll3_inclk9_logical_to_physical_mapping,
         pll4_inclk0_logical_to_physical_mapping     => pll4_inclk0_logical_to_physical_mapping,
         pll4_inclk1_logical_to_physical_mapping     => pll4_inclk1_logical_to_physical_mapping,
         pll4_inclk2_logical_to_physical_mapping     => pll4_inclk2_logical_to_physical_mapping,
         pll4_inclk3_logical_to_physical_mapping     => pll4_inclk3_logical_to_physical_mapping,
         pll4_inclk4_logical_to_physical_mapping     => pll4_inclk4_logical_to_physical_mapping,
         pll4_inclk5_logical_to_physical_mapping     => pll4_inclk5_logical_to_physical_mapping,
         pll4_inclk6_logical_to_physical_mapping     => pll4_inclk6_logical_to_physical_mapping,
         pll4_inclk7_logical_to_physical_mapping     => pll4_inclk7_logical_to_physical_mapping,
         pll4_inclk8_logical_to_physical_mapping     => pll4_inclk8_logical_to_physical_mapping,
         pll4_inclk9_logical_to_physical_mapping     => pll4_inclk9_logical_to_physical_mapping,
         pll5_inclk0_logical_to_physical_mapping     => pll5_inclk0_logical_to_physical_mapping,
         pll5_inclk1_logical_to_physical_mapping     => pll5_inclk1_logical_to_physical_mapping,
         pll5_inclk2_logical_to_physical_mapping     => pll5_inclk2_logical_to_physical_mapping,
         pll5_inclk3_logical_to_physical_mapping     => pll5_inclk3_logical_to_physical_mapping,
         pll5_inclk4_logical_to_physical_mapping     => pll5_inclk4_logical_to_physical_mapping,
         pll5_inclk5_logical_to_physical_mapping     => pll5_inclk5_logical_to_physical_mapping,
         pll5_inclk6_logical_to_physical_mapping     => pll5_inclk6_logical_to_physical_mapping,
         pll5_inclk7_logical_to_physical_mapping     => pll5_inclk7_logical_to_physical_mapping,
         pll5_inclk8_logical_to_physical_mapping     => pll5_inclk8_logical_to_physical_mapping,
         pll5_inclk9_logical_to_physical_mapping     => pll5_inclk9_logical_to_physical_mapping,
         pll0_logical_to_physical_mapping            => pll0_logical_to_physical_mapping,
         pll1_logical_to_physical_mapping            => pll1_logical_to_physical_mapping,
         pll2_logical_to_physical_mapping            => pll2_logical_to_physical_mapping,
         pll3_logical_to_physical_mapping            => pll3_logical_to_physical_mapping,
         pll4_logical_to_physical_mapping            => pll4_logical_to_physical_mapping,
         pll5_logical_to_physical_mapping            => pll5_logical_to_physical_mapping,
         refclk_divider0_logical_to_physical_mapping => refclk_divider0_logical_to_physical_mapping,
         refclk_divider1_logical_to_physical_mapping => refclk_divider1_logical_to_physical_mapping,
         rx0_logical_to_physical_mapping             => rx0_logical_to_physical_mapping,
         rx1_logical_to_physical_mapping             => rx1_logical_to_physical_mapping,
         rx2_logical_to_physical_mapping             => rx2_logical_to_physical_mapping,
         rx3_logical_to_physical_mapping             => rx3_logical_to_physical_mapping,
         rx4_logical_to_physical_mapping             => rx4_logical_to_physical_mapping,
         rx5_logical_to_physical_mapping             => rx5_logical_to_physical_mapping,
         tx0_logical_to_physical_mapping             => tx0_logical_to_physical_mapping,
         tx1_logical_to_physical_mapping             => tx1_logical_to_physical_mapping,
         tx2_logical_to_physical_mapping             => tx2_logical_to_physical_mapping,
         tx3_logical_to_physical_mapping             => tx3_logical_to_physical_mapping,
         tx4_logical_to_physical_mapping             => tx4_logical_to_physical_mapping,
         tx5_logical_to_physical_mapping             => tx5_logical_to_physical_mapping,
          
         tx0_pma_inclk0_logical_to_physical_mapping  => tx0_pma_inclk0_logical_to_physical_mapping,
         tx0_pma_inclk1_logical_to_physical_mapping  => tx0_pma_inclk1_logical_to_physical_mapping,
         tx0_pma_inclk2_logical_to_physical_mapping  => tx0_pma_inclk2_logical_to_physical_mapping,
         tx0_pma_inclk3_logical_to_physical_mapping  => tx0_pma_inclk3_logical_to_physical_mapping,
         tx0_pma_inclk4_logical_to_physical_mapping  => tx0_pma_inclk4_logical_to_physical_mapping,
         tx1_pma_inclk0_logical_to_physical_mapping  => tx1_pma_inclk0_logical_to_physical_mapping,
         tx1_pma_inclk1_logical_to_physical_mapping  => tx1_pma_inclk1_logical_to_physical_mapping,
         tx1_pma_inclk2_logical_to_physical_mapping  => tx1_pma_inclk2_logical_to_physical_mapping,
         tx1_pma_inclk3_logical_to_physical_mapping  => tx1_pma_inclk3_logical_to_physical_mapping,
         tx1_pma_inclk4_logical_to_physical_mapping  => tx1_pma_inclk4_logical_to_physical_mapping,
         tx2_pma_inclk0_logical_to_physical_mapping  => tx2_pma_inclk0_logical_to_physical_mapping,
         tx2_pma_inclk1_logical_to_physical_mapping  => tx2_pma_inclk1_logical_to_physical_mapping,
         tx2_pma_inclk2_logical_to_physical_mapping  => tx2_pma_inclk2_logical_to_physical_mapping,
         tx2_pma_inclk3_logical_to_physical_mapping  => tx2_pma_inclk3_logical_to_physical_mapping,
         tx2_pma_inclk4_logical_to_physical_mapping  => tx2_pma_inclk4_logical_to_physical_mapping,
         tx3_pma_inclk0_logical_to_physical_mapping  => tx3_pma_inclk0_logical_to_physical_mapping,
         tx3_pma_inclk1_logical_to_physical_mapping  => tx3_pma_inclk1_logical_to_physical_mapping,
         tx3_pma_inclk2_logical_to_physical_mapping  => tx3_pma_inclk2_logical_to_physical_mapping,
         tx3_pma_inclk3_logical_to_physical_mapping  => tx3_pma_inclk3_logical_to_physical_mapping,
         tx3_pma_inclk4_logical_to_physical_mapping  => tx3_pma_inclk4_logical_to_physical_mapping,
         tx4_pma_inclk0_logical_to_physical_mapping  => tx4_pma_inclk0_logical_to_physical_mapping,
         tx4_pma_inclk1_logical_to_physical_mapping  => tx4_pma_inclk1_logical_to_physical_mapping,
         tx4_pma_inclk2_logical_to_physical_mapping  => tx4_pma_inclk2_logical_to_physical_mapping,
         tx4_pma_inclk3_logical_to_physical_mapping  => tx4_pma_inclk3_logical_to_physical_mapping,
         tx4_pma_inclk4_logical_to_physical_mapping  => tx4_pma_inclk4_logical_to_physical_mapping,
         tx5_pma_inclk0_logical_to_physical_mapping  => tx5_pma_inclk0_logical_to_physical_mapping,
         tx5_pma_inclk1_logical_to_physical_mapping  => tx5_pma_inclk1_logical_to_physical_mapping,
         tx5_pma_inclk2_logical_to_physical_mapping  => tx5_pma_inclk2_logical_to_physical_mapping,
         tx5_pma_inclk3_logical_to_physical_mapping  => tx5_pma_inclk3_logical_to_physical_mapping,
         tx5_pma_inclk4_logical_to_physical_mapping  => tx5_pma_inclk4_logical_to_physical_mapping,

         sim_dump_dprio_internal_reg_at_time  => sim_dump_dprio_internal_reg_at_time,
         sim_dump_filename                    => sim_dump_filename
      )
   
      PORT MAP (
         
         cmudividerdprioin      => cmudividerdprioin,
         cmuplldprioin          => cmuplldprioin,
         refclkdividerdprioin   => refclkdividerdprioin,
         rxpcsdprioin           => rxpcsdprioin,
         rxpmadprioin           => rxpmadprioin,
         txpcsdprioin           => txpcsdprioin,
         txpmadprioin           => txpmadprioin,
         
         ch0_dp_chnl_out        => dp_chnl_out_ch0,
         ch1_dp_chnl_out        => dp_chnl_out_ch1,
         ch2_dp_chnl_out        => dp_chnl_out_ch2,
         ch3_dp_chnl_out        => dp_chnl_out_ch3,
         ch0_dp_chnl_out_reserved => dp_chnl_out_reserved_ch0,
         ch1_dp_chnl_out_reserved => dp_chnl_out_reserved_ch1,
         ch2_dp_chnl_out_reserved => dp_chnl_out_reserved_ch2,
         ch3_dp_chnl_out_reserved => dp_chnl_out_reserved_ch3,
         dp_centrl_out            => dp_centrl_out,
         dp_centrl_out_reserved   => dp_centrl_out_reserved,
         
         ch0_csr_chnl_in        => csr_chnl_in_ch0,
         ch1_csr_chnl_in        => csr_chnl_in_ch1,
         ch2_csr_chnl_in        => csr_chnl_in_ch2,
         ch3_csr_chnl_in        => csr_chnl_in_ch3,
         ch0_csr_chnl_in_reserved => csr_chnl_in_reserved_ch0,
         ch1_csr_chnl_in_reserved => csr_chnl_in_reserved_ch1,
         ch2_csr_chnl_in_reserved => csr_chnl_in_reserved_ch2,
         ch3_csr_chnl_in_reserved => csr_chnl_in_reserved_ch3,
         csr_centrl_in            => csr_centrl_in,
         csr_centrl_in_reserved   => csr_centrl_in_reserved,
         
         cmudividerdprioout     => cmudividerdprioout_xhdl0,
         cmuplldprioout         => cmuplldprioout_xhdl1,
         refclkdividerdprioout  => refclkdividerdprioout_xhdl4,
         rxpcsdprioout          => rxpcsdprioout_xhdl5,
         rxpmadprioout          => rxpmadprioout_xhdl6,
         txpcsdprioout          => txpcsdprioout_xhdl7,
         txpmadprioout          => txpmadprioout_xhdl8
      );
   
END trans;



LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;
LIBRARY STD;
USE STD.textio.ALL;
USE work.stratixiv_hssi_components.all;

USE IEEE.VITAL_Timing.all;
USE IEEE.VITAL_Primitives.all;
ENTITY stratixiv_hssi_cmu IS
   GENERIC (

          --  generic control parameters  --
       MsgOn                       : Boolean := DefGlitchMsgOn;
       XOn                         : Boolean := DefGlitchXOn;
       MsgOnChecks                 : Boolean := DefMsgOnChecks;
       XOnChecks                   : Boolean := DefXOnChecks;
       InstancePath                : String := "*";
       TimingChecksOn              : Boolean := True;
          --  tipd  :interconnect path delays --
      tipd_txphfiforddisable       : VitalDelayType01 := DefpropDelay01;
      tipd_txctrl                  : VitalDelayArrayType01(3 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rxdatain                : VitalDelayArrayType01(31 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_txclk                   : VitalDelayType01 := DefpropDelay01;
      tipd_syncstatus              : VitalDelayArrayType01(3 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rxpcsdprioin            : VitalDelayArrayType01(1599 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_txdigitalreset          : VitalDelayArrayType01(3 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_txdatain                : VitalDelayArrayType01(31 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_scanclk                 : VitalDelayType01 := DefpropDelay01;
      tipd_rateswitchdonein        : VitalDelayType01 := DefpropDelay01;
      tipd_rdenablesync            : VitalDelayType01 := DefpropDelay01;
      tipd_dpclk                   : VitalDelayType01 := DefpropDelay01;
      tipd_rxphfiforeset           : VitalDelayType01 := DefpropDelay01;
      tipd_testin                  : VitalDelayArrayType01(9999 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_txpllreset              : VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rxrunningdisp           : VitalDelayArrayType01(3 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rxdatavalid             : VitalDelayArrayType01(3 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_refclkdividerdprioin    : VitalDelayArrayType01(1 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_txpcsdprioin            : VitalDelayArrayType01(599 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_dprioin                 : VitalDelayType01 := DefpropDelay01;
      tipd_rateswitch              : VitalDelayType01 := DefpropDelay01;
      tipd_rxctrl                  : VitalDelayArrayType01(3 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rxanalogreset           : VitalDelayArrayType01(5 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rxclk                   : VitalDelayType01 := DefpropDelay01;
      tipd_txphfifowrenable        : VitalDelayType01 := DefpropDelay01;
      tipd_rxphfifowrdisable       : VitalDelayType01 := DefpropDelay01;
      tipd_rdalign                 : VitalDelayArrayType01(3 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_fixedclk                : VitalDelayArrayType01(5 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_dpriodisable            : VitalDelayType01 := DefpropDelay01;
      tipd_scanmode                : VitalDelayType01 := DefpropDelay01;
      tipd_rxphfifordenable        : VitalDelayType01 := DefpropDelay01;
      tipd_cmuplldprioin           : VitalDelayArrayType01(1799 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_txphfiforeset           : VitalDelayType01 := DefpropDelay01;
      tipd_txcoreclk               : VitalDelayType01 := DefpropDelay01;
      tipd_adet                    : VitalDelayArrayType01(3 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rxdigitalreset          : VitalDelayArrayType01(3 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rxpmadprioin            : VitalDelayArrayType01(1799 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_cmudividerdprioin       : VitalDelayArrayType01(599 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_rxcoreclk               : VitalDelayType01 := DefpropDelay01;
      tipd_dprioload               : VitalDelayType01 := DefpropDelay01;
      tipd_scanin                  : VitalDelayArrayType01(22 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_quadreset               : VitalDelayType01 := DefpropDelay01;
      tipd_nonuserfromcal          : VitalDelayType01 := DefpropDelay01;
      tipd_scanshift               : VitalDelayType01 := DefpropDelay01;
      tipd_txpmadprioin            : VitalDelayArrayType01(1799 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      tipd_recovclk                : VitalDelayType01 := DefpropDelay01;
      tipd_rxpowerdown             : VitalDelayArrayType01(5 DOWNTO 0)   := (OTHERS => DefPropDelay01);
      -- TSU/TH section
      tsetup_dprioin_dpclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      thold_dprioin_dpclk_noedge_posedge : VitalDelayType := DefSetupHoldCnst;
      -- TCO section
      tpd_dpclk_dprioout_posedge : VitalDelayType01 := DefPropDelay01;
      tpd_dpclk_dpriooe_posedge : VitalDelayType01 := DefPropDelay01;
      
      lpm_type                                     : STRING := "stratixiv_hssi_cmu";
      analog_test_bus_enable                       : STRING := "false";       
      auto_spd_deassert_ph_fifo_rst_count          : INTEGER := 0;       
      auto_spd_phystatus_notify_count              : INTEGER := 0;        
      bonded_quad_mode                             : STRING := "none";
      bypass_bandgap                               : STRING := "false";     
      central_test_bus_select                      : INTEGER := 0;        
      cmu_type                                     : STRING := "regular";
      devaddr                                      : INTEGER := 1;
      dprio_config_mode               			   : STD_LOGIC_VECTOR(5 DOWNTO 0) := "000000";
      in_xaui_mode                                 : STRING := "false";
      migrated_from_prev_family                    : STRING := "false";
      num_con_align_chars_for_align                : INTEGER := 4;
      num_con_errors_for_align_loss                : INTEGER := 2;
      num_con_good_data_for_align_approach         : INTEGER := 3;
      offset_all_errors_align                      : STRING := "false";
      pipe_auto_speed_nego_enable                  : STRING := "false";      
      pipe_freq_scale_mode                         : STRING := "Data width"; 
      pma_done_count                               : INTEGER := 0;        
      portaddr                                     : INTEGER := 1;
      rx0_auto_spd_self_switch_enable              : STRING := "false";   
      rx0_channel_bonding                          : STRING := "none";    
      rx0_clk1_mux_select                          : STRING := "recovered clock";        
      rx0_clk2_mux_select                          : STRING := "recovered clock";        
      rx0_clk_pd_enable                            : STRING := "false";        
      rx0_ph_fifo_reg_mode                         : STRING := "false";        
      rx0_ph_fifo_reset_enable                     : STRING := "false";        
      rx0_ph_fifo_user_ctrl_enable                 : STRING := "false";        
      rx0_phfifo_wait_cnt                          : INTEGER := 0;          
      rx0_rd_clk_mux_select                        : STRING := "int clock";        
      rx0_recovered_clk_mux_select                 : STRING := "recovered clock";  
      rx0_reset_clock_output_during_digital_reset  : STRING := "false";        
      rx0_use_double_data_mode                     : STRING := "false";        
      rx_master_direction                          : STRING := "none";        
      rx_xaui_sm_backward_compatible_enable        : STRING := "false";       
      test_mode                                    : STRING := "false";
      tx0_auto_spd_self_switch_enable              : STRING := "false";       
      tx0_channel_bonding                          : STRING := "none";        
      tx0_clk_pd_enable                            : STRING := "false";       
      tx0_ph_fifo_reg_mode                         : STRING := "false";       
      tx0_ph_fifo_reset_enable                     : STRING := "false";       
      tx0_ph_fifo_user_ctrl_enable                 : STRING := "false";       
      tx0_rd_clk_mux_select                        : STRING := "int clock";   
      tx0_reset_clock_output_during_digital_reset  : STRING := "false";       
      tx0_use_double_data_mode                     : STRING := "false";       
      tx0_wr_clk_mux_select                        : STRING := "int_clk";     
      tx_master_direction                          : STRING := "none";        
      tx_pll0_used_as_rx_cdr                       : STRING := "false";       
      tx_pll1_used_as_rx_cdr                       : STRING := "false";       
      tx_xaui_sm_backward_compatible_enable        : STRING := "false";       
      use_deskew_fifo                              : STRING := "false";       
      vcceh_voltage                                : STRING := "3.0V";
      vcceh_voltage_user_specified_auto            : STRING := "true";
      protocol_hint                                : STRING := "basic";
      
      -- Simulation Only 
      clkdiv0_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv0_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv1_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv1_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv2_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv2_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv3_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv3_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv4_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv4_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv5_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv5_inclk1_logical_to_physical_mapping   : STRING := "pll1";
            
      cmu_divider0_inclk0_physical_mapping      :   STRING := "pll0";
      cmu_divider0_inclk1_physical_mapping      :   STRING := "pll1";
      cmu_divider0_inclk2_physical_mapping      :   STRING := "x4";
      cmu_divider0_inclk3_physical_mapping      :   STRING := "xn_t";
      cmu_divider0_inclk4_physical_mapping      :   STRING := "xn_b";
      cmu_divider1_inclk0_physical_mapping      :   STRING := "pll0";
      cmu_divider1_inclk1_physical_mapping      :   STRING := "pll1";
      cmu_divider1_inclk2_physical_mapping      :   STRING := "x4";
      cmu_divider1_inclk3_physical_mapping      :   STRING := "xn_t";
      cmu_divider1_inclk4_physical_mapping      :   STRING := "xn_b";
      cmu_divider2_inclk0_physical_mapping      :   STRING := "pll0";
      cmu_divider2_inclk1_physical_mapping      :   STRING := "pll1";
      cmu_divider2_inclk2_physical_mapping      :   STRING := "x4";
      cmu_divider2_inclk3_physical_mapping      :   STRING := "xn_t";
      cmu_divider2_inclk4_physical_mapping      :   STRING := "xn_b";
      cmu_divider3_inclk0_physical_mapping      :   STRING := "pll0";
      cmu_divider3_inclk1_physical_mapping      :   STRING := "pll1";
      cmu_divider3_inclk2_physical_mapping      :   STRING := "x4";
      cmu_divider3_inclk3_physical_mapping      :   STRING := "xn_t";
      cmu_divider3_inclk4_physical_mapping      :   STRING := "xn_b";
      cmu_divider4_inclk0_physical_mapping      :   STRING := "pll0";
      cmu_divider4_inclk1_physical_mapping      :   STRING := "pll1";
      cmu_divider4_inclk2_physical_mapping      :   STRING := "x4";
      cmu_divider4_inclk3_physical_mapping      :   STRING := "xn_t";
      cmu_divider4_inclk4_physical_mapping      :   STRING := "xn_b";
      cmu_divider5_inclk0_physical_mapping      :   STRING := "pll0";
      cmu_divider5_inclk1_physical_mapping      :   STRING := "pll1";
      cmu_divider5_inclk2_physical_mapping      :   STRING := "x4";
      cmu_divider5_inclk3_physical_mapping      :   STRING := "xn_t";
      cmu_divider5_inclk4_physical_mapping      :   STRING := "xn_b";
      
      pll0_inclk0_logical_to_physical_mapping    :    STRING := "clkrefclk0";
      pll0_inclk1_logical_to_physical_mapping    :    STRING := "clkrefclk1";
      pll0_inclk2_logical_to_physical_mapping    :    STRING := "iq2";
      pll0_inclk3_logical_to_physical_mapping    :    STRING := "iq3";
      pll0_inclk4_logical_to_physical_mapping    :    STRING := "iq4";
      pll0_inclk5_logical_to_physical_mapping    :    STRING := "iq5";
      pll0_inclk6_logical_to_physical_mapping    :    STRING := "iq6";
      pll0_inclk7_logical_to_physical_mapping    :    STRING := "iq7";
      pll0_inclk8_logical_to_physical_mapping    :    STRING := "pld_clk";
      pll0_inclk9_logical_to_physical_mapping    :    STRING := "gpll_clk";
      pll1_inclk0_logical_to_physical_mapping    :    STRING := "clkrefclk0";
      pll1_inclk1_logical_to_physical_mapping    :    STRING := "clkrefclk1";
      pll1_inclk2_logical_to_physical_mapping    :    STRING := "iq2";
      pll1_inclk3_logical_to_physical_mapping    :    STRING := "iq3";
      pll1_inclk4_logical_to_physical_mapping    :    STRING := "iq4";
      pll1_inclk5_logical_to_physical_mapping    :    STRING := "iq5";
      pll1_inclk6_logical_to_physical_mapping    :    STRING := "iq6";
      pll1_inclk7_logical_to_physical_mapping    :    STRING := "iq7";
      pll1_inclk8_logical_to_physical_mapping    :    STRING := "pld_clk";
      pll1_inclk9_logical_to_physical_mapping    :    STRING := "gpll_clk";
      pll2_inclk0_logical_to_physical_mapping    :    STRING := "clkrefclk0";
      pll2_inclk1_logical_to_physical_mapping    :    STRING := "clkrefclk1";
      pll2_inclk2_logical_to_physical_mapping    :    STRING := "iq2";
      pll2_inclk3_logical_to_physical_mapping    :    STRING := "iq3";
      pll2_inclk4_logical_to_physical_mapping    :    STRING := "iq4";
      pll2_inclk5_logical_to_physical_mapping    :    STRING := "iq5";
      pll2_inclk6_logical_to_physical_mapping    :    STRING := "iq6";
      pll2_inclk7_logical_to_physical_mapping    :    STRING := "iq7";
      pll2_inclk8_logical_to_physical_mapping    :    STRING := "pld_clk";
      pll2_inclk9_logical_to_physical_mapping    :    STRING := "gpll_clk";
      pll3_inclk0_logical_to_physical_mapping    :    STRING := "clkrefclk0";
      pll3_inclk1_logical_to_physical_mapping    :    STRING := "clkrefclk1";
      pll3_inclk2_logical_to_physical_mapping    :    STRING := "iq2";
      pll3_inclk3_logical_to_physical_mapping    :    STRING := "iq3";
      pll3_inclk4_logical_to_physical_mapping    :    STRING := "iq4";
      pll3_inclk5_logical_to_physical_mapping    :    STRING := "iq5";
      pll3_inclk6_logical_to_physical_mapping    :    STRING := "iq6";
      pll3_inclk7_logical_to_physical_mapping    :    STRING := "iq7";
      pll3_inclk8_logical_to_physical_mapping    :    STRING := "pld_clk";
      pll3_inclk9_logical_to_physical_mapping    :    STRING := "gpll_clk";
      pll4_inclk0_logical_to_physical_mapping    :    STRING := "clkrefclk0";
      pll4_inclk1_logical_to_physical_mapping    :    STRING := "clkrefclk1";
      pll4_inclk2_logical_to_physical_mapping    :    STRING := "iq2";
      pll4_inclk3_logical_to_physical_mapping    :    STRING := "iq3";
      pll4_inclk4_logical_to_physical_mapping    :    STRING := "iq4";
      pll4_inclk5_logical_to_physical_mapping    :    STRING := "iq5";
      pll4_inclk6_logical_to_physical_mapping    :    STRING := "iq6";
      pll4_inclk7_logical_to_physical_mapping    :    STRING := "iq7";
      pll4_inclk8_logical_to_physical_mapping    :    STRING := "pld_clk";
      pll4_inclk9_logical_to_physical_mapping    :    STRING := "gpll_clk";
      pll5_inclk0_logical_to_physical_mapping    :    STRING := "clkrefclk0";
      pll5_inclk1_logical_to_physical_mapping    :    STRING := "clkrefclk1";
      pll5_inclk2_logical_to_physical_mapping    :    STRING := "iq2";
      pll5_inclk3_logical_to_physical_mapping    :    STRING := "iq3";
      pll5_inclk4_logical_to_physical_mapping    :    STRING := "iq4";
      pll5_inclk5_logical_to_physical_mapping    :    STRING := "iq5";
      pll5_inclk6_logical_to_physical_mapping    :    STRING := "iq6";
      pll5_inclk7_logical_to_physical_mapping    :    STRING := "iq7";
      pll5_inclk8_logical_to_physical_mapping    :    STRING := "pld_clk";
      pll5_inclk9_logical_to_physical_mapping    :    STRING := "gpll_clk";
      
      pll0_logical_to_physical_mapping    :    INTEGER := 0;
      pll1_logical_to_physical_mapping    :    INTEGER := 1;
      pll2_logical_to_physical_mapping    :    INTEGER := 2;
      pll3_logical_to_physical_mapping    :    INTEGER := 3;
      pll4_logical_to_physical_mapping    :    INTEGER := 4;
      pll5_logical_to_physical_mapping    :    INTEGER := 5;
            
      refclk_divider0_logical_to_physical_mapping    :    INTEGER := 0;
      refclk_divider1_logical_to_physical_mapping    :    INTEGER := 1;
      
      rx0_logical_to_physical_mapping    :    INTEGER := 0;
      rx1_logical_to_physical_mapping    :    INTEGER := 1;
      rx2_logical_to_physical_mapping    :    INTEGER := 2;
      rx3_logical_to_physical_mapping    :    INTEGER := 3;
      rx4_logical_to_physical_mapping    :    INTEGER := 4;
      rx5_logical_to_physical_mapping    :    INTEGER := 5;
      
      tx0_logical_to_physical_mapping    :    INTEGER := 0;
      tx1_logical_to_physical_mapping    :    INTEGER := 1;
      tx2_logical_to_physical_mapping    :    INTEGER := 2;
      tx3_logical_to_physical_mapping    :    INTEGER := 3;
      tx4_logical_to_physical_mapping    :    INTEGER := 4;
      tx5_logical_to_physical_mapping    :    INTEGER := 5;
      
      tx0_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx0_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx0_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx0_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx0_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx1_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx1_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx1_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx1_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx1_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx2_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx2_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx2_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx2_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx2_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx3_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx3_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx3_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx3_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx3_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx4_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx4_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx4_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx4_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx4_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx5_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx5_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx5_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx5_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx5_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";

      sim_dump_dprio_internal_reg_at_time          : INTEGER := 0;        -- in ps
      sim_dump_filename                            : STRING := "sim_dprio_dump.txt"        -- over-write when multiple CMUs
   );
   PORT (
      adet                                         : IN STD_LOGIC_VECTOR(3 DOWNTO 0) := (others => '0');
      cmudividerdprioin                            : IN STD_LOGIC_VECTOR(599 DOWNTO 0) := (others => '0');
      cmuplldprioin                                : IN STD_LOGIC_VECTOR(1799 DOWNTO 0) := (others => '0');
      dpclk                                        : IN STD_LOGIC := '0';
      dpriodisable                                 : IN STD_LOGIC := '1';
      dprioin                                      : IN STD_LOGIC := '0';
      dprioload                                    : IN STD_LOGIC := '0';
      extra10gin                                   : IN STD_LOGIC_VECTOR(6 DOWNTO 0) := (others => '0');
      fixedclk                                     : IN STD_LOGIC_VECTOR(5 DOWNTO 0) := (others => '0');
      lccmurtestbussel                             : IN STD_LOGIC_VECTOR(2 DOWNTO 0) := (others => '0');
      nonuserfromcal                               : IN STD_LOGIC := '0';
      pmacramtest                                  : IN STD_LOGIC := '0';    -- new 9.0 ww47
      quadreset                                    : IN STD_LOGIC := '0';
      rateswitch                                   : IN STD_LOGIC := '0';
      rateswitchdonein                             : IN STD_LOGIC := '0';
      rdalign                                      : IN STD_LOGIC_VECTOR(3 DOWNTO 0) := (others => '0');
      rdenablesync                                 : IN STD_LOGIC := '0';
      recovclk                                     : IN STD_LOGIC := '0';
      refclkdividerdprioin                         : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');
      rxanalogreset                                : IN STD_LOGIC_VECTOR(5 DOWNTO 0) := (others => '0');
      rxclk                                        : IN STD_LOGIC := '0';
      rxcoreclk                                    : IN STD_LOGIC := '0';
      rxctrl                                       : IN STD_LOGIC_VECTOR(3 DOWNTO 0) := (others => '0');
      rxdatain                                     : IN STD_LOGIC_VECTOR(31 DOWNTO 0) := (others => '0');
      rxdatavalid                                  : IN STD_LOGIC_VECTOR(3 DOWNTO 0) := (others => '0');
      rxdigitalreset                               : IN STD_LOGIC_VECTOR(3 DOWNTO 0) := (others => '0');
      rxpcsdprioin                                 : IN STD_LOGIC_VECTOR(1599 DOWNTO 0) := (others => '0');
      rxphfifordenable                             : IN STD_LOGIC := '0';
      rxphfiforeset                                : IN STD_LOGIC := '0';
      rxphfifowrdisable                            : IN STD_LOGIC := '0';
      rxpmadprioin                                 : IN STD_LOGIC_VECTOR(1799 DOWNTO 0) := (others => '0');
      rxpowerdown                                  : IN STD_LOGIC_VECTOR(5 DOWNTO 0) := (others => '0');
      rxrunningdisp                                : IN STD_LOGIC_VECTOR(3 DOWNTO 0) := (others => '0');
      scanclk                                      : IN STD_LOGIC := '0';
      scanin                                       : IN STD_LOGIC_VECTOR(22 DOWNTO 0) := (others => '0');
      scanmode                                     : IN STD_LOGIC := '0';
      scanshift                                    : IN STD_LOGIC := '0';
      syncstatus                                   : IN STD_LOGIC_VECTOR(3 DOWNTO 0) := (others => '0');
      testin                                       : IN STD_LOGIC_VECTOR(9999 DOWNTO 0) := (others => '0');
      txclk                                        : IN STD_LOGIC := '0';
      txcoreclk                                    : IN STD_LOGIC := '0';
      txctrl                                       : IN STD_LOGIC_VECTOR(3 DOWNTO 0) := (others => '0');
      txdatain                                     : IN STD_LOGIC_VECTOR(31 DOWNTO 0) := (others => '0');
      txdigitalreset                               : IN STD_LOGIC_VECTOR(3 DOWNTO 0) := (others => '0');
      txpcsdprioin                                 : IN STD_LOGIC_VECTOR(599 DOWNTO 0) := (others => '0');
      txphfiforddisable                            : IN STD_LOGIC := '0';
      txphfiforeset                                : IN STD_LOGIC := '0';
      txphfifowrenable                             : IN STD_LOGIC := '0';
      txpllreset                                   : IN STD_LOGIC_VECTOR(1 DOWNTO 0) := (others => '0');
      txpmadprioin                                 : IN STD_LOGIC_VECTOR(1799 DOWNTO 0) := (others => '0');
      alignstatus                                  : OUT STD_LOGIC;
      autospdx4configsel                           : OUT STD_LOGIC;
      autospdx4rateswitchout                       : OUT STD_LOGIC;
      autospdx4spdchg                              : OUT STD_LOGIC;
      clkdivpowerdn                                : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      
      cmudividerdprioout                           : OUT STD_LOGIC_VECTOR(599 DOWNTO 0);
      cmuplldprioout                               : OUT STD_LOGIC_VECTOR(1799 DOWNTO 0);
      digitaltestout                               : OUT STD_LOGIC_VECTOR(9 DOWNTO 0);
      dpriodisableout                              : OUT STD_LOGIC;
      dpriooe                                      : OUT STD_LOGIC;
      dprioout                                     : OUT STD_LOGIC;
      enabledeskew                                 : OUT STD_LOGIC;
      extra10gout                                  : OUT STD_LOGIC;
      fiforesetrd                                  : OUT STD_LOGIC;
      lccmutestbus                                 : OUT STD_LOGIC_VECTOR(7 DOWNTO 0);
      phfifiox4ptrsreset                           : OUT STD_LOGIC;
      pllpowerdn                                   : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      pllresetout                                  : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      quadresetout                                 : OUT STD_LOGIC;
      refclkdividerdprioout                        : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
      rxadcepowerdown                              : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      rxadceresetout                               : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      rxanalogresetout                             : OUT STD_LOGIC_VECTOR(5 DOWNTO 0);
      rxcrupowerdown                               : OUT STD_LOGIC_VECTOR(5 DOWNTO 0);
      rxcruresetout                                : OUT STD_LOGIC_VECTOR(5 DOWNTO 0);
      rxctrlout                                    : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      rxdataout                                    : OUT STD_LOGIC_VECTOR(31 DOWNTO 0);
      rxdigitalresetout                            : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      rxibpowerdown                                : OUT STD_LOGIC_VECTOR(5 DOWNTO 0);
      rxpcsdprioout                                : OUT STD_LOGIC_VECTOR(1599 DOWNTO 0);
      rxphfifox4byteselout                         : OUT STD_LOGIC;
      rxphfifox4wrclkout                           : OUT STD_LOGIC;
      rxphfifox4rdenableout                        : OUT STD_LOGIC;
      rxphfifox4wrenableout                        : OUT STD_LOGIC;
      rxpmadprioout                                : OUT STD_LOGIC_VECTOR(1799 DOWNTO 0);
      scanout                                      : OUT STD_LOGIC_VECTOR(22 DOWNTO 0);
      testout                                      : OUT STD_LOGIC_VECTOR(6999 DOWNTO 0);
      txanalogresetout                             : OUT STD_LOGIC_VECTOR(5 DOWNTO 0);
      txctrlout                                    : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      txdataout                                    : OUT STD_LOGIC_VECTOR(31 DOWNTO 0);
      txdetectrxpowerdown                          : OUT STD_LOGIC_VECTOR(5 DOWNTO 0);
      txdigitalresetout                            : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
      txdividerpowerdown                           : OUT STD_LOGIC_VECTOR(5 DOWNTO 0);
      txobpowerdown                                : OUT STD_LOGIC_VECTOR(5 DOWNTO 0);
      txpcsdprioout                                : OUT STD_LOGIC_VECTOR(599 DOWNTO 0);
      txphfifox4byteselout                         : OUT STD_LOGIC;
      txphfifox4rdclkout                           : OUT STD_LOGIC;
      txphfifox4rdenableout                        : OUT STD_LOGIC;
      txphfifox4wrenableout                        : OUT STD_LOGIC;
      txpmadprioout                                : OUT STD_LOGIC_VECTOR(1799 DOWNTO 0)
   );
END stratixiv_hssi_cmu;

ARCHITECTURE trans OF stratixiv_hssi_cmu IS

  signal txphfiforddisable_ipd  :STD_LOGIC;
  signal txctrl_ipd  :STD_LOGIC_VECTOR(3 DOWNTO 0);
  signal rxdatain_ipd  :STD_LOGIC_VECTOR(31 DOWNTO 0);
  signal txclk_ipd  :STD_LOGIC;
  signal syncstatus_ipd  :STD_LOGIC_VECTOR(3 DOWNTO 0);
  signal rxpcsdprioin_ipd  :STD_LOGIC_VECTOR(1599 DOWNTO 0);
  signal txdigitalreset_ipd  :STD_LOGIC_VECTOR(3 DOWNTO 0);
  signal txdatain_ipd  :STD_LOGIC_VECTOR(31 DOWNTO 0);
  signal scanclk_ipd  :STD_LOGIC;
  signal rateswitchdonein_ipd  :STD_LOGIC;
  signal rdenablesync_ipd  :STD_LOGIC;
  signal dpclk_ipd  :STD_LOGIC;
  signal rxphfiforeset_ipd  :STD_LOGIC;
  signal testin_ipd  :STD_LOGIC_VECTOR(9999 DOWNTO 0);
  signal txpllreset_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal rxrunningdisp_ipd  :STD_LOGIC_VECTOR(3 DOWNTO 0);
  signal rxdatavalid_ipd  :STD_LOGIC_VECTOR(3 DOWNTO 0);
  signal refclkdividerdprioin_ipd  :STD_LOGIC_VECTOR(1 DOWNTO 0);
  signal txpcsdprioin_ipd  :STD_LOGIC_VECTOR(599 DOWNTO 0);
  signal dprioin_ipd  :STD_LOGIC;
  signal rateswitch_ipd  :STD_LOGIC;
  signal rxctrl_ipd  :STD_LOGIC_VECTOR(3 DOWNTO 0);
  signal rxanalogreset_ipd  :STD_LOGIC_VECTOR(5 DOWNTO 0);
  signal rxclk_ipd  :STD_LOGIC;
  signal txphfifowrenable_ipd  :STD_LOGIC;
  signal rxphfifowrdisable_ipd  :STD_LOGIC;
  signal rdalign_ipd  :STD_LOGIC_VECTOR(3 DOWNTO 0);
  signal fixedclk_ipd  :STD_LOGIC_VECTOR(5 DOWNTO 0);
  signal dpriodisable_ipd  :STD_LOGIC;
  signal scanmode_ipd  :STD_LOGIC;
  signal rxphfifordenable_ipd  :STD_LOGIC;
  signal cmuplldprioin_ipd  :STD_LOGIC_VECTOR(1799 DOWNTO 0);
  signal txphfiforeset_ipd  :STD_LOGIC;
  signal txcoreclk_ipd  :STD_LOGIC;
  signal adet_ipd  :STD_LOGIC_VECTOR(3 DOWNTO 0);
  signal rxdigitalreset_ipd  :STD_LOGIC_VECTOR(3 DOWNTO 0);
  signal rxpmadprioin_ipd  :STD_LOGIC_VECTOR(1799 DOWNTO 0);
  signal cmudividerdprioin_ipd  :STD_LOGIC_VECTOR(599 DOWNTO 0);
  signal rxcoreclk_ipd  :STD_LOGIC;
  signal dprioload_ipd  :STD_LOGIC;
  signal scanin_ipd  :STD_LOGIC_VECTOR(22 DOWNTO 0);
  signal quadreset_ipd  :STD_LOGIC;
  signal nonuserfromcal_ipd  :STD_LOGIC;
  signal scanshift_ipd  :STD_LOGIC;
  signal txpmadprioin_ipd  :STD_LOGIC_VECTOR(1799 DOWNTO 0);
  signal recovclk_ipd  :STD_LOGIC;
  signal rxpowerdown_ipd  :STD_LOGIC_VECTOR(5 DOWNTO 0);

  signal pcie_tmp : STD_LOGIC;
  
   COMPONENT stratixiv_hssi_dskw_sm
      PORT (
         soft_reset                           : IN STD_LOGIC;
         clk_1                                : IN STD_LOGIC;
         octal_mode                           : IN STD_LOGIC;
         align_det_sync                       : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         rd_align                             : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         sync_status                          : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
         align_status                         : OUT STD_LOGIC;
         enable_deskew                        : OUT STD_LOGIC;
         fifo_reset_rd                        : OUT STD_LOGIC;
         curr_state                           : OUT STD_LOGIC_VECTOR(3 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_chnl_reset
      PORT (
         hard_reset                           : IN STD_LOGIC;
         soft_reset_all_hssi                  : IN STD_LOGIC;
         rreset                               : IN STD_LOGIC;
         rpowerdown                           : IN STD_LOGIC;
         rxurstpma                            : IN STD_LOGIC;
         rxurstpcs                            : IN STD_LOGIC;
         txurstpcs                            : IN STD_LOGIC;
         rpowdnr                              : IN STD_LOGIC;
         rpowdnt                              : IN STD_LOGIC;
         rrxurstpcs                           : IN STD_LOGIC;
         rtxurstpcs                           : IN STD_LOGIC;
         rrxurstpma                           : IN STD_LOGIC;
         rrx_cru_rst                          : IN STD_LOGIC;
         radce_rst                            : IN STD_LOGIC;
         urx_pdb                              : IN STD_LOGIC;
         rurx_pdb                             : IN STD_LOGIC;
         radce_pdb                            : IN STD_LOGIC;
         rrx_ib_pdb                           : IN STD_LOGIC;
         rtx_ob_pdb                           : IN STD_LOGIC;
         rtx_cgb_pdb                          : IN STD_LOGIC;
         rrx_cru_pdb                          : IN STD_LOGIC;
         rtx_pipe_en                          : IN STD_LOGIC;
         p0_state                             : IN STD_LOGIC;
         p0s_state                            : IN STD_LOGIC;
         p2_state                             : IN STD_LOGIC;
         rxpma_rstb                           : OUT STD_LOGIC;
         txpma_rstb                           : OUT STD_LOGIC;
         rxpcs_rst                            : OUT STD_LOGIC;
         txpcs_rst                            : OUT STD_LOGIC;
         cru_rstb                             : OUT STD_LOGIC;
         adce_rstb                            : OUT STD_LOGIC;
         adce_pdb                             : OUT STD_LOGIC;
         cru_pdb                              : OUT STD_LOGIC;
         rx_pdb                               : OUT STD_LOGIC;
         tx_pdb                               : OUT STD_LOGIC;
         cgb_pdb                              : OUT STD_LOGIC;
         rx_det_pdb                           : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_rxclk_ctl
      PORT (
         pld_rx_clk                           : IN STD_LOGIC;
         rcvd_clk_pma                         : IN STD_LOGIC;
         rcvd_clk0_pma                        : IN STD_LOGIC;
         tx_pma_clk                           : IN STD_LOGIC;
         refclk_pma                           : IN STD_LOGIC;
         fref                                 : IN STD_LOGIC;
         clklow                               : IN STD_LOGIC;
         scan_mode                            : IN STD_LOGIC;
         gen2ngen1                            : IN STD_LOGIC;
         gen2ngen1_bundle                     : IN STD_LOGIC;
         rx_div2_sync_centrl                  : IN STD_LOGIC;
         rx_div2_sync_quad_up                 : IN STD_LOGIC;
         rx_div2_sync_quad_down               : IN STD_LOGIC;
         rrcvd_clk_sel                        : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rclk_1_sel                           : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rclk_2_sel                           : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rrx_rd_clk_sel                       : IN STD_LOGIC;
         rxrst                                : IN STD_LOGIC;
         rindv_rx                             : IN STD_LOGIC;
         rdwidth_rx                           : IN STD_LOGIC;
         rfreerun_rx                          : IN STD_LOGIC;
         rauto_speed_ena                      : IN STD_LOGIC;
         rfreq_sel                            : IN STD_LOGIC;
         rrxpcsclkpwdn                        : IN STD_LOGIC;
         rmaster_rx                           : IN STD_LOGIC;
         rmaster_up_rx                        : IN STD_LOGIC;
         rself_sw_en_rx                       : IN STD_LOGIC;
         fref_muxed                           : OUT STD_LOGIC;
         clklow_muxed                         : OUT STD_LOGIC;
         rcvd_clk                             : OUT STD_LOGIC;
         clk_1_b                              : OUT STD_LOGIC;
         clk_2_b                              : OUT STD_LOGIC;
         rx_wr_clk                            : OUT STD_LOGIC;
         rx_rd_clk                            : OUT STD_LOGIC;
         rx_clk                               : OUT STD_LOGIC;
         rcvd_clk_pma_b                       : OUT STD_LOGIC;
         clk_2_b_raw                          : OUT STD_LOGIC;
         rx_wr_clk_raw                        : OUT STD_LOGIC;
         rx_rd_clk_raw                        : OUT STD_LOGIC;
         rx_div2_sync_out                     : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_rcv_sm
      PORT (
         clk_2                                : IN STD_LOGIC;
         soft_reset                           : IN STD_LOGIC;
         indv                                 : IN STD_LOGIC;
         dec_data_valid                       : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         dec_data                             : IN STD_LOGIC_VECTOR(31 DOWNTO 0);
         dec_ctl                              : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         running_disp                         : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         rx_local_fault_clr                   : IN STD_LOGIC;
         xs_link_status_set                   : IN STD_LOGIC;
         tx_local_fault_det                   : IN STD_LOGIC;
         rxaui_s2gx_en                        : IN  STD_LOGIC;
         rx_data_rs                           : OUT STD_LOGIC_VECTOR(31 DOWNTO 0);
         rx_ctl_rs                            : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
         rx_local_fault                       : OUT STD_LOGIC;
         xs_link_status                       : OUT STD_LOGIC;
         curr_state                           : OUT STD_LOGIC_VECTOR(1 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_txclk_ctl
      PORT (
         pld_tx_clk                           : IN STD_LOGIC;
         refclk_pma                           : IN STD_LOGIC;
         txpma_local_clk                      : IN STD_LOGIC;
         txrst                                : IN STD_LOGIC;
         scan_mode                            : IN STD_LOGIC;
         gen2ngen1                            : IN STD_LOGIC;
         gen2ngen1_bundle                     : IN STD_LOGIC;
         tx_div2_sync_centrl                  : IN STD_LOGIC;
         tx_div2_sync_quad_up                 : IN STD_LOGIC;
         tx_div2_sync_quad_down               : IN STD_LOGIC;
         rindv_tx                             : IN STD_LOGIC;
         rtxwrclksel                          : IN STD_LOGIC;
         rtxrdclksel                          : IN STD_LOGIC;
         rdwidth_tx                           : IN STD_LOGIC;
         rfreerun_tx                          : IN STD_LOGIC;
         rauto_speed_ena                      : IN STD_LOGIC;
         rfreq_sel                            : IN STD_LOGIC;
         rtxpcsclkpwdn                        : IN STD_LOGIC;
         rmaster_tx                           : IN STD_LOGIC;
         rmaster_up_tx                        : IN STD_LOGIC;
         rself_sw_en_tx                       : IN STD_LOGIC;
         refclk_b                             : OUT STD_LOGIC;
         wr_clk_pos                           : OUT STD_LOGIC;
         fifo_rd_clk                          : OUT STD_LOGIC;
         tx_clk_out                           : OUT STD_LOGIC;
         refclk_b_raw                         : OUT STD_LOGIC;
         wr_clk_pos_raw                       : OUT STD_LOGIC;
         fifo_rd_clk_raw                      : OUT STD_LOGIC;
         tx_div2_sync_out                     : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_auto_speed_neg
       GENERIC (
          WAIT_RATE_CHANGE           : INTEGER := 0;
          WAIT_FOR_PHFIFO            : INTEGER := 1;
          DISABLE_PC_BYTE            : INTEGER := 2;
          SET_CONFIG_SEL             : INTEGER := 3;
          WAIT_GEN2NGEN1_CHANGE      : INTEGER := 4;
          WAIT_PMA_DONE_CNTR         : INTEGER := 5;
          DEASSERT_PC_PTR_RESET      : INTEGER := 6;
          WAIT_DEASSERT_RST_CNTR     : INTEGER := 7;
          ENABLE_PC_BYTE             : INTEGER := 8;
          WAIT_ENABLE_CNTR           : INTEGER := 9;
          SPEED_CHANGE_DONE          : INTEGER := 10
       );
       PORT (
          refclk                     : IN STD_LOGIC;
          rxpcs_rst_int              : IN STD_LOGIC;
          rate                       : IN STD_LOGIC;
          gen2ngen1                  : IN STD_LOGIC;
          config_sel_centrl          : IN STD_LOGIC;
          config_sel_quad_up         : IN STD_LOGIC;
          config_sel_quad_down       : IN STD_LOGIC;
          rindv_rx                   : IN STD_LOGIC;
          rmaster_rx                 : IN STD_LOGIC;
          rmaster_up_rx              : IN STD_LOGIC;
          rauto_speed_ena            : IN STD_LOGIC;
          singleorbundle             : IN STD_LOGIC;
          rphfifo_regmode_rx         : IN STD_LOGIC;
          rpma_done_count            : IN STD_LOGIC_VECTOR(17 DOWNTO 0);
          rauto_deassert_pc_rst_cnt  : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
          rauto_pc_en_cnt            : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
          rwait_for_phfifo_cnt       : IN STD_LOGIC_VECTOR(5 DOWNTO 0);
          config_sel                 : OUT STD_LOGIC;
          pcie_switch                : OUT STD_LOGIC;
          speed_change               : OUT STD_LOGIC;
          dis_pc_byte                : OUT STD_LOGIC;
          reset_pc_ptrs              : OUT STD_LOGIC;
          cs                         : OUT STD_LOGIC_VECTOR(3 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_dprio_top
      GENERIC (
      -- Simulation Only 
      clkdiv0_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv0_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv1_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv1_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv2_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv2_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv3_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv3_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv4_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv4_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      clkdiv5_inclk0_logical_to_physical_mapping   : STRING := "pll0";
      clkdiv5_inclk1_logical_to_physical_mapping   : STRING := "pll1";
      
      pll0_inclk0_logical_to_physical_mapping    :    STRING := "clkrefclk0";
      pll0_inclk1_logical_to_physical_mapping    :    STRING := "clkrefclk1";
      pll0_inclk2_logical_to_physical_mapping    :    STRING := "iq2";
      pll0_inclk3_logical_to_physical_mapping    :    STRING := "iq3";
      pll0_inclk4_logical_to_physical_mapping    :    STRING := "iq4";
      pll0_inclk5_logical_to_physical_mapping    :    STRING := "iq5";
      pll0_inclk6_logical_to_physical_mapping    :    STRING := "iq6";
      pll0_inclk7_logical_to_physical_mapping    :    STRING := "iq7";
      pll0_inclk8_logical_to_physical_mapping    :    STRING := "pld_clk";
      pll0_inclk9_logical_to_physical_mapping    :    STRING := "gpll_clk";
      pll1_inclk0_logical_to_physical_mapping    :    STRING := "clkrefclk0";
      pll1_inclk1_logical_to_physical_mapping    :    STRING := "clkrefclk1";
      pll1_inclk2_logical_to_physical_mapping    :    STRING := "iq2";
      pll1_inclk3_logical_to_physical_mapping    :    STRING := "iq3";
      pll1_inclk4_logical_to_physical_mapping    :    STRING := "iq4";
      pll1_inclk5_logical_to_physical_mapping    :    STRING := "iq5";
      pll1_inclk6_logical_to_physical_mapping    :    STRING := "iq6";
      pll1_inclk7_logical_to_physical_mapping    :    STRING := "iq7";
      pll1_inclk8_logical_to_physical_mapping    :    STRING := "pld_clk";
      pll1_inclk9_logical_to_physical_mapping    :    STRING := "gpll_clk";
      pll2_inclk0_logical_to_physical_mapping    :    STRING := "clkrefclk0";
      pll2_inclk1_logical_to_physical_mapping    :    STRING := "clkrefclk1";
      pll2_inclk2_logical_to_physical_mapping    :    STRING := "iq2";
      pll2_inclk3_logical_to_physical_mapping    :    STRING := "iq3";
      pll2_inclk4_logical_to_physical_mapping    :    STRING := "iq4";
      pll2_inclk5_logical_to_physical_mapping    :    STRING := "iq5";
      pll2_inclk6_logical_to_physical_mapping    :    STRING := "iq6";
      pll2_inclk7_logical_to_physical_mapping    :    STRING := "iq7";
      pll2_inclk8_logical_to_physical_mapping    :    STRING := "pld_clk";
      pll2_inclk9_logical_to_physical_mapping    :    STRING := "gpll_clk";
      pll3_inclk0_logical_to_physical_mapping    :    STRING := "clkrefclk0";
      pll3_inclk1_logical_to_physical_mapping    :    STRING := "clkrefclk1";
      pll3_inclk2_logical_to_physical_mapping    :    STRING := "iq2";
      pll3_inclk3_logical_to_physical_mapping    :    STRING := "iq3";
      pll3_inclk4_logical_to_physical_mapping    :    STRING := "iq4";
      pll3_inclk5_logical_to_physical_mapping    :    STRING := "iq5";
      pll3_inclk6_logical_to_physical_mapping    :    STRING := "iq6";
      pll3_inclk7_logical_to_physical_mapping    :    STRING := "iq7";
      pll3_inclk8_logical_to_physical_mapping    :    STRING := "pld_clk";
      pll3_inclk9_logical_to_physical_mapping    :    STRING := "gpll_clk";
      pll4_inclk0_logical_to_physical_mapping    :    STRING := "clkrefclk0";
      pll4_inclk1_logical_to_physical_mapping    :    STRING := "clkrefclk1";
      pll4_inclk2_logical_to_physical_mapping    :    STRING := "iq2";
      pll4_inclk3_logical_to_physical_mapping    :    STRING := "iq3";
      pll4_inclk4_logical_to_physical_mapping    :    STRING := "iq4";
      pll4_inclk5_logical_to_physical_mapping    :    STRING := "iq5";
      pll4_inclk6_logical_to_physical_mapping    :    STRING := "iq6";
      pll4_inclk7_logical_to_physical_mapping    :    STRING := "iq7";
      pll4_inclk8_logical_to_physical_mapping    :    STRING := "pld_clk";
      pll4_inclk9_logical_to_physical_mapping    :    STRING := "gpll_clk";
      pll5_inclk0_logical_to_physical_mapping    :    STRING := "clkrefclk0";
      pll5_inclk1_logical_to_physical_mapping    :    STRING := "clkrefclk1";
      pll5_inclk2_logical_to_physical_mapping    :    STRING := "iq2";
      pll5_inclk3_logical_to_physical_mapping    :    STRING := "iq3";
      pll5_inclk4_logical_to_physical_mapping    :    STRING := "iq4";
      pll5_inclk5_logical_to_physical_mapping    :    STRING := "iq5";
      pll5_inclk6_logical_to_physical_mapping    :    STRING := "iq6";
      pll5_inclk7_logical_to_physical_mapping    :    STRING := "iq7";
      pll5_inclk8_logical_to_physical_mapping    :    STRING := "pld_clk";
      pll5_inclk9_logical_to_physical_mapping    :    STRING := "gpll_clk";
      
      pll0_logical_to_physical_mapping    :    INTEGER := 0;
      pll1_logical_to_physical_mapping    :    INTEGER := 1;
      pll2_logical_to_physical_mapping    :    INTEGER := 2;
      pll3_logical_to_physical_mapping    :    INTEGER := 3;
      pll4_logical_to_physical_mapping    :    INTEGER := 4;
      pll5_logical_to_physical_mapping    :    INTEGER := 5;

      refclk_divider0_logical_to_physical_mapping    :    INTEGER := 0;
      refclk_divider1_logical_to_physical_mapping    :    INTEGER := 1;
      
      rx0_logical_to_physical_mapping    :    INTEGER := 0;
      rx1_logical_to_physical_mapping    :    INTEGER := 1;
      rx2_logical_to_physical_mapping    :    INTEGER := 2;
      rx3_logical_to_physical_mapping    :    INTEGER := 3;
      rx4_logical_to_physical_mapping    :    INTEGER := 4;
      rx5_logical_to_physical_mapping    :    INTEGER := 5;
      
      tx0_logical_to_physical_mapping    :    INTEGER := 0;
      tx1_logical_to_physical_mapping    :    INTEGER := 1;
      tx2_logical_to_physical_mapping    :    INTEGER := 2;
      tx3_logical_to_physical_mapping    :    INTEGER := 3;
      tx4_logical_to_physical_mapping    :    INTEGER := 4;
      tx5_logical_to_physical_mapping    :    INTEGER := 5;
      
      tx0_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx0_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx0_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx0_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx0_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx1_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx1_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx1_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx1_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx1_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx2_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx2_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx2_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx2_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx2_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx3_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx3_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx3_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx3_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx3_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx4_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx4_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx4_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx4_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx4_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";
      tx5_pma_inclk0_logical_to_physical_mapping : STRING := "x1";
      tx5_pma_inclk1_logical_to_physical_mapping : STRING := "x4";
      tx5_pma_inclk2_logical_to_physical_mapping : STRING := "xn_top";
      tx5_pma_inclk3_logical_to_physical_mapping : STRING := "xn_bottom";
      tx5_pma_inclk4_logical_to_physical_mapping : STRING := "hypertransport";

         sim_dump_dprio_internal_reg_at_time          : INTEGER := 0;
         sim_dump_filename                            : STRING := "sim_dprio_dump.txt"
      );
      PORT (
         sync_status                          : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         align_status                         : IN STD_LOGIC;
         mdio_in                              : IN STD_LOGIC;
         mdc                                  : IN STD_LOGIC;
         port_addr                            : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         dev_addr                             : IN STD_LOGIC_VECTOR(4 DOWNTO 0);
         mdio_dis                             : IN STD_LOGIC;
         dprioload                            : IN STD_LOGIC;
         mdio_rst                             : IN STD_LOGIC;
         cmudividerdprioin                    : IN STD_LOGIC_VECTOR(599 DOWNTO 0);
         cmuplldprioin                        : IN STD_LOGIC_VECTOR(1799 DOWNTO 0);
         refclkdividerdprioin                 : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rxpcsdprioin                         : IN STD_LOGIC_VECTOR(1599 DOWNTO 0);
         rxpmadprioin                         : IN STD_LOGIC_VECTOR(1799 DOWNTO 0);
         txpcsdprioin                         : IN STD_LOGIC_VECTOR(599 DOWNTO 0);
         txpmadprioin                         : IN STD_LOGIC_VECTOR(1799 DOWNTO 0);
         cmudividerdprioout                   : OUT STD_LOGIC_VECTOR(599 DOWNTO 0);
         cmuplldprioout                       : OUT STD_LOGIC_VECTOR(1799 DOWNTO 0);
         refclkdividerdprioout                : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
         rxpcsdprioout                        : OUT STD_LOGIC_VECTOR(1599 DOWNTO 0);
         rxpmadprioout                        : OUT STD_LOGIC_VECTOR(1799 DOWNTO 0);
         txpcsdprioout                        : OUT STD_LOGIC_VECTOR(599 DOWNTO 0);
         txpmadprioout                        : OUT STD_LOGIC_VECTOR(1799 DOWNTO 0);
         mdio_out                             : OUT STD_LOGIC;
         data_enable_n                        : OUT STD_LOGIC;
         mdio_curr_st                         : OUT STD_LOGIC_VECTOR(2 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_clk_ctl
      PORT (
         pclk_pma                             : IN STD_LOGIC;
         refclk_dig                           : IN STD_LOGIC;
         mdc                                  : IN STD_LOGIC;
         ser_clk                              : IN STD_LOGIC;
         ser_mode                             : IN STD_LOGIC;
         scan_mode                            : IN STD_LOGIC;
         scan_clk                             : IN STD_LOGIC;
         rfreerun_centrl                      : IN STD_LOGIC;
         rcentrl_clk_sel                      : IN STD_LOGIC;
         rrefclk_out_div2                     : IN STD_LOGIC;
         hard_reset                           : IN STD_LOGIC;
         txrst                                : IN STD_LOGIC;
         refclk_pma_out                       : OUT STD_LOGIC;
         mdc_b                                : OUT STD_LOGIC;
         refclk_out                           : OUT STD_LOGIC;
         rauto_speed_ena                      : IN STD_LOGIC;
         rfreq_sel                            : IN STD_LOGIC;
         gen2ngen1_bundle                     : IN STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_tx_sm
      PORT (
         tx_clk                               : IN STD_LOGIC;
         soft_reset                           : IN STD_LOGIC;
         tx_data                              : IN STD_LOGIC_VECTOR(31 DOWNTO 0);
         tx_ctl                               : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
         tx_local_fault_clr                   : IN STD_LOGIC;
         indv                                 : IN STD_LOGIC;
         rd_enable_sync                       : IN STD_LOGIC;
         rxaui_s2gx_en                        : IN  STD_LOGIC;
         sm_data                              : OUT STD_LOGIC_VECTOR(31 DOWNTO 0);
         sm_ctl                               : OUT STD_LOGIC_VECTOR(3 DOWNTO 0);
         tx_local_fault_det                   : OUT STD_LOGIC;
         tx_local_fault                       : OUT STD_LOGIC;
         curr_state                           : OUT STD_LOGIC_VECTOR(3 DOWNTO 0)
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_rx_ctrl
      PORT (
         soft_reset                           : IN STD_LOGIC;
         clk_2                                : IN STD_LOGIC;
         rx_rd_clk                            : IN STD_LOGIC;
         rx_wr_clk                            : IN STD_LOGIC;
         scan_mode                            : IN STD_LOGIC;
         rrxfifo_urst_en                      : IN STD_LOGIC;
         rxfifo_urst                          : IN STD_LOGIC;
         rrxphfifopldctl_en                   : IN STD_LOGIC;
         pld_wr_dis                           : IN STD_LOGIC;
         pld_re                               : IN STD_LOGIC;
         dis_pc_byte                          : IN STD_LOGIC;
         rauto_speed_ena                      : IN STD_LOGIC;
         rx_we_out                            : OUT STD_LOGIC;
         wr_enable_out                        : OUT STD_LOGIC;
         rd_enable_out                        : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_quad_reset
      PORT (
         entest                               : IN STD_LOGIC;
         plniotri                             : IN STD_LOGIC;
         npor                                 : IN STD_LOGIC;
         frzreg                               : IN STD_LOGIC;
         pllurst                              : IN STD_LOGIC;
         rpllurst                             : IN STD_LOGIC;
         rpowerdown                           : IN STD_LOGIC;
         rreset                               : IN STD_LOGIC;
         rxurstcmu                            : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rrxurstcmu                           : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rrx_cmu_rst                          : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         ucmurx_pdb                           : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rclk_pdb                             : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rcmu_powdnr                          : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rcmu_cru_pdb                         : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rcmu_urx_pdb                         : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rcmu_rx_ib_pdb                       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rcmu_powdnt                          : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rcmu_tx_ob_pdb                       : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rcmu_tx_cgb_pdb                      : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         rcmu_rx_det_pdb                      : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
         cmu0_rxpma_rstb                      : OUT STD_LOGIC;
         cmu0_txpma_rstb                      : OUT STD_LOGIC;
         cmu0_cru_rstb                        : OUT STD_LOGIC;
         cmu1_rxpma_rstb                      : OUT STD_LOGIC;
         cmu1_txpma_rstb                      : OUT STD_LOGIC;
         cmu1_cru_rstb                        : OUT STD_LOGIC;
         cmu0_rx_pdb                          : OUT STD_LOGIC;
         cmu0_cru_pdb                         : OUT STD_LOGIC;
         cmu0_clk_pdb                         : OUT STD_LOGIC;
         cmu0_tx_pdb                          : OUT STD_LOGIC;
         cmu0_cgb_pdb                         : OUT STD_LOGIC;
         cmu0_rx_det_pdb                      : OUT STD_LOGIC;
         cmu1_rx_pdb                          : OUT STD_LOGIC;
         cmu1_cru_pdb                         : OUT STD_LOGIC;
         cmu1_clk_pdb                         : OUT STD_LOGIC;
         cmu1_tx_pdb                          : OUT STD_LOGIC;
         cmu1_cgb_pdb                         : OUT STD_LOGIC;
         cmu1_rx_det_pdb                      : OUT STD_LOGIC;
         mdio_rst                             : OUT STD_LOGIC;
         hard_reset                           : OUT STD_LOGIC;
         soft_reset_all_hssi                  : OUT STD_LOGIC
      );
   END COMPONENT;
   
   COMPONENT stratixiv_hssi_cmu_tx_ctrl
      PORT (
         soft_reset                           : IN STD_LOGIC;
         fifo_wr_clk                          : IN STD_LOGIC;
         fifo_rd_clk                          : IN STD_LOGIC;
         refclk_b_in                          : IN STD_LOGIC;
         scan_mode                            : IN STD_LOGIC;
         rtxfifo_urst_en                      : IN STD_LOGIC;
         txfifo_urst                          : IN STD_LOGIC;
         rtxphfifopldctl_en                   : IN STD_LOGIC;
         pld_we                               : IN STD_LOGIC;
         pld_rd_dis                           : IN STD_LOGIC;
         dis_pc_byte                          : IN STD_LOGIC;
         rauto_speed_ena                      : IN STD_LOGIC;
         wr_enable_out                        : OUT STD_LOGIC;
         rd_enable_out                        : OUT STD_LOGIC;
         fifo_select_out                      : OUT STD_LOGIC
      );
   END COMPONENT;
   
   --/////////////////////////////////////////////////////////////////////////
   -- const wire ---------------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   SIGNAL vcc_wire                          : STD_LOGIC;
   SIGNAL gnd_wire                          : STD_LOGIC;
   SIGNAL dummy_wire                        : STD_LOGIC;
   
   --/////////////////////////////////////////////////////////////////////////
   -- optimization -------------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   SIGNAL init_in_xaui_mode                 : STD_LOGIC;
   
   --/////////////////////////////////////////////////////////////////////////
   -- ww47 new CRAMs ------------------------------------------------------ //
   --/////////////////////////////////////////////////////////////////////////
   SIGNAL init_rauto_deassert_pc_rst_cnt    : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL init_rauto_pc_en_cnt              : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL init_rauto_speed_ena              : STD_LOGIC;
   SIGNAL init_rclk_1_sel                   : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rclk_2_sel                   : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rdwidth_rx                   : STD_LOGIC;
   SIGNAL init_rdwidth_tx                   : STD_LOGIC;
   SIGNAL init_rfreerun_rx                  : STD_LOGIC;
   SIGNAL init_rfreerun_tx                  : STD_LOGIC;
   SIGNAL init_rfreq_sel                    : STD_LOGIC;
   SIGNAL init_rindv_rx                     : STD_LOGIC;
   SIGNAL init_rindv_tx                     : STD_LOGIC;
   SIGNAL init_rmaster_rx                   : STD_LOGIC;
   SIGNAL init_rmaster_tx                   : STD_LOGIC;
   SIGNAL init_rmaster_up_rx                : STD_LOGIC;
   SIGNAL init_rmaster_up_tx                : STD_LOGIC;
   SIGNAL init_rphfifo_regmode_rx           : STD_LOGIC;
   SIGNAL init_rpma_done_count              : STD_LOGIC_VECTOR(17 DOWNTO 0);
   SIGNAL init_rrcvd_clk_sel                : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL init_rrx_rd_clk_sel               : STD_LOGIC;
   SIGNAL init_rrxfifo_urst_en              : STD_LOGIC;
   SIGNAL init_rrxpcsclkpwdn                : STD_LOGIC;
   SIGNAL init_rrxphfifopldctl_en           : STD_LOGIC;
   SIGNAL init_rself_sw_en_rx               : STD_LOGIC;
   SIGNAL init_rself_sw_en_tx               : STD_LOGIC;
   SIGNAL init_rtxpcsclkpwdn                : STD_LOGIC;
   SIGNAL init_rtxphfifopldctl_en           : STD_LOGIC;
   SIGNAL init_rtxrdclksel                  : STD_LOGIC;
   SIGNAL init_rtxwrclksel                  : STD_LOGIC;
   SIGNAL init_scan_mode                    : STD_LOGIC;
   
   -- cram used in centrl_clk_ctl but not in WYS
   SIGNAL init_rfreerun_centrl              : STD_LOGIC;
   SIGNAL init_rcentrl_clk_sel              : STD_LOGIC;
   SIGNAL init_rrefclk_out_div2             : STD_LOGIC;
   
   SIGNAL init_rtxfifo_urst_en              : STD_LOGIC;        -- used in txctrl
   
   SIGNAL cram_rauto_deassert_pc_rst_cnt    : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL cram_rauto_pc_en_cnt              : STD_LOGIC_VECTOR(4 DOWNTO 0);
   SIGNAL cram_rauto_speed_ena              : STD_LOGIC;
   SIGNAL cram_rclk_1_sel                   : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rclk_2_sel                   : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rdwidth_rx                   : STD_LOGIC;
   SIGNAL cram_rdwidth_tx                   : STD_LOGIC;
   SIGNAL cram_rfreerun_rx                  : STD_LOGIC;
   SIGNAL cram_rfreerun_tx                  : STD_LOGIC;
   SIGNAL cram_rfreq_sel                    : STD_LOGIC;
   SIGNAL cram_rindv_rx                     : STD_LOGIC;
   SIGNAL cram_rindv_tx                     : STD_LOGIC;
   SIGNAL cram_rmaster_rx                   : STD_LOGIC;
   SIGNAL cram_rmaster_tx                   : STD_LOGIC;
   SIGNAL cram_rmaster_up_rx                : STD_LOGIC;
   SIGNAL cram_rmaster_up_tx                : STD_LOGIC;
   SIGNAL cram_rphfifo_regmode_rx           : STD_LOGIC;
   SIGNAL cram_rpma_done_count              : STD_LOGIC_VECTOR(17 DOWNTO 0);
   SIGNAL cram_rrcvd_clk_sel                : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL cram_rrx_rd_clk_sel               : STD_LOGIC;
   SIGNAL cram_rrxfifo_urst_en              : STD_LOGIC;
   SIGNAL cram_rrxpcsclkpwdn                : STD_LOGIC;
   SIGNAL cram_rrxphfifopldctl_en           : STD_LOGIC;
   SIGNAL cram_rself_sw_en_rx               : STD_LOGIC;
   SIGNAL cram_rself_sw_en_tx               : STD_LOGIC;
   SIGNAL cram_rtxpcsclkpwdn                : STD_LOGIC;
   SIGNAL cram_rtxphfifopldctl_en           : STD_LOGIC;
   SIGNAL cram_rtxrdclksel                  : STD_LOGIC;
   SIGNAL cram_rtxwrclksel                  : STD_LOGIC;
   SIGNAL cram_scan_mode                    : STD_LOGIC;
   
   -- cram used in centrl_clk_ctl but not in WYS
   SIGNAL cram_rfreerun_centrl              : STD_LOGIC;
   SIGNAL cram_rcentrl_clk_sel              : STD_LOGIC;
   SIGNAL cram_rrefclk_out_div2             : STD_LOGIC;
   
   SIGNAL cram_rtxfifo_urst_en              : STD_LOGIC;       -- used in txctrl

   -- ww12_RTL update
   SIGNAL init_rxaui_s2gx_en_rx             : STD_LOGIC;
   SIGNAL init_rxaui_s2gx_en_tx             : STD_LOGIC;
   SIGNAL cram_rxaui_s2gx_en_rx             : STD_LOGIC;
   SIGNAL cram_rxaui_s2gx_en_tx             : STD_LOGIC;

   SIGNAL init_rwait_for_phfifo_cnt         : STD_LOGIC_VECTOR(5 DOWNTO 0);
   SIGNAL cram_rwait_for_phfifo_cnt         : STD_LOGIC_VECTOR(5 DOWNTO 0);
   
   --///////////////////////////////////////////////////////////////////////////
   -- INPUT Filtering --------------------------------------------------------//
   --///////////////////////////////////////////////////////////////////////////
   
   SIGNAL dpclk_in                          : STD_LOGIC;
   SIGNAL dpriodisable_in                   : STD_LOGIC;
   SIGNAL dprioin_in                        : STD_LOGIC;
   SIGNAL dprioload_in                      : STD_LOGIC;
   SIGNAL fixedclk_in                       : STD_LOGIC_VECTOR(5 DOWNTO 0);
   SIGNAL quadreset_in                      : STD_LOGIC;
   SIGNAL rxanalogreset_in                  : STD_LOGIC_VECTOR(5 DOWNTO 0);
   SIGNAL rxclk_in                          : STD_LOGIC;
   SIGNAL rxdigitalreset_in                 : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rxpowerdown_in                    : STD_LOGIC_VECTOR(5 DOWNTO 0);
   SIGNAL txclk_in                          : STD_LOGIC;
   SIGNAL txdigitalreset_in                 : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL txpllreset_in                     : STD_LOGIC_VECTOR(1 DOWNTO 0);        --NEW
   
   -- new added in ww47
   SIGNAL rateswitch_in                     : STD_LOGIC;
   SIGNAL rateswitchdonein_in               : STD_LOGIC;
   SIGNAL rxcoreclk_in                      : STD_LOGIC;
   SIGNAL rxphfifordenable_in               : STD_LOGIC;
   SIGNAL rxphfiforeset_in                  : STD_LOGIC;
   SIGNAL rxphfifowrdisable_in              : STD_LOGIC;
   SIGNAL scanclk_in                        : STD_LOGIC;
   SIGNAL scanin_in                         : STD_LOGIC_VECTOR(22 DOWNTO 0);
   SIGNAL scanmode_in                       : STD_LOGIC;
   SIGNAL scanshift_in                      : STD_LOGIC;
   SIGNAL txcoreclk_in                      : STD_LOGIC;
   SIGNAL txphfiforddisable_in              : STD_LOGIC;
   SIGNAL txphfiforeset_in                  : STD_LOGIC;
   SIGNAL txphfifowrenable_in               : STD_LOGIC;
   
   --///////////////////////////////////////////////////////////////////////////
   -- TIMING -- TCO/TSU/HOLD                                                  //
   --///////////////////////////////////////////////////////////////////////////
   SIGNAL dprioout_tim                      : STD_LOGIC;
   SIGNAL dpriooe_tim                       : STD_LOGIC;
   
   --/////////////////////////////////////////////////////////////////////////
   -- quad_reset ---------------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   
   SIGNAL qr_in_entest                      : STD_LOGIC;        -- Test mode control from Control block
   SIGNAL qr_in_plniotri                    : STD_LOGIC;        -- PLL output enable
   SIGNAL qr_in_npor                        : STD_LOGIC;        -- Power on reset
   SIGNAL qr_in_frzreg                      : STD_LOGIC;        -- Freeze register during power-up
   SIGNAL qr_in_pllurst                     : STD_LOGIC;        -- PLL user reset
   -- Reset CRAMs
   SIGNAL qr_cram_rpllurst                  : STD_LOGIC;        -- Gating CRAM for PLLURST
   SIGNAL qr_cram_rpowerdown                : STD_LOGIC;        -- Quad power down CRAM
   SIGNAL qr_cram_rreset                    : STD_LOGIC;        -- Quad reset CRAM
   
   -- Reset outputs
   SIGNAL qr_out_cmu_rstb                   : STD_LOGIC;        -- CMU reset
   SIGNAL qr_out_mdio_rst                   : STD_LOGIC;        -- MDIO reset
   SIGNAL qr_out_hard_reset                 : STD_LOGIC;        -- Output HARD_RESET signal for other MDIO modules
   SIGNAL qr_out_soft_reset_all_hssi        : STD_LOGIC;        -- Quad soft reset output
   
   -- new in ww47 -------------------------------------------
   -- CMU reset inputs
   SIGNAL qr_in_rxurstcmu                   : STD_LOGIC_VECTOR(1 DOWNTO 0);        -- Dynamic signal for CMU[1:0]_RXPMA_RSTB
   
   -- CMU qr_cram_reset CRAMs
   SIGNAL qr_cram_rrxurstcmu                : STD_LOGIC_VECTOR(1 DOWNTO 0);        -- Gating CRAM for dynamic signal qr_cram_rxurstcmu
   SIGNAL qr_cram_rrx_cmu_rst               : STD_LOGIC_VECTOR(1 DOWNTO 0);        -- TXPLL / qr_cram_rXPLL qr_cram_reset
   
   -- CMU powerdown inputs
   SIGNAL qr_in_ucmurx_pdb                  : STD_LOGIC_VECTOR(1 DOWNTO 0);        -- Dynamic signal for CMU[1:0]_RX_PDB
   
   -- CMU powerdown CRAMs
   SIGNAL qr_cram_rclk_pdb                  : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL qr_cram_rcmu_powdnr               : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL qr_cram_rcmu_cru_pdb              : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL qr_cram_rcmu_urx_pdb              : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL qr_cram_rcmu_rx_ib_pdb            : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL qr_cram_rcmu_powdnt               : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL qr_cram_rcmu_tx_ob_pdb            : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL qr_cram_rcmu_tx_cgb_pdb           : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL qr_cram_rcmu_rx_det_pdb           : STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   -- CMU reset outputs - moved to chnl reset
   SIGNAL qr_out_cmu0_rxpma_rstb            : STD_LOGIC;
   SIGNAL qr_out_cmu0_txpma_rstb            : STD_LOGIC;
   SIGNAL qr_out_cmu0_cru_rstb              : STD_LOGIC;
   
   SIGNAL qr_out_cmu1_rxpma_rstb            : STD_LOGIC;
   SIGNAL qr_out_cmu1_txpma_rstb            : STD_LOGIC;
   SIGNAL qr_out_cmu1_cru_rstb              : STD_LOGIC;
   
   -- CMU powerdown outputs - moved to chnl reset
   SIGNAL qr_out_cmu0_rx_pdb                : STD_LOGIC;
   SIGNAL qr_out_cmu0_cru_pdb               : STD_LOGIC;
   SIGNAL qr_out_cmu0_clk_pdb               : STD_LOGIC;
   SIGNAL qr_out_cmu0_tx_pdb                : STD_LOGIC;
   SIGNAL qr_out_cmu0_cgb_pdb               : STD_LOGIC;
   SIGNAL qr_out_cmu0_rx_det_pdb            : STD_LOGIC;
   
   SIGNAL qr_out_cmu1_rx_pdb                : STD_LOGIC;
   SIGNAL qr_out_cmu1_cru_pdb               : STD_LOGIC;
   SIGNAL qr_out_cmu1_clk_pdb               : STD_LOGIC;
   SIGNAL qr_out_cmu1_tx_pdb                : STD_LOGIC;
   SIGNAL qr_out_cmu1_cgb_pdb               : STD_LOGIC;
   SIGNAL qr_out_cmu1_rx_det_pdb            : STD_LOGIC;
   
   --/////////////////////////////////////////////////////////////////////////
   -- channel_reset ------------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   
   -- Inputs from QUAD reset module          
   SIGNAL chr_in_hard_reset                 : STD_LOGIC;        -- hardreset signal
   SIGNAL chr_in_soft_reset_all_hssi        : STD_LOGIC;        -- soft reset for all channel
   SIGNAL chr_in_rreset                     : STD_LOGIC;        -- Quad reset CRAM
   SIGNAL chr_in_rpowerdown                 : STD_LOGIC;        -- Quad power down CRAM
   
   -- Channel Reset inputs
   SIGNAL chr_in_rxurstpma                  : STD_LOGIC_VECTOR(5 DOWNTO 0);        -- RX PMA user reset - all ch
   SIGNAL chr_in_rxurstpcs                  : STD_LOGIC_VECTOR(3 DOWNTO 0);        -- RX PCS user reset
   SIGNAL chr_in_txurstpcs                  : STD_LOGIC_VECTOR(3 DOWNTO 0);        -- TX PCS user reset
   
   -- Channel Reset CRAMs
   SIGNAL chr_in_rpowdnr                    : STD_LOGIC;        -- RX channel power down CRAM
   SIGNAL chr_in_rpowdnt                    : STD_LOGIC;        -- TX channel power down CRAM
   SIGNAL chr_in_rrxurstpcs                 : STD_LOGIC;        -- Gating CRAM for RXURSTPCS
   SIGNAL chr_in_rtxurstpcs                 : STD_LOGIC;        -- Gating CRAM for TXURSTPCS
   SIGNAL chr_in_rrxurstpma                 : STD_LOGIC;        -- Gating CRAM for RXURSTPMA
   SIGNAL chr_in_rrx_cru_rst                : STD_LOGIC;        -- Channel RX PLL reset CRAMs
   SIGNAL chr_in_radce_rst                  : STD_LOGIC;        -- Channel Adaptive block reset CRAMs
   
   -- Powerdown inputs
   SIGNAL chr_in_urx_pdb                    : STD_LOGIC_VECTOR(5 DOWNTO 0);        -- RX user powerdown signal - all ch
   
   -- Powerdown CRAMs
   SIGNAL chr_in_rurx_pdb                   : STD_LOGIC;        -- Gating CRAM for urx_pdb signals
   SIGNAL chr_in_radce_pdb                  : STD_LOGIC;        -- Adaptive block powerdown CRAMs
   SIGNAL chr_in_rrx_ib_pdb                 : STD_LOGIC;        -- RX Input buffer and PLL powerdown CRAMs
   SIGNAL chr_in_rtx_ob_pdb                 : STD_LOGIC;        -- TX Output buffer powerdown CRAMs
   SIGNAL chr_in_rtx_cgb_pdb                : STD_LOGIC;        -- TX clock generator powerdown CRAMs
   SIGNAL chr_in_rrx_cru_pdb                : STD_LOGIC;        -- RX PLL powerdown CRAMs
   
   -- PIPE Inputs
   SIGNAL chr_in_rtx_pipe_en                : STD_LOGIC;        -- PIPE enable CRAMs
   SIGNAL chr_in_p0_state                   : STD_LOGIC;        -- PIPE P0 state indicators
   SIGNAL chr_in_p0s_state                  : STD_LOGIC;        -- PIPE P0S state indicators
   SIGNAL chr_in_p2_state                   : STD_LOGIC;        -- PIPE P2 state indicators
   
   -- Channel Reset outputs
   SIGNAL chr_out_rxpma_rstb                : STD_LOGIC_VECTOR(5 DOWNTO 0);        -- RX PMA resets (powerdown)
   SIGNAL chr_out_txpma_rstb                : STD_LOGIC_VECTOR(5 DOWNTO 0);        -- TX PMA resets (powerdown)
   SIGNAL chr_out_rxpcs_rst                 : STD_LOGIC_VECTOR(3 DOWNTO 0);        -- RX PCS resets - extra dummy for 4/5 
   SIGNAL chr_out_txpcs_rst                 : STD_LOGIC_VECTOR(3 DOWNTO 0);        -- TX PCS resets - extra dummy for 4/5
   SIGNAL chr_out_cru_rstb                  : STD_LOGIC_VECTOR(5 DOWNTO 0);        -- RX PLL resets
   SIGNAL chr_out_adce_rstb                 : STD_LOGIC_VECTOR(3 DOWNTO 0);        -- Adaptive block resets
   
   -- Channel Powerdown outputs
   SIGNAL chr_out_adce_pdb                  : STD_LOGIC_VECTOR(3 DOWNTO 0);        -- Adaptive block powerdown
   SIGNAL chr_out_cru_pdb                   : STD_LOGIC_VECTOR(5 DOWNTO 0);        -- RX PLL powerdown
   SIGNAL chr_out_rx_pdb                    : STD_LOGIC_VECTOR(5 DOWNTO 0);        -- RX powerdown
   SIGNAL chr_out_tx_pdb                    : STD_LOGIC_VECTOR(5 DOWNTO 0);        -- TX driver powerdown
   SIGNAL chr_out_cgb_pdb                   : STD_LOGIC_VECTOR(5 DOWNTO 0);        -- Clock generator powerdown
   SIGNAL chr_out_rx_det_pdb                : STD_LOGIC_VECTOR(5 DOWNTO 0);        -- Receiver detector powerdown
   
   --/////////////////////////////////////////////////////////////////////////
   -- centrl_clk_ctl ------------------------------------------------------ //
   --/////////////////////////////////////////////////////////////////////////
   
   -- S2GX style
   SIGNAL refclk_pma_out                    : STD_LOGIC;        -- output - Global TX PCS clock
   SIGNAL mdc_b                             : STD_LOGIC;        -- MD Clock
   -- refclk_out moved to clock_divider
   
   SIGNAL centrlclk_ctl_in_pclk_pma         : STD_LOGIC;        -- x4 PCLK from PMA CMU
   SIGNAL centrlclk_ctl_in_refclk_dig       : STD_LOGIC;        -- External digital clock
   SIGNAL centrlclk_ctl_in_mdc              : STD_LOGIC;        -- MDIO input clock
   SIGNAL centrlclk_ctl_in_ser_clk          : STD_LOGIC;        -- Serial clock
   SIGNAL centrlclk_ctl_in_ser_mode         : STD_LOGIC;        -- Serial shift configuration mode
   SIGNAL centrlclk_ctl_in_scan_mode        : STD_LOGIC;        -- Scan mode
   SIGNAL centrlclk_ctl_in_scan_clk         : STD_LOGIC;        -- Scan mode
   SIGNAL centrlclk_ctl_in_rfreerun_centrl  : STD_LOGIC;        -- REFCLK_OUT free running enable CRAM
   SIGNAL centrlclk_ctl_in_rcentrl_clk_sel  : STD_LOGIC;        -- REFCLK_PMA global clock selection CRAM
   SIGNAL centrlclk_ctl_in_rrefclk_out_div2 : STD_LOGIC;        -- REFCLK_OUT divide by 2 enable CRAM
   SIGNAL centrlclk_ctl_in_hard_reset       : STD_LOGIC;        -- Hard reset input
   SIGNAL centrlclk_ctl_in_txrst            : STD_LOGIC;
   
   SIGNAL centrlclk_ctl_in_gen2ngen1_bundle : STD_LOGIC;
   
   SIGNAL centrlclk_ctl_out_refclk_pma_out  : STD_LOGIC;        -- Global TX PCS clock
   SIGNAL centrlclk_ctl_out_mdc_b           : STD_LOGIC;        -- Configuration output clock
   SIGNAL centrlclk_ctl_out_refclk_out      : STD_LOGIC;        -- REFCLK_OUT output clk
   
   --/////////////////////////////////////////////////////////////////////////
   -- rxclk_ctl_ctrl ------------------------------------------------------ //
   --/////////////////////////////////////////////////////////////////////////
   
   -- S2GX portion ----------------------------------------------------------
   SIGNAL clk_1_b                           : STD_LOGIC;        -- output - feeding to Deskew SM only
   SIGNAL clk_2_b                           : STD_LOGIC;        -- output - to RCV_SM, centrl_reset
   
   SIGNAL rxclk_ctl_in_pld_rx_clk           : STD_LOGIC;
   SIGNAL rxclk_ctl_in_rcvd_clk0_pma        : STD_LOGIC;
   SIGNAL rxclk_ctl_in_refclk_pma           : STD_LOGIC;
   SIGNAL rxclk_ctl_in_scan_mode            : STD_LOGIC;
   SIGNAL rxclk_ctl_in_gen2ngen1_bundle     : STD_LOGIC;
   SIGNAL rxclk_ctl_in_rx_div2_sync_centrl  : STD_LOGIC;
   SIGNAL rxclk_ctl_in_rrcvd_clk_sel        : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rxclk_ctl_in_rclk_1_sel           : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rxclk_ctl_in_rclk_2_sel           : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rxclk_ctl_in_rrx_rd_clk_sel       : STD_LOGIC;
   SIGNAL rxclk_ctl_in_rxrst                : STD_LOGIC;
   SIGNAL rxclk_ctl_in_rindv_rx             : STD_LOGIC;
   SIGNAL rxclk_ctl_in_rdwidth_rx           : STD_LOGIC;
   SIGNAL rxclk_ctl_in_rfreerun_rx          : STD_LOGIC;
   SIGNAL rxclk_ctl_in_rauto_speed_ena      : STD_LOGIC;
   SIGNAL rxclk_ctl_in_rfreq_sel            : STD_LOGIC;
   SIGNAL rxclk_ctl_in_rrxpcsclkpwdn        : STD_LOGIC;
   SIGNAL rxclk_ctl_in_rmaster_rx           : STD_LOGIC;
   SIGNAL rxclk_ctl_in_rmaster_up_rx        : STD_LOGIC;
   
   SIGNAL rxclk_ctl_out_clk_1_b             : STD_LOGIC;
   SIGNAL rxclk_ctl_out_clk_2_b             : STD_LOGIC;
   SIGNAL rxclk_ctl_out_rx_wr_clk           : STD_LOGIC;
   SIGNAL rxclk_ctl_out_rx_rd_clk           : STD_LOGIC;
   SIGNAL rxclk_ctl_out_rx_div2_sync_out    : STD_LOGIC;
   
   --unused outputs - connected for VHDL convertions and non-x (no single dummy)
   SIGNAL rxclk_ctl_out_fref_muxed          : STD_LOGIC;
   SIGNAL rxclk_ctl_out_clklow_muxed        : STD_LOGIC;
   SIGNAL rxclk_ctl_out_rcvd_clk            : STD_LOGIC;
   SIGNAL rxclk_ctl_out_rx_clk              : STD_LOGIC;
   SIGNAL rxclk_ctl_out_rcvd_clk_pma_b      : STD_LOGIC;
   SIGNAL rxclk_ctl_out_clk_2_b_raw         : STD_LOGIC;
   SIGNAL rxclk_ctl_out_rx_wr_clk_raw       : STD_LOGIC;
   SIGNAL rxclk_ctl_out_rx_rd_clk_raw       : STD_LOGIC;
   
   --/////////////////////////////////////////////////////////////////////////
   -- txclk_ctl_ctrl ------------------------------------------------------ //
   --/////////////////////////////////////////////////////////////////////////
   
   -- s2gx portion 
   SIGNAL refclk_b                          : STD_LOGIC;        -- output to centrl_reset and TX_SM
   
   -- STRATIXIV for bundling
   SIGNAL txclk_ctl_in_pld_tx_clk           : STD_LOGIC;
   SIGNAL txclk_ctl_in_refclk_pma           : STD_LOGIC;
   SIGNAL txclk_ctl_in_txrst                : STD_LOGIC;
   SIGNAL txclk_ctl_in_scan_mode            : STD_LOGIC;
   SIGNAL txclk_ctl_in_gen2ngen1_bundle     : STD_LOGIC;
   SIGNAL txclk_ctl_in_tx_div2_sync_centrl  : STD_LOGIC;
   
   SIGNAL txclk_ctl_out_refclk_b            : STD_LOGIC;
   SIGNAL txclk_ctl_out_wr_clk_pos          : STD_LOGIC;
   SIGNAL txclk_ctl_out_fifo_rd_clk         : STD_LOGIC;
   SIGNAL txclk_ctl_out_tx_div2_sync_out    : STD_LOGIC;
   
   --unused outputs - connected for VHDL convertions and non-x (no single dummy)
   SIGNAL txclk_ctl_out_tx_clk_out          : STD_LOGIC;
   SIGNAL txclk_ctl_out_refclk_b_raw        : STD_LOGIC;
   SIGNAL txclk_ctl_out_wr_clk_pos_raw      : STD_LOGIC;
   SIGNAL txclk_ctl_out_fifo_rd_clk_raw     : STD_LOGIC;
   
   --/////////////////////////////////////////////////////////////////////////
   -- centrl_reset -------------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   SIGNAL rxrst_int                         : STD_LOGIC;        -- to DSKW,RCV_SM, div2 on rxclk_sel (ignore)
   SIGNAL txrst_int                         : STD_LOGIC;
   
   SIGNAL txrst_sync1                       : STD_LOGIC := '0';
   SIGNAL txrst_sync2                       : STD_LOGIC := '0';
   SIGNAL rxrst_sync1                       : STD_LOGIC := '0';
   SIGNAL rxrst_sync2                       : STD_LOGIC := '0';
   
   --/////////////////////////////////////////////////////////////////////////
   -- auto_speed_neg ------------------------------------------------------ //
   --/////////////////////////////////////////////////////////////////////////
   SIGNAL auto_in_refclk                    : STD_LOGIC;
   SIGNAL auto_in_rxpcs_rst_int             : STD_LOGIC;
   SIGNAL auto_in_rate                      : STD_LOGIC;        -- high gen2 and low gen1 
   SIGNAL auto_in_gen2ngen1                 : STD_LOGIC;
   SIGNAL auto_in_config_sel_centrl         : STD_LOGIC;
   SIGNAL auto_in_config_sel_quad_up        : STD_LOGIC;
   SIGNAL auto_in_config_sel_quad_down      : STD_LOGIC;
   SIGNAL auto_in_singleorbundle            : STD_LOGIC;
   
   -- control signal output for bundle mode  high is gen2, low is gen1
   SIGNAL auto_out_config_sel               : STD_LOGIC;
   -- PMA rate change control
   SIGNAL auto_out_pcie_switch              : STD_LOGIC;
   -- RX Phase Comp
   -- Handshake signal to PIPE interface to assert PhyStatus
   SIGNAL auto_out_speed_change             : STD_LOGIC;
   -- Phase Comp and byte ser/deser control signals
   SIGNAL auto_out_dis_pc_byte              : STD_LOGIC;
   SIGNAL auto_out_reset_pc_ptrs            : STD_LOGIC;
   SIGNAL auto_out_cs                       : STD_LOGIC_VECTOR(3 DOWNTO 0);
   
   --/////////////////////////////////////////////////////////////////////////
   -- rx_ctl_ctrl --------------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   SIGNAL rxctrl_in_soft_reset              : STD_LOGIC;
   SIGNAL rxctrl_in_clk_2                   : STD_LOGIC;
   SIGNAL rxctrl_in_rx_rd_clk               : STD_LOGIC;        -- This replaces PLD_RX_CLK
   SIGNAL rxctrl_in_rx_wr_clk               : STD_LOGIC;        -- divided by 1 or 2 write clockwire rxctrl_in_
   SIGNAL rxctrl_in_scan_mode               : STD_LOGIC;        -- scan enable
   SIGNAL rxctrl_in_rxfifo_urst             : STD_LOGIC;        -- User reset exclusive to rx_ctrl & below
   SIGNAL rxctrl_in_pld_wr_dis              : STD_LOGIC;        -- PLD write disable
   SIGNAL rxctrl_in_pld_re                  : STD_LOGIC;        -- PLD read eanble
   SIGNAL rxctrl_in_dis_pc_byte             : STD_LOGIC;
   
   SIGNAL rxctrl_out_rx_we_out              : STD_LOGIC;
   SIGNAL rxctrl_out_wr_enable_out          : STD_LOGIC;
   SIGNAL rxctrl_out_rd_enable_out          : STD_LOGIC;
   
   --/////////////////////////////////////////////////////////////////////////
   -- tx_ctl_ctrl --------------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   SIGNAL txctrl_in_soft_reset              : STD_LOGIC;        -- Reset
   SIGNAL txctrl_in_fifo_wr_clk             : STD_LOGIC;        -- Used to be wr_clk_pos
   SIGNAL txctrl_in_fifo_rd_clk             : STD_LOGIC;        -- Coming from txclk_xg_ctl 
   SIGNAL txctrl_in_refclk_b_in             : STD_LOGIC;        -- The local reference clock used by the internal
   SIGNAL txctrl_in_scan_mode               : STD_LOGIC;        -- scan enable
   SIGNAL txctrl_in_txfifo_urst             : STD_LOGIC;        -- user reset 
   SIGNAL txctrl_in_pld_we                  : STD_LOGIC;        -- PLD phase compwire txctrl_in_ fifo we, level active
   SIGNAL txctrl_in_pld_rd_dis              : STD_LOGIC;        -- PLD phase compwire txctrl_in_ fifo rd dis, edge active
   SIGNAL txctrl_in_dis_pc_byte             : STD_LOGIC;
   
   SIGNAL txctrl_out_wr_enable_out          : STD_LOGIC;        -- ch0 wr_enable1 output for X4/X8 mode
   SIGNAL txctrl_out_rd_enable_out          : STD_LOGIC;        -- ch0 rd_enable1 output for X4/X8 mode
   SIGNAL txctrl_out_fifo_select_out        : STD_LOGIC;        -- New output for Revwire txctrl_in_B 
   
   --/////////////////////////////////////////////////////////////////////////
   -- DSKW SM ------------------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   
   SIGNAL dskw_curr_st                      : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL alignstatus_int                   : STD_LOGIC;        -- feeding to PLD and DPRIO
   
   SIGNAL dskw_sm_clk                       : STD_LOGIC;
   
   --/////////////////////////////////////////////////////////////////////////
   -- TX SM --------------------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   
   SIGNAL rtx_rx_local_fault_clr_int        : STD_LOGIC;        -- from DPRIO
   SIGNAL rindv_tx_int                      : STD_LOGIC;
   
   SIGNAL tx_curr_st                        : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL tx_local_fault_det                : STD_LOGIC;        -- output to rx_sm
   SIGNAL tx_local_fault_int                : STD_LOGIC;        -- feeding nowhere
   
   SIGNAL tx_sm_clk                         : STD_LOGIC;
   SIGNAL tx_sm_datain                      : STD_LOGIC_VECTOR(31 DOWNTO 0);
   SIGNAL tx_sm_ctrlin                      : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL tx_sm_rdenablesyncin              : STD_LOGIC;
   
   --/////////////////////////////////////////////////////////////////////////
   -- RX SM --------------------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   
   SIGNAL rindv_rx_int                      : STD_LOGIC;        -- from DPRIO
   SIGNAL rxs_link_status_set_int           : STD_LOGIC;        -- from DPRIO
   SIGNAL xs_link_status_int                : STD_LOGIC;
   
   SIGNAL rx_local_fault_int                : STD_LOGIC;        -- feeding DPRIO
   SIGNAL xlink_status_int                  : STD_LOGIC;        -- feeding DPRIO
   SIGNAL rcv_curr_st                       : STD_LOGIC_VECTOR(1 DOWNTO 0);
   
   SIGNAL rcv_sm_clk                        : STD_LOGIC;
   SIGNAL rcv_sm_decdatavalid               : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rcv_sm_decdata                    : STD_LOGIC_VECTOR(31 DOWNTO 0);
   SIGNAL rcv_sm_decctl                     : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rcv_sm_rxrunningdisp              : STD_LOGIC_VECTOR(3 DOWNTO 0);
   
   --/////////////////////////////////////////////////////////////////////////
   -- DPRIO --------------------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   
   SIGNAL port_addr                         : STD_LOGIC_VECTOR(4 DOWNTO 0);        -- convert from top parameter
   SIGNAL dev_addr                          : STD_LOGIC_VECTOR(4 DOWNTO 0);        -- convert from top parameter
   SIGNAL mdio_rst                          : STD_LOGIC;
   SIGNAL cmudprioin                        : STD_LOGIC_VECTOR(29 DOWNTO 0);        --local wrt cmu todo: rem
   SIGNAL cmudprioout                       : STD_LOGIC_VECTOR(29 DOWNTO 0);        --local wrt cmu todo: rem
   SIGNAL mdio_curr_st                      : STD_LOGIC_VECTOR(2 DOWNTO 0);
   SIGNAL mdio_in                           : STD_LOGIC;
   
   SIGNAL mdio_rst_reg                      : STD_LOGIC;
   -- X-HDL generated signals

   SIGNAL xhdl13 : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL xhdl14 : STD_LOGIC_VECTOR(7 DOWNTO 0);
   SIGNAL xhdl15 : STD_LOGIC_VECTOR(7 DOWNTO 0);
   
   -- Declare intermediate signals for referenced outputs
   SIGNAL cmudividerdprioout_xhdl0          : STD_LOGIC_VECTOR(599 DOWNTO 0);
   SIGNAL cmuplldprioout_xhdl1              : STD_LOGIC_VECTOR(1799 DOWNTO 0);
   SIGNAL enabledeskew_xhdl2                : STD_LOGIC;
   SIGNAL fiforesetrd_xhdl3                 : STD_LOGIC;
   SIGNAL refclkdividerdprioout_xhdl4       : STD_LOGIC_VECTOR(1 DOWNTO 0);
   SIGNAL rxctrlout_xhdl5                   : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL rxdataout_xhdl6                   : STD_LOGIC_VECTOR(31 DOWNTO 0);
   SIGNAL rxpcsdprioout_xhdl7               : STD_LOGIC_VECTOR(1599 DOWNTO 0);
   SIGNAL rxpmadprioout_xhdl8               : STD_LOGIC_VECTOR(1799 DOWNTO 0);
   SIGNAL txctrlout_xhdl9                   : STD_LOGIC_VECTOR(3 DOWNTO 0);
   SIGNAL txdataout_xhdl10                  : STD_LOGIC_VECTOR(31 DOWNTO 0);
   SIGNAL txpcsdprioout_xhdl11              : STD_LOGIC_VECTOR(599 DOWNTO 0);
   SIGNAL txpmadprioout_xhdl12              : STD_LOGIC_VECTOR(1799 DOWNTO 0);
BEGIN
          
      ------------------------
      --  Wire Delay Block --
      ------------------------
      WireDelay : BLOCK
      BEGIN
           VitalWireDelay (txphfiforddisable_ipd,txphfiforddisable, tipd_txphfiforddisable);
       bits_txctrl : FOR i in txctrl'RANGE GENERATE
           VitalWireDelay (txctrl_ipd(i),txctrl(i), tipd_txctrl(i));
       END GENERATE;
       bits_rxdatain : FOR i in rxdatain'RANGE GENERATE
           VitalWireDelay (rxdatain_ipd(i),rxdatain(i), tipd_rxdatain(i));
       END GENERATE;
           VitalWireDelay (txclk_ipd,txclk, tipd_txclk);
       bits_syncstatus : FOR i in syncstatus'RANGE GENERATE
           VitalWireDelay (syncstatus_ipd(i),syncstatus(i), tipd_syncstatus(i));
       END GENERATE;
       bits_rxpcsdprioin : FOR i in rxpcsdprioin'RANGE GENERATE
           VitalWireDelay (rxpcsdprioin_ipd(i),rxpcsdprioin(i), tipd_rxpcsdprioin(i));
       END GENERATE;
       bits_txdigitalreset : FOR i in txdigitalreset'RANGE GENERATE
           VitalWireDelay (txdigitalreset_ipd(i),txdigitalreset(i), tipd_txdigitalreset(i));
       END GENERATE;
       bits_txdatain : FOR i in txdatain'RANGE GENERATE
           VitalWireDelay (txdatain_ipd(i),txdatain(i), tipd_txdatain(i));
       END GENERATE;
           VitalWireDelay (scanclk_ipd,scanclk, tipd_scanclk);
           VitalWireDelay (rateswitchdonein_ipd,rateswitchdonein, tipd_rateswitchdonein);
           VitalWireDelay (rdenablesync_ipd,rdenablesync, tipd_rdenablesync);
           VitalWireDelay (dpclk_ipd,dpclk, tipd_dpclk);
           VitalWireDelay (rxphfiforeset_ipd,rxphfiforeset, tipd_rxphfiforeset);
       bits_testin : FOR i in testin'RANGE GENERATE
           VitalWireDelay (testin_ipd(i),testin(i), tipd_testin(i));
       END GENERATE;
       bits_rxrunningdisp : FOR i in rxrunningdisp'RANGE GENERATE
           VitalWireDelay (rxrunningdisp_ipd(i),rxrunningdisp(i), tipd_rxrunningdisp(i));
       END GENERATE;
       bits_txpllreset : FOR i in txpllreset'RANGE GENERATE
           VitalWireDelay (txpllreset_ipd(i),txpllreset(i), tipd_txpllreset(i));
       END GENERATE;
       bits_refclkdividerdprioin : FOR i in refclkdividerdprioin'RANGE GENERATE
           VitalWireDelay (refclkdividerdprioin_ipd(i),refclkdividerdprioin(i), tipd_refclkdividerdprioin(i));
       END GENERATE;
       bits_rxdatavalid : FOR i in rxdatavalid'RANGE GENERATE
           VitalWireDelay (rxdatavalid_ipd(i),rxdatavalid(i), tipd_rxdatavalid(i));
       END GENERATE;
       bits_txpcsdprioin : FOR i in txpcsdprioin'RANGE GENERATE
           VitalWireDelay (txpcsdprioin_ipd(i),txpcsdprioin(i), tipd_txpcsdprioin(i));
       END GENERATE;
           VitalWireDelay (dprioin_ipd,dprioin, tipd_dprioin);
           VitalWireDelay (rateswitch_ipd,rateswitch, tipd_rateswitch);
       bits_rxctrl : FOR i in rxctrl'RANGE GENERATE
           VitalWireDelay (rxctrl_ipd(i),rxctrl(i), tipd_rxctrl(i));
       END GENERATE;
       bits_rxanalogreset : FOR i in rxanalogreset'RANGE GENERATE
           VitalWireDelay (rxanalogreset_ipd(i),rxanalogreset(i), tipd_rxanalogreset(i));
       END GENERATE;
           VitalWireDelay (rxclk_ipd,rxclk, tipd_rxclk);
           VitalWireDelay (txphfifowrenable_ipd,txphfifowrenable, tipd_txphfifowrenable);
           VitalWireDelay (rxphfifowrdisable_ipd,rxphfifowrdisable, tipd_rxphfifowrdisable);
       bits_rdalign : FOR i in rdalign'RANGE GENERATE
           VitalWireDelay (rdalign_ipd(i),rdalign(i), tipd_rdalign(i));
       END GENERATE;
       bits_fixedclk : FOR i in fixedclk'RANGE GENERATE
           VitalWireDelay (fixedclk_ipd(i),fixedclk(i), tipd_fixedclk(i));
       END GENERATE;
           VitalWireDelay (dpriodisable_ipd,dpriodisable, tipd_dpriodisable);
           VitalWireDelay (rxphfifordenable_ipd,rxphfifordenable, tipd_rxphfifordenable);
           VitalWireDelay (scanmode_ipd,scanmode, tipd_scanmode);
       bits_cmuplldprioin : FOR i in cmuplldprioin'RANGE GENERATE
           VitalWireDelay (cmuplldprioin_ipd(i),cmuplldprioin(i), tipd_cmuplldprioin(i));
       END GENERATE;
       bits_rxpmadprioin : FOR i in rxpmadprioin'RANGE GENERATE
           VitalWireDelay (rxpmadprioin_ipd(i),rxpmadprioin(i), tipd_rxpmadprioin(i));
       END GENERATE;
       bits_rxdigitalreset : FOR i in rxdigitalreset'RANGE GENERATE
           VitalWireDelay (rxdigitalreset_ipd(i),rxdigitalreset(i), tipd_rxdigitalreset(i));
       END GENERATE;
       bits_adet : FOR i in adet'RANGE GENERATE
           VitalWireDelay (adet_ipd(i),adet(i), tipd_adet(i));
       END GENERATE;
           VitalWireDelay (txcoreclk_ipd,txcoreclk, tipd_txcoreclk);
           VitalWireDelay (txphfiforeset_ipd,txphfiforeset, tipd_txphfiforeset);
       bits_cmudividerdprioin : FOR i in cmudividerdprioin'RANGE GENERATE
           VitalWireDelay (cmudividerdprioin_ipd(i),cmudividerdprioin(i), tipd_cmudividerdprioin(i));
       END GENERATE;
           VitalWireDelay (rxcoreclk_ipd,rxcoreclk, tipd_rxcoreclk);
           VitalWireDelay (dprioload_ipd,dprioload, tipd_dprioload);
       bits_scanin : FOR i in scanin'RANGE GENERATE
           VitalWireDelay (scanin_ipd(i),scanin(i), tipd_scanin(i));
       END GENERATE;
           VitalWireDelay (quadreset_ipd,quadreset, tipd_quadreset);
           VitalWireDelay (nonuserfromcal_ipd,nonuserfromcal, tipd_nonuserfromcal);
           VitalWireDelay (scanshift_ipd,scanshift, tipd_scanshift);
       bits_txpmadprioin : FOR i in txpmadprioin'RANGE GENERATE
           VitalWireDelay (txpmadprioin_ipd(i),txpmadprioin(i), tipd_txpmadprioin(i));
       END GENERATE;
       bits_rxpowerdown : FOR i in rxpowerdown'RANGE GENERATE
           VitalWireDelay (rxpowerdown_ipd(i),rxpowerdown(i), tipd_rxpowerdown(i));
       END GENERATE;
           VitalWireDelay (recovclk_ipd,recovclk, tipd_recovclk);
      END BLOCK;
          
      ------------------------
      --  Functionality Section --
      ------------------------
   -- Drive referenced outputs
   cmudividerdprioout <= cmudividerdprioout_xhdl0;
   cmuplldprioout <= cmuplldprioout_xhdl1;
   enabledeskew <= enabledeskew_xhdl2;
   fiforesetrd <= fiforesetrd_xhdl3;
   refclkdividerdprioout <= refclkdividerdprioout_xhdl4;
   rxctrlout <= rxctrlout_xhdl5;
   rxdataout <= rxdataout_xhdl6;
   rxpcsdprioout <= rxpcsdprioout_xhdl7;
   rxpmadprioout <= rxpmadprioout_xhdl8;
   txctrlout <= txctrlout_xhdl9;
   txdataout <= txdataout_xhdl10;
   txpcsdprioout <= txpcsdprioout_xhdl11;
   txpmadprioout <= txpmadprioout_xhdl12;
   
   --///////////////////////////////////////////////////////////////////////////
   -- Const wires ------------------------------------------------------------//
   --///////////////////////////////////////////////////////////////////////////
   vcc_wire <= '1';
   gnd_wire <= '0';
  
   -- VITAL Timing

    VITAL : PROCESS(dpclk_in, dprioin_in, dprioout_tim, dpriooe_tim)
    variable Tviol_dprioin_dpclk : std_ulogic := '0';
    variable TimingData_dprioin_dpclk : VitalTimingDataType := VitalTimingDataInit;
    variable dprioout_VitalGlitchData: VitalGlitchDataType;
    variable dpriooe_VitalGlitchData: VitalGlitchDataType;

   BEGIN

       -----------------------
       -- Timing Check Section
       -----------------------

       if (TimingChecksOn) then

               VitalSetupHoldCheck (
                       Violation       => Tviol_dprioin_dpclk,
                       TimingData      => TimingData_dprioin_dpclk,
                       TestSignal      => dprioin_in,
                       TestSignalName  => "DPRIOIN",
                       RefSignal       => dpclk_in,
                       RefSignalName   => "DPCLK",
                       SetUpHigh       => tsetup_dprioin_dpclk_noedge_posedge,
                       SetUpLow        => tsetup_dprioin_dpclk_noedge_posedge,
                       HoldHigh        => thold_dprioin_dpclk_noedge_posedge,
                       HoldLow         => thold_dprioin_dpclk_noedge_posedge,
                       RefTransition   => '/',
                       HeaderMsg       => InstancePath & "/STRATIXIV_HSSI_CMU",
                       XOn             => XOnChecks,
                       MsgOn           => MsgOnChecks );
       end if;

       ---------------------
       -- Path Delay Section
       ---------------------

       VitalPathDelay01 (
           OutSignal => dprioout,
           OutSignalName => "DPRIOOUT",
           OutTemp => dprioout_tim,
           Paths => (1 => (dpclk_in'last_event, tpd_dpclk_dprioout_posedge, TRUE)),
           GlitchData => dprioout_VitalGlitchData,
           Mode => DefGlitchMode,
           XOn => XOn,
           MsgOn => MsgOn );

       VitalPathDelay01 (
           OutSignal => dpriooe,
           OutSignalName => "DPRIOOE",
           OutTemp => dpriooe_tim,
           Paths => (1 => (dpclk_in'last_event, tpd_dpclk_dpriooe_posedge, TRUE)),
           GlitchData => dpriooe_VitalGlitchData,
           Mode => DefGlitchMode,
           XOn => XOn, 
           MsgOn => MsgOn );

   END PROCESS;
 
   --///////////////////////////////////////////////////////////////////////////
   -- process param ----------------------------------------------------------//
   --///////////////////////////////////////////////////////////////////////////
   PROCESS 
   BEGIN
      init_rauto_deassert_pc_rst_cnt <= int2bin(auto_spd_deassert_ph_fifo_rst_count, 4);
      init_rauto_pc_en_cnt <= int2bin(auto_spd_phystatus_notify_count, 5);
      init_rauto_speed_ena <= mux_select((pipe_auto_speed_nego_enable = ("true")), '1', '0');
      
      init_rclk_1_sel <= mux_select((rx0_clk1_mux_select = ("recvd_clk") OR rx0_clk1_mux_select = ("recovered clock")), "00", mux_select((rx0_clk1_mux_select = ("digital_refclk") OR rx0_clk1_mux_select = ("digital reference clock")), "01", mux_select((rx0_clk1_mux_select = ("local_refclk") OR rx0_clk1_mux_select = ("local reference clock")), "10", mux_select((rx0_clk1_mux_select = ("master_clk") OR rx0_clk1_mux_select = ("master clk") OR rx0_clk1_mux_select = ("master clock")), "11", "ZZ"))));
      init_rclk_2_sel <= mux_select((rx0_clk2_mux_select = ("recvd_clk") OR rx0_clk2_mux_select = ("recovered clock")), "00", mux_select((rx0_clk2_mux_select = ("digital_refclk") OR rx0_clk2_mux_select = ("digital reference clock")), "10", mux_select((rx0_clk2_mux_select = ("local_refclk") OR rx0_clk2_mux_select = ("local reference clock")), "01", mux_select((rx0_clk2_mux_select = ("core_clk") OR rx0_clk2_mux_select = ("core clk") OR rx0_clk2_mux_select = ("core clock")), "11", "ZZ"))));
      init_rdwidth_rx <= mux_select((rx0_use_double_data_mode = ("true")), '1', '0');
      init_rdwidth_tx <= mux_select((tx0_use_double_data_mode = ("true")), '1', '0');
      init_rfreerun_rx <= mux_select((rx0_reset_clock_output_during_digital_reset = ("false")), '1', '0');
      init_rfreerun_tx <= mux_select((tx0_reset_clock_output_during_digital_reset = ("false")), '1', '0');        -- "Data width"
      init_rfreq_sel <= mux_select((alpha_tolower(pipe_freq_scale_mode) = ("data width")), '0', '1');
      init_rindv_rx <= mux_select((rx0_channel_bonding = ("x4") OR rx0_channel_bonding = ("x8") OR in_xaui_mode = ("true")), '0', '1');
      init_rindv_tx <= mux_select((tx0_channel_bonding = ("x4") OR tx0_channel_bonding = ("x8") OR in_xaui_mode = ("true")), '0', '1');
      init_rmaster_rx <= mux_select((rx_master_direction = ("none")), '1', '0');
      init_rmaster_tx <= mux_select((tx_master_direction = ("none")), '1', '0');
      init_rmaster_up_rx <= mux_select((rx_master_direction = ("up")), '1', '0');
      init_rmaster_up_tx <= mux_select((tx_master_direction = ("up")), '1', '0');
      init_rphfifo_regmode_rx <= mux_select((rx0_ph_fifo_reg_mode = ("true")), '1', '0');
      init_rpma_done_count <= "000000000000001111"; -- int2bin(pma_done_count, 18);
      init_rrcvd_clk_sel <= mux_select((rx0_recovered_clk_mux_select = ("recvd_clk") OR rx0_recovered_clk_mux_select = ("recovered clock")), "00", mux_select((rx0_recovered_clk_mux_select = ("digital_refclk") OR rx0_recovered_clk_mux_select = ("digital reference clock")), "01", mux_select((rx0_recovered_clk_mux_select = ("local_refclk") OR rx0_recovered_clk_mux_select = ("local reference clock")), "10", "ZZ")));
      init_rrx_rd_clk_sel <= mux_select((rx0_rd_clk_mux_select = ("core_clk") OR rx0_rd_clk_mux_select = ("core clk") OR rx0_rd_clk_mux_select = ("core clock")), '1', '0');
      init_rrxfifo_urst_en <= mux_select((rx0_ph_fifo_reset_enable = ("true")), '1', '0');
      init_rrxpcsclkpwdn <= mux_select((rx0_clk_pd_enable = ("true")), '1', '0');
      init_rrxphfifopldctl_en <= mux_select((rx0_ph_fifo_user_ctrl_enable = ("true")), '1', '0');
      init_rself_sw_en_rx <= mux_select((rx0_auto_spd_self_switch_enable = ("true")), '1', '0');
      init_rself_sw_en_tx <= mux_select((tx0_auto_spd_self_switch_enable = ("true")), '1', '0');
      init_rtxpcsclkpwdn <= mux_select((tx0_clk_pd_enable = ("true")), '1', '0');
      init_rtxphfifopldctl_en <= mux_select((tx0_ph_fifo_user_ctrl_enable = ("true")), '1', '0');        -- TxFifo Rd clock 1=refclk_pma, 0=local_refclk_pma
      init_rtxrdclksel <= mux_select((tx0_rd_clk_mux_select = ("cmu_clock_divider") OR tx0_rd_clk_mux_select = ("cmu clock divider")), '1', '0');
      init_rtxwrclksel <= mux_select((tx0_wr_clk_mux_select = ("int_clk") OR tx0_wr_clk_mux_select = ("int clk") OR tx0_wr_clk_mux_select = ("internal clock")), '1', '0');        -- TxFifo Write clk. 1=int_clk; 0=pld_tx_clk
      
      -- cram used in centrl_clk_ctl but not in WYS
      init_scan_mode <= '0';        -- REFCLK_OUT free running enable CRAM
      init_rfreerun_centrl <= init_rfreerun_rx;        --1 - select digi_ref REFCLK_PMA global clock selection CRAM
      init_rcentrl_clk_sel <= '0';        -- REFCLK_OUT divide by 2 enable CRAM
      
      init_rrefclk_out_div2 <= '0';        -- used in txctrl
      
      IF (tx0_ph_fifo_reset_enable = "true") THEN
          init_rtxfifo_urst_en <= '1';
      ELSE
          init_rtxfifo_urst_en <= '0';
      END IF;
      
      -- ww12_RTL
      IF (rx_xaui_sm_backward_compatible_enable = "true") THEN
          init_rxaui_s2gx_en_rx  <= '1';
      ELSE
          init_rxaui_s2gx_en_rx  <= '0';
      END IF;
      
      IF (tx_xaui_sm_backward_compatible_enable = "true") THEN
          init_rxaui_s2gx_en_tx  <= '1';
      ELSE
          init_rxaui_s2gx_en_tx  <= '0';
      END IF;
      
      init_rwait_for_phfifo_cnt <= "100000"; -- todo
      
      WAIT;
   END PROCESS;
   
   --///////////////////////////////////////////////////////////////////////////
   -- CRAM -------------------------------------------------------------------//
   --///////////////////////////////////////////////////////////////////////////
   cram_rauto_deassert_pc_rst_cnt <= init_rauto_deassert_pc_rst_cnt;
   cram_rauto_pc_en_cnt           <= init_rauto_pc_en_cnt;
   cram_rauto_speed_ena <= init_rauto_speed_ena;
   cram_rclk_1_sel <= init_rclk_1_sel;
   cram_rclk_2_sel <= init_rclk_2_sel;
   cram_rdwidth_rx <= init_rdwidth_rx;
   cram_rdwidth_tx <= init_rdwidth_tx;
   cram_rfreerun_rx <= init_rfreerun_rx;
   cram_rfreerun_tx <= init_rfreerun_tx;
   cram_rfreq_sel <= init_rfreq_sel;
   cram_rindv_rx <= init_rindv_rx;
   cram_rindv_tx <= init_rindv_tx;
   cram_rmaster_rx <= init_rmaster_rx;
   cram_rmaster_tx <= init_rmaster_tx;
   cram_rmaster_up_rx <= init_rmaster_up_rx;
   cram_rmaster_up_tx <= init_rmaster_up_tx;
   cram_rphfifo_regmode_rx <= init_rphfifo_regmode_rx;
   cram_rpma_done_count <= init_rpma_done_count;
   cram_rrcvd_clk_sel <= init_rrcvd_clk_sel;
   cram_rrx_rd_clk_sel <= init_rrx_rd_clk_sel;
   cram_rrxfifo_urst_en <= init_rrxfifo_urst_en;
   cram_rrxpcsclkpwdn <= init_rrxpcsclkpwdn;
   cram_rrxphfifopldctl_en <= init_rrxphfifopldctl_en;
   cram_rself_sw_en_rx <= init_rself_sw_en_rx;
   cram_rself_sw_en_tx <= init_rself_sw_en_tx;
   cram_rtxpcsclkpwdn <= init_rtxpcsclkpwdn;
   cram_rtxphfifopldctl_en <= init_rtxphfifopldctl_en;
   cram_rtxrdclksel <= init_rtxrdclksel;
   cram_rtxwrclksel <= init_rtxwrclksel;
   cram_scan_mode <= init_scan_mode;
   
   -- cram used in centrl_clk_ctl but not in WYS
   cram_rfreerun_centrl <= init_rfreerun_centrl;
   cram_rcentrl_clk_sel <= init_rcentrl_clk_sel;
   cram_rrefclk_out_div2 <= init_rrefclk_out_div2;
   
   cram_rtxfifo_urst_en <= init_rtxfifo_urst_en;    -- used in txctrl

   -- ww12_RTL
   cram_rxaui_s2gx_en_rx  <= init_rxaui_s2gx_en_rx;
   cram_rxaui_s2gx_en_tx  <= init_rxaui_s2gx_en_tx;
   cram_rwait_for_phfifo_cnt <= init_rwait_for_phfifo_cnt;
   
   --///////////////////////////////////////////////////////////////////////////
   -- INPUT Filtering --------------------------------------------------------//
   --///////////////////////////////////////////////////////////////////////////
   
   dpclk_in <= '1' WHEN (dpclk = '1') ELSE
               '0';
   dpriodisable_in <= '0' WHEN (dpriodisable = '0') ELSE
                      '1';
   dprioin_in <= dprioin; 
   
   dprioload_in <= '1' WHEN (dprioload = '1') ELSE
                   '0';
   fixedclk_in(0) <= '1' WHEN (fixedclk(0) = '1') ELSE
                     '0';
   fixedclk_in(1) <= '1' WHEN (fixedclk(1) = '1') ELSE
                     '0';
   fixedclk_in(2) <= '1' WHEN (fixedclk(2) = '1') ELSE
                     '0';
   fixedclk_in(3) <= '1' WHEN (fixedclk(3) = '1') ELSE
                     '0';
   fixedclk_in(4) <= '1' WHEN (fixedclk(4) = '1') ELSE
                     '0';
   fixedclk_in(5) <= '1' WHEN (fixedclk(5) = '1') ELSE
                     '0';
   --assign quadenable_in        = (quadenable  === 1'b0)      ? 1'b0 : 1'b1;
   quadreset_in <= '1' WHEN (quadreset = '1') ELSE
                   '0';
   rxanalogreset_in(0) <= '1' WHEN (rxanalogreset(0) = '1') ELSE
                          '0';
   rxanalogreset_in(1) <= '1' WHEN (rxanalogreset(1) = '1') ELSE
                          '0';
   rxanalogreset_in(2) <= '1' WHEN (rxanalogreset(2) = '1') ELSE
                          '0';
   rxanalogreset_in(3) <= '1' WHEN (rxanalogreset(3) = '1') ELSE
                          '0';
   rxanalogreset_in(4) <= '1' WHEN (rxanalogreset(4) = '1') ELSE
                          '0';
   rxanalogreset_in(5) <= '1' WHEN (rxanalogreset(5) = '1') ELSE
                          '0';
   rxclk_in <= '1' WHEN (rxclk = '1') ELSE
               '0';
   rxdigitalreset_in(0) <= '1' WHEN (rxdigitalreset(0) = '1') ELSE
                           '0';
   rxdigitalreset_in(1) <= '1' WHEN (rxdigitalreset(1) = '1') ELSE
                           '0';
   rxdigitalreset_in(2) <= '1' WHEN (rxdigitalreset(2) = '1') ELSE
                           '0';
   rxdigitalreset_in(3) <= '1' WHEN (rxdigitalreset(3) = '1') ELSE
                           '0';
   rxpowerdown_in(0) <= '0' WHEN (rxpowerdown(0) = '1') ELSE        --inverted
                        '1';
   rxpowerdown_in(1) <= '0' WHEN (rxpowerdown(1) = '1') ELSE        --inverted
                        '1';
   rxpowerdown_in(2) <= '0' WHEN (rxpowerdown(2) = '1') ELSE        --inverted
                        '1';
   rxpowerdown_in(3) <= '0' WHEN (rxpowerdown(3) = '1') ELSE        --inverted
                        '1';
   rxpowerdown_in(4) <= '0' WHEN (rxpowerdown(4) = '1') ELSE        --inverted
                        '1';
   rxpowerdown_in(5) <= '0' WHEN (rxpowerdown(5) = '1') ELSE        --inverted
                        '1';
   txclk_in <= '1' WHEN (txclk = '1') ELSE
               '0';
   txdigitalreset_in(0) <= '1' WHEN (txdigitalreset(0) = '1') ELSE
                           '0';
   txdigitalreset_in(1) <= '1' WHEN (txdigitalreset(1) = '1') ELSE
                           '0';
   txdigitalreset_in(2) <= '1' WHEN (txdigitalreset(2) = '1') ELSE
                           '0';
   txdigitalreset_in(3) <= '1' WHEN (txdigitalreset(3) = '1') ELSE
                           '0';
   txpllreset_in(0) <= '1' WHEN (txpllreset(0) = '1') ELSE
                       '0';
   txpllreset_in(1) <= '1' WHEN (txpllreset(1) = '1') ELSE
                       '0';
   
   -- new one added in ww47
   rateswitch_in <= rateswitch;
   rateswitchdonein_in <= rateswitchdonein;
   rxcoreclk_in <= rxcoreclk;
   rxphfifordenable_in <= rxphfifordenable;
   rxphfiforeset_in <= rxphfiforeset;
   rxphfifowrdisable_in <= rxphfifowrdisable;
   scanclk_in <= '1' WHEN (scanclk = '1') ELSE
                 '0';
   scanin_in <= "00000000000000000000001" WHEN (scanin = "00000000000000000000001") ELSE
                "00000000000000000000000";
   scanmode_in <= '1' WHEN (scanmode = '1') ELSE
                  '0';
   scanshift_in <= '1' WHEN (scanshift = '1') ELSE
                   '0';
   txcoreclk_in <= txcoreclk;
   txphfiforddisable_in <= txphfiforddisable;
   txphfiforeset_in <= txphfiforeset;
   txphfifowrenable_in <= txphfifowrenable;
   
   --///////////////////////////////////////////////////////////////////////////
   -- TIMING -- TCO/TSU/HOLD                                                  //
   --///////////////////////////////////////////////////////////////////////////
   
   dprioout <= dprioout_tim;
   dpriooe <= dpriooe_tim;
   
   --/////////////////////////////////////////////////////////////////////////
   -- quad_reset inst ----------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   
   qr_in_entest <= '0';        -- Test mode control from Control block
   qr_in_plniotri <= '1';        -- PLL output enable
   qr_in_npor <= '1';        -- Power on reset
   qr_in_frzreg <= '0';        -- Freeze register during power-up
   qr_in_pllurst <= '1' WHEN (quadreset_in = '1') ELSE        -- PLL user reset
                    '0';
   
   -- enable corresponding port by default in simulation
   qr_cram_rpllurst <= '1';        -- Gating CRAM for PLLURST
   qr_cram_rpowerdown <= '0';        -- Quad power down CRAM
   qr_cram_rreset <= '0';        -- Quad reset CRAM - scan_mode ? 1'b0 : rreset;
   
   -- new in ww47 ----------------------------------------------------
   
   -- CMU0/1 reset - moved rx_pll, rx_pma and tx_pma resets to chnl reset [4:5] 
   -- but kept CMU_PLL (LC_PLL) resets in Quadreset 
   qr_in_rxurstcmu <= txpllreset_in;
   qr_in_ucmurx_pdb <= "00";
   
   -- CMU qr_cram_reset CRAMs
   qr_cram_rrxurstcmu <= "11";        -- Gating CRAM for dynamic signal rxurstcmu
   qr_cram_rrx_cmu_rst <= "00";        -- TXPLL / RXPLL reset
   
   -- CMU powerdown CRAMs
   qr_cram_rclk_pdb <= "00";        --generating cmu0/1_clk_pdb
   qr_cram_rcmu_powdnr <= "00";
   qr_cram_rcmu_cru_pdb <= "11";
   qr_cram_rcmu_urx_pdb <= "11";
   qr_cram_rcmu_rx_ib_pdb <= "11";
   qr_cram_rcmu_powdnt <= "00";
   qr_cram_rcmu_tx_ob_pdb <= "11";
   qr_cram_rcmu_tx_cgb_pdb <= "11";
   qr_cram_rcmu_rx_det_pdb <= "11";
   
   -- Moved cmu0/cmu1 reset/powerdown out to channel reset
   -- still controls cmu_pll/cmu_clk_divider and hardreset
   
   
   quad_reset_1 : stratixiv_hssi_cmu_quad_reset
      PORT MAP (
         entest               => qr_in_entest,
         plniotri             => qr_in_plniotri,
         npor                 => qr_in_npor,
         frzreg               => qr_in_frzreg,
         pllurst              => qr_in_pllurst,
         rpllurst             => qr_cram_rpllurst,
         rreset               => qr_cram_rreset,
         rpowerdown           => qr_cram_rpowerdown,
         
         -- CMU reset inputs
         rxurstcmu            => qr_in_rxurstcmu,
         -- CMU reset CRAMs
         rrxurstcmu           => qr_cram_rrxurstcmu,
         rrx_cmu_rst          => qr_cram_rrx_cmu_rst,
         -- CMU powerdown inputs
         ucmurx_pdb           => qr_in_ucmurx_pdb,
         -- CMU powerdown CRAMs
         rclk_pdb             => qr_cram_rclk_pdb,
         rcmu_powdnr          => qr_cram_rcmu_powdnr,
         rcmu_cru_pdb         => qr_cram_rcmu_cru_pdb,
         rcmu_urx_pdb         => qr_cram_rcmu_urx_pdb,
         rcmu_rx_ib_pdb       => qr_cram_rcmu_rx_ib_pdb,
         rcmu_powdnt          => qr_cram_rcmu_powdnt,
         rcmu_tx_ob_pdb       => qr_cram_rcmu_tx_ob_pdb,
         rcmu_tx_cgb_pdb      => qr_cram_rcmu_tx_cgb_pdb,
         rcmu_rx_det_pdb      => qr_cram_rcmu_rx_det_pdb,
         -- CMU reset outputs
         cmu0_rxpma_rstb      => qr_out_cmu0_rxpma_rstb,
         cmu0_txpma_rstb      => qr_out_cmu0_txpma_rstb,
         cmu0_cru_rstb        => qr_out_cmu0_cru_rstb,
         cmu1_rxpma_rstb      => qr_out_cmu1_rxpma_rstb,
         cmu1_txpma_rstb      => qr_out_cmu1_txpma_rstb,
         cmu1_cru_rstb        => qr_out_cmu1_cru_rstb,
         -- CMU powerdown outputs
         cmu0_rx_pdb          => qr_out_cmu0_rx_pdb,
         cmu0_cru_pdb         => qr_out_cmu0_cru_pdb,
         cmu0_clk_pdb         => qr_out_cmu0_clk_pdb,
         cmu0_tx_pdb          => qr_out_cmu0_tx_pdb,
         cmu0_cgb_pdb         => qr_out_cmu0_cgb_pdb,
         cmu0_rx_det_pdb      => qr_out_cmu0_rx_det_pdb,
         cmu1_rx_pdb          => qr_out_cmu1_rx_pdb,
         cmu1_cru_pdb         => qr_out_cmu1_cru_pdb,
         cmu1_clk_pdb         => qr_out_cmu1_clk_pdb,
         cmu1_tx_pdb          => qr_out_cmu1_tx_pdb,
         cmu1_cgb_pdb         => qr_out_cmu1_cgb_pdb,
         cmu1_rx_det_pdb      => qr_out_cmu1_rx_det_pdb,
         -- Other outputs
         mdio_rst             => qr_out_mdio_rst,
         hard_reset           => qr_out_hard_reset,
         soft_reset_all_hssi  => qr_out_soft_reset_all_hssi
      );
   
   --/////////////////////////////////////////////////////////////////////////
   -- chnl_reset inst ----------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   
   chr_in_hard_reset <= qr_out_hard_reset;        -- hardreset signal
   chr_in_soft_reset_all_hssi <= qr_out_soft_reset_all_hssi;        -- soft reset for all channel
   chr_in_rreset <= qr_cram_rreset;        -- Quad reset CRAM
   chr_in_rpowerdown <= qr_cram_rpowerdown;        -- Quad power down CRAM
   
   -- Channel Reset inputs
   chr_in_rxurstpma <= rxanalogreset_in;        -- RX PMA user reset
   chr_in_rxurstpcs <= rxdigitalreset_in;        -- RX PCS user reset
   chr_in_txurstpcs <= txdigitalreset_in;        -- TX PCS user reset
   
   -- Channel Reset CRAMs
   chr_in_rpowdnr <= '0';        -- RX channel power down CRAM
   chr_in_rpowdnt <= '0';        -- TX channel power down CRAM
   chr_in_rrxurstpcs <= '1';        -- Gating CRAM for RXURSTPCS
   chr_in_rtxurstpcs <= '1';        -- Gating CRAM for TXURSTPCS
   chr_in_rrxurstpma <= '1';        -- Gating CRAM for RXURSTPMA
   chr_in_rrx_cru_rst <= '0';        -- Channel RX PLL reset CRAMs
   chr_in_radce_rst <= '0';        -- Channel Adaptive block reset CRAMs
   
   -- Powerdown inputs
   chr_in_urx_pdb <= rxpowerdown_in;        -- RX user powerdown signal
   
   -- Powerdown CRAMs - active low
   chr_in_rurx_pdb <= '1';        -- Gating CRAM for urx_pdb signals
   chr_in_radce_pdb <= '1';        -- Adaptive block powerdown CRAMs
   chr_in_rrx_ib_pdb <= '1';        -- RX Input buffer and PLL powerdown CRAMs
   chr_in_rtx_ob_pdb <= '1';        -- TX Output buffer powerdown CRAMs
   chr_in_rtx_cgb_pdb <= '1';        -- TX clock generator powerdown CRAMs
   chr_in_rrx_cru_pdb <= '1';        -- RX PLL powerdown CRAMs
   
   -- PIPE Inputs
   chr_in_rtx_pipe_en <= '0';        -- PIPE enable CRAMs
   --todo: revisit - signal from tx_PIPE_INTERFACE_TOP
   chr_in_p0_state <= '0';        -- PIPE P0 state indicators
   chr_in_p0s_state <= '0';        -- PIPE P0S state indicators
   chr_in_p2_state <= '0';        -- PIPE P2 state indicators
   
   -- Channel-based reset logic (for both PCS and PMA channel)                          
   chnl_reset0 : stratixiv_hssi_cmu_chnl_reset
      PORT MAP (
         hard_reset           => chr_in_hard_reset,
         soft_reset_all_hssi  => chr_in_soft_reset_all_hssi,
         rreset               => chr_in_rreset,
         rpowerdown           => chr_in_rpowerdown,
         rxurstpma            => chr_in_rxurstpma(0),
         rxurstpcs            => chr_in_rxurstpcs(0),
         txurstpcs            => chr_in_txurstpcs(0),
         rpowdnr              => chr_in_rpowdnr,
         rpowdnt              => chr_in_rpowdnt,
         rrxurstpcs           => chr_in_rrxurstpcs,
         rtxurstpcs           => chr_in_rtxurstpcs,
         rrxurstpma           => chr_in_rrxurstpma,
         rrx_cru_rst          => chr_in_rrx_cru_rst,
         radce_rst            => chr_in_radce_rst,
         urx_pdb              => chr_in_urx_pdb(0),
         rurx_pdb             => chr_in_rurx_pdb,
         radce_pdb            => chr_in_radce_pdb,
         rrx_ib_pdb           => chr_in_rrx_ib_pdb,
         rtx_ob_pdb           => chr_in_rtx_ob_pdb,
         rtx_cgb_pdb          => chr_in_rtx_cgb_pdb,
         rrx_cru_pdb          => chr_in_rrx_cru_pdb,
         rtx_pipe_en          => chr_in_rtx_pipe_en,
         p0_state             => chr_in_p0_state,
         p0s_state            => chr_in_p0s_state,
         p2_state             => chr_in_p2_state,
         
         rxpma_rstb           => chr_out_rxpma_rstb(0),
         txpma_rstb           => chr_out_txpma_rstb(0),
         rxpcs_rst            => chr_out_rxpcs_rst(0),
         txpcs_rst            => chr_out_txpcs_rst(0),
         cru_rstb             => chr_out_cru_rstb(0),
         adce_rstb            => chr_out_adce_rstb(0),
         adce_pdb             => chr_out_adce_pdb(0),
         cru_pdb              => chr_out_cru_pdb(0),
         rx_pdb               => chr_out_rx_pdb(0),
         tx_pdb               => chr_out_tx_pdb(0),
         cgb_pdb              => chr_out_cgb_pdb(0),
         rx_det_pdb           => chr_out_rx_det_pdb(0)
      );
   
   chnl_reset1 : stratixiv_hssi_cmu_chnl_reset
      PORT MAP (
         hard_reset           => chr_in_hard_reset,
         soft_reset_all_hssi  => chr_in_soft_reset_all_hssi,
         rreset               => chr_in_rreset,
         rpowerdown           => chr_in_rpowerdown,
         rxurstpma            => chr_in_rxurstpma(1),
         rxurstpcs            => chr_in_rxurstpcs(1),
         txurstpcs            => chr_in_txurstpcs(1),
         rpowdnr              => chr_in_rpowdnr,
         rpowdnt              => chr_in_rpowdnt,
         rrxurstpcs           => chr_in_rrxurstpcs,
         rtxurstpcs           => chr_in_rtxurstpcs,
         rrxurstpma           => chr_in_rrxurstpma,
         rrx_cru_rst          => chr_in_rrx_cru_rst,
         radce_rst            => chr_in_radce_rst,
         urx_pdb              => chr_in_urx_pdb(1),
         rurx_pdb             => chr_in_rurx_pdb,
         radce_pdb            => chr_in_radce_pdb,
         rrx_ib_pdb           => chr_in_rrx_ib_pdb,
         rtx_ob_pdb           => chr_in_rtx_ob_pdb,
         rtx_cgb_pdb          => chr_in_rtx_cgb_pdb,
         rrx_cru_pdb          => chr_in_rrx_cru_pdb,
         rtx_pipe_en          => chr_in_rtx_pipe_en,
         p0_state             => chr_in_p0_state,
         p0s_state            => chr_in_p0s_state,
         p2_state             => chr_in_p2_state,
         
         rxpma_rstb           => chr_out_rxpma_rstb(1),
         txpma_rstb           => chr_out_txpma_rstb(1),
         rxpcs_rst            => chr_out_rxpcs_rst(1),
         txpcs_rst            => chr_out_txpcs_rst(1),
         cru_rstb             => chr_out_cru_rstb(1),
         adce_rstb            => chr_out_adce_rstb(1),
         adce_pdb             => chr_out_adce_pdb(1),
         cru_pdb              => chr_out_cru_pdb(1),
         rx_pdb               => chr_out_rx_pdb(1),
         tx_pdb               => chr_out_tx_pdb(1),
         cgb_pdb              => chr_out_cgb_pdb(1),
         rx_det_pdb           => chr_out_rx_det_pdb(1)
      );
   
   chnl_reset2 : stratixiv_hssi_cmu_chnl_reset
      PORT MAP (
         hard_reset           => chr_in_hard_reset,
         soft_reset_all_hssi  => chr_in_soft_reset_all_hssi,
         rreset               => chr_in_rreset,
         rpowerdown           => chr_in_rpowerdown,
         rxurstpma            => chr_in_rxurstpma(2),
         rxurstpcs            => chr_in_rxurstpcs(2),
         txurstpcs            => chr_in_txurstpcs(2),
         rpowdnr              => chr_in_rpowdnr,
         rpowdnt              => chr_in_rpowdnt,
         rrxurstpcs           => chr_in_rrxurstpcs,
         rtxurstpcs           => chr_in_rtxurstpcs,
         rrxurstpma           => chr_in_rrxurstpma,
         rrx_cru_rst          => chr_in_rrx_cru_rst,
         radce_rst            => chr_in_radce_rst,
         urx_pdb              => chr_in_urx_pdb(2),
         rurx_pdb             => chr_in_rurx_pdb,
         radce_pdb            => chr_in_radce_pdb,
         rrx_ib_pdb           => chr_in_rrx_ib_pdb,
         rtx_ob_pdb           => chr_in_rtx_ob_pdb,
         rtx_cgb_pdb          => chr_in_rtx_cgb_pdb,
         rrx_cru_pdb          => chr_in_rrx_cru_pdb,
         rtx_pipe_en          => chr_in_rtx_pipe_en,
         p0_state             => chr_in_p0_state,
         p0s_state            => chr_in_p0s_state,
         p2_state             => chr_in_p2_state,
         
         rxpma_rstb           => chr_out_rxpma_rstb(2),
         txpma_rstb           => chr_out_txpma_rstb(2),
         rxpcs_rst            => chr_out_rxpcs_rst(2),
         txpcs_rst            => chr_out_txpcs_rst(2),
         cru_rstb             => chr_out_cru_rstb(2),
         adce_rstb            => chr_out_adce_rstb(2),
         adce_pdb             => chr_out_adce_pdb(2),
         cru_pdb              => chr_out_cru_pdb(2),
         rx_pdb               => chr_out_rx_pdb(2),
         tx_pdb               => chr_out_tx_pdb(2),
         cgb_pdb              => chr_out_cgb_pdb(2),
         rx_det_pdb           => chr_out_rx_det_pdb(2)
      );
   
   chnl_reset3 : stratixiv_hssi_cmu_chnl_reset
      PORT MAP (
         hard_reset           => chr_in_hard_reset,
         soft_reset_all_hssi  => chr_in_soft_reset_all_hssi,
         rreset               => chr_in_rreset,
         rpowerdown           => chr_in_rpowerdown,
         rxurstpma            => chr_in_rxurstpma(3),
         rxurstpcs            => chr_in_rxurstpcs(3),
         txurstpcs            => chr_in_txurstpcs(3),
         rpowdnr              => chr_in_rpowdnr,
         rpowdnt              => chr_in_rpowdnt,
         rrxurstpcs           => chr_in_rrxurstpcs,
         rtxurstpcs           => chr_in_rtxurstpcs,
         rrxurstpma           => chr_in_rrxurstpma,
         rrx_cru_rst          => chr_in_rrx_cru_rst,
         radce_rst            => chr_in_radce_rst,
         urx_pdb              => chr_in_urx_pdb(3),
         rurx_pdb             => chr_in_rurx_pdb,
         radce_pdb            => chr_in_radce_pdb,
         rrx_ib_pdb           => chr_in_rrx_ib_pdb,
         rtx_ob_pdb           => chr_in_rtx_ob_pdb,
         rtx_cgb_pdb          => chr_in_rtx_cgb_pdb,
         rrx_cru_pdb          => chr_in_rrx_cru_pdb,
         rtx_pipe_en          => chr_in_rtx_pipe_en,
         p0_state             => chr_in_p0_state,
         p0s_state            => chr_in_p0s_state,
         p2_state             => chr_in_p2_state,
         
         rxpma_rstb           => chr_out_rxpma_rstb(3),
         txpma_rstb           => chr_out_txpma_rstb(3),
         rxpcs_rst            => chr_out_rxpcs_rst(3),
         txpcs_rst            => chr_out_txpcs_rst(3),
         cru_rstb             => chr_out_cru_rstb(3),
         adce_rstb            => chr_out_adce_rstb(3),
         adce_pdb             => chr_out_adce_pdb(3),
         cru_pdb              => chr_out_cru_pdb(3),
         rx_pdb               => chr_out_rx_pdb(3),
         tx_pdb               => chr_out_tx_pdb(3),
         cgb_pdb              => chr_out_cgb_pdb(3),
         rx_det_pdb           => chr_out_rx_det_pdb(3)
      );
   
   -- channel 4
   
   cmu0_reset : stratixiv_hssi_cmu_chnl_reset
      PORT MAP (
         hard_reset           => chr_in_hard_reset,
         soft_reset_all_hssi  => chr_in_soft_reset_all_hssi,
         rreset               => chr_in_rreset,
         rpowerdown           => chr_in_rpowerdown,
         rxurstpma            => chr_in_rxurstpma(4),
         rxurstpcs            => gnd_wire,
         txurstpcs            => gnd_wire,
         rpowdnr              => chr_in_rpowdnr,
         rpowdnt              => chr_in_rpowdnt,
         rrxurstpcs           => chr_in_rrxurstpcs,
         rtxurstpcs           => chr_in_rtxurstpcs,
         rrxurstpma           => chr_in_rrxurstpma,
         rrx_cru_rst          => chr_in_rrx_cru_rst,
         radce_rst            => chr_in_radce_rst,
         urx_pdb              => chr_in_urx_pdb(4),
         rurx_pdb             => chr_in_rurx_pdb,
         radce_pdb            => chr_in_radce_pdb,
         rrx_ib_pdb           => chr_in_rrx_ib_pdb,
         rtx_ob_pdb           => chr_in_rtx_ob_pdb,
         rtx_cgb_pdb          => chr_in_rtx_cgb_pdb,
         rrx_cru_pdb          => chr_in_rrx_cru_pdb,
         rtx_pipe_en          => chr_in_rtx_pipe_en,
         p0_state             => chr_in_p0_state,
         p0s_state            => chr_in_p0s_state,
         p2_state             => chr_in_p2_state,
         
         rxpma_rstb           => chr_out_rxpma_rstb(4),
         txpma_rstb           => chr_out_txpma_rstb(4),
         rxpcs_rst            => dummy_wire,
         txpcs_rst            => dummy_wire,
         cru_rstb             => chr_out_cru_rstb(4),
         adce_rstb            => dummy_wire,
         adce_pdb             => dummy_wire,
         cru_pdb              => chr_out_cru_pdb(4),
         rx_pdb               => chr_out_rx_pdb(4),
         tx_pdb               => chr_out_tx_pdb(4),
         cgb_pdb              => chr_out_cgb_pdb(4),
         rx_det_pdb           => chr_out_rx_det_pdb(4)
      );
   -- channel 5
   
   cmu1_reset : stratixiv_hssi_cmu_chnl_reset
      PORT MAP (
         hard_reset           => chr_in_hard_reset,
         soft_reset_all_hssi  => chr_in_soft_reset_all_hssi,
         rreset               => chr_in_rreset,
         rpowerdown           => chr_in_rpowerdown,
         rxurstpma            => chr_in_rxurstpma(5),
         rxurstpcs            => gnd_wire,
         txurstpcs            => gnd_wire,
         rpowdnr              => chr_in_rpowdnr,
         rpowdnt              => chr_in_rpowdnt,
         rrxurstpcs           => chr_in_rrxurstpcs,
         rtxurstpcs           => chr_in_rtxurstpcs,
         rrxurstpma           => chr_in_rrxurstpma,
         rrx_cru_rst          => chr_in_rrx_cru_rst,
         radce_rst            => chr_in_radce_rst,
         urx_pdb              => chr_in_urx_pdb(5),
         rurx_pdb             => chr_in_rurx_pdb,
         radce_pdb            => chr_in_radce_pdb,
         rrx_ib_pdb           => chr_in_rrx_ib_pdb,
         rtx_ob_pdb           => chr_in_rtx_ob_pdb,
         rtx_cgb_pdb          => chr_in_rtx_cgb_pdb,
         rrx_cru_pdb          => chr_in_rrx_cru_pdb,
         rtx_pipe_en          => chr_in_rtx_pipe_en,
         p0_state             => chr_in_p0_state,
         p0s_state            => chr_in_p0s_state,
         p2_state             => chr_in_p2_state,
         
         rxpma_rstb           => chr_out_rxpma_rstb(5),
         txpma_rstb           => chr_out_txpma_rstb(5),
         rxpcs_rst            => dummy_wire,
         txpcs_rst            => dummy_wire,
         cru_rstb             => chr_out_cru_rstb(5),
         adce_rstb            => dummy_wire,
         adce_pdb             => dummy_wire,
         cru_pdb              => chr_out_cru_pdb(5),
         rx_pdb               => chr_out_rx_pdb(5),
         tx_pdb               => chr_out_tx_pdb(5),
         cgb_pdb              => chr_out_cgb_pdb(5),
         rx_det_pdb           => chr_out_rx_det_pdb(5)
      );
   
   --/////////////////////////////////////////////////////////////////////////
   -- centrl_clk_ctl ------------------------------------------------------ //
   --/////////////////////////////////////////////////////////////////////////
   
   refclk_pma_out <= centrlclk_ctl_out_refclk_pma_out;        -- txclk_in <= pclk/digitalrefclkout
   mdc_b <= centrlclk_ctl_out_mdc_b;        -- dpclk_in;
   
   -- refclk_out is moved to (cmu) clock_divider atom:
   -- it has /2 and gen2ngen1 bundle logic and rfreq_sel control
   
   centrlclk_ctl_in_pclk_pma <= txclk_in;        --todo: WYS to add x4 PCLK from PMA CMU
   centrlclk_ctl_in_refclk_dig <= txclk_in;        --todo: External digital clock - moved to cmu_clock_divider
   centrlclk_ctl_in_mdc <= dpclk_in;        -- MDIO input clock
   centrlclk_ctl_in_ser_clk <= '0';        -- Serial clock
   centrlclk_ctl_in_ser_mode <= '0';        -- Serial shift configuration mode
   centrlclk_ctl_in_scan_mode <= scanmode_in;        -- Scan mode
   centrlclk_ctl_in_scan_clk <= scanclk_in;        -- Scan mode
   centrlclk_ctl_in_hard_reset <= qr_out_hard_reset;        -- Hard reset input
   centrlclk_ctl_in_txrst <= txrst_int;
   
   centrlclk_ctl_in_gen2ngen1_bundle <= rateswitchdonein_in;
   
   mcmu_centrlclk_ctl : stratixiv_hssi_cmu_clk_ctl
      PORT MAP (
         pclk_pma          => centrlclk_ctl_in_pclk_pma,
         refclk_dig        => centrlclk_ctl_in_refclk_dig,
         mdc               => centrlclk_ctl_in_mdc,
         ser_clk           => centrlclk_ctl_in_ser_clk,
         ser_mode          => centrlclk_ctl_in_ser_mode,
         scan_mode         => centrlclk_ctl_in_scan_mode,
         scan_clk          => centrlclk_ctl_in_scan_clk,
         rfreerun_centrl   => cram_rfreerun_centrl,
         rcentrl_clk_sel   => cram_rcentrl_clk_sel,
         rrefclk_out_div2  => cram_rrefclk_out_div2,
         hard_reset        => centrlclk_ctl_in_hard_reset,
         txrst             => centrlclk_ctl_in_txrst,
         rauto_speed_ena   => cram_rauto_speed_ena,
         rfreq_sel         => cram_rfreq_sel,
         gen2ngen1_bundle  => centrlclk_ctl_in_gen2ngen1_bundle,
         
         refclk_pma_out    => centrlclk_ctl_out_refclk_pma_out,
         mdc_b             => centrlclk_ctl_out_mdc_b,
         refclk_out        => centrlclk_ctl_out_refclk_out
      );
   
   --/////////////////////////////////////////////////////////////////////////
   -- rxclk_ctl_ctrl inst ------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   
   -- for S2GX portion
   clk_1_b <= rxclk_ctl_out_clk_1_b;        --recovclk - from ch0 of recover_clk
   clk_2_b <= rxclk_ctl_out_clk_2_b;        --rxclk_in - masterclk in XAUI, not work for other x4
   
   -- for STRATIXIV bundling - 
   -- - copy rx_ch0 clocking select info here to generate FIFO_bundle_ptrs_centrl
   rxclk_ctl_in_pld_rx_clk <= rxcoreclk_in;
   rxclk_ctl_in_rcvd_clk0_pma <= recovclk;
   rxclk_ctl_in_refclk_pma <= centrlclk_ctl_out_refclk_pma_out;
   rxclk_ctl_in_scan_mode <= scanmode_in;
   rxclk_ctl_in_gen2ngen1_bundle <= rateswitchdonein_in;
   rxclk_ctl_in_rx_div2_sync_centrl <= rxclk_ctl_out_rx_div2_sync_out;
   rxclk_ctl_in_rxrst <= txrst_int;        -- from centrl_reset                 
   
   mcmu_rxclk_ctl : stratixiv_hssi_cmu_rxclk_ctl
      PORT MAP (
         pld_rx_clk              => rxclk_ctl_in_pld_rx_clk,
         rcvd_clk_pma            => gnd_wire,
         rcvd_clk0_pma           => rxclk_ctl_in_rcvd_clk0_pma,
         tx_pma_clk              => gnd_wire,
         refclk_pma              => rxclk_ctl_in_refclk_pma,
         fref                    => gnd_wire,
         clklow                  => gnd_wire,
         scan_mode               => rxclk_ctl_in_scan_mode,
         gen2ngen1               => rxclk_ctl_in_gen2ngen1_bundle,   -- ww35.2008 gnd_wire,
         gen2ngen1_bundle        => rxclk_ctl_in_gen2ngen1_bundle,
         rx_div2_sync_centrl     => rxclk_ctl_in_rx_div2_sync_centrl,
         rx_div2_sync_quad_up    => gnd_wire,
         rx_div2_sync_quad_down  => gnd_wire,
         rrcvd_clk_sel           => cram_rrcvd_clk_sel,
         rclk_1_sel              => cram_rclk_1_sel,
         rclk_2_sel              => cram_rclk_2_sel,
         rrx_rd_clk_sel          => cram_rrx_rd_clk_sel,
         
         rxrst                   => rxclk_ctl_in_rxrst,
         
         rindv_rx                => vcc_wire,   -- ww35.2008 cram_rindv_rx,
         rdwidth_rx              => cram_rdwidth_rx,
         rfreerun_rx             => cram_rfreerun_rx,
         rauto_speed_ena         => cram_rauto_speed_ena,
         rfreq_sel               => cram_rfreq_sel,
         rrxpcsclkpwdn           => gnd_wire,
         rmaster_rx              => vcc_wire,   -- ww35.2008 cram_rmaster_rx,
         rmaster_up_rx           => cram_rmaster_up_rx,
         rself_sw_en_rx          => gnd_wire,
         
         fref_muxed              => rxclk_ctl_out_fref_muxed,
         clklow_muxed            => rxclk_ctl_out_clklow_muxed,
         rcvd_clk                => rxclk_ctl_out_rcvd_clk,
         clk_1_b                 => rxclk_ctl_out_clk_1_b,
         clk_2_b                 => rxclk_ctl_out_clk_2_b,
         rx_wr_clk               => rxclk_ctl_out_rx_wr_clk,
         rx_rd_clk               => rxclk_ctl_out_rx_rd_clk,
         rx_clk                  => rxclk_ctl_out_rx_clk,
         rcvd_clk_pma_b          => rxclk_ctl_out_rcvd_clk_pma_b,
         clk_2_b_raw             => rxclk_ctl_out_clk_2_b_raw,
         rx_wr_clk_raw           => rxclk_ctl_out_rx_wr_clk_raw,
         rx_rd_clk_raw           => rxclk_ctl_out_rx_rd_clk_raw,
         rx_div2_sync_out        => rxclk_ctl_out_rx_div2_sync_out
      );
   
   --/////////////////////////////////////////////////////////////////////////
   -- txclk_ctl_centrl inst ------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   -- s2gx style
   refclk_b <= refclk_pma_out;        -- output to centrl_reset and TX_SM
   
   -- STRATIXIV for bundling
   txclk_ctl_in_pld_tx_clk <= txcoreclk_in;
   txclk_ctl_in_refclk_pma <= centrlclk_ctl_out_refclk_pma_out;
   txclk_ctl_in_txrst <= txrst_int;
   txclk_ctl_in_scan_mode <= scanmode_in;
   txclk_ctl_in_gen2ngen1_bundle <= rateswitchdonein_in;
   txclk_ctl_in_tx_div2_sync_centrl <= txclk_ctl_out_tx_div2_sync_out;
   
   -- Clock selection logic and muxes for refclk_b
   
   mcmu_txclk_ctl : stratixiv_hssi_cmu_txclk_ctl
      PORT MAP (
         pld_tx_clk              => txclk_ctl_in_pld_tx_clk,
         refclk_pma              => txclk_ctl_in_refclk_pma,
         txpma_local_clk         => gnd_wire,
         txrst                   => txclk_ctl_in_txrst,
         scan_mode               => txclk_ctl_in_scan_mode,
         gen2ngen1               => txclk_ctl_in_gen2ngen1_bundle, -- ww35.2008 gnd_wire,
         gen2ngen1_bundle        => txclk_ctl_in_gen2ngen1_bundle,
         tx_div2_sync_centrl     => txclk_ctl_out_tx_div2_sync_out,
         tx_div2_sync_quad_up    => gnd_wire,
         tx_div2_sync_quad_down  => gnd_wire,
         rindv_tx                => vcc_wire,  -- ww35.2008 cram_rindv_tx,
         rtxwrclksel             => cram_rtxwrclksel,
         rtxrdclksel             => cram_rtxrdclksel,
         rdwidth_tx              => cram_rdwidth_tx,
         rfreerun_tx             => cram_rfreerun_tx,
         rauto_speed_ena         => cram_rauto_speed_ena,
         rfreq_sel               => cram_rfreq_sel,
         rtxpcsclkpwdn           => gnd_wire,
         rmaster_tx              => vcc_wire,  -- ww35.2008 cram_rmaster_tx,
         rmaster_up_tx           => cram_rmaster_up_tx,
         rself_sw_en_tx          => gnd_wire,
         
         refclk_b                => txclk_ctl_out_refclk_b,
         wr_clk_pos              => txclk_ctl_out_wr_clk_pos,
         fifo_rd_clk             => txclk_ctl_out_fifo_rd_clk,
         tx_clk_out              => txclk_ctl_out_tx_clk_out,
         refclk_b_raw            => txclk_ctl_out_refclk_b_raw,
         wr_clk_pos_raw          => txclk_ctl_out_wr_clk_pos_raw,
         fifo_rd_clk_raw         => txclk_ctl_out_fifo_rd_clk_raw,
         tx_div2_sync_out        => txclk_ctl_out_tx_div2_sync_out
      );
   
   --/////////////////////////////////////////////////////////////////////////
   -- centrl_reset -------------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   
   PROCESS (qr_out_hard_reset, clk_2_b)
VARIABLE  txt : LINE;
   BEGIN
      IF (qr_out_hard_reset = '1') THEN
         rxrst_sync2 <= '1';
         rxrst_sync1 <= '1';
      ELSIF (clk_2_b'EVENT AND clk_2_b = '1') THEN
         rxrst_sync2 <=  TRANSPORT rxrst_sync1 AFTER 1 ps;
         rxrst_sync1 <= chr_out_rxpcs_rst(0);
      END IF;
   END PROCESS;
   
   
   PROCESS (qr_out_hard_reset, refclk_b)
VARIABLE  txt : LINE;
   BEGIN
      IF (qr_out_hard_reset = '1') THEN
         txrst_sync2 <= '1';
         txrst_sync1 <= '1';
      ELSIF (refclk_b'EVENT AND refclk_b = '1') THEN
         txrst_sync2 <=  TRANSPORT txrst_sync1 AFTER 1 ps;
         txrst_sync1 <= chr_out_txpcs_rst(0);
      END IF;
   END PROCESS;
   
   
   txrst_int <= txrst_sync2;
   rxrst_int <= rxrst_sync2;
   
   --/////////////////////////////////////////////////////////////////////////
   -- auto_speed_neg ------------------------------------------------------ //
   --/////////////////////////////////////////////////////////////////////////
   
   auto_in_refclk <= rxclk_ctl_out_clk_2_b;
   auto_in_rxpcs_rst_int <= rxrst_int;
   auto_in_rate <= rateswitch_in;        -- high gen2 and low gen1 
   auto_in_gen2ngen1 <= rateswitchdonein_in;
   auto_in_config_sel_centrl <= auto_out_config_sel;
   auto_in_config_sel_quad_up <= '0';
   auto_in_config_sel_quad_down <= '0';
   auto_in_singleorbundle <= (NOT(cram_rindv_rx) AND cram_rmaster_rx);
   
   mcmu_auto : stratixiv_hssi_cmu_auto_speed_neg
      PORT MAP (
         refclk                     => auto_in_refclk,
         rxpcs_rst_int              => auto_in_rxpcs_rst_int,
         rate                       => auto_in_rate,
         gen2ngen1                  => auto_in_gen2ngen1,
         config_sel_centrl          => auto_in_config_sel_centrl,
         config_sel_quad_up         => auto_in_config_sel_quad_up,
         config_sel_quad_down       => auto_in_config_sel_quad_down,
         rindv_rx                   => cram_rindv_rx,
         rmaster_rx                 => cram_rmaster_rx,
         rmaster_up_rx              => cram_rmaster_up_rx,
         rauto_speed_ena            => cram_rauto_speed_ena,
         singleorbundle             => auto_in_singleorbundle,
         rphfifo_regmode_rx         => cram_rphfifo_regmode_rx,
         rpma_done_count            => cram_rpma_done_count,
         rauto_deassert_pc_rst_cnt  => cram_rauto_deassert_pc_rst_cnt,
         rauto_pc_en_cnt            => cram_rauto_pc_en_cnt,
         rwait_for_phfifo_cnt       => cram_rwait_for_phfifo_cnt,         
         config_sel                 => auto_out_config_sel,
         pcie_switch                => auto_out_pcie_switch,
         speed_change               => auto_out_speed_change,
         dis_pc_byte                => auto_out_dis_pc_byte,
         reset_pc_ptrs              => auto_out_reset_pc_ptrs,
         cs                         => auto_out_cs
      );
   
   --/////////////////////////////////////////////////////////////////////////
   -- rx_ctl_ctrl --------------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   rxctrl_in_soft_reset <= rxrst_int;        -- from centrl_reset
   rxctrl_in_clk_2 <= rxclk_ctl_out_clk_2_b;
   rxctrl_in_rx_rd_clk <= rxclk_ctl_out_rx_rd_clk;
   rxctrl_in_rx_wr_clk <= rxclk_ctl_out_rx_wr_clk;
   rxctrl_in_scan_mode <= scanmode_in;
   rxctrl_in_rxfifo_urst <= rxphfiforeset_in;
   rxctrl_in_pld_wr_dis <= rxphfifowrdisable_in;
   rxctrl_in_pld_re <= rxphfifordenable_in;
   rxctrl_in_dis_pc_byte <= auto_out_dis_pc_byte;
   
   mcmu_rx_ctrl : stratixiv_hssi_cmu_rx_ctrl
      PORT MAP (
         soft_reset          => rxctrl_in_soft_reset,
         clk_2               => rxctrl_in_clk_2,
         rx_rd_clk           => rxctrl_in_rx_rd_clk,
         rx_wr_clk           => rxctrl_in_rx_wr_clk,
         scan_mode           => rxctrl_in_scan_mode,
         rrxfifo_urst_en     => cram_rrxfifo_urst_en,
         rxfifo_urst         => rxctrl_in_rxfifo_urst,
         rrxphfifopldctl_en  => cram_rrxphfifopldctl_en,
         pld_wr_dis          => rxctrl_in_pld_wr_dis,
         pld_re              => rxctrl_in_pld_re,
         dis_pc_byte         => rxctrl_in_dis_pc_byte,
         rauto_speed_ena     => cram_rauto_speed_ena,
         
         rx_we_out           => rxctrl_out_rx_we_out,
         wr_enable_out       => rxctrl_out_wr_enable_out,
         rd_enable_out       => rxctrl_out_rd_enable_out
      );
   
   --/////////////////////////////////////////////////////////////////////////
   -- rx_ctl_ctrl --------------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   txctrl_in_soft_reset <= txrst_int;
   txctrl_in_fifo_wr_clk <= txclk_ctl_out_wr_clk_pos;
   txctrl_in_fifo_rd_clk <= txclk_ctl_out_fifo_rd_clk;
   txctrl_in_refclk_b_in <= txclk_ctl_out_refclk_b;
   txctrl_in_scan_mode <= scanmode_in;
   txctrl_in_txfifo_urst <= txphfiforeset_in;
   txctrl_in_pld_we <= txphfifowrenable_in;
   txctrl_in_pld_rd_dis <= txphfiforddisable_in;
   txctrl_in_dis_pc_byte <= auto_out_dis_pc_byte;
   
   mcmu_tx_ctrl : stratixiv_hssi_cmu_tx_ctrl
      PORT MAP (
         soft_reset          => txctrl_in_soft_reset,
         fifo_wr_clk         => txctrl_in_fifo_wr_clk,
         fifo_rd_clk         => txctrl_in_fifo_rd_clk,
         refclk_b_in         => txctrl_in_refclk_b_in,
         scan_mode           => txctrl_in_scan_mode,
         rtxfifo_urst_en     => cram_rtxfifo_urst_en,
         txfifo_urst         => txctrl_in_txfifo_urst,
         rtxphfifopldctl_en  => cram_rtxphfifopldctl_en,
         pld_we              => txctrl_in_pld_we,
         pld_rd_dis          => txctrl_in_pld_rd_dis,
         dis_pc_byte         => txctrl_in_dis_pc_byte,
         rauto_speed_ena     => cram_rauto_speed_ena,
         
         wr_enable_out       => txctrl_out_wr_enable_out,
         rd_enable_out       => txctrl_out_rd_enable_out,
         fifo_select_out     => txctrl_out_fifo_select_out
      );
   
   --/////////////////////////////////////////////////////////////////////////
   -- optimization  --------------------------------------------------------//
   --/////////////////////////////////////////////////////////////////////////
   
   PROCESS 
   BEGIN
      init_in_xaui_mode <= mux_select((in_xaui_mode = ("true") OR use_deskew_fifo = ("true")), '1', '0');
      WAIT;
   END PROCESS;
   
   --/////////////////////////////////////////////////////////////////////////
   -- instantiate DSKW SM ------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   
   dskw_sm_clk <= clk_1_b WHEN (init_in_xaui_mode = '1') ELSE
                  '0';
   
   --.clk_1        (clk_1_b),
   xhdl13 <= ("1111" & adet);
   xhdl14 <= ("1111" & rdalign);
   xhdl15 <= ("1111" & syncstatus);
   dskw_sm_1 : stratixiv_hssi_dskw_sm
      PORT MAP (
         soft_reset      => rxrst_int,
         clk_1           => dskw_sm_clk,
         octal_mode      => '0',
         align_det_sync  => xhdl13,
         rd_align        => xhdl14,
         sync_status     => xhdl15,
         align_status    => alignstatus_int,
         enable_deskew   => enabledeskew_xhdl2,
         fifo_reset_rd   => fiforesetrd_xhdl3,
         curr_state      => dskw_curr_st
      );
   
   --/////////////////////////////////////////////////////////////////////////
   -- instantiate TX SM --------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   
   tx_sm_clk <= refclk_b WHEN (init_in_xaui_mode = '1') ELSE
                '0';
   tx_sm_datain <= txdatain WHEN (init_in_xaui_mode = '1') ELSE
                   "00000000000000000000000000000000";
   tx_sm_ctrlin <= txctrl WHEN (init_in_xaui_mode = '1') ELSE
                   "0000";
   tx_sm_rdenablesyncin <= rdenablesync WHEN (init_in_xaui_mode = '1') ELSE
                           '0';
   
   rtx_rx_local_fault_clr_int <= '0';
   rindv_tx_int <= '0';        -- tx sm just sends K when set
   
   tx_sm_1 : stratixiv_hssi_tx_sm
      PORT MAP (
         tx_clk              => tx_sm_clk,
         --.tx_clk             (refclk_b),
         soft_reset          => txrst_int,
         indv                => rindv_tx_int,
         tx_data             => tx_sm_datain,
         --.tx_data            (txdatain),
         tx_ctl              => tx_sm_ctrlin,
         --.tx_ctl             (txctrl),
         rd_enable_sync      => tx_sm_rdenablesyncin,
         --.rd_enable_sync     (rdenablesync), 
         tx_local_fault_clr  => gnd_wire,        --shared with tx_sm
         sm_data             => txdataout_xhdl10,
         sm_ctl              => txctrlout_xhdl9,
         tx_local_fault_det  => tx_local_fault_det,        -- to rcv_sm
         tx_local_fault      => tx_local_fault_int,
         curr_state          => tx_curr_st,
         rxaui_s2gx_en       => cram_rxaui_s2gx_en_tx         
      );
   
   --/////////////////////////////////////////////////////////////////////////
   -- instantiate RX SM --------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   
   rcv_sm_clk <= clk_2_b WHEN (init_in_xaui_mode = '1') ELSE
                 '0';
   rcv_sm_decdatavalid <= rxdatavalid WHEN (init_in_xaui_mode = '1') ELSE
                          "0001";
   rcv_sm_decdata <= rxdatain WHEN (init_in_xaui_mode = '1') ELSE
                     "00000000000000000000000000000000";
   rcv_sm_decctl <= rxctrl WHEN (init_in_xaui_mode = '1') ELSE
                    "0000";
   rcv_sm_rxrunningdisp <= rxrunningdisp WHEN (init_in_xaui_mode = '1') ELSE
                           "0000";
   
   rindv_rx_int <= '0';
   rxs_link_status_set_int <= '0';
   
   rcv_sm_1 : stratixiv_hssi_rcv_sm
      PORT MAP (
         clk_2               => rcv_sm_clk,
         soft_reset          => rxrst_int,
         indv                => rindv_rx_int,
         dec_data_valid      => rcv_sm_decdatavalid,
         dec_data            => rcv_sm_decdata,
         dec_ctl             => rcv_sm_decctl,
         running_disp        => rcv_sm_rxrunningdisp,
         rx_local_fault_clr  => gnd_wire,        --shared with tx_sm
         xs_link_status_set  => gnd_wire,
         tx_local_fault_det  => tx_local_fault_det,        -- from tx_sm
         rx_data_rs          => rxdataout_xhdl6,
         rx_ctl_rs           => rxctrlout_xhdl5,
         rx_local_fault      => rx_local_fault_int,
         xs_link_status      => xs_link_status_int,
         curr_state          => rcv_curr_st,
         rxaui_s2gx_en       => cram_rxaui_s2gx_en_rx         
      );
   
   --/////////////////////////////////////////////////////////////////////////
   -- instantiate DPRIO_CONTROL_TOP --------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   
   port_addr <= int2bin(portaddr, 5) - "00001";        --port_address-1;   int (1-based into 0-based) to 5'b conversion
   dev_addr <= int2bin(devaddr, 5) - "00001";        --device_address-1; int (1-based into 0-based)to 5'b conversion
   
   mdio_in <= dprioin_in;
   mdio_rst <= mdio_rst_reg;        -- ~(plniotri & ~entest & npor);
   PROCESS 
   BEGIN
      mdio_rst_reg <= '1';
      WAIT FOR 1000 ps;
      mdio_rst_reg <= '0';
      WAIT;
   END PROCESS;
   
   cmudprioin <= "00000000000000000000000000000X";
   
   control_top_0 : stratixiv_hssi_cmu_dprio_top
      GENERIC MAP (
         clkdiv0_inclk0_logical_to_physical_mapping  => clkdiv0_inclk0_logical_to_physical_mapping,
         clkdiv0_inclk1_logical_to_physical_mapping  => clkdiv0_inclk1_logical_to_physical_mapping,
         clkdiv1_inclk0_logical_to_physical_mapping  => clkdiv1_inclk0_logical_to_physical_mapping,
         clkdiv1_inclk1_logical_to_physical_mapping  => clkdiv1_inclk1_logical_to_physical_mapping,
         clkdiv2_inclk0_logical_to_physical_mapping  => clkdiv2_inclk0_logical_to_physical_mapping,
         clkdiv2_inclk1_logical_to_physical_mapping  => clkdiv2_inclk1_logical_to_physical_mapping,
         clkdiv3_inclk0_logical_to_physical_mapping  => clkdiv3_inclk0_logical_to_physical_mapping,
         clkdiv3_inclk1_logical_to_physical_mapping  => clkdiv3_inclk1_logical_to_physical_mapping,
         clkdiv4_inclk0_logical_to_physical_mapping  => clkdiv4_inclk0_logical_to_physical_mapping,
         clkdiv4_inclk1_logical_to_physical_mapping  => clkdiv4_inclk1_logical_to_physical_mapping,
         clkdiv5_inclk0_logical_to_physical_mapping  => clkdiv5_inclk0_logical_to_physical_mapping,
         clkdiv5_inclk1_logical_to_physical_mapping  => clkdiv5_inclk1_logical_to_physical_mapping,

         pll0_inclk0_logical_to_physical_mapping     => pll0_inclk0_logical_to_physical_mapping,
         pll0_inclk1_logical_to_physical_mapping     => pll0_inclk1_logical_to_physical_mapping,
         pll0_inclk2_logical_to_physical_mapping     => pll0_inclk2_logical_to_physical_mapping,
         pll0_inclk3_logical_to_physical_mapping     => pll0_inclk3_logical_to_physical_mapping,
         pll0_inclk4_logical_to_physical_mapping     => pll0_inclk4_logical_to_physical_mapping,
         pll0_inclk5_logical_to_physical_mapping     => pll0_inclk5_logical_to_physical_mapping,
         pll0_inclk6_logical_to_physical_mapping     => pll0_inclk6_logical_to_physical_mapping,
         pll0_inclk7_logical_to_physical_mapping     => pll0_inclk7_logical_to_physical_mapping,
         pll0_inclk8_logical_to_physical_mapping     => pll0_inclk8_logical_to_physical_mapping,
         pll0_inclk9_logical_to_physical_mapping     => pll0_inclk9_logical_to_physical_mapping,
         pll1_inclk0_logical_to_physical_mapping     => pll1_inclk0_logical_to_physical_mapping,
         pll1_inclk1_logical_to_physical_mapping     => pll1_inclk1_logical_to_physical_mapping,
         pll1_inclk2_logical_to_physical_mapping     => pll1_inclk2_logical_to_physical_mapping,
         pll1_inclk3_logical_to_physical_mapping     => pll1_inclk3_logical_to_physical_mapping,
         pll1_inclk4_logical_to_physical_mapping     => pll1_inclk4_logical_to_physical_mapping,
         pll1_inclk5_logical_to_physical_mapping     => pll1_inclk5_logical_to_physical_mapping,
         pll1_inclk6_logical_to_physical_mapping     => pll1_inclk6_logical_to_physical_mapping,
         pll1_inclk7_logical_to_physical_mapping     => pll1_inclk7_logical_to_physical_mapping,
         pll1_inclk8_logical_to_physical_mapping     => pll1_inclk8_logical_to_physical_mapping,
         pll1_inclk9_logical_to_physical_mapping     => pll1_inclk9_logical_to_physical_mapping,
         pll2_inclk0_logical_to_physical_mapping     => pll2_inclk0_logical_to_physical_mapping,
         pll2_inclk1_logical_to_physical_mapping     => pll2_inclk1_logical_to_physical_mapping,
         pll2_inclk2_logical_to_physical_mapping     => pll2_inclk2_logical_to_physical_mapping,
         pll2_inclk3_logical_to_physical_mapping     => pll2_inclk3_logical_to_physical_mapping,
         pll2_inclk4_logical_to_physical_mapping     => pll2_inclk4_logical_to_physical_mapping,
         pll2_inclk5_logical_to_physical_mapping     => pll2_inclk5_logical_to_physical_mapping,
         pll2_inclk6_logical_to_physical_mapping     => pll2_inclk6_logical_to_physical_mapping,
         pll2_inclk7_logical_to_physical_mapping     => pll2_inclk7_logical_to_physical_mapping,
         pll2_inclk8_logical_to_physical_mapping     => pll2_inclk8_logical_to_physical_mapping,
         pll2_inclk9_logical_to_physical_mapping     => pll2_inclk9_logical_to_physical_mapping,
         pll3_inclk0_logical_to_physical_mapping     => pll3_inclk0_logical_to_physical_mapping,
         pll3_inclk1_logical_to_physical_mapping     => pll3_inclk1_logical_to_physical_mapping,
         pll3_inclk2_logical_to_physical_mapping     => pll3_inclk2_logical_to_physical_mapping,
         pll3_inclk3_logical_to_physical_mapping     => pll3_inclk3_logical_to_physical_mapping,
         pll3_inclk4_logical_to_physical_mapping     => pll3_inclk4_logical_to_physical_mapping,
         pll3_inclk5_logical_to_physical_mapping     => pll3_inclk5_logical_to_physical_mapping,
         pll3_inclk6_logical_to_physical_mapping     => pll3_inclk6_logical_to_physical_mapping,
         pll3_inclk7_logical_to_physical_mapping     => pll3_inclk7_logical_to_physical_mapping,
         pll3_inclk8_logical_to_physical_mapping     => pll3_inclk8_logical_to_physical_mapping,
         pll3_inclk9_logical_to_physical_mapping     => pll3_inclk9_logical_to_physical_mapping,
         pll4_inclk0_logical_to_physical_mapping     => pll4_inclk0_logical_to_physical_mapping,
         pll4_inclk1_logical_to_physical_mapping     => pll4_inclk1_logical_to_physical_mapping,
         pll4_inclk2_logical_to_physical_mapping     => pll4_inclk2_logical_to_physical_mapping,
         pll4_inclk3_logical_to_physical_mapping     => pll4_inclk3_logical_to_physical_mapping,
         pll4_inclk4_logical_to_physical_mapping     => pll4_inclk4_logical_to_physical_mapping,
         pll4_inclk5_logical_to_physical_mapping     => pll4_inclk5_logical_to_physical_mapping,
         pll4_inclk6_logical_to_physical_mapping     => pll4_inclk6_logical_to_physical_mapping,
         pll4_inclk7_logical_to_physical_mapping     => pll4_inclk7_logical_to_physical_mapping,
         pll4_inclk8_logical_to_physical_mapping     => pll4_inclk8_logical_to_physical_mapping,
         pll4_inclk9_logical_to_physical_mapping     => pll4_inclk9_logical_to_physical_mapping,
         pll5_inclk0_logical_to_physical_mapping     => pll5_inclk0_logical_to_physical_mapping,
         pll5_inclk1_logical_to_physical_mapping     => pll5_inclk1_logical_to_physical_mapping,
         pll5_inclk2_logical_to_physical_mapping     => pll5_inclk2_logical_to_physical_mapping,
         pll5_inclk3_logical_to_physical_mapping     => pll5_inclk3_logical_to_physical_mapping,
         pll5_inclk4_logical_to_physical_mapping     => pll5_inclk4_logical_to_physical_mapping,
         pll5_inclk5_logical_to_physical_mapping     => pll5_inclk5_logical_to_physical_mapping,
         pll5_inclk6_logical_to_physical_mapping     => pll5_inclk6_logical_to_physical_mapping,
         pll5_inclk7_logical_to_physical_mapping     => pll5_inclk7_logical_to_physical_mapping,
         pll5_inclk8_logical_to_physical_mapping     => pll5_inclk8_logical_to_physical_mapping,
         pll5_inclk9_logical_to_physical_mapping     => pll5_inclk9_logical_to_physical_mapping,
         pll0_logical_to_physical_mapping            => pll0_logical_to_physical_mapping,
         pll1_logical_to_physical_mapping            => pll1_logical_to_physical_mapping,
         pll2_logical_to_physical_mapping            => pll2_logical_to_physical_mapping,
         pll3_logical_to_physical_mapping            => pll3_logical_to_physical_mapping,
         pll4_logical_to_physical_mapping            => pll4_logical_to_physical_mapping,
         pll5_logical_to_physical_mapping            => pll5_logical_to_physical_mapping,
         refclk_divider0_logical_to_physical_mapping => refclk_divider0_logical_to_physical_mapping,
         refclk_divider1_logical_to_physical_mapping => refclk_divider1_logical_to_physical_mapping,
         rx0_logical_to_physical_mapping             => rx0_logical_to_physical_mapping,
         rx1_logical_to_physical_mapping             => rx1_logical_to_physical_mapping,
         rx2_logical_to_physical_mapping             => rx2_logical_to_physical_mapping,
         rx3_logical_to_physical_mapping             => rx3_logical_to_physical_mapping,
         rx4_logical_to_physical_mapping             => rx4_logical_to_physical_mapping,
         rx5_logical_to_physical_mapping             => rx5_logical_to_physical_mapping,
         tx0_logical_to_physical_mapping             => tx0_logical_to_physical_mapping,
         tx1_logical_to_physical_mapping             => tx1_logical_to_physical_mapping,
         tx2_logical_to_physical_mapping             => tx2_logical_to_physical_mapping,
         tx3_logical_to_physical_mapping             => tx3_logical_to_physical_mapping,
         tx4_logical_to_physical_mapping             => tx4_logical_to_physical_mapping,
         tx5_logical_to_physical_mapping             => tx5_logical_to_physical_mapping,
         
         tx0_pma_inclk0_logical_to_physical_mapping  => tx0_pma_inclk0_logical_to_physical_mapping,
         tx0_pma_inclk1_logical_to_physical_mapping  => tx0_pma_inclk1_logical_to_physical_mapping,
         tx0_pma_inclk2_logical_to_physical_mapping  => tx0_pma_inclk2_logical_to_physical_mapping,
         tx0_pma_inclk3_logical_to_physical_mapping  => tx0_pma_inclk3_logical_to_physical_mapping,
         tx0_pma_inclk4_logical_to_physical_mapping  => tx0_pma_inclk4_logical_to_physical_mapping,
         tx1_pma_inclk0_logical_to_physical_mapping  => tx1_pma_inclk0_logical_to_physical_mapping,
         tx1_pma_inclk1_logical_to_physical_mapping  => tx1_pma_inclk1_logical_to_physical_mapping,
         tx1_pma_inclk2_logical_to_physical_mapping  => tx1_pma_inclk2_logical_to_physical_mapping,
         tx1_pma_inclk3_logical_to_physical_mapping  => tx1_pma_inclk3_logical_to_physical_mapping,
         tx1_pma_inclk4_logical_to_physical_mapping  => tx1_pma_inclk4_logical_to_physical_mapping,
         tx2_pma_inclk0_logical_to_physical_mapping  => tx2_pma_inclk0_logical_to_physical_mapping,
         tx2_pma_inclk1_logical_to_physical_mapping  => tx2_pma_inclk1_logical_to_physical_mapping,
         tx2_pma_inclk2_logical_to_physical_mapping  => tx2_pma_inclk2_logical_to_physical_mapping,
         tx2_pma_inclk3_logical_to_physical_mapping  => tx2_pma_inclk3_logical_to_physical_mapping,
         tx2_pma_inclk4_logical_to_physical_mapping  => tx2_pma_inclk4_logical_to_physical_mapping,
         tx3_pma_inclk0_logical_to_physical_mapping  => tx3_pma_inclk0_logical_to_physical_mapping,
         tx3_pma_inclk1_logical_to_physical_mapping  => tx3_pma_inclk1_logical_to_physical_mapping,
         tx3_pma_inclk2_logical_to_physical_mapping  => tx3_pma_inclk2_logical_to_physical_mapping,
         tx3_pma_inclk3_logical_to_physical_mapping  => tx3_pma_inclk3_logical_to_physical_mapping,
         tx3_pma_inclk4_logical_to_physical_mapping  => tx3_pma_inclk4_logical_to_physical_mapping,
         tx4_pma_inclk0_logical_to_physical_mapping  => tx4_pma_inclk0_logical_to_physical_mapping,
         tx4_pma_inclk1_logical_to_physical_mapping  => tx4_pma_inclk1_logical_to_physical_mapping,
         tx4_pma_inclk2_logical_to_physical_mapping  => tx4_pma_inclk2_logical_to_physical_mapping,
         tx4_pma_inclk3_logical_to_physical_mapping  => tx4_pma_inclk3_logical_to_physical_mapping,
         tx4_pma_inclk4_logical_to_physical_mapping  => tx4_pma_inclk4_logical_to_physical_mapping,
         tx5_pma_inclk0_logical_to_physical_mapping  => tx5_pma_inclk0_logical_to_physical_mapping,
         tx5_pma_inclk1_logical_to_physical_mapping  => tx5_pma_inclk1_logical_to_physical_mapping,
         tx5_pma_inclk2_logical_to_physical_mapping  => tx5_pma_inclk2_logical_to_physical_mapping,
         tx5_pma_inclk3_logical_to_physical_mapping  => tx5_pma_inclk3_logical_to_physical_mapping,
         tx5_pma_inclk4_logical_to_physical_mapping  => tx5_pma_inclk4_logical_to_physical_mapping,

         sim_dump_dprio_internal_reg_at_time  => sim_dump_dprio_internal_reg_at_time,
         sim_dump_filename                    => sim_dump_filename
      )
      PORT MAP (
         cmudividerdprioin      => cmudividerdprioin,
         cmuplldprioin          => cmuplldprioin,
         refclkdividerdprioin   => refclkdividerdprioin,
         rxpcsdprioin           => rxpcsdprioin,
         rxpmadprioin           => rxpmadprioin,
         txpcsdprioin           => txpcsdprioin,
         txpmadprioin           => txpmadprioin,
         cmudividerdprioout     => cmudividerdprioout_xhdl0,
         cmuplldprioout         => cmuplldprioout_xhdl1,
         refclkdividerdprioout  => refclkdividerdprioout_xhdl4,
         rxpcsdprioout          => rxpcsdprioout_xhdl7,
         rxpmadprioout          => rxpmadprioout_xhdl8,
         txpcsdprioout          => txpcsdprioout_xhdl11,
         txpmadprioout          => txpmadprioout_xhdl12,
         sync_status            => syncstatus,
         align_status           => alignstatus_int,
         dprioload              => dprioload_in,
         mdio_in                => mdio_in,
         mdc                    => dpclk_in,
         port_addr              => port_addr,
         dev_addr               => dev_addr,
         mdio_dis               => dpriodisable_in,
         mdio_rst               => mdio_rst,
         mdio_out               => dprioout_tim,
         data_enable_n          => dpriooe_tim,
         mdio_curr_st           => mdio_curr_st
      );
   
   --/////////////////////////////////////////////////////////////////////////
   -- establish outputs --------------------------------------------------- //
   --/////////////////////////////////////////////////////////////////////////
   
   alignstatus <= alignstatus_int;        -- from dskw_sm
   dpriodisableout <= dpriodisable_in;        -- from top

   -- pcie_rateswitch
   --digitaltestout <= "000000000X";        -- 10 Test ports

    pcie_tmp <=  auto_out_pcie_switch WHEN ( rx0_channel_bonding = ("x4") OR rx0_channel_bonding = ("x8") ) ELSE
                adet(0);
    digitaltestout <= "0000000" & pcie_tmp & "0X";
    
   -- reset and powerdown - everything turns into Active High ---------------
   pllresetout <= ( (NOT(qr_out_cmu1_cru_rstb) OR NOT(qr_out_cmu1_rxpma_rstb)) & (NOT(qr_out_cmu0_cru_rstb) OR NOT(qr_out_cmu0_rxpma_rstb)) );
   quadresetout <= qr_out_hard_reset;
   
   rxadceresetout <= NOT(chr_out_adce_rstb);
   rxanalogresetout <= NOT(chr_out_rxpma_rstb);
   rxcruresetout <= (NOT(chr_out_cru_rstb)) OR (NOT(chr_out_rxpma_rstb));
   rxdigitalresetout <= chr_out_rxpcs_rst;
   txanalogresetout <= NOT(chr_out_txpma_rstb);
   txdigitalresetout <= chr_out_txpcs_rst;
   
   clkdivpowerdn <= (NOT(qr_out_cmu1_cgb_pdb) & NOT(qr_out_cmu0_cgb_pdb));
   pllpowerdn <= (NOT(qr_out_cmu1_cru_pdb) & NOT(qr_out_cmu0_cru_pdb));
   
   rxadcepowerdown <= NOT(chr_out_adce_pdb);
   rxcrupowerdown <= NOT(chr_out_cru_pdb);
   rxibpowerdown <= NOT(chr_out_rx_pdb);
   txdetectrxpowerdown <= NOT(chr_out_rx_det_pdb);
   txdividerpowerdown <= NOT(chr_out_cgb_pdb);
   txobpowerdown <= NOT(chr_out_tx_pdb);
   
   -- ww47_out
   autospdx4configsel <= auto_out_config_sel;
   autospdx4rateswitchout <= auto_out_pcie_switch;
   autospdx4spdchg <= auto_out_speed_change;
   phfifiox4ptrsreset <= auto_out_reset_pc_ptrs;
   rxphfifox4byteselout <= rxctrl_out_rx_we_out;
   rxphfifox4wrclkout <= rxclk_ctl_out_rx_div2_sync_out;
   rxphfifox4rdenableout <= rxctrl_out_rd_enable_out;
   rxphfifox4wrenableout <= rxctrl_out_wr_enable_out;
   scanout <= "ZZZZZZZZZZZZZZZZZZZZZZZ";
   txphfifox4byteselout <= txctrl_out_fifo_select_out;
   txphfifox4rdclkout <= txclk_ctl_out_tx_div2_sync_out;
   txphfifox4rdenableout <= txctrl_out_rd_enable_out;
   txphfifox4wrenableout <= txctrl_out_wr_enable_out;
   
END trans;


--
-- 
-- no digital behavior to simulate
--

LIBRARY IEEE;
USE IEEE.std_logic_1164.ALL;

USE WORK.stratixiv_hssi_components.ALL;
USE IEEE.VITAL_Timing.all;
USE IEEE.VITAL_Primitives.all;

ENTITY stratixiv_hssi_calibration_block IS
    GENERIC (    
          --  generic control parameters  --
       MsgOn                   : Boolean := DefGlitchMsgOn;
       XOn                     : Boolean := DefGlitchXOn;
       MsgOnChecks             : Boolean := DefMsgOnChecks;
       XOnChecks               : Boolean := DefXOnChecks;
       InstancePath            : String := "*";
       TimingChecksOn          : Boolean := True;
          --  tipd  :interconnect path delays --
      tipd_clk                : VitalDelayType01 := DefpropDelay01;
        lpm_type                       :  string  := "stratixiv_hssi_calibration_block";    
        cont_cal_mode                  :  string  := "false";    
        enable_rx_cal_tw               :  string  := "false";    
        enable_tx_cal_tw               :  string  := "false";
        migrated_from_prev_family      :  string  := "false";
        rtest                          :  string  := "false";            
        rx_cal_wt_value                :  integer := 0;    
        send_rx_cal_status             :  string  := "true";
        tx_cal_wt_value                :  integer := 1);   
    PORT (
        clk                            : IN std_logic := '0';   
        enabletestbus                  : IN std_logic := '0';   
        powerdn                        : IN std_logic := '0'; 
        testctrl                       : IN std_logic := '0';           
        calibrationstatus              : OUT std_logic_vector(4 DOWNTO 0);
        nonusertocmu                   : OUT std_logic);   
END stratixiv_hssi_calibration_block;

ARCHITECTURE sim_calib_arch OF stratixiv_hssi_calibration_block IS


    SIGNAL calibrationstatus_xhdl1  :  std_logic_vector(4 DOWNTO 0) := "11111";   

BEGIN
    calibrationstatus <= calibrationstatus_xhdl1;

END sim_calib_arch;

LIBRARY IEEE;
USE IEEE.std_logic_1164.ALL;
USE IEEE.VITAL_Timing.ALL;
USE IEEE.VITAL_Primitives.ALL;

USE WORK.stratixiv_hssi_components.ALL;

USE work.stratixiv_hssi_aux_clock_div;

ENTITY stratixiv_hssi_refclk_divider IS
    GENERIC (
        divider_number : INTEGER := 0;  -- 0 or 1 for logical numbering
        enable_divider : STRING  := "false";
        lpm_type       : STRING  := "stratixiv_hssi_refclk_divider";
        refclk_coupling_termination : STRING := "dc_coupling_external_termination";
        MsgOnChecks: Boolean := DefMsgOnChecks;
        XOnChecks: Boolean := DefXOnChecks;
        tipd_dpriodisable : VitalDelayType01 := DefPropDelay01;
        tipd_dprioin      : VitalDelayType01 := DefPropDelay01;
        tipd_inclk        : VitalDelayType01 := DefPropDelay01;
        tpd_inclk_clkout  : VitalDelayType01 := DefPropDelay01
    );
    PORT (
        dpriodisable            : IN STD_LOGIC := '1';   
        dprioin                 : IN STD_LOGIC := '0';   
        inclk                   : IN STD_LOGIC:= '0';   
        clkout                  : OUT STD_LOGIC;   
        dprioout                : OUT STD_LOGIC);   
END stratixiv_hssi_refclk_divider;

ARCHITECTURE refclk_div_arch OF stratixiv_hssi_refclk_divider IS

    COMPONENT stratixiv_hssi_aux_clock_div
        GENERIC (
            clk_divide_by : INTEGER := 1;
            extra_latency : INTEGER := 0);
        PORT (
            clk                     : IN  STD_LOGIC;
            reset                   : IN  STD_LOGIC := '0';
	    powerdown               : IN  STD_LOGIC := '0';
            enable_d                : IN STD_LOGIC := '0';
            d                       : IN STD_LOGIC_VECTOR(7 DOWNTO 0) := "00000001";
            clkout                  : OUT STD_LOGIC);
    END COMPONENT;

    SIGNAL inclk_ipd                :  STD_LOGIC;
    SIGNAL dprioin_ipd              :  STD_LOGIC;
    SIGNAL dpriodisable_ipd         :  STD_LOGIC;

    SIGNAL divide_by_2_clk          :  STD_LOGIC; 
    SIGNAL divide_by_2_out          :  STD_LOGIC; 

    SIGNAL tmp_clkout_sig : STD_LOGIC;

BEGIN

    WireDelay : BLOCK
    BEGIN
        VitalWireDelay (inclk_ipd, inclk, tipd_inclk);
        VitalWireDelay (dprioin_ipd, dprioin, tipd_dprioin);
        VitalWireDelay (dpriodisable_ipd, dpriodisable, tipd_dpriodisable);
    END BLOCK;

    VITALTIMING : process(tmp_clkout_sig)
    VARIABLE clkout_VitalGlitchData : VitalGlitchDataType;
    VARIABLE tmp_clkout : STD_LOGIC;
    BEGIN
    
        tmp_clkout := tmp_clkout_sig;
        
        VitalPathDelay01 
        (
            OutSignal => clkout,
            OutSignalName => "CLKOUT",
            OutTemp => tmp_clkout,
            Paths => (
                        0 => (inclk_ipd'last_event, tpd_inclk_clkout, TRUE)
                     ),
            GlitchData => clkout_VitalGlitchData,
            Mode => DefGlitchMode,
            XOn => XOnChecks,
            MsgOn => MsgOnChecks
        );
    
    END process;
    
    divide_by_2_clk <= '0' WHEN (enable_divider = "false") ELSE inclk_ipd;
    tmp_clkout_sig  <= inclk_ipd WHEN (enable_divider = "false") ELSE divide_by_2_out;
    
    divide_by_2 : stratixiv_hssi_aux_clock_div 
        GENERIC MAP (
            clk_divide_by => 2,
            extra_latency => 0)
        PORT MAP (
            clk    => divide_by_2_clk, 
            clkout => divide_by_2_out);   
    
    
    dprioout <= '0' WHEN (dpriodisable_ipd = '1') ELSE dprioin_ipd;

END refclk_div_arch;
